// This file is @generated by crates/typos-vars/tests/codegen.rs
#![allow(clippy::unreadable_literal, clippy::type_complexity)]

pub type Variants = &'static [&'static str];
pub type VariantsMap = [Variants; 4];

pub fn all_categories() -> crate::CategorySet {
    crate::Category::American
        | crate::Category::BritishIse
        | crate::Category::Canadian
        | crate::Category::Australian
}

pub fn corrections(category: crate::Category, options: VariantsMap) -> &'static [&'static str] {
    match category {
        crate::Category::American => options[0],
        crate::Category::BritishIse => options[1],
        crate::Category::Canadian => options[2],
        crate::Category::Australian => options[3],
        crate::Category::BritishIze | crate::Category::Other => {
            unreachable!("{:?} is unused", category)
        }
    }
}

pub static VARS_TRIE: dictgen::DictTrie<&[(u8, &VariantsMap)]> = dictgen::DictTrie {
    root: &VARS_NODE,
    unicode: &VARS_UNICODE_TABLE,
    range: 2..=24,
};

pub static VARS_UNICODE_TABLE: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CHILDREN),
    value: None,
};

static VARS_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_A_NODE),
    Some(&VARS_B_NODE),
    Some(&VARS_C_NODE),
    Some(&VARS_D_NODE),
    Some(&VARS_E_NODE),
    Some(&VARS_F_NODE),
    Some(&VARS_G_NODE),
    Some(&VARS_H_NODE),
    Some(&VARS_I_NODE),
    Some(&VARS_J_NODE),
    Some(&VARS_K_NODE),
    Some(&VARS_L_NODE),
    Some(&VARS_M_NODE),
    Some(&VARS_N_NODE),
    Some(&VARS_O_NODE),
    Some(&VARS_P_NODE),
    Some(&VARS_Q_NODE),
    Some(&VARS_R_NODE),
    Some(&VARS_S_NODE),
    Some(&VARS_T_NODE),
    Some(&VARS_U_NODE),
    Some(&VARS_V_NODE),
    Some(&VARS_W_NODE),
    None,
    Some(&VARS_Y_NODE),
    Some(&VARS_Z_NODE),
];

static VARS_Z_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_Z_CHILDREN),
    value: None,
};

pub static VARS_Z_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("affer"),
        dictgen::InsensitiveStr::Ascii("affers"),
        dictgen::InsensitiveStr::Ascii("affre"),
        dictgen::InsensitiveStr::Ascii("affres"),
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("eas"),
        dictgen::InsensitiveStr::Ascii("eroise"),
        dictgen::InsensitiveStr::Ascii("eroised"),
        dictgen::InsensitiveStr::Ascii("eroises"),
        dictgen::InsensitiveStr::Ascii("eroising"),
        dictgen::InsensitiveStr::Ascii("eroize"),
        dictgen::InsensitiveStr::Ascii("eroized"),
        dictgen::InsensitiveStr::Ascii("eroizes"),
        dictgen::InsensitiveStr::Ascii("eroizing"),
        dictgen::InsensitiveStr::Ascii("oaea"),
        dictgen::InsensitiveStr::Ascii("oea"),
        dictgen::InsensitiveStr::Ascii("oeae"),
        dictgen::InsensitiveStr::Ascii("oeal"),
        dictgen::InsensitiveStr::Ascii("oeas"),
        dictgen::InsensitiveStr::Ascii("oecia"),
        dictgen::InsensitiveStr::Ascii("oecium"),
        dictgen::InsensitiveStr::Ascii("onaesthesia"),
        dictgen::InsensitiveStr::Ascii("onesthesia"),
        dictgen::InsensitiveStr::Ascii("onulae"),
        dictgen::InsensitiveStr::Ascii("onule"),
        dictgen::InsensitiveStr::Ascii("ooea"),
        dictgen::InsensitiveStr::Ascii("ooeae"),
        dictgen::InsensitiveStr::Ascii("ooeal"),
        dictgen::InsensitiveStr::Ascii("ooeas"),
        dictgen::InsensitiveStr::Ascii("ooecia"),
        dictgen::InsensitiveStr::Ascii("ooecium"),
        dictgen::InsensitiveStr::Ascii("ooglea"),
        dictgen::InsensitiveStr::Ascii("oogleae"),
        dictgen::InsensitiveStr::Ascii("oogleal"),
        dictgen::InsensitiveStr::Ascii("oogleas"),
        dictgen::InsensitiveStr::Ascii("oogloea"),
        dictgen::InsensitiveStr::Ascii("oogloeae"),
        dictgen::InsensitiveStr::Ascii("oogloeal"),
        dictgen::InsensitiveStr::Ascii("oogloeas"),
        dictgen::InsensitiveStr::Ascii("ygaenid"),
        dictgen::InsensitiveStr::Ascii("ygenid"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ZAFFER_1782028266821462296)],
        &[(0b00001, &ENTRY_ZAFFERS_18135861342380490241)],
        &[(0b11010, &ENTRY_ZAFFER_1782028266821462296)],
        &[(0b11010, &ENTRY_ZAFFERS_18135861342380490241)],
        &[(0b00001, &ENTRY_ZEA_18144512594597847862)],
        &[(0b00001, &ENTRY_ZEAS_5878550334347614910)],
        &[(0b10010, &ENTRY_ZEROIZE_12861688847880490798)],
        &[(0b10010, &ENTRY_ZEROIZED_14083500582707636275)],
        &[(0b10010, &ENTRY_ZEROIZES_18412755642364966459)],
        &[(0b10010, &ENTRY_ZEROIZING_11012654682606419940)],
        &[(0b01001, &ENTRY_ZEROIZE_12861688847880490798)],
        &[(0b01001, &ENTRY_ZEROIZED_14083500582707636275)],
        &[(0b01001, &ENTRY_ZEROIZES_18412755642364966459)],
        &[(0b01001, &ENTRY_ZEROIZING_11012654682606419940)],
        &[(0b11010, &ENTRY_ZOEA_5407976721583269765)],
        &[
            (0b11010, &ENTRY_ZEA_18144512594597847862),
            (0b00001, &ENTRY_ZOEA_5407976721583269765),
            (0b00001, &ENTRY_ZOEA_7677728383051875918),
        ],
        &[(0b00001, &ENTRY_ZOEAE_6587921986871953627)],
        &[(0b00001, &ENTRY_ZOEAL_10183908722620440824)],
        &[
            (0b11010, &ENTRY_ZEAS_5878550334347614910),
            (0b00001, &ENTRY_ZOEAS_681757442323763522),
        ],
        &[(0b00001, &ENTRY_ZOECIA_3187153722664521655)],
        &[(0b00001, &ENTRY_ZOECIUM_6905291993571367110)],
        &[(0b11010, &ENTRY_ZONESTHESIA_5241288651423447523)],
        &[(0b00001, &ENTRY_ZONESTHESIA_5241288651423447523)],
        &[(0b11010, &ENTRY_ZONULE_9256134977663685758)],
        &[(0b00001, &ENTRY_ZONULE_9256134977663685758)],
        &[(0b11010, &ENTRY_ZOEA_7677728383051875918)],
        &[(0b11010, &ENTRY_ZOEAE_6587921986871953627)],
        &[(0b11010, &ENTRY_ZOEAL_10183908722620440824)],
        &[(0b11010, &ENTRY_ZOEAS_681757442323763522)],
        &[(0b11010, &ENTRY_ZOECIA_3187153722664521655)],
        &[(0b11010, &ENTRY_ZOECIUM_6905291993571367110)],
        &[(0b00001, &ENTRY_ZOOGLEA_12784694771058649379)],
        &[(0b00001, &ENTRY_ZOOGLEAE_1475063023468604603)],
        &[(0b00001, &ENTRY_ZOOGLEAL_8144222639814201645)],
        &[(0b00001, &ENTRY_ZOOGLEAS_18230224253523630238)],
        &[(0b11010, &ENTRY_ZOOGLEA_12784694771058649379)],
        &[(0b11010, &ENTRY_ZOOGLEAE_1475063023468604603)],
        &[(0b11010, &ENTRY_ZOOGLEAL_8144222639814201645)],
        &[(0b11010, &ENTRY_ZOOGLEAS_18230224253523630238)],
        &[(0b11010, &ENTRY_ZYGENID_6699911520066413279)],
        &[(0b00001, &ENTRY_ZYGENID_6699911520066413279)],
    ],
    range: 2..=11,
};

static VARS_Y_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_Y_CHILDREN),
    value: None,
};

pub static VARS_Y_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("odeled"),
        dictgen::InsensitiveStr::Ascii("odeler"),
        dictgen::InsensitiveStr::Ascii("odelers"),
        dictgen::InsensitiveStr::Ascii("odeling"),
        dictgen::InsensitiveStr::Ascii("odelled"),
        dictgen::InsensitiveStr::Ascii("odeller"),
        dictgen::InsensitiveStr::Ascii("odellers"),
        dictgen::InsensitiveStr::Ascii("odelling"),
        dictgen::InsensitiveStr::Ascii("oghourt"),
        dictgen::InsensitiveStr::Ascii("oghourts"),
        dictgen::InsensitiveStr::Ascii("oghurt"),
        dictgen::InsensitiveStr::Ascii("oghurts"),
        dictgen::InsensitiveStr::Ascii("ogourt"),
        dictgen::InsensitiveStr::Ascii("ogourts"),
    ],
    values: &[
        &[(0b01001, &ENTRY_YODELED_15671817307109302642)],
        &[(0b01001, &ENTRY_YODELER_7988137706216703211)],
        &[(0b01001, &ENTRY_YODELERS_18010970770053754843)],
        &[(0b01001, &ENTRY_YODELING_5584968248317185710)],
        &[(0b11010, &ENTRY_YODELED_15671817307109302642)],
        &[(0b11010, &ENTRY_YODELER_7988137706216703211)],
        &[(0b11010, &ENTRY_YODELERS_18010970770053754843)],
        &[(0b11010, &ENTRY_YODELING_5584968248317185710)],
        &[(0b10010, &ENTRY_YOGURT_4836021873407169494)],
        &[(0b10010, &ENTRY_YOGURTS_12979282136707959016)],
        &[(0b11010, &ENTRY_YOGURT_4836021873407169494)],
        &[(0b11010, &ENTRY_YOGURTS_12979282136707959016)],
        &[(0b01000, &ENTRY_YOGURT_4836021873407169494)],
        &[(0b01000, &ENTRY_YOGURTS_12979282136707959016)],
    ],
    range: 6..=8,
};

static VARS_W_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_W_CHILDREN),
    value: None,
};

static VARS_W_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_WA_NODE),
    None,
    None,
    None,
    Some(&VARS_WE_NODE),
    None,
    None,
    Some(&VARS_WH_NODE),
    Some(&VARS_WI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_WO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_WO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_WO_CHILDREN),
    value: None,
};

pub static VARS_WO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("manisation"),
        dictgen::InsensitiveStr::Ascii("manisations"),
        dictgen::InsensitiveStr::Ascii("manise"),
        dictgen::InsensitiveStr::Ascii("manised"),
        dictgen::InsensitiveStr::Ascii("maniser"),
        dictgen::InsensitiveStr::Ascii("manisers"),
        dictgen::InsensitiveStr::Ascii("manises"),
        dictgen::InsensitiveStr::Ascii("manising"),
        dictgen::InsensitiveStr::Ascii("manization"),
        dictgen::InsensitiveStr::Ascii("manizations"),
        dictgen::InsensitiveStr::Ascii("manize"),
        dictgen::InsensitiveStr::Ascii("manized"),
        dictgen::InsensitiveStr::Ascii("manizer"),
        dictgen::InsensitiveStr::Ascii("manizers"),
        dictgen::InsensitiveStr::Ascii("manizes"),
        dictgen::InsensitiveStr::Ascii("manizing"),
        dictgen::InsensitiveStr::Ascii("odcockise"),
        dictgen::InsensitiveStr::Ascii("odcockises"),
        dictgen::InsensitiveStr::Ascii("odcockize"),
        dictgen::InsensitiveStr::Ascii("odcockizes"),
        dictgen::InsensitiveStr::Ascii("olen"),
        dictgen::InsensitiveStr::Ascii("olenization"),
        dictgen::InsensitiveStr::Ascii("olenizations"),
        dictgen::InsensitiveStr::Ascii("olenize"),
        dictgen::InsensitiveStr::Ascii("olenizes"),
        dictgen::InsensitiveStr::Ascii("olenner"),
        dictgen::InsensitiveStr::Ascii("olennest"),
        dictgen::InsensitiveStr::Ascii("olens"),
        dictgen::InsensitiveStr::Ascii("ollen"),
        dictgen::InsensitiveStr::Ascii("ollenisation"),
        dictgen::InsensitiveStr::Ascii("ollenisations"),
        dictgen::InsensitiveStr::Ascii("ollenise"),
        dictgen::InsensitiveStr::Ascii("ollenises"),
        dictgen::InsensitiveStr::Ascii("ollenization"),
        dictgen::InsensitiveStr::Ascii("ollenizations"),
        dictgen::InsensitiveStr::Ascii("ollenize"),
        dictgen::InsensitiveStr::Ascii("ollenizes"),
        dictgen::InsensitiveStr::Ascii("ollenner"),
        dictgen::InsensitiveStr::Ascii("ollennest"),
        dictgen::InsensitiveStr::Ascii("ollens"),
        dictgen::InsensitiveStr::Ascii("rnil"),
        dictgen::InsensitiveStr::Ascii("rshiped"),
        dictgen::InsensitiveStr::Ascii("rshiper"),
        dictgen::InsensitiveStr::Ascii("rshipers"),
        dictgen::InsensitiveStr::Ascii("rshiping"),
        dictgen::InsensitiveStr::Ascii("rshipped"),
        dictgen::InsensitiveStr::Ascii("rshipper"),
        dictgen::InsensitiveStr::Ascii("rshippers"),
        dictgen::InsensitiveStr::Ascii("rshipping"),
        dictgen::InsensitiveStr::Ascii("urnil"),
    ],
    values: &[
        &[(0b10010, &ENTRY_WOMANIZATION_2912095657356208823)],
        &[(0b10010, &ENTRY_WOMANIZATIONS_6214286373586139061)],
        &[(0b10010, &ENTRY_WOMANIZE_13944014032617070061)],
        &[(0b10010, &ENTRY_WOMANIZED_6823201211994765463)],
        &[(0b10010, &ENTRY_WOMANIZER_12959923156017407936)],
        &[(0b10010, &ENTRY_WOMANIZERS_2730363125830539583)],
        &[(0b10010, &ENTRY_WOMANIZES_1396386385917615542)],
        &[(0b10010, &ENTRY_WOMANIZING_14010372556431313508)],
        &[(0b01001, &ENTRY_WOMANIZATION_2912095657356208823)],
        &[(0b01001, &ENTRY_WOMANIZATIONS_6214286373586139061)],
        &[(0b01001, &ENTRY_WOMANIZE_13944014032617070061)],
        &[(0b01001, &ENTRY_WOMANIZED_6823201211994765463)],
        &[(0b01001, &ENTRY_WOMANIZER_12959923156017407936)],
        &[(0b01001, &ENTRY_WOMANIZERS_2730363125830539583)],
        &[(0b01001, &ENTRY_WOMANIZES_1396386385917615542)],
        &[(0b01001, &ENTRY_WOMANIZING_14010372556431313508)],
        &[(0b10010, &ENTRY_WOODCOCKIZE_5663866505253252015)],
        &[(0b10010, &ENTRY_WOODCOCKIZES_14952192357364422589)],
        &[(0b01001, &ENTRY_WOODCOCKIZE_5663866505253252015)],
        &[(0b01001, &ENTRY_WOODCOCKIZES_14952192357364422589)],
        &[(0b01001, &ENTRY_WOOLEN_16877039187309954068)],
        &[(0b00001, &ENTRY_WOOLENIZATION_8391870250405491314)],
        &[(0b00001, &ENTRY_WOOLENIZATIONS_9008183640003333341)],
        &[(0b00001, &ENTRY_WOOLENIZE_5989697679481924564)],
        &[(0b00001, &ENTRY_WOOLENIZES_13915140718286830624)],
        &[(0b01001, &ENTRY_WOOLENNER_16121158420209065321)],
        &[(0b01001, &ENTRY_WOOLENNEST_9962428894247675717)],
        &[(0b01001, &ENTRY_WOOLENS_6397410426801008847)],
        &[(0b11010, &ENTRY_WOOLEN_16877039187309954068)],
        &[(0b10010, &ENTRY_WOOLENIZATION_8391870250405491314)],
        &[(0b10010, &ENTRY_WOOLENIZATIONS_9008183640003333341)],
        &[(0b10010, &ENTRY_WOOLENIZE_5989697679481924564)],
        &[(0b10010, &ENTRY_WOOLENIZES_13915140718286830624)],
        &[(0b01000, &ENTRY_WOOLENIZATION_8391870250405491314)],
        &[(0b01000, &ENTRY_WOOLENIZATIONS_9008183640003333341)],
        &[(0b01000, &ENTRY_WOOLENIZE_5989697679481924564)],
        &[(0b01000, &ENTRY_WOOLENIZES_13915140718286830624)],
        &[(0b11010, &ENTRY_WOOLENNER_16121158420209065321)],
        &[(0b11010, &ENTRY_WOOLENNEST_9962428894247675717)],
        &[(0b11010, &ENTRY_WOOLENS_6397410426801008847)],
        &[(0b00001, &ENTRY_WORNIL_15281974950870959304)],
        &[(0b00001, &ENTRY_WORSHIPED_13801735218945656036)],
        &[(0b00001, &ENTRY_WORSHIPER_9520180601499296676)],
        &[(0b00001, &ENTRY_WORSHIPERS_2792179872387820015)],
        &[(0b00001, &ENTRY_WORSHIPING_9531564570456686375)],
        &[(0b11010, &ENTRY_WORSHIPED_13801735218945656036)],
        &[(0b11010, &ENTRY_WORSHIPER_9520180601499296676)],
        &[(0b11010, &ENTRY_WORSHIPERS_2792179872387820015)],
        &[(0b11010, &ENTRY_WORSHIPING_9531564570456686375)],
        &[(0b11010, &ENTRY_WORNIL_15281974950870959304)],
    ],
    range: 4..=13,
};

static VARS_WI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_WI_CHILDREN),
    value: None,
};

pub static VARS_WI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lfullier"),
        dictgen::InsensitiveStr::Ascii("lfulliest"),
        dictgen::InsensitiveStr::Ascii("lfully"),
        dictgen::InsensitiveStr::Ascii("llful"),
        dictgen::InsensitiveStr::Ascii("llfuler"),
        dictgen::InsensitiveStr::Ascii("llfulest"),
        dictgen::InsensitiveStr::Ascii("llfullier"),
        dictgen::InsensitiveStr::Ascii("llfulliest"),
        dictgen::InsensitiveStr::Ascii("llfully"),
        dictgen::InsensitiveStr::Ascii("llfulness"),
        dictgen::InsensitiveStr::Ascii("nterisation"),
        dictgen::InsensitiveStr::Ascii("nterisations"),
        dictgen::InsensitiveStr::Ascii("nterise"),
        dictgen::InsensitiveStr::Ascii("nterised"),
        dictgen::InsensitiveStr::Ascii("nterises"),
        dictgen::InsensitiveStr::Ascii("nterising"),
        dictgen::InsensitiveStr::Ascii("nterization"),
        dictgen::InsensitiveStr::Ascii("nterizations"),
        dictgen::InsensitiveStr::Ascii("nterize"),
        dictgen::InsensitiveStr::Ascii("nterized"),
        dictgen::InsensitiveStr::Ascii("nterizes"),
        dictgen::InsensitiveStr::Ascii("nterizing"),
        dictgen::InsensitiveStr::Ascii("sen"),
        dictgen::InsensitiveStr::Ascii("zen"),
    ],
    values: &[
        &[(0b11010, &ENTRY_WILLFULLIER_15285733710201810363)],
        &[(0b11010, &ENTRY_WILLFULLIEST_1229078038469558436)],
        &[(0b11010, &ENTRY_WILLFULLY_11177950727637010120)],
        &[(0b01001, &ENTRY_WILLFUL_888733828666730475)],
        &[(0b01001, &ENTRY_WILLFULER_5381487143875928951)],
        &[(0b01001, &ENTRY_WILLFULEST_14812841215434133378)],
        &[(0b00001, &ENTRY_WILLFULLIER_15285733710201810363)],
        &[(0b00001, &ENTRY_WILLFULLIEST_1229078038469558436)],
        &[(0b00001, &ENTRY_WILLFULLY_11177950727637010120)],
        &[(0b00001, &ENTRY_WILLFULNESS_10353200066895422050)],
        &[(0b10010, &ENTRY_WINTERIZATION_347749948628387205)],
        &[(0b10010, &ENTRY_WINTERIZATIONS_10939012107648324861)],
        &[(0b10010, &ENTRY_WINTERIZE_2183252607445844863)],
        &[(0b10010, &ENTRY_WINTERIZED_13138859505846530038)],
        &[(0b10010, &ENTRY_WINTERIZES_6133753376693721696)],
        &[(0b10010, &ENTRY_WINTERIZING_3911142690065298063)],
        &[(0b01001, &ENTRY_WINTERIZATION_347749948628387205)],
        &[(0b01001, &ENTRY_WINTERIZATIONS_10939012107648324861)],
        &[(0b01001, &ENTRY_WINTERIZE_2183252607445844863)],
        &[(0b01001, &ENTRY_WINTERIZED_13138859505846530038)],
        &[(0b01001, &ENTRY_WINTERIZES_6133753376693721696)],
        &[(0b01001, &ENTRY_WINTERIZING_3911142690065298063)],
        &[(0b10010, &ENTRY_WIZEN_4334319069968315511)],
        &[(0b01001, &ENTRY_WIZEN_4334319069968315511)],
    ],
    range: 3..=12,
};

static VARS_WH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_WH_CHILDREN),
    value: None,
};

pub static VARS_WH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iskeys"),
        dictgen::InsensitiveStr::Ascii("itmanise"),
        dictgen::InsensitiveStr::Ascii("itmanises"),
        dictgen::InsensitiveStr::Ascii("itmanize"),
        dictgen::InsensitiveStr::Ascii("itmanizes"),
    ],
    values: &[
        &[(0b01001, &ENTRY_WHISKEYS_7436468433370877238)],
        &[(0b10010, &ENTRY_WHITMANIZE_12604676802077785810)],
        &[(0b10010, &ENTRY_WHITMANIZES_14406113232286981648)],
        &[(0b01001, &ENTRY_WHITMANIZE_12604676802077785810)],
        &[(0b01001, &ENTRY_WHITMANIZES_14406113232286981648)],
    ],
    range: 6..=9,
};

static VARS_WE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_WE_CHILDREN),
    value: None,
};

pub static VARS_WE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aseled"),
        dictgen::InsensitiveStr::Ascii("aseling"),
        dictgen::InsensitiveStr::Ascii("aselled"),
        dictgen::InsensitiveStr::Ascii("aselling"),
        dictgen::InsensitiveStr::Ascii("atherise"),
        dictgen::InsensitiveStr::Ascii("atherised"),
        dictgen::InsensitiveStr::Ascii("atherises"),
        dictgen::InsensitiveStr::Ascii("atherising"),
        dictgen::InsensitiveStr::Ascii("atherize"),
        dictgen::InsensitiveStr::Ascii("atherized"),
        dictgen::InsensitiveStr::Ascii("atherizes"),
        dictgen::InsensitiveStr::Ascii("atherizing"),
        dictgen::InsensitiveStr::Ascii("eviled"),
        dictgen::InsensitiveStr::Ascii("evilled"),
        dictgen::InsensitiveStr::Ascii("ftwise"),
        dictgen::InsensitiveStr::Ascii("ftwize"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("sternisation"),
        dictgen::InsensitiveStr::Ascii("sternisations"),
        dictgen::InsensitiveStr::Ascii("sternise"),
        dictgen::InsensitiveStr::Ascii("sternised"),
        dictgen::InsensitiveStr::Ascii("sternises"),
        dictgen::InsensitiveStr::Ascii("sternising"),
        dictgen::InsensitiveStr::Ascii("sternization"),
        dictgen::InsensitiveStr::Ascii("sternizations"),
        dictgen::InsensitiveStr::Ascii("sternize"),
        dictgen::InsensitiveStr::Ascii("sternized"),
        dictgen::InsensitiveStr::Ascii("sternizes"),
        dictgen::InsensitiveStr::Ascii("sternizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_WEASELED_7269396054259240547)],
        &[(0b01001, &ENTRY_WEASELING_2632216130329270938)],
        &[(0b10010, &ENTRY_WEASELED_7269396054259240547)],
        &[(0b10010, &ENTRY_WEASELING_2632216130329270938)],
        &[(0b10010, &ENTRY_WEATHERIZE_4961563587908804252)],
        &[(0b10010, &ENTRY_WEATHERIZED_18030948967314137256)],
        &[(0b10010, &ENTRY_WEATHERIZES_761792162885352580)],
        &[(0b10010, &ENTRY_WEATHERIZING_10998488814413655578)],
        &[(0b01001, &ENTRY_WEATHERIZE_4961563587908804252)],
        &[(0b01001, &ENTRY_WEATHERIZED_18030948967314137256)],
        &[(0b01001, &ENTRY_WEATHERIZES_761792162885352580)],
        &[(0b01001, &ENTRY_WEATHERIZING_10998488814413655578)],
        &[(0b00001, &ENTRY_WEEVILED_5671527057159191731)],
        &[(0b11010, &ENTRY_WEEVILED_5671527057159191731)],
        &[(0b10010, &ENTRY_WEFTWIZE_18228736157171688040)],
        &[(0b01001, &ENTRY_WEFTWIZE_18228736157171688040)],
        &[(0b10010, &ENTRY_WEIZE_4692929171720256071)],
        &[(0b10010, &ENTRY_WEIZED_11856800976027190563)],
        &[(0b10010, &ENTRY_WEIZES_7549448166735182951)],
        &[(0b10010, &ENTRY_WEIZING_13035760845280706799)],
        &[(0b01001, &ENTRY_WEIZE_4692929171720256071)],
        &[(0b01001, &ENTRY_WEIZED_11856800976027190563)],
        &[(0b01001, &ENTRY_WEIZES_7549448166735182951)],
        &[(0b01001, &ENTRY_WEIZING_13035760845280706799)],
        &[(0b00001, &ENTRY_WER_11639588756994874397)],
        &[(0b10010, &ENTRY_WESTERNIZATION_10693435618580655065)],
        &[(0b10010, &ENTRY_WESTERNIZATIONS_17887310843739967172)],
        &[(0b10010, &ENTRY_WESTERNIZE_11346667543067253389)],
        &[(0b10010, &ENTRY_WESTERNIZED_17634020200167691104)],
        &[(0b10010, &ENTRY_WESTERNIZES_4968126506243709279)],
        &[(0b10010, &ENTRY_WESTERNIZING_14820707154271141813)],
        &[(0b01001, &ENTRY_WESTERNIZATION_10693435618580655065)],
        &[(0b01001, &ENTRY_WESTERNIZATIONS_17887310843739967172)],
        &[(0b01001, &ENTRY_WESTERNIZE_11346667543067253389)],
        &[(0b01001, &ENTRY_WESTERNIZED_17634020200167691104)],
        &[(0b01001, &ENTRY_WESTERNIZES_4968126506243709279)],
        &[(0b01001, &ENTRY_WESTERNIZING_14820707154271141813)],
    ],
    range: 1..=13,
};

static VARS_WA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_WA_CHILDREN),
    value: None,
};

pub static VARS_WA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ckes"),
        dictgen::InsensitiveStr::Ascii("ckoes"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ggon"),
        dictgen::InsensitiveStr::Ascii("ggoned"),
        dictgen::InsensitiveStr::Ascii("ggoneer"),
        dictgen::InsensitiveStr::Ascii("ggoner"),
        dictgen::InsensitiveStr::Ascii("ggoners"),
        dictgen::InsensitiveStr::Ascii("ggonette"),
        dictgen::InsensitiveStr::Ascii("ggonettes"),
        dictgen::InsensitiveStr::Ascii("ggoning"),
        dictgen::InsensitiveStr::Ascii("ggons"),
        dictgen::InsensitiveStr::Ascii("gnerise"),
        dictgen::InsensitiveStr::Ascii("gnerises"),
        dictgen::InsensitiveStr::Ascii("gnerize"),
        dictgen::InsensitiveStr::Ascii("gnerizes"),
        dictgen::InsensitiveStr::Ascii("ntonise"),
        dictgen::InsensitiveStr::Ascii("ntonised"),
        dictgen::InsensitiveStr::Ascii("ntonises"),
        dictgen::InsensitiveStr::Ascii("ntonising"),
        dictgen::InsensitiveStr::Ascii("ntonize"),
        dictgen::InsensitiveStr::Ascii("ntonized"),
        dictgen::InsensitiveStr::Ascii("ntonizes"),
        dictgen::InsensitiveStr::Ascii("ntonizing"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rford"),
        dictgen::InsensitiveStr::Ascii("rfourd"),
        dictgen::InsensitiveStr::Ascii("rrantise"),
        dictgen::InsensitiveStr::Ascii("rrantize"),
        dictgen::InsensitiveStr::Ascii("rre"),
        dictgen::InsensitiveStr::Ascii("tercolor"),
        dictgen::InsensitiveStr::Ascii("tercolored"),
        dictgen::InsensitiveStr::Ascii("tercoloring"),
        dictgen::InsensitiveStr::Ascii("tercolorist"),
        dictgen::InsensitiveStr::Ascii("tercolorists"),
        dictgen::InsensitiveStr::Ascii("tercolors"),
        dictgen::InsensitiveStr::Ascii("tercolour"),
        dictgen::InsensitiveStr::Ascii("tercoloured"),
        dictgen::InsensitiveStr::Ascii("tercolouring"),
        dictgen::InsensitiveStr::Ascii("tercolourist"),
        dictgen::InsensitiveStr::Ascii("tercolourists"),
        dictgen::InsensitiveStr::Ascii("tercolours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_WACKES_510047826766852133)],
        &[(0b11010, &ENTRY_WACKES_510047826766852133)],
        &[(0b11010, &ENTRY_WER_11639588756994874397)],
        &[(0b10010, &ENTRY_WAGON_5335298714004042393)],
        &[(0b10010, &ENTRY_WAGONED_18404896035191047132)],
        &[(0b11010, &ENTRY_WAGONEER_7695357654896841244)],
        &[(0b10010, &ENTRY_WAGONER_11432045632874199662)],
        &[(0b10010, &ENTRY_WAGONERS_6388316509001104344)],
        &[(0b10010, &ENTRY_WAGONETTE_3903149371449355531)],
        &[(0b10010, &ENTRY_WAGONETTES_2415032088297891551)],
        &[(0b10010, &ENTRY_WAGONING_2887560265469426881)],
        &[(0b10010, &ENTRY_WAGONS_11395031855637672578)],
        &[(0b10010, &ENTRY_WAGNERIZE_5769761765957663761)],
        &[(0b10010, &ENTRY_WAGNERIZES_16225753643669617315)],
        &[(0b01001, &ENTRY_WAGNERIZE_5769761765957663761)],
        &[(0b01001, &ENTRY_WAGNERIZES_16225753643669617315)],
        &[(0b10010, &ENTRY_WANTONIZE_4641875869566290004)],
        &[(0b10010, &ENTRY_WANTONIZED_10968755963901267296)],
        &[(0b10010, &ENTRY_WANTONIZES_2129137010298333861)],
        &[(0b10010, &ENTRY_WANTONIZING_3889295691274401356)],
        &[(0b01001, &ENTRY_WANTONIZE_4641875869566290004)],
        &[(0b01001, &ENTRY_WANTONIZED_10968755963901267296)],
        &[(0b01001, &ENTRY_WANTONIZES_2129137010298333861)],
        &[(0b01001, &ENTRY_WANTONIZING_3889295691274401356)],
        &[(0b00001, &ENTRY_WARER_11382540724162869048)],
        &[(0b00001, &ENTRY_WARFORD_16540495906064731465)],
        &[(0b11010, &ENTRY_WARFORD_16540495906064731465)],
        &[(0b10010, &ENTRY_WARRANTIZE_4993893254884557601)],
        &[(0b01001, &ENTRY_WARRANTIZE_4993893254884557601)],
        &[(0b11010, &ENTRY_WARER_11382540724162869048)],
        &[(0b11001, &ENTRY_WATERCOLOR_1242471837856686461)],
        &[(0b11001, &ENTRY_WATERCOLORED_551761815331700825)],
        &[(0b11001, &ENTRY_WATERCOLORING_7585263825752051770)],
        &[(0b00001, &ENTRY_WATERCOLORIST_15171920726508503979)],
        &[(0b00001, &ENTRY_WATERCOLORISTS_16203366413065930985)],
        &[(0b11001, &ENTRY_WATERCOLORS_9935320064817263087)],
        &[(0b11010, &ENTRY_WATERCOLOR_1242471837856686461)],
        &[(0b11010, &ENTRY_WATERCOLORED_551761815331700825)],
        &[(0b11010, &ENTRY_WATERCOLORING_7585263825752051770)],
        &[(0b11010, &ENTRY_WATERCOLORIST_15171920726508503979)],
        &[(0b11010, &ENTRY_WATERCOLORISTS_16203366413065930985)],
        &[(0b11010, &ENTRY_WATERCOLORS_9935320064817263087)],
    ],
    range: 2..=13,
};

static VARS_V_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_V_CHILDREN),
    value: None,
};

static VARS_V_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_VA_NODE),
    None,
    None,
    None,
    Some(&VARS_VE_NODE),
    None,
    None,
    None,
    Some(&VARS_VI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_VU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VU_CHILDREN),
    value: None,
};

pub static VARS_VU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lcanisable"),
        dictgen::InsensitiveStr::Ascii("lcanisabler"),
        dictgen::InsensitiveStr::Ascii("lcanisables"),
        dictgen::InsensitiveStr::Ascii("lcanisablest"),
        dictgen::InsensitiveStr::Ascii("lcanisate"),
        dictgen::InsensitiveStr::Ascii("lcanisates"),
        dictgen::InsensitiveStr::Ascii("lcanisation"),
        dictgen::InsensitiveStr::Ascii("lcanisations"),
        dictgen::InsensitiveStr::Ascii("lcanise"),
        dictgen::InsensitiveStr::Ascii("lcanised"),
        dictgen::InsensitiveStr::Ascii("lcaniser"),
        dictgen::InsensitiveStr::Ascii("lcanisers"),
        dictgen::InsensitiveStr::Ascii("lcanises"),
        dictgen::InsensitiveStr::Ascii("lcanising"),
        dictgen::InsensitiveStr::Ascii("lcanizable"),
        dictgen::InsensitiveStr::Ascii("lcanizabler"),
        dictgen::InsensitiveStr::Ascii("lcanizables"),
        dictgen::InsensitiveStr::Ascii("lcanizablest"),
        dictgen::InsensitiveStr::Ascii("lcanizate"),
        dictgen::InsensitiveStr::Ascii("lcanizates"),
        dictgen::InsensitiveStr::Ascii("lcanization"),
        dictgen::InsensitiveStr::Ascii("lcanizations"),
        dictgen::InsensitiveStr::Ascii("lcanize"),
        dictgen::InsensitiveStr::Ascii("lcanized"),
        dictgen::InsensitiveStr::Ascii("lcanizer"),
        dictgen::InsensitiveStr::Ascii("lcanizers"),
        dictgen::InsensitiveStr::Ascii("lcanizes"),
        dictgen::InsensitiveStr::Ascii("lcanizing"),
        dictgen::InsensitiveStr::Ascii("lgarisation"),
        dictgen::InsensitiveStr::Ascii("lgarisations"),
        dictgen::InsensitiveStr::Ascii("lgarise"),
        dictgen::InsensitiveStr::Ascii("lgarised"),
        dictgen::InsensitiveStr::Ascii("lgariser"),
        dictgen::InsensitiveStr::Ascii("lgarisers"),
        dictgen::InsensitiveStr::Ascii("lgarises"),
        dictgen::InsensitiveStr::Ascii("lgarising"),
        dictgen::InsensitiveStr::Ascii("lgarization"),
        dictgen::InsensitiveStr::Ascii("lgarizations"),
        dictgen::InsensitiveStr::Ascii("lgarize"),
        dictgen::InsensitiveStr::Ascii("lgarized"),
        dictgen::InsensitiveStr::Ascii("lgarizer"),
        dictgen::InsensitiveStr::Ascii("lgarizers"),
        dictgen::InsensitiveStr::Ascii("lgarizes"),
        dictgen::InsensitiveStr::Ascii("lgarizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VULCANIZABLE_12933258001910720543)],
        &[(0b10010, &ENTRY_VULCANIZABLER_5626985747083053444)],
        &[(0b10010, &ENTRY_VULCANIZABLES_1003331057376447528)],
        &[(0b10010, &ENTRY_VULCANIZABLEST_7532718328423894637)],
        &[(0b10010, &ENTRY_VULCANIZATE_11388221665594117242)],
        &[(0b10010, &ENTRY_VULCANIZATES_4114082830948149633)],
        &[(0b10010, &ENTRY_VULCANIZATION_7905884940104482341)],
        &[(0b10010, &ENTRY_VULCANIZATIONS_15847832065617865889)],
        &[(0b10010, &ENTRY_VULCANIZE_6585960079549072743)],
        &[(0b10010, &ENTRY_VULCANIZED_14313743718177692805)],
        &[(0b10010, &ENTRY_VULCANIZER_9826867449740889574)],
        &[(0b10010, &ENTRY_VULCANIZERS_17322632051634463265)],
        &[(0b10010, &ENTRY_VULCANIZES_16377609962408860153)],
        &[(0b10010, &ENTRY_VULCANIZING_13984517742257009109)],
        &[(0b01001, &ENTRY_VULCANIZABLE_12933258001910720543)],
        &[(0b01001, &ENTRY_VULCANIZABLER_5626985747083053444)],
        &[(0b01001, &ENTRY_VULCANIZABLES_1003331057376447528)],
        &[(0b01001, &ENTRY_VULCANIZABLEST_7532718328423894637)],
        &[(0b01001, &ENTRY_VULCANIZATE_11388221665594117242)],
        &[(0b01001, &ENTRY_VULCANIZATES_4114082830948149633)],
        &[(0b01001, &ENTRY_VULCANIZATION_7905884940104482341)],
        &[(0b01001, &ENTRY_VULCANIZATIONS_15847832065617865889)],
        &[(0b01001, &ENTRY_VULCANIZE_6585960079549072743)],
        &[(0b01001, &ENTRY_VULCANIZED_14313743718177692805)],
        &[(0b01001, &ENTRY_VULCANIZER_9826867449740889574)],
        &[(0b01001, &ENTRY_VULCANIZERS_17322632051634463265)],
        &[(0b01001, &ENTRY_VULCANIZES_16377609962408860153)],
        &[(0b01001, &ENTRY_VULCANIZING_13984517742257009109)],
        &[(0b10010, &ENTRY_VULGARIZATION_15527570270767072109)],
        &[(0b10010, &ENTRY_VULGARIZATIONS_8843218827275212658)],
        &[(0b10010, &ENTRY_VULGARIZE_6707031466678228051)],
        &[(0b10010, &ENTRY_VULGARIZED_8073979986420271297)],
        &[(0b10010, &ENTRY_VULGARIZER_9773650239919878284)],
        &[(0b10010, &ENTRY_VULGARIZERS_15985805307582944778)],
        &[(0b10010, &ENTRY_VULGARIZES_645579138050710392)],
        &[(0b10010, &ENTRY_VULGARIZING_6396108281264937628)],
        &[(0b01001, &ENTRY_VULGARIZATION_15527570270767072109)],
        &[(0b01001, &ENTRY_VULGARIZATIONS_8843218827275212658)],
        &[(0b01001, &ENTRY_VULGARIZE_6707031466678228051)],
        &[(0b01001, &ENTRY_VULGARIZED_8073979986420271297)],
        &[(0b01001, &ENTRY_VULGARIZER_9773650239919878284)],
        &[(0b01001, &ENTRY_VULGARIZERS_15985805307582944778)],
        &[(0b01001, &ENTRY_VULGARIZES_645579138050710392)],
        &[(0b01001, &ENTRY_VULGARIZING_6396108281264937628)],
    ],
    range: 7..=12,
};

static VARS_VO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_VO_CHILDREN),
    value: None,
};

static VARS_VO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_VOC_NODE),
    None,
    Some(&VARS_VOE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VOL_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VOW_NODE),
    None,
    None,
    None,
];

static VARS_VOW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VOW_CHILDREN),
    value: None,
};

pub static VARS_VOW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elisation"),
        dictgen::InsensitiveStr::Ascii("elisations"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elising"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elizations"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("elizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VOWELIZATION_8028405167364651675)],
        &[(0b10010, &ENTRY_VOWELIZATIONS_9949470389871637399)],
        &[(0b10010, &ENTRY_VOWELIZE_11831882778950051901)],
        &[(0b10010, &ENTRY_VOWELIZED_13363070483633135702)],
        &[(0b10010, &ENTRY_VOWELIZES_15733936200840210114)],
        &[(0b10010, &ENTRY_VOWELIZING_15780479645088969618)],
        &[(0b01001, &ENTRY_VOWELIZATION_8028405167364651675)],
        &[(0b01001, &ENTRY_VOWELIZATIONS_9949470389871637399)],
        &[(0b01001, &ENTRY_VOWELIZE_11831882778950051901)],
        &[(0b01001, &ENTRY_VOWELIZED_13363070483633135702)],
        &[(0b01001, &ENTRY_VOWELIZES_15733936200840210114)],
        &[(0b01001, &ENTRY_VOWELIZING_15780479645088969618)],
    ],
    range: 5..=10,
};

static VARS_VOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VOL_CHILDREN),
    value: None,
};

pub static VARS_VOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atilisable"),
        dictgen::InsensitiveStr::Ascii("atilisabler"),
        dictgen::InsensitiveStr::Ascii("atilisables"),
        dictgen::InsensitiveStr::Ascii("atilisablest"),
        dictgen::InsensitiveStr::Ascii("atilisation"),
        dictgen::InsensitiveStr::Ascii("atilisations"),
        dictgen::InsensitiveStr::Ascii("atilise"),
        dictgen::InsensitiveStr::Ascii("atilised"),
        dictgen::InsensitiveStr::Ascii("atiliser"),
        dictgen::InsensitiveStr::Ascii("atilisers"),
        dictgen::InsensitiveStr::Ascii("atilises"),
        dictgen::InsensitiveStr::Ascii("atilising"),
        dictgen::InsensitiveStr::Ascii("atilizable"),
        dictgen::InsensitiveStr::Ascii("atilizabler"),
        dictgen::InsensitiveStr::Ascii("atilizables"),
        dictgen::InsensitiveStr::Ascii("atilizablest"),
        dictgen::InsensitiveStr::Ascii("atilization"),
        dictgen::InsensitiveStr::Ascii("atilizations"),
        dictgen::InsensitiveStr::Ascii("atilize"),
        dictgen::InsensitiveStr::Ascii("atilized"),
        dictgen::InsensitiveStr::Ascii("atilizer"),
        dictgen::InsensitiveStr::Ascii("atilizers"),
        dictgen::InsensitiveStr::Ascii("atilizes"),
        dictgen::InsensitiveStr::Ascii("atilizing"),
        dictgen::InsensitiveStr::Ascii("canisation"),
        dictgen::InsensitiveStr::Ascii("canisations"),
        dictgen::InsensitiveStr::Ascii("canise"),
        dictgen::InsensitiveStr::Ascii("canised"),
        dictgen::InsensitiveStr::Ascii("canises"),
        dictgen::InsensitiveStr::Ascii("canising"),
        dictgen::InsensitiveStr::Ascii("canization"),
        dictgen::InsensitiveStr::Ascii("canizations"),
        dictgen::InsensitiveStr::Ascii("canize"),
        dictgen::InsensitiveStr::Ascii("canized"),
        dictgen::InsensitiveStr::Ascii("canizes"),
        dictgen::InsensitiveStr::Ascii("canizing"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VOLATILIZABLE_10168029689535730959)],
        &[(0b10010, &ENTRY_VOLATILIZABLER_15124316039469427064)],
        &[(0b10010, &ENTRY_VOLATILIZABLES_10994615031924961365)],
        &[(0b10010, &ENTRY_VOLATILIZABLEST_1211109177921536207)],
        &[(0b10010, &ENTRY_VOLATILIZATION_3221641183281199106)],
        &[(0b10010, &ENTRY_VOLATILIZATIONS_8168537470161802057)],
        &[(0b10010, &ENTRY_VOLATILIZE_16270565871743863998)],
        &[(0b10010, &ENTRY_VOLATILIZED_13699473491173599192)],
        &[(0b10010, &ENTRY_VOLATILIZER_967038296345618448)],
        &[(0b10010, &ENTRY_VOLATILIZERS_13014590752496196530)],
        &[(0b10010, &ENTRY_VOLATILIZES_14953405067501371419)],
        &[(0b10010, &ENTRY_VOLATILIZING_9187797455588347418)],
        &[(0b01001, &ENTRY_VOLATILIZABLE_10168029689535730959)],
        &[(0b01001, &ENTRY_VOLATILIZABLER_15124316039469427064)],
        &[(0b01001, &ENTRY_VOLATILIZABLES_10994615031924961365)],
        &[(0b01001, &ENTRY_VOLATILIZABLEST_1211109177921536207)],
        &[(0b01001, &ENTRY_VOLATILIZATION_3221641183281199106)],
        &[(0b01001, &ENTRY_VOLATILIZATIONS_8168537470161802057)],
        &[(0b01001, &ENTRY_VOLATILIZE_16270565871743863998)],
        &[(0b01001, &ENTRY_VOLATILIZED_13699473491173599192)],
        &[(0b01001, &ENTRY_VOLATILIZER_967038296345618448)],
        &[(0b01001, &ENTRY_VOLATILIZERS_13014590752496196530)],
        &[(0b01001, &ENTRY_VOLATILIZES_14953405067501371419)],
        &[(0b01001, &ENTRY_VOLATILIZING_9187797455588347418)],
        &[(0b10010, &ENTRY_VOLCANIZATION_8985433655421469811)],
        &[(0b10010, &ENTRY_VOLCANIZATIONS_11356670470517236039)],
        &[(0b10010, &ENTRY_VOLCANIZE_15707442069580141816)],
        &[(0b10010, &ENTRY_VOLCANIZED_7831688113853222131)],
        &[(0b10010, &ENTRY_VOLCANIZES_14691477153026326923)],
        &[(0b10010, &ENTRY_VOLCANIZING_16325307602678280336)],
        &[(0b01001, &ENTRY_VOLCANIZATION_8985433655421469811)],
        &[(0b01001, &ENTRY_VOLCANIZATIONS_11356670470517236039)],
        &[(0b01001, &ENTRY_VOLCANIZE_15707442069580141816)],
        &[(0b01001, &ENTRY_VOLCANIZED_7831688113853222131)],
        &[(0b01001, &ENTRY_VOLCANIZES_14691477153026326923)],
        &[(0b01001, &ENTRY_VOLCANIZING_16325307602678280336)],
        &[(0b10010, &ENTRY_VOLTIZE_3168582630243886919)],
        &[(0b10010, &ENTRY_VOLTIZES_13001217679494650700)],
        &[(0b01001, &ENTRY_VOLTIZE_3168582630243886919)],
        &[(0b01001, &ENTRY_VOLTIZES_13001217679494650700)],
    ],
    range: 4..=12,
};

static VARS_VOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VOE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_VE_5155558316755050493)]),
};

pub static VARS_VOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_VOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VOC_CHILDREN),
    value: None,
};

pub static VARS_VOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("ationalisation"),
        dictgen::InsensitiveStr::Ascii("ationalisations"),
        dictgen::InsensitiveStr::Ascii("ationalise"),
        dictgen::InsensitiveStr::Ascii("ationalises"),
        dictgen::InsensitiveStr::Ascii("ationalization"),
        dictgen::InsensitiveStr::Ascii("ationalizations"),
        dictgen::InsensitiveStr::Ascii("ationalize"),
        dictgen::InsensitiveStr::Ascii("ationalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VOCALIZATION_3101814292430397767)],
        &[(0b10010, &ENTRY_VOCALIZATIONS_17133298955574595735)],
        &[(0b10010, &ENTRY_VOCALIZE_4185858433777108713)],
        &[(0b10010, &ENTRY_VOCALIZED_10488165785915354680)],
        &[(0b10010, &ENTRY_VOCALIZER_16276723661570906787)],
        &[(0b10010, &ENTRY_VOCALIZERS_16676498064430857034)],
        &[(0b10010, &ENTRY_VOCALIZES_9022405961253042006)],
        &[(0b10010, &ENTRY_VOCALIZING_6360195233059633529)],
        &[(0b01001, &ENTRY_VOCALIZATION_3101814292430397767)],
        &[(0b01001, &ENTRY_VOCALIZATIONS_17133298955574595735)],
        &[(0b01001, &ENTRY_VOCALIZE_4185858433777108713)],
        &[(0b01001, &ENTRY_VOCALIZED_10488165785915354680)],
        &[(0b01001, &ENTRY_VOCALIZER_16276723661570906787)],
        &[(0b01001, &ENTRY_VOCALIZERS_16676498064430857034)],
        &[(0b01001, &ENTRY_VOCALIZES_9022405961253042006)],
        &[(0b01001, &ENTRY_VOCALIZING_6360195233059633529)],
        &[(0b10010, &ENTRY_VOCATIONALIZATION_16884053563133857076)],
        &[(0b10010, &ENTRY_VOCATIONALIZATIONS_645102237578435655)],
        &[(0b10010, &ENTRY_VOCATIONALIZE_484999010571215919)],
        &[(0b10010, &ENTRY_VOCATIONALIZES_4008731000111938679)],
        &[(0b01001, &ENTRY_VOCATIONALIZATION_16884053563133857076)],
        &[(0b01001, &ENTRY_VOCATIONALIZATIONS_645102237578435655)],
        &[(0b01001, &ENTRY_VOCATIONALIZE_484999010571215919)],
        &[(0b01001, &ENTRY_VOCATIONALIZES_4008731000111938679)],
    ],
    range: 5..=15,
};

static VARS_VI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_VI_CHILDREN),
    value: None,
};

static VARS_VI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_VIA_NODE),
    None,
    Some(&VARS_VIC_NODE),
    Some(&VARS_VID_NODE),
    Some(&VARS_VIE_NODE),
    None,
    Some(&VARS_VIG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_VIL_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VIR_NODE),
    Some(&VARS_VIS_NODE),
    Some(&VARS_VIT_NODE),
    None,
    Some(&VARS_VIV_NODE),
    None,
    None,
    None,
    Some(&VARS_VIZ_NODE),
];

static VARS_VIZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIZ_CHILDREN),
    value: None,
};

pub static VARS_VIZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ard"),
        dictgen::InsensitiveStr::Ascii("ards"),
        dictgen::InsensitiveStr::Ascii("ied"),
        dictgen::InsensitiveStr::Ascii("ies"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ors"),
    ],
    values: &[
        &[(0b01001, &ENTRY_VIZARD_2639323971974804824)],
        &[(0b01001, &ENTRY_VIZARDS_9340526966771883402)],
        &[(0b01001, &ENTRY_VIZIED_795958706997274905)],
        &[(0b01001, &ENTRY_VIZIES_8365615820765009417)],
        &[(0b10011, &ENTRY_VISOR_6793712644535862367)],
        &[(0b10011, &ENTRY_VISORS_134473816422776887)],
    ],
    range: 2..=4,
};

static VARS_VIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIV_CHILDREN),
    value: None,
};

pub static VARS_VIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("andier"),
        dictgen::InsensitiveStr::Ascii("andire"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("errinae"),
        dictgen::InsensitiveStr::Ascii("errine"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("res"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VIVANDIER_12796368736143739188)],
        &[(0b11010, &ENTRY_VIVANDIER_12796368736143739188)],
        &[(0b00001, &ENTRY_VIVER_8964657704628755516)],
        &[(0b11010, &ENTRY_VIVERRINE_13661408646720182258)],
        &[(0b00001, &ENTRY_VIVERRINE_13661408646720182258)],
        &[(0b00001, &ENTRY_VIVERS_10514623990192410896)],
        &[(0b11010, &ENTRY_VIVER_8964657704628755516)],
        &[(0b11010, &ENTRY_VIVERS_10514623990192410896)],
    ],
    range: 2..=7,
};

static VARS_VIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIT_CHILDREN),
    value: None,
};

pub static VARS_VIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alisingly"),
        dictgen::InsensitiveStr::Ascii("alisings"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("alizingly"),
        dictgen::InsensitiveStr::Ascii("alizings"),
        dictgen::InsensitiveStr::Ascii("aminisation"),
        dictgen::InsensitiveStr::Ascii("aminise"),
        dictgen::InsensitiveStr::Ascii("aminised"),
        dictgen::InsensitiveStr::Ascii("aminises"),
        dictgen::InsensitiveStr::Ascii("aminising"),
        dictgen::InsensitiveStr::Ascii("aminization"),
        dictgen::InsensitiveStr::Ascii("aminize"),
        dictgen::InsensitiveStr::Ascii("aminized"),
        dictgen::InsensitiveStr::Ascii("aminizes"),
        dictgen::InsensitiveStr::Ascii("aminizing"),
        dictgen::InsensitiveStr::Ascii("riolisable"),
        dictgen::InsensitiveStr::Ascii("riolisables"),
        dictgen::InsensitiveStr::Ascii("riolisation"),
        dictgen::InsensitiveStr::Ascii("riolisations"),
        dictgen::InsensitiveStr::Ascii("riolise"),
        dictgen::InsensitiveStr::Ascii("riolised"),
        dictgen::InsensitiveStr::Ascii("rioliser"),
        dictgen::InsensitiveStr::Ascii("riolisers"),
        dictgen::InsensitiveStr::Ascii("riolises"),
        dictgen::InsensitiveStr::Ascii("riolising"),
        dictgen::InsensitiveStr::Ascii("riolizable"),
        dictgen::InsensitiveStr::Ascii("riolizables"),
        dictgen::InsensitiveStr::Ascii("riolization"),
        dictgen::InsensitiveStr::Ascii("riolizations"),
        dictgen::InsensitiveStr::Ascii("riolize"),
        dictgen::InsensitiveStr::Ascii("riolized"),
        dictgen::InsensitiveStr::Ascii("riolizer"),
        dictgen::InsensitiveStr::Ascii("riolizers"),
        dictgen::InsensitiveStr::Ascii("riolizes"),
        dictgen::InsensitiveStr::Ascii("riolizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VITALIZATION_6622991581175063916)],
        &[(0b10010, &ENTRY_VITALIZATIONS_10201411925742357344)],
        &[(0b10010, &ENTRY_VITALIZE_6481155641390081467)],
        &[(0b10010, &ENTRY_VITALIZED_4801592680431520472)],
        &[(0b10010, &ENTRY_VITALIZER_6854541332740985774)],
        &[(0b10010, &ENTRY_VITALIZERS_16513879370855291377)],
        &[(0b10010, &ENTRY_VITALIZES_3154160873090627908)],
        &[(0b10010, &ENTRY_VITALIZING_5684293940323598911)],
        &[(0b10010, &ENTRY_VITALIZINGLY_3721526376897688302)],
        &[(0b10010, &ENTRY_VITALIZINGS_3549538285617044596)],
        &[(0b01001, &ENTRY_VITALIZATION_6622991581175063916)],
        &[(0b01001, &ENTRY_VITALIZATIONS_10201411925742357344)],
        &[(0b01001, &ENTRY_VITALIZE_6481155641390081467)],
        &[(0b01001, &ENTRY_VITALIZED_4801592680431520472)],
        &[(0b01001, &ENTRY_VITALIZER_6854541332740985774)],
        &[(0b01001, &ENTRY_VITALIZERS_16513879370855291377)],
        &[(0b01001, &ENTRY_VITALIZES_3154160873090627908)],
        &[(0b01001, &ENTRY_VITALIZING_5684293940323598911)],
        &[(0b01001, &ENTRY_VITALIZINGLY_3721526376897688302)],
        &[(0b01001, &ENTRY_VITALIZINGS_3549538285617044596)],
        &[(0b10010, &ENTRY_VITAMINIZATION_8611340282933462961)],
        &[(0b10010, &ENTRY_VITAMINIZE_9229796811292738647)],
        &[(0b10010, &ENTRY_VITAMINIZED_4419964457316336553)],
        &[(0b10010, &ENTRY_VITAMINIZES_5130824241734522496)],
        &[(0b10010, &ENTRY_VITAMINIZING_9349914309549143713)],
        &[(0b01001, &ENTRY_VITAMINIZATION_8611340282933462961)],
        &[(0b01001, &ENTRY_VITAMINIZE_9229796811292738647)],
        &[(0b01001, &ENTRY_VITAMINIZED_4419964457316336553)],
        &[(0b01001, &ENTRY_VITAMINIZES_5130824241734522496)],
        &[(0b01001, &ENTRY_VITAMINIZING_9349914309549143713)],
        &[(0b10010, &ENTRY_VITRIOLIZABLE_17310862678824970477)],
        &[(0b10010, &ENTRY_VITRIOLIZABLES_2644365146835371145)],
        &[(0b10010, &ENTRY_VITRIOLIZATION_4706708016116909857)],
        &[(0b10010, &ENTRY_VITRIOLIZATIONS_10025992055840934495)],
        &[(0b10010, &ENTRY_VITRIOLIZE_2463142402858277228)],
        &[(0b10010, &ENTRY_VITRIOLIZED_1910528837394386896)],
        &[(0b10010, &ENTRY_VITRIOLIZER_3565340187130070331)],
        &[(0b10010, &ENTRY_VITRIOLIZERS_11660516492851129479)],
        &[(0b10010, &ENTRY_VITRIOLIZES_6916423318398411349)],
        &[(0b10010, &ENTRY_VITRIOLIZING_3937845223854221826)],
        &[(0b01001, &ENTRY_VITRIOLIZABLE_17310862678824970477)],
        &[(0b01001, &ENTRY_VITRIOLIZABLES_2644365146835371145)],
        &[(0b01001, &ENTRY_VITRIOLIZATION_4706708016116909857)],
        &[(0b01001, &ENTRY_VITRIOLIZATIONS_10025992055840934495)],
        &[(0b01001, &ENTRY_VITRIOLIZE_2463142402858277228)],
        &[(0b01001, &ENTRY_VITRIOLIZED_1910528837394386896)],
        &[(0b01001, &ENTRY_VITRIOLIZER_3565340187130070331)],
        &[(0b01001, &ENTRY_VITRIOLIZERS_11660516492851129479)],
        &[(0b01001, &ENTRY_VITRIOLIZES_6916423318398411349)],
        &[(0b01001, &ENTRY_VITRIOLIZING_3937845223854221826)],
    ],
    range: 5..=12,
};

static VARS_VIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIS_CHILDREN),
    value: None,
};

pub static VARS_VIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ard"),
        dictgen::InsensitiveStr::Ascii("ards"),
        dictgen::InsensitiveStr::Ascii("ied"),
        dictgen::InsensitiveStr::Ascii("ies"),
        dictgen::InsensitiveStr::Ascii("ionise"),
        dictgen::InsensitiveStr::Ascii("ionises"),
        dictgen::InsensitiveStr::Ascii("ionize"),
        dictgen::InsensitiveStr::Ascii("ionizes"),
        dictgen::InsensitiveStr::Ascii("ualisable"),
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualiser"),
        dictgen::InsensitiveStr::Ascii("ualisers"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualizable"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizer"),
        dictgen::InsensitiveStr::Ascii("ualizers"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VIZARD_2639323971974804824)],
        &[(0b10010, &ENTRY_VIZARDS_9340526966771883402)],
        &[(0b10010, &ENTRY_VIZIED_795958706997274905)],
        &[(0b10010, &ENTRY_VIZIES_8365615820765009417)],
        &[(0b10010, &ENTRY_VISIONIZE_17590832811892481012)],
        &[(0b10010, &ENTRY_VISIONIZES_5651557240049522584)],
        &[(0b01001, &ENTRY_VISIONIZE_17590832811892481012)],
        &[(0b01001, &ENTRY_VISIONIZES_5651557240049522584)],
        &[(0b10010, &ENTRY_VISUALIZABLE_4488080677314869313)],
        &[(0b10010, &ENTRY_VISUALIZATION_17562130536164744176)],
        &[(0b10010, &ENTRY_VISUALIZATIONS_18350724909305357812)],
        &[(0b10010, &ENTRY_VISUALIZE_11481052441218524608)],
        &[(0b10010, &ENTRY_VISUALIZED_4674981066915252884)],
        &[(0b10010, &ENTRY_VISUALIZER_2048106900160833279)],
        &[(0b10010, &ENTRY_VISUALIZERS_17582533695928893219)],
        &[(0b10010, &ENTRY_VISUALIZES_127948688781322581)],
        &[(0b10010, &ENTRY_VISUALIZING_8899358108480045240)],
        &[(0b01001, &ENTRY_VISUALIZABLE_4488080677314869313)],
        &[(0b01001, &ENTRY_VISUALIZATION_17562130536164744176)],
        &[(0b01001, &ENTRY_VISUALIZATIONS_18350724909305357812)],
        &[(0b01001, &ENTRY_VISUALIZE_11481052441218524608)],
        &[(0b01001, &ENTRY_VISUALIZED_4674981066915252884)],
        &[(0b01001, &ENTRY_VISUALIZER_2048106900160833279)],
        &[(0b01001, &ENTRY_VISUALIZERS_17582533695928893219)],
        &[(0b01001, &ENTRY_VISUALIZES_127948688781322581)],
        &[(0b01001, &ENTRY_VISUALIZING_8899358108480045240)],
    ],
    range: 3..=11,
};

static VARS_VIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIR_CHILDREN),
    value: None,
};

pub static VARS_VIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("aemias"),
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emias"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
        dictgen::InsensitiveStr::Ascii("tualisation"),
        dictgen::InsensitiveStr::Ascii("tualise"),
        dictgen::InsensitiveStr::Ascii("tualises"),
        dictgen::InsensitiveStr::Ascii("tualization"),
        dictgen::InsensitiveStr::Ascii("tualize"),
        dictgen::InsensitiveStr::Ascii("tualizes"),
        dictgen::InsensitiveStr::Ascii("tuosoes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_VIREMIA_18098587143582639437)],
        &[(0b11010, &ENTRY_VIREMIAS_11493695761490485429)],
        &[(0b11010, &ENTRY_VIREMIC_15410392453836001545)],
        &[(0b11010, &ENTRY_VIER_13580000022985666082)],
        &[(0b00001, &ENTRY_VIREMIA_18098587143582639437)],
        &[(0b00001, &ENTRY_VIREMIAS_11493695761490485429)],
        &[(0b00001, &ENTRY_VIREMIC_15410392453836001545)],
        &[(0b11010, &ENTRY_VIERS_14228033346609932442)],
        &[(0b10010, &ENTRY_VIRILIZATION_12310404704293015767)],
        &[(0b10010, &ENTRY_VIRILIZATIONS_18121305511677110671)],
        &[(0b10010, &ENTRY_VIRILIZED_4676286724956217154)],
        &[(0b10010, &ENTRY_VIRILIZING_10763847981856232025)],
        &[(0b01001, &ENTRY_VIRILIZATION_12310404704293015767)],
        &[(0b01001, &ENTRY_VIRILIZATIONS_18121305511677110671)],
        &[(0b01001, &ENTRY_VIRILIZED_4676286724956217154)],
        &[(0b01001, &ENTRY_VIRILIZING_10763847981856232025)],
        &[(0b11010, &ENTRY_VIRTUALIZATION_12995073314893119762)],
        &[(0b10010, &ENTRY_VIRTUALIZE_18433638723664756869)],
        &[(0b10010, &ENTRY_VIRTUALIZES_8235670628188929025)],
        &[(0b00001, &ENTRY_VIRTUALIZATION_12995073314893119762)],
        &[(0b01001, &ENTRY_VIRTUALIZE_18433638723664756869)],
        &[(0b01001, &ENTRY_VIRTUALIZES_8235670628188929025)],
        &[(0b00001, &ENTRY_VIRTUOSI_16194921273122969553)],
    ],
    range: 1..=11,
};

static VARS_VIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIL_CHILDREN),
    value: None,
};

pub static VARS_VIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lagisation"),
        dictgen::InsensitiveStr::Ascii("lagisations"),
        dictgen::InsensitiveStr::Ascii("lagization"),
        dictgen::InsensitiveStr::Ascii("lagizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VILLAGIZATION_6704300146786129340)],
        &[(0b10010, &ENTRY_VILLAGIZATIONS_9645056958423616662)],
        &[(0b01001, &ENTRY_VILLAGIZATION_6704300146786129340)],
        &[(0b01001, &ENTRY_VILLAGIZATIONS_9645056958423616662)],
    ],
    range: 10..=11,
};

static VARS_VIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIG_CHILDREN),
    value: None,
};

pub static VARS_VIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("orless"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ourless"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_VIGOR_15557932597045951621)],
        &[(0b00001, &ENTRY_VIGORLESS_6116200848533060992)],
        &[(0b11001, &ENTRY_VIGORS_2946830186019355206)],
        &[(0b11010, &ENTRY_VIGOR_15557932597045951621)],
        &[(0b11010, &ENTRY_VIGORLESS_6116200848533060992)],
        &[(0b11010, &ENTRY_VIGORS_2946830186019355206)],
    ],
    range: 2..=7,
};

static VARS_VIE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIE_CHILDREN),
    value: None,
};

pub static VARS_VIE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("tnamisation"),
        dictgen::InsensitiveStr::Ascii("tnamise"),
        dictgen::InsensitiveStr::Ascii("tnamised"),
        dictgen::InsensitiveStr::Ascii("tnamises"),
        dictgen::InsensitiveStr::Ascii("tnamising"),
        dictgen::InsensitiveStr::Ascii("tnamization"),
        dictgen::InsensitiveStr::Ascii("tnamize"),
        dictgen::InsensitiveStr::Ascii("tnamized"),
        dictgen::InsensitiveStr::Ascii("tnamizes"),
        dictgen::InsensitiveStr::Ascii("tnamizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VIER_13580000022985666082)],
        &[(0b00001, &ENTRY_VIERS_14228033346609932442)],
        &[(0b10010, &ENTRY_VIETNAMIZATION_15878813039655610439)],
        &[(0b10010, &ENTRY_VIETNAMIZE_10929007049885521412)],
        &[(0b10010, &ENTRY_VIETNAMIZED_12635785661712716002)],
        &[(0b10010, &ENTRY_VIETNAMIZES_5960161263908738812)],
        &[(0b10010, &ENTRY_VIETNAMIZING_2857912616716494009)],
        &[(0b01001, &ENTRY_VIETNAMIZATION_15878813039655610439)],
        &[(0b01001, &ENTRY_VIETNAMIZE_10929007049885521412)],
        &[(0b01001, &ENTRY_VIETNAMIZED_12635785661712716002)],
        &[(0b01001, &ENTRY_VIETNAMIZES_5960161263908738812)],
        &[(0b01001, &ENTRY_VIETNAMIZING_2857912616716494009)],
    ],
    range: 1..=11,
};

static VARS_VID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VID_CHILDREN),
    value: None,
};

pub static VARS_VID_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eodisk"),
        dictgen::InsensitiveStr::Ascii("eodisks"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VIDEODISC_6353050125875667178)],
        &[(0b00001, &ENTRY_VIDEODISCS_16872815408295672812)],
    ],
    range: 6..=7,
};

static VARS_VIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIC_CHILDREN),
    value: None,
};

pub static VARS_VIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("timisable"),
        dictgen::InsensitiveStr::Ascii("timisables"),
        dictgen::InsensitiveStr::Ascii("timisation"),
        dictgen::InsensitiveStr::Ascii("timisations"),
        dictgen::InsensitiveStr::Ascii("timise"),
        dictgen::InsensitiveStr::Ascii("timised"),
        dictgen::InsensitiveStr::Ascii("timiser"),
        dictgen::InsensitiveStr::Ascii("timisers"),
        dictgen::InsensitiveStr::Ascii("timises"),
        dictgen::InsensitiveStr::Ascii("timising"),
        dictgen::InsensitiveStr::Ascii("timizable"),
        dictgen::InsensitiveStr::Ascii("timizables"),
        dictgen::InsensitiveStr::Ascii("timization"),
        dictgen::InsensitiveStr::Ascii("timizations"),
        dictgen::InsensitiveStr::Ascii("timize"),
        dictgen::InsensitiveStr::Ascii("timized"),
        dictgen::InsensitiveStr::Ascii("timizer"),
        dictgen::InsensitiveStr::Ascii("timizers"),
        dictgen::InsensitiveStr::Ascii("timizes"),
        dictgen::InsensitiveStr::Ascii("timizing"),
        dictgen::InsensitiveStr::Ascii("torianise"),
        dictgen::InsensitiveStr::Ascii("torianises"),
        dictgen::InsensitiveStr::Ascii("torianize"),
        dictgen::InsensitiveStr::Ascii("torianizes"),
        dictgen::InsensitiveStr::Ascii("tualage"),
        dictgen::InsensitiveStr::Ascii("tualages"),
        dictgen::InsensitiveStr::Ascii("tualed"),
        dictgen::InsensitiveStr::Ascii("tualer"),
        dictgen::InsensitiveStr::Ascii("tualers"),
        dictgen::InsensitiveStr::Ascii("tualess"),
        dictgen::InsensitiveStr::Ascii("tualing"),
        dictgen::InsensitiveStr::Ascii("tuallage"),
        dictgen::InsensitiveStr::Ascii("tuallages"),
        dictgen::InsensitiveStr::Ascii("tualled"),
        dictgen::InsensitiveStr::Ascii("tualler"),
        dictgen::InsensitiveStr::Ascii("tuallers"),
        dictgen::InsensitiveStr::Ascii("tualless"),
        dictgen::InsensitiveStr::Ascii("tualling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VICTIMIZABLE_6325841584128803768)],
        &[(0b10010, &ENTRY_VICTIMIZABLES_6241000807340860355)],
        &[(0b10010, &ENTRY_VICTIMIZATION_6473682179195269391)],
        &[(0b10010, &ENTRY_VICTIMIZATIONS_5670211910093257144)],
        &[(0b10010, &ENTRY_VICTIMIZE_17964381173204803563)],
        &[(0b10010, &ENTRY_VICTIMIZED_16785627582641973610)],
        &[(0b10010, &ENTRY_VICTIMIZER_15193367442648599657)],
        &[(0b10010, &ENTRY_VICTIMIZERS_1678778459889759577)],
        &[(0b10010, &ENTRY_VICTIMIZES_10527897189755188591)],
        &[(0b10010, &ENTRY_VICTIMIZING_2512377935106454315)],
        &[(0b01001, &ENTRY_VICTIMIZABLE_6325841584128803768)],
        &[(0b01001, &ENTRY_VICTIMIZABLES_6241000807340860355)],
        &[(0b01001, &ENTRY_VICTIMIZATION_6473682179195269391)],
        &[(0b01001, &ENTRY_VICTIMIZATIONS_5670211910093257144)],
        &[(0b01001, &ENTRY_VICTIMIZE_17964381173204803563)],
        &[(0b01001, &ENTRY_VICTIMIZED_16785627582641973610)],
        &[(0b01001, &ENTRY_VICTIMIZER_15193367442648599657)],
        &[(0b01001, &ENTRY_VICTIMIZERS_1678778459889759577)],
        &[(0b01001, &ENTRY_VICTIMIZES_10527897189755188591)],
        &[(0b01001, &ENTRY_VICTIMIZING_2512377935106454315)],
        &[(0b10010, &ENTRY_VICTORIANIZE_278741780816601909)],
        &[(0b10010, &ENTRY_VICTORIANIZES_4206206383857008164)],
        &[(0b01001, &ENTRY_VICTORIANIZE_278741780816601909)],
        &[(0b01001, &ENTRY_VICTORIANIZES_4206206383857008164)],
        &[(0b00001, &ENTRY_VICTUALAGE_550065404232068014)],
        &[(0b00001, &ENTRY_VICTUALAGES_7832395254409182637)],
        &[(0b00001, &ENTRY_VICTUALED_15540819304108381987)],
        &[(0b00001, &ENTRY_VICTUALER_6653512003545303549)],
        &[(0b00001, &ENTRY_VICTUALERS_12039289652841636588)],
        &[(0b00001, &ENTRY_VICTUALESS_5827356037504397036)],
        &[(0b00001, &ENTRY_VICTUALING_15440302570998416657)],
        &[(0b11010, &ENTRY_VICTUALAGE_550065404232068014)],
        &[(0b11010, &ENTRY_VICTUALAGES_7832395254409182637)],
        &[(0b11010, &ENTRY_VICTUALED_15540819304108381987)],
        &[(0b11010, &ENTRY_VICTUALER_6653512003545303549)],
        &[(0b11010, &ENTRY_VICTUALERS_12039289652841636588)],
        &[(0b11010, &ENTRY_VICTUALESS_5827356037504397036)],
        &[(0b11010, &ENTRY_VICTUALING_15440302570998416657)],
    ],
    range: 6..=11,
};

static VARS_VIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIA_CHILDREN),
    value: None,
};

pub static VARS_VIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("lling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VIALED_6673508382112164229)],
        &[(0b00001, &ENTRY_VIALING_8784593913542250179)],
        &[(0b11010, &ENTRY_VIALED_6673508382112164229)],
        &[(0b11010, &ENTRY_VIALING_8784593913542250179)],
    ],
    range: 3..=5,
};

static VARS_VE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_VE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_VE_5155558316755050493)]),
};

static VARS_VE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_VEC_NODE),
    None,
    Some(&VARS_VEE_NODE),
    None,
    Some(&VARS_VEG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_VEL_NODE),
    None,
    Some(&VARS_VEN_NODE),
    None,
    None,
    None,
    Some(&VARS_VER_NODE),
    Some(&VARS_VES_NODE),
    Some(&VARS_VET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_VET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VET_CHILDREN),
    value: None,
};

pub static VARS_VET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("eranise"),
        dictgen::InsensitiveStr::Ascii("eranises"),
        dictgen::InsensitiveStr::Ascii("eranize"),
        dictgen::InsensitiveStr::Ascii("eranizes"),
        dictgen::InsensitiveStr::Ascii("oer"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VETER_13271994869120784461)],
        &[(0b10010, &ENTRY_VETERANIZE_10475186833571792476)],
        &[(0b10010, &ENTRY_VETERANIZES_12354557690927578928)],
        &[(0b01001, &ENTRY_VETERANIZE_10475186833571792476)],
        &[(0b01001, &ENTRY_VETERANIZES_12354557690927578928)],
        &[(0b11010, &ENTRY_VETER_13271994869120784461)],
    ],
    range: 2..=8,
};

static VARS_VES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VES_CHILDREN),
    value: None,
};

pub static VARS_VES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iculae"),
        dictgen::InsensitiveStr::Ascii("icule"),
        dictgen::InsensitiveStr::Ascii("tryise"),
        dictgen::InsensitiveStr::Ascii("tryises"),
        dictgen::InsensitiveStr::Ascii("tryize"),
        dictgen::InsensitiveStr::Ascii("tryizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_VESICULE_16844954968158523223)],
        &[(0b00001, &ENTRY_VESICULE_16844954968158523223)],
        &[(0b10010, &ENTRY_VESTRYIZE_5233128555052687391)],
        &[(0b10010, &ENTRY_VESTRYIZES_6797183257216810494)],
        &[(0b01001, &ENTRY_VESTRYIZE_5233128555052687391)],
        &[(0b01001, &ENTRY_VESTRYIZES_6797183257216810494)],
    ],
    range: 5..=7,
};

static VARS_VER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VER_CHILDREN),
    value: None,
};

pub static VARS_VER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("balisation"),
        dictgen::InsensitiveStr::Ascii("balisations"),
        dictgen::InsensitiveStr::Ascii("balise"),
        dictgen::InsensitiveStr::Ascii("balised"),
        dictgen::InsensitiveStr::Ascii("baliser"),
        dictgen::InsensitiveStr::Ascii("balisers"),
        dictgen::InsensitiveStr::Ascii("balises"),
        dictgen::InsensitiveStr::Ascii("balising"),
        dictgen::InsensitiveStr::Ascii("balization"),
        dictgen::InsensitiveStr::Ascii("balizations"),
        dictgen::InsensitiveStr::Ascii("balize"),
        dictgen::InsensitiveStr::Ascii("balized"),
        dictgen::InsensitiveStr::Ascii("balizer"),
        dictgen::InsensitiveStr::Ascii("balizers"),
        dictgen::InsensitiveStr::Ascii("balizes"),
        dictgen::InsensitiveStr::Ascii("balizing"),
        dictgen::InsensitiveStr::Ascii("ey"),
        dictgen::InsensitiveStr::Ascii("meiled"),
        dictgen::InsensitiveStr::Ascii("meiles"),
        dictgen::InsensitiveStr::Ascii("meiling"),
        dictgen::InsensitiveStr::Ascii("meilled"),
        dictgen::InsensitiveStr::Ascii("meilles"),
        dictgen::InsensitiveStr::Ascii("meilling"),
        dictgen::InsensitiveStr::Ascii("milionise"),
        dictgen::InsensitiveStr::Ascii("milionises"),
        dictgen::InsensitiveStr::Ascii("milionize"),
        dictgen::InsensitiveStr::Ascii("milionizes"),
        dictgen::InsensitiveStr::Ascii("nacularisation"),
        dictgen::InsensitiveStr::Ascii("nacularisations"),
        dictgen::InsensitiveStr::Ascii("nacularise"),
        dictgen::InsensitiveStr::Ascii("nacularised"),
        dictgen::InsensitiveStr::Ascii("nacularises"),
        dictgen::InsensitiveStr::Ascii("nacularising"),
        dictgen::InsensitiveStr::Ascii("nacularization"),
        dictgen::InsensitiveStr::Ascii("nacularizations"),
        dictgen::InsensitiveStr::Ascii("nacularize"),
        dictgen::InsensitiveStr::Ascii("nacularized"),
        dictgen::InsensitiveStr::Ascii("nacularizes"),
        dictgen::InsensitiveStr::Ascii("nacularizing"),
        dictgen::InsensitiveStr::Ascii("nalisation"),
        dictgen::InsensitiveStr::Ascii("nalisations"),
        dictgen::InsensitiveStr::Ascii("nalise"),
        dictgen::InsensitiveStr::Ascii("nalised"),
        dictgen::InsensitiveStr::Ascii("nalises"),
        dictgen::InsensitiveStr::Ascii("nalising"),
        dictgen::InsensitiveStr::Ascii("nalization"),
        dictgen::InsensitiveStr::Ascii("nalizations"),
        dictgen::InsensitiveStr::Ascii("nalize"),
        dictgen::InsensitiveStr::Ascii("nalized"),
        dictgen::InsensitiveStr::Ascii("nalizes"),
        dictgen::InsensitiveStr::Ascii("nalizing"),
        dictgen::InsensitiveStr::Ascii("sicolor"),
        dictgen::InsensitiveStr::Ascii("sicolorate"),
        dictgen::InsensitiveStr::Ascii("sicolored"),
        dictgen::InsensitiveStr::Ascii("sicolorous"),
        dictgen::InsensitiveStr::Ascii("sicolour"),
        dictgen::InsensitiveStr::Ascii("sicolourate"),
        dictgen::InsensitiveStr::Ascii("sicoloured"),
        dictgen::InsensitiveStr::Ascii("sicolourous"),
        dictgen::InsensitiveStr::Ascii("sionise"),
        dictgen::InsensitiveStr::Ascii("sionises"),
        dictgen::InsensitiveStr::Ascii("sionize"),
        dictgen::InsensitiveStr::Ascii("sionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VERBALIZATION_17014780536966514150)],
        &[(0b10010, &ENTRY_VERBALIZATIONS_2148556691017306909)],
        &[(0b10010, &ENTRY_VERBALIZE_1198319365461788046)],
        &[(0b10010, &ENTRY_VERBALIZED_10494008423617804243)],
        &[(0b10010, &ENTRY_VERBALIZER_4530481668094425579)],
        &[(0b10010, &ENTRY_VERBALIZERS_6929664897053786061)],
        &[(0b10010, &ENTRY_VERBALIZES_11158219462754520064)],
        &[(0b10010, &ENTRY_VERBALIZING_3065579017212147213)],
        &[(0b01001, &ENTRY_VERBALIZATION_17014780536966514150)],
        &[(0b01001, &ENTRY_VERBALIZATIONS_2148556691017306909)],
        &[(0b01001, &ENTRY_VERBALIZE_1198319365461788046)],
        &[(0b01001, &ENTRY_VERBALIZED_10494008423617804243)],
        &[(0b01001, &ENTRY_VERBALIZER_4530481668094425579)],
        &[(0b01001, &ENTRY_VERBALIZERS_6929664897053786061)],
        &[(0b01001, &ENTRY_VERBALIZES_11158219462754520064)],
        &[(0b01001, &ENTRY_VERBALIZING_3065579017212147213)],
        &[(0b11010, &ENTRY_VEERY_16377240070055312686)],
        &[(0b00001, &ENTRY_VERMEILED_17836589369144520864)],
        &[(0b00001, &ENTRY_VERMEILES_8456241915430697238)],
        &[(0b00001, &ENTRY_VERMEILING_17221139503778611025)],
        &[(0b11010, &ENTRY_VERMEILED_17836589369144520864)],
        &[(0b11010, &ENTRY_VERMEILES_8456241915430697238)],
        &[(0b11010, &ENTRY_VERMEILING_17221139503778611025)],
        &[(0b10010, &ENTRY_VERMILIONIZE_507242095798633515)],
        &[(0b10010, &ENTRY_VERMILIONIZES_3945706269410456994)],
        &[(0b01001, &ENTRY_VERMILIONIZE_507242095798633515)],
        &[(0b01001, &ENTRY_VERMILIONIZES_3945706269410456994)],
        &[(0b10010, &ENTRY_VERNACULARIZATION_13966126810584473659)],
        &[(0b10010, &ENTRY_VERNACULARIZATIONS_18117165289653141930)],
        &[(0b10010, &ENTRY_VERNACULARIZE_2429868034092124522)],
        &[(0b10010, &ENTRY_VERNACULARIZED_12976593463419560760)],
        &[(0b10010, &ENTRY_VERNACULARIZES_15421918173517522502)],
        &[(0b10010, &ENTRY_VERNACULARIZING_12054872340898509491)],
        &[(0b01001, &ENTRY_VERNACULARIZATION_13966126810584473659)],
        &[(0b01001, &ENTRY_VERNACULARIZATIONS_18117165289653141930)],
        &[(0b01001, &ENTRY_VERNACULARIZE_2429868034092124522)],
        &[(0b01001, &ENTRY_VERNACULARIZED_12976593463419560760)],
        &[(0b01001, &ENTRY_VERNACULARIZES_15421918173517522502)],
        &[(0b01001, &ENTRY_VERNACULARIZING_12054872340898509491)],
        &[(0b10010, &ENTRY_VERNALIZATION_8602093814476102861)],
        &[(0b10010, &ENTRY_VERNALIZATIONS_16909117428759612836)],
        &[(0b10010, &ENTRY_VERNALIZE_5219754446623447026)],
        &[(0b10010, &ENTRY_VERNALIZED_7603884031730520040)],
        &[(0b10010, &ENTRY_VERNALIZES_4553921016291793785)],
        &[(0b10010, &ENTRY_VERNALIZING_3592189555940731803)],
        &[(0b01001, &ENTRY_VERNALIZATION_8602093814476102861)],
        &[(0b01001, &ENTRY_VERNALIZATIONS_16909117428759612836)],
        &[(0b01001, &ENTRY_VERNALIZE_5219754446623447026)],
        &[(0b01001, &ENTRY_VERNALIZED_7603884031730520040)],
        &[(0b01001, &ENTRY_VERNALIZES_4553921016291793785)],
        &[(0b01001, &ENTRY_VERNALIZING_3592189555940731803)],
        &[(0b00001, &ENTRY_VERSICOLOR_14351830468170420943)],
        &[(0b00001, &ENTRY_VERSICOLORATE_10320999794267613649)],
        &[(0b00001, &ENTRY_VERSICOLORED_8040480056728281804)],
        &[(0b00001, &ENTRY_VERSICOLOROUS_233687980256971301)],
        &[(0b11010, &ENTRY_VERSICOLOR_14351830468170420943)],
        &[(0b11010, &ENTRY_VERSICOLORATE_10320999794267613649)],
        &[(0b11010, &ENTRY_VERSICOLORED_8040480056728281804)],
        &[(0b11010, &ENTRY_VERSICOLOROUS_233687980256971301)],
        &[(0b10010, &ENTRY_VERSIONIZE_12827553166085838878)],
        &[(0b10010, &ENTRY_VERSIONIZES_7018911115976618102)],
        &[(0b01001, &ENTRY_VERSIONIZE_12827553166085838878)],
        &[(0b01001, &ENTRY_VERSIONIZES_7018911115976618102)],
    ],
    range: 2..=15,
};

static VARS_VEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VEN_CHILDREN),
    value: None,
};

pub static VARS_VEN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("der"),
        dictgen::InsensitiveStr::Ascii("ders"),
        dictgen::InsensitiveStr::Ascii("omisation"),
        dictgen::InsensitiveStr::Ascii("omisations"),
        dictgen::InsensitiveStr::Ascii("omise"),
        dictgen::InsensitiveStr::Ascii("omises"),
        dictgen::InsensitiveStr::Ascii("omization"),
        dictgen::InsensitiveStr::Ascii("omizations"),
        dictgen::InsensitiveStr::Ascii("omize"),
        dictgen::InsensitiveStr::Ascii("omizes"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tres"),
        dictgen::InsensitiveStr::Ascii("triloquise"),
        dictgen::InsensitiveStr::Ascii("triloquised"),
        dictgen::InsensitiveStr::Ascii("triloquises"),
        dictgen::InsensitiveStr::Ascii("triloquising"),
        dictgen::InsensitiveStr::Ascii("triloquize"),
        dictgen::InsensitiveStr::Ascii("triloquized"),
        dictgen::InsensitiveStr::Ascii("triloquizes"),
        dictgen::InsensitiveStr::Ascii("triloquizing"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VENALIZATION_10105179936386523824)],
        &[(0b10010, &ENTRY_VENALIZATIONS_18162172463769168949)],
        &[(0b10010, &ENTRY_VENALIZE_16371697667188046045)],
        &[(0b10010, &ENTRY_VENALIZES_17167448239623843588)],
        &[(0b01001, &ENTRY_VENALIZATION_10105179936386523824)],
        &[(0b01001, &ENTRY_VENALIZATIONS_18162172463769168949)],
        &[(0b01001, &ENTRY_VENALIZE_16371697667188046045)],
        &[(0b01001, &ENTRY_VENALIZES_17167448239623843588)],
        &[(0b00001, &ENTRY_VENDOR_614257521164925268)],
        &[(0b00001, &ENTRY_VENDORS_1436950525202030326)],
        &[(0b10010, &ENTRY_VENOMIZATION_3248380214395011937)],
        &[(0b10010, &ENTRY_VENOMIZATIONS_15562672786718899376)],
        &[(0b10010, &ENTRY_VENOMIZE_13397367997497163317)],
        &[(0b10010, &ENTRY_VENOMIZES_1220144968938148346)],
        &[(0b01001, &ENTRY_VENOMIZATION_3248380214395011937)],
        &[(0b01001, &ENTRY_VENOMIZATIONS_15562672786718899376)],
        &[(0b01001, &ENTRY_VENOMIZE_13397367997497163317)],
        &[(0b01001, &ENTRY_VENOMIZES_1220144968938148346)],
        &[(0b00001, &ENTRY_VENTER_3246201295857892913)],
        &[(0b00001, &ENTRY_VENTERS_10581975041225097234)],
        &[(0b11010, &ENTRY_VENTER_3246201295857892913)],
        &[(0b11010, &ENTRY_VENTERS_10581975041225097234)],
        &[(0b10010, &ENTRY_VENTRILOQUIZE_6075592572709749127)],
        &[(0b10010, &ENTRY_VENTRILOQUIZED_3898326028561445962)],
        &[(0b10010, &ENTRY_VENTRILOQUIZES_221071050486777356)],
        &[(0b10010, &ENTRY_VENTRILOQUIZING_17870016245092386407)],
        &[(0b01001, &ENTRY_VENTRILOQUIZE_6075592572709749127)],
        &[(0b01001, &ENTRY_VENTRILOQUIZED_3898326028561445962)],
        &[(0b01001, &ENTRY_VENTRILOQUIZES_221071050486777356)],
        &[(0b01001, &ENTRY_VENTRILOQUIZING_17870016245092386407)],
        &[(0b11010, &ENTRY_VENULE_15331508582682614848)],
        &[(0b00001, &ENTRY_VENULE_15331508582682614848)],
    ],
    range: 3..=12,
};

static VARS_VEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VEL_CHILDREN),
    value: None,
};

pub static VARS_VEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arisation"),
        dictgen::InsensitiveStr::Ascii("arisations"),
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arised"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arising"),
        dictgen::InsensitiveStr::Ascii("arization"),
        dictgen::InsensitiveStr::Ascii("arizations"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arized"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("arizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VELARIZATION_6695615417336752356)],
        &[(0b10010, &ENTRY_VELARIZATIONS_16578843012905334995)],
        &[(0b10010, &ENTRY_VELARIZE_11928218775132434386)],
        &[(0b10010, &ENTRY_VELARIZED_6812327040601340521)],
        &[(0b10010, &ENTRY_VELARIZES_15540494560951794576)],
        &[(0b10010, &ENTRY_VELARIZING_1563679261014512608)],
        &[(0b01001, &ENTRY_VELARIZATION_6695615417336752356)],
        &[(0b01001, &ENTRY_VELARIZATIONS_16578843012905334995)],
        &[(0b01001, &ENTRY_VELARIZE_11928218775132434386)],
        &[(0b01001, &ENTRY_VELARIZED_6812327040601340521)],
        &[(0b01001, &ENTRY_VELARIZES_15540494560951794576)],
        &[(0b01001, &ENTRY_VELARIZING_1563679261014512608)],
    ],
    range: 5..=10,
};

static VARS_VEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VEG_CHILDREN),
    value: None,
};

pub static VARS_VEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etablise"),
        dictgen::InsensitiveStr::Ascii("etablises"),
        dictgen::InsensitiveStr::Ascii("etablize"),
        dictgen::InsensitiveStr::Ascii("etablizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VEGETABLIZE_240867435962121524)],
        &[(0b10010, &ENTRY_VEGETABLIZES_13431862844399419063)],
        &[(0b01001, &ENTRY_VEGETABLIZE_240867435962121524)],
        &[(0b01001, &ENTRY_VEGETABLIZES_13431862844399419063)],
    ],
    range: 8..=9,
};

static VARS_VEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VEE_CHILDREN),
    value: None,
};

pub static VARS_VEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ry")],
    values: &[&[(0b00001, &ENTRY_VEERY_16377240070055312686)]],
    range: 2..=2,
};

static VARS_VEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VEC_CHILDREN),
    value: None,
};

pub static VARS_VEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("torisable"),
        dictgen::InsensitiveStr::Ascii("torisation"),
        dictgen::InsensitiveStr::Ascii("torisations"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torised"),
        dictgen::InsensitiveStr::Ascii("toriser"),
        dictgen::InsensitiveStr::Ascii("torisered"),
        dictgen::InsensitiveStr::Ascii("torisering"),
        dictgen::InsensitiveStr::Ascii("torisers"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torising"),
        dictgen::InsensitiveStr::Ascii("torizable"),
        dictgen::InsensitiveStr::Ascii("torization"),
        dictgen::InsensitiveStr::Ascii("torizations"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torized"),
        dictgen::InsensitiveStr::Ascii("torizer"),
        dictgen::InsensitiveStr::Ascii("torizered"),
        dictgen::InsensitiveStr::Ascii("torizering"),
        dictgen::InsensitiveStr::Ascii("torizers"),
        dictgen::InsensitiveStr::Ascii("torizes"),
        dictgen::InsensitiveStr::Ascii("torizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VECTORIZABLE_7700511871799517175)],
        &[(0b10010, &ENTRY_VECTORIZATION_10787111062319216653)],
        &[(0b10010, &ENTRY_VECTORIZATIONS_15801982123847128215)],
        &[(0b10010, &ENTRY_VECTORIZE_7621545906945634571)],
        &[(0b10010, &ENTRY_VECTORIZED_11582193843268490434)],
        &[(0b10010, &ENTRY_VECTORIZER_10024278019728920356)],
        &[(0b10010, &ENTRY_VECTORIZERED_12945770792403996963)],
        &[(0b10010, &ENTRY_VECTORIZERING_7399862757873995787)],
        &[(0b10010, &ENTRY_VECTORIZERS_10774848315320864388)],
        &[(0b10010, &ENTRY_VECTORIZES_10986965122273304100)],
        &[(0b10010, &ENTRY_VECTORIZING_9813119268612536101)],
        &[(0b01001, &ENTRY_VECTORIZABLE_7700511871799517175)],
        &[(0b01001, &ENTRY_VECTORIZATION_10787111062319216653)],
        &[(0b01001, &ENTRY_VECTORIZATIONS_15801982123847128215)],
        &[(0b01001, &ENTRY_VECTORIZE_7621545906945634571)],
        &[(0b01001, &ENTRY_VECTORIZED_11582193843268490434)],
        &[(0b01001, &ENTRY_VECTORIZER_10024278019728920356)],
        &[(0b01001, &ENTRY_VECTORIZERED_12945770792403996963)],
        &[(0b01001, &ENTRY_VECTORIZERING_7399862757873995787)],
        &[(0b01001, &ENTRY_VECTORIZERS_10774848315320864388)],
        &[(0b01001, &ENTRY_VECTORIZES_10986965122273304100)],
        &[(0b01001, &ENTRY_VECTORIZING_9813119268612536101)],
    ],
    range: 6..=11,
};

static VARS_VA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_VA_CHILDREN),
    value: None,
};

static VARS_VA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_VAA_NODE),
    None,
    Some(&VARS_VAC_NODE),
    None,
    None,
    None,
    Some(&VARS_VAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_VAL_NODE),
    Some(&VARS_VAM_NODE),
    Some(&VARS_VAN_NODE),
    None,
    Some(&VARS_VAP_NODE),
    None,
    Some(&VARS_VAR_NODE),
    Some(&VARS_VAS_NODE),
    Some(&VARS_VAT_NODE),
    None,
    Some(&VARS_VAV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_VAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAV_CHILDREN),
    value: None,
};

pub static VARS_VAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("asor"),
        dictgen::InsensitiveStr::Ascii("asors"),
        dictgen::InsensitiveStr::Ascii("asour"),
        dictgen::InsensitiveStr::Ascii("asours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VAVASOR_13335526244828687938)],
        &[(0b00001, &ENTRY_VAVASORS_13483440249798277072)],
        &[(0b11010, &ENTRY_VAVASOR_13335526244828687938)],
        &[(0b11010, &ENTRY_VAVASORS_13483440249798277072)],
    ],
    range: 4..=6,
};

static VARS_VAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAT_CHILDREN),
    value: None,
};

pub static VARS_VAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icanisation"),
        dictgen::InsensitiveStr::Ascii("icanisations"),
        dictgen::InsensitiveStr::Ascii("icanise"),
        dictgen::InsensitiveStr::Ascii("icanises"),
        dictgen::InsensitiveStr::Ascii("icanization"),
        dictgen::InsensitiveStr::Ascii("icanizations"),
        dictgen::InsensitiveStr::Ascii("icanize"),
        dictgen::InsensitiveStr::Ascii("icanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VATICANIZATION_9714400903507160409)],
        &[(0b10010, &ENTRY_VATICANIZATIONS_4284951110958617053)],
        &[(0b10010, &ENTRY_VATICANIZE_447252295327213484)],
        &[(0b10010, &ENTRY_VATICANIZES_15643199634116450854)],
        &[(0b01001, &ENTRY_VATICANIZATION_9714400903507160409)],
        &[(0b01001, &ENTRY_VATICANIZATIONS_4284951110958617053)],
        &[(0b01001, &ENTRY_VATICANIZE_447252295327213484)],
        &[(0b01001, &ENTRY_VATICANIZES_15643199634116450854)],
    ],
    range: 7..=12,
};

static VARS_VAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAS_CHILDREN),
    value: None,
};

pub static VARS_VAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cularisation"),
        dictgen::InsensitiveStr::Ascii("cularisations"),
        dictgen::InsensitiveStr::Ascii("cularise"),
        dictgen::InsensitiveStr::Ascii("cularised"),
        dictgen::InsensitiveStr::Ascii("cularises"),
        dictgen::InsensitiveStr::Ascii("cularising"),
        dictgen::InsensitiveStr::Ascii("cularization"),
        dictgen::InsensitiveStr::Ascii("cularizations"),
        dictgen::InsensitiveStr::Ascii("cularize"),
        dictgen::InsensitiveStr::Ascii("cularized"),
        dictgen::InsensitiveStr::Ascii("cularizes"),
        dictgen::InsensitiveStr::Ascii("cularizing"),
        dictgen::InsensitiveStr::Ascii("ectomise"),
        dictgen::InsensitiveStr::Ascii("ectomised"),
        dictgen::InsensitiveStr::Ascii("ectomising"),
        dictgen::InsensitiveStr::Ascii("ectomize"),
        dictgen::InsensitiveStr::Ascii("ectomized"),
        dictgen::InsensitiveStr::Ascii("ectomizing"),
        dictgen::InsensitiveStr::Ascii("salisation"),
        dictgen::InsensitiveStr::Ascii("salise"),
        dictgen::InsensitiveStr::Ascii("salised"),
        dictgen::InsensitiveStr::Ascii("salises"),
        dictgen::InsensitiveStr::Ascii("salising"),
        dictgen::InsensitiveStr::Ascii("salization"),
        dictgen::InsensitiveStr::Ascii("salize"),
        dictgen::InsensitiveStr::Ascii("salized"),
        dictgen::InsensitiveStr::Ascii("salizes"),
        dictgen::InsensitiveStr::Ascii("salizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VASCULARIZATION_1873656875493637800)],
        &[(0b10010, &ENTRY_VASCULARIZATIONS_10231044964090450051)],
        &[(0b10010, &ENTRY_VASCULARIZE_18409549429241791397)],
        &[(0b10010, &ENTRY_VASCULARIZED_15040037911474250866)],
        &[(0b10010, &ENTRY_VASCULARIZES_7450544747817806685)],
        &[(0b10010, &ENTRY_VASCULARIZING_13147736200759695458)],
        &[(0b01001, &ENTRY_VASCULARIZATION_1873656875493637800)],
        &[(0b01001, &ENTRY_VASCULARIZATIONS_10231044964090450051)],
        &[(0b01001, &ENTRY_VASCULARIZE_18409549429241791397)],
        &[(0b01001, &ENTRY_VASCULARIZED_15040037911474250866)],
        &[(0b01001, &ENTRY_VASCULARIZES_7450544747817806685)],
        &[(0b01001, &ENTRY_VASCULARIZING_13147736200759695458)],
        &[(0b10010, &ENTRY_VASECTOMIZE_14117059244189610141)],
        &[(0b10010, &ENTRY_VASECTOMIZED_9802783923443016839)],
        &[(0b10010, &ENTRY_VASECTOMIZING_9067814547217523949)],
        &[(0b01001, &ENTRY_VASECTOMIZE_14117059244189610141)],
        &[(0b01001, &ENTRY_VASECTOMIZED_9802783923443016839)],
        &[(0b01001, &ENTRY_VASECTOMIZING_9067814547217523949)],
        &[(0b10010, &ENTRY_VASSALIZATION_11913810286930660962)],
        &[(0b10010, &ENTRY_VASSALIZE_15684651890209783105)],
        &[(0b10010, &ENTRY_VASSALIZED_14302164483296963637)],
        &[(0b10010, &ENTRY_VASSALIZES_404335759200109889)],
        &[(0b10010, &ENTRY_VASSALIZING_10504927354705456811)],
        &[(0b01001, &ENTRY_VASSALIZATION_11913810286930660962)],
        &[(0b01001, &ENTRY_VASSALIZE_15684651890209783105)],
        &[(0b01001, &ENTRY_VASSALIZED_14302164483296963637)],
        &[(0b01001, &ENTRY_VASSALIZES_404335759200109889)],
        &[(0b01001, &ENTRY_VASSALIZING_10504927354705456811)],
    ],
    range: 6..=13,
};

static VARS_VAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAR_CHILDREN),
    value: None,
};

pub static VARS_VAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icolored"),
        dictgen::InsensitiveStr::Ascii("icoloredder"),
        dictgen::InsensitiveStr::Ascii("icoloreddest"),
        dictgen::InsensitiveStr::Ascii("icoloreds"),
        dictgen::InsensitiveStr::Ascii("icolorous"),
        dictgen::InsensitiveStr::Ascii("icoloured"),
        dictgen::InsensitiveStr::Ascii("icolouredder"),
        dictgen::InsensitiveStr::Ascii("icoloureddest"),
        dictgen::InsensitiveStr::Ascii("icoloureds"),
        dictgen::InsensitiveStr::Ascii("icolourous"),
    ],
    values: &[
        &[(0b01001, &ENTRY_VARICOLORED_14826810108614522572)],
        &[(0b01001, &ENTRY_VARICOLOREDDER_17739587046028260965)],
        &[(0b01001, &ENTRY_VARICOLOREDDEST_13804238764633913841)],
        &[(0b01001, &ENTRY_VARICOLOREDS_11023757870916070482)],
        &[(0b00001, &ENTRY_VARICOLOROUS_12718480012886049444)],
        &[(0b11010, &ENTRY_VARICOLORED_14826810108614522572)],
        &[(0b11010, &ENTRY_VARICOLOREDDER_17739587046028260965)],
        &[(0b11010, &ENTRY_VARICOLOREDDEST_13804238764633913841)],
        &[(0b11010, &ENTRY_VARICOLOREDS_11023757870916070482)],
        &[(0b11010, &ENTRY_VARICOLOROUS_12718480012886049444)],
    ],
    range: 8..=13,
};

static VARS_VAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_VAP_CHILDREN),
    value: None,
};

static VARS_VAP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VAPO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_VAPO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_VAPO_CHILDREN),
    value: None,
};

static VARS_VAPO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VAPOR_NODE),
    None,
    None,
    Some(&VARS_VAPOU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_VAPOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAPOU_CHILDREN),
    value: None,
};

pub static VARS_VAPOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rabilities"),
        dictgen::InsensitiveStr::Ascii("rability"),
        dictgen::InsensitiveStr::Ascii("rable"),
        dictgen::InsensitiveStr::Ascii("rables"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("rescent"),
        dictgen::InsensitiveStr::Ascii("rier"),
        dictgen::InsensitiveStr::Ascii("riest"),
        dictgen::InsensitiveStr::Ascii("rific"),
        dictgen::InsensitiveStr::Ascii("rimeter"),
        dictgen::InsensitiveStr::Ascii("ring"),
        dictgen::InsensitiveStr::Ascii("ringly"),
        dictgen::InsensitiveStr::Ascii("rings"),
        dictgen::InsensitiveStr::Ascii("rish"),
        dictgen::InsensitiveStr::Ascii("risher"),
        dictgen::InsensitiveStr::Ascii("rishest"),
        dictgen::InsensitiveStr::Ascii("rishness"),
        dictgen::InsensitiveStr::Ascii("rishnesses"),
        dictgen::InsensitiveStr::Ascii("rless"),
        dictgen::InsensitiveStr::Ascii("rlesses"),
        dictgen::InsensitiveStr::Ascii("rlike"),
        dictgen::InsensitiveStr::Ascii("rlikes"),
        dictgen::InsensitiveStr::Ascii("rose"),
        dictgen::InsensitiveStr::Ascii("rously"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("rware"),
        dictgen::InsensitiveStr::Ascii("ry"),
    ],
    values: &[
        &[(0b11010, &ENTRY_VAPOR_2186715544993402811)],
        &[(0b11010, &ENTRY_VAPORABILITIES_16210230667077421998)],
        &[(0b11010, &ENTRY_VAPORABILITY_12774606556739795339)],
        &[(0b11010, &ENTRY_VAPORABLE_5501212841170621386)],
        &[(0b11010, &ENTRY_VAPORABLES_11612330563163535423)],
        &[(0b11010, &ENTRY_VAPORED_8090866757673721955)],
        &[(0b11010, &ENTRY_VAPORER_15606043365547492909)],
        &[(0b11010, &ENTRY_VAPORERS_1337800929973980777)],
        &[(0b11010, &ENTRY_VAPORESCENT_5937298821672753827)],
        &[(0b11010, &ENTRY_VAPORIER_10870396883532803185)],
        &[(0b11010, &ENTRY_VAPORIEST_14983690178384093877)],
        &[(0b11010, &ENTRY_VAPORIFIC_4203042838768085117)],
        &[(0b11010, &ENTRY_VAPORIMETER_6307567735178986275)],
        &[(0b11010, &ENTRY_VAPORING_420257298669421065)],
        &[(0b11010, &ENTRY_VAPORINGLY_17882474581404052992)],
        &[(0b11010, &ENTRY_VAPORINGS_1485515244068360371)],
        &[(0b11010, &ENTRY_VAPORISH_1792709436180269388)],
        &[(0b11010, &ENTRY_VAPORISHER_1025608314806119016)],
        &[(0b11010, &ENTRY_VAPORISHEST_2688111660339631646)],
        &[(0b11010, &ENTRY_VAPORISHNESS_15785186011197470564)],
        &[(0b11010, &ENTRY_VAPORISHNESSES_6785939461569914269)],
        &[(0b11010, &ENTRY_VAPORLESS_12823347514087919905)],
        &[(0b11010, &ENTRY_VAPORLESSES_5837573394417037459)],
        &[(0b11010, &ENTRY_VAPORLIKE_12611878629021498077)],
        &[(0b11010, &ENTRY_VAPORLIKES_4827403622949682642)],
        &[(0b11010, &ENTRY_VAPOROSE_6449688285161662447)],
        &[(0b11010, &ENTRY_VAPOROUSLY_4033817846371416657)],
        &[(0b11010, &ENTRY_VAPORS_10654457609159557123)],
        &[(0b11010, &ENTRY_VAPORWARE_9698524933063954413)],
        &[(0b11010, &ENTRY_VAPORY_2699803825003632190)],
    ],
    range: 1..=10,
};

static VARS_VAPOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAPOR_CHILDREN),
    value: Some(&[(0b11001, &ENTRY_VAPOR_2186715544993402811)]),
};

pub static VARS_VAPOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abilities"),
        dictgen::InsensitiveStr::Ascii("ability"),
        dictgen::InsensitiveStr::Ascii("able"),
        dictgen::InsensitiveStr::Ascii("ables"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("escent"),
        dictgen::InsensitiveStr::Ascii("ier"),
        dictgen::InsensitiveStr::Ascii("iest"),
        dictgen::InsensitiveStr::Ascii("ific"),
        dictgen::InsensitiveStr::Ascii("imeter"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("ingly"),
        dictgen::InsensitiveStr::Ascii("ings"),
        dictgen::InsensitiveStr::Ascii("isable"),
        dictgen::InsensitiveStr::Ascii("isabler"),
        dictgen::InsensitiveStr::Ascii("isables"),
        dictgen::InsensitiveStr::Ascii("isablest"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("iser"),
        dictgen::InsensitiveStr::Ascii("isers"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ish"),
        dictgen::InsensitiveStr::Ascii("isher"),
        dictgen::InsensitiveStr::Ascii("ishest"),
        dictgen::InsensitiveStr::Ascii("ishness"),
        dictgen::InsensitiveStr::Ascii("ishnesses"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("izable"),
        dictgen::InsensitiveStr::Ascii("izabler"),
        dictgen::InsensitiveStr::Ascii("izables"),
        dictgen::InsensitiveStr::Ascii("izablest"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izer"),
        dictgen::InsensitiveStr::Ascii("izers"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
        dictgen::InsensitiveStr::Ascii("less"),
        dictgen::InsensitiveStr::Ascii("lesses"),
        dictgen::InsensitiveStr::Ascii("like"),
        dictgen::InsensitiveStr::Ascii("likes"),
        dictgen::InsensitiveStr::Ascii("ose"),
        dictgen::InsensitiveStr::Ascii("ously"),
        dictgen::InsensitiveStr::Ascii("s"),
        dictgen::InsensitiveStr::Ascii("ware"),
        dictgen::InsensitiveStr::Ascii("y"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VAPORABILITIES_16210230667077421998)],
        &[(0b00001, &ENTRY_VAPORABILITY_12774606556739795339)],
        &[(0b00001, &ENTRY_VAPORABLE_5501212841170621386)],
        &[(0b00001, &ENTRY_VAPORABLES_11612330563163535423)],
        &[(0b11001, &ENTRY_VAPORED_8090866757673721955)],
        &[(0b00001, &ENTRY_VAPORER_15606043365547492909)],
        &[(0b00001, &ENTRY_VAPORERS_1337800929973980777)],
        &[(0b00001, &ENTRY_VAPORESCENT_5937298821672753827)],
        &[(0b00001, &ENTRY_VAPORIER_10870396883532803185)],
        &[(0b00001, &ENTRY_VAPORIEST_14983690178384093877)],
        &[(0b00001, &ENTRY_VAPORIFIC_4203042838768085117)],
        &[(0b00001, &ENTRY_VAPORIMETER_6307567735178986275)],
        &[(0b11001, &ENTRY_VAPORING_420257298669421065)],
        &[(0b00001, &ENTRY_VAPORINGLY_17882474581404052992)],
        &[(0b11001, &ENTRY_VAPORINGS_1485515244068360371)],
        &[(0b10010, &ENTRY_VAPORIZABLE_11495926926379792888)],
        &[(0b10010, &ENTRY_VAPORIZABLER_2686036342147244593)],
        &[(0b10010, &ENTRY_VAPORIZABLES_602114803906365139)],
        &[(0b10010, &ENTRY_VAPORIZABLEST_6961996652683939422)],
        &[(0b10010, &ENTRY_VAPORIZATION_18013020655663665183)],
        &[(0b10010, &ENTRY_VAPORIZATIONS_16022234579712511195)],
        &[(0b10010, &ENTRY_VAPORIZE_3098164633633455886)],
        &[(0b10010, &ENTRY_VAPORIZED_15975626787835074281)],
        &[(0b10010, &ENTRY_VAPORIZER_2660185636167297891)],
        &[(0b10010, &ENTRY_VAPORIZERS_5986565178581788761)],
        &[(0b10010, &ENTRY_VAPORIZES_9602890245599971042)],
        &[(0b00001, &ENTRY_VAPORISH_1792709436180269388)],
        &[(0b00001, &ENTRY_VAPORISHER_1025608314806119016)],
        &[(0b00001, &ENTRY_VAPORISHEST_2688111660339631646)],
        &[(0b00001, &ENTRY_VAPORISHNESS_15785186011197470564)],
        &[(0b00001, &ENTRY_VAPORISHNESSES_6785939461569914269)],
        &[(0b10010, &ENTRY_VAPORIZING_11567514291379105650)],
        &[(0b01001, &ENTRY_VAPORIZABLE_11495926926379792888)],
        &[(0b01001, &ENTRY_VAPORIZABLER_2686036342147244593)],
        &[(0b01001, &ENTRY_VAPORIZABLES_602114803906365139)],
        &[(0b01001, &ENTRY_VAPORIZABLEST_6961996652683939422)],
        &[(0b01001, &ENTRY_VAPORIZATION_18013020655663665183)],
        &[(0b01001, &ENTRY_VAPORIZATIONS_16022234579712511195)],
        &[(0b01001, &ENTRY_VAPORIZE_3098164633633455886)],
        &[(0b01001, &ENTRY_VAPORIZED_15975626787835074281)],
        &[(0b01001, &ENTRY_VAPORIZER_2660185636167297891)],
        &[(0b01001, &ENTRY_VAPORIZERS_5986565178581788761)],
        &[(0b01001, &ENTRY_VAPORIZES_9602890245599971042)],
        &[(0b01001, &ENTRY_VAPORIZING_11567514291379105650)],
        &[(0b00001, &ENTRY_VAPORLESS_12823347514087919905)],
        &[(0b00001, &ENTRY_VAPORLESSES_5837573394417037459)],
        &[(0b00001, &ENTRY_VAPORLIKE_12611878629021498077)],
        &[(0b00001, &ENTRY_VAPORLIKES_4827403622949682642)],
        &[(0b00001, &ENTRY_VAPOROSE_6449688285161662447)],
        &[(0b00001, &ENTRY_VAPOROUSLY_4033817846371416657)],
        &[(0b11001, &ENTRY_VAPORS_10654457609159557123)],
        &[(0b01001, &ENTRY_VAPORWARE_9698524933063954413)],
        &[(0b00001, &ENTRY_VAPORY_2699803825003632190)],
    ],
    range: 1..=9,
};

static VARS_VAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAN_CHILDREN),
    value: None,
};

pub static VARS_VAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dalisation"),
        dictgen::InsensitiveStr::Ascii("dalisations"),
        dictgen::InsensitiveStr::Ascii("dalise"),
        dictgen::InsensitiveStr::Ascii("dalised"),
        dictgen::InsensitiveStr::Ascii("dalises"),
        dictgen::InsensitiveStr::Ascii("dalising"),
        dictgen::InsensitiveStr::Ascii("dalization"),
        dictgen::InsensitiveStr::Ascii("dalizations"),
        dictgen::InsensitiveStr::Ascii("dalize"),
        dictgen::InsensitiveStr::Ascii("dalized"),
        dictgen::InsensitiveStr::Ascii("dalizes"),
        dictgen::InsensitiveStr::Ascii("dalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VANDALIZATION_6495560549083632958)],
        &[(0b10010, &ENTRY_VANDALIZATIONS_15625432211900495710)],
        &[(0b10010, &ENTRY_VANDALIZE_3654743374834615371)],
        &[(0b10010, &ENTRY_VANDALIZED_4895140872617125953)],
        &[(0b10010, &ENTRY_VANDALIZES_7396543552418251345)],
        &[(0b10010, &ENTRY_VANDALIZING_2999607049988004510)],
        &[(0b01001, &ENTRY_VANDALIZATION_6495560549083632958)],
        &[(0b01001, &ENTRY_VANDALIZATIONS_15625432211900495710)],
        &[(0b01001, &ENTRY_VANDALIZE_3654743374834615371)],
        &[(0b01001, &ENTRY_VANDALIZED_4895140872617125953)],
        &[(0b01001, &ENTRY_VANDALIZES_7396543552418251345)],
        &[(0b01001, &ENTRY_VANDALIZING_2999607049988004510)],
    ],
    range: 6..=11,
};

static VARS_VAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAM_CHILDREN),
    value: None,
};

pub static VARS_VAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("pirise"),
        dictgen::InsensitiveStr::Ascii("pirised"),
        dictgen::InsensitiveStr::Ascii("pirises"),
        dictgen::InsensitiveStr::Ascii("pirising"),
        dictgen::InsensitiveStr::Ascii("pirize"),
        dictgen::InsensitiveStr::Ascii("pirized"),
        dictgen::InsensitiveStr::Ascii("pirizes"),
        dictgen::InsensitiveStr::Ascii("pirizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VAMPIRIZE_17453207416415996069)],
        &[(0b10010, &ENTRY_VAMPIRIZED_14222402737807902965)],
        &[(0b10010, &ENTRY_VAMPIRIZES_16562346264831458764)],
        &[(0b10010, &ENTRY_VAMPIRIZING_9793272166226198060)],
        &[(0b01001, &ENTRY_VAMPIRIZE_17453207416415996069)],
        &[(0b01001, &ENTRY_VAMPIRIZED_14222402737807902965)],
        &[(0b01001, &ENTRY_VAMPIRIZES_16562346264831458764)],
        &[(0b01001, &ENTRY_VAMPIRIZING_9793272166226198060)],
    ],
    range: 6..=8,
};

static VARS_VAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAL_CHILDREN),
    value: None,
};

pub static VARS_VAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
        dictgen::InsensitiveStr::Ascii("orousness"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ourousness"),
        dictgen::InsensitiveStr::Ascii("ours"),
        dictgen::InsensitiveStr::Ascii("vulae"),
        dictgen::InsensitiveStr::Ascii("vule"),
    ],
    values: &[
        &[(0b11001, &ENTRY_VALOR_10381241029341969425)],
        &[(0b10010, &ENTRY_VALORIZATION_13227626070656104535)],
        &[(0b10010, &ENTRY_VALORIZATIONS_18099999439268061636)],
        &[(0b10010, &ENTRY_VALORIZE_2044080804493227048)],
        &[(0b10010, &ENTRY_VALORIZED_18268036447448640796)],
        &[(0b10010, &ENTRY_VALORIZES_8203138506905157861)],
        &[(0b10010, &ENTRY_VALORIZING_1072198845281593214)],
        &[(0b01001, &ENTRY_VALORIZATION_13227626070656104535)],
        &[(0b01001, &ENTRY_VALORIZATIONS_18099999439268061636)],
        &[(0b01001, &ENTRY_VALORIZE_2044080804493227048)],
        &[(0b01001, &ENTRY_VALORIZED_18268036447448640796)],
        &[(0b01001, &ENTRY_VALORIZES_8203138506905157861)],
        &[(0b01001, &ENTRY_VALORIZING_1072198845281593214)],
        &[(0b00001, &ENTRY_VALOROUSNESS_9703103708455235988)],
        &[(0b11001, &ENTRY_VALORS_9234945520471825890)],
        &[(0b11010, &ENTRY_VALOR_10381241029341969425)],
        &[(0b11010, &ENTRY_VALOROUSNESS_9703103708455235988)],
        &[(0b11010, &ENTRY_VALORS_9234945520471825890)],
        &[(0b11010, &ENTRY_VALVULE_8551640593569568914)],
        &[(0b00001, &ENTRY_VALVULE_8551640593569568914)],
    ],
    range: 2..=10,
};

static VARS_VAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAG_CHILDREN),
    value: None,
};

pub static VARS_VAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abondise"),
        dictgen::InsensitiveStr::Ascii("abondised"),
        dictgen::InsensitiveStr::Ascii("abondiser"),
        dictgen::InsensitiveStr::Ascii("abondisers"),
        dictgen::InsensitiveStr::Ascii("abondises"),
        dictgen::InsensitiveStr::Ascii("abondising"),
        dictgen::InsensitiveStr::Ascii("abondize"),
        dictgen::InsensitiveStr::Ascii("abondized"),
        dictgen::InsensitiveStr::Ascii("abondizer"),
        dictgen::InsensitiveStr::Ascii("abondizers"),
        dictgen::InsensitiveStr::Ascii("abondizes"),
        dictgen::InsensitiveStr::Ascii("abondizing"),
        dictgen::InsensitiveStr::Ascii("inulae"),
        dictgen::InsensitiveStr::Ascii("inule"),
        dictgen::InsensitiveStr::Ascii("rantise"),
        dictgen::InsensitiveStr::Ascii("rantises"),
        dictgen::InsensitiveStr::Ascii("rantize"),
        dictgen::InsensitiveStr::Ascii("rantizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VAGABONDIZE_1828506949789504418)],
        &[(0b10010, &ENTRY_VAGABONDIZED_15281278738005878763)],
        &[(0b10010, &ENTRY_VAGABONDIZER_10845102064298248541)],
        &[(0b10010, &ENTRY_VAGABONDIZERS_3747353708553114039)],
        &[(0b10010, &ENTRY_VAGABONDIZES_16914905745572024859)],
        &[(0b10010, &ENTRY_VAGABONDIZING_536301653145662259)],
        &[(0b01001, &ENTRY_VAGABONDIZE_1828506949789504418)],
        &[(0b01001, &ENTRY_VAGABONDIZED_15281278738005878763)],
        &[(0b01001, &ENTRY_VAGABONDIZER_10845102064298248541)],
        &[(0b01001, &ENTRY_VAGABONDIZERS_3747353708553114039)],
        &[(0b01001, &ENTRY_VAGABONDIZES_16914905745572024859)],
        &[(0b01001, &ENTRY_VAGABONDIZING_536301653145662259)],
        &[(0b11010, &ENTRY_VAGINULE_10192361025884867710)],
        &[(0b00001, &ENTRY_VAGINULE_10192361025884867710)],
        &[(0b10010, &ENTRY_VAGRANTIZE_16327806044259598431)],
        &[(0b10010, &ENTRY_VAGRANTIZES_5103890612140781248)],
        &[(0b01001, &ENTRY_VAGRANTIZE_16327806044259598431)],
        &[(0b01001, &ENTRY_VAGRANTIZES_5103890612140781248)],
    ],
    range: 5..=10,
};

static VARS_VAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAC_CHILDREN),
    value: None,
};

pub static VARS_VAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cinisation"),
        dictgen::InsensitiveStr::Ascii("cinisations"),
        dictgen::InsensitiveStr::Ascii("cinization"),
        dictgen::InsensitiveStr::Ascii("cinizations"),
        dictgen::InsensitiveStr::Ascii("uolisation"),
        dictgen::InsensitiveStr::Ascii("uolisations"),
        dictgen::InsensitiveStr::Ascii("uolization"),
        dictgen::InsensitiveStr::Ascii("uolizations"),
        dictgen::InsensitiveStr::Ascii("uumise"),
        dictgen::InsensitiveStr::Ascii("uumised"),
        dictgen::InsensitiveStr::Ascii("uumises"),
        dictgen::InsensitiveStr::Ascii("uumising"),
        dictgen::InsensitiveStr::Ascii("uumize"),
        dictgen::InsensitiveStr::Ascii("uumized"),
        dictgen::InsensitiveStr::Ascii("uumizes"),
        dictgen::InsensitiveStr::Ascii("uumizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VACCINIZATION_8106181806810108402)],
        &[(0b10010, &ENTRY_VACCINIZATIONS_1922009171419608969)],
        &[(0b01001, &ENTRY_VACCINIZATION_8106181806810108402)],
        &[(0b01001, &ENTRY_VACCINIZATIONS_1922009171419608969)],
        &[(0b10010, &ENTRY_VACUOLIZATION_11646539416302232322)],
        &[(0b10010, &ENTRY_VACUOLIZATIONS_10347160945935413661)],
        &[(0b01001, &ENTRY_VACUOLIZATION_11646539416302232322)],
        &[(0b01001, &ENTRY_VACUOLIZATIONS_10347160945935413661)],
        &[(0b10010, &ENTRY_VACUUMIZE_13526087569368801646)],
        &[(0b10010, &ENTRY_VACUUMIZED_4493282451537357801)],
        &[(0b10010, &ENTRY_VACUUMIZES_17532454384376281205)],
        &[(0b10010, &ENTRY_VACUUMIZING_14054787523141533264)],
        &[(0b01001, &ENTRY_VACUUMIZE_13526087569368801646)],
        &[(0b01001, &ENTRY_VACUUMIZED_4493282451537357801)],
        &[(0b01001, &ENTRY_VACUUMIZES_17532454384376281205)],
        &[(0b01001, &ENTRY_VACUUMIZING_14054787523141533264)],
    ],
    range: 6..=11,
};

static VARS_VAA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAA_CHILDREN),
    value: None,
};

pub static VARS_VAA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gmaer"),
        dictgen::InsensitiveStr::Ascii("gmer"),
    ],
    values: &[
        &[(0b11010, &ENTRY_VAAGMER_17502048229443235773)],
        &[(0b00001, &ENTRY_VAAGMER_17502048229443235773)],
    ],
    range: 4..=5,
};

static VARS_U_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_U_CHILDREN),
    value: None,
};

static VARS_U_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UL_NODE),
    None,
    Some(&VARS_UN_NODE),
    None,
    Some(&VARS_UP_NODE),
    None,
    Some(&VARS_UR_NODE),
    Some(&VARS_US_NODE),
    Some(&VARS_UT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_UT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UT_CHILDREN),
    value: None,
};

pub static VARS_UT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilisabilities"),
        dictgen::InsensitiveStr::Ascii("ilisability"),
        dictgen::InsensitiveStr::Ascii("ilisable"),
        dictgen::InsensitiveStr::Ascii("ilisables"),
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("iliser"),
        dictgen::InsensitiveStr::Ascii("ilisers"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilitarianise"),
        dictgen::InsensitiveStr::Ascii("ilitarianised"),
        dictgen::InsensitiveStr::Ascii("ilitarianises"),
        dictgen::InsensitiveStr::Ascii("ilitarianising"),
        dictgen::InsensitiveStr::Ascii("ilitarianize"),
        dictgen::InsensitiveStr::Ascii("ilitarianized"),
        dictgen::InsensitiveStr::Ascii("ilitarianizes"),
        dictgen::InsensitiveStr::Ascii("ilitarianizing"),
        dictgen::InsensitiveStr::Ascii("ilizabilities"),
        dictgen::InsensitiveStr::Ascii("ilizability"),
        dictgen::InsensitiveStr::Ascii("ilizable"),
        dictgen::InsensitiveStr::Ascii("ilizables"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizer"),
        dictgen::InsensitiveStr::Ascii("ilizers"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
        dictgen::InsensitiveStr::Ascii("opianise"),
        dictgen::InsensitiveStr::Ascii("opianised"),
        dictgen::InsensitiveStr::Ascii("opianiser"),
        dictgen::InsensitiveStr::Ascii("opianisers"),
        dictgen::InsensitiveStr::Ascii("opianises"),
        dictgen::InsensitiveStr::Ascii("opianising"),
        dictgen::InsensitiveStr::Ascii("opianize"),
        dictgen::InsensitiveStr::Ascii("opianized"),
        dictgen::InsensitiveStr::Ascii("opianizer"),
        dictgen::InsensitiveStr::Ascii("opianizers"),
        dictgen::InsensitiveStr::Ascii("opianizes"),
        dictgen::InsensitiveStr::Ascii("opianizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UTILIZABILITIES_11881898061855249496)],
        &[(0b10010, &ENTRY_UTILIZABILITY_12860697351170482431)],
        &[(0b10010, &ENTRY_UTILIZABLE_6658429424042092500)],
        &[(0b10010, &ENTRY_UTILIZABLES_10040108748299984073)],
        &[(0b10010, &ENTRY_UTILIZATION_6568984108837424526)],
        &[(0b10010, &ENTRY_UTILIZATIONS_5213929250198924058)],
        &[(0b10010, &ENTRY_UTILIZE_10044375682174548784)],
        &[(0b10010, &ENTRY_UTILIZED_18374385558160803150)],
        &[(0b10010, &ENTRY_UTILIZER_12640552973480950568)],
        &[(0b10010, &ENTRY_UTILIZERS_7421512610729195706)],
        &[(0b10010, &ENTRY_UTILIZES_17217644256000960699)],
        &[(0b10010, &ENTRY_UTILIZING_6570837818573449537)],
        &[(0b10010, &ENTRY_UTILITARIANIZE_16499671456877398727)],
        &[(0b10010, &ENTRY_UTILITARIANIZED_4163007102774670957)],
        &[(0b10010, &ENTRY_UTILITARIANIZES_18334315752484546497)],
        &[(0b10010, &ENTRY_UTILITARIANIZING_15409066625405044535)],
        &[(0b01001, &ENTRY_UTILITARIANIZE_16499671456877398727)],
        &[(0b01001, &ENTRY_UTILITARIANIZED_4163007102774670957)],
        &[(0b01001, &ENTRY_UTILITARIANIZES_18334315752484546497)],
        &[(0b01001, &ENTRY_UTILITARIANIZING_15409066625405044535)],
        &[(0b01001, &ENTRY_UTILIZABILITIES_11881898061855249496)],
        &[(0b01001, &ENTRY_UTILIZABILITY_12860697351170482431)],
        &[(0b01001, &ENTRY_UTILIZABLE_6658429424042092500)],
        &[(0b01001, &ENTRY_UTILIZABLES_10040108748299984073)],
        &[(0b01001, &ENTRY_UTILIZATION_6568984108837424526)],
        &[(0b01001, &ENTRY_UTILIZATIONS_5213929250198924058)],
        &[(0b01001, &ENTRY_UTILIZE_10044375682174548784)],
        &[(0b01001, &ENTRY_UTILIZED_18374385558160803150)],
        &[(0b01001, &ENTRY_UTILIZER_12640552973480950568)],
        &[(0b01001, &ENTRY_UTILIZERS_7421512610729195706)],
        &[(0b01001, &ENTRY_UTILIZES_17217644256000960699)],
        &[(0b01001, &ENTRY_UTILIZING_6570837818573449537)],
        &[(0b10010, &ENTRY_UTOPIANIZE_3909405410781325408)],
        &[(0b10010, &ENTRY_UTOPIANIZED_5257825936015196627)],
        &[(0b10010, &ENTRY_UTOPIANIZER_9926780539300230048)],
        &[(0b10010, &ENTRY_UTOPIANIZERS_16589758661481842229)],
        &[(0b10010, &ENTRY_UTOPIANIZES_7436002859222682332)],
        &[(0b10010, &ENTRY_UTOPIANIZING_10367314140698776591)],
        &[(0b01001, &ENTRY_UTOPIANIZE_3909405410781325408)],
        &[(0b01001, &ENTRY_UTOPIANIZED_5257825936015196627)],
        &[(0b01001, &ENTRY_UTOPIANIZER_9926780539300230048)],
        &[(0b01001, &ENTRY_UTOPIANIZERS_16589758661481842229)],
        &[(0b01001, &ENTRY_UTOPIANIZES_7436002859222682332)],
        &[(0b01001, &ENTRY_UTOPIANIZING_10367314140698776591)],
    ],
    range: 5..=14,
};

static VARS_US_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_US_CHILDREN),
    value: None,
};

pub static VARS_US_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("eability")],
    values: &[&[(0b00001, &ENTRY_USABILITY_14697152389699662448)]],
    range: 8..=8,
};

static VARS_UR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UR_CHILDREN),
    value: None,
};

pub static VARS_UR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("aemias"),
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("alitisation"),
        dictgen::InsensitiveStr::Ascii("alitisations"),
        dictgen::InsensitiveStr::Ascii("alitise"),
        dictgen::InsensitiveStr::Ascii("alitised"),
        dictgen::InsensitiveStr::Ascii("alitises"),
        dictgen::InsensitiveStr::Ascii("alitising"),
        dictgen::InsensitiveStr::Ascii("alitization"),
        dictgen::InsensitiveStr::Ascii("alitizations"),
        dictgen::InsensitiveStr::Ascii("alitize"),
        dictgen::InsensitiveStr::Ascii("alitized"),
        dictgen::InsensitiveStr::Ascii("alitizes"),
        dictgen::InsensitiveStr::Ascii("alitizing"),
        dictgen::InsensitiveStr::Ascii("ataemia"),
        dictgen::InsensitiveStr::Ascii("atemia"),
        dictgen::InsensitiveStr::Ascii("banisation"),
        dictgen::InsensitiveStr::Ascii("banisations"),
        dictgen::InsensitiveStr::Ascii("banise"),
        dictgen::InsensitiveStr::Ascii("banised"),
        dictgen::InsensitiveStr::Ascii("banises"),
        dictgen::InsensitiveStr::Ascii("banising"),
        dictgen::InsensitiveStr::Ascii("banization"),
        dictgen::InsensitiveStr::Ascii("banizations"),
        dictgen::InsensitiveStr::Ascii("banize"),
        dictgen::InsensitiveStr::Ascii("banized"),
        dictgen::InsensitiveStr::Ascii("banizes"),
        dictgen::InsensitiveStr::Ascii("banizing"),
        dictgen::InsensitiveStr::Ascii("edema"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emias"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("ethrorrhea"),
        dictgen::InsensitiveStr::Ascii("ethrorrhoea"),
        dictgen::InsensitiveStr::Ascii("icaemia"),
        dictgen::InsensitiveStr::Ascii("icaemic"),
        dictgen::InsensitiveStr::Ascii("icemia"),
        dictgen::InsensitiveStr::Ascii("icemic"),
        dictgen::InsensitiveStr::Ascii("inaemia"),
        dictgen::InsensitiveStr::Ascii("inaemic"),
        dictgen::InsensitiveStr::Ascii("inemia"),
        dictgen::InsensitiveStr::Ascii("inemic"),
        dictgen::InsensitiveStr::Ascii("oedema"),
        dictgen::InsensitiveStr::Ascii("ohaematin"),
        dictgen::InsensitiveStr::Ascii("ohematin"),
        dictgen::InsensitiveStr::Ascii("ophaein"),
        dictgen::InsensitiveStr::Ascii("ophein"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UREMIA_18083383868084280126)],
        &[(0b10010, &ENTRY_UREMIAS_12816641380732423378)],
        &[(0b10010, &ENTRY_UREMIC_1443341952685545241)],
        &[(0b10010, &ENTRY_URALITIZATION_2328489967231120643)],
        &[(0b10010, &ENTRY_URALITIZATIONS_5627846874760536030)],
        &[(0b10010, &ENTRY_URALITIZE_3773590098260410307)],
        &[(0b10010, &ENTRY_URALITIZED_204002861074668809)],
        &[(0b10010, &ENTRY_URALITIZES_16267515381011421047)],
        &[(0b10010, &ENTRY_URALITIZING_10355237273114377488)],
        &[(0b01001, &ENTRY_URALITIZATION_2328489967231120643)],
        &[(0b01001, &ENTRY_URALITIZATIONS_5627846874760536030)],
        &[(0b01001, &ENTRY_URALITIZE_3773590098260410307)],
        &[(0b01001, &ENTRY_URALITIZED_204002861074668809)],
        &[(0b01001, &ENTRY_URALITIZES_16267515381011421047)],
        &[(0b01001, &ENTRY_URALITIZING_10355237273114377488)],
        &[(0b11010, &ENTRY_URATEMIA_14232416398105000456)],
        &[(0b00001, &ENTRY_URATEMIA_14232416398105000456)],
        &[(0b10010, &ENTRY_URBANIZATION_12387885989461849064)],
        &[(0b10010, &ENTRY_URBANIZATIONS_8711148164069228358)],
        &[(0b10010, &ENTRY_URBANIZE_7137294181980044513)],
        &[(0b10010, &ENTRY_URBANIZED_8452856878168803812)],
        &[(0b10010, &ENTRY_URBANIZES_10930122484117694307)],
        &[(0b10010, &ENTRY_URBANIZING_14508129715867395456)],
        &[(0b01001, &ENTRY_URBANIZATION_12387885989461849064)],
        &[(0b01001, &ENTRY_URBANIZATIONS_8711148164069228358)],
        &[(0b01001, &ENTRY_URBANIZE_7137294181980044513)],
        &[(0b01001, &ENTRY_URBANIZED_8452856878168803812)],
        &[(0b01001, &ENTRY_URBANIZES_10930122484117694307)],
        &[(0b01001, &ENTRY_URBANIZING_14508129715867395456)],
        &[(0b00001, &ENTRY_UREDEMA_4080149276415718183)],
        &[(0b01001, &ENTRY_UREMIA_18083383868084280126)],
        &[(0b01001, &ENTRY_UREMIAS_12816641380732423378)],
        &[(0b01001, &ENTRY_UREMIC_1443341952685545241)],
        &[(0b00001, &ENTRY_URETHRORRHEA_4573312718933151955)],
        &[(0b11010, &ENTRY_URETHRORRHEA_4573312718933151955)],
        &[(0b11010, &ENTRY_URICEMIA_10236250755038957119)],
        &[(0b11010, &ENTRY_URICEMIC_10169615382969686007)],
        &[(0b00001, &ENTRY_URICEMIA_10236250755038957119)],
        &[(0b00001, &ENTRY_URICEMIC_10169615382969686007)],
        &[(0b11010, &ENTRY_URINEMIA_16117298491410487282)],
        &[(0b11010, &ENTRY_URINEMIC_16880578158575836043)],
        &[(0b00001, &ENTRY_URINEMIA_16117298491410487282)],
        &[(0b00001, &ENTRY_URINEMIC_16880578158575836043)],
        &[(0b11010, &ENTRY_UREDEMA_4080149276415718183)],
        &[(0b11010, &ENTRY_UROHEMATIN_13360943616892094038)],
        &[(0b00001, &ENTRY_UROHEMATIN_13360943616892094038)],
        &[(0b11010, &ENTRY_UROPHEIN_6391807598160189992)],
        &[(0b00001, &ENTRY_UROPHEIN_6391807598160189992)],
    ],
    range: 4..=12,
};

static VARS_UP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UP_CHILDREN),
    value: None,
};

pub static VARS_UP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("draft"),
        dictgen::InsensitiveStr::Ascii("drafts"),
        dictgen::InsensitiveStr::Ascii("draught"),
        dictgen::InsensitiveStr::Ascii("draughts"),
    ],
    values: &[
        &[(0b01001, &ENTRY_UPDRAFT_2544941178284387496)],
        &[(0b01001, &ENTRY_UPDRAFTS_3266150290118937286)],
        &[(0b11010, &ENTRY_UPDRAFT_2544941178284387496)],
        &[(0b11010, &ENTRY_UPDRAFTS_3266150290118937286)],
    ],
    range: 5..=8,
};

static VARS_UN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UN_CHILDREN),
    value: None,
};

static VARS_UN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNA_NODE),
    Some(&VARS_UNB_NODE),
    Some(&VARS_UNC_NODE),
    Some(&VARS_UND_NODE),
    Some(&VARS_UNE_NODE),
    Some(&VARS_UNF_NODE),
    Some(&VARS_UNG_NODE),
    Some(&VARS_UNH_NODE),
    Some(&VARS_UNI_NODE),
    Some(&VARS_UNJ_NODE),
    Some(&VARS_UNK_NODE),
    Some(&VARS_UNL_NODE),
    Some(&VARS_UNM_NODE),
    Some(&VARS_UNN_NODE),
    Some(&VARS_UNO_NODE),
    Some(&VARS_UNP_NODE),
    Some(&VARS_UNQ_NODE),
    Some(&VARS_UNR_NODE),
    Some(&VARS_UNS_NODE),
    Some(&VARS_UNT_NODE),
    Some(&VARS_UNU_NODE),
    Some(&VARS_UNV_NODE),
    Some(&VARS_UNW_NODE),
    None,
    None,
    None,
];

static VARS_UNW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNW_CHILDREN),
    value: None,
};

pub static VARS_UNW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("esternised"),
        dictgen::InsensitiveStr::Ascii("esterniseds"),
        dictgen::InsensitiveStr::Ascii("esternized"),
        dictgen::InsensitiveStr::Ascii("esternizeds"),
        dictgen::InsensitiveStr::Ascii("omanise"),
        dictgen::InsensitiveStr::Ascii("omanised"),
        dictgen::InsensitiveStr::Ascii("omanises"),
        dictgen::InsensitiveStr::Ascii("omanize"),
        dictgen::InsensitiveStr::Ascii("omanized"),
        dictgen::InsensitiveStr::Ascii("omanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNWESTERNIZED_16804384595354754797)],
        &[(0b10010, &ENTRY_UNWESTERNIZEDS_7464751557548933854)],
        &[(0b01001, &ENTRY_UNWESTERNIZED_16804384595354754797)],
        &[(0b01001, &ENTRY_UNWESTERNIZEDS_7464751557548933854)],
        &[(0b10010, &ENTRY_UNWOMANIZE_1985503055403674491)],
        &[(0b10010, &ENTRY_UNWOMANIZED_10013478943540238931)],
        &[(0b10010, &ENTRY_UNWOMANIZES_2686931929978088595)],
        &[(0b01001, &ENTRY_UNWOMANIZE_1985503055403674491)],
        &[(0b01001, &ENTRY_UNWOMANIZED_10013478943540238931)],
        &[(0b01001, &ENTRY_UNWOMANIZES_2686931929978088595)],
    ],
    range: 7..=11,
};

static VARS_UNV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNV_CHILDREN),
    value: None,
};

pub static VARS_UNV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aporised"),
        dictgen::InsensitiveStr::Ascii("aporiseds"),
        dictgen::InsensitiveStr::Ascii("aporized"),
        dictgen::InsensitiveStr::Ascii("aporizeds"),
        dictgen::InsensitiveStr::Ascii("ectorisable"),
        dictgen::InsensitiveStr::Ascii("ectorizable"),
        dictgen::InsensitiveStr::Ascii("erbalised"),
        dictgen::InsensitiveStr::Ascii("erbalized"),
        dictgen::InsensitiveStr::Ascii("ictimised"),
        dictgen::InsensitiveStr::Ascii("ictimized"),
        dictgen::InsensitiveStr::Ascii("isualised"),
        dictgen::InsensitiveStr::Ascii("isualisedder"),
        dictgen::InsensitiveStr::Ascii("isualiseddest"),
        dictgen::InsensitiveStr::Ascii("isualized"),
        dictgen::InsensitiveStr::Ascii("isualizedder"),
        dictgen::InsensitiveStr::Ascii("isualizeddest"),
        dictgen::InsensitiveStr::Ascii("italised"),
        dictgen::InsensitiveStr::Ascii("italiseds"),
        dictgen::InsensitiveStr::Ascii("italized"),
        dictgen::InsensitiveStr::Ascii("italizeds"),
        dictgen::InsensitiveStr::Ascii("itriolised"),
        dictgen::InsensitiveStr::Ascii("itrioliseds"),
        dictgen::InsensitiveStr::Ascii("itriolized"),
        dictgen::InsensitiveStr::Ascii("itriolizeds"),
        dictgen::InsensitiveStr::Ascii("ocalised"),
        dictgen::InsensitiveStr::Ascii("ocalisedder"),
        dictgen::InsensitiveStr::Ascii("ocaliseddest"),
        dictgen::InsensitiveStr::Ascii("ocaliseds"),
        dictgen::InsensitiveStr::Ascii("ocalized"),
        dictgen::InsensitiveStr::Ascii("ocalizedder"),
        dictgen::InsensitiveStr::Ascii("ocalizeddest"),
        dictgen::InsensitiveStr::Ascii("ocalizeds"),
        dictgen::InsensitiveStr::Ascii("olatilise"),
        dictgen::InsensitiveStr::Ascii("olatilised"),
        dictgen::InsensitiveStr::Ascii("olatilisedder"),
        dictgen::InsensitiveStr::Ascii("olatiliseddest"),
        dictgen::InsensitiveStr::Ascii("olatilises"),
        dictgen::InsensitiveStr::Ascii("olatilize"),
        dictgen::InsensitiveStr::Ascii("olatilized"),
        dictgen::InsensitiveStr::Ascii("olatilizedder"),
        dictgen::InsensitiveStr::Ascii("olatilizeddest"),
        dictgen::InsensitiveStr::Ascii("olatilizes"),
        dictgen::InsensitiveStr::Ascii("ulcanised"),
        dictgen::InsensitiveStr::Ascii("ulcanisedder"),
        dictgen::InsensitiveStr::Ascii("ulcaniseddest"),
        dictgen::InsensitiveStr::Ascii("ulcaniseds"),
        dictgen::InsensitiveStr::Ascii("ulcanized"),
        dictgen::InsensitiveStr::Ascii("ulcanizedder"),
        dictgen::InsensitiveStr::Ascii("ulcanizeddest"),
        dictgen::InsensitiveStr::Ascii("ulcanizeds"),
        dictgen::InsensitiveStr::Ascii("ulgarise"),
        dictgen::InsensitiveStr::Ascii("ulgarised"),
        dictgen::InsensitiveStr::Ascii("ulgarises"),
        dictgen::InsensitiveStr::Ascii("ulgarising"),
        dictgen::InsensitiveStr::Ascii("ulgarize"),
        dictgen::InsensitiveStr::Ascii("ulgarized"),
        dictgen::InsensitiveStr::Ascii("ulgarizes"),
        dictgen::InsensitiveStr::Ascii("ulgarizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNVAPORIZED_9453095998519615936)],
        &[(0b10010, &ENTRY_UNVAPORIZEDS_3053547386158063137)],
        &[(0b01001, &ENTRY_UNVAPORIZED_9453095998519615936)],
        &[(0b01001, &ENTRY_UNVAPORIZEDS_3053547386158063137)],
        &[(0b10010, &ENTRY_UNVECTORIZABLE_6179247702715111446)],
        &[(0b01001, &ENTRY_UNVECTORIZABLE_6179247702715111446)],
        &[(0b10010, &ENTRY_UNVERBALIZED_15207072139205961298)],
        &[(0b01001, &ENTRY_UNVERBALIZED_15207072139205961298)],
        &[(0b10010, &ENTRY_UNVICTIMIZED_13147930702000821440)],
        &[(0b01001, &ENTRY_UNVICTIMIZED_13147930702000821440)],
        &[(0b10010, &ENTRY_UNVISUALIZED_10629125161003204005)],
        &[(0b10010, &ENTRY_UNVISUALIZEDDER_17148048408574308157)],
        &[(0b10010, &ENTRY_UNVISUALIZEDDEST_3766144370146755628)],
        &[(0b01001, &ENTRY_UNVISUALIZED_10629125161003204005)],
        &[(0b01001, &ENTRY_UNVISUALIZEDDER_17148048408574308157)],
        &[(0b01001, &ENTRY_UNVISUALIZEDDEST_3766144370146755628)],
        &[(0b10010, &ENTRY_UNVITALIZED_3227640869725648957)],
        &[(0b10010, &ENTRY_UNVITALIZEDS_3502721533025861731)],
        &[(0b01001, &ENTRY_UNVITALIZED_3227640869725648957)],
        &[(0b01001, &ENTRY_UNVITALIZEDS_3502721533025861731)],
        &[(0b10010, &ENTRY_UNVITRIOLIZED_18178005376251422334)],
        &[(0b10010, &ENTRY_UNVITRIOLIZEDS_6279669080760237108)],
        &[(0b01001, &ENTRY_UNVITRIOLIZED_18178005376251422334)],
        &[(0b01001, &ENTRY_UNVITRIOLIZEDS_6279669080760237108)],
        &[(0b10010, &ENTRY_UNVOCALIZED_11577467705658915530)],
        &[(0b10010, &ENTRY_UNVOCALIZEDDER_14054075246195872904)],
        &[(0b10010, &ENTRY_UNVOCALIZEDDEST_11194321700060332314)],
        &[(0b10010, &ENTRY_UNVOCALIZEDS_9772690236419527892)],
        &[(0b01001, &ENTRY_UNVOCALIZED_11577467705658915530)],
        &[(0b01001, &ENTRY_UNVOCALIZEDDER_14054075246195872904)],
        &[(0b01001, &ENTRY_UNVOCALIZEDDEST_11194321700060332314)],
        &[(0b01001, &ENTRY_UNVOCALIZEDS_9772690236419527892)],
        &[(0b10010, &ENTRY_UNVOLATILIZE_11661168719592780567)],
        &[(0b10010, &ENTRY_UNVOLATILIZED_510948108982730129)],
        &[(0b10010, &ENTRY_UNVOLATILIZEDDER_3893053978188165962)],
        &[(0b10010, &ENTRY_UNVOLATILIZEDDEST_2981075151788794586)],
        &[(0b10010, &ENTRY_UNVOLATILIZES_11377758185893284437)],
        &[(0b01001, &ENTRY_UNVOLATILIZE_11661168719592780567)],
        &[(0b01001, &ENTRY_UNVOLATILIZED_510948108982730129)],
        &[(0b01001, &ENTRY_UNVOLATILIZEDDER_3893053978188165962)],
        &[(0b01001, &ENTRY_UNVOLATILIZEDDEST_2981075151788794586)],
        &[(0b01001, &ENTRY_UNVOLATILIZES_11377758185893284437)],
        &[(0b10010, &ENTRY_UNVULCANIZED_4883353722370077258)],
        &[(0b10010, &ENTRY_UNVULCANIZEDDER_9219302424160022442)],
        &[(0b10010, &ENTRY_UNVULCANIZEDDEST_13602333265783224219)],
        &[(0b10010, &ENTRY_UNVULCANIZEDS_14843559940845440326)],
        &[(0b01001, &ENTRY_UNVULCANIZED_4883353722370077258)],
        &[(0b01001, &ENTRY_UNVULCANIZEDDER_9219302424160022442)],
        &[(0b01001, &ENTRY_UNVULCANIZEDDEST_13602333265783224219)],
        &[(0b01001, &ENTRY_UNVULCANIZEDS_14843559940845440326)],
        &[(0b10010, &ENTRY_UNVULGARIZE_7587382011777787660)],
        &[(0b10010, &ENTRY_UNVULGARIZED_9965815826975289580)],
        &[(0b10010, &ENTRY_UNVULGARIZES_9567873413092075624)],
        &[(0b10010, &ENTRY_UNVULGARIZING_13060747384314447095)],
        &[(0b01001, &ENTRY_UNVULGARIZE_7587382011777787660)],
        &[(0b01001, &ENTRY_UNVULGARIZED_9965815826975289580)],
        &[(0b01001, &ENTRY_UNVULGARIZES_9567873413092075624)],
        &[(0b01001, &ENTRY_UNVULGARIZING_13060747384314447095)],
    ],
    range: 8..=14,
};

static VARS_UNU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNU_CHILDREN),
    value: None,
};

pub static VARS_UNU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tilisable"),
        dictgen::InsensitiveStr::Ascii("tilisables"),
        dictgen::InsensitiveStr::Ascii("tilised"),
        dictgen::InsensitiveStr::Ascii("tilizable"),
        dictgen::InsensitiveStr::Ascii("tilizables"),
        dictgen::InsensitiveStr::Ascii("tilized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNUTILIZABLE_3295844226688802618)],
        &[(0b10010, &ENTRY_UNUTILIZABLES_8540746522822486622)],
        &[(0b10010, &ENTRY_UNUTILIZED_1068022609704657690)],
        &[(0b01001, &ENTRY_UNUTILIZABLE_3295844226688802618)],
        &[(0b01001, &ENTRY_UNUTILIZABLES_8540746522822486622)],
        &[(0b01001, &ENTRY_UNUTILIZED_1068022609704657690)],
    ],
    range: 7..=10,
};

static VARS_UNT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNT_CHILDREN),
    value: None,
};

pub static VARS_UNT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("antalised"),
        dictgen::InsensitiveStr::Ascii("antalisedder"),
        dictgen::InsensitiveStr::Ascii("antaliseddest"),
        dictgen::InsensitiveStr::Ascii("antalising"),
        dictgen::InsensitiveStr::Ascii("antalisinger"),
        dictgen::InsensitiveStr::Ascii("antalisingest"),
        dictgen::InsensitiveStr::Ascii("antalisings"),
        dictgen::InsensitiveStr::Ascii("antalized"),
        dictgen::InsensitiveStr::Ascii("antalizedder"),
        dictgen::InsensitiveStr::Ascii("antalizeddest"),
        dictgen::InsensitiveStr::Ascii("antalizing"),
        dictgen::InsensitiveStr::Ascii("antalizinger"),
        dictgen::InsensitiveStr::Ascii("antalizingest"),
        dictgen::InsensitiveStr::Ascii("antalizings"),
        dictgen::InsensitiveStr::Ascii("artarised"),
        dictgen::InsensitiveStr::Ascii("artariseds"),
        dictgen::InsensitiveStr::Ascii("artarized"),
        dictgen::InsensitiveStr::Ascii("artarizeds"),
        dictgen::InsensitiveStr::Ascii("echnicalise"),
        dictgen::InsensitiveStr::Ascii("echnicalises"),
        dictgen::InsensitiveStr::Ascii("echnicalize"),
        dictgen::InsensitiveStr::Ascii("echnicalizes"),
        dictgen::InsensitiveStr::Ascii("emporising"),
        dictgen::InsensitiveStr::Ascii("emporisings"),
        dictgen::InsensitiveStr::Ascii("emporizing"),
        dictgen::InsensitiveStr::Ascii("emporizings"),
        dictgen::InsensitiveStr::Ascii("errorised"),
        dictgen::InsensitiveStr::Ascii("errorized"),
        dictgen::InsensitiveStr::Ascii("heorisable"),
        dictgen::InsensitiveStr::Ascii("heorisables"),
        dictgen::InsensitiveStr::Ascii("heorizable"),
        dictgen::InsensitiveStr::Ascii("heorizables"),
        dictgen::InsensitiveStr::Ascii("rammeled"),
        dictgen::InsensitiveStr::Ascii("rammeledder"),
        dictgen::InsensitiveStr::Ascii("rammeleddest"),
        dictgen::InsensitiveStr::Ascii("rammelled"),
        dictgen::InsensitiveStr::Ascii("rammelledder"),
        dictgen::InsensitiveStr::Ascii("rammelleddest"),
        dictgen::InsensitiveStr::Ascii("ranquilised"),
        dictgen::InsensitiveStr::Ascii("ranquilized"),
        dictgen::InsensitiveStr::Ascii("ranquillise"),
        dictgen::InsensitiveStr::Ascii("ranquillised"),
        dictgen::InsensitiveStr::Ascii("ranquillize"),
        dictgen::InsensitiveStr::Ascii("ranquillized"),
        dictgen::InsensitiveStr::Ascii("yrannised"),
        dictgen::InsensitiveStr::Ascii("yrannized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNTANTALIZED_17464672990124408329)],
        &[(0b10010, &ENTRY_UNTANTALIZEDDER_9017568026967264940)],
        &[(0b10010, &ENTRY_UNTANTALIZEDDEST_17151831953922163616)],
        &[(0b10010, &ENTRY_UNTANTALIZING_8959423826533397051)],
        &[(0b10010, &ENTRY_UNTANTALIZINGER_419332726477913928)],
        &[(0b10010, &ENTRY_UNTANTALIZINGEST_5960038359849071682)],
        &[(0b10010, &ENTRY_UNTANTALIZINGS_15651718507232611764)],
        &[(0b01001, &ENTRY_UNTANTALIZED_17464672990124408329)],
        &[(0b01001, &ENTRY_UNTANTALIZEDDER_9017568026967264940)],
        &[(0b01001, &ENTRY_UNTANTALIZEDDEST_17151831953922163616)],
        &[(0b01001, &ENTRY_UNTANTALIZING_8959423826533397051)],
        &[(0b01001, &ENTRY_UNTANTALIZINGER_419332726477913928)],
        &[(0b01001, &ENTRY_UNTANTALIZINGEST_5960038359849071682)],
        &[(0b01001, &ENTRY_UNTANTALIZINGS_15651718507232611764)],
        &[(0b10010, &ENTRY_UNTARTARIZED_3133720179395977215)],
        &[(0b10010, &ENTRY_UNTARTARIZEDS_8407791349105830225)],
        &[(0b01001, &ENTRY_UNTARTARIZED_3133720179395977215)],
        &[(0b01001, &ENTRY_UNTARTARIZEDS_8407791349105830225)],
        &[(0b10010, &ENTRY_UNTECHNICALIZE_13274966953497077306)],
        &[(0b10010, &ENTRY_UNTECHNICALIZES_3126412773353612904)],
        &[(0b01001, &ENTRY_UNTECHNICALIZE_13274966953497077306)],
        &[(0b01001, &ENTRY_UNTECHNICALIZES_3126412773353612904)],
        &[(0b10010, &ENTRY_UNTEMPORIZING_5353772823642385999)],
        &[(0b10010, &ENTRY_UNTEMPORIZINGS_2315283902611343260)],
        &[(0b01001, &ENTRY_UNTEMPORIZING_5353772823642385999)],
        &[(0b01001, &ENTRY_UNTEMPORIZINGS_2315283902611343260)],
        &[(0b10010, &ENTRY_UNTERRORIZED_4367682942057022296)],
        &[(0b01001, &ENTRY_UNTERRORIZED_4367682942057022296)],
        &[(0b10010, &ENTRY_UNTHEORIZABLE_2154526804700643766)],
        &[(0b10010, &ENTRY_UNTHEORIZABLES_16215355028071233497)],
        &[(0b01001, &ENTRY_UNTHEORIZABLE_2154526804700643766)],
        &[(0b01001, &ENTRY_UNTHEORIZABLES_16215355028071233497)],
        &[(0b00001, &ENTRY_UNTRAMMELED_10950501341680868626)],
        &[(0b00001, &ENTRY_UNTRAMMELEDDER_14704643385630931751)],
        &[(0b00001, &ENTRY_UNTRAMMELEDDEST_9165425453399950000)],
        &[(0b11010, &ENTRY_UNTRAMMELED_10950501341680868626)],
        &[(0b11010, &ENTRY_UNTRAMMELEDDER_14704643385630931751)],
        &[(0b11010, &ENTRY_UNTRAMMELEDDEST_9165425453399950000)],
        &[(0b10010, &ENTRY_UNTRANQUILIZED_6652837859667827274)],
        &[(0b01001, &ENTRY_UNTRANQUILIZED_6652837859667827274)],
        &[(0b10010, &ENTRY_UNTRANQUILLIZE_5773855129723549449)],
        &[(0b10010, &ENTRY_UNTRANQUILLIZED_11685243952236058416)],
        &[(0b01001, &ENTRY_UNTRANQUILLIZE_5773855129723549449)],
        &[(0b01001, &ENTRY_UNTRANQUILLIZED_11685243952236058416)],
        &[(0b10010, &ENTRY_UNTYRANNIZED_1381270595557515408)],
        &[(0b01001, &ENTRY_UNTYRANNIZED_1381270595557515408)],
    ],
    range: 8..=13,
};

static VARS_UNS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNS_CHILDREN),
    value: None,
};

static VARS_UNS_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNSA_NODE),
    None,
    Some(&VARS_UNSC_NODE),
    None,
    Some(&VARS_UNSE_NODE),
    None,
    None,
    Some(&VARS_UNSH_NODE),
    Some(&VARS_UNSI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNSO_NODE),
    Some(&VARS_UNSP_NODE),
    None,
    None,
    None,
    Some(&VARS_UNST_NODE),
    Some(&VARS_UNSU_NODE),
    None,
    None,
    None,
    Some(&VARS_UNSY_NODE),
    None,
];

static VARS_UNSY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNSY_CHILDREN),
    value: None,
};

static VARS_UNSY_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNSYM_NODE),
    Some(&VARS_UNSYN_NODE),
    None,
    Some(&VARS_UNSYP_NODE),
    None,
    None,
    Some(&VARS_UNSYS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNSYS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSYS_CHILDREN),
    value: None,
};

pub static VARS_UNSYS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tematised"),
        dictgen::InsensitiveStr::Ascii("tematisedder"),
        dictgen::InsensitiveStr::Ascii("tematiseddest"),
        dictgen::InsensitiveStr::Ascii("tematisedly"),
        dictgen::InsensitiveStr::Ascii("tematising"),
        dictgen::InsensitiveStr::Ascii("tematisinger"),
        dictgen::InsensitiveStr::Ascii("tematisingest"),
        dictgen::InsensitiveStr::Ascii("tematized"),
        dictgen::InsensitiveStr::Ascii("tematizedder"),
        dictgen::InsensitiveStr::Ascii("tematizeddest"),
        dictgen::InsensitiveStr::Ascii("tematizedly"),
        dictgen::InsensitiveStr::Ascii("tematizing"),
        dictgen::InsensitiveStr::Ascii("tematizinger"),
        dictgen::InsensitiveStr::Ascii("tematizingest"),
        dictgen::InsensitiveStr::Ascii("temisable"),
        dictgen::InsensitiveStr::Ascii("temisables"),
        dictgen::InsensitiveStr::Ascii("temizable"),
        dictgen::InsensitiveStr::Ascii("temizables"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSYSTEMATIZED_14693004019922481080)],
        &[(0b10010, &ENTRY_UNSYSTEMATIZEDDER_1302648680013691438)],
        &[(0b10010, &ENTRY_UNSYSTEMATIZEDDEST_13096641924022288041)],
        &[(0b10010, &ENTRY_UNSYSTEMATIZEDLY_10792111716627672784)],
        &[(0b10010, &ENTRY_UNSYSTEMATIZING_17458304099489437827)],
        &[(0b10010, &ENTRY_UNSYSTEMATIZINGER_16173262785830006988)],
        &[(0b10010, &ENTRY_UNSYSTEMATIZINGEST_7531122843621325837)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZED_14693004019922481080)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZEDDER_1302648680013691438)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZEDDEST_13096641924022288041)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZEDLY_10792111716627672784)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZING_17458304099489437827)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZINGER_16173262785830006988)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZINGEST_7531122843621325837)],
        &[(0b10010, &ENTRY_UNSYSTEMIZABLE_13398089433943014635)],
        &[(0b10010, &ENTRY_UNSYSTEMIZABLES_539302938187104170)],
        &[(0b01001, &ENTRY_UNSYSTEMIZABLE_13398089433943014635)],
        &[(0b01001, &ENTRY_UNSYSTEMIZABLES_539302938187104170)],
    ],
    range: 9..=13,
};

static VARS_UNSYP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSYP_CHILDREN),
    value: None,
};

pub static VARS_UNSYP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hon"),
        dictgen::InsensitiveStr::Ascii("hons"),
    ],
    values: &[
        &[(0b11010, &ENTRY_UNSIPHON_2201477182742736895)],
        &[(0b11010, &ENTRY_UNSIPHONS_11966284679782715486)],
    ],
    range: 3..=4,
};

static VARS_UNSYN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSYN_CHILDREN),
    value: None,
};

pub static VARS_UNSYN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chronised"),
        dictgen::InsensitiveStr::Ascii("chronisedder"),
        dictgen::InsensitiveStr::Ascii("chroniseddest"),
        dictgen::InsensitiveStr::Ascii("chronized"),
        dictgen::InsensitiveStr::Ascii("chronizedder"),
        dictgen::InsensitiveStr::Ascii("chronizeddest"),
        dictgen::InsensitiveStr::Ascii("thesised"),
        dictgen::InsensitiveStr::Ascii("thesisedder"),
        dictgen::InsensitiveStr::Ascii("thesiseddest"),
        dictgen::InsensitiveStr::Ascii("thesized"),
        dictgen::InsensitiveStr::Ascii("thesizedder"),
        dictgen::InsensitiveStr::Ascii("thesizeddest"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSYNCHRONIZED_12193751578059218406)],
        &[(0b10010, &ENTRY_UNSYNCHRONIZEDDER_14730878662606801638)],
        &[(0b10010, &ENTRY_UNSYNCHRONIZEDDEST_15177448949665547626)],
        &[(0b01001, &ENTRY_UNSYNCHRONIZED_12193751578059218406)],
        &[(0b01001, &ENTRY_UNSYNCHRONIZEDDER_14730878662606801638)],
        &[(0b01001, &ENTRY_UNSYNCHRONIZEDDEST_15177448949665547626)],
        &[(0b10010, &ENTRY_UNSYNTHESIZED_18216819107912450745)],
        &[(0b10010, &ENTRY_UNSYNTHESIZEDDER_479663997349491379)],
        &[(0b10010, &ENTRY_UNSYNTHESIZEDDEST_16230758731030483885)],
        &[(0b01001, &ENTRY_UNSYNTHESIZED_18216819107912450745)],
        &[(0b01001, &ENTRY_UNSYNTHESIZEDDER_479663997349491379)],
        &[(0b01001, &ENTRY_UNSYNTHESIZEDDEST_16230758731030483885)],
    ],
    range: 8..=13,
};

static VARS_UNSYM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSYM_CHILDREN),
    value: None,
};

pub static VARS_UNSYM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bolised"),
        dictgen::InsensitiveStr::Ascii("bolisedder"),
        dictgen::InsensitiveStr::Ascii("boliseddest"),
        dictgen::InsensitiveStr::Ascii("bolized"),
        dictgen::InsensitiveStr::Ascii("bolizedder"),
        dictgen::InsensitiveStr::Ascii("bolizeddest"),
        dictgen::InsensitiveStr::Ascii("metrised"),
        dictgen::InsensitiveStr::Ascii("metriseds"),
        dictgen::InsensitiveStr::Ascii("metrized"),
        dictgen::InsensitiveStr::Ascii("metrizeds"),
        dictgen::InsensitiveStr::Ascii("pathisabilities"),
        dictgen::InsensitiveStr::Ascii("pathisability"),
        dictgen::InsensitiveStr::Ascii("pathisable"),
        dictgen::InsensitiveStr::Ascii("pathisables"),
        dictgen::InsensitiveStr::Ascii("pathised"),
        dictgen::InsensitiveStr::Ascii("pathisedder"),
        dictgen::InsensitiveStr::Ascii("pathiseddest"),
        dictgen::InsensitiveStr::Ascii("pathising"),
        dictgen::InsensitiveStr::Ascii("pathisinger"),
        dictgen::InsensitiveStr::Ascii("pathisingest"),
        dictgen::InsensitiveStr::Ascii("pathisinglier"),
        dictgen::InsensitiveStr::Ascii("pathisingliest"),
        dictgen::InsensitiveStr::Ascii("pathisingly"),
        dictgen::InsensitiveStr::Ascii("pathisings"),
        dictgen::InsensitiveStr::Ascii("pathizabilities"),
        dictgen::InsensitiveStr::Ascii("pathizability"),
        dictgen::InsensitiveStr::Ascii("pathizable"),
        dictgen::InsensitiveStr::Ascii("pathizables"),
        dictgen::InsensitiveStr::Ascii("pathized"),
        dictgen::InsensitiveStr::Ascii("pathizedder"),
        dictgen::InsensitiveStr::Ascii("pathizeddest"),
        dictgen::InsensitiveStr::Ascii("pathizing"),
        dictgen::InsensitiveStr::Ascii("pathizinger"),
        dictgen::InsensitiveStr::Ascii("pathizingest"),
        dictgen::InsensitiveStr::Ascii("pathizinglier"),
        dictgen::InsensitiveStr::Ascii("pathizingliest"),
        dictgen::InsensitiveStr::Ascii("pathizingly"),
        dictgen::InsensitiveStr::Ascii("pathizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSYMBOLIZED_12442949087766027580)],
        &[(0b10010, &ENTRY_UNSYMBOLIZEDDER_5607794258564831297)],
        &[(0b10010, &ENTRY_UNSYMBOLIZEDDEST_5231089008393444113)],
        &[(0b01001, &ENTRY_UNSYMBOLIZED_12442949087766027580)],
        &[(0b01001, &ENTRY_UNSYMBOLIZEDDER_5607794258564831297)],
        &[(0b01001, &ENTRY_UNSYMBOLIZEDDEST_5231089008393444113)],
        &[(0b10010, &ENTRY_UNSYMMETRIZED_17823967768468208874)],
        &[(0b10010, &ENTRY_UNSYMMETRIZEDS_16967469102765366856)],
        &[(0b01001, &ENTRY_UNSYMMETRIZED_17823967768468208874)],
        &[(0b01001, &ENTRY_UNSYMMETRIZEDS_16967469102765366856)],
        &[(0b10010, &ENTRY_UNSYMPATHIZABILITIES_10871972451749839275)],
        &[(0b10010, &ENTRY_UNSYMPATHIZABILITY_8670082626189206465)],
        &[(0b10010, &ENTRY_UNSYMPATHIZABLE_1492652348373590024)],
        &[(0b10010, &ENTRY_UNSYMPATHIZABLES_17966199469317566401)],
        &[(0b10010, &ENTRY_UNSYMPATHIZED_11591186610900438376)],
        &[(0b10010, &ENTRY_UNSYMPATHIZEDDER_2799017229074261659)],
        &[(0b10010, &ENTRY_UNSYMPATHIZEDDEST_3121473820642946837)],
        &[(0b10010, &ENTRY_UNSYMPATHIZING_17910112294386472908)],
        &[(0b10010, &ENTRY_UNSYMPATHIZINGER_653153874121707552)],
        &[(0b10010, &ENTRY_UNSYMPATHIZINGEST_13140732246250859755)],
        &[(0b10010, &ENTRY_UNSYMPATHIZINGLIER_13699392946495371982)],
        &[(0b10010, &ENTRY_UNSYMPATHIZINGLIEST_1266776181731729210)],
        &[(0b10010, &ENTRY_UNSYMPATHIZINGLY_615018246483482543)],
        &[(0b10010, &ENTRY_UNSYMPATHIZINGS_12442450452539388270)],
        &[(0b01001, &ENTRY_UNSYMPATHIZABILITIES_10871972451749839275)],
        &[(0b01001, &ENTRY_UNSYMPATHIZABILITY_8670082626189206465)],
        &[(0b01001, &ENTRY_UNSYMPATHIZABLE_1492652348373590024)],
        &[(0b01001, &ENTRY_UNSYMPATHIZABLES_17966199469317566401)],
        &[(0b01001, &ENTRY_UNSYMPATHIZED_11591186610900438376)],
        &[(0b01001, &ENTRY_UNSYMPATHIZEDDER_2799017229074261659)],
        &[(0b01001, &ENTRY_UNSYMPATHIZEDDEST_3121473820642946837)],
        &[(0b01001, &ENTRY_UNSYMPATHIZING_17910112294386472908)],
        &[(0b01001, &ENTRY_UNSYMPATHIZINGER_653153874121707552)],
        &[(0b01001, &ENTRY_UNSYMPATHIZINGEST_13140732246250859755)],
        &[(0b01001, &ENTRY_UNSYMPATHIZINGLIER_13699392946495371982)],
        &[(0b01001, &ENTRY_UNSYMPATHIZINGLIEST_1266776181731729210)],
        &[(0b01001, &ENTRY_UNSYMPATHIZINGLY_615018246483482543)],
        &[(0b01001, &ENTRY_UNSYMPATHIZINGS_12442450452539388270)],
    ],
    range: 7..=15,
};

static VARS_UNSU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSU_CHILDREN),
    value: None,
};

pub static VARS_UNSU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bsidised"),
        dictgen::InsensitiveStr::Ascii("bsidized"),
        dictgen::InsensitiveStr::Ascii("bstantialise"),
        dictgen::InsensitiveStr::Ascii("bstantialised"),
        dictgen::InsensitiveStr::Ascii("bstantialises"),
        dictgen::InsensitiveStr::Ascii("bstantialising"),
        dictgen::InsensitiveStr::Ascii("bstantialize"),
        dictgen::InsensitiveStr::Ascii("bstantialized"),
        dictgen::InsensitiveStr::Ascii("bstantializes"),
        dictgen::InsensitiveStr::Ascii("bstantializing"),
        dictgen::InsensitiveStr::Ascii("ccorable"),
        dictgen::InsensitiveStr::Ascii("ccorables"),
        dictgen::InsensitiveStr::Ascii("ccored"),
        dictgen::InsensitiveStr::Ascii("ccourable"),
        dictgen::InsensitiveStr::Ascii("ccourables"),
        dictgen::InsensitiveStr::Ascii("ccoured"),
        dictgen::InsensitiveStr::Ascii("lphurised"),
        dictgen::InsensitiveStr::Ascii("lphuriseds"),
        dictgen::InsensitiveStr::Ascii("lphurized"),
        dictgen::InsensitiveStr::Ascii("lphurizeds"),
        dictgen::InsensitiveStr::Ascii("mmarisable"),
        dictgen::InsensitiveStr::Ascii("mmarised"),
        dictgen::InsensitiveStr::Ascii("mmarisedder"),
        dictgen::InsensitiveStr::Ascii("mmariseddest"),
        dictgen::InsensitiveStr::Ascii("mmarizable"),
        dictgen::InsensitiveStr::Ascii("mmarized"),
        dictgen::InsensitiveStr::Ascii("mmarizedder"),
        dictgen::InsensitiveStr::Ascii("mmarizeddest"),
        dictgen::InsensitiveStr::Ascii("pernaturalise"),
        dictgen::InsensitiveStr::Ascii("pernaturalised"),
        dictgen::InsensitiveStr::Ascii("pernaturalises"),
        dictgen::InsensitiveStr::Ascii("pernaturalize"),
        dictgen::InsensitiveStr::Ascii("pernaturalized"),
        dictgen::InsensitiveStr::Ascii("pernaturalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSUBSIDIZED_4767425605608650705)],
        &[(0b01001, &ENTRY_UNSUBSIDIZED_4767425605608650705)],
        &[(0b10010, &ENTRY_UNSUBSTANTIALIZE_7167575127151537643)],
        &[(0b10010, &ENTRY_UNSUBSTANTIALIZED_16840433461130643933)],
        &[(0b10010, &ENTRY_UNSUBSTANTIALIZES_16087693605789653784)],
        &[(0b10010, &ENTRY_UNSUBSTANTIALIZING_5715571309095915572)],
        &[(0b01001, &ENTRY_UNSUBSTANTIALIZE_7167575127151537643)],
        &[(0b01001, &ENTRY_UNSUBSTANTIALIZED_16840433461130643933)],
        &[(0b01001, &ENTRY_UNSUBSTANTIALIZES_16087693605789653784)],
        &[(0b01001, &ENTRY_UNSUBSTANTIALIZING_5715571309095915572)],
        &[(0b00001, &ENTRY_UNSUCCORABLE_14166115535199719478)],
        &[(0b00001, &ENTRY_UNSUCCORABLES_7445917141274035146)],
        &[(0b00001, &ENTRY_UNSUCCORED_8876180192974098027)],
        &[(0b11010, &ENTRY_UNSUCCORABLE_14166115535199719478)],
        &[(0b11010, &ENTRY_UNSUCCORABLES_7445917141274035146)],
        &[(0b11010, &ENTRY_UNSUCCORED_8876180192974098027)],
        &[(0b10010, &ENTRY_UNSULPHURIZED_17918992173910340976)],
        &[(0b10010, &ENTRY_UNSULPHURIZEDS_12878019452075350923)],
        &[(0b01001, &ENTRY_UNSULPHURIZED_17918992173910340976)],
        &[(0b01001, &ENTRY_UNSULPHURIZEDS_12878019452075350923)],
        &[(0b10010, &ENTRY_UNSUMMARIZABLE_12043279703030794088)],
        &[(0b10010, &ENTRY_UNSUMMARIZED_12298858164299539938)],
        &[(0b10010, &ENTRY_UNSUMMARIZEDDER_1909102770740554249)],
        &[(0b10010, &ENTRY_UNSUMMARIZEDDEST_11938489051378385243)],
        &[(0b01001, &ENTRY_UNSUMMARIZABLE_12043279703030794088)],
        &[(0b01001, &ENTRY_UNSUMMARIZED_12298858164299539938)],
        &[(0b01001, &ENTRY_UNSUMMARIZEDDER_1909102770740554249)],
        &[(0b01001, &ENTRY_UNSUMMARIZEDDEST_11938489051378385243)],
        &[(0b10010, &ENTRY_UNSUPERNATURALIZE_10992801829063966196)],
        &[(0b10010, &ENTRY_UNSUPERNATURALIZED_138394761197753453)],
        &[(0b10010, &ENTRY_UNSUPERNATURALIZES_10254282064098281782)],
        &[(0b01001, &ENTRY_UNSUPERNATURALIZE_10992801829063966196)],
        &[(0b01001, &ENTRY_UNSUPERNATURALIZED_138394761197753453)],
        &[(0b01001, &ENTRY_UNSUPERNATURALIZES_10254282064098281782)],
    ],
    range: 6..=14,
};

static VARS_UNST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNST_CHILDREN),
    value: None,
};

pub static VARS_UNST_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abilised"),
        dictgen::InsensitiveStr::Ascii("abilising"),
        dictgen::InsensitiveStr::Ascii("abilized"),
        dictgen::InsensitiveStr::Ascii("abilizing"),
        dictgen::InsensitiveStr::Ascii("andardisable"),
        dictgen::InsensitiveStr::Ascii("andardised"),
        dictgen::InsensitiveStr::Ascii("andardisedder"),
        dictgen::InsensitiveStr::Ascii("andardiseddest"),
        dictgen::InsensitiveStr::Ascii("andardizable"),
        dictgen::InsensitiveStr::Ascii("andardized"),
        dictgen::InsensitiveStr::Ascii("andardizedder"),
        dictgen::InsensitiveStr::Ascii("andardizeddest"),
        dictgen::InsensitiveStr::Ascii("erilised"),
        dictgen::InsensitiveStr::Ascii("erilized"),
        dictgen::InsensitiveStr::Ascii("igmatised"),
        dictgen::InsensitiveStr::Ascii("igmatisedder"),
        dictgen::InsensitiveStr::Ascii("igmatiseddest"),
        dictgen::InsensitiveStr::Ascii("igmatiseds"),
        dictgen::InsensitiveStr::Ascii("igmatized"),
        dictgen::InsensitiveStr::Ascii("igmatizedder"),
        dictgen::InsensitiveStr::Ascii("igmatizeddest"),
        dictgen::InsensitiveStr::Ascii("igmatizeds"),
        dictgen::InsensitiveStr::Ascii("oicise"),
        dictgen::InsensitiveStr::Ascii("oicises"),
        dictgen::InsensitiveStr::Ascii("oicize"),
        dictgen::InsensitiveStr::Ascii("oicizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSTABILIZED_12732354267194876239)],
        &[(0b10010, &ENTRY_UNSTABILIZING_7613851599613717731)],
        &[(0b01001, &ENTRY_UNSTABILIZED_12732354267194876239)],
        &[(0b01001, &ENTRY_UNSTABILIZING_7613851599613717731)],
        &[(0b10010, &ENTRY_UNSTANDARDIZABLE_3270324052895078989)],
        &[(0b10010, &ENTRY_UNSTANDARDIZED_12491554302043952151)],
        &[(0b10010, &ENTRY_UNSTANDARDIZEDDER_6565607621393721916)],
        &[(0b10010, &ENTRY_UNSTANDARDIZEDDEST_4054711965309446578)],
        &[(0b01001, &ENTRY_UNSTANDARDIZABLE_3270324052895078989)],
        &[(0b01001, &ENTRY_UNSTANDARDIZED_12491554302043952151)],
        &[(0b01001, &ENTRY_UNSTANDARDIZEDDER_6565607621393721916)],
        &[(0b01001, &ENTRY_UNSTANDARDIZEDDEST_4054711965309446578)],
        &[(0b10010, &ENTRY_UNSTERILIZED_10084050054715413010)],
        &[(0b01001, &ENTRY_UNSTERILIZED_10084050054715413010)],
        &[(0b10010, &ENTRY_UNSTIGMATIZED_9617189081690540365)],
        &[(0b10010, &ENTRY_UNSTIGMATIZEDDER_1556903362413866083)],
        &[(0b10010, &ENTRY_UNSTIGMATIZEDDEST_3672863394691019431)],
        &[(0b10010, &ENTRY_UNSTIGMATIZEDS_2110294383752462220)],
        &[(0b01001, &ENTRY_UNSTIGMATIZED_9617189081690540365)],
        &[(0b01001, &ENTRY_UNSTIGMATIZEDDER_1556903362413866083)],
        &[(0b01001, &ENTRY_UNSTIGMATIZEDDEST_3672863394691019431)],
        &[(0b01001, &ENTRY_UNSTIGMATIZEDS_2110294383752462220)],
        &[(0b10010, &ENTRY_UNSTOICIZE_5593462469547952299)],
        &[(0b10010, &ENTRY_UNSTOICIZES_5409151828444702636)],
        &[(0b01001, &ENTRY_UNSTOICIZE_5593462469547952299)],
        &[(0b01001, &ENTRY_UNSTOICIZES_5409151828444702636)],
    ],
    range: 6..=14,
};

static VARS_UNSP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSP_CHILDREN),
    value: None,
};

pub static VARS_UNSP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecialised"),
        dictgen::InsensitiveStr::Ascii("ecialisedder"),
        dictgen::InsensitiveStr::Ascii("ecialiseddest"),
        dictgen::InsensitiveStr::Ascii("ecialising"),
        dictgen::InsensitiveStr::Ascii("ecialisinger"),
        dictgen::InsensitiveStr::Ascii("ecialisingest"),
        dictgen::InsensitiveStr::Ascii("ecialized"),
        dictgen::InsensitiveStr::Ascii("ecializedder"),
        dictgen::InsensitiveStr::Ascii("ecializeddest"),
        dictgen::InsensitiveStr::Ascii("ecializing"),
        dictgen::InsensitiveStr::Ascii("ecializinger"),
        dictgen::InsensitiveStr::Ascii("ecializingest"),
        dictgen::InsensitiveStr::Ascii("ecterlike"),
        dictgen::InsensitiveStr::Ascii("ecterlikes"),
        dictgen::InsensitiveStr::Ascii("ectrelike"),
        dictgen::InsensitiveStr::Ascii("ectrelikes"),
        dictgen::InsensitiveStr::Ascii("iritualise"),
        dictgen::InsensitiveStr::Ascii("iritualised"),
        dictgen::InsensitiveStr::Ascii("iritualises"),
        dictgen::InsensitiveStr::Ascii("iritualising"),
        dictgen::InsensitiveStr::Ascii("iritualize"),
        dictgen::InsensitiveStr::Ascii("iritualized"),
        dictgen::InsensitiveStr::Ascii("iritualizes"),
        dictgen::InsensitiveStr::Ascii("iritualizing"),
        dictgen::InsensitiveStr::Ascii("lendorous"),
        dictgen::InsensitiveStr::Ascii("lendorously"),
        dictgen::InsensitiveStr::Ascii("lendourous"),
        dictgen::InsensitiveStr::Ascii("lendourously"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSPECIALIZED_5465071604094517809)],
        &[(0b10010, &ENTRY_UNSPECIALIZEDDER_9071034409026977091)],
        &[(0b10010, &ENTRY_UNSPECIALIZEDDEST_8581399916465856628)],
        &[(0b10010, &ENTRY_UNSPECIALIZING_9421997668487501018)],
        &[(0b10010, &ENTRY_UNSPECIALIZINGER_16940094743315712229)],
        &[(0b10010, &ENTRY_UNSPECIALIZINGEST_18418227812211404765)],
        &[(0b01001, &ENTRY_UNSPECIALIZED_5465071604094517809)],
        &[(0b01001, &ENTRY_UNSPECIALIZEDDER_9071034409026977091)],
        &[(0b01001, &ENTRY_UNSPECIALIZEDDEST_8581399916465856628)],
        &[(0b01001, &ENTRY_UNSPECIALIZING_9421997668487501018)],
        &[(0b01001, &ENTRY_UNSPECIALIZINGER_16940094743315712229)],
        &[(0b01001, &ENTRY_UNSPECIALIZINGEST_18418227812211404765)],
        &[(0b00001, &ENTRY_UNSPECTERLIKE_2141876370934724325)],
        &[(0b00001, &ENTRY_UNSPECTERLIKES_7509114770076619624)],
        &[(0b11010, &ENTRY_UNSPECTERLIKE_2141876370934724325)],
        &[(0b11010, &ENTRY_UNSPECTERLIKES_7509114770076619624)],
        &[(0b10010, &ENTRY_UNSPIRITUALIZE_372925422412985909)],
        &[(0b10010, &ENTRY_UNSPIRITUALIZED_1702102857886189847)],
        &[(0b10010, &ENTRY_UNSPIRITUALIZES_6758197377913290909)],
        &[(0b10010, &ENTRY_UNSPIRITUALIZING_9667822503310703185)],
        &[(0b01001, &ENTRY_UNSPIRITUALIZE_372925422412985909)],
        &[(0b01001, &ENTRY_UNSPIRITUALIZED_1702102857886189847)],
        &[(0b01001, &ENTRY_UNSPIRITUALIZES_6758197377913290909)],
        &[(0b01001, &ENTRY_UNSPIRITUALIZING_9667822503310703185)],
        &[(0b00001, &ENTRY_UNSPLENDOROUS_8544602661563641204)],
        &[(0b00001, &ENTRY_UNSPLENDOROUSLY_4500859628733032967)],
        &[(0b11010, &ENTRY_UNSPLENDOROUS_8544602661563641204)],
        &[(0b11010, &ENTRY_UNSPLENDOROUSLY_4500859628733032967)],
    ],
    range: 9..=13,
};

static VARS_UNSO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSO_CHILDREN),
    value: None,
};

pub static VARS_UNSO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cialised"),
        dictgen::InsensitiveStr::Ascii("cialisedder"),
        dictgen::InsensitiveStr::Ascii("cialiseddest"),
        dictgen::InsensitiveStr::Ascii("cialising"),
        dictgen::InsensitiveStr::Ascii("cialized"),
        dictgen::InsensitiveStr::Ascii("cializedder"),
        dictgen::InsensitiveStr::Ascii("cializeddest"),
        dictgen::InsensitiveStr::Ascii("cializing"),
        dictgen::InsensitiveStr::Ascii("lemnise"),
        dictgen::InsensitiveStr::Ascii("lemnised"),
        dictgen::InsensitiveStr::Ascii("lemnisedder"),
        dictgen::InsensitiveStr::Ascii("lemniseddest"),
        dictgen::InsensitiveStr::Ascii("lemnises"),
        dictgen::InsensitiveStr::Ascii("lemnize"),
        dictgen::InsensitiveStr::Ascii("lemnized"),
        dictgen::InsensitiveStr::Ascii("lemnizedder"),
        dictgen::InsensitiveStr::Ascii("lemnizeddest"),
        dictgen::InsensitiveStr::Ascii("lemnizes"),
        dictgen::InsensitiveStr::Ascii("mber"),
        dictgen::InsensitiveStr::Ascii("mberly"),
        dictgen::InsensitiveStr::Ascii("mberness"),
        dictgen::InsensitiveStr::Ascii("mbre"),
        dictgen::InsensitiveStr::Ascii("mbrely"),
        dictgen::InsensitiveStr::Ascii("mbreness"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSOCIALIZED_14989628692775218168)],
        &[(0b10010, &ENTRY_UNSOCIALIZEDDER_856229867973138497)],
        &[(0b10010, &ENTRY_UNSOCIALIZEDDEST_8753817887210581029)],
        &[(0b10010, &ENTRY_UNSOCIALIZING_4910985306707895534)],
        &[(0b01001, &ENTRY_UNSOCIALIZED_14989628692775218168)],
        &[(0b01001, &ENTRY_UNSOCIALIZEDDER_856229867973138497)],
        &[(0b01001, &ENTRY_UNSOCIALIZEDDEST_8753817887210581029)],
        &[(0b01001, &ENTRY_UNSOCIALIZING_4910985306707895534)],
        &[(0b10010, &ENTRY_UNSOLEMNIZE_11168537395109875287)],
        &[(0b10010, &ENTRY_UNSOLEMNIZED_16387242389688387024)],
        &[(0b10010, &ENTRY_UNSOLEMNIZEDDER_11258782760404945860)],
        &[(0b10010, &ENTRY_UNSOLEMNIZEDDEST_12652695066155929748)],
        &[(0b10010, &ENTRY_UNSOLEMNIZES_16920004258925216679)],
        &[(0b01001, &ENTRY_UNSOLEMNIZE_11168537395109875287)],
        &[(0b01001, &ENTRY_UNSOLEMNIZED_16387242389688387024)],
        &[(0b01001, &ENTRY_UNSOLEMNIZEDDER_11258782760404945860)],
        &[(0b01001, &ENTRY_UNSOLEMNIZEDDEST_12652695066155929748)],
        &[(0b01001, &ENTRY_UNSOLEMNIZES_16920004258925216679)],
        &[(0b00001, &ENTRY_UNSOMBER_5660053662769742895)],
        &[(0b00001, &ENTRY_UNSOMBERLY_15086202074328462192)],
        &[(0b00001, &ENTRY_UNSOMBERNESS_5216333562398296695)],
        &[(0b11010, &ENTRY_UNSOMBER_5660053662769742895)],
        &[(0b11010, &ENTRY_UNSOMBERLY_15086202074328462192)],
        &[(0b11010, &ENTRY_UNSOMBERNESS_5216333562398296695)],
    ],
    range: 4..=12,
};

static VARS_UNSI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSI_CHILDREN),
    value: None,
};

pub static VARS_UNSI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gnalised"),
        dictgen::InsensitiveStr::Ascii("gnalisedder"),
        dictgen::InsensitiveStr::Ascii("gnaliseddest"),
        dictgen::InsensitiveStr::Ascii("gnaliseds"),
        dictgen::InsensitiveStr::Ascii("gnalized"),
        dictgen::InsensitiveStr::Ascii("gnalizedder"),
        dictgen::InsensitiveStr::Ascii("gnalizeddest"),
        dictgen::InsensitiveStr::Ascii("gnalizeds"),
        dictgen::InsensitiveStr::Ascii("phon"),
        dictgen::InsensitiveStr::Ascii("phons"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSIGNALIZED_14483193965409880939)],
        &[(0b10010, &ENTRY_UNSIGNALIZEDDER_705937437443397616)],
        &[(0b10010, &ENTRY_UNSIGNALIZEDDEST_14660298846752223251)],
        &[(0b10010, &ENTRY_UNSIGNALIZEDS_4457009391245218633)],
        &[(0b01001, &ENTRY_UNSIGNALIZED_14483193965409880939)],
        &[(0b01001, &ENTRY_UNSIGNALIZEDDER_705937437443397616)],
        &[(0b01001, &ENTRY_UNSIGNALIZEDDEST_14660298846752223251)],
        &[(0b01001, &ENTRY_UNSIGNALIZEDS_4457009391245218633)],
        &[(0b00001, &ENTRY_UNSIPHON_2201477182742736895)],
        &[(0b00001, &ENTRY_UNSIPHONS_11966284679782715486)],
    ],
    range: 4..=12,
};

static VARS_UNSH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSH_CHILDREN),
    value: None,
};

pub static VARS_UNSH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("oed"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNSHED_5262139668880542294)],
        &[(0b11010, &ENTRY_UNSHED_5262139668880542294)],
    ],
    range: 2..=3,
};

static VARS_UNSE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSE_CHILDREN),
    value: None,
};

pub static VARS_UNSE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ctarianise"),
        dictgen::InsensitiveStr::Ascii("ctarianises"),
        dictgen::InsensitiveStr::Ascii("ctarianize"),
        dictgen::InsensitiveStr::Ascii("ctarianizes"),
        dictgen::InsensitiveStr::Ascii("ctionalised"),
        dictgen::InsensitiveStr::Ascii("ctionalized"),
        dictgen::InsensitiveStr::Ascii("cularise"),
        dictgen::InsensitiveStr::Ascii("cularised"),
        dictgen::InsensitiveStr::Ascii("cularisedder"),
        dictgen::InsensitiveStr::Ascii("culariseddest"),
        dictgen::InsensitiveStr::Ascii("cularises"),
        dictgen::InsensitiveStr::Ascii("cularize"),
        dictgen::InsensitiveStr::Ascii("cularized"),
        dictgen::InsensitiveStr::Ascii("cularizedder"),
        dictgen::InsensitiveStr::Ascii("cularizeddest"),
        dictgen::InsensitiveStr::Ascii("cularizes"),
        dictgen::InsensitiveStr::Ascii("nsitise"),
        dictgen::InsensitiveStr::Ascii("nsitised"),
        dictgen::InsensitiveStr::Ascii("nsitises"),
        dictgen::InsensitiveStr::Ascii("nsitising"),
        dictgen::InsensitiveStr::Ascii("nsitize"),
        dictgen::InsensitiveStr::Ascii("nsitized"),
        dictgen::InsensitiveStr::Ascii("nsitizes"),
        dictgen::InsensitiveStr::Ascii("nsitizing"),
        dictgen::InsensitiveStr::Ascii("nsualise"),
        dictgen::InsensitiveStr::Ascii("nsualised"),
        dictgen::InsensitiveStr::Ascii("nsualises"),
        dictgen::InsensitiveStr::Ascii("nsualising"),
        dictgen::InsensitiveStr::Ascii("nsualize"),
        dictgen::InsensitiveStr::Ascii("nsualized"),
        dictgen::InsensitiveStr::Ascii("nsualizes"),
        dictgen::InsensitiveStr::Ascii("nsualizing"),
        dictgen::InsensitiveStr::Ascii("ntimentalise"),
        dictgen::InsensitiveStr::Ascii("ntimentalised"),
        dictgen::InsensitiveStr::Ascii("ntimentalises"),
        dictgen::InsensitiveStr::Ascii("ntimentalize"),
        dictgen::InsensitiveStr::Ascii("ntimentalized"),
        dictgen::InsensitiveStr::Ascii("ntimentalizes"),
        dictgen::InsensitiveStr::Ascii("pulcher"),
        dictgen::InsensitiveStr::Ascii("pulchered"),
        dictgen::InsensitiveStr::Ascii("pulchers"),
        dictgen::InsensitiveStr::Ascii("pulchre"),
        dictgen::InsensitiveStr::Ascii("pulchred"),
        dictgen::InsensitiveStr::Ascii("pulchres"),
        dictgen::InsensitiveStr::Ascii("rialised"),
        dictgen::InsensitiveStr::Ascii("rialized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSECTARIANIZE_7363850891406916279)],
        &[(0b10010, &ENTRY_UNSECTARIANIZES_18248497066495696520)],
        &[(0b01001, &ENTRY_UNSECTARIANIZE_7363850891406916279)],
        &[(0b01001, &ENTRY_UNSECTARIANIZES_18248497066495696520)],
        &[(0b10010, &ENTRY_UNSECTIONALIZED_14160946284121325933)],
        &[(0b01001, &ENTRY_UNSECTIONALIZED_14160946284121325933)],
        &[(0b10010, &ENTRY_UNSECULARIZE_14132148258894262887)],
        &[(0b10010, &ENTRY_UNSECULARIZED_14199565598148621175)],
        &[(0b10010, &ENTRY_UNSECULARIZEDDER_2842961345958441791)],
        &[(0b10010, &ENTRY_UNSECULARIZEDDEST_12149248990561677937)],
        &[(0b10010, &ENTRY_UNSECULARIZES_13447532511726190479)],
        &[(0b01001, &ENTRY_UNSECULARIZE_14132148258894262887)],
        &[(0b01001, &ENTRY_UNSECULARIZED_14199565598148621175)],
        &[(0b01001, &ENTRY_UNSECULARIZEDDER_2842961345958441791)],
        &[(0b01001, &ENTRY_UNSECULARIZEDDEST_12149248990561677937)],
        &[(0b01001, &ENTRY_UNSECULARIZES_13447532511726190479)],
        &[(0b10010, &ENTRY_UNSENSITIZE_7473555488224076656)],
        &[(0b10010, &ENTRY_UNSENSITIZED_1745594334360308084)],
        &[(0b10010, &ENTRY_UNSENSITIZES_13345318411364622184)],
        &[(0b10010, &ENTRY_UNSENSITIZING_13954263948551463374)],
        &[(0b01001, &ENTRY_UNSENSITIZE_7473555488224076656)],
        &[(0b01001, &ENTRY_UNSENSITIZED_1745594334360308084)],
        &[(0b01001, &ENTRY_UNSENSITIZES_13345318411364622184)],
        &[(0b01001, &ENTRY_UNSENSITIZING_13954263948551463374)],
        &[(0b10010, &ENTRY_UNSENSUALIZE_3872317908881106198)],
        &[(0b10010, &ENTRY_UNSENSUALIZED_1487257633805307913)],
        &[(0b10010, &ENTRY_UNSENSUALIZES_7920151341600586361)],
        &[(0b10010, &ENTRY_UNSENSUALIZING_17972016725852543610)],
        &[(0b01001, &ENTRY_UNSENSUALIZE_3872317908881106198)],
        &[(0b01001, &ENTRY_UNSENSUALIZED_1487257633805307913)],
        &[(0b01001, &ENTRY_UNSENSUALIZES_7920151341600586361)],
        &[(0b01001, &ENTRY_UNSENSUALIZING_17972016725852543610)],
        &[(0b10010, &ENTRY_UNSENTIMENTALIZE_15546981073227478616)],
        &[(0b10010, &ENTRY_UNSENTIMENTALIZED_10901313714433298415)],
        &[(0b10010, &ENTRY_UNSENTIMENTALIZES_12335131210195268447)],
        &[(0b01001, &ENTRY_UNSENTIMENTALIZE_15546981073227478616)],
        &[(0b01001, &ENTRY_UNSENTIMENTALIZED_10901313714433298415)],
        &[(0b01001, &ENTRY_UNSENTIMENTALIZES_12335131210195268447)],
        &[(0b00001, &ENTRY_UNSEPULCHER_2014873108753613465)],
        &[(0b00001, &ENTRY_UNSEPULCHERED_8119587175553677223)],
        &[(0b00001, &ENTRY_UNSEPULCHERS_8204420699755543106)],
        &[(0b11010, &ENTRY_UNSEPULCHER_2014873108753613465)],
        &[(0b11010, &ENTRY_UNSEPULCHERED_8119587175553677223)],
        &[(0b11010, &ENTRY_UNSEPULCHERS_8204420699755543106)],
        &[(0b10010, &ENTRY_UNSERIALIZED_659557943907801624)],
        &[(0b01001, &ENTRY_UNSERIALIZED_659557943907801624)],
    ],
    range: 7..=13,
};

static VARS_UNSC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSC_CHILDREN),
    value: None,
};

pub static VARS_UNSC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("andalise"),
        dictgen::InsensitiveStr::Ascii("andalised"),
        dictgen::InsensitiveStr::Ascii("andalisedder"),
        dictgen::InsensitiveStr::Ascii("andaliseddest"),
        dictgen::InsensitiveStr::Ascii("andalises"),
        dictgen::InsensitiveStr::Ascii("andalize"),
        dictgen::InsensitiveStr::Ascii("andalized"),
        dictgen::InsensitiveStr::Ascii("andalizedder"),
        dictgen::InsensitiveStr::Ascii("andalizeddest"),
        dictgen::InsensitiveStr::Ascii("andalizes"),
        dictgen::InsensitiveStr::Ascii("epter"),
        dictgen::InsensitiveStr::Ascii("eptered"),
        dictgen::InsensitiveStr::Ascii("epteredder"),
        dictgen::InsensitiveStr::Ascii("eptereddest"),
        dictgen::InsensitiveStr::Ascii("epters"),
        dictgen::InsensitiveStr::Ascii("eptre"),
        dictgen::InsensitiveStr::Ascii("eptred"),
        dictgen::InsensitiveStr::Ascii("eptredder"),
        dictgen::InsensitiveStr::Ascii("eptreddest"),
        dictgen::InsensitiveStr::Ascii("eptres"),
        dictgen::InsensitiveStr::Ascii("hematised"),
        dictgen::InsensitiveStr::Ascii("hematisedder"),
        dictgen::InsensitiveStr::Ascii("hematiseddest"),
        dictgen::InsensitiveStr::Ascii("hematiseds"),
        dictgen::InsensitiveStr::Ascii("hematized"),
        dictgen::InsensitiveStr::Ascii("hematizedder"),
        dictgen::InsensitiveStr::Ascii("hematizeddest"),
        dictgen::InsensitiveStr::Ascii("hematizeds"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("rutinised"),
        dictgen::InsensitiveStr::Ascii("rutinisedder"),
        dictgen::InsensitiveStr::Ascii("rutiniseddest"),
        dictgen::InsensitiveStr::Ascii("rutinising"),
        dictgen::InsensitiveStr::Ascii("rutinisinger"),
        dictgen::InsensitiveStr::Ascii("rutinisingest"),
        dictgen::InsensitiveStr::Ascii("rutinisinglier"),
        dictgen::InsensitiveStr::Ascii("rutinisingliest"),
        dictgen::InsensitiveStr::Ascii("rutinisingly"),
        dictgen::InsensitiveStr::Ascii("rutinized"),
        dictgen::InsensitiveStr::Ascii("rutinizedder"),
        dictgen::InsensitiveStr::Ascii("rutinizeddest"),
        dictgen::InsensitiveStr::Ascii("rutinizing"),
        dictgen::InsensitiveStr::Ascii("rutinizinger"),
        dictgen::InsensitiveStr::Ascii("rutinizingest"),
        dictgen::InsensitiveStr::Ascii("rutinizinglier"),
        dictgen::InsensitiveStr::Ascii("rutinizingliest"),
        dictgen::InsensitiveStr::Ascii("rutinizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSCANDALIZE_16053982694142286033)],
        &[(0b10010, &ENTRY_UNSCANDALIZED_13546507575715226266)],
        &[(0b10010, &ENTRY_UNSCANDALIZEDDER_18111310313303038296)],
        &[(0b10010, &ENTRY_UNSCANDALIZEDDEST_16242039314569406272)],
        &[(0b10010, &ENTRY_UNSCANDALIZES_2398862153730255258)],
        &[(0b01001, &ENTRY_UNSCANDALIZE_16053982694142286033)],
        &[(0b01001, &ENTRY_UNSCANDALIZED_13546507575715226266)],
        &[(0b01001, &ENTRY_UNSCANDALIZEDDER_18111310313303038296)],
        &[(0b01001, &ENTRY_UNSCANDALIZEDDEST_16242039314569406272)],
        &[(0b01001, &ENTRY_UNSCANDALIZES_2398862153730255258)],
        &[(0b00001, &ENTRY_UNSCEPTER_4166508186468970951)],
        &[(0b00001, &ENTRY_UNSCEPTERED_15452211318470868971)],
        &[(0b00001, &ENTRY_UNSCEPTEREDDER_12181291417107771822)],
        &[(0b00001, &ENTRY_UNSCEPTEREDDEST_17540039512158448742)],
        &[(0b00001, &ENTRY_UNSCEPTERS_12034158920508538724)],
        &[(0b11010, &ENTRY_UNSCEPTER_4166508186468970951)],
        &[(0b11010, &ENTRY_UNSCEPTERED_15452211318470868971)],
        &[(0b11010, &ENTRY_UNSCEPTEREDDER_12181291417107771822)],
        &[(0b11010, &ENTRY_UNSCEPTEREDDEST_17540039512158448742)],
        &[(0b11010, &ENTRY_UNSCEPTERS_12034158920508538724)],
        &[(0b10010, &ENTRY_UNSCHEMATIZED_10049986821140403897)],
        &[(0b10010, &ENTRY_UNSCHEMATIZEDDER_14428713257920703614)],
        &[(0b10010, &ENTRY_UNSCHEMATIZEDDEST_18287776028283084494)],
        &[(0b10010, &ENTRY_UNSCHEMATIZEDS_6728956752645304288)],
        &[(0b01001, &ENTRY_UNSCHEMATIZED_10049986821140403897)],
        &[(0b01001, &ENTRY_UNSCHEMATIZEDDER_14428713257920703614)],
        &[(0b01001, &ENTRY_UNSCHEMATIZEDDEST_18287776028283084494)],
        &[(0b01001, &ENTRY_UNSCHEMATIZEDS_6728956752645304288)],
        &[(0b00001, &ENTRY_UNSCORED_47447901486425280)],
        &[(0b00001, &ENTRY_UNSCORING_1751337690368155193)],
        &[(0b11010, &ENTRY_UNSCORED_47447901486425280)],
        &[(0b11010, &ENTRY_UNSCORING_1751337690368155193)],
        &[(0b10010, &ENTRY_UNSCRUTINIZED_11149142688617945574)],
        &[(0b10010, &ENTRY_UNSCRUTINIZEDDER_6435886601825655981)],
        &[(0b10010, &ENTRY_UNSCRUTINIZEDDEST_12242353205786815739)],
        &[(0b10010, &ENTRY_UNSCRUTINIZING_4062568311194108442)],
        &[(0b10010, &ENTRY_UNSCRUTINIZINGER_5676669904103635154)],
        &[(0b10010, &ENTRY_UNSCRUTINIZINGEST_18196137909826699146)],
        &[(0b10010, &ENTRY_UNSCRUTINIZINGLIER_3953405087476382875)],
        &[(0b10010, &ENTRY_UNSCRUTINIZINGLIEST_15514859191792249061)],
        &[(0b10010, &ENTRY_UNSCRUTINIZINGLY_10127047352540752813)],
        &[(0b01001, &ENTRY_UNSCRUTINIZED_11149142688617945574)],
        &[(0b01001, &ENTRY_UNSCRUTINIZEDDER_6435886601825655981)],
        &[(0b01001, &ENTRY_UNSCRUTINIZEDDEST_12242353205786815739)],
        &[(0b01001, &ENTRY_UNSCRUTINIZING_4062568311194108442)],
        &[(0b01001, &ENTRY_UNSCRUTINIZINGER_5676669904103635154)],
        &[(0b01001, &ENTRY_UNSCRUTINIZINGEST_18196137909826699146)],
        &[(0b01001, &ENTRY_UNSCRUTINIZINGLIER_3953405087476382875)],
        &[(0b01001, &ENTRY_UNSCRUTINIZINGLIEST_15514859191792249061)],
        &[(0b01001, &ENTRY_UNSCRUTINIZINGLY_10127047352540752813)],
    ],
    range: 4..=15,
};

static VARS_UNSA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSA_CHILDREN),
    value: None,
};

pub static VARS_UNSA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bered"),
        dictgen::InsensitiveStr::Ascii("beredder"),
        dictgen::InsensitiveStr::Ascii("bereddest"),
        dictgen::InsensitiveStr::Ascii("bred"),
        dictgen::InsensitiveStr::Ascii("bredder"),
        dictgen::InsensitiveStr::Ascii("breddest"),
        dictgen::InsensitiveStr::Ascii("tirisable"),
        dictgen::InsensitiveStr::Ascii("tirise"),
        dictgen::InsensitiveStr::Ascii("tirised"),
        dictgen::InsensitiveStr::Ascii("tirisedder"),
        dictgen::InsensitiveStr::Ascii("tiriseddest"),
        dictgen::InsensitiveStr::Ascii("tirises"),
        dictgen::InsensitiveStr::Ascii("tirizable"),
        dictgen::InsensitiveStr::Ascii("tirize"),
        dictgen::InsensitiveStr::Ascii("tirized"),
        dictgen::InsensitiveStr::Ascii("tirizedder"),
        dictgen::InsensitiveStr::Ascii("tirizeddest"),
        dictgen::InsensitiveStr::Ascii("tirizes"),
        dictgen::InsensitiveStr::Ascii("vored"),
        dictgen::InsensitiveStr::Ascii("voredder"),
        dictgen::InsensitiveStr::Ascii("voreddest"),
        dictgen::InsensitiveStr::Ascii("voredly"),
        dictgen::InsensitiveStr::Ascii("voredness"),
        dictgen::InsensitiveStr::Ascii("vorier"),
        dictgen::InsensitiveStr::Ascii("vories"),
        dictgen::InsensitiveStr::Ascii("voriest"),
        dictgen::InsensitiveStr::Ascii("vorilier"),
        dictgen::InsensitiveStr::Ascii("vorilies"),
        dictgen::InsensitiveStr::Ascii("voriliest"),
        dictgen::InsensitiveStr::Ascii("vorily"),
        dictgen::InsensitiveStr::Ascii("voriness"),
        dictgen::InsensitiveStr::Ascii("vorinesses"),
        dictgen::InsensitiveStr::Ascii("vory"),
        dictgen::InsensitiveStr::Ascii("voured"),
        dictgen::InsensitiveStr::Ascii("vouredder"),
        dictgen::InsensitiveStr::Ascii("voureddest"),
        dictgen::InsensitiveStr::Ascii("vouredly"),
        dictgen::InsensitiveStr::Ascii("vouredness"),
        dictgen::InsensitiveStr::Ascii("vourier"),
        dictgen::InsensitiveStr::Ascii("vouries"),
        dictgen::InsensitiveStr::Ascii("vouriest"),
        dictgen::InsensitiveStr::Ascii("vourilier"),
        dictgen::InsensitiveStr::Ascii("vourilies"),
        dictgen::InsensitiveStr::Ascii("vouriliest"),
        dictgen::InsensitiveStr::Ascii("vourily"),
        dictgen::InsensitiveStr::Ascii("vouriness"),
        dictgen::InsensitiveStr::Ascii("vourinesses"),
        dictgen::InsensitiveStr::Ascii("voury"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNSABERED_12373905418079294291)],
        &[(0b00001, &ENTRY_UNSABEREDDER_6684241841706286704)],
        &[(0b00001, &ENTRY_UNSABEREDDEST_18251233635069875174)],
        &[(0b11010, &ENTRY_UNSABERED_12373905418079294291)],
        &[(0b11010, &ENTRY_UNSABEREDDER_6684241841706286704)],
        &[(0b11010, &ENTRY_UNSABEREDDEST_18251233635069875174)],
        &[(0b10010, &ENTRY_UNSATIRIZABLE_3145098919717260943)],
        &[(0b10010, &ENTRY_UNSATIRIZE_8851857183483386343)],
        &[(0b10010, &ENTRY_UNSATIRIZED_10918619380161599373)],
        &[(0b10010, &ENTRY_UNSATIRIZEDDER_16298087524992431097)],
        &[(0b10010, &ENTRY_UNSATIRIZEDDEST_1911445418808524947)],
        &[(0b10010, &ENTRY_UNSATIRIZES_13785980925145652389)],
        &[(0b01001, &ENTRY_UNSATIRIZABLE_3145098919717260943)],
        &[(0b01001, &ENTRY_UNSATIRIZE_8851857183483386343)],
        &[(0b01001, &ENTRY_UNSATIRIZED_10918619380161599373)],
        &[(0b01001, &ENTRY_UNSATIRIZEDDER_16298087524992431097)],
        &[(0b01001, &ENTRY_UNSATIRIZEDDEST_1911445418808524947)],
        &[(0b01001, &ENTRY_UNSATIRIZES_13785980925145652389)],
        &[(0b00001, &ENTRY_UNSAVORED_11475616474446054221)],
        &[(0b00001, &ENTRY_UNSAVOREDDER_15068022672465287063)],
        &[(0b00001, &ENTRY_UNSAVOREDDEST_17270994326222090025)],
        &[(0b00001, &ENTRY_UNSAVOREDLY_1848146764107083498)],
        &[(0b00001, &ENTRY_UNSAVOREDNESS_2191242243682590718)],
        &[(0b01001, &ENTRY_UNSAVORIER_7566012794202894976)],
        &[(0b01001, &ENTRY_UNSAVORIES_13570256108415909776)],
        &[(0b01001, &ENTRY_UNSAVORIEST_18354309014937328323)],
        &[(0b00001, &ENTRY_UNSAVORILIER_9113239881471687179)],
        &[(0b00001, &ENTRY_UNSAVORILIES_17139583247048205448)],
        &[(0b00001, &ENTRY_UNSAVORILIEST_4268592476904671461)],
        &[(0b00001, &ENTRY_UNSAVORILY_15922738901841500332)],
        &[(0b00001, &ENTRY_UNSAVORINESS_10308314055531850628)],
        &[(0b00001, &ENTRY_UNSAVORINESSES_9146175498090621820)],
        &[(0b01001, &ENTRY_UNSAVORY_14080716095107745994)],
        &[(0b11010, &ENTRY_UNSAVORED_11475616474446054221)],
        &[(0b11010, &ENTRY_UNSAVOREDDER_15068022672465287063)],
        &[(0b11010, &ENTRY_UNSAVOREDDEST_17270994326222090025)],
        &[(0b11010, &ENTRY_UNSAVOREDLY_1848146764107083498)],
        &[(0b11010, &ENTRY_UNSAVOREDNESS_2191242243682590718)],
        &[(0b11010, &ENTRY_UNSAVORIER_7566012794202894976)],
        &[(0b11010, &ENTRY_UNSAVORIES_13570256108415909776)],
        &[(0b11010, &ENTRY_UNSAVORIEST_18354309014937328323)],
        &[(0b11010, &ENTRY_UNSAVORILIER_9113239881471687179)],
        &[(0b11010, &ENTRY_UNSAVORILIES_17139583247048205448)],
        &[(0b11010, &ENTRY_UNSAVORILIEST_4268592476904671461)],
        &[(0b11010, &ENTRY_UNSAVORILY_15922738901841500332)],
        &[(0b11010, &ENTRY_UNSAVORINESS_10308314055531850628)],
        &[(0b11010, &ENTRY_UNSAVORINESSES_9146175498090621820)],
        &[(0b11010, &ENTRY_UNSAVORY_14080716095107745994)],
    ],
    range: 4..=11,
};

static VARS_UNR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNR_CHILDREN),
    value: None,
};

static VARS_UNR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNRA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNRE_NODE),
    None,
    None,
    None,
    Some(&VARS_UNRI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNRO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNRU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNRU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNRU_CHILDREN),
    value: None,
};

pub static VARS_UNRU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mored"),
        dictgen::InsensitiveStr::Ascii("moredder"),
        dictgen::InsensitiveStr::Ascii("moreddest"),
        dictgen::InsensitiveStr::Ascii("moured"),
        dictgen::InsensitiveStr::Ascii("mouredder"),
        dictgen::InsensitiveStr::Ascii("moureddest"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNRUMORED_9567717996555253392)],
        &[(0b00001, &ENTRY_UNRUMOREDDER_2068713489527969729)],
        &[(0b00001, &ENTRY_UNRUMOREDDEST_13156480564204110238)],
        &[(0b11010, &ENTRY_UNRUMORED_9567717996555253392)],
        &[(0b11010, &ENTRY_UNRUMOREDDER_2068713489527969729)],
        &[(0b11010, &ENTRY_UNRUMOREDDEST_13156480564204110238)],
    ],
    range: 5..=10,
};

static VARS_UNRO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNRO_CHILDREN),
    value: None,
};

pub static VARS_UNRO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("manised"),
        dictgen::InsensitiveStr::Ascii("manized"),
        dictgen::InsensitiveStr::Ascii("manticised"),
        dictgen::InsensitiveStr::Ascii("manticisedder"),
        dictgen::InsensitiveStr::Ascii("manticiseddest"),
        dictgen::InsensitiveStr::Ascii("manticiseds"),
        dictgen::InsensitiveStr::Ascii("manticized"),
        dictgen::InsensitiveStr::Ascii("manticizedder"),
        dictgen::InsensitiveStr::Ascii("manticizeddest"),
        dictgen::InsensitiveStr::Ascii("manticizeds"),
        dictgen::InsensitiveStr::Ascii("yalised"),
        dictgen::InsensitiveStr::Ascii("yaliseds"),
        dictgen::InsensitiveStr::Ascii("yalized"),
        dictgen::InsensitiveStr::Ascii("yalizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNROMANIZED_16023433417294923847)],
        &[(0b01001, &ENTRY_UNROMANIZED_16023433417294923847)],
        &[(0b10010, &ENTRY_UNROMANTICIZED_9116532491725444580)],
        &[(0b10010, &ENTRY_UNROMANTICIZEDDER_14224183937969515578)],
        &[(0b10010, &ENTRY_UNROMANTICIZEDDEST_4370230398020789302)],
        &[(0b10010, &ENTRY_UNROMANTICIZEDS_13982309102621522933)],
        &[(0b01001, &ENTRY_UNROMANTICIZED_9116532491725444580)],
        &[(0b01001, &ENTRY_UNROMANTICIZEDDER_14224183937969515578)],
        &[(0b01001, &ENTRY_UNROMANTICIZEDDEST_4370230398020789302)],
        &[(0b01001, &ENTRY_UNROMANTICIZEDS_13982309102621522933)],
        &[(0b10010, &ENTRY_UNROYALIZED_4739257089152987612)],
        &[(0b10010, &ENTRY_UNROYALIZEDS_546156597779010632)],
        &[(0b01001, &ENTRY_UNROYALIZED_4739257089152987612)],
        &[(0b01001, &ENTRY_UNROYALIZEDS_546156597779010632)],
    ],
    range: 7..=14,
};

static VARS_UNRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNRI_CHILDREN),
    value: None,
};

pub static VARS_UNRI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("valed"),
        dictgen::InsensitiveStr::Ascii("valedder"),
        dictgen::InsensitiveStr::Ascii("valeddest"),
        dictgen::InsensitiveStr::Ascii("valled"),
        dictgen::InsensitiveStr::Ascii("valledder"),
        dictgen::InsensitiveStr::Ascii("valleddest"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNRIVALED_7537208612931158340)],
        &[(0b00001, &ENTRY_UNRIVALEDDER_8854788039016975855)],
        &[(0b00001, &ENTRY_UNRIVALEDDEST_18237777950481518710)],
        &[(0b11010, &ENTRY_UNRIVALED_7537208612931158340)],
        &[(0b11010, &ENTRY_UNRIVALEDDER_8854788039016975855)],
        &[(0b11010, &ENTRY_UNRIVALEDDEST_18237777950481518710)],
    ],
    range: 5..=10,
};

static VARS_UNRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNRE_CHILDREN),
    value: None,
};

pub static VARS_UNRE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisable"),
        dictgen::InsensitiveStr::Ascii("alisables"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alisings"),
        dictgen::InsensitiveStr::Ascii("alizable"),
        dictgen::InsensitiveStr::Ascii("alizables"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("alizings"),
        dictgen::InsensitiveStr::Ascii("cognisable"),
        dictgen::InsensitiveStr::Ascii("cognisabler"),
        dictgen::InsensitiveStr::Ascii("cognisablest"),
        dictgen::InsensitiveStr::Ascii("cognisably"),
        dictgen::InsensitiveStr::Ascii("cognised"),
        dictgen::InsensitiveStr::Ascii("cognising"),
        dictgen::InsensitiveStr::Ascii("cognisingly"),
        dictgen::InsensitiveStr::Ascii("cognizable"),
        dictgen::InsensitiveStr::Ascii("cognizabler"),
        dictgen::InsensitiveStr::Ascii("cognizablest"),
        dictgen::InsensitiveStr::Ascii("cognizably"),
        dictgen::InsensitiveStr::Ascii("cognized"),
        dictgen::InsensitiveStr::Ascii("cognizing"),
        dictgen::InsensitiveStr::Ascii("cognizingly"),
        dictgen::InsensitiveStr::Ascii("connoitered"),
        dictgen::InsensitiveStr::Ascii("connoiteredder"),
        dictgen::InsensitiveStr::Ascii("connoitereddest"),
        dictgen::InsensitiveStr::Ascii("connoitereds"),
        dictgen::InsensitiveStr::Ascii("connoitred"),
        dictgen::InsensitiveStr::Ascii("connoitredder"),
        dictgen::InsensitiveStr::Ascii("connoitreddest"),
        dictgen::InsensitiveStr::Ascii("connoitreds"),
        dictgen::InsensitiveStr::Ascii("gularised"),
        dictgen::InsensitiveStr::Ascii("gularized"),
        dictgen::InsensitiveStr::Ascii("organised"),
        dictgen::InsensitiveStr::Ascii("organisedder"),
        dictgen::InsensitiveStr::Ascii("organiseddest"),
        dictgen::InsensitiveStr::Ascii("organized"),
        dictgen::InsensitiveStr::Ascii("organizedder"),
        dictgen::InsensitiveStr::Ascii("organizeddest"),
        dictgen::InsensitiveStr::Ascii("velationise"),
        dictgen::InsensitiveStr::Ascii("velationises"),
        dictgen::InsensitiveStr::Ascii("velationize"),
        dictgen::InsensitiveStr::Ascii("velationizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNREALIZABLE_11418766116297521465)],
        &[(0b10010, &ENTRY_UNREALIZABLES_11601733641828871347)],
        &[(0b10010, &ENTRY_UNREALIZE_13293507645818343125)],
        &[(0b10010, &ENTRY_UNREALIZED_13998697549380132918)],
        &[(0b10010, &ENTRY_UNREALIZES_16009560303031337105)],
        &[(0b10010, &ENTRY_UNREALIZING_14733349295903954205)],
        &[(0b10010, &ENTRY_UNREALIZINGS_7526494100193070690)],
        &[(0b01001, &ENTRY_UNREALIZABLE_11418766116297521465)],
        &[(0b01001, &ENTRY_UNREALIZABLES_11601733641828871347)],
        &[(0b01001, &ENTRY_UNREALIZE_13293507645818343125)],
        &[(0b01001, &ENTRY_UNREALIZED_13998697549380132918)],
        &[(0b01001, &ENTRY_UNREALIZES_16009560303031337105)],
        &[(0b01001, &ENTRY_UNREALIZING_14733349295903954205)],
        &[(0b01001, &ENTRY_UNREALIZINGS_7526494100193070690)],
        &[(0b10010, &ENTRY_UNRECOGNIZABLE_7821646033253824562)],
        &[(0b10010, &ENTRY_UNRECOGNIZABLER_16831988820104346693)],
        &[(0b10010, &ENTRY_UNRECOGNIZABLEST_3385202348855994373)],
        &[(0b10010, &ENTRY_UNRECOGNIZABLY_16907513329485194946)],
        &[(0b10010, &ENTRY_UNRECOGNIZED_291281988118866118)],
        &[(0b10010, &ENTRY_UNRECOGNIZING_13216348411080336247)],
        &[(0b10010, &ENTRY_UNRECOGNIZINGLY_15939972486893394420)],
        &[(0b01001, &ENTRY_UNRECOGNIZABLE_7821646033253824562)],
        &[(0b01001, &ENTRY_UNRECOGNIZABLER_16831988820104346693)],
        &[(0b01001, &ENTRY_UNRECOGNIZABLEST_3385202348855994373)],
        &[(0b01001, &ENTRY_UNRECOGNIZABLY_16907513329485194946)],
        &[(0b01001, &ENTRY_UNRECOGNIZED_291281988118866118)],
        &[(0b01001, &ENTRY_UNRECOGNIZING_13216348411080336247)],
        &[(0b01001, &ENTRY_UNRECOGNIZINGLY_15939972486893394420)],
        &[(0b00001, &ENTRY_UNRECONNOITERED_13885276521917349849)],
        &[(0b00001, &ENTRY_UNRECONNOITEREDDER_17279023728979016058)],
        &[(0b00001, &ENTRY_UNRECONNOITEREDDEST_7283425295463639954)],
        &[(0b00001, &ENTRY_UNRECONNOITEREDS_1865811208169191767)],
        &[(0b11010, &ENTRY_UNRECONNOITERED_13885276521917349849)],
        &[(0b11010, &ENTRY_UNRECONNOITEREDDER_17279023728979016058)],
        &[(0b11010, &ENTRY_UNRECONNOITEREDDEST_7283425295463639954)],
        &[(0b11010, &ENTRY_UNRECONNOITEREDS_1865811208169191767)],
        &[(0b10010, &ENTRY_UNREGULARIZED_7607836970895525487)],
        &[(0b01001, &ENTRY_UNREGULARIZED_7607836970895525487)],
        &[(0b10010, &ENTRY_UNREORGANIZED_15643801344688977172)],
        &[(0b10010, &ENTRY_UNREORGANIZEDDER_13944138977099129044)],
        &[(0b10010, &ENTRY_UNREORGANIZEDDEST_6133551850899844304)],
        &[(0b01001, &ENTRY_UNREORGANIZED_15643801344688977172)],
        &[(0b01001, &ENTRY_UNREORGANIZEDDER_13944138977099129044)],
        &[(0b01001, &ENTRY_UNREORGANIZEDDEST_6133551850899844304)],
        &[(0b10010, &ENTRY_UNREVELATIONIZE_4135354342146461062)],
        &[(0b10010, &ENTRY_UNREVELATIONIZES_7331467037457288853)],
        &[(0b01001, &ENTRY_UNREVELATIONIZE_4135354342146461062)],
        &[(0b01001, &ENTRY_UNREVELATIONIZES_7331467037457288853)],
    ],
    range: 5..=15,
};

static VARS_UNRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNRA_CHILDREN),
    value: None,
};

pub static VARS_UNRA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dicalise"),
        dictgen::InsensitiveStr::Ascii("dicalises"),
        dictgen::InsensitiveStr::Ascii("dicalize"),
        dictgen::InsensitiveStr::Ascii("dicalizes"),
        dictgen::InsensitiveStr::Ascii("ncored"),
        dictgen::InsensitiveStr::Ascii("ncoredder"),
        dictgen::InsensitiveStr::Ascii("ncoreddest"),
        dictgen::InsensitiveStr::Ascii("ncoreds"),
        dictgen::InsensitiveStr::Ascii("ncorous"),
        dictgen::InsensitiveStr::Ascii("ncoured"),
        dictgen::InsensitiveStr::Ascii("ncouredder"),
        dictgen::InsensitiveStr::Ascii("ncoureddest"),
        dictgen::InsensitiveStr::Ascii("ncoureds"),
        dictgen::InsensitiveStr::Ascii("ncourous"),
        dictgen::InsensitiveStr::Ascii("tionalised"),
        dictgen::InsensitiveStr::Ascii("tionalising"),
        dictgen::InsensitiveStr::Ascii("tionalized"),
        dictgen::InsensitiveStr::Ascii("tionalizing"),
        dictgen::InsensitiveStr::Ascii("veled"),
        dictgen::InsensitiveStr::Ascii("veler"),
        dictgen::InsensitiveStr::Ascii("velers"),
        dictgen::InsensitiveStr::Ascii("veling"),
        dictgen::InsensitiveStr::Ascii("velled"),
        dictgen::InsensitiveStr::Ascii("veller"),
        dictgen::InsensitiveStr::Ascii("vellers"),
        dictgen::InsensitiveStr::Ascii("velling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNRADICALIZE_955382331879439831)],
        &[(0b10010, &ENTRY_UNRADICALIZES_10451136333567222975)],
        &[(0b01001, &ENTRY_UNRADICALIZE_955382331879439831)],
        &[(0b01001, &ENTRY_UNRADICALIZES_10451136333567222975)],
        &[(0b00001, &ENTRY_UNRANCORED_5635330286579157636)],
        &[(0b00001, &ENTRY_UNRANCOREDDER_3817724469012828292)],
        &[(0b00001, &ENTRY_UNRANCOREDDEST_11592021472933036375)],
        &[(0b00001, &ENTRY_UNRANCOREDS_3912120812229597055)],
        &[(0b00001, &ENTRY_UNRANCOROUS_1719417862290606862)],
        &[(0b11010, &ENTRY_UNRANCORED_5635330286579157636)],
        &[(0b11010, &ENTRY_UNRANCOREDDER_3817724469012828292)],
        &[(0b11010, &ENTRY_UNRANCOREDDEST_11592021472933036375)],
        &[(0b11010, &ENTRY_UNRANCOREDS_3912120812229597055)],
        &[(0b11010, &ENTRY_UNRANCOROUS_1719417862290606862)],
        &[(0b10010, &ENTRY_UNRATIONALIZED_125325346924816385)],
        &[(0b10010, &ENTRY_UNRATIONALIZING_6157188971216094486)],
        &[(0b01001, &ENTRY_UNRATIONALIZED_125325346924816385)],
        &[(0b01001, &ENTRY_UNRATIONALIZING_6157188971216094486)],
        &[(0b00001, &ENTRY_UNRAVELED_903111391532922846)],
        &[(0b00001, &ENTRY_UNRAVELER_8361573843424236468)],
        &[(0b00001, &ENTRY_UNRAVELERS_12461798051374270996)],
        &[(0b00001, &ENTRY_UNRAVELING_765040154842555334)],
        &[(0b11010, &ENTRY_UNRAVELED_903111391532922846)],
        &[(0b11010, &ENTRY_UNRAVELER_8361573843424236468)],
        &[(0b11010, &ENTRY_UNRAVELERS_12461798051374270996)],
        &[(0b11010, &ENTRY_UNRAVELING_765040154842555334)],
    ],
    range: 5..=11,
};

static VARS_UNQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNQ_CHILDREN),
    value: None,
};

pub static VARS_UNQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uantised"),
        dictgen::InsensitiveStr::Ascii("uantized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNQUANTIZED_2276689698541240314)],
        &[(0b01001, &ENTRY_UNQUANTIZED_2276689698541240314)],
    ],
    range: 8..=8,
};

static VARS_UNP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNP_CHILDREN),
    value: None,
};

static VARS_UNP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNPA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNPE_NODE),
    None,
    None,
    Some(&VARS_UNPH_NODE),
    Some(&VARS_UNPI_NODE),
    None,
    None,
    Some(&VARS_UNPL_NODE),
    None,
    None,
    Some(&VARS_UNPO_NODE),
    None,
    None,
    Some(&VARS_UNPR_NODE),
    None,
    None,
    Some(&VARS_UNPU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNPU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPU_CHILDREN),
    value: None,
};

pub static VARS_UNPU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("blicised"),
        dictgen::InsensitiveStr::Ascii("blicized"),
        dictgen::InsensitiveStr::Ascii("lverise"),
        dictgen::InsensitiveStr::Ascii("lverised"),
        dictgen::InsensitiveStr::Ascii("lverisedder"),
        dictgen::InsensitiveStr::Ascii("lveriseddest"),
        dictgen::InsensitiveStr::Ascii("lverises"),
        dictgen::InsensitiveStr::Ascii("lverize"),
        dictgen::InsensitiveStr::Ascii("lverized"),
        dictgen::InsensitiveStr::Ascii("lverizedder"),
        dictgen::InsensitiveStr::Ascii("lverizeddest"),
        dictgen::InsensitiveStr::Ascii("lverizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPUBLICIZED_11411018472574932653)],
        &[(0b01001, &ENTRY_UNPUBLICIZED_11411018472574932653)],
        &[(0b10010, &ENTRY_UNPULVERIZE_4306052034176949975)],
        &[(0b10010, &ENTRY_UNPULVERIZED_3203903971461779566)],
        &[(0b10010, &ENTRY_UNPULVERIZEDDER_5484774944919909274)],
        &[(0b10010, &ENTRY_UNPULVERIZEDDEST_8625344905804142571)],
        &[(0b10010, &ENTRY_UNPULVERIZES_7678149392200211776)],
        &[(0b01001, &ENTRY_UNPULVERIZE_4306052034176949975)],
        &[(0b01001, &ENTRY_UNPULVERIZED_3203903971461779566)],
        &[(0b01001, &ENTRY_UNPULVERIZEDDER_5484774944919909274)],
        &[(0b01001, &ENTRY_UNPULVERIZEDDEST_8625344905804142571)],
        &[(0b01001, &ENTRY_UNPULVERIZES_7678149392200211776)],
    ],
    range: 7..=12,
};

static VARS_UNPR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPR_CHILDREN),
    value: None,
};

pub static VARS_UNPR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("acticed"),
        dictgen::InsensitiveStr::Ascii("acticedder"),
        dictgen::InsensitiveStr::Ascii("acticeddest"),
        dictgen::InsensitiveStr::Ascii("actised"),
        dictgen::InsensitiveStr::Ascii("actisedder"),
        dictgen::InsensitiveStr::Ascii("actiseddest"),
        dictgen::InsensitiveStr::Ascii("eceptively"),
        dictgen::InsensitiveStr::Ascii("essurised"),
        dictgen::InsensitiveStr::Ascii("essurized"),
        dictgen::InsensitiveStr::Ascii("otestantise"),
        dictgen::InsensitiveStr::Ascii("otestantised"),
        dictgen::InsensitiveStr::Ascii("otestantises"),
        dictgen::InsensitiveStr::Ascii("otestantising"),
        dictgen::InsensitiveStr::Ascii("otestantize"),
        dictgen::InsensitiveStr::Ascii("otestantized"),
        dictgen::InsensitiveStr::Ascii("otestantizes"),
        dictgen::InsensitiveStr::Ascii("otestantizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_UNPRACTICED_6794067215889205747)],
        &[(0b01001, &ENTRY_UNPRACTICEDDER_17255783698342166608)],
        &[(0b01001, &ENTRY_UNPRACTICEDDEST_12496382526145371505)],
        &[(0b11010, &ENTRY_UNPRACTICED_6794067215889205747)],
        &[(0b11010, &ENTRY_UNPRACTICEDDER_17255783698342166608)],
        &[(0b11010, &ENTRY_UNPRACTICEDDEST_12496382526145371505)],
        &[(0b11010, &ENTRY_UNPERCEPTIVELY_13837914378436327028)],
        &[(0b10010, &ENTRY_UNPRESSURIZED_5109647751733072461)],
        &[(0b01001, &ENTRY_UNPRESSURIZED_5109647751733072461)],
        &[(0b10010, &ENTRY_UNPROTESTANTIZE_5546605125187361751)],
        &[(0b10010, &ENTRY_UNPROTESTANTIZED_12530485034019770123)],
        &[(0b10010, &ENTRY_UNPROTESTANTIZES_4530211699671168989)],
        &[(0b10010, &ENTRY_UNPROTESTANTIZING_14528978671585766161)],
        &[(0b01001, &ENTRY_UNPROTESTANTIZE_5546605125187361751)],
        &[(0b01001, &ENTRY_UNPROTESTANTIZED_12530485034019770123)],
        &[(0b01001, &ENTRY_UNPROTESTANTIZES_4530211699671168989)],
        &[(0b01001, &ENTRY_UNPROTESTANTIZING_14528978671585766161)],
    ],
    range: 7..=13,
};

static VARS_UNPO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPO_CHILDREN),
    value: None,
};

pub static VARS_UNPO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eticised"),
        dictgen::InsensitiveStr::Ascii("eticisedder"),
        dictgen::InsensitiveStr::Ascii("eticiseddest"),
        dictgen::InsensitiveStr::Ascii("eticiseds"),
        dictgen::InsensitiveStr::Ascii("eticized"),
        dictgen::InsensitiveStr::Ascii("eticizedder"),
        dictgen::InsensitiveStr::Ascii("eticizeddest"),
        dictgen::InsensitiveStr::Ascii("eticizeds"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("larisable"),
        dictgen::InsensitiveStr::Ascii("larisables"),
        dictgen::InsensitiveStr::Ascii("larised"),
        dictgen::InsensitiveStr::Ascii("larisedder"),
        dictgen::InsensitiveStr::Ascii("lariseddest"),
        dictgen::InsensitiveStr::Ascii("lariseds"),
        dictgen::InsensitiveStr::Ascii("larizable"),
        dictgen::InsensitiveStr::Ascii("larizables"),
        dictgen::InsensitiveStr::Ascii("larized"),
        dictgen::InsensitiveStr::Ascii("larizedder"),
        dictgen::InsensitiveStr::Ascii("larizeddest"),
        dictgen::InsensitiveStr::Ascii("larizeds"),
        dictgen::InsensitiveStr::Ascii("lymerised"),
        dictgen::InsensitiveStr::Ascii("lymerisedder"),
        dictgen::InsensitiveStr::Ascii("lymeriseddest"),
        dictgen::InsensitiveStr::Ascii("lymeriseds"),
        dictgen::InsensitiveStr::Ascii("lymerized"),
        dictgen::InsensitiveStr::Ascii("lymerizedder"),
        dictgen::InsensitiveStr::Ascii("lymerizeddest"),
        dictgen::InsensitiveStr::Ascii("lymerizeds"),
        dictgen::InsensitiveStr::Ascii("pularise"),
        dictgen::InsensitiveStr::Ascii("pularised"),
        dictgen::InsensitiveStr::Ascii("pularises"),
        dictgen::InsensitiveStr::Ascii("pularize"),
        dictgen::InsensitiveStr::Ascii("pularized"),
        dictgen::InsensitiveStr::Ascii("pularizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPOETICIZED_3981988256882871001)],
        &[(0b10010, &ENTRY_UNPOETICIZEDDER_16553304193349405175)],
        &[(0b10010, &ENTRY_UNPOETICIZEDDEST_11199398706019278294)],
        &[(0b10010, &ENTRY_UNPOETICIZEDS_17118411588245987939)],
        &[(0b01001, &ENTRY_UNPOETICIZED_3981988256882871001)],
        &[(0b01001, &ENTRY_UNPOETICIZEDDER_16553304193349405175)],
        &[(0b01001, &ENTRY_UNPOETICIZEDDEST_11199398706019278294)],
        &[(0b01001, &ENTRY_UNPOETICIZEDS_17118411588245987939)],
        &[(0b10010, &ENTRY_UNPOETIZE_11031261235007991496)],
        &[(0b10010, &ENTRY_UNPOETIZED_18184155777880410653)],
        &[(0b10010, &ENTRY_UNPOETIZES_7036862048295060125)],
        &[(0b01001, &ENTRY_UNPOETIZE_11031261235007991496)],
        &[(0b01001, &ENTRY_UNPOETIZED_18184155777880410653)],
        &[(0b01001, &ENTRY_UNPOETIZES_7036862048295060125)],
        &[(0b10010, &ENTRY_UNPOLARIZABLE_17741525376413399461)],
        &[(0b10010, &ENTRY_UNPOLARIZABLES_906462527546243871)],
        &[(0b10010, &ENTRY_UNPOLARIZED_2025887269421260061)],
        &[(0b10010, &ENTRY_UNPOLARIZEDDER_18443570066569643692)],
        &[(0b10010, &ENTRY_UNPOLARIZEDDEST_13477670326494096714)],
        &[(0b10010, &ENTRY_UNPOLARIZEDS_1059673460729973543)],
        &[(0b01001, &ENTRY_UNPOLARIZABLE_17741525376413399461)],
        &[(0b01001, &ENTRY_UNPOLARIZABLES_906462527546243871)],
        &[(0b01001, &ENTRY_UNPOLARIZED_2025887269421260061)],
        &[(0b01001, &ENTRY_UNPOLARIZEDDER_18443570066569643692)],
        &[(0b01001, &ENTRY_UNPOLARIZEDDEST_13477670326494096714)],
        &[(0b01001, &ENTRY_UNPOLARIZEDS_1059673460729973543)],
        &[(0b10010, &ENTRY_UNPOLYMERIZED_12019370435077113473)],
        &[(0b10010, &ENTRY_UNPOLYMERIZEDDER_13246460519378073245)],
        &[(0b10010, &ENTRY_UNPOLYMERIZEDDEST_6621171249833858730)],
        &[(0b10010, &ENTRY_UNPOLYMERIZEDS_11993450819958873813)],
        &[(0b01001, &ENTRY_UNPOLYMERIZED_12019370435077113473)],
        &[(0b01001, &ENTRY_UNPOLYMERIZEDDER_13246460519378073245)],
        &[(0b01001, &ENTRY_UNPOLYMERIZEDDEST_6621171249833858730)],
        &[(0b01001, &ENTRY_UNPOLYMERIZEDS_11993450819958873813)],
        &[(0b10010, &ENTRY_UNPOPULARIZE_399092079636575360)],
        &[(0b10010, &ENTRY_UNPOPULARIZED_11819251259971662834)],
        &[(0b10010, &ENTRY_UNPOPULARIZES_11095429734262523629)],
        &[(0b01001, &ENTRY_UNPOPULARIZE_399092079636575360)],
        &[(0b01001, &ENTRY_UNPOPULARIZED_11819251259971662834)],
        &[(0b01001, &ENTRY_UNPOPULARIZES_11095429734262523629)],
    ],
    range: 5..=13,
};

static VARS_UNPL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPL_CHILDREN),
    value: None,
};

pub static VARS_UNPL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agiarised"),
        dictgen::InsensitiveStr::Ascii("agiarisedder"),
        dictgen::InsensitiveStr::Ascii("agiariseddest"),
        dictgen::InsensitiveStr::Ascii("agiariseds"),
        dictgen::InsensitiveStr::Ascii("agiarized"),
        dictgen::InsensitiveStr::Ascii("agiarizedder"),
        dictgen::InsensitiveStr::Ascii("agiarizeddest"),
        dictgen::InsensitiveStr::Ascii("agiarizeds"),
        dictgen::InsensitiveStr::Ascii("uralised"),
        dictgen::InsensitiveStr::Ascii("uralized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPLAGIARIZED_569462043008408881)],
        &[(0b10010, &ENTRY_UNPLAGIARIZEDDER_2844070019396842238)],
        &[(0b10010, &ENTRY_UNPLAGIARIZEDDEST_10297070360250990028)],
        &[(0b10010, &ENTRY_UNPLAGIARIZEDS_16363973607034012033)],
        &[(0b01001, &ENTRY_UNPLAGIARIZED_569462043008408881)],
        &[(0b01001, &ENTRY_UNPLAGIARIZEDDER_2844070019396842238)],
        &[(0b01001, &ENTRY_UNPLAGIARIZEDDEST_10297070360250990028)],
        &[(0b01001, &ENTRY_UNPLAGIARIZEDS_16363973607034012033)],
        &[(0b10010, &ENTRY_UNPLURALIZED_730997926914844312)],
        &[(0b01001, &ENTRY_UNPLURALIZED_730997926914844312)],
    ],
    range: 8..=13,
};

static VARS_UNPI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPI_CHILDREN),
    value: None,
};

pub static VARS_UNPI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ctorialise"),
        dictgen::InsensitiveStr::Ascii("ctorialised"),
        dictgen::InsensitiveStr::Ascii("ctorialising"),
        dictgen::InsensitiveStr::Ascii("ctorialize"),
        dictgen::InsensitiveStr::Ascii("ctorialized"),
        dictgen::InsensitiveStr::Ascii("ctorializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPICTORIALIZE_3126347844933178338)],
        &[(0b10010, &ENTRY_UNPICTORIALIZED_5301866355430257659)],
        &[(0b10010, &ENTRY_UNPICTORIALIZING_10203584904739205498)],
        &[(0b01001, &ENTRY_UNPICTORIALIZE_3126347844933178338)],
        &[(0b01001, &ENTRY_UNPICTORIALIZED_5301866355430257659)],
        &[(0b01001, &ENTRY_UNPICTORIALIZING_10203584904739205498)],
    ],
    range: 10..=12,
};

static VARS_UNPH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPH_CHILDREN),
    value: None,
};

pub static VARS_UNPH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilosophise"),
        dictgen::InsensitiveStr::Ascii("ilosophised"),
        dictgen::InsensitiveStr::Ascii("ilosophises"),
        dictgen::InsensitiveStr::Ascii("ilosophize"),
        dictgen::InsensitiveStr::Ascii("ilosophized"),
        dictgen::InsensitiveStr::Ascii("ilosophizes"),
        dictgen::InsensitiveStr::Ascii("osphatised"),
        dictgen::InsensitiveStr::Ascii("osphatisedder"),
        dictgen::InsensitiveStr::Ascii("osphatiseddest"),
        dictgen::InsensitiveStr::Ascii("osphatiseds"),
        dictgen::InsensitiveStr::Ascii("osphatized"),
        dictgen::InsensitiveStr::Ascii("osphatizedder"),
        dictgen::InsensitiveStr::Ascii("osphatizeddest"),
        dictgen::InsensitiveStr::Ascii("osphatizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPHILOSOPHIZE_7144628023446557783)],
        &[(0b10010, &ENTRY_UNPHILOSOPHIZED_12661540003568404124)],
        &[(0b10010, &ENTRY_UNPHILOSOPHIZES_5880855030624936917)],
        &[(0b01001, &ENTRY_UNPHILOSOPHIZE_7144628023446557783)],
        &[(0b01001, &ENTRY_UNPHILOSOPHIZED_12661540003568404124)],
        &[(0b01001, &ENTRY_UNPHILOSOPHIZES_5880855030624936917)],
        &[(0b10010, &ENTRY_UNPHOSPHATIZED_13106493599965727596)],
        &[(0b10010, &ENTRY_UNPHOSPHATIZEDDER_10420838305229474623)],
        &[(0b10010, &ENTRY_UNPHOSPHATIZEDDEST_8261623546482924636)],
        &[(0b10010, &ENTRY_UNPHOSPHATIZEDS_3767209936877351046)],
        &[(0b01001, &ENTRY_UNPHOSPHATIZED_13106493599965727596)],
        &[(0b01001, &ENTRY_UNPHOSPHATIZEDDER_10420838305229474623)],
        &[(0b01001, &ENTRY_UNPHOSPHATIZEDDEST_8261623546482924636)],
        &[(0b01001, &ENTRY_UNPHOSPHATIZEDS_3767209936877351046)],
    ],
    range: 10..=14,
};

static VARS_UNPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPE_CHILDREN),
    value: None,
};

pub static VARS_UNPE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nalised"),
        dictgen::InsensitiveStr::Ascii("nalisedder"),
        dictgen::InsensitiveStr::Ascii("naliseddest"),
        dictgen::InsensitiveStr::Ascii("nalized"),
        dictgen::InsensitiveStr::Ascii("nalizedder"),
        dictgen::InsensitiveStr::Ascii("nalizeddest"),
        dictgen::InsensitiveStr::Ascii("rceptively"),
        dictgen::InsensitiveStr::Ascii("rsonalised"),
        dictgen::InsensitiveStr::Ascii("rsonalising"),
        dictgen::InsensitiveStr::Ascii("rsonalized"),
        dictgen::InsensitiveStr::Ascii("rsonalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPENALIZED_725934609298878108)],
        &[(0b10010, &ENTRY_UNPENALIZEDDER_4990731968902937554)],
        &[(0b10010, &ENTRY_UNPENALIZEDDEST_10380252802297336859)],
        &[(0b01001, &ENTRY_UNPENALIZED_725934609298878108)],
        &[(0b01001, &ENTRY_UNPENALIZEDDER_4990731968902937554)],
        &[(0b01001, &ENTRY_UNPENALIZEDDEST_10380252802297336859)],
        &[(0b00001, &ENTRY_UNPERCEPTIVELY_13837914378436327028)],
        &[(0b10010, &ENTRY_UNPERSONALIZED_11833179297358942798)],
        &[(0b10010, &ENTRY_UNPERSONALIZING_10320557453890272802)],
        &[(0b01001, &ENTRY_UNPERSONALIZED_11833179297358942798)],
        &[(0b01001, &ENTRY_UNPERSONALIZING_10320557453890272802)],
    ],
    range: 7..=11,
};

static VARS_UNPA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNPA_CHILDREN),
    value: None,
};

static VARS_UNPA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNPAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_UNPAL_NODE),
    None,
    Some(&VARS_UNPAN_NODE),
    None,
    None,
    None,
    Some(&VARS_UNPAR_NODE),
    Some(&VARS_UNPAS_NODE),
    Some(&VARS_UNPAT_NODE),
    Some(&VARS_UNPAU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNPAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAU_CHILDREN),
    value: None,
};

pub static VARS_UNPAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("perised"),
        dictgen::InsensitiveStr::Ascii("periseds"),
        dictgen::InsensitiveStr::Ascii("perized"),
        dictgen::InsensitiveStr::Ascii("perizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPAUPERIZED_4384463109542126829)],
        &[(0b10010, &ENTRY_UNPAUPERIZEDS_7927657084998837690)],
        &[(0b01001, &ENTRY_UNPAUPERIZED_4384463109542126829)],
        &[(0b01001, &ENTRY_UNPAUPERIZEDS_7927657084998837690)],
    ],
    range: 7..=8,
};

static VARS_UNPAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAT_CHILDREN),
    value: None,
};

pub static VARS_UNPAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ronisable"),
        dictgen::InsensitiveStr::Ascii("ronisabler"),
        dictgen::InsensitiveStr::Ascii("ronisables"),
        dictgen::InsensitiveStr::Ascii("ronisablest"),
        dictgen::InsensitiveStr::Ascii("ronised"),
        dictgen::InsensitiveStr::Ascii("ronising"),
        dictgen::InsensitiveStr::Ascii("ronizable"),
        dictgen::InsensitiveStr::Ascii("ronizabler"),
        dictgen::InsensitiveStr::Ascii("ronizables"),
        dictgen::InsensitiveStr::Ascii("ronizablest"),
        dictgen::InsensitiveStr::Ascii("ronized"),
        dictgen::InsensitiveStr::Ascii("ronizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPATRONIZABLE_14055227709009863359)],
        &[(0b10010, &ENTRY_UNPATRONIZABLER_14573100045387724371)],
        &[(0b10010, &ENTRY_UNPATRONIZABLES_18262489304591786860)],
        &[(0b10010, &ENTRY_UNPATRONIZABLEST_16886725498057048673)],
        &[(0b10010, &ENTRY_UNPATRONIZED_9325244204582847374)],
        &[(0b10010, &ENTRY_UNPATRONIZING_6560093157771836424)],
        &[(0b01001, &ENTRY_UNPATRONIZABLE_14055227709009863359)],
        &[(0b01001, &ENTRY_UNPATRONIZABLER_14573100045387724371)],
        &[(0b01001, &ENTRY_UNPATRONIZABLES_18262489304591786860)],
        &[(0b01001, &ENTRY_UNPATRONIZABLEST_16886725498057048673)],
        &[(0b01001, &ENTRY_UNPATRONIZED_9325244204582847374)],
        &[(0b01001, &ENTRY_UNPATRONIZING_6560093157771836424)],
    ],
    range: 7..=11,
};

static VARS_UNPAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAS_CHILDREN),
    value: None,
};

pub static VARS_UNPAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("teurised"),
        dictgen::InsensitiveStr::Ascii("teurized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPASTEURIZED_5265896385107446936)],
        &[(0b01001, &ENTRY_UNPASTEURIZED_5265896385107446936)],
    ],
    range: 8..=8,
};

static VARS_UNPAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAR_CHILDREN),
    value: None,
};

pub static VARS_UNPAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agonised"),
        dictgen::InsensitiveStr::Ascii("agoniseds"),
        dictgen::InsensitiveStr::Ascii("agonized"),
        dictgen::InsensitiveStr::Ascii("agonizeds"),
        dictgen::InsensitiveStr::Ascii("alysed"),
        dictgen::InsensitiveStr::Ascii("alysedder"),
        dictgen::InsensitiveStr::Ascii("alyseddest"),
        dictgen::InsensitiveStr::Ascii("alyseds"),
        dictgen::InsensitiveStr::Ascii("alyzed"),
        dictgen::InsensitiveStr::Ascii("alyzedder"),
        dictgen::InsensitiveStr::Ascii("alyzeddest"),
        dictgen::InsensitiveStr::Ascii("alyzeds"),
        dictgen::InsensitiveStr::Ascii("ameterised"),
        dictgen::InsensitiveStr::Ascii("ameterized"),
        dictgen::InsensitiveStr::Ascii("ametrised"),
        dictgen::InsensitiveStr::Ascii("ametrized"),
        dictgen::InsensitiveStr::Ascii("celed"),
        dictgen::InsensitiveStr::Ascii("celedder"),
        dictgen::InsensitiveStr::Ascii("celeddest"),
        dictgen::InsensitiveStr::Ascii("celled"),
        dictgen::InsensitiveStr::Ascii("celledder"),
        dictgen::InsensitiveStr::Ascii("celleddest"),
        dictgen::InsensitiveStr::Ascii("enthesised"),
        dictgen::InsensitiveStr::Ascii("enthesized"),
        dictgen::InsensitiveStr::Ascii("ticularised"),
        dictgen::InsensitiveStr::Ascii("ticularisedder"),
        dictgen::InsensitiveStr::Ascii("ticulariseddest"),
        dictgen::InsensitiveStr::Ascii("ticulariseds"),
        dictgen::InsensitiveStr::Ascii("ticularising"),
        dictgen::InsensitiveStr::Ascii("ticularisinger"),
        dictgen::InsensitiveStr::Ascii("ticularisingest"),
        dictgen::InsensitiveStr::Ascii("ticularisings"),
        dictgen::InsensitiveStr::Ascii("ticularized"),
        dictgen::InsensitiveStr::Ascii("ticularizedder"),
        dictgen::InsensitiveStr::Ascii("ticularizeddest"),
        dictgen::InsensitiveStr::Ascii("ticularizeds"),
        dictgen::InsensitiveStr::Ascii("ticularizing"),
        dictgen::InsensitiveStr::Ascii("ticularizinger"),
        dictgen::InsensitiveStr::Ascii("ticularizingest"),
        dictgen::InsensitiveStr::Ascii("ticularizings"),
        dictgen::InsensitiveStr::Ascii("tisan"),
        dictgen::InsensitiveStr::Ascii("tizan"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPARAGONIZED_14832217974011410500)],
        &[(0b10010, &ENTRY_UNPARAGONIZEDS_13371268766791176199)],
        &[(0b01001, &ENTRY_UNPARAGONIZED_14832217974011410500)],
        &[(0b01001, &ENTRY_UNPARAGONIZEDS_13371268766791176199)],
        &[(0b11010, &ENTRY_UNPARALYZED_6958549761941429886)],
        &[(0b11010, &ENTRY_UNPARALYZEDDER_12368724256798535530)],
        &[(0b11010, &ENTRY_UNPARALYZEDDEST_11163810169190211510)],
        &[(0b11010, &ENTRY_UNPARALYZEDS_14494225354968815994)],
        &[(0b00001, &ENTRY_UNPARALYZED_6958549761941429886)],
        &[(0b00001, &ENTRY_UNPARALYZEDDER_12368724256798535530)],
        &[(0b00001, &ENTRY_UNPARALYZEDDEST_11163810169190211510)],
        &[(0b00001, &ENTRY_UNPARALYZEDS_14494225354968815994)],
        &[(0b10010, &ENTRY_UNPARAMETERIZED_16947457520544710568)],
        &[(0b01001, &ENTRY_UNPARAMETERIZED_16947457520544710568)],
        &[(0b10010, &ENTRY_UNPARAMETRIZED_12259132055588179393)],
        &[(0b01001, &ENTRY_UNPARAMETRIZED_12259132055588179393)],
        &[(0b00001, &ENTRY_UNPARCELED_262743817097801452)],
        &[(0b00001, &ENTRY_UNPARCELEDDER_11844117497562549294)],
        &[(0b00001, &ENTRY_UNPARCELEDDEST_10483130332035933664)],
        &[(0b11010, &ENTRY_UNPARCELED_262743817097801452)],
        &[(0b11010, &ENTRY_UNPARCELEDDER_11844117497562549294)],
        &[(0b11010, &ENTRY_UNPARCELEDDEST_10483130332035933664)],
        &[(0b10010, &ENTRY_UNPARENTHESIZED_7803630114504922502)],
        &[(0b01001, &ENTRY_UNPARENTHESIZED_7803630114504922502)],
        &[(0b10010, &ENTRY_UNPARTICULARIZED_13897465210935993798)],
        &[(0b10010, &ENTRY_UNPARTICULARIZEDDER_11469278173298354240)],
        &[(0b10010, &ENTRY_UNPARTICULARIZEDDEST_8647720932351021234)],
        &[(0b10010, &ENTRY_UNPARTICULARIZEDS_11035216646331913261)],
        &[(0b10010, &ENTRY_UNPARTICULARIZING_9707431197331693971)],
        &[(0b10010, &ENTRY_UNPARTICULARIZINGER_11495496854437849250)],
        &[(0b10010, &ENTRY_UNPARTICULARIZINGEST_10293813669141093640)],
        &[(0b10010, &ENTRY_UNPARTICULARIZINGS_12705022570599294056)],
        &[(0b01001, &ENTRY_UNPARTICULARIZED_13897465210935993798)],
        &[(0b01001, &ENTRY_UNPARTICULARIZEDDER_11469278173298354240)],
        &[(0b01001, &ENTRY_UNPARTICULARIZEDDEST_8647720932351021234)],
        &[(0b01001, &ENTRY_UNPARTICULARIZEDS_11035216646331913261)],
        &[(0b01001, &ENTRY_UNPARTICULARIZING_9707431197331693971)],
        &[(0b01001, &ENTRY_UNPARTICULARIZINGER_11495496854437849250)],
        &[(0b01001, &ENTRY_UNPARTICULARIZINGEST_10293813669141093640)],
        &[(0b01001, &ENTRY_UNPARTICULARIZINGS_12705022570599294056)],
        &[(0b10010, &ENTRY_UNPARTIZAN_2554553357403784183)],
        &[(0b01001, &ENTRY_UNPARTIZAN_2554553357403784183)],
    ],
    range: 5..=15,
};

static VARS_UNPAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAN_CHILDREN),
    value: None,
};

pub static VARS_UNPAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("egyrised"),
        dictgen::InsensitiveStr::Ascii("egyrized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPANEGYRIZED_18214590288764386066)],
        &[(0b01001, &ENTRY_UNPANEGYRIZED_18214590288764386066)],
    ],
    range: 8..=8,
};

static VARS_UNPAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAL_CHILDREN),
    value: None,
};

pub static VARS_UNPAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isaded"),
        dictgen::InsensitiveStr::Ascii("isadoed"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNPALISADED_9363420074275544577)],
        &[(0b11010, &ENTRY_UNPALISADED_9363420074275544577)],
    ],
    range: 6..=7,
};

static VARS_UNPAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAG_CHILDREN),
    value: None,
};

pub static VARS_UNPAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPAGANIZE_4513523638718785743)],
        &[(0b10010, &ENTRY_UNPAGANIZES_7555124108067566716)],
        &[(0b01001, &ENTRY_UNPAGANIZE_4513523638718785743)],
        &[(0b01001, &ENTRY_UNPAGANIZES_7555124108067566716)],
    ],
    range: 5..=6,
};

static VARS_UNO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNO_CHILDREN),
    value: None,
};

pub static VARS_UNO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ptimise"),
        dictgen::InsensitiveStr::Ascii("ptimised"),
        dictgen::InsensitiveStr::Ascii("ptimises"),
        dictgen::InsensitiveStr::Ascii("ptimising"),
        dictgen::InsensitiveStr::Ascii("ptimize"),
        dictgen::InsensitiveStr::Ascii("ptimized"),
        dictgen::InsensitiveStr::Ascii("ptimizes"),
        dictgen::InsensitiveStr::Ascii("ptimizing"),
        dictgen::InsensitiveStr::Ascii("rganisable"),
        dictgen::InsensitiveStr::Ascii("rganisabler"),
        dictgen::InsensitiveStr::Ascii("rganisables"),
        dictgen::InsensitiveStr::Ascii("rganisablest"),
        dictgen::InsensitiveStr::Ascii("rganise"),
        dictgen::InsensitiveStr::Ascii("rganised"),
        dictgen::InsensitiveStr::Ascii("rganisedly"),
        dictgen::InsensitiveStr::Ascii("rganisedness"),
        dictgen::InsensitiveStr::Ascii("rganizable"),
        dictgen::InsensitiveStr::Ascii("rganizabler"),
        dictgen::InsensitiveStr::Ascii("rganizables"),
        dictgen::InsensitiveStr::Ascii("rganizablest"),
        dictgen::InsensitiveStr::Ascii("rganize"),
        dictgen::InsensitiveStr::Ascii("rganized"),
        dictgen::InsensitiveStr::Ascii("rganizedly"),
        dictgen::InsensitiveStr::Ascii("rganizedness"),
        dictgen::InsensitiveStr::Ascii("xidisable"),
        dictgen::InsensitiveStr::Ascii("xidisabler"),
        dictgen::InsensitiveStr::Ascii("xidisables"),
        dictgen::InsensitiveStr::Ascii("xidisablest"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidisedder"),
        dictgen::InsensitiveStr::Ascii("xidiseddest"),
        dictgen::InsensitiveStr::Ascii("xidizable"),
        dictgen::InsensitiveStr::Ascii("xidizabler"),
        dictgen::InsensitiveStr::Ascii("xidizables"),
        dictgen::InsensitiveStr::Ascii("xidizablest"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizedder"),
        dictgen::InsensitiveStr::Ascii("xidizeddest"),
        dictgen::InsensitiveStr::Ascii("xygenised"),
        dictgen::InsensitiveStr::Ascii("xygeniseds"),
        dictgen::InsensitiveStr::Ascii("xygenized"),
        dictgen::InsensitiveStr::Ascii("xygenizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNOPTIMIZE_2225906295826486470)],
        &[(0b10010, &ENTRY_UNOPTIMIZED_16942042074875027551)],
        &[(0b10010, &ENTRY_UNOPTIMIZES_4650439389608219823)],
        &[(0b10010, &ENTRY_UNOPTIMIZING_13917033577308167414)],
        &[(0b01001, &ENTRY_UNOPTIMIZE_2225906295826486470)],
        &[(0b01001, &ENTRY_UNOPTIMIZED_16942042074875027551)],
        &[(0b01001, &ENTRY_UNOPTIMIZES_4650439389608219823)],
        &[(0b01001, &ENTRY_UNOPTIMIZING_13917033577308167414)],
        &[(0b10010, &ENTRY_UNORGANIZABLE_11991965426515761260)],
        &[(0b10010, &ENTRY_UNORGANIZABLER_12327186123744522228)],
        &[(0b10010, &ENTRY_UNORGANIZABLES_7347832752348610754)],
        &[(0b10010, &ENTRY_UNORGANIZABLEST_14186046003153225163)],
        &[(0b10010, &ENTRY_UNORGANIZE_13934278640366945691)],
        &[(0b10010, &ENTRY_UNORGANIZED_11234215167570055764)],
        &[(0b10010, &ENTRY_UNORGANIZEDLY_12175435547618889361)],
        &[(0b10010, &ENTRY_UNORGANIZEDNESS_16136998940664713050)],
        &[(0b01001, &ENTRY_UNORGANIZABLE_11991965426515761260)],
        &[(0b01001, &ENTRY_UNORGANIZABLER_12327186123744522228)],
        &[(0b01001, &ENTRY_UNORGANIZABLES_7347832752348610754)],
        &[(0b01001, &ENTRY_UNORGANIZABLEST_14186046003153225163)],
        &[(0b01001, &ENTRY_UNORGANIZE_13934278640366945691)],
        &[(0b01001, &ENTRY_UNORGANIZED_11234215167570055764)],
        &[(0b01001, &ENTRY_UNORGANIZEDLY_12175435547618889361)],
        &[(0b01001, &ENTRY_UNORGANIZEDNESS_16136998940664713050)],
        &[(0b10010, &ENTRY_UNOXIDIZABLE_1866331079475280360)],
        &[(0b10010, &ENTRY_UNOXIDIZABLER_1507332604073799190)],
        &[(0b10010, &ENTRY_UNOXIDIZABLES_13262035573197556458)],
        &[(0b10010, &ENTRY_UNOXIDIZABLEST_3100338328549585672)],
        &[(0b10010, &ENTRY_UNOXIDIZED_6163194422377055559)],
        &[(0b10010, &ENTRY_UNOXIDIZEDDER_12013452575486590169)],
        &[(0b10010, &ENTRY_UNOXIDIZEDDEST_7098572889716170401)],
        &[(0b01001, &ENTRY_UNOXIDIZABLE_1866331079475280360)],
        &[(0b01001, &ENTRY_UNOXIDIZABLER_1507332604073799190)],
        &[(0b01001, &ENTRY_UNOXIDIZABLES_13262035573197556458)],
        &[(0b01001, &ENTRY_UNOXIDIZABLEST_3100338328549585672)],
        &[(0b01001, &ENTRY_UNOXIDIZED_6163194422377055559)],
        &[(0b01001, &ENTRY_UNOXIDIZEDDER_12013452575486590169)],
        &[(0b01001, &ENTRY_UNOXIDIZEDDEST_7098572889716170401)],
        &[(0b10010, &ENTRY_UNOXYGENIZED_3138801117611264462)],
        &[(0b10010, &ENTRY_UNOXYGENIZEDS_9668138306819694641)],
        &[(0b01001, &ENTRY_UNOXYGENIZED_3138801117611264462)],
        &[(0b01001, &ENTRY_UNOXYGENIZEDS_9668138306819694641)],
    ],
    range: 7..=12,
};

static VARS_UNN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNN_CHILDREN),
    value: None,
};

static VARS_UNN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNNA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNNE_NODE),
    None,
    None,
    None,
    Some(&VARS_UNNI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNNO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNNO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNNO_CHILDREN),
    value: None,
};

pub static VARS_UNNO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ncolorables"),
        dictgen::InsensitiveStr::Ascii("ncolorablies"),
        dictgen::InsensitiveStr::Ascii("ncolorably"),
        dictgen::InsensitiveStr::Ascii("ncolourables"),
        dictgen::InsensitiveStr::Ascii("ncolourablies"),
        dictgen::InsensitiveStr::Ascii("ncolourably"),
        dictgen::InsensitiveStr::Ascii("rmalise"),
        dictgen::InsensitiveStr::Ascii("rmalised"),
        dictgen::InsensitiveStr::Ascii("rmalisedder"),
        dictgen::InsensitiveStr::Ascii("rmaliseddest"),
        dictgen::InsensitiveStr::Ascii("rmalises"),
        dictgen::InsensitiveStr::Ascii("rmalising"),
        dictgen::InsensitiveStr::Ascii("rmalisinger"),
        dictgen::InsensitiveStr::Ascii("rmalisingest"),
        dictgen::InsensitiveStr::Ascii("rmalize"),
        dictgen::InsensitiveStr::Ascii("rmalized"),
        dictgen::InsensitiveStr::Ascii("rmalizedder"),
        dictgen::InsensitiveStr::Ascii("rmalizeddest"),
        dictgen::InsensitiveStr::Ascii("rmalizes"),
        dictgen::InsensitiveStr::Ascii("rmalizing"),
        dictgen::InsensitiveStr::Ascii("rmalizinger"),
        dictgen::InsensitiveStr::Ascii("rmalizingest"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNNONCOLORABLES_15129902177178103036)],
        &[(0b00001, &ENTRY_UNNONCOLORABLIES_511634610054739335)],
        &[(0b00001, &ENTRY_UNNONCOLORABLY_3291489823657748402)],
        &[(0b11010, &ENTRY_UNNONCOLORABLES_15129902177178103036)],
        &[(0b11010, &ENTRY_UNNONCOLORABLIES_511634610054739335)],
        &[(0b11010, &ENTRY_UNNONCOLORABLY_3291489823657748402)],
        &[(0b10010, &ENTRY_UNNORMALIZE_6669476142619447499)],
        &[(0b10010, &ENTRY_UNNORMALIZED_4666322878556737891)],
        &[(0b10010, &ENTRY_UNNORMALIZEDDER_4485274349407128413)],
        &[(0b10010, &ENTRY_UNNORMALIZEDDEST_14330056459661112775)],
        &[(0b10010, &ENTRY_UNNORMALIZES_7328316644426171612)],
        &[(0b10010, &ENTRY_UNNORMALIZING_2469755702378752753)],
        &[(0b10010, &ENTRY_UNNORMALIZINGER_9460951407730348444)],
        &[(0b10010, &ENTRY_UNNORMALIZINGEST_18164527599111165108)],
        &[(0b01001, &ENTRY_UNNORMALIZE_6669476142619447499)],
        &[(0b01001, &ENTRY_UNNORMALIZED_4666322878556737891)],
        &[(0b01001, &ENTRY_UNNORMALIZEDDER_4485274349407128413)],
        &[(0b01001, &ENTRY_UNNORMALIZEDDEST_14330056459661112775)],
        &[(0b01001, &ENTRY_UNNORMALIZES_7328316644426171612)],
        &[(0b01001, &ENTRY_UNNORMALIZING_2469755702378752753)],
        &[(0b01001, &ENTRY_UNNORMALIZINGER_9460951407730348444)],
        &[(0b01001, &ENTRY_UNNORMALIZINGEST_18164527599111165108)],
    ],
    range: 7..=13,
};

static VARS_UNNI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNNI_CHILDREN),
    value: None,
};

pub static VARS_UNNI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("trogenised"),
        dictgen::InsensitiveStr::Ascii("trogenisedder"),
        dictgen::InsensitiveStr::Ascii("trogeniseddest"),
        dictgen::InsensitiveStr::Ascii("trogeniseds"),
        dictgen::InsensitiveStr::Ascii("trogenized"),
        dictgen::InsensitiveStr::Ascii("trogenizedder"),
        dictgen::InsensitiveStr::Ascii("trogenizeddest"),
        dictgen::InsensitiveStr::Ascii("trogenizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNNITROGENIZED_11363970866698133470)],
        &[(0b10010, &ENTRY_UNNITROGENIZEDDER_4668460112104893964)],
        &[(0b10010, &ENTRY_UNNITROGENIZEDDEST_12183639058740360422)],
        &[(0b10010, &ENTRY_UNNITROGENIZEDS_16568352907153090415)],
        &[(0b01001, &ENTRY_UNNITROGENIZED_11363970866698133470)],
        &[(0b01001, &ENTRY_UNNITROGENIZEDDER_4668460112104893964)],
        &[(0b01001, &ENTRY_UNNITROGENIZEDDEST_12183639058740360422)],
        &[(0b01001, &ENTRY_UNNITROGENIZEDS_16568352907153090415)],
    ],
    range: 10..=14,
};

static VARS_UNNE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNNE_CHILDREN),
    value: None,
};

pub static VARS_UNNE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ighbored"),
        dictgen::InsensitiveStr::Ascii("ighborlier"),
        dictgen::InsensitiveStr::Ascii("ighborliest"),
        dictgen::InsensitiveStr::Ascii("ighborlike"),
        dictgen::InsensitiveStr::Ascii("ighborlikes"),
        dictgen::InsensitiveStr::Ascii("ighborliness"),
        dictgen::InsensitiveStr::Ascii("ighborlinesses"),
        dictgen::InsensitiveStr::Ascii("ighborly"),
        dictgen::InsensitiveStr::Ascii("ighboured"),
        dictgen::InsensitiveStr::Ascii("ighbourlier"),
        dictgen::InsensitiveStr::Ascii("ighbourliest"),
        dictgen::InsensitiveStr::Ascii("ighbourlike"),
        dictgen::InsensitiveStr::Ascii("ighbourlikes"),
        dictgen::InsensitiveStr::Ascii("ighbourliness"),
        dictgen::InsensitiveStr::Ascii("ighbourlinesses"),
        dictgen::InsensitiveStr::Ascii("ighbourly"),
        dictgen::InsensitiveStr::Ascii("utralise"),
        dictgen::InsensitiveStr::Ascii("utralised"),
        dictgen::InsensitiveStr::Ascii("utralising"),
        dictgen::InsensitiveStr::Ascii("utralize"),
        dictgen::InsensitiveStr::Ascii("utralized"),
        dictgen::InsensitiveStr::Ascii("utralizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNNEIGHBORED_8697632354577371299)],
        &[(0b00001, &ENTRY_UNNEIGHBORLIER_16454004623478436285)],
        &[(0b00001, &ENTRY_UNNEIGHBORLIEST_5019821008335017472)],
        &[(0b00001, &ENTRY_UNNEIGHBORLIKE_930605837147479219)],
        &[(0b00001, &ENTRY_UNNEIGHBORLIKES_14251473804138837266)],
        &[(0b00001, &ENTRY_UNNEIGHBORLINESS_4945316531198682259)],
        &[(0b00001, &ENTRY_UNNEIGHBORLINESSES_8622001054811759799)],
        &[(0b00001, &ENTRY_UNNEIGHBORLY_5887888161506730946)],
        &[(0b11010, &ENTRY_UNNEIGHBORED_8697632354577371299)],
        &[(0b11010, &ENTRY_UNNEIGHBORLIER_16454004623478436285)],
        &[(0b11010, &ENTRY_UNNEIGHBORLIEST_5019821008335017472)],
        &[(0b11010, &ENTRY_UNNEIGHBORLIKE_930605837147479219)],
        &[(0b11010, &ENTRY_UNNEIGHBORLIKES_14251473804138837266)],
        &[(0b11010, &ENTRY_UNNEIGHBORLINESS_4945316531198682259)],
        &[(0b11010, &ENTRY_UNNEIGHBORLINESSES_8622001054811759799)],
        &[(0b11010, &ENTRY_UNNEIGHBORLY_5887888161506730946)],
        &[(0b10010, &ENTRY_UNNEUTRALIZE_18018061019251914124)],
        &[(0b10010, &ENTRY_UNNEUTRALIZED_3127903145081496539)],
        &[(0b10010, &ENTRY_UNNEUTRALIZING_12083896961836140168)],
        &[(0b01001, &ENTRY_UNNEUTRALIZE_18018061019251914124)],
        &[(0b01001, &ENTRY_UNNEUTRALIZED_3127903145081496539)],
        &[(0b01001, &ENTRY_UNNEUTRALIZING_12083896961836140168)],
    ],
    range: 8..=15,
};

static VARS_UNNA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNNA_CHILDREN),
    value: None,
};

pub static VARS_UNNA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tionalised"),
        dictgen::InsensitiveStr::Ascii("tionalisedder"),
        dictgen::InsensitiveStr::Ascii("tionaliseddest"),
        dictgen::InsensitiveStr::Ascii("tionalized"),
        dictgen::InsensitiveStr::Ascii("tionalizedder"),
        dictgen::InsensitiveStr::Ascii("tionalizeddest"),
        dictgen::InsensitiveStr::Ascii("turalisable"),
        dictgen::InsensitiveStr::Ascii("turalisables"),
        dictgen::InsensitiveStr::Ascii("turalise"),
        dictgen::InsensitiveStr::Ascii("turalised"),
        dictgen::InsensitiveStr::Ascii("turalises"),
        dictgen::InsensitiveStr::Ascii("turalising"),
        dictgen::InsensitiveStr::Ascii("turalizable"),
        dictgen::InsensitiveStr::Ascii("turalizables"),
        dictgen::InsensitiveStr::Ascii("turalize"),
        dictgen::InsensitiveStr::Ascii("turalized"),
        dictgen::InsensitiveStr::Ascii("turalizes"),
        dictgen::InsensitiveStr::Ascii("turalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNNATIONALIZED_13305692858549585336)],
        &[(0b10010, &ENTRY_UNNATIONALIZEDDER_10308676019005864186)],
        &[(0b10010, &ENTRY_UNNATIONALIZEDDEST_8402812183279300374)],
        &[(0b01001, &ENTRY_UNNATIONALIZED_13305692858549585336)],
        &[(0b01001, &ENTRY_UNNATIONALIZEDDER_10308676019005864186)],
        &[(0b01001, &ENTRY_UNNATIONALIZEDDEST_8402812183279300374)],
        &[(0b10010, &ENTRY_UNNATURALIZABLE_16480663493395775143)],
        &[(0b10010, &ENTRY_UNNATURALIZABLES_13596151371214167721)],
        &[(0b10010, &ENTRY_UNNATURALIZE_16622774998946225122)],
        &[(0b10010, &ENTRY_UNNATURALIZED_5866490090567009574)],
        &[(0b10010, &ENTRY_UNNATURALIZES_8476052793010992170)],
        &[(0b10010, &ENTRY_UNNATURALIZING_6880744307034128987)],
        &[(0b01001, &ENTRY_UNNATURALIZABLE_16480663493395775143)],
        &[(0b01001, &ENTRY_UNNATURALIZABLES_13596151371214167721)],
        &[(0b01001, &ENTRY_UNNATURALIZE_16622774998946225122)],
        &[(0b01001, &ENTRY_UNNATURALIZED_5866490090567009574)],
        &[(0b01001, &ENTRY_UNNATURALIZES_8476052793010992170)],
        &[(0b01001, &ENTRY_UNNATURALIZING_6880744307034128987)],
    ],
    range: 8..=14,
};

static VARS_UNM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNM_CHILDREN),
    value: None,
};

static VARS_UNM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNMA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNME_NODE),
    None,
    None,
    None,
    Some(&VARS_UNMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNMO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNMU_NODE),
    None,
    None,
    None,
    Some(&VARS_UNMY_NODE),
    None,
];

static VARS_UNMY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNMY_CHILDREN),
    value: None,
};

pub static VARS_UNMY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sticise"),
        dictgen::InsensitiveStr::Ascii("sticised"),
        dictgen::InsensitiveStr::Ascii("sticises"),
        dictgen::InsensitiveStr::Ascii("sticising"),
        dictgen::InsensitiveStr::Ascii("sticize"),
        dictgen::InsensitiveStr::Ascii("sticized"),
        dictgen::InsensitiveStr::Ascii("sticizes"),
        dictgen::InsensitiveStr::Ascii("sticizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNMYSTICIZE_12388597900585961073)],
        &[(0b10010, &ENTRY_UNMYSTICIZED_11062556013503200560)],
        &[(0b10010, &ENTRY_UNMYSTICIZES_17390241333164575800)],
        &[(0b10010, &ENTRY_UNMYSTICIZING_12458261619992424221)],
        &[(0b01001, &ENTRY_UNMYSTICIZE_12388597900585961073)],
        &[(0b01001, &ENTRY_UNMYSTICIZED_11062556013503200560)],
        &[(0b01001, &ENTRY_UNMYSTICIZES_17390241333164575800)],
        &[(0b01001, &ENTRY_UNMYSTICIZING_12458261619992424221)],
    ],
    range: 7..=9,
};

static VARS_UNMU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNMU_CHILDREN),
    value: None,
};

pub static VARS_UNMU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nicipalised"),
        dictgen::InsensitiveStr::Ascii("nicipalisedder"),
        dictgen::InsensitiveStr::Ascii("nicipaliseddest"),
        dictgen::InsensitiveStr::Ascii("nicipaliseds"),
        dictgen::InsensitiveStr::Ascii("nicipalized"),
        dictgen::InsensitiveStr::Ascii("nicipalizedder"),
        dictgen::InsensitiveStr::Ascii("nicipalizeddest"),
        dictgen::InsensitiveStr::Ascii("nicipalizeds"),
        dictgen::InsensitiveStr::Ascii("tualised"),
        dictgen::InsensitiveStr::Ascii("tualisedder"),
        dictgen::InsensitiveStr::Ascii("tualiseddest"),
        dictgen::InsensitiveStr::Ascii("tualiseds"),
        dictgen::InsensitiveStr::Ascii("tualized"),
        dictgen::InsensitiveStr::Ascii("tualizedder"),
        dictgen::InsensitiveStr::Ascii("tualizeddest"),
        dictgen::InsensitiveStr::Ascii("tualizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNMUNICIPALIZED_12122839729704889640)],
        &[(0b10010, &ENTRY_UNMUNICIPALIZEDDER_14808890863362223595)],
        &[(0b10010, &ENTRY_UNMUNICIPALIZEDDEST_10995903656105467027)],
        &[(0b10010, &ENTRY_UNMUNICIPALIZEDS_9334949007165725184)],
        &[(0b01001, &ENTRY_UNMUNICIPALIZED_12122839729704889640)],
        &[(0b01001, &ENTRY_UNMUNICIPALIZEDDER_14808890863362223595)],
        &[(0b01001, &ENTRY_UNMUNICIPALIZEDDEST_10995903656105467027)],
        &[(0b01001, &ENTRY_UNMUNICIPALIZEDS_9334949007165725184)],
        &[(0b10010, &ENTRY_UNMUTUALIZED_11726828009810562838)],
        &[(0b10010, &ENTRY_UNMUTUALIZEDDER_6120773781645783648)],
        &[(0b10010, &ENTRY_UNMUTUALIZEDDEST_644266925710147172)],
        &[(0b10010, &ENTRY_UNMUTUALIZEDS_4071796319304281606)],
        &[(0b01001, &ENTRY_UNMUTUALIZED_11726828009810562838)],
        &[(0b01001, &ENTRY_UNMUTUALIZEDDER_6120773781645783648)],
        &[(0b01001, &ENTRY_UNMUTUALIZEDDEST_644266925710147172)],
        &[(0b01001, &ENTRY_UNMUTUALIZEDS_4071796319304281606)],
    ],
    range: 8..=15,
};

static VARS_UNMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNMO_CHILDREN),
    value: None,
};

pub static VARS_UNMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilised"),
        dictgen::InsensitiveStr::Ascii("bilisedder"),
        dictgen::InsensitiveStr::Ascii("biliseddest"),
        dictgen::InsensitiveStr::Ascii("biliseds"),
        dictgen::InsensitiveStr::Ascii("bilized"),
        dictgen::InsensitiveStr::Ascii("bilizedder"),
        dictgen::InsensitiveStr::Ascii("bilizeddest"),
        dictgen::InsensitiveStr::Ascii("bilizeds"),
        dictgen::InsensitiveStr::Ascii("dernise"),
        dictgen::InsensitiveStr::Ascii("dernised"),
        dictgen::InsensitiveStr::Ascii("dernisedder"),
        dictgen::InsensitiveStr::Ascii("derniseddest"),
        dictgen::InsensitiveStr::Ascii("dernises"),
        dictgen::InsensitiveStr::Ascii("dernize"),
        dictgen::InsensitiveStr::Ascii("dernized"),
        dictgen::InsensitiveStr::Ascii("dernizedder"),
        dictgen::InsensitiveStr::Ascii("dernizeddest"),
        dictgen::InsensitiveStr::Ascii("dernizes"),
        dictgen::InsensitiveStr::Ascii("nopolise"),
        dictgen::InsensitiveStr::Ascii("nopolised"),
        dictgen::InsensitiveStr::Ascii("nopolisedder"),
        dictgen::InsensitiveStr::Ascii("nopoliseddest"),
        dictgen::InsensitiveStr::Ascii("nopolises"),
        dictgen::InsensitiveStr::Ascii("nopolising"),
        dictgen::InsensitiveStr::Ascii("nopolisinger"),
        dictgen::InsensitiveStr::Ascii("nopolisingest"),
        dictgen::InsensitiveStr::Ascii("nopolisings"),
        dictgen::InsensitiveStr::Ascii("nopolize"),
        dictgen::InsensitiveStr::Ascii("nopolized"),
        dictgen::InsensitiveStr::Ascii("nopolizedder"),
        dictgen::InsensitiveStr::Ascii("nopolizeddest"),
        dictgen::InsensitiveStr::Ascii("nopolizes"),
        dictgen::InsensitiveStr::Ascii("nopolizing"),
        dictgen::InsensitiveStr::Ascii("nopolizinger"),
        dictgen::InsensitiveStr::Ascii("nopolizingest"),
        dictgen::InsensitiveStr::Ascii("nopolizings"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralised"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralising"),
        dictgen::InsensitiveStr::Ascii("ralisinger"),
        dictgen::InsensitiveStr::Ascii("ralisingest"),
        dictgen::InsensitiveStr::Ascii("ralisings"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralized"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralizing"),
        dictgen::InsensitiveStr::Ascii("ralizinger"),
        dictgen::InsensitiveStr::Ascii("ralizingest"),
        dictgen::InsensitiveStr::Ascii("ralizings"),
        dictgen::InsensitiveStr::Ascii("torised"),
        dictgen::InsensitiveStr::Ascii("torisedder"),
        dictgen::InsensitiveStr::Ascii("toriseddest"),
        dictgen::InsensitiveStr::Ascii("torized"),
        dictgen::InsensitiveStr::Ascii("torizedder"),
        dictgen::InsensitiveStr::Ascii("torizeddest"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNMOBILIZED_6882258248677469216)],
        &[(0b10010, &ENTRY_UNMOBILIZEDDER_11927063159506308450)],
        &[(0b10010, &ENTRY_UNMOBILIZEDDEST_10224224733783290289)],
        &[(0b10010, &ENTRY_UNMOBILIZEDS_14948038683001063666)],
        &[(0b01001, &ENTRY_UNMOBILIZED_6882258248677469216)],
        &[(0b01001, &ENTRY_UNMOBILIZEDDER_11927063159506308450)],
        &[(0b01001, &ENTRY_UNMOBILIZEDDEST_10224224733783290289)],
        &[(0b01001, &ENTRY_UNMOBILIZEDS_14948038683001063666)],
        &[(0b10010, &ENTRY_UNMODERNIZE_12082713052164864740)],
        &[(0b10010, &ENTRY_UNMODERNIZED_17940257161248789338)],
        &[(0b10010, &ENTRY_UNMODERNIZEDDER_2184253259481509851)],
        &[(0b10010, &ENTRY_UNMODERNIZEDDEST_5884036476751578639)],
        &[(0b10010, &ENTRY_UNMODERNIZES_15371503983089338847)],
        &[(0b01001, &ENTRY_UNMODERNIZE_12082713052164864740)],
        &[(0b01001, &ENTRY_UNMODERNIZED_17940257161248789338)],
        &[(0b01001, &ENTRY_UNMODERNIZEDDER_2184253259481509851)],
        &[(0b01001, &ENTRY_UNMODERNIZEDDEST_5884036476751578639)],
        &[(0b01001, &ENTRY_UNMODERNIZES_15371503983089338847)],
        &[(0b10010, &ENTRY_UNMONOPOLIZE_8561469392171138113)],
        &[(0b10010, &ENTRY_UNMONOPOLIZED_5990364325192494246)],
        &[(0b10010, &ENTRY_UNMONOPOLIZEDDER_17142775490849128548)],
        &[(0b10010, &ENTRY_UNMONOPOLIZEDDEST_7447523346026484536)],
        &[(0b10010, &ENTRY_UNMONOPOLIZES_13270158276860099999)],
        &[(0b10010, &ENTRY_UNMONOPOLIZING_8354787337348046373)],
        &[(0b10010, &ENTRY_UNMONOPOLIZINGER_360819679104472363)],
        &[(0b10010, &ENTRY_UNMONOPOLIZINGEST_3073556729363282506)],
        &[(0b10010, &ENTRY_UNMONOPOLIZINGS_17013019050710709283)],
        &[(0b01001, &ENTRY_UNMONOPOLIZE_8561469392171138113)],
        &[(0b01001, &ENTRY_UNMONOPOLIZED_5990364325192494246)],
        &[(0b01001, &ENTRY_UNMONOPOLIZEDDER_17142775490849128548)],
        &[(0b01001, &ENTRY_UNMONOPOLIZEDDEST_7447523346026484536)],
        &[(0b01001, &ENTRY_UNMONOPOLIZES_13270158276860099999)],
        &[(0b01001, &ENTRY_UNMONOPOLIZING_8354787337348046373)],
        &[(0b01001, &ENTRY_UNMONOPOLIZINGER_360819679104472363)],
        &[(0b01001, &ENTRY_UNMONOPOLIZINGEST_3073556729363282506)],
        &[(0b01001, &ENTRY_UNMONOPOLIZINGS_17013019050710709283)],
        &[(0b10010, &ENTRY_UNMORALIZE_16577373069040947378)],
        &[(0b10010, &ENTRY_UNMORALIZED_14682688325335149210)],
        &[(0b10010, &ENTRY_UNMORALIZES_5154600717815072047)],
        &[(0b10010, &ENTRY_UNMORALIZING_2925852403949922365)],
        &[(0b10010, &ENTRY_UNMORALIZINGER_7095495741685677317)],
        &[(0b10010, &ENTRY_UNMORALIZINGEST_558050961128963437)],
        &[(0b10010, &ENTRY_UNMORALIZINGS_10824587508976338526)],
        &[(0b01001, &ENTRY_UNMORALIZE_16577373069040947378)],
        &[(0b01001, &ENTRY_UNMORALIZED_14682688325335149210)],
        &[(0b01001, &ENTRY_UNMORALIZES_5154600717815072047)],
        &[(0b01001, &ENTRY_UNMORALIZING_2925852403949922365)],
        &[(0b01001, &ENTRY_UNMORALIZINGER_7095495741685677317)],
        &[(0b01001, &ENTRY_UNMORALIZINGEST_558050961128963437)],
        &[(0b01001, &ENTRY_UNMORALIZINGS_10824587508976338526)],
        &[(0b10010, &ENTRY_UNMOTORIZED_8115416776448533269)],
        &[(0b10010, &ENTRY_UNMOTORIZEDDER_1909498846471688585)],
        &[(0b10010, &ENTRY_UNMOTORIZEDDEST_13434675976031166453)],
        &[(0b01001, &ENTRY_UNMOTORIZED_8115416776448533269)],
        &[(0b01001, &ENTRY_UNMOTORIZEDDER_1909498846471688585)],
        &[(0b01001, &ENTRY_UNMOTORIZEDDEST_13434675976031166453)],
    ],
    range: 6..=13,
};

static VARS_UNMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNMI_CHILDREN),
    value: None,
};

pub static VARS_UNMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("litarised"),
        dictgen::InsensitiveStr::Ascii("litarized"),
        dictgen::InsensitiveStr::Ascii("neralised"),
        dictgen::InsensitiveStr::Ascii("neralisedder"),
        dictgen::InsensitiveStr::Ascii("neraliseddest"),
        dictgen::InsensitiveStr::Ascii("neraliseds"),
        dictgen::InsensitiveStr::Ascii("neralized"),
        dictgen::InsensitiveStr::Ascii("neralizedder"),
        dictgen::InsensitiveStr::Ascii("neralizeddest"),
        dictgen::InsensitiveStr::Ascii("neralizeds"),
        dictgen::InsensitiveStr::Ascii("nimised"),
        dictgen::InsensitiveStr::Ascii("nimisedder"),
        dictgen::InsensitiveStr::Ascii("nimiseddest"),
        dictgen::InsensitiveStr::Ascii("nimising"),
        dictgen::InsensitiveStr::Ascii("nimized"),
        dictgen::InsensitiveStr::Ascii("nimizedder"),
        dictgen::InsensitiveStr::Ascii("nimizeddest"),
        dictgen::InsensitiveStr::Ascii("nimizing"),
        dictgen::InsensitiveStr::Ascii("ssionised"),
        dictgen::InsensitiveStr::Ascii("ssioniseds"),
        dictgen::InsensitiveStr::Ascii("ssionized"),
        dictgen::InsensitiveStr::Ascii("ssionizeds"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tres"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNMILITARIZED_1485314695149985787)],
        &[(0b01001, &ENTRY_UNMILITARIZED_1485314695149985787)],
        &[(0b10010, &ENTRY_UNMINERALIZED_13182690126429279818)],
        &[(0b10010, &ENTRY_UNMINERALIZEDDER_17640203002238743394)],
        &[(0b10010, &ENTRY_UNMINERALIZEDDEST_16144751391346858077)],
        &[(0b10010, &ENTRY_UNMINERALIZEDS_18108031203100511951)],
        &[(0b01001, &ENTRY_UNMINERALIZED_13182690126429279818)],
        &[(0b01001, &ENTRY_UNMINERALIZEDDER_17640203002238743394)],
        &[(0b01001, &ENTRY_UNMINERALIZEDDEST_16144751391346858077)],
        &[(0b01001, &ENTRY_UNMINERALIZEDS_18108031203100511951)],
        &[(0b10010, &ENTRY_UNMINIMIZED_10804108869596653578)],
        &[(0b10010, &ENTRY_UNMINIMIZEDDER_9929018702523158132)],
        &[(0b10010, &ENTRY_UNMINIMIZEDDEST_10423241850474892989)],
        &[(0b10010, &ENTRY_UNMINIMIZING_7828881953798020330)],
        &[(0b01001, &ENTRY_UNMINIMIZED_10804108869596653578)],
        &[(0b01001, &ENTRY_UNMINIMIZEDDER_9929018702523158132)],
        &[(0b01001, &ENTRY_UNMINIMIZEDDEST_10423241850474892989)],
        &[(0b01001, &ENTRY_UNMINIMIZING_7828881953798020330)],
        &[(0b10010, &ENTRY_UNMISSIONIZED_6055141146647724226)],
        &[(0b10010, &ENTRY_UNMISSIONIZEDS_15498615692624108021)],
        &[(0b01001, &ENTRY_UNMISSIONIZED_6055141146647724226)],
        &[(0b01001, &ENTRY_UNMISSIONIZEDS_15498615692624108021)],
        &[(0b00001, &ENTRY_UNMITER_4436356488941610561)],
        &[(0b00001, &ENTRY_UNMITERS_10693236987116708733)],
        &[(0b11010, &ENTRY_UNMITER_4436356488941610561)],
        &[(0b11010, &ENTRY_UNMITERS_10693236987116708733)],
    ],
    range: 3..=13,
};

static VARS_UNME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNME_CHILDREN),
    value: None,
};

pub static VARS_UNME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chanise"),
        dictgen::InsensitiveStr::Ascii("chanised"),
        dictgen::InsensitiveStr::Ascii("chanises"),
        dictgen::InsensitiveStr::Ascii("chanising"),
        dictgen::InsensitiveStr::Ascii("chanize"),
        dictgen::InsensitiveStr::Ascii("chanized"),
        dictgen::InsensitiveStr::Ascii("chanizes"),
        dictgen::InsensitiveStr::Ascii("chanizing"),
        dictgen::InsensitiveStr::Ascii("diaeval"),
        dictgen::InsensitiveStr::Ascii("diatised"),
        dictgen::InsensitiveStr::Ascii("diatiseds"),
        dictgen::InsensitiveStr::Ascii("diatized"),
        dictgen::InsensitiveStr::Ascii("diatizeds"),
        dictgen::InsensitiveStr::Ascii("dieval"),
        dictgen::InsensitiveStr::Ascii("lodised"),
        dictgen::InsensitiveStr::Ascii("lodized"),
        dictgen::InsensitiveStr::Ascii("morialised"),
        dictgen::InsensitiveStr::Ascii("morialisedder"),
        dictgen::InsensitiveStr::Ascii("morialiseddest"),
        dictgen::InsensitiveStr::Ascii("morialiseds"),
        dictgen::InsensitiveStr::Ascii("morialized"),
        dictgen::InsensitiveStr::Ascii("morializedder"),
        dictgen::InsensitiveStr::Ascii("morializeddest"),
        dictgen::InsensitiveStr::Ascii("morializeds"),
        dictgen::InsensitiveStr::Ascii("morised"),
        dictgen::InsensitiveStr::Ascii("morized"),
        dictgen::InsensitiveStr::Ascii("rcerised"),
        dictgen::InsensitiveStr::Ascii("rceriseds"),
        dictgen::InsensitiveStr::Ascii("rcerized"),
        dictgen::InsensitiveStr::Ascii("rcerizeds"),
        dictgen::InsensitiveStr::Ascii("smerise"),
        dictgen::InsensitiveStr::Ascii("smerised"),
        dictgen::InsensitiveStr::Ascii("smerisedder"),
        dictgen::InsensitiveStr::Ascii("smeriseddest"),
        dictgen::InsensitiveStr::Ascii("smerises"),
        dictgen::InsensitiveStr::Ascii("smerize"),
        dictgen::InsensitiveStr::Ascii("smerized"),
        dictgen::InsensitiveStr::Ascii("smerizedder"),
        dictgen::InsensitiveStr::Ascii("smerizeddest"),
        dictgen::InsensitiveStr::Ascii("smerizes"),
        dictgen::InsensitiveStr::Ascii("talized"),
        dictgen::InsensitiveStr::Ascii("talizeds"),
        dictgen::InsensitiveStr::Ascii("tallised"),
        dictgen::InsensitiveStr::Ascii("talliseds"),
        dictgen::InsensitiveStr::Ascii("tallized"),
        dictgen::InsensitiveStr::Ascii("tallizeds"),
        dictgen::InsensitiveStr::Ascii("thodised"),
        dictgen::InsensitiveStr::Ascii("thodisedder"),
        dictgen::InsensitiveStr::Ascii("thodiseddest"),
        dictgen::InsensitiveStr::Ascii("thodiseds"),
        dictgen::InsensitiveStr::Ascii("thodising"),
        dictgen::InsensitiveStr::Ascii("thodisinger"),
        dictgen::InsensitiveStr::Ascii("thodisingest"),
        dictgen::InsensitiveStr::Ascii("thodisings"),
        dictgen::InsensitiveStr::Ascii("thodized"),
        dictgen::InsensitiveStr::Ascii("thodizedder"),
        dictgen::InsensitiveStr::Ascii("thodizeddest"),
        dictgen::InsensitiveStr::Ascii("thodizeds"),
        dictgen::InsensitiveStr::Ascii("thodizing"),
        dictgen::InsensitiveStr::Ascii("thodizinger"),
        dictgen::InsensitiveStr::Ascii("thodizingest"),
        dictgen::InsensitiveStr::Ascii("thodizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNMECHANIZE_12567709989894150163)],
        &[(0b10010, &ENTRY_UNMECHANIZED_16721303431448088542)],
        &[(0b10010, &ENTRY_UNMECHANIZES_13574271478828569360)],
        &[(0b10010, &ENTRY_UNMECHANIZING_8319964999572980399)],
        &[(0b01001, &ENTRY_UNMECHANIZE_12567709989894150163)],
        &[(0b01001, &ENTRY_UNMECHANIZED_16721303431448088542)],
        &[(0b01001, &ENTRY_UNMECHANIZES_13574271478828569360)],
        &[(0b01001, &ENTRY_UNMECHANIZING_8319964999572980399)],
        &[(0b11010, &ENTRY_UNMEDIEVAL_18446665201522752648)],
        &[(0b10010, &ENTRY_UNMEDIATIZED_8755314419661725158)],
        &[(0b10010, &ENTRY_UNMEDIATIZEDS_10932726138966957967)],
        &[(0b01001, &ENTRY_UNMEDIATIZED_8755314419661725158)],
        &[(0b01001, &ENTRY_UNMEDIATIZEDS_10932726138966957967)],
        &[(0b00001, &ENTRY_UNMEDIEVAL_18446665201522752648)],
        &[(0b10010, &ENTRY_UNMELODIZED_5604267675766024708)],
        &[(0b01001, &ENTRY_UNMELODIZED_5604267675766024708)],
        &[(0b10010, &ENTRY_UNMEMORIALIZED_3865802921441210140)],
        &[(0b10010, &ENTRY_UNMEMORIALIZEDDER_4759079110106574727)],
        &[(0b10010, &ENTRY_UNMEMORIALIZEDDEST_10631489810683710839)],
        &[(0b10010, &ENTRY_UNMEMORIALIZEDS_7803701197481713742)],
        &[(0b01001, &ENTRY_UNMEMORIALIZED_3865802921441210140)],
        &[(0b01001, &ENTRY_UNMEMORIALIZEDDER_4759079110106574727)],
        &[(0b01001, &ENTRY_UNMEMORIALIZEDDEST_10631489810683710839)],
        &[(0b01001, &ENTRY_UNMEMORIALIZEDS_7803701197481713742)],
        &[(0b10010, &ENTRY_UNMEMORIZED_17008272697746293921)],
        &[(0b01001, &ENTRY_UNMEMORIZED_17008272697746293921)],
        &[(0b10010, &ENTRY_UNMERCERIZED_3875470586449512690)],
        &[(0b10010, &ENTRY_UNMERCERIZEDS_15957558455222000048)],
        &[(0b01001, &ENTRY_UNMERCERIZED_3875470586449512690)],
        &[(0b01001, &ENTRY_UNMERCERIZEDS_15957558455222000048)],
        &[(0b10010, &ENTRY_UNMESMERIZE_16375686298282822286)],
        &[(0b10010, &ENTRY_UNMESMERIZED_17296099928682062139)],
        &[(0b10010, &ENTRY_UNMESMERIZEDDER_6729466480851972942)],
        &[(0b10010, &ENTRY_UNMESMERIZEDDEST_1620171434081064380)],
        &[(0b10010, &ENTRY_UNMESMERIZES_13030574456077520578)],
        &[(0b01001, &ENTRY_UNMESMERIZE_16375686298282822286)],
        &[(0b01001, &ENTRY_UNMESMERIZED_17296099928682062139)],
        &[(0b01001, &ENTRY_UNMESMERIZEDDER_6729466480851972942)],
        &[(0b01001, &ENTRY_UNMESMERIZEDDEST_1620171434081064380)],
        &[(0b01001, &ENTRY_UNMESMERIZES_13030574456077520578)],
        &[(0b00001, &ENTRY_UNMETALIZED_6211291008887157429)],
        &[(0b00001, &ENTRY_UNMETALIZEDS_4575503008268873870)],
        &[(0b10010, &ENTRY_UNMETALIZED_6211291008887157429)],
        &[(0b10010, &ENTRY_UNMETALIZEDS_4575503008268873870)],
        &[(0b01000, &ENTRY_UNMETALIZED_6211291008887157429)],
        &[(0b01000, &ENTRY_UNMETALIZEDS_4575503008268873870)],
        &[(0b10010, &ENTRY_UNMETHODIZED_10946517892898645417)],
        &[(0b10010, &ENTRY_UNMETHODIZEDDER_8100212412642341077)],
        &[(0b10010, &ENTRY_UNMETHODIZEDDEST_3462202797716679669)],
        &[(0b10010, &ENTRY_UNMETHODIZEDS_7986474180166911324)],
        &[(0b10010, &ENTRY_UNMETHODIZING_13344558328835996895)],
        &[(0b10010, &ENTRY_UNMETHODIZINGER_7099500888782377207)],
        &[(0b10010, &ENTRY_UNMETHODIZINGEST_9585135668735652608)],
        &[(0b10010, &ENTRY_UNMETHODIZINGS_12701861300369560867)],
        &[(0b01001, &ENTRY_UNMETHODIZED_10946517892898645417)],
        &[(0b01001, &ENTRY_UNMETHODIZEDDER_8100212412642341077)],
        &[(0b01001, &ENTRY_UNMETHODIZEDDEST_3462202797716679669)],
        &[(0b01001, &ENTRY_UNMETHODIZEDS_7986474180166911324)],
        &[(0b01001, &ENTRY_UNMETHODIZING_13344558328835996895)],
        &[(0b01001, &ENTRY_UNMETHODIZINGER_7099500888782377207)],
        &[(0b01001, &ENTRY_UNMETHODIZINGEST_9585135668735652608)],
        &[(0b01001, &ENTRY_UNMETHODIZINGS_12701861300369560867)],
    ],
    range: 6..=14,
};

static VARS_UNMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNMA_CHILDREN),
    value: None,
};

pub static VARS_UNMA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cadamised"),
        dictgen::InsensitiveStr::Ascii("cadamized"),
        dictgen::InsensitiveStr::Ascii("gnetised"),
        dictgen::InsensitiveStr::Ascii("gnetisedder"),
        dictgen::InsensitiveStr::Ascii("gnetiseddest"),
        dictgen::InsensitiveStr::Ascii("gnetiseds"),
        dictgen::InsensitiveStr::Ascii("gnetized"),
        dictgen::InsensitiveStr::Ascii("gnetizedder"),
        dictgen::InsensitiveStr::Ascii("gnetizeddest"),
        dictgen::InsensitiveStr::Ascii("gnetizeds"),
        dictgen::InsensitiveStr::Ascii("terialised"),
        dictgen::InsensitiveStr::Ascii("terialized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNMACADAMIZED_3275723831952183615)],
        &[(0b01001, &ENTRY_UNMACADAMIZED_3275723831952183615)],
        &[(0b10010, &ENTRY_UNMAGNETIZED_1016024906065652662)],
        &[(0b10010, &ENTRY_UNMAGNETIZEDDER_15710200139655009020)],
        &[(0b10010, &ENTRY_UNMAGNETIZEDDEST_2932179077945017913)],
        &[(0b10010, &ENTRY_UNMAGNETIZEDS_16811876985713273780)],
        &[(0b01001, &ENTRY_UNMAGNETIZED_1016024906065652662)],
        &[(0b01001, &ENTRY_UNMAGNETIZEDDER_15710200139655009020)],
        &[(0b01001, &ENTRY_UNMAGNETIZEDDEST_2932179077945017913)],
        &[(0b01001, &ENTRY_UNMAGNETIZEDS_16811876985713273780)],
        &[(0b10010, &ENTRY_UNMATERIALIZED_6876889534618019929)],
        &[(0b01001, &ENTRY_UNMATERIALIZED_6876889534618019929)],
    ],
    range: 8..=12,
};

static VARS_UNL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNL_CHILDREN),
    value: None,
};

static VARS_UNL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNLA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNLE_NODE),
    None,
    None,
    None,
    Some(&VARS_UNLI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNLO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNLO_CHILDREN),
    value: None,
};

pub static VARS_UNLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("calisable"),
        dictgen::InsensitiveStr::Ascii("calisabler"),
        dictgen::InsensitiveStr::Ascii("calisables"),
        dictgen::InsensitiveStr::Ascii("calisablest"),
        dictgen::InsensitiveStr::Ascii("calise"),
        dictgen::InsensitiveStr::Ascii("calised"),
        dictgen::InsensitiveStr::Ascii("calises"),
        dictgen::InsensitiveStr::Ascii("calising"),
        dictgen::InsensitiveStr::Ascii("calizable"),
        dictgen::InsensitiveStr::Ascii("calizabler"),
        dictgen::InsensitiveStr::Ascii("calizables"),
        dictgen::InsensitiveStr::Ascii("calizablest"),
        dictgen::InsensitiveStr::Ascii("calize"),
        dictgen::InsensitiveStr::Ascii("calized"),
        dictgen::InsensitiveStr::Ascii("calizes"),
        dictgen::InsensitiveStr::Ascii("calizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNLOCALIZABLE_14292436275798738192)],
        &[(0b10010, &ENTRY_UNLOCALIZABLER_7537908645677548744)],
        &[(0b10010, &ENTRY_UNLOCALIZABLES_6890565389055859424)],
        &[(0b10010, &ENTRY_UNLOCALIZABLEST_14079275978309136005)],
        &[(0b10010, &ENTRY_UNLOCALIZE_124944264009925738)],
        &[(0b10010, &ENTRY_UNLOCALIZED_4103084257883656085)],
        &[(0b10010, &ENTRY_UNLOCALIZES_10056596505491890711)],
        &[(0b10010, &ENTRY_UNLOCALIZING_4812710385579738803)],
        &[(0b01001, &ENTRY_UNLOCALIZABLE_14292436275798738192)],
        &[(0b01001, &ENTRY_UNLOCALIZABLER_7537908645677548744)],
        &[(0b01001, &ENTRY_UNLOCALIZABLES_6890565389055859424)],
        &[(0b01001, &ENTRY_UNLOCALIZABLEST_14079275978309136005)],
        &[(0b01001, &ENTRY_UNLOCALIZE_124944264009925738)],
        &[(0b01001, &ENTRY_UNLOCALIZED_4103084257883656085)],
        &[(0b01001, &ENTRY_UNLOCALIZES_10056596505491890711)],
        &[(0b01001, &ENTRY_UNLOCALIZING_4812710385579738803)],
    ],
    range: 6..=11,
};

static VARS_UNLI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNLI_CHILDREN),
    value: None,
};

pub static VARS_UNLI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("beralised"),
        dictgen::InsensitiveStr::Ascii("beralisedder"),
        dictgen::InsensitiveStr::Ascii("beraliseddest"),
        dictgen::InsensitiveStr::Ascii("beralized"),
        dictgen::InsensitiveStr::Ascii("beralizedder"),
        dictgen::InsensitiveStr::Ascii("beralizeddest"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("teralised"),
        dictgen::InsensitiveStr::Ascii("teralized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNLIBERALIZED_3641414538278460652)],
        &[(0b10010, &ENTRY_UNLIBERALIZEDDER_4461656846504146142)],
        &[(0b10010, &ENTRY_UNLIBERALIZEDDEST_14758526200738928936)],
        &[(0b01001, &ENTRY_UNLIBERALIZED_3641414538278460652)],
        &[(0b01001, &ENTRY_UNLIBERALIZEDDER_4461656846504146142)],
        &[(0b01001, &ENTRY_UNLIBERALIZEDDEST_14758526200738928936)],
        &[(0b10010, &ENTRY_UNLIONIZED_5835800076716610222)],
        &[(0b01001, &ENTRY_UNLIONIZED_5835800076716610222)],
        &[(0b10010, &ENTRY_UNLITERALIZED_3082179323060504252)],
        &[(0b01001, &ENTRY_UNLITERALIZED_3082179323060504252)],
    ],
    range: 6..=13,
};

static VARS_UNLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNLE_CHILDREN),
    value: None,
};

pub static VARS_UNLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arnt"),
        dictgen::InsensitiveStr::Ascii("galised"),
        dictgen::InsensitiveStr::Ascii("galisedder"),
        dictgen::InsensitiveStr::Ascii("galiseddest"),
        dictgen::InsensitiveStr::Ascii("galized"),
        dictgen::InsensitiveStr::Ascii("galizedder"),
        dictgen::InsensitiveStr::Ascii("galizeddest"),
        dictgen::InsensitiveStr::Ascii("veled"),
        dictgen::InsensitiveStr::Ascii("veling"),
        dictgen::InsensitiveStr::Ascii("velled"),
        dictgen::InsensitiveStr::Ascii("velling"),
    ],
    values: &[
        &[(0b11010, &ENTRY_UNLEARNED_4424673437597791231)],
        &[(0b10010, &ENTRY_UNLEGALIZED_10345441232305055471)],
        &[(0b10010, &ENTRY_UNLEGALIZEDDER_8012198770985007318)],
        &[(0b10010, &ENTRY_UNLEGALIZEDDEST_17306165656930561184)],
        &[(0b01001, &ENTRY_UNLEGALIZED_10345441232305055471)],
        &[(0b01001, &ENTRY_UNLEGALIZEDDER_8012198770985007318)],
        &[(0b01001, &ENTRY_UNLEGALIZEDDEST_17306165656930561184)],
        &[(0b00001, &ENTRY_UNLEVELED_14811436885559634904)],
        &[(0b00001, &ENTRY_UNLEVELING_3313982499129049944)],
        &[(0b11010, &ENTRY_UNLEVELED_14811436885559634904)],
        &[(0b11010, &ENTRY_UNLEVELING_3313982499129049944)],
    ],
    range: 4..=11,
};

static VARS_UNLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNLA_CHILDREN),
    value: None,
};

pub static VARS_UNLA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("beled"),
        dictgen::InsensitiveStr::Ascii("beledder"),
        dictgen::InsensitiveStr::Ascii("beleddest"),
        dictgen::InsensitiveStr::Ascii("belled"),
        dictgen::InsensitiveStr::Ascii("belledder"),
        dictgen::InsensitiveStr::Ascii("belleddest"),
        dictgen::InsensitiveStr::Ascii("bialise"),
        dictgen::InsensitiveStr::Ascii("bialised"),
        dictgen::InsensitiveStr::Ascii("bialises"),
        dictgen::InsensitiveStr::Ascii("bialising"),
        dictgen::InsensitiveStr::Ascii("bialize"),
        dictgen::InsensitiveStr::Ascii("bialized"),
        dictgen::InsensitiveStr::Ascii("bializes"),
        dictgen::InsensitiveStr::Ascii("bializing"),
        dictgen::InsensitiveStr::Ascii("borable"),
        dictgen::InsensitiveStr::Ascii("borables"),
        dictgen::InsensitiveStr::Ascii("bored"),
        dictgen::InsensitiveStr::Ascii("boredder"),
        dictgen::InsensitiveStr::Ascii("boreddest"),
        dictgen::InsensitiveStr::Ascii("boring"),
        dictgen::InsensitiveStr::Ascii("boringer"),
        dictgen::InsensitiveStr::Ascii("boringest"),
        dictgen::InsensitiveStr::Ascii("borings"),
        dictgen::InsensitiveStr::Ascii("bourable"),
        dictgen::InsensitiveStr::Ascii("bourables"),
        dictgen::InsensitiveStr::Ascii("boured"),
        dictgen::InsensitiveStr::Ascii("bouredder"),
        dictgen::InsensitiveStr::Ascii("boureddest"),
        dictgen::InsensitiveStr::Ascii("bouring"),
        dictgen::InsensitiveStr::Ascii("bouringer"),
        dictgen::InsensitiveStr::Ascii("bouringest"),
        dictgen::InsensitiveStr::Ascii("bourings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNLABELED_5521478301443297379)],
        &[(0b00001, &ENTRY_UNLABELEDDER_14520124038825557406)],
        &[(0b00001, &ENTRY_UNLABELEDDEST_17384647877826400058)],
        &[(0b11010, &ENTRY_UNLABELED_5521478301443297379)],
        &[(0b11010, &ENTRY_UNLABELEDDER_14520124038825557406)],
        &[(0b11010, &ENTRY_UNLABELEDDEST_17384647877826400058)],
        &[(0b10010, &ENTRY_UNLABIALIZE_14700231870563288334)],
        &[(0b10010, &ENTRY_UNLABIALIZED_18161976242006416543)],
        &[(0b10010, &ENTRY_UNLABIALIZES_11090976916776589003)],
        &[(0b10010, &ENTRY_UNLABIALIZING_17998770221957811654)],
        &[(0b01001, &ENTRY_UNLABIALIZE_14700231870563288334)],
        &[(0b01001, &ENTRY_UNLABIALIZED_18161976242006416543)],
        &[(0b01001, &ENTRY_UNLABIALIZES_11090976916776589003)],
        &[(0b01001, &ENTRY_UNLABIALIZING_17998770221957811654)],
        &[(0b00001, &ENTRY_UNLABORABLE_5597257290729843911)],
        &[(0b00001, &ENTRY_UNLABORABLES_8002074775965731933)],
        &[(0b00001, &ENTRY_UNLABORED_1615322569123204547)],
        &[(0b00001, &ENTRY_UNLABOREDDER_12202991864716052732)],
        &[(0b00001, &ENTRY_UNLABOREDDEST_3561720129928496444)],
        &[(0b00001, &ENTRY_UNLABORING_7621181090729553452)],
        &[(0b00001, &ENTRY_UNLABORINGER_17618283927523064423)],
        &[(0b00001, &ENTRY_UNLABORINGEST_11076910916694514810)],
        &[(0b00001, &ENTRY_UNLABORINGS_13595599544117141943)],
        &[(0b11010, &ENTRY_UNLABORABLE_5597257290729843911)],
        &[(0b11010, &ENTRY_UNLABORABLES_8002074775965731933)],
        &[(0b11010, &ENTRY_UNLABORED_1615322569123204547)],
        &[(0b11010, &ENTRY_UNLABOREDDER_12202991864716052732)],
        &[(0b11010, &ENTRY_UNLABOREDDEST_3561720129928496444)],
        &[(0b11010, &ENTRY_UNLABORING_7621181090729553452)],
        &[(0b11010, &ENTRY_UNLABORINGER_17618283927523064423)],
        &[(0b11010, &ENTRY_UNLABORINGEST_11076910916694514810)],
        &[(0b11010, &ENTRY_UNLABORINGS_13595599544117141943)],
    ],
    range: 5..=10,
};

static VARS_UNK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNK_CHILDREN),
    value: None,
};

pub static VARS_UNK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enneled"),
        dictgen::InsensitiveStr::Ascii("enneling"),
        dictgen::InsensitiveStr::Ascii("ennelled"),
        dictgen::InsensitiveStr::Ascii("ennelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNKENNELED_14459883499276528555)],
        &[(0b00001, &ENTRY_UNKENNELING_3079694918155233686)],
        &[(0b11010, &ENTRY_UNKENNELED_14459883499276528555)],
        &[(0b11010, &ENTRY_UNKENNELING_3079694918155233686)],
    ],
    range: 7..=9,
};

static VARS_UNJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNJ_CHILDREN),
    value: None,
};

pub static VARS_UNJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eopardised"),
        dictgen::InsensitiveStr::Ascii("eopardized"),
        dictgen::InsensitiveStr::Ascii("ournalised"),
        dictgen::InsensitiveStr::Ascii("ournalized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNJEOPARDIZED_17486399707788562883)],
        &[(0b01001, &ENTRY_UNJEOPARDIZED_17486399707788562883)],
        &[(0b10010, &ENTRY_UNJOURNALIZED_4436133202537390136)],
        &[(0b01001, &ENTRY_UNJOURNALIZED_4436133202537390136)],
    ],
    range: 10..=10,
};

static VARS_UNI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNI_CHILDREN),
    value: None,
};

static VARS_UNI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_UNIC_NODE),
    Some(&VARS_UNID_NODE),
    None,
    Some(&VARS_UNIF_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNIL_NODE),
    Some(&VARS_UNIM_NODE),
    Some(&VARS_UNIN_NODE),
    Some(&VARS_UNIO_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_UNIT_NODE),
    None,
    Some(&VARS_UNIV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_UNIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIV_CHILDREN),
    value: None,
};

pub static VARS_UNIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ersalisation"),
        dictgen::InsensitiveStr::Ascii("ersalisations"),
        dictgen::InsensitiveStr::Ascii("ersalise"),
        dictgen::InsensitiveStr::Ascii("ersalised"),
        dictgen::InsensitiveStr::Ascii("ersaliser"),
        dictgen::InsensitiveStr::Ascii("ersalisers"),
        dictgen::InsensitiveStr::Ascii("ersalises"),
        dictgen::InsensitiveStr::Ascii("ersalising"),
        dictgen::InsensitiveStr::Ascii("ersalization"),
        dictgen::InsensitiveStr::Ascii("ersalizations"),
        dictgen::InsensitiveStr::Ascii("ersalize"),
        dictgen::InsensitiveStr::Ascii("ersalized"),
        dictgen::InsensitiveStr::Ascii("ersalizer"),
        dictgen::InsensitiveStr::Ascii("ersalizers"),
        dictgen::InsensitiveStr::Ascii("ersalizes"),
        dictgen::InsensitiveStr::Ascii("ersalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNIVERSALIZATION_2454309767089738201)],
        &[(0b10010, &ENTRY_UNIVERSALIZATIONS_13530116854029584990)],
        &[(0b10010, &ENTRY_UNIVERSALIZE_14896798826234728638)],
        &[(0b10010, &ENTRY_UNIVERSALIZED_7596820744757624427)],
        &[(0b10010, &ENTRY_UNIVERSALIZER_3507098281330240508)],
        &[(0b10010, &ENTRY_UNIVERSALIZERS_2548517964365124361)],
        &[(0b10010, &ENTRY_UNIVERSALIZES_7397422123387773820)],
        &[(0b10010, &ENTRY_UNIVERSALIZING_10782273614602618944)],
        &[(0b01001, &ENTRY_UNIVERSALIZATION_2454309767089738201)],
        &[(0b01001, &ENTRY_UNIVERSALIZATIONS_13530116854029584990)],
        &[(0b01001, &ENTRY_UNIVERSALIZE_14896798826234728638)],
        &[(0b01001, &ENTRY_UNIVERSALIZED_7596820744757624427)],
        &[(0b01001, &ENTRY_UNIVERSALIZER_3507098281330240508)],
        &[(0b01001, &ENTRY_UNIVERSALIZERS_2548517964365124361)],
        &[(0b01001, &ENTRY_UNIVERSALIZES_7397422123387773820)],
        &[(0b01001, &ENTRY_UNIVERSALIZING_10782273614602618944)],
    ],
    range: 8..=13,
};

static VARS_UNIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIT_CHILDREN),
    value: None,
};

pub static VARS_UNIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alicised"),
        dictgen::InsensitiveStr::Ascii("alicized"),
        dictgen::InsensitiveStr::Ascii("arianise"),
        dictgen::InsensitiveStr::Ascii("arianises"),
        dictgen::InsensitiveStr::Ascii("arianize"),
        dictgen::InsensitiveStr::Ascii("arianizes"),
        dictgen::InsensitiveStr::Ascii("emised"),
        dictgen::InsensitiveStr::Ascii("emized"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNITALICIZED_17037791464209006878)],
        &[(0b01001, &ENTRY_UNITALICIZED_17037791464209006878)],
        &[(0b10010, &ENTRY_UNITARIANIZE_17273315308284727882)],
        &[(0b10010, &ENTRY_UNITARIANIZES_6993618606081407804)],
        &[(0b01001, &ENTRY_UNITARIANIZE_17273315308284727882)],
        &[(0b01001, &ENTRY_UNITARIANIZES_6993618606081407804)],
        &[(0b10010, &ENTRY_UNITEMIZED_10435569559841782555)],
        &[(0b01001, &ENTRY_UNITEMIZED_10435569559841782555)],
        &[(0b10010, &ENTRY_UNITIZATION_4383385584028471093)],
        &[(0b10010, &ENTRY_UNITIZATIONS_13955434829892541568)],
        &[(0b10010, &ENTRY_UNITIZE_3757352850523028761)],
        &[(0b10010, &ENTRY_UNITIZED_10679179499203160842)],
        &[(0b10010, &ENTRY_UNITIZES_13809626517201188910)],
        &[(0b10010, &ENTRY_UNITIZING_5223811169788144692)],
        &[(0b01001, &ENTRY_UNITIZATION_4383385584028471093)],
        &[(0b01001, &ENTRY_UNITIZATIONS_13955434829892541568)],
        &[(0b01001, &ENTRY_UNITIZE_3757352850523028761)],
        &[(0b01001, &ENTRY_UNITIZED_10679179499203160842)],
        &[(0b01001, &ENTRY_UNITIZES_13809626517201188910)],
        &[(0b01001, &ENTRY_UNITIZING_5223811169788144692)],
    ],
    range: 3..=9,
};

static VARS_UNIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIO_CHILDREN),
    value: None,
};

pub static VARS_UNIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNIONIZATION_2816931840848288400)],
        &[(0b10010, &ENTRY_UNIONIZATIONS_8188645564688971694)],
        &[(0b10010, &ENTRY_UNIONIZE_10414936899999594660)],
        &[(0b10010, &ENTRY_UNIONIZED_4300815435733718278)],
        &[(0b10010, &ENTRY_UNIONIZER_18311427809549346577)],
        &[(0b10010, &ENTRY_UNIONIZERS_4535038362799968844)],
        &[(0b10010, &ENTRY_UNIONIZES_1566009791777584230)],
        &[(0b10010, &ENTRY_UNIONIZING_7690467481138958046)],
        &[(0b01001, &ENTRY_UNIONIZATION_2816931840848288400)],
        &[(0b01001, &ENTRY_UNIONIZATIONS_8188645564688971694)],
        &[(0b01001, &ENTRY_UNIONIZE_10414936899999594660)],
        &[(0b01001, &ENTRY_UNIONIZED_4300815435733718278)],
        &[(0b01001, &ENTRY_UNIONIZER_18311427809549346577)],
        &[(0b01001, &ENTRY_UNIONIZERS_4535038362799968844)],
        &[(0b01001, &ENTRY_UNIONIZES_1566009791777584230)],
        &[(0b01001, &ENTRY_UNIONIZING_7690467481138958046)],
    ],
    range: 4..=9,
};

static VARS_UNIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIN_CHILDREN),
    value: None,
};

pub static VARS_UNIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dividualise"),
        dictgen::InsensitiveStr::Ascii("dividualised"),
        dictgen::InsensitiveStr::Ascii("dividualises"),
        dictgen::InsensitiveStr::Ascii("dividualize"),
        dictgen::InsensitiveStr::Ascii("dividualized"),
        dictgen::InsensitiveStr::Ascii("dividualizes"),
        dictgen::InsensitiveStr::Ascii("dustrialised"),
        dictgen::InsensitiveStr::Ascii("dustrialiseds"),
        dictgen::InsensitiveStr::Ascii("dustrialized"),
        dictgen::InsensitiveStr::Ascii("dustrializeds"),
        dictgen::InsensitiveStr::Ascii("itialisable"),
        dictgen::InsensitiveStr::Ascii("itialised"),
        dictgen::InsensitiveStr::Ascii("itializable"),
        dictgen::InsensitiveStr::Ascii("itialized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNINDIVIDUALIZE_15522862361188070635)],
        &[(0b10010, &ENTRY_UNINDIVIDUALIZED_9978336683560948261)],
        &[(0b10010, &ENTRY_UNINDIVIDUALIZES_9652328537629869880)],
        &[(0b01001, &ENTRY_UNINDIVIDUALIZE_15522862361188070635)],
        &[(0b01001, &ENTRY_UNINDIVIDUALIZED_9978336683560948261)],
        &[(0b01001, &ENTRY_UNINDIVIDUALIZES_9652328537629869880)],
        &[(0b10010, &ENTRY_UNINDUSTRIALIZED_16910106454060086905)],
        &[(0b10010, &ENTRY_UNINDUSTRIALIZEDS_14309123692343325999)],
        &[(0b01001, &ENTRY_UNINDUSTRIALIZED_16910106454060086905)],
        &[(0b01001, &ENTRY_UNINDUSTRIALIZEDS_14309123692343325999)],
        &[(0b10010, &ENTRY_UNINITIALIZABLE_7902667084930987540)],
        &[(0b10010, &ENTRY_UNINITIALIZED_13632684259926269346)],
        &[(0b01001, &ENTRY_UNINITIALIZABLE_7902667084930987540)],
        &[(0b01001, &ENTRY_UNINITIALIZED_13632684259926269346)],
    ],
    range: 9..=13,
};

static VARS_UNIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIM_CHILDREN),
    value: None,
};

pub static VARS_UNIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mortalise"),
        dictgen::InsensitiveStr::Ascii("mortalised"),
        dictgen::InsensitiveStr::Ascii("mortalises"),
        dictgen::InsensitiveStr::Ascii("mortalize"),
        dictgen::InsensitiveStr::Ascii("mortalized"),
        dictgen::InsensitiveStr::Ascii("mortalizes"),
        dictgen::InsensitiveStr::Ascii("munised"),
        dictgen::InsensitiveStr::Ascii("munized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNIMMORTALIZE_2559458109653754603)],
        &[(0b10010, &ENTRY_UNIMMORTALIZED_17439839362062815218)],
        &[(0b10010, &ENTRY_UNIMMORTALIZES_2326945565115161743)],
        &[(0b01001, &ENTRY_UNIMMORTALIZE_2559458109653754603)],
        &[(0b01001, &ENTRY_UNIMMORTALIZED_17439839362062815218)],
        &[(0b01001, &ENTRY_UNIMMORTALIZES_2326945565115161743)],
        &[(0b10010, &ENTRY_UNIMMUNIZED_9723702448629673605)],
        &[(0b01001, &ENTRY_UNIMMUNIZED_9723702448629673605)],
    ],
    range: 7..=10,
};

static VARS_UNIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIL_CHILDREN),
    value: None,
};

pub static VARS_UNIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ateralisation"),
        dictgen::InsensitiveStr::Ascii("ateralisations"),
        dictgen::InsensitiveStr::Ascii("ateralise"),
        dictgen::InsensitiveStr::Ascii("ateralises"),
        dictgen::InsensitiveStr::Ascii("ateralization"),
        dictgen::InsensitiveStr::Ascii("ateralizations"),
        dictgen::InsensitiveStr::Ascii("ateralize"),
        dictgen::InsensitiveStr::Ascii("ateralizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNILATERALIZATION_4288199725380356569)],
        &[(0b10010, &ENTRY_UNILATERALIZATIONS_16769494285291495801)],
        &[(0b10010, &ENTRY_UNILATERALIZE_17363790504930513832)],
        &[(0b10010, &ENTRY_UNILATERALIZES_17232043563681281696)],
        &[(0b01001, &ENTRY_UNILATERALIZATION_4288199725380356569)],
        &[(0b01001, &ENTRY_UNILATERALIZATIONS_16769494285291495801)],
        &[(0b01001, &ENTRY_UNILATERALIZE_17363790504930513832)],
        &[(0b01001, &ENTRY_UNILATERALIZES_17232043563681281696)],
    ],
    range: 9..=14,
};

static VARS_UNIF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIF_CHILDREN),
    value: None,
};

pub static VARS_UNIF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ormisation"),
        dictgen::InsensitiveStr::Ascii("ormisations"),
        dictgen::InsensitiveStr::Ascii("ormise"),
        dictgen::InsensitiveStr::Ascii("ormised"),
        dictgen::InsensitiveStr::Ascii("ormises"),
        dictgen::InsensitiveStr::Ascii("ormising"),
        dictgen::InsensitiveStr::Ascii("ormization"),
        dictgen::InsensitiveStr::Ascii("ormizations"),
        dictgen::InsensitiveStr::Ascii("ormize"),
        dictgen::InsensitiveStr::Ascii("ormized"),
        dictgen::InsensitiveStr::Ascii("ormizes"),
        dictgen::InsensitiveStr::Ascii("ormizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNIFORMIZATION_13391023365117343462)],
        &[(0b10010, &ENTRY_UNIFORMIZATIONS_12665372292806972250)],
        &[(0b10010, &ENTRY_UNIFORMIZE_16664384967794257664)],
        &[(0b10010, &ENTRY_UNIFORMIZED_779131196589099729)],
        &[(0b10010, &ENTRY_UNIFORMIZES_13485704841992152874)],
        &[(0b10010, &ENTRY_UNIFORMIZING_11410783001199896652)],
        &[(0b01001, &ENTRY_UNIFORMIZATION_13391023365117343462)],
        &[(0b01001, &ENTRY_UNIFORMIZATIONS_12665372292806972250)],
        &[(0b01001, &ENTRY_UNIFORMIZE_16664384967794257664)],
        &[(0b01001, &ENTRY_UNIFORMIZED_779131196589099729)],
        &[(0b01001, &ENTRY_UNIFORMIZES_13485704841992152874)],
        &[(0b01001, &ENTRY_UNIFORMIZING_11410783001199896652)],
    ],
    range: 6..=11,
};

static VARS_UNID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNID_CHILDREN),
    value: None,
};

pub static VARS_UNID_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ealised"),
        dictgen::InsensitiveStr::Ascii("ealisedder"),
        dictgen::InsensitiveStr::Ascii("ealiseddest"),
        dictgen::InsensitiveStr::Ascii("ealized"),
        dictgen::InsensitiveStr::Ascii("ealizedder"),
        dictgen::InsensitiveStr::Ascii("ealizeddest"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olisedder"),
        dictgen::InsensitiveStr::Ascii("oliseddest"),
        dictgen::InsensitiveStr::Ascii("oliseds"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizedder"),
        dictgen::InsensitiveStr::Ascii("olizeddest"),
        dictgen::InsensitiveStr::Ascii("olizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNIDEALIZED_18263684325928084797)],
        &[(0b10010, &ENTRY_UNIDEALIZEDDER_9531311480747399110)],
        &[(0b10010, &ENTRY_UNIDEALIZEDDEST_6258316838435840632)],
        &[(0b01001, &ENTRY_UNIDEALIZED_18263684325928084797)],
        &[(0b01001, &ENTRY_UNIDEALIZEDDER_9531311480747399110)],
        &[(0b01001, &ENTRY_UNIDEALIZEDDEST_6258316838435840632)],
        &[(0b10010, &ENTRY_UNIDOLIZED_4988379165333344084)],
        &[(0b10010, &ENTRY_UNIDOLIZEDDER_4579557691614853236)],
        &[(0b10010, &ENTRY_UNIDOLIZEDDEST_16953396813667748727)],
        &[(0b10010, &ENTRY_UNIDOLIZEDS_10372074101999609838)],
        &[(0b01001, &ENTRY_UNIDOLIZED_4988379165333344084)],
        &[(0b01001, &ENTRY_UNIDOLIZEDDER_4579557691614853236)],
        &[(0b01001, &ENTRY_UNIDOLIZEDDEST_16953396813667748727)],
        &[(0b01001, &ENTRY_UNIDOLIZEDS_10372074101999609838)],
    ],
    range: 6..=11,
};

static VARS_UNIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIC_CHILDREN),
    value: None,
};

pub static VARS_UNIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olorate"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("olorous"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("olourate"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olourous"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNICOLOR_7951294365410695890)],
        &[(0b00001, &ENTRY_UNICOLORATE_9925921492993125409)],
        &[(0b00001, &ENTRY_UNICOLORED_13888790365655202389)],
        &[(0b00001, &ENTRY_UNICOLOROUS_15234607672611841882)],
        &[(0b11010, &ENTRY_UNICOLOR_7951294365410695890)],
        &[(0b11010, &ENTRY_UNICOLORATE_9925921492993125409)],
        &[(0b11010, &ENTRY_UNICOLORED_13888790365655202389)],
        &[(0b11010, &ENTRY_UNICOLOROUS_15234607672611841882)],
    ],
    range: 4..=8,
};

static VARS_UNH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNH_CHILDREN),
    value: None,
};

static VARS_UNH_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNHA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNHE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNHO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNHU_NODE),
    None,
    None,
    None,
    Some(&VARS_UNHY_NODE),
    None,
];

static VARS_UNHY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNHY_CHILDREN),
    value: None,
};

pub static VARS_UNHY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("drolysed"),
        dictgen::InsensitiveStr::Ascii("drolyseds"),
        dictgen::InsensitiveStr::Ascii("drolyzed"),
        dictgen::InsensitiveStr::Ascii("drolyzeds"),
        dictgen::InsensitiveStr::Ascii("pnotisable"),
        dictgen::InsensitiveStr::Ascii("pnotisabler"),
        dictgen::InsensitiveStr::Ascii("pnotisables"),
        dictgen::InsensitiveStr::Ascii("pnotisablest"),
        dictgen::InsensitiveStr::Ascii("pnotise"),
        dictgen::InsensitiveStr::Ascii("pnotised"),
        dictgen::InsensitiveStr::Ascii("pnotises"),
        dictgen::InsensitiveStr::Ascii("pnotising"),
        dictgen::InsensitiveStr::Ascii("pnotizable"),
        dictgen::InsensitiveStr::Ascii("pnotizabler"),
        dictgen::InsensitiveStr::Ascii("pnotizables"),
        dictgen::InsensitiveStr::Ascii("pnotizablest"),
        dictgen::InsensitiveStr::Ascii("pnotize"),
        dictgen::InsensitiveStr::Ascii("pnotized"),
        dictgen::InsensitiveStr::Ascii("pnotizes"),
        dictgen::InsensitiveStr::Ascii("pnotizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_UNHYDROLYZED_4176688738875490222)],
        &[(0b11010, &ENTRY_UNHYDROLYZEDS_3654098217580741282)],
        &[(0b00001, &ENTRY_UNHYDROLYZED_4176688738875490222)],
        &[(0b00001, &ENTRY_UNHYDROLYZEDS_3654098217580741282)],
        &[(0b10010, &ENTRY_UNHYPNOTIZABLE_3023984005494874707)],
        &[(0b10010, &ENTRY_UNHYPNOTIZABLER_8305672016674438516)],
        &[(0b10010, &ENTRY_UNHYPNOTIZABLES_6312193248281361674)],
        &[(0b10010, &ENTRY_UNHYPNOTIZABLEST_10447283984210613307)],
        &[(0b10010, &ENTRY_UNHYPNOTIZE_14826256691134863152)],
        &[(0b10010, &ENTRY_UNHYPNOTIZED_743015943914592881)],
        &[(0b10010, &ENTRY_UNHYPNOTIZES_193211741624635662)],
        &[(0b10010, &ENTRY_UNHYPNOTIZING_2116650708300517622)],
        &[(0b01001, &ENTRY_UNHYPNOTIZABLE_3023984005494874707)],
        &[(0b01001, &ENTRY_UNHYPNOTIZABLER_8305672016674438516)],
        &[(0b01001, &ENTRY_UNHYPNOTIZABLES_6312193248281361674)],
        &[(0b01001, &ENTRY_UNHYPNOTIZABLEST_10447283984210613307)],
        &[(0b01001, &ENTRY_UNHYPNOTIZE_14826256691134863152)],
        &[(0b01001, &ENTRY_UNHYPNOTIZED_743015943914592881)],
        &[(0b01001, &ENTRY_UNHYPNOTIZES_193211741624635662)],
        &[(0b01001, &ENTRY_UNHYPNOTIZING_2116650708300517622)],
    ],
    range: 7..=12,
};

static VARS_UNHU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNHU_CHILDREN),
    value: None,
};

pub static VARS_UNHU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("manise"),
        dictgen::InsensitiveStr::Ascii("manised"),
        dictgen::InsensitiveStr::Ascii("manises"),
        dictgen::InsensitiveStr::Ascii("manising"),
        dictgen::InsensitiveStr::Ascii("manize"),
        dictgen::InsensitiveStr::Ascii("manized"),
        dictgen::InsensitiveStr::Ascii("manizes"),
        dictgen::InsensitiveStr::Ascii("manizing"),
        dictgen::InsensitiveStr::Ascii("mored"),
        dictgen::InsensitiveStr::Ascii("moredder"),
        dictgen::InsensitiveStr::Ascii("moreddest"),
        dictgen::InsensitiveStr::Ascii("morous"),
        dictgen::InsensitiveStr::Ascii("morously"),
        dictgen::InsensitiveStr::Ascii("moured"),
        dictgen::InsensitiveStr::Ascii("mouredder"),
        dictgen::InsensitiveStr::Ascii("moureddest"),
        dictgen::InsensitiveStr::Ascii("mourous"),
        dictgen::InsensitiveStr::Ascii("mourously"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNHUMANIZE_9275488574912041634)],
        &[(0b10010, &ENTRY_UNHUMANIZED_11850238111200004906)],
        &[(0b10010, &ENTRY_UNHUMANIZES_438461434554460503)],
        &[(0b10010, &ENTRY_UNHUMANIZING_922703227770676812)],
        &[(0b01001, &ENTRY_UNHUMANIZE_9275488574912041634)],
        &[(0b01001, &ENTRY_UNHUMANIZED_11850238111200004906)],
        &[(0b01001, &ENTRY_UNHUMANIZES_438461434554460503)],
        &[(0b01001, &ENTRY_UNHUMANIZING_922703227770676812)],
        &[(0b00001, &ENTRY_UNHUMORED_9270244412900857495)],
        &[(0b00001, &ENTRY_UNHUMOREDDER_12582156681544655808)],
        &[(0b00001, &ENTRY_UNHUMOREDDEST_3090681874029593777)],
        &[(0b00001, &ENTRY_UNHUMOROUS_15431740540620940624)],
        &[(0b00001, &ENTRY_UNHUMOROUSLY_2997877439653370896)],
        &[(0b11010, &ENTRY_UNHUMORED_9270244412900857495)],
        &[(0b11010, &ENTRY_UNHUMOREDDER_12582156681544655808)],
        &[(0b11010, &ENTRY_UNHUMOREDDEST_3090681874029593777)],
        &[(0b11010, &ENTRY_UNHUMOROUS_15431740540620940624)],
        &[(0b11010, &ENTRY_UNHUMOROUSLY_2997877439653370896)],
    ],
    range: 5..=10,
};

static VARS_UNHO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNHO_CHILDREN),
    value: None,
};

pub static VARS_UNHO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("norable"),
        dictgen::InsensitiveStr::Ascii("norables"),
        dictgen::InsensitiveStr::Ascii("norablies"),
        dictgen::InsensitiveStr::Ascii("norably"),
        dictgen::InsensitiveStr::Ascii("nored"),
        dictgen::InsensitiveStr::Ascii("noredder"),
        dictgen::InsensitiveStr::Ascii("noreddest"),
        dictgen::InsensitiveStr::Ascii("nourable"),
        dictgen::InsensitiveStr::Ascii("nourables"),
        dictgen::InsensitiveStr::Ascii("nourablies"),
        dictgen::InsensitiveStr::Ascii("nourably"),
        dictgen::InsensitiveStr::Ascii("noured"),
        dictgen::InsensitiveStr::Ascii("nouredder"),
        dictgen::InsensitiveStr::Ascii("noureddest"),
        dictgen::InsensitiveStr::Ascii("useled"),
        dictgen::InsensitiveStr::Ascii("uselled"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNHONORABLE_2571371106091765213)],
        &[(0b00001, &ENTRY_UNHONORABLES_2602046928790025604)],
        &[(0b00001, &ENTRY_UNHONORABLIES_8756645705579311445)],
        &[(0b00001, &ENTRY_UNHONORABLY_14594026255233946792)],
        &[(0b00001, &ENTRY_UNHONORED_1763420376323415335)],
        &[(0b00001, &ENTRY_UNHONOREDDER_5145501164984603406)],
        &[(0b00001, &ENTRY_UNHONOREDDEST_253419705093959263)],
        &[(0b11010, &ENTRY_UNHONORABLE_2571371106091765213)],
        &[(0b11010, &ENTRY_UNHONORABLES_2602046928790025604)],
        &[(0b11010, &ENTRY_UNHONORABLIES_8756645705579311445)],
        &[(0b11010, &ENTRY_UNHONORABLY_14594026255233946792)],
        &[(0b11010, &ENTRY_UNHONORED_1763420376323415335)],
        &[(0b11010, &ENTRY_UNHONOREDDER_5145501164984603406)],
        &[(0b11010, &ENTRY_UNHONOREDDEST_253419705093959263)],
        &[(0b00001, &ENTRY_UNHOUSELED_9514624409997890163)],
        &[(0b11010, &ENTRY_UNHOUSELED_9514624409997890163)],
    ],
    range: 5..=10,
};

static VARS_UNHE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNHE_CHILDREN),
    value: None,
};

pub static VARS_UNHE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("roise"),
        dictgen::InsensitiveStr::Ascii("roises"),
        dictgen::InsensitiveStr::Ascii("roize"),
        dictgen::InsensitiveStr::Ascii("roizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNHEROIZE_14719025801623380202)],
        &[(0b10010, &ENTRY_UNHEROIZES_14874152198907028504)],
        &[(0b01001, &ENTRY_UNHEROIZE_14719025801623380202)],
        &[(0b01001, &ENTRY_UNHEROIZES_14874152198907028504)],
    ],
    range: 5..=6,
};

static VARS_UNHA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNHA_CHILDREN),
    value: None,
};

pub static VARS_UNHA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rbor"),
        dictgen::InsensitiveStr::Ascii("rbored"),
        dictgen::InsensitiveStr::Ascii("rbour"),
        dictgen::InsensitiveStr::Ascii("rboured"),
        dictgen::InsensitiveStr::Ascii("rmonise"),
        dictgen::InsensitiveStr::Ascii("rmonised"),
        dictgen::InsensitiveStr::Ascii("rmonises"),
        dictgen::InsensitiveStr::Ascii("rmonising"),
        dictgen::InsensitiveStr::Ascii("rmonize"),
        dictgen::InsensitiveStr::Ascii("rmonized"),
        dictgen::InsensitiveStr::Ascii("rmonizes"),
        dictgen::InsensitiveStr::Ascii("rmonizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNHARBOR_3808891720499086153)],
        &[(0b00001, &ENTRY_UNHARBORED_6775117848685665911)],
        &[(0b11010, &ENTRY_UNHARBOR_3808891720499086153)],
        &[(0b11010, &ENTRY_UNHARBORED_6775117848685665911)],
        &[(0b10010, &ENTRY_UNHARMONIZE_6028907999174872917)],
        &[(0b10010, &ENTRY_UNHARMONIZED_17900579618906076059)],
        &[(0b10010, &ENTRY_UNHARMONIZES_18388139136613077997)],
        &[(0b10010, &ENTRY_UNHARMONIZING_5754608021634090726)],
        &[(0b01001, &ENTRY_UNHARMONIZE_6028907999174872917)],
        &[(0b01001, &ENTRY_UNHARMONIZED_17900579618906076059)],
        &[(0b01001, &ENTRY_UNHARMONIZES_18388139136613077997)],
        &[(0b01001, &ENTRY_UNHARMONIZING_5754608021634090726)],
    ],
    range: 4..=9,
};

static VARS_UNG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNG_CHILDREN),
    value: None,
};

pub static VARS_UNG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alvanised"),
        dictgen::InsensitiveStr::Ascii("alvaniseds"),
        dictgen::InsensitiveStr::Ascii("alvanized"),
        dictgen::InsensitiveStr::Ascii("alvanizeds"),
        dictgen::InsensitiveStr::Ascii("elatinisable"),
        dictgen::InsensitiveStr::Ascii("elatinisables"),
        dictgen::InsensitiveStr::Ascii("elatinised"),
        dictgen::InsensitiveStr::Ascii("elatiniseds"),
        dictgen::InsensitiveStr::Ascii("elatinizable"),
        dictgen::InsensitiveStr::Ascii("elatinizables"),
        dictgen::InsensitiveStr::Ascii("elatinized"),
        dictgen::InsensitiveStr::Ascii("elatinizeds"),
        dictgen::InsensitiveStr::Ascii("eneralised"),
        dictgen::InsensitiveStr::Ascii("eneralisedder"),
        dictgen::InsensitiveStr::Ascii("eneraliseddest"),
        dictgen::InsensitiveStr::Ascii("eneralising"),
        dictgen::InsensitiveStr::Ascii("eneralized"),
        dictgen::InsensitiveStr::Ascii("eneralizedder"),
        dictgen::InsensitiveStr::Ascii("eneralizeddest"),
        dictgen::InsensitiveStr::Ascii("eneralizing"),
        dictgen::InsensitiveStr::Ascii("entilise"),
        dictgen::InsensitiveStr::Ascii("entilises"),
        dictgen::InsensitiveStr::Ascii("entilize"),
        dictgen::InsensitiveStr::Ascii("entilizes"),
        dictgen::InsensitiveStr::Ascii("entlemanise"),
        dictgen::InsensitiveStr::Ascii("entlemanises"),
        dictgen::InsensitiveStr::Ascii("entlemanize"),
        dictgen::InsensitiveStr::Ascii("entlemanizes"),
        dictgen::InsensitiveStr::Ascii("lamourous"),
        dictgen::InsensitiveStr::Ascii("lamourously"),
        dictgen::InsensitiveStr::Ascii("ospelised"),
        dictgen::InsensitiveStr::Ascii("ospeliseds"),
        dictgen::InsensitiveStr::Ascii("ospelized"),
        dictgen::InsensitiveStr::Ascii("ospelizeds"),
        dictgen::InsensitiveStr::Ascii("raphitised"),
        dictgen::InsensitiveStr::Ascii("raphitiseds"),
        dictgen::InsensitiveStr::Ascii("raphitized"),
        dictgen::InsensitiveStr::Ascii("raphitizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNGALVANIZED_8045809390486265382)],
        &[(0b10010, &ENTRY_UNGALVANIZEDS_8383279107759676747)],
        &[(0b01001, &ENTRY_UNGALVANIZED_8045809390486265382)],
        &[(0b01001, &ENTRY_UNGALVANIZEDS_8383279107759676747)],
        &[(0b10010, &ENTRY_UNGELATINIZABLE_14072020582199354747)],
        &[(0b10010, &ENTRY_UNGELATINIZABLES_6386667123269773422)],
        &[(0b10010, &ENTRY_UNGELATINIZED_10373227658204020685)],
        &[(0b10010, &ENTRY_UNGELATINIZEDS_11671694804301099117)],
        &[(0b01001, &ENTRY_UNGELATINIZABLE_14072020582199354747)],
        &[(0b01001, &ENTRY_UNGELATINIZABLES_6386667123269773422)],
        &[(0b01001, &ENTRY_UNGELATINIZED_10373227658204020685)],
        &[(0b01001, &ENTRY_UNGELATINIZEDS_11671694804301099117)],
        &[(0b10010, &ENTRY_UNGENERALIZED_14143149454140309313)],
        &[(0b10010, &ENTRY_UNGENERALIZEDDER_11296864575965360245)],
        &[(0b10010, &ENTRY_UNGENERALIZEDDEST_10829752942426843396)],
        &[(0b10010, &ENTRY_UNGENERALIZING_1839845840030566278)],
        &[(0b01001, &ENTRY_UNGENERALIZED_14143149454140309313)],
        &[(0b01001, &ENTRY_UNGENERALIZEDDER_11296864575965360245)],
        &[(0b01001, &ENTRY_UNGENERALIZEDDEST_10829752942426843396)],
        &[(0b01001, &ENTRY_UNGENERALIZING_1839845840030566278)],
        &[(0b10010, &ENTRY_UNGENTILIZE_1723028300980426250)],
        &[(0b10010, &ENTRY_UNGENTILIZES_4989241345981017864)],
        &[(0b01001, &ENTRY_UNGENTILIZE_1723028300980426250)],
        &[(0b01001, &ENTRY_UNGENTILIZES_4989241345981017864)],
        &[(0b10010, &ENTRY_UNGENTLEMANIZE_18186282254227733891)],
        &[(0b10010, &ENTRY_UNGENTLEMANIZES_14225357015905456046)],
        &[(0b01001, &ENTRY_UNGENTLEMANIZE_18186282254227733891)],
        &[(0b01001, &ENTRY_UNGENTLEMANIZES_14225357015905456046)],
        &[(0b11010, &ENTRY_UNGLAMOROUS_17159152581421977091)],
        &[(0b11010, &ENTRY_UNGLAMOROUSLY_13876889208379675435)],
        &[(0b10010, &ENTRY_UNGOSPELIZED_7104427828857537577)],
        &[(0b10010, &ENTRY_UNGOSPELIZEDS_9818924277430364811)],
        &[(0b01001, &ENTRY_UNGOSPELIZED_7104427828857537577)],
        &[(0b01001, &ENTRY_UNGOSPELIZEDS_9818924277430364811)],
        &[(0b10010, &ENTRY_UNGRAPHITIZED_11151981879102463629)],
        &[(0b10010, &ENTRY_UNGRAPHITIZEDS_8135878505595004848)],
        &[(0b01001, &ENTRY_UNGRAPHITIZED_11151981879102463629)],
        &[(0b01001, &ENTRY_UNGRAPHITIZEDS_8135878505595004848)],
    ],
    range: 8..=14,
};

static VARS_UNF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNF_CHILDREN),
    value: None,
};

static VARS_UNF_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNFA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNFE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNFL_NODE),
    None,
    None,
    Some(&VARS_UNFO_NODE),
    None,
    None,
    Some(&VARS_UNFR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNFR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNFR_CHILDREN),
    value: None,
};

pub static VARS_UNFR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aternised"),
        dictgen::InsensitiveStr::Ascii("aternising"),
        dictgen::InsensitiveStr::Ascii("aternisings"),
        dictgen::InsensitiveStr::Ascii("aternized"),
        dictgen::InsensitiveStr::Ascii("aternizing"),
        dictgen::InsensitiveStr::Ascii("aternizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNFRATERNIZED_16285087131580785609)],
        &[(0b10010, &ENTRY_UNFRATERNIZING_4612503372516640985)],
        &[(0b10010, &ENTRY_UNFRATERNIZINGS_12977443623394508497)],
        &[(0b01001, &ENTRY_UNFRATERNIZED_16285087131580785609)],
        &[(0b01001, &ENTRY_UNFRATERNIZING_4612503372516640985)],
        &[(0b01001, &ENTRY_UNFRATERNIZINGS_12977443623394508497)],
    ],
    range: 9..=11,
};

static VARS_UNFO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNFO_CHILDREN),
    value: None,
};

pub static VARS_UNFO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rmalised"),
        dictgen::InsensitiveStr::Ascii("rmalisedder"),
        dictgen::InsensitiveStr::Ascii("rmaliseddest"),
        dictgen::InsensitiveStr::Ascii("rmalized"),
        dictgen::InsensitiveStr::Ascii("rmalizedder"),
        dictgen::InsensitiveStr::Ascii("rmalizeddest"),
        dictgen::InsensitiveStr::Ascii("ssilised"),
        dictgen::InsensitiveStr::Ascii("ssilisedder"),
        dictgen::InsensitiveStr::Ascii("ssiliseddest"),
        dictgen::InsensitiveStr::Ascii("ssiliseds"),
        dictgen::InsensitiveStr::Ascii("ssilized"),
        dictgen::InsensitiveStr::Ascii("ssilizedder"),
        dictgen::InsensitiveStr::Ascii("ssilizeddest"),
        dictgen::InsensitiveStr::Ascii("ssilizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNFORMALIZED_7899916370079121441)],
        &[(0b10010, &ENTRY_UNFORMALIZEDDER_14165770520440361407)],
        &[(0b10010, &ENTRY_UNFORMALIZEDDEST_17208946494472238886)],
        &[(0b01001, &ENTRY_UNFORMALIZED_7899916370079121441)],
        &[(0b01001, &ENTRY_UNFORMALIZEDDER_14165770520440361407)],
        &[(0b01001, &ENTRY_UNFORMALIZEDDEST_17208946494472238886)],
        &[(0b10010, &ENTRY_UNFOSSILIZED_13346837272047276618)],
        &[(0b10010, &ENTRY_UNFOSSILIZEDDER_14434730201241982353)],
        &[(0b10010, &ENTRY_UNFOSSILIZEDDEST_13071168100410233552)],
        &[(0b10010, &ENTRY_UNFOSSILIZEDS_16301703807130406696)],
        &[(0b01001, &ENTRY_UNFOSSILIZED_13346837272047276618)],
        &[(0b01001, &ENTRY_UNFOSSILIZEDDER_14434730201241982353)],
        &[(0b01001, &ENTRY_UNFOSSILIZEDDEST_13071168100410233552)],
        &[(0b01001, &ENTRY_UNFOSSILIZEDS_16301703807130406696)],
    ],
    range: 8..=12,
};

static VARS_UNFL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNFL_CHILDREN),
    value: None,
};

pub static VARS_UNFL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avored"),
        dictgen::InsensitiveStr::Ascii("avoredder"),
        dictgen::InsensitiveStr::Ascii("avoreddest"),
        dictgen::InsensitiveStr::Ascii("avorous"),
        dictgen::InsensitiveStr::Ascii("avoured"),
        dictgen::InsensitiveStr::Ascii("avouredder"),
        dictgen::InsensitiveStr::Ascii("avoureddest"),
        dictgen::InsensitiveStr::Ascii("avourous"),
    ],
    values: &[
        &[(0b11001, &ENTRY_UNFLAVORED_9672896276378072278)],
        &[(0b11001, &ENTRY_UNFLAVOREDDER_8175850200918329116)],
        &[(0b11001, &ENTRY_UNFLAVOREDDEST_5088848224529312235)],
        &[(0b00001, &ENTRY_UNFLAVOROUS_15116595106089847138)],
        &[(0b11010, &ENTRY_UNFLAVORED_9672896276378072278)],
        &[(0b11010, &ENTRY_UNFLAVOREDDER_8175850200918329116)],
        &[(0b11010, &ENTRY_UNFLAVOREDDEST_5088848224529312235)],
        &[(0b11010, &ENTRY_UNFLAVOROUS_15116595106089847138)],
    ],
    range: 6..=11,
};

static VARS_UNFE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNFE_CHILDREN),
    value: None,
};

pub static VARS_UNFE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("minise"),
        dictgen::InsensitiveStr::Ascii("minised"),
        dictgen::InsensitiveStr::Ascii("minising"),
        dictgen::InsensitiveStr::Ascii("minize"),
        dictgen::InsensitiveStr::Ascii("minized"),
        dictgen::InsensitiveStr::Ascii("minizing"),
        dictgen::InsensitiveStr::Ascii("rtilisable"),
        dictgen::InsensitiveStr::Ascii("rtilisabler"),
        dictgen::InsensitiveStr::Ascii("rtilisables"),
        dictgen::InsensitiveStr::Ascii("rtilisablest"),
        dictgen::InsensitiveStr::Ascii("rtilised"),
        dictgen::InsensitiveStr::Ascii("rtilisedder"),
        dictgen::InsensitiveStr::Ascii("rtiliseddest"),
        dictgen::InsensitiveStr::Ascii("rtilising"),
        dictgen::InsensitiveStr::Ascii("rtilizable"),
        dictgen::InsensitiveStr::Ascii("rtilizabler"),
        dictgen::InsensitiveStr::Ascii("rtilizables"),
        dictgen::InsensitiveStr::Ascii("rtilizablest"),
        dictgen::InsensitiveStr::Ascii("rtilized"),
        dictgen::InsensitiveStr::Ascii("rtilizedder"),
        dictgen::InsensitiveStr::Ascii("rtilizeddest"),
        dictgen::InsensitiveStr::Ascii("rtilizing"),
        dictgen::InsensitiveStr::Ascii("udalise"),
        dictgen::InsensitiveStr::Ascii("udalised"),
        dictgen::InsensitiveStr::Ascii("udalises"),
        dictgen::InsensitiveStr::Ascii("udalising"),
        dictgen::InsensitiveStr::Ascii("udalize"),
        dictgen::InsensitiveStr::Ascii("udalized"),
        dictgen::InsensitiveStr::Ascii("udalizes"),
        dictgen::InsensitiveStr::Ascii("udalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNFEMINIZE_2001388748715757690)],
        &[(0b10010, &ENTRY_UNFEMINIZED_2220407209529111709)],
        &[(0b10010, &ENTRY_UNFEMINIZING_10216822851481831958)],
        &[(0b01001, &ENTRY_UNFEMINIZE_2001388748715757690)],
        &[(0b01001, &ENTRY_UNFEMINIZED_2220407209529111709)],
        &[(0b01001, &ENTRY_UNFEMINIZING_10216822851481831958)],
        &[(0b10010, &ENTRY_UNFERTILIZABLE_6992270943983134373)],
        &[(0b10010, &ENTRY_UNFERTILIZABLER_6121110660744572333)],
        &[(0b10010, &ENTRY_UNFERTILIZABLES_2130405461712866243)],
        &[(0b10010, &ENTRY_UNFERTILIZABLEST_11998703244940643531)],
        &[(0b10010, &ENTRY_UNFERTILIZED_1896012193898147315)],
        &[(0b10010, &ENTRY_UNFERTILIZEDDER_3962795259989687011)],
        &[(0b10010, &ENTRY_UNFERTILIZEDDEST_16794644706411544184)],
        &[(0b10010, &ENTRY_UNFERTILIZING_12441724634999163602)],
        &[(0b01001, &ENTRY_UNFERTILIZABLE_6992270943983134373)],
        &[(0b01001, &ENTRY_UNFERTILIZABLER_6121110660744572333)],
        &[(0b01001, &ENTRY_UNFERTILIZABLES_2130405461712866243)],
        &[(0b01001, &ENTRY_UNFERTILIZABLEST_11998703244940643531)],
        &[(0b01001, &ENTRY_UNFERTILIZED_1896012193898147315)],
        &[(0b01001, &ENTRY_UNFERTILIZEDDER_3962795259989687011)],
        &[(0b01001, &ENTRY_UNFERTILIZEDDEST_16794644706411544184)],
        &[(0b01001, &ENTRY_UNFERTILIZING_12441724634999163602)],
        &[(0b10010, &ENTRY_UNFEUDALIZE_4948744929952762262)],
        &[(0b10010, &ENTRY_UNFEUDALIZED_4489675212740440309)],
        &[(0b10010, &ENTRY_UNFEUDALIZES_7666754629620871610)],
        &[(0b10010, &ENTRY_UNFEUDALIZING_6652813473340699512)],
        &[(0b01001, &ENTRY_UNFEUDALIZE_4948744929952762262)],
        &[(0b01001, &ENTRY_UNFEUDALIZED_4489675212740440309)],
        &[(0b01001, &ENTRY_UNFEUDALIZES_7666754629620871610)],
        &[(0b01001, &ENTRY_UNFEUDALIZING_6652813473340699512)],
    ],
    range: 6..=12,
};

static VARS_UNFA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNFA_CHILDREN),
    value: None,
};

pub static VARS_UNFA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("miliarised"),
        dictgen::InsensitiveStr::Ascii("miliarisedder"),
        dictgen::InsensitiveStr::Ascii("miliariseddest"),
        dictgen::InsensitiveStr::Ascii("miliarized"),
        dictgen::InsensitiveStr::Ascii("miliarizedder"),
        dictgen::InsensitiveStr::Ascii("miliarizeddest"),
        dictgen::InsensitiveStr::Ascii("vorable"),
        dictgen::InsensitiveStr::Ascii("vorableness"),
        dictgen::InsensitiveStr::Ascii("vorablenesses"),
        dictgen::InsensitiveStr::Ascii("vorabler"),
        dictgen::InsensitiveStr::Ascii("vorables"),
        dictgen::InsensitiveStr::Ascii("vorablest"),
        dictgen::InsensitiveStr::Ascii("vorablier"),
        dictgen::InsensitiveStr::Ascii("vorabliest"),
        dictgen::InsensitiveStr::Ascii("vorably"),
        dictgen::InsensitiveStr::Ascii("vored"),
        dictgen::InsensitiveStr::Ascii("voredder"),
        dictgen::InsensitiveStr::Ascii("voreddest"),
        dictgen::InsensitiveStr::Ascii("voring"),
        dictgen::InsensitiveStr::Ascii("voringer"),
        dictgen::InsensitiveStr::Ascii("voringest"),
        dictgen::InsensitiveStr::Ascii("vorings"),
        dictgen::InsensitiveStr::Ascii("vorite"),
        dictgen::InsensitiveStr::Ascii("voriter"),
        dictgen::InsensitiveStr::Ascii("vorites"),
        dictgen::InsensitiveStr::Ascii("voritest"),
        dictgen::InsensitiveStr::Ascii("vourable"),
        dictgen::InsensitiveStr::Ascii("vourableness"),
        dictgen::InsensitiveStr::Ascii("vourablenesses"),
        dictgen::InsensitiveStr::Ascii("vourabler"),
        dictgen::InsensitiveStr::Ascii("vourables"),
        dictgen::InsensitiveStr::Ascii("vourablest"),
        dictgen::InsensitiveStr::Ascii("vourablier"),
        dictgen::InsensitiveStr::Ascii("vourabliest"),
        dictgen::InsensitiveStr::Ascii("vourably"),
        dictgen::InsensitiveStr::Ascii("voured"),
        dictgen::InsensitiveStr::Ascii("vouredder"),
        dictgen::InsensitiveStr::Ascii("voureddest"),
        dictgen::InsensitiveStr::Ascii("vouring"),
        dictgen::InsensitiveStr::Ascii("vouringer"),
        dictgen::InsensitiveStr::Ascii("vouringest"),
        dictgen::InsensitiveStr::Ascii("vourings"),
        dictgen::InsensitiveStr::Ascii("vourite"),
        dictgen::InsensitiveStr::Ascii("vouriter"),
        dictgen::InsensitiveStr::Ascii("vourites"),
        dictgen::InsensitiveStr::Ascii("vouritest"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNFAMILIARIZED_3461949634289269826)],
        &[(0b10010, &ENTRY_UNFAMILIARIZEDDER_14155937485679466752)],
        &[(0b10010, &ENTRY_UNFAMILIARIZEDDEST_1917999470235328318)],
        &[(0b01001, &ENTRY_UNFAMILIARIZED_3461949634289269826)],
        &[(0b01001, &ENTRY_UNFAMILIARIZEDDER_14155937485679466752)],
        &[(0b01001, &ENTRY_UNFAMILIARIZEDDEST_1917999470235328318)],
        &[(0b11001, &ENTRY_UNFAVORABLE_5650317643174313946)],
        &[(0b11001, &ENTRY_UNFAVORABLENESS_9419895507281118929)],
        &[(0b11001, &ENTRY_UNFAVORABLENESSES_7937279763475314531)],
        &[(0b11001, &ENTRY_UNFAVORABLER_8407653781350191045)],
        &[(0b11001, &ENTRY_UNFAVORABLES_245237680247907199)],
        &[(0b11001, &ENTRY_UNFAVORABLEST_8329180226725391402)],
        &[(0b11001, &ENTRY_UNFAVORABLIER_5445832020764674982)],
        &[(0b11001, &ENTRY_UNFAVORABLIEST_9135988438022295109)],
        &[(0b11001, &ENTRY_UNFAVORABLY_4995649989227121664)],
        &[(0b11001, &ENTRY_UNFAVORED_4073522488222730170)],
        &[(0b11001, &ENTRY_UNFAVOREDDER_1591015547238508735)],
        &[(0b11001, &ENTRY_UNFAVOREDDEST_2194563377250381555)],
        &[(0b11001, &ENTRY_UNFAVORING_5915402494320502167)],
        &[(0b11001, &ENTRY_UNFAVORINGER_8115927317700614456)],
        &[(0b11001, &ENTRY_UNFAVORINGEST_18384809876281860545)],
        &[(0b11001, &ENTRY_UNFAVORINGS_821556787073286206)],
        &[(0b11001, &ENTRY_UNFAVORITE_9839169349258021237)],
        &[(0b11001, &ENTRY_UNFAVORITER_13011370405101578377)],
        &[(0b11001, &ENTRY_UNFAVORITES_16626569901250523880)],
        &[(0b11001, &ENTRY_UNFAVORITEST_10894783312557521667)],
        &[(0b11010, &ENTRY_UNFAVORABLE_5650317643174313946)],
        &[(0b11010, &ENTRY_UNFAVORABLENESS_9419895507281118929)],
        &[(0b11010, &ENTRY_UNFAVORABLENESSES_7937279763475314531)],
        &[(0b11010, &ENTRY_UNFAVORABLER_8407653781350191045)],
        &[(0b11010, &ENTRY_UNFAVORABLES_245237680247907199)],
        &[(0b11010, &ENTRY_UNFAVORABLEST_8329180226725391402)],
        &[(0b11010, &ENTRY_UNFAVORABLIER_5445832020764674982)],
        &[(0b11010, &ENTRY_UNFAVORABLIEST_9135988438022295109)],
        &[(0b11010, &ENTRY_UNFAVORABLY_4995649989227121664)],
        &[(0b11010, &ENTRY_UNFAVORED_4073522488222730170)],
        &[(0b11010, &ENTRY_UNFAVOREDDER_1591015547238508735)],
        &[(0b11010, &ENTRY_UNFAVOREDDEST_2194563377250381555)],
        &[(0b11010, &ENTRY_UNFAVORING_5915402494320502167)],
        &[(0b11010, &ENTRY_UNFAVORINGER_8115927317700614456)],
        &[(0b11010, &ENTRY_UNFAVORINGEST_18384809876281860545)],
        &[(0b11010, &ENTRY_UNFAVORINGS_821556787073286206)],
        &[(0b11010, &ENTRY_UNFAVORITE_9839169349258021237)],
        &[(0b11010, &ENTRY_UNFAVORITER_13011370405101578377)],
        &[(0b11010, &ENTRY_UNFAVORITES_16626569901250523880)],
        &[(0b11010, &ENTRY_UNFAVORITEST_10894783312557521667)],
    ],
    range: 5..=14,
};

static VARS_UNE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNE_CHILDREN),
    value: None,
};

pub static VARS_UNE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("conomising"),
        dictgen::InsensitiveStr::Ascii("conomizing"),
        dictgen::InsensitiveStr::Ascii("namored"),
        dictgen::InsensitiveStr::Ascii("namoredder"),
        dictgen::InsensitiveStr::Ascii("namoreddest"),
        dictgen::InsensitiveStr::Ascii("namoreds"),
        dictgen::InsensitiveStr::Ascii("namoured"),
        dictgen::InsensitiveStr::Ascii("namouredder"),
        dictgen::InsensitiveStr::Ascii("namoureddest"),
        dictgen::InsensitiveStr::Ascii("namoureds"),
        dictgen::InsensitiveStr::Ascii("ndeavored"),
        dictgen::InsensitiveStr::Ascii("ndeavoured"),
        dictgen::InsensitiveStr::Ascii("nergised"),
        dictgen::InsensitiveStr::Ascii("nergiseds"),
        dictgen::InsensitiveStr::Ascii("nergized"),
        dictgen::InsensitiveStr::Ascii("nergizeds"),
        dictgen::InsensitiveStr::Ascii("pitomised"),
        dictgen::InsensitiveStr::Ascii("pitomisedder"),
        dictgen::InsensitiveStr::Ascii("pitomiseddest"),
        dictgen::InsensitiveStr::Ascii("pitomized"),
        dictgen::InsensitiveStr::Ascii("pitomizedder"),
        dictgen::InsensitiveStr::Ascii("pitomizeddest"),
        dictgen::InsensitiveStr::Ascii("qualed"),
        dictgen::InsensitiveStr::Ascii("qualedder"),
        dictgen::InsensitiveStr::Ascii("qualeddest"),
        dictgen::InsensitiveStr::Ascii("qualise"),
        dictgen::InsensitiveStr::Ascii("qualised"),
        dictgen::InsensitiveStr::Ascii("qualises"),
        dictgen::InsensitiveStr::Ascii("qualising"),
        dictgen::InsensitiveStr::Ascii("qualize"),
        dictgen::InsensitiveStr::Ascii("qualized"),
        dictgen::InsensitiveStr::Ascii("qualizes"),
        dictgen::InsensitiveStr::Ascii("qualizing"),
        dictgen::InsensitiveStr::Ascii("qualled"),
        dictgen::InsensitiveStr::Ascii("qualledder"),
        dictgen::InsensitiveStr::Ascii("qualleddest"),
        dictgen::InsensitiveStr::Ascii("ulogised"),
        dictgen::InsensitiveStr::Ascii("ulogisedder"),
        dictgen::InsensitiveStr::Ascii("ulogiseddest"),
        dictgen::InsensitiveStr::Ascii("ulogiseds"),
        dictgen::InsensitiveStr::Ascii("ulogized"),
        dictgen::InsensitiveStr::Ascii("ulogizedder"),
        dictgen::InsensitiveStr::Ascii("ulogizeddest"),
        dictgen::InsensitiveStr::Ascii("ulogizeds"),
        dictgen::InsensitiveStr::Ascii("vangelised"),
        dictgen::InsensitiveStr::Ascii("vangelisedder"),
        dictgen::InsensitiveStr::Ascii("vangeliseddest"),
        dictgen::InsensitiveStr::Ascii("vangeliseds"),
        dictgen::InsensitiveStr::Ascii("vangelized"),
        dictgen::InsensitiveStr::Ascii("vangelizedder"),
        dictgen::InsensitiveStr::Ascii("vangelizeddest"),
        dictgen::InsensitiveStr::Ascii("vangelizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNECONOMIZING_15361850876984202426)],
        &[(0b01001, &ENTRY_UNECONOMIZING_15361850876984202426)],
        &[(0b00001, &ENTRY_UNENAMORED_10334414449150181515)],
        &[(0b00001, &ENTRY_UNENAMOREDDER_15030893414945898832)],
        &[(0b00001, &ENTRY_UNENAMOREDDEST_4443009802859750012)],
        &[(0b00001, &ENTRY_UNENAMOREDS_2048092433213968436)],
        &[(0b11010, &ENTRY_UNENAMORED_10334414449150181515)],
        &[(0b11010, &ENTRY_UNENAMOREDDER_15030893414945898832)],
        &[(0b11010, &ENTRY_UNENAMOREDDEST_4443009802859750012)],
        &[(0b11010, &ENTRY_UNENAMOREDS_2048092433213968436)],
        &[(0b00001, &ENTRY_UNENDEAVORED_7088517032114848)],
        &[(0b11010, &ENTRY_UNENDEAVORED_7088517032114848)],
        &[(0b10010, &ENTRY_UNENERGIZED_6824210473919222731)],
        &[(0b10010, &ENTRY_UNENERGIZEDS_13766204943868625189)],
        &[(0b01001, &ENTRY_UNENERGIZED_6824210473919222731)],
        &[(0b01001, &ENTRY_UNENERGIZEDS_13766204943868625189)],
        &[(0b10010, &ENTRY_UNEPITOMIZED_12749922881696348309)],
        &[(0b10010, &ENTRY_UNEPITOMIZEDDER_11044100971858801429)],
        &[(0b10010, &ENTRY_UNEPITOMIZEDDEST_13090266195761403470)],
        &[(0b01001, &ENTRY_UNEPITOMIZED_12749922881696348309)],
        &[(0b01001, &ENTRY_UNEPITOMIZEDDER_11044100971858801429)],
        &[(0b01001, &ENTRY_UNEPITOMIZEDDEST_13090266195761403470)],
        &[(0b00001, &ENTRY_UNEQUALED_13151580965074494682)],
        &[(0b00001, &ENTRY_UNEQUALEDDER_6427424448868113114)],
        &[(0b00001, &ENTRY_UNEQUALEDDEST_2906178077931186884)],
        &[(0b10010, &ENTRY_UNEQUALIZE_1864493647225706635)],
        &[(0b10010, &ENTRY_UNEQUALIZED_1264478642545746533)],
        &[(0b10010, &ENTRY_UNEQUALIZES_4019346570786096058)],
        &[(0b10010, &ENTRY_UNEQUALIZING_4434056561745779801)],
        &[(0b01001, &ENTRY_UNEQUALIZE_1864493647225706635)],
        &[(0b01001, &ENTRY_UNEQUALIZED_1264478642545746533)],
        &[(0b01001, &ENTRY_UNEQUALIZES_4019346570786096058)],
        &[(0b01001, &ENTRY_UNEQUALIZING_4434056561745779801)],
        &[(0b11010, &ENTRY_UNEQUALED_13151580965074494682)],
        &[(0b11010, &ENTRY_UNEQUALEDDER_6427424448868113114)],
        &[(0b11010, &ENTRY_UNEQUALEDDEST_2906178077931186884)],
        &[(0b10010, &ENTRY_UNEULOGIZED_15906086694931473085)],
        &[(0b10010, &ENTRY_UNEULOGIZEDDER_14436657900787507056)],
        &[(0b10010, &ENTRY_UNEULOGIZEDDEST_12757263395641675477)],
        &[(0b10010, &ENTRY_UNEULOGIZEDS_8420268768630297949)],
        &[(0b01001, &ENTRY_UNEULOGIZED_15906086694931473085)],
        &[(0b01001, &ENTRY_UNEULOGIZEDDER_14436657900787507056)],
        &[(0b01001, &ENTRY_UNEULOGIZEDDEST_12757263395641675477)],
        &[(0b01001, &ENTRY_UNEULOGIZEDS_8420268768630297949)],
        &[(0b10010, &ENTRY_UNEVANGELIZED_493364703036041093)],
        &[(0b10010, &ENTRY_UNEVANGELIZEDDER_8418942558979715181)],
        &[(0b10010, &ENTRY_UNEVANGELIZEDDEST_16823940955538972844)],
        &[(0b10010, &ENTRY_UNEVANGELIZEDS_11394973428109629288)],
        &[(0b01001, &ENTRY_UNEVANGELIZED_493364703036041093)],
        &[(0b01001, &ENTRY_UNEVANGELIZEDDER_8418942558979715181)],
        &[(0b01001, &ENTRY_UNEVANGELIZEDDEST_16823940955538972844)],
        &[(0b01001, &ENTRY_UNEVANGELIZEDS_11394973428109629288)],
    ],
    range: 6..=14,
};

static VARS_UND_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UND_CHILDREN),
    value: None,
};

static VARS_UND_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_UNDE_NODE),
    None,
    None,
    None,
    Some(&VARS_UNDI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNDR_NODE),
    None,
    None,
    Some(&VARS_UNDU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNDU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDU_CHILDREN),
    value: None,
};

pub static VARS_UNDU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDUALIZE_14512061026250797714)],
        &[(0b10010, &ENTRY_UNDUALIZES_907900132788100323)],
        &[(0b01001, &ENTRY_UNDUALIZE_14512061026250797714)],
        &[(0b01001, &ENTRY_UNDUALIZES_907900132788100323)],
    ],
    range: 5..=6,
};

static VARS_UNDR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDR_CHILDREN),
    value: None,
};

pub static VARS_UNDR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("amatisable"),
        dictgen::InsensitiveStr::Ascii("amatisabler"),
        dictgen::InsensitiveStr::Ascii("amatisables"),
        dictgen::InsensitiveStr::Ascii("amatisablest"),
        dictgen::InsensitiveStr::Ascii("amatised"),
        dictgen::InsensitiveStr::Ascii("amatiseds"),
        dictgen::InsensitiveStr::Ascii("amatizable"),
        dictgen::InsensitiveStr::Ascii("amatizabler"),
        dictgen::InsensitiveStr::Ascii("amatizables"),
        dictgen::InsensitiveStr::Ascii("amatizablest"),
        dictgen::InsensitiveStr::Ascii("amatized"),
        dictgen::InsensitiveStr::Ascii("amatizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDRAMATIZABLE_858223802227706690)],
        &[(0b10010, &ENTRY_UNDRAMATIZABLER_13792948696025531595)],
        &[(0b10010, &ENTRY_UNDRAMATIZABLES_13405611959481771902)],
        &[(0b10010, &ENTRY_UNDRAMATIZABLEST_16859389726173129688)],
        &[(0b10010, &ENTRY_UNDRAMATIZED_15106387989278045439)],
        &[(0b10010, &ENTRY_UNDRAMATIZEDS_8874745974154709414)],
        &[(0b01001, &ENTRY_UNDRAMATIZABLE_858223802227706690)],
        &[(0b01001, &ENTRY_UNDRAMATIZABLER_13792948696025531595)],
        &[(0b01001, &ENTRY_UNDRAMATIZABLES_13405611959481771902)],
        &[(0b01001, &ENTRY_UNDRAMATIZABLEST_16859389726173129688)],
        &[(0b01001, &ENTRY_UNDRAMATIZED_15106387989278045439)],
        &[(0b01001, &ENTRY_UNDRAMATIZEDS_8874745974154709414)],
    ],
    range: 8..=12,
};

static VARS_UNDI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDI_CHILDREN),
    value: None,
};

pub static VARS_UNDI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alysed"),
        dictgen::InsensitiveStr::Ascii("alyseds"),
        dictgen::InsensitiveStr::Ascii("alyzed"),
        dictgen::InsensitiveStr::Ascii("alyzeds"),
        dictgen::InsensitiveStr::Ascii("phthongise"),
        dictgen::InsensitiveStr::Ascii("phthongises"),
        dictgen::InsensitiveStr::Ascii("phthongize"),
        dictgen::InsensitiveStr::Ascii("phthongizes"),
        dictgen::InsensitiveStr::Ascii("scolored"),
        dictgen::InsensitiveStr::Ascii("scoloredder"),
        dictgen::InsensitiveStr::Ascii("scoloreddest"),
        dictgen::InsensitiveStr::Ascii("scoloreds"),
        dictgen::InsensitiveStr::Ascii("scoloured"),
        dictgen::InsensitiveStr::Ascii("scolouredder"),
        dictgen::InsensitiveStr::Ascii("scoloureddest"),
        dictgen::InsensitiveStr::Ascii("scoloureds"),
        dictgen::InsensitiveStr::Ascii("shonored"),
        dictgen::InsensitiveStr::Ascii("shonoured"),
        dictgen::InsensitiveStr::Ascii("sorganised"),
        dictgen::InsensitiveStr::Ascii("sorganized"),
    ],
    values: &[
        &[(0b11010, &ENTRY_UNDIALYZED_6937122698553980061)],
        &[(0b11010, &ENTRY_UNDIALYZEDS_8300878326723839717)],
        &[(0b00001, &ENTRY_UNDIALYZED_6937122698553980061)],
        &[(0b00001, &ENTRY_UNDIALYZEDS_8300878326723839717)],
        &[(0b10010, &ENTRY_UNDIPHTHONGIZE_3039948312517507404)],
        &[(0b10010, &ENTRY_UNDIPHTHONGIZES_1596685277229183988)],
        &[(0b01001, &ENTRY_UNDIPHTHONGIZE_3039948312517507404)],
        &[(0b01001, &ENTRY_UNDIPHTHONGIZES_1596685277229183988)],
        &[(0b00001, &ENTRY_UNDISCOLORED_11284105783683995277)],
        &[(0b00001, &ENTRY_UNDISCOLOREDDER_9889756595104883661)],
        &[(0b00001, &ENTRY_UNDISCOLOREDDEST_17082256163046268738)],
        &[(0b00001, &ENTRY_UNDISCOLOREDS_3407916046171759215)],
        &[(0b11010, &ENTRY_UNDISCOLORED_11284105783683995277)],
        &[(0b11010, &ENTRY_UNDISCOLOREDDER_9889756595104883661)],
        &[(0b11010, &ENTRY_UNDISCOLOREDDEST_17082256163046268738)],
        &[(0b11010, &ENTRY_UNDISCOLOREDS_3407916046171759215)],
        &[(0b00001, &ENTRY_UNDISHONORED_9663612534816223685)],
        &[(0b11010, &ENTRY_UNDISHONORED_9663612534816223685)],
        &[(0b10010, &ENTRY_UNDISORGANIZED_6929340290183050050)],
        &[(0b01001, &ENTRY_UNDISORGANIZED_6929340290183050050)],
    ],
    range: 6..=13,
};

static VARS_UNDE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNDE_CHILDREN),
    value: None,
};

static VARS_UNDE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNDEF_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNDEM_NODE),
    Some(&VARS_UNDEN_NODE),
    None,
    None,
    None,
    Some(&VARS_UNDER_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNDER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNDER_CHILDREN),
    value: None,
};

static VARS_UNDER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_UNDERC_NODE),
    None,
    Some(&VARS_UNDERE_NODE),
    None,
    Some(&VARS_UNDERG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_UNDERL_NODE),
    None,
    None,
    Some(&VARS_UNDERO_NODE),
    Some(&VARS_UNDERP_NODE),
    None,
    Some(&VARS_UNDERR_NODE),
    Some(&VARS_UNDERS_NODE),
    None,
    Some(&VARS_UNDERU_NODE),
    Some(&VARS_UNDERV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_UNDERV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERV_CHILDREN),
    value: None,
};

pub static VARS_UNDERV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("italised"),
        dictgen::InsensitiveStr::Ascii("italiseds"),
        dictgen::InsensitiveStr::Ascii("italized"),
        dictgen::InsensitiveStr::Ascii("italizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDERVITALIZED_5414632877340114792)],
        &[(0b10010, &ENTRY_UNDERVITALIZEDS_6753695904801318252)],
        &[(0b01001, &ENTRY_UNDERVITALIZED_5414632877340114792)],
        &[(0b01001, &ENTRY_UNDERVITALIZEDS_6753695904801318252)],
    ],
    range: 8..=9,
};

static VARS_UNDERU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERU_CHILDREN),
    value: None,
};

pub static VARS_UNDERU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tilisation"),
        dictgen::InsensitiveStr::Ascii("tilisations"),
        dictgen::InsensitiveStr::Ascii("tilise"),
        dictgen::InsensitiveStr::Ascii("tilised"),
        dictgen::InsensitiveStr::Ascii("tilises"),
        dictgen::InsensitiveStr::Ascii("tilising"),
        dictgen::InsensitiveStr::Ascii("tilization"),
        dictgen::InsensitiveStr::Ascii("tilizations"),
        dictgen::InsensitiveStr::Ascii("tilize"),
        dictgen::InsensitiveStr::Ascii("tilized"),
        dictgen::InsensitiveStr::Ascii("tilizes"),
        dictgen::InsensitiveStr::Ascii("tilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDERUTILIZATION_14694691541150582602)],
        &[(0b10010, &ENTRY_UNDERUTILIZATIONS_16994081773856805411)],
        &[(0b10010, &ENTRY_UNDERUTILIZE_12788386196891414227)],
        &[(0b10010, &ENTRY_UNDERUTILIZED_11374623631374378006)],
        &[(0b10010, &ENTRY_UNDERUTILIZES_10200345077765075455)],
        &[(0b10010, &ENTRY_UNDERUTILIZING_8716553292659107585)],
        &[(0b01001, &ENTRY_UNDERUTILIZATION_14694691541150582602)],
        &[(0b01001, &ENTRY_UNDERUTILIZATIONS_16994081773856805411)],
        &[(0b01001, &ENTRY_UNDERUTILIZE_12788386196891414227)],
        &[(0b01001, &ENTRY_UNDERUTILIZED_11374623631374378006)],
        &[(0b01001, &ENTRY_UNDERUTILIZES_10200345077765075455)],
        &[(0b01001, &ENTRY_UNDERUTILIZING_8716553292659107585)],
    ],
    range: 6..=11,
};

static VARS_UNDERS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERS_CHILDREN),
    value: None,
};

pub static VARS_UNDERS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avior"),
        dictgen::InsensitiveStr::Ascii("aviors"),
        dictgen::InsensitiveStr::Ascii("aviour"),
        dictgen::InsensitiveStr::Ascii("aviours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNDERSAVIOR_2090602886568177317)],
        &[(0b00001, &ENTRY_UNDERSAVIORS_7688724448035832319)],
        &[(0b11010, &ENTRY_UNDERSAVIOR_2090602886568177317)],
        &[(0b11010, &ENTRY_UNDERSAVIORS_7688724448035832319)],
    ],
    range: 5..=7,
};

static VARS_UNDERR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERR_CHILDREN),
    value: None,
};

pub static VARS_UNDERR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ealise"),
        dictgen::InsensitiveStr::Ascii("ealised"),
        dictgen::InsensitiveStr::Ascii("ealises"),
        dictgen::InsensitiveStr::Ascii("ealising"),
        dictgen::InsensitiveStr::Ascii("ealize"),
        dictgen::InsensitiveStr::Ascii("ealized"),
        dictgen::InsensitiveStr::Ascii("ealizes"),
        dictgen::InsensitiveStr::Ascii("ealizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDERREALIZE_17524145276470925370)],
        &[(0b10010, &ENTRY_UNDERREALIZED_4300059467226466630)],
        &[(0b10010, &ENTRY_UNDERREALIZES_16394967831846757976)],
        &[(0b10010, &ENTRY_UNDERREALIZING_6376345855147929055)],
        &[(0b01001, &ENTRY_UNDERREALIZE_17524145276470925370)],
        &[(0b01001, &ENTRY_UNDERREALIZED_4300059467226466630)],
        &[(0b01001, &ENTRY_UNDERREALIZES_16394967831846757976)],
        &[(0b01001, &ENTRY_UNDERREALIZING_6376345855147929055)],
    ],
    range: 6..=8,
};

static VARS_UNDERP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERP_CHILDREN),
    value: None,
};

pub static VARS_UNDERP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDERPRIZE_14018313629368366509)],
        &[(0b10010, &ENTRY_UNDERPRIZED_8679591291804814785)],
        &[(0b10010, &ENTRY_UNDERPRIZES_17322055758636776705)],
        &[(0b10010, &ENTRY_UNDERPRIZING_14871696714578944018)],
        &[(0b01001, &ENTRY_UNDERPRIZE_14018313629368366509)],
        &[(0b01001, &ENTRY_UNDERPRIZED_8679591291804814785)],
        &[(0b01001, &ENTRY_UNDERPRIZES_17322055758636776705)],
        &[(0b01001, &ENTRY_UNDERPRIZING_14871696714578944018)],
    ],
    range: 4..=6,
};

static VARS_UNDERO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERO_CHILDREN),
    value: None,
};

pub static VARS_UNDERO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("xidise"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidises"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidize"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizes"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDERORGANIZATION_10009598596379538989)],
        &[(0b10010, &ENTRY_UNDERORGANIZATIONS_12286569977525174410)],
        &[(0b01001, &ENTRY_UNDERORGANIZATION_10009598596379538989)],
        &[(0b01001, &ENTRY_UNDERORGANIZATIONS_12286569977525174410)],
        &[(0b10010, &ENTRY_UNDEROXIDIZE_6035673128957984405)],
        &[(0b10010, &ENTRY_UNDEROXIDIZED_2770429837622229926)],
        &[(0b10010, &ENTRY_UNDEROXIDIZES_14772434272924509932)],
        &[(0b10010, &ENTRY_UNDEROXIDIZING_5388968909302695001)],
        &[(0b01001, &ENTRY_UNDEROXIDIZE_6035673128957984405)],
        &[(0b01001, &ENTRY_UNDEROXIDIZED_2770429837622229926)],
        &[(0b01001, &ENTRY_UNDEROXIDIZES_14772434272924509932)],
        &[(0b01001, &ENTRY_UNDEROXIDIZING_5388968909302695001)],
    ],
    range: 6..=12,
};

static VARS_UNDERL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERL_CHILDREN),
    value: None,
};

pub static VARS_UNDERL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aborer"),
        dictgen::InsensitiveStr::Ascii("aborers"),
        dictgen::InsensitiveStr::Ascii("abourer"),
        dictgen::InsensitiveStr::Ascii("abourers"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNDERLABORER_11220879972499550950)],
        &[(0b00001, &ENTRY_UNDERLABORERS_17760031799064124243)],
        &[(0b11010, &ENTRY_UNDERLABORER_11220879972499550950)],
        &[(0b11010, &ENTRY_UNDERLABORERS_17760031799064124243)],
    ],
    range: 6..=8,
};

static VARS_UNDERG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERG_CHILDREN),
    value: None,
};

pub static VARS_UNDERG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oer"),
        dictgen::InsensitiveStr::Ascii("ore"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNDERGOER_3088049738904644403)],
        &[(0b11010, &ENTRY_UNDERGOER_3088049738904644403)],
    ],
    range: 3..=3,
};

static VARS_UNDERE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERE_CHILDREN),
    value: None,
};

pub static VARS_UNDERE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasised"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasising"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasized"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
        dictgen::InsensitiveStr::Ascii("mphasizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDEREMPHASIZE_113262683283266999)],
        &[(0b10010, &ENTRY_UNDEREMPHASIZED_16225182233832818906)],
        &[(0b10010, &ENTRY_UNDEREMPHASIZES_15383330958221639486)],
        &[(0b10010, &ENTRY_UNDEREMPHASIZING_8500735646633380499)],
        &[(0b01001, &ENTRY_UNDEREMPHASIZE_113262683283266999)],
        &[(0b01001, &ENTRY_UNDEREMPHASIZED_16225182233832818906)],
        &[(0b01001, &ENTRY_UNDEREMPHASIZES_15383330958221639486)],
        &[(0b01001, &ENTRY_UNDEREMPHASIZING_8500735646633380499)],
    ],
    range: 8..=10,
};

static VARS_UNDERC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERC_CHILDREN),
    value: None,
};

pub static VARS_UNDERC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("apitalisation"),
        dictgen::InsensitiveStr::Ascii("apitalisations"),
        dictgen::InsensitiveStr::Ascii("apitalise"),
        dictgen::InsensitiveStr::Ascii("apitalised"),
        dictgen::InsensitiveStr::Ascii("apitalises"),
        dictgen::InsensitiveStr::Ascii("apitalising"),
        dictgen::InsensitiveStr::Ascii("apitalization"),
        dictgen::InsensitiveStr::Ascii("apitalizations"),
        dictgen::InsensitiveStr::Ascii("apitalize"),
        dictgen::InsensitiveStr::Ascii("apitalized"),
        dictgen::InsensitiveStr::Ascii("apitalizes"),
        dictgen::InsensitiveStr::Ascii("apitalizing"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("oloring"),
        dictgen::InsensitiveStr::Ascii("olorings"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olouring"),
        dictgen::InsensitiveStr::Ascii("olourings"),
        dictgen::InsensitiveStr::Ascii("olours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDERCAPITALIZATION_8460263852916102032)],
        &[(0b10010, &ENTRY_UNDERCAPITALIZATIONS_15413528605787492170)],
        &[(0b10010, &ENTRY_UNDERCAPITALIZE_18099217300236175519)],
        &[(0b10010, &ENTRY_UNDERCAPITALIZED_14438718972230406682)],
        &[(0b10010, &ENTRY_UNDERCAPITALIZES_14774979177213178352)],
        &[(0b10010, &ENTRY_UNDERCAPITALIZING_13409262727547250690)],
        &[(0b01001, &ENTRY_UNDERCAPITALIZATION_8460263852916102032)],
        &[(0b01001, &ENTRY_UNDERCAPITALIZATIONS_15413528605787492170)],
        &[(0b01001, &ENTRY_UNDERCAPITALIZE_18099217300236175519)],
        &[(0b01001, &ENTRY_UNDERCAPITALIZED_14438718972230406682)],
        &[(0b01001, &ENTRY_UNDERCAPITALIZES_14774979177213178352)],
        &[(0b01001, &ENTRY_UNDERCAPITALIZING_13409262727547250690)],
        &[(0b00001, &ENTRY_UNDERCOLOR_1027999095899511970)],
        &[(0b00001, &ENTRY_UNDERCOLORED_8574607569897245160)],
        &[(0b00001, &ENTRY_UNDERCOLORING_1186796377206381483)],
        &[(0b00001, &ENTRY_UNDERCOLORINGS_8932749399301090002)],
        &[(0b00001, &ENTRY_UNDERCOLORS_13161743376725576886)],
        &[(0b11010, &ENTRY_UNDERCOLOR_1027999095899511970)],
        &[(0b11010, &ENTRY_UNDERCOLORED_8574607569897245160)],
        &[(0b11010, &ENTRY_UNDERCOLORING_1186796377206381483)],
        &[(0b11010, &ENTRY_UNDERCOLORINGS_8932749399301090002)],
        &[(0b11010, &ENTRY_UNDERCOLORS_13161743376725576886)],
    ],
    range: 4..=14,
};

static VARS_UNDEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDEN_CHILDREN),
    value: None,
};

pub static VARS_UNDEN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ominationalise"),
        dictgen::InsensitiveStr::Ascii("ominationalises"),
        dictgen::InsensitiveStr::Ascii("ominationalize"),
        dictgen::InsensitiveStr::Ascii("ominationalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDENOMINATIONALIZE_3072439986846169544)],
        &[(0b10010, &ENTRY_UNDENOMINATIONALIZES_17484696335581871493)],
        &[(0b01001, &ENTRY_UNDENOMINATIONALIZE_3072439986846169544)],
        &[(0b01001, &ENTRY_UNDENOMINATIONALIZES_17484696335581871493)],
    ],
    range: 14..=15,
};

static VARS_UNDEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDEM_CHILDREN),
    value: None,
};

pub static VARS_UNDEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agnetisable"),
        dictgen::InsensitiveStr::Ascii("agnetisables"),
        dictgen::InsensitiveStr::Ascii("agnetizable"),
        dictgen::InsensitiveStr::Ascii("agnetizables"),
        dictgen::InsensitiveStr::Ascii("ocratisation"),
        dictgen::InsensitiveStr::Ascii("ocratise"),
        dictgen::InsensitiveStr::Ascii("ocratised"),
        dictgen::InsensitiveStr::Ascii("ocratises"),
        dictgen::InsensitiveStr::Ascii("ocratising"),
        dictgen::InsensitiveStr::Ascii("ocratization"),
        dictgen::InsensitiveStr::Ascii("ocratize"),
        dictgen::InsensitiveStr::Ascii("ocratized"),
        dictgen::InsensitiveStr::Ascii("ocratizes"),
        dictgen::InsensitiveStr::Ascii("ocratizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDEMAGNETIZABLE_9221760784135532695)],
        &[(0b10010, &ENTRY_UNDEMAGNETIZABLES_14205057507765717155)],
        &[(0b01001, &ENTRY_UNDEMAGNETIZABLE_9221760784135532695)],
        &[(0b01001, &ENTRY_UNDEMAGNETIZABLES_14205057507765717155)],
        &[(0b10010, &ENTRY_UNDEMOCRATIZATION_3147337646074026875)],
        &[(0b10010, &ENTRY_UNDEMOCRATIZE_5865450725521639549)],
        &[(0b10010, &ENTRY_UNDEMOCRATIZED_12454645037887379138)],
        &[(0b10010, &ENTRY_UNDEMOCRATIZES_7922361479467248866)],
        &[(0b10010, &ENTRY_UNDEMOCRATIZING_3638836602448829184)],
        &[(0b01001, &ENTRY_UNDEMOCRATIZATION_3147337646074026875)],
        &[(0b01001, &ENTRY_UNDEMOCRATIZE_5865450725521639549)],
        &[(0b01001, &ENTRY_UNDEMOCRATIZED_12454645037887379138)],
        &[(0b01001, &ENTRY_UNDEMOCRATIZES_7922361479467248866)],
        &[(0b01001, &ENTRY_UNDEMOCRATIZING_3638836602448829184)],
    ],
    range: 8..=12,
};

static VARS_UNDEF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDEF_CHILDREN),
    value: None,
};

pub static VARS_UNDEF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ence"),
        dictgen::InsensitiveStr::Ascii("ences"),
        dictgen::InsensitiveStr::Ascii("ense"),
        dictgen::InsensitiveStr::Ascii("enses"),
    ],
    values: &[
        &[(0b11010, &ENTRY_UNDEFENSE_17516267082874975159)],
        &[(0b11010, &ENTRY_UNDEFENSES_6841055240379604765)],
        &[(0b00001, &ENTRY_UNDEFENSE_17516267082874975159)],
        &[(0b00001, &ENTRY_UNDEFENSES_6841055240379604765)],
    ],
    range: 4..=5,
};

static VARS_UNC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNC_CHILDREN),
    value: None,
};

static VARS_UNC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNCA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNCE_NODE),
    None,
    None,
    Some(&VARS_UNCH_NODE),
    Some(&VARS_UNCI_NODE),
    None,
    None,
    Some(&VARS_UNCL_NODE),
    None,
    None,
    Some(&VARS_UNCO_NODE),
    None,
    None,
    Some(&VARS_UNCR_NODE),
    None,
    None,
    Some(&VARS_UNCU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNCU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCU_CHILDREN),
    value: None,
};

pub static VARS_UNCU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rricularised"),
        dictgen::InsensitiveStr::Ascii("rriculariseds"),
        dictgen::InsensitiveStr::Ascii("rricularized"),
        dictgen::InsensitiveStr::Ascii("rricularizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCURRICULARIZED_3643432582785827881)],
        &[(0b10010, &ENTRY_UNCURRICULARIZEDS_9305723134204411782)],
        &[(0b01001, &ENTRY_UNCURRICULARIZED_3643432582785827881)],
        &[(0b01001, &ENTRY_UNCURRICULARIZEDS_9305723134204411782)],
    ],
    range: 12..=13,
};

static VARS_UNCR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCR_CHILDREN),
    value: None,
};

pub static VARS_UNCR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iticisable"),
        dictgen::InsensitiveStr::Ascii("iticisabler"),
        dictgen::InsensitiveStr::Ascii("iticisables"),
        dictgen::InsensitiveStr::Ascii("iticisablest"),
        dictgen::InsensitiveStr::Ascii("iticisably"),
        dictgen::InsensitiveStr::Ascii("iticised"),
        dictgen::InsensitiveStr::Ascii("iticising"),
        dictgen::InsensitiveStr::Ascii("iticisingly"),
        dictgen::InsensitiveStr::Ascii("iticizable"),
        dictgen::InsensitiveStr::Ascii("iticizabler"),
        dictgen::InsensitiveStr::Ascii("iticizables"),
        dictgen::InsensitiveStr::Ascii("iticizablest"),
        dictgen::InsensitiveStr::Ascii("iticizably"),
        dictgen::InsensitiveStr::Ascii("iticized"),
        dictgen::InsensitiveStr::Ascii("iticizing"),
        dictgen::InsensitiveStr::Ascii("iticizingly"),
        dictgen::InsensitiveStr::Ascii("ystallisabilities"),
        dictgen::InsensitiveStr::Ascii("ystallisability"),
        dictgen::InsensitiveStr::Ascii("ystallisable"),
        dictgen::InsensitiveStr::Ascii("ystallisabler"),
        dictgen::InsensitiveStr::Ascii("ystallisables"),
        dictgen::InsensitiveStr::Ascii("ystallisablest"),
        dictgen::InsensitiveStr::Ascii("ystallised"),
        dictgen::InsensitiveStr::Ascii("ystallizabilities"),
        dictgen::InsensitiveStr::Ascii("ystallizability"),
        dictgen::InsensitiveStr::Ascii("ystallizable"),
        dictgen::InsensitiveStr::Ascii("ystallizabler"),
        dictgen::InsensitiveStr::Ascii("ystallizables"),
        dictgen::InsensitiveStr::Ascii("ystallizablest"),
        dictgen::InsensitiveStr::Ascii("ystallized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCRITICIZABLE_5988050938990112074)],
        &[(0b10010, &ENTRY_UNCRITICIZABLER_17254678315858537421)],
        &[(0b10010, &ENTRY_UNCRITICIZABLES_1774501697582082300)],
        &[(0b10010, &ENTRY_UNCRITICIZABLEST_12461946144251713170)],
        &[(0b10010, &ENTRY_UNCRITICIZABLY_15048536753630299272)],
        &[(0b10010, &ENTRY_UNCRITICIZED_278671110568990284)],
        &[(0b10010, &ENTRY_UNCRITICIZING_16870256726875456150)],
        &[(0b10010, &ENTRY_UNCRITICIZINGLY_3491212942449906984)],
        &[(0b01001, &ENTRY_UNCRITICIZABLE_5988050938990112074)],
        &[(0b01001, &ENTRY_UNCRITICIZABLER_17254678315858537421)],
        &[(0b01001, &ENTRY_UNCRITICIZABLES_1774501697582082300)],
        &[(0b01001, &ENTRY_UNCRITICIZABLEST_12461946144251713170)],
        &[(0b01001, &ENTRY_UNCRITICIZABLY_15048536753630299272)],
        &[(0b01001, &ENTRY_UNCRITICIZED_278671110568990284)],
        &[(0b01001, &ENTRY_UNCRITICIZING_16870256726875456150)],
        &[(0b01001, &ENTRY_UNCRITICIZINGLY_3491212942449906984)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZABILITIES_3244595590594411060)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZABILITY_11201467748814217685)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZABLE_8887681379037019389)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZABLER_3580664972194989519)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZABLES_9036384453456811297)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZABLEST_12020400672527082645)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZED_17631452865900152396)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZABILITIES_3244595590594411060)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZABILITY_11201467748814217685)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZABLE_8887681379037019389)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZABLER_3580664972194989519)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZABLES_9036384453456811297)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZABLEST_12020400672527082645)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZED_17631452865900152396)],
    ],
    range: 8..=17,
};

static VARS_UNCO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCO_CHILDREN),
    value: None,
};

pub static VARS_UNCO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gnisable"),
        dictgen::InsensitiveStr::Ascii("gnizable"),
        dictgen::InsensitiveStr::Ascii("lonise"),
        dictgen::InsensitiveStr::Ascii("lonised"),
        dictgen::InsensitiveStr::Ascii("lonises"),
        dictgen::InsensitiveStr::Ascii("lonising"),
        dictgen::InsensitiveStr::Ascii("lonize"),
        dictgen::InsensitiveStr::Ascii("lonized"),
        dictgen::InsensitiveStr::Ascii("lonizes"),
        dictgen::InsensitiveStr::Ascii("lonizing"),
        dictgen::InsensitiveStr::Ascii("lorable"),
        dictgen::InsensitiveStr::Ascii("lorabler"),
        dictgen::InsensitiveStr::Ascii("lorables"),
        dictgen::InsensitiveStr::Ascii("lorablest"),
        dictgen::InsensitiveStr::Ascii("lorablier"),
        dictgen::InsensitiveStr::Ascii("lorablies"),
        dictgen::InsensitiveStr::Ascii("lorabliest"),
        dictgen::InsensitiveStr::Ascii("lorably"),
        dictgen::InsensitiveStr::Ascii("lored"),
        dictgen::InsensitiveStr::Ascii("loredder"),
        dictgen::InsensitiveStr::Ascii("loreddest"),
        dictgen::InsensitiveStr::Ascii("loredlier"),
        dictgen::InsensitiveStr::Ascii("loredliest"),
        dictgen::InsensitiveStr::Ascii("loredly"),
        dictgen::InsensitiveStr::Ascii("loredness"),
        dictgen::InsensitiveStr::Ascii("lorednesses"),
        dictgen::InsensitiveStr::Ascii("loreds"),
        dictgen::InsensitiveStr::Ascii("lourable"),
        dictgen::InsensitiveStr::Ascii("lourabler"),
        dictgen::InsensitiveStr::Ascii("lourables"),
        dictgen::InsensitiveStr::Ascii("lourablest"),
        dictgen::InsensitiveStr::Ascii("lourablier"),
        dictgen::InsensitiveStr::Ascii("lourablies"),
        dictgen::InsensitiveStr::Ascii("lourabliest"),
        dictgen::InsensitiveStr::Ascii("lourably"),
        dictgen::InsensitiveStr::Ascii("loured"),
        dictgen::InsensitiveStr::Ascii("louredder"),
        dictgen::InsensitiveStr::Ascii("loureddest"),
        dictgen::InsensitiveStr::Ascii("louredlier"),
        dictgen::InsensitiveStr::Ascii("louredliest"),
        dictgen::InsensitiveStr::Ascii("louredly"),
        dictgen::InsensitiveStr::Ascii("louredness"),
        dictgen::InsensitiveStr::Ascii("lourednesses"),
        dictgen::InsensitiveStr::Ascii("loureds"),
        dictgen::InsensitiveStr::Ascii("ncerted"),
        dictgen::InsensitiveStr::Ascii("ncreted"),
        dictgen::InsensitiveStr::Ascii("nventionalise"),
        dictgen::InsensitiveStr::Ascii("nventionalises"),
        dictgen::InsensitiveStr::Ascii("nventionalize"),
        dictgen::InsensitiveStr::Ascii("nventionalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCOGNIZABLE_14160489995106158884)],
        &[(0b01001, &ENTRY_UNCOGNIZABLE_14160489995106158884)],
        &[(0b10010, &ENTRY_UNCOLONIZE_16324652224120342941)],
        &[(0b10010, &ENTRY_UNCOLONIZED_793048061484833307)],
        &[(0b10010, &ENTRY_UNCOLONIZES_8621451791889938290)],
        &[(0b10010, &ENTRY_UNCOLONIZING_8737005258550725588)],
        &[(0b01001, &ENTRY_UNCOLONIZE_16324652224120342941)],
        &[(0b01001, &ENTRY_UNCOLONIZED_793048061484833307)],
        &[(0b01001, &ENTRY_UNCOLONIZES_8621451791889938290)],
        &[(0b01001, &ENTRY_UNCOLONIZING_8737005258550725588)],
        &[(0b00001, &ENTRY_UNCOLORABLE_4153423912585578276)],
        &[(0b00001, &ENTRY_UNCOLORABLER_17292750876767117491)],
        &[(0b00001, &ENTRY_UNCOLORABLES_8980215200270465076)],
        &[(0b00001, &ENTRY_UNCOLORABLEST_7092331381236258847)],
        &[(0b00001, &ENTRY_UNCOLORABLIER_18378872394705595553)],
        &[(0b00001, &ENTRY_UNCOLORABLIES_13195393864962337812)],
        &[(0b00001, &ENTRY_UNCOLORABLIEST_7529954443419348402)],
        &[(0b00001, &ENTRY_UNCOLORABLY_3052740007631630517)],
        &[(0b11001, &ENTRY_UNCOLORED_5376239934140006972)],
        &[(0b11001, &ENTRY_UNCOLOREDDER_7581046306117193660)],
        &[(0b11001, &ENTRY_UNCOLOREDDEST_2266252169475963598)],
        &[(0b00001, &ENTRY_UNCOLOREDLIER_1339679359641458561)],
        &[(0b00001, &ENTRY_UNCOLOREDLIEST_1084139031301806119)],
        &[(0b00001, &ENTRY_UNCOLOREDLY_14489589125749046875)],
        &[(0b00001, &ENTRY_UNCOLOREDNESS_13585750041493123595)],
        &[(0b00001, &ENTRY_UNCOLOREDNESSES_10914401521990992291)],
        &[(0b11001, &ENTRY_UNCOLOREDS_17448592794042459595)],
        &[(0b11010, &ENTRY_UNCOLORABLE_4153423912585578276)],
        &[(0b11010, &ENTRY_UNCOLORABLER_17292750876767117491)],
        &[(0b11010, &ENTRY_UNCOLORABLES_8980215200270465076)],
        &[(0b11010, &ENTRY_UNCOLORABLEST_7092331381236258847)],
        &[(0b11010, &ENTRY_UNCOLORABLIER_18378872394705595553)],
        &[(0b11010, &ENTRY_UNCOLORABLIES_13195393864962337812)],
        &[(0b11010, &ENTRY_UNCOLORABLIEST_7529954443419348402)],
        &[(0b11010, &ENTRY_UNCOLORABLY_3052740007631630517)],
        &[(0b11010, &ENTRY_UNCOLORED_5376239934140006972)],
        &[(0b11010, &ENTRY_UNCOLOREDDER_7581046306117193660)],
        &[(0b11010, &ENTRY_UNCOLOREDDEST_2266252169475963598)],
        &[(0b11010, &ENTRY_UNCOLOREDLIER_1339679359641458561)],
        &[(0b11010, &ENTRY_UNCOLOREDLIEST_1084139031301806119)],
        &[(0b11010, &ENTRY_UNCOLOREDLY_14489589125749046875)],
        &[(0b11010, &ENTRY_UNCOLOREDNESS_13585750041493123595)],
        &[(0b11010, &ENTRY_UNCOLOREDNESSES_10914401521990992291)],
        &[(0b11010, &ENTRY_UNCOLOREDS_17448592794042459595)],
        &[(0b00001, &ENTRY_UNCONCERTED_12056905702324932430)],
        &[(0b11010, &ENTRY_UNCONCERTED_12056905702324932430)],
        &[(0b10010, &ENTRY_UNCONVENTIONALIZE_3086010869676785607)],
        &[(0b10010, &ENTRY_UNCONVENTIONALIZES_15104067497605581394)],
        &[(0b01001, &ENTRY_UNCONVENTIONALIZE_3086010869676785607)],
        &[(0b01001, &ENTRY_UNCONVENTIONALIZES_15104067497605581394)],
    ],
    range: 5..=14,
};

static VARS_UNCL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCL_CHILDREN),
    value: None,
};

pub static VARS_UNCL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ericalise"),
        dictgen::InsensitiveStr::Ascii("ericalises"),
        dictgen::InsensitiveStr::Ascii("ericalize"),
        dictgen::InsensitiveStr::Ascii("ericalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCLERICALIZE_10491140255704276060)],
        &[(0b10010, &ENTRY_UNCLERICALIZES_7600984410124444968)],
        &[(0b01001, &ENTRY_UNCLERICALIZE_10491140255704276060)],
        &[(0b01001, &ENTRY_UNCLERICALIZES_7600984410124444968)],
    ],
    range: 9..=10,
};

static VARS_UNCI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCI_CHILDREN),
    value: None,
};

pub static VARS_UNCI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rcularised"),
        dictgen::InsensitiveStr::Ascii("rcularisedder"),
        dictgen::InsensitiveStr::Ascii("rculariseddest"),
        dictgen::InsensitiveStr::Ascii("rculariseds"),
        dictgen::InsensitiveStr::Ascii("rcularized"),
        dictgen::InsensitiveStr::Ascii("rcularizedder"),
        dictgen::InsensitiveStr::Ascii("rcularizeddest"),
        dictgen::InsensitiveStr::Ascii("rcularizeds"),
        dictgen::InsensitiveStr::Ascii("vilisable"),
        dictgen::InsensitiveStr::Ascii("vilisabler"),
        dictgen::InsensitiveStr::Ascii("vilisables"),
        dictgen::InsensitiveStr::Ascii("vilisablest"),
        dictgen::InsensitiveStr::Ascii("vilise"),
        dictgen::InsensitiveStr::Ascii("vilised"),
        dictgen::InsensitiveStr::Ascii("vilisedly"),
        dictgen::InsensitiveStr::Ascii("vilisedness"),
        dictgen::InsensitiveStr::Ascii("vilises"),
        dictgen::InsensitiveStr::Ascii("vilizable"),
        dictgen::InsensitiveStr::Ascii("vilizabler"),
        dictgen::InsensitiveStr::Ascii("vilizables"),
        dictgen::InsensitiveStr::Ascii("vilizablest"),
        dictgen::InsensitiveStr::Ascii("vilize"),
        dictgen::InsensitiveStr::Ascii("vilized"),
        dictgen::InsensitiveStr::Ascii("vilizedly"),
        dictgen::InsensitiveStr::Ascii("vilizedness"),
        dictgen::InsensitiveStr::Ascii("vilizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCIRCULARIZED_5516328689456799366)],
        &[(0b10010, &ENTRY_UNCIRCULARIZEDDER_12944133233619541189)],
        &[(0b10010, &ENTRY_UNCIRCULARIZEDDEST_9090461193585593982)],
        &[(0b10010, &ENTRY_UNCIRCULARIZEDS_13542263411727476574)],
        &[(0b01001, &ENTRY_UNCIRCULARIZED_5516328689456799366)],
        &[(0b01001, &ENTRY_UNCIRCULARIZEDDER_12944133233619541189)],
        &[(0b01001, &ENTRY_UNCIRCULARIZEDDEST_9090461193585593982)],
        &[(0b01001, &ENTRY_UNCIRCULARIZEDS_13542263411727476574)],
        &[(0b10010, &ENTRY_UNCIVILIZABLE_16446988570314426126)],
        &[(0b10010, &ENTRY_UNCIVILIZABLER_10123621737542280246)],
        &[(0b10010, &ENTRY_UNCIVILIZABLES_4009429130801153745)],
        &[(0b10010, &ENTRY_UNCIVILIZABLEST_6482892165423219182)],
        &[(0b10010, &ENTRY_UNCIVILIZE_3952228005440427293)],
        &[(0b10010, &ENTRY_UNCIVILIZED_11842993558173640265)],
        &[(0b10010, &ENTRY_UNCIVILIZEDLY_1281692747978442810)],
        &[(0b10010, &ENTRY_UNCIVILIZEDNESS_8883593449646355660)],
        &[(0b10010, &ENTRY_UNCIVILIZES_16809125612449158210)],
        &[(0b01001, &ENTRY_UNCIVILIZABLE_16446988570314426126)],
        &[(0b01001, &ENTRY_UNCIVILIZABLER_10123621737542280246)],
        &[(0b01001, &ENTRY_UNCIVILIZABLES_4009429130801153745)],
        &[(0b01001, &ENTRY_UNCIVILIZABLEST_6482892165423219182)],
        &[(0b01001, &ENTRY_UNCIVILIZE_3952228005440427293)],
        &[(0b01001, &ENTRY_UNCIVILIZED_11842993558173640265)],
        &[(0b01001, &ENTRY_UNCIVILIZEDLY_1281692747978442810)],
        &[(0b01001, &ENTRY_UNCIVILIZEDNESS_8883593449646355660)],
        &[(0b01001, &ENTRY_UNCIVILIZES_16809125612449158210)],
    ],
    range: 6..=14,
};

static VARS_UNCH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCH_CHILDREN),
    value: None,
};

pub static VARS_UNCH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aracterised"),
        dictgen::InsensitiveStr::Ascii("aracterisedder"),
        dictgen::InsensitiveStr::Ascii("aracteriseddest"),
        dictgen::InsensitiveStr::Ascii("aracterized"),
        dictgen::InsensitiveStr::Ascii("aracterizedder"),
        dictgen::InsensitiveStr::Ascii("aracterizeddest"),
        dictgen::InsensitiveStr::Ascii("astisable"),
        dictgen::InsensitiveStr::Ascii("astised"),
        dictgen::InsensitiveStr::Ascii("astizable"),
        dictgen::InsensitiveStr::Ascii("astized"),
        dictgen::InsensitiveStr::Ascii("loridised"),
        dictgen::InsensitiveStr::Ascii("loridiseds"),
        dictgen::InsensitiveStr::Ascii("loridized"),
        dictgen::InsensitiveStr::Ascii("loridizeds"),
        dictgen::InsensitiveStr::Ascii("ristianise"),
        dictgen::InsensitiveStr::Ascii("ristianised"),
        dictgen::InsensitiveStr::Ascii("ristianises"),
        dictgen::InsensitiveStr::Ascii("ristianising"),
        dictgen::InsensitiveStr::Ascii("ristianize"),
        dictgen::InsensitiveStr::Ascii("ristianized"),
        dictgen::InsensitiveStr::Ascii("ristianizes"),
        dictgen::InsensitiveStr::Ascii("ristianizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCHARACTERIZED_15697554808843700392)],
        &[(0b10010, &ENTRY_UNCHARACTERIZEDDER_6498221828694645324)],
        &[(0b10010, &ENTRY_UNCHARACTERIZEDDEST_4388817827499986014)],
        &[(0b01001, &ENTRY_UNCHARACTERIZED_15697554808843700392)],
        &[(0b01001, &ENTRY_UNCHARACTERIZEDDER_6498221828694645324)],
        &[(0b01001, &ENTRY_UNCHARACTERIZEDDEST_4388817827499986014)],
        &[(0b10010, &ENTRY_UNCHASTIZABLE_4405051919316243197)],
        &[(0b10010, &ENTRY_UNCHASTIZED_12401944732910362657)],
        &[(0b01001, &ENTRY_UNCHASTIZABLE_4405051919316243197)],
        &[(0b01001, &ENTRY_UNCHASTIZED_12401944732910362657)],
        &[(0b10010, &ENTRY_UNCHLORIDIZED_14175199389689712768)],
        &[(0b10010, &ENTRY_UNCHLORIDIZEDS_385449338440357613)],
        &[(0b01001, &ENTRY_UNCHLORIDIZED_14175199389689712768)],
        &[(0b01001, &ENTRY_UNCHLORIDIZEDS_385449338440357613)],
        &[(0b10010, &ENTRY_UNCHRISTIANIZE_6343100935595500731)],
        &[(0b10010, &ENTRY_UNCHRISTIANIZED_14017558686975729907)],
        &[(0b10010, &ENTRY_UNCHRISTIANIZES_12099095202959795788)],
        &[(0b10010, &ENTRY_UNCHRISTIANIZING_14969118364175418495)],
        &[(0b01001, &ENTRY_UNCHRISTIANIZE_6343100935595500731)],
        &[(0b01001, &ENTRY_UNCHRISTIANIZED_14017558686975729907)],
        &[(0b01001, &ENTRY_UNCHRISTIANIZES_12099095202959795788)],
        &[(0b01001, &ENTRY_UNCHRISTIANIZING_14969118364175418495)],
    ],
    range: 7..=15,
};

static VARS_UNCE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCE_CHILDREN),
    value: None,
};

pub static VARS_UNCE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lestialised"),
        dictgen::InsensitiveStr::Ascii("lestialiseds"),
        dictgen::InsensitiveStr::Ascii("lestialized"),
        dictgen::InsensitiveStr::Ascii("lestializeds"),
        dictgen::InsensitiveStr::Ascii("nter"),
        dictgen::InsensitiveStr::Ascii("ntralised"),
        dictgen::InsensitiveStr::Ascii("ntralized"),
        dictgen::InsensitiveStr::Ascii("ntre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCELESTIALIZED_6713837851303993314)],
        &[(0b10010, &ENTRY_UNCELESTIALIZEDS_11516400320799709785)],
        &[(0b01001, &ENTRY_UNCELESTIALIZED_6713837851303993314)],
        &[(0b01001, &ENTRY_UNCELESTIALIZEDS_11516400320799709785)],
        &[(0b00001, &ENTRY_UNCENTER_5022668129641428633)],
        &[(0b10010, &ENTRY_UNCENTRALIZED_5605282303614363703)],
        &[(0b01001, &ENTRY_UNCENTRALIZED_5605282303614363703)],
        &[(0b11010, &ENTRY_UNCENTER_5022668129641428633)],
    ],
    range: 4..=12,
};

static VARS_UNCA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCA_CHILDREN),
    value: None,
};

pub static VARS_UNCA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nceled"),
        dictgen::InsensitiveStr::Ascii("nceledder"),
        dictgen::InsensitiveStr::Ascii("nceleddest"),
        dictgen::InsensitiveStr::Ascii("ndor"),
        dictgen::InsensitiveStr::Ascii("ndour"),
        dictgen::InsensitiveStr::Ascii("nonisation"),
        dictgen::InsensitiveStr::Ascii("nonise"),
        dictgen::InsensitiveStr::Ascii("nonised"),
        dictgen::InsensitiveStr::Ascii("nonises"),
        dictgen::InsensitiveStr::Ascii("nonising"),
        dictgen::InsensitiveStr::Ascii("nonization"),
        dictgen::InsensitiveStr::Ascii("nonize"),
        dictgen::InsensitiveStr::Ascii("nonized"),
        dictgen::InsensitiveStr::Ascii("nonizes"),
        dictgen::InsensitiveStr::Ascii("nonizing"),
        dictgen::InsensitiveStr::Ascii("ntonised"),
        dictgen::InsensitiveStr::Ascii("ntoniseds"),
        dictgen::InsensitiveStr::Ascii("ntonized"),
        dictgen::InsensitiveStr::Ascii("ntonizeds"),
        dictgen::InsensitiveStr::Ascii("pitalised"),
        dictgen::InsensitiveStr::Ascii("pitalisedder"),
        dictgen::InsensitiveStr::Ascii("pitaliseddest"),
        dictgen::InsensitiveStr::Ascii("pitalized"),
        dictgen::InsensitiveStr::Ascii("pitalizedder"),
        dictgen::InsensitiveStr::Ascii("pitalizeddest"),
        dictgen::InsensitiveStr::Ascii("ramelised"),
        dictgen::InsensitiveStr::Ascii("ramelized"),
        dictgen::InsensitiveStr::Ascii("techised"),
        dictgen::InsensitiveStr::Ascii("techisedness"),
        dictgen::InsensitiveStr::Ascii("techiseds"),
        dictgen::InsensitiveStr::Ascii("techized"),
        dictgen::InsensitiveStr::Ascii("techizedness"),
        dictgen::InsensitiveStr::Ascii("techizeds"),
        dictgen::InsensitiveStr::Ascii("tegorised"),
        dictgen::InsensitiveStr::Ascii("tegorisedder"),
        dictgen::InsensitiveStr::Ascii("tegoriseddest"),
        dictgen::InsensitiveStr::Ascii("tegorized"),
        dictgen::InsensitiveStr::Ascii("tegorizedder"),
        dictgen::InsensitiveStr::Ascii("tegorizeddest"),
        dictgen::InsensitiveStr::Ascii("tholicise"),
        dictgen::InsensitiveStr::Ascii("tholicised"),
        dictgen::InsensitiveStr::Ascii("tholicises"),
        dictgen::InsensitiveStr::Ascii("tholicising"),
        dictgen::InsensitiveStr::Ascii("tholicize"),
        dictgen::InsensitiveStr::Ascii("tholicized"),
        dictgen::InsensitiveStr::Ascii("tholicizes"),
        dictgen::InsensitiveStr::Ascii("tholicizing"),
        dictgen::InsensitiveStr::Ascii("uterised"),
        dictgen::InsensitiveStr::Ascii("uteriseds"),
        dictgen::InsensitiveStr::Ascii("uterized"),
        dictgen::InsensitiveStr::Ascii("uterizeds"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNCANCELED_10644523307563396416)],
        &[(0b00001, &ENTRY_UNCANCELEDDER_1822139248734979732)],
        &[(0b00001, &ENTRY_UNCANCELEDDEST_2175636256977122000)],
        &[(0b00001, &ENTRY_UNCANDOR_5207953205214088481)],
        &[(0b11010, &ENTRY_UNCANDOR_5207953205214088481)],
        &[(0b10010, &ENTRY_UNCANONIZATION_2201545706272739551)],
        &[(0b10010, &ENTRY_UNCANONIZE_14994860079175039706)],
        &[(0b10010, &ENTRY_UNCANONIZED_14726062427399498221)],
        &[(0b10010, &ENTRY_UNCANONIZES_9447116594202466407)],
        &[(0b10010, &ENTRY_UNCANONIZING_4301993812611231009)],
        &[(0b01001, &ENTRY_UNCANONIZATION_2201545706272739551)],
        &[(0b01001, &ENTRY_UNCANONIZE_14994860079175039706)],
        &[(0b01001, &ENTRY_UNCANONIZED_14726062427399498221)],
        &[(0b01001, &ENTRY_UNCANONIZES_9447116594202466407)],
        &[(0b01001, &ENTRY_UNCANONIZING_4301993812611231009)],
        &[(0b10010, &ENTRY_UNCANTONIZED_3780031636037658309)],
        &[(0b10010, &ENTRY_UNCANTONIZEDS_10622385437791373383)],
        &[(0b01001, &ENTRY_UNCANTONIZED_3780031636037658309)],
        &[(0b01001, &ENTRY_UNCANTONIZEDS_10622385437791373383)],
        &[(0b10010, &ENTRY_UNCAPITALIZED_6472912780712347860)],
        &[(0b10010, &ENTRY_UNCAPITALIZEDDER_15898505255980224646)],
        &[(0b10010, &ENTRY_UNCAPITALIZEDDEST_5510422959972350228)],
        &[(0b01001, &ENTRY_UNCAPITALIZED_6472912780712347860)],
        &[(0b01001, &ENTRY_UNCAPITALIZEDDER_15898505255980224646)],
        &[(0b01001, &ENTRY_UNCAPITALIZEDDEST_5510422959972350228)],
        &[(0b10010, &ENTRY_UNCARAMELIZED_5424340709113979062)],
        &[(0b01001, &ENTRY_UNCARAMELIZED_5424340709113979062)],
        &[(0b10010, &ENTRY_UNCATECHIZED_471552697184504321)],
        &[(0b10010, &ENTRY_UNCATECHIZEDNESS_4331333175951017514)],
        &[(0b10010, &ENTRY_UNCATECHIZEDS_18151531885968775832)],
        &[(0b01001, &ENTRY_UNCATECHIZED_471552697184504321)],
        &[(0b01001, &ENTRY_UNCATECHIZEDNESS_4331333175951017514)],
        &[(0b01001, &ENTRY_UNCATECHIZEDS_18151531885968775832)],
        &[(0b10010, &ENTRY_UNCATEGORIZED_1908101284533338669)],
        &[(0b10010, &ENTRY_UNCATEGORIZEDDER_10884232809970429610)],
        &[(0b10010, &ENTRY_UNCATEGORIZEDDEST_12893814694726934833)],
        &[(0b01001, &ENTRY_UNCATEGORIZED_1908101284533338669)],
        &[(0b01001, &ENTRY_UNCATEGORIZEDDER_10884232809970429610)],
        &[(0b01001, &ENTRY_UNCATEGORIZEDDEST_12893814694726934833)],
        &[(0b10010, &ENTRY_UNCATHOLICIZE_551995962418758886)],
        &[(0b10010, &ENTRY_UNCATHOLICIZED_4600831380867755451)],
        &[(0b10010, &ENTRY_UNCATHOLICIZES_6093318458474574467)],
        &[(0b10010, &ENTRY_UNCATHOLICIZING_3296529327544351990)],
        &[(0b01001, &ENTRY_UNCATHOLICIZE_551995962418758886)],
        &[(0b01001, &ENTRY_UNCATHOLICIZED_4600831380867755451)],
        &[(0b01001, &ENTRY_UNCATHOLICIZES_6093318458474574467)],
        &[(0b01001, &ENTRY_UNCATHOLICIZING_3296529327544351990)],
        &[(0b10010, &ENTRY_UNCAUTERIZED_13322201167603831983)],
        &[(0b10010, &ENTRY_UNCAUTERIZEDS_11640317330948644398)],
        &[(0b01001, &ENTRY_UNCAUTERIZED_13322201167603831983)],
        &[(0b01001, &ENTRY_UNCAUTERIZEDS_11640317330948644398)],
    ],
    range: 4..=13,
};

static VARS_UNB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNB_CHILDREN),
    value: None,
};

pub static VARS_UNB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aptise"),
        dictgen::InsensitiveStr::Ascii("aptised"),
        dictgen::InsensitiveStr::Ascii("aptises"),
        dictgen::InsensitiveStr::Ascii("aptising"),
        dictgen::InsensitiveStr::Ascii("aptize"),
        dictgen::InsensitiveStr::Ascii("aptized"),
        dictgen::InsensitiveStr::Ascii("aptizes"),
        dictgen::InsensitiveStr::Ascii("aptizing"),
        dictgen::InsensitiveStr::Ascii("arbarise"),
        dictgen::InsensitiveStr::Ascii("arbarised"),
        dictgen::InsensitiveStr::Ascii("arbarising"),
        dictgen::InsensitiveStr::Ascii("arbarize"),
        dictgen::InsensitiveStr::Ascii("arbarized"),
        dictgen::InsensitiveStr::Ascii("arbarizing"),
        dictgen::InsensitiveStr::Ascii("arricaded"),
        dictgen::InsensitiveStr::Ascii("arricadoed"),
        dictgen::InsensitiveStr::Ascii("astardised"),
        dictgen::InsensitiveStr::Ascii("astardisedder"),
        dictgen::InsensitiveStr::Ascii("astardiseddest"),
        dictgen::InsensitiveStr::Ascii("astardized"),
        dictgen::InsensitiveStr::Ascii("astardizedder"),
        dictgen::InsensitiveStr::Ascii("astardizeddest"),
        dictgen::InsensitiveStr::Ascii("rutalise"),
        dictgen::InsensitiveStr::Ascii("rutalised"),
        dictgen::InsensitiveStr::Ascii("rutalises"),
        dictgen::InsensitiveStr::Ascii("rutalising"),
        dictgen::InsensitiveStr::Ascii("rutalize"),
        dictgen::InsensitiveStr::Ascii("rutalized"),
        dictgen::InsensitiveStr::Ascii("rutalizes"),
        dictgen::InsensitiveStr::Ascii("rutalizing"),
        dictgen::InsensitiveStr::Ascii("rutise"),
        dictgen::InsensitiveStr::Ascii("rutised"),
        dictgen::InsensitiveStr::Ascii("rutises"),
        dictgen::InsensitiveStr::Ascii("rutising"),
        dictgen::InsensitiveStr::Ascii("rutize"),
        dictgen::InsensitiveStr::Ascii("rutized"),
        dictgen::InsensitiveStr::Ascii("rutizes"),
        dictgen::InsensitiveStr::Ascii("rutizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNBAPTIZE_2007112232120526430)],
        &[(0b10010, &ENTRY_UNBAPTIZED_7114930556734248374)],
        &[(0b10010, &ENTRY_UNBAPTIZES_10354617340461951966)],
        &[(0b10010, &ENTRY_UNBAPTIZING_8254180624736921315)],
        &[(0b01001, &ENTRY_UNBAPTIZE_2007112232120526430)],
        &[(0b01001, &ENTRY_UNBAPTIZED_7114930556734248374)],
        &[(0b01001, &ENTRY_UNBAPTIZES_10354617340461951966)],
        &[(0b01001, &ENTRY_UNBAPTIZING_8254180624736921315)],
        &[(0b10010, &ENTRY_UNBARBARIZE_18442703460791352976)],
        &[(0b10010, &ENTRY_UNBARBARIZED_4841774978519823120)],
        &[(0b10010, &ENTRY_UNBARBARIZING_7934844739514827618)],
        &[(0b01001, &ENTRY_UNBARBARIZE_18442703460791352976)],
        &[(0b01001, &ENTRY_UNBARBARIZED_4841774978519823120)],
        &[(0b01001, &ENTRY_UNBARBARIZING_7934844739514827618)],
        &[(0b00001, &ENTRY_UNBARRICADED_6576411157510102243)],
        &[(0b11010, &ENTRY_UNBARRICADED_6576411157510102243)],
        &[(0b10010, &ENTRY_UNBASTARDIZED_3379280974151775201)],
        &[(0b10010, &ENTRY_UNBASTARDIZEDDER_394854340525866069)],
        &[(0b10010, &ENTRY_UNBASTARDIZEDDEST_14646212897935089229)],
        &[(0b01001, &ENTRY_UNBASTARDIZED_3379280974151775201)],
        &[(0b01001, &ENTRY_UNBASTARDIZEDDER_394854340525866069)],
        &[(0b01001, &ENTRY_UNBASTARDIZEDDEST_14646212897935089229)],
        &[(0b10010, &ENTRY_UNBRUTALIZE_17065857289068718766)],
        &[(0b10010, &ENTRY_UNBRUTALIZED_1523087329944301575)],
        &[(0b10010, &ENTRY_UNBRUTALIZES_5482040690111908246)],
        &[(0b10010, &ENTRY_UNBRUTALIZING_6665598309600919361)],
        &[(0b01001, &ENTRY_UNBRUTALIZE_17065857289068718766)],
        &[(0b01001, &ENTRY_UNBRUTALIZED_1523087329944301575)],
        &[(0b01001, &ENTRY_UNBRUTALIZES_5482040690111908246)],
        &[(0b01001, &ENTRY_UNBRUTALIZING_6665598309600919361)],
        &[(0b10010, &ENTRY_UNBRUTIZE_8757257384632965724)],
        &[(0b10010, &ENTRY_UNBRUTIZED_13887610461628810713)],
        &[(0b10010, &ENTRY_UNBRUTIZES_8490136628242832874)],
        &[(0b10010, &ENTRY_UNBRUTIZING_806322460612871582)],
        &[(0b01001, &ENTRY_UNBRUTIZE_8757257384632965724)],
        &[(0b01001, &ENTRY_UNBRUTIZED_13887610461628810713)],
        &[(0b01001, &ENTRY_UNBRUTIZES_8490136628242832874)],
        &[(0b01001, &ENTRY_UNBRUTIZING_806322460612871582)],
    ],
    range: 6..=14,
};

static VARS_UNA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNA_CHILDREN),
    value: None,
};

static VARS_UNA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_UNAC_NODE),
    None,
    None,
    None,
    Some(&VARS_UNAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_UNAL_NODE),
    Some(&VARS_UNAM_NODE),
    Some(&VARS_UNAN_NODE),
    None,
    Some(&VARS_UNAP_NODE),
    None,
    Some(&VARS_UNAR_NODE),
    None,
    None,
    Some(&VARS_UNAU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAU_CHILDREN),
    value: None,
};

pub static VARS_UNAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thorise"),
        dictgen::InsensitiveStr::Ascii("thorised"),
        dictgen::InsensitiveStr::Ascii("thorisedder"),
        dictgen::InsensitiveStr::Ascii("thoriseddest"),
        dictgen::InsensitiveStr::Ascii("thorisedly"),
        dictgen::InsensitiveStr::Ascii("thorisedness"),
        dictgen::InsensitiveStr::Ascii("thorises"),
        dictgen::InsensitiveStr::Ascii("thorize"),
        dictgen::InsensitiveStr::Ascii("thorized"),
        dictgen::InsensitiveStr::Ascii("thorizedder"),
        dictgen::InsensitiveStr::Ascii("thorizeddest"),
        dictgen::InsensitiveStr::Ascii("thorizedly"),
        dictgen::InsensitiveStr::Ascii("thorizedness"),
        dictgen::InsensitiveStr::Ascii("thorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNAUTHORIZE_1583120497916853288)],
        &[(0b10010, &ENTRY_UNAUTHORIZED_1030895852257832941)],
        &[(0b10010, &ENTRY_UNAUTHORIZEDDER_6601639422567613002)],
        &[(0b10010, &ENTRY_UNAUTHORIZEDDEST_4803048533625012750)],
        &[(0b10010, &ENTRY_UNAUTHORIZEDLY_10077114453746645352)],
        &[(0b10010, &ENTRY_UNAUTHORIZEDNESS_6472820454762316069)],
        &[(0b10010, &ENTRY_UNAUTHORIZES_17588435880504437850)],
        &[(0b01001, &ENTRY_UNAUTHORIZE_1583120497916853288)],
        &[(0b01001, &ENTRY_UNAUTHORIZED_1030895852257832941)],
        &[(0b01001, &ENTRY_UNAUTHORIZEDDER_6601639422567613002)],
        &[(0b01001, &ENTRY_UNAUTHORIZEDDEST_4803048533625012750)],
        &[(0b01001, &ENTRY_UNAUTHORIZEDLY_10077114453746645352)],
        &[(0b01001, &ENTRY_UNAUTHORIZEDNESS_6472820454762316069)],
        &[(0b01001, &ENTRY_UNAUTHORIZES_17588435880504437850)],
    ],
    range: 7..=12,
};

static VARS_UNAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAR_CHILDREN),
    value: None,
};

pub static VARS_UNAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bored"),
        dictgen::InsensitiveStr::Ascii("boured"),
        dictgen::InsensitiveStr::Ascii("mored"),
        dictgen::InsensitiveStr::Ascii("moredder"),
        dictgen::InsensitiveStr::Ascii("moreddest"),
        dictgen::InsensitiveStr::Ascii("moured"),
        dictgen::InsensitiveStr::Ascii("mouredder"),
        dictgen::InsensitiveStr::Ascii("moureddest"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNARBORED_10184848105069432838)],
        &[(0b11010, &ENTRY_UNARBORED_10184848105069432838)],
        &[(0b00001, &ENTRY_UNARMORED_2648707804512127765)],
        &[(0b00001, &ENTRY_UNARMOREDDER_4492879592434092039)],
        &[(0b00001, &ENTRY_UNARMOREDDEST_5729736686969793724)],
        &[(0b11010, &ENTRY_UNARMORED_2648707804512127765)],
        &[(0b11010, &ENTRY_UNARMOREDDER_4492879592434092039)],
        &[(0b11010, &ENTRY_UNARMOREDDEST_5729736686969793724)],
    ],
    range: 5..=10,
};

static VARS_UNAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAP_CHILDREN),
    value: None,
};

pub static VARS_UNAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ologising"),
        dictgen::InsensitiveStr::Ascii("ologizing"),
        dictgen::InsensitiveStr::Ascii("ostatised"),
        dictgen::InsensitiveStr::Ascii("ostatiseds"),
        dictgen::InsensitiveStr::Ascii("ostatized"),
        dictgen::InsensitiveStr::Ascii("ostatizeds"),
        dictgen::InsensitiveStr::Ascii("petising"),
        dictgen::InsensitiveStr::Ascii("petisinger"),
        dictgen::InsensitiveStr::Ascii("petisingest"),
        dictgen::InsensitiveStr::Ascii("petisinglier"),
        dictgen::InsensitiveStr::Ascii("petisingliest"),
        dictgen::InsensitiveStr::Ascii("petisingly"),
        dictgen::InsensitiveStr::Ascii("petizing"),
        dictgen::InsensitiveStr::Ascii("petizinger"),
        dictgen::InsensitiveStr::Ascii("petizingest"),
        dictgen::InsensitiveStr::Ascii("petizinglier"),
        dictgen::InsensitiveStr::Ascii("petizingliest"),
        dictgen::InsensitiveStr::Ascii("petizingly"),
        dictgen::InsensitiveStr::Ascii("prised"),
        dictgen::InsensitiveStr::Ascii("prized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNAPOLOGIZING_8023597989278305648)],
        &[(0b01001, &ENTRY_UNAPOLOGIZING_8023597989278305648)],
        &[(0b10010, &ENTRY_UNAPOSTATIZED_7778978492175304009)],
        &[(0b10010, &ENTRY_UNAPOSTATIZEDS_16772014085952263940)],
        &[(0b01001, &ENTRY_UNAPOSTATIZED_7778978492175304009)],
        &[(0b01001, &ENTRY_UNAPOSTATIZEDS_16772014085952263940)],
        &[(0b10010, &ENTRY_UNAPPETIZING_17929454627207091337)],
        &[(0b10010, &ENTRY_UNAPPETIZINGER_8263527658294102086)],
        &[(0b10010, &ENTRY_UNAPPETIZINGEST_10792936073593456042)],
        &[(0b10010, &ENTRY_UNAPPETIZINGLIER_5664751833539432448)],
        &[(0b10010, &ENTRY_UNAPPETIZINGLIEST_17210870251486801769)],
        &[(0b10010, &ENTRY_UNAPPETIZINGLY_3201479097994435826)],
        &[(0b01001, &ENTRY_UNAPPETIZING_17929454627207091337)],
        &[(0b01001, &ENTRY_UNAPPETIZINGER_8263527658294102086)],
        &[(0b01001, &ENTRY_UNAPPETIZINGEST_10792936073593456042)],
        &[(0b01001, &ENTRY_UNAPPETIZINGLIER_5664751833539432448)],
        &[(0b01001, &ENTRY_UNAPPETIZINGLIEST_17210870251486801769)],
        &[(0b01001, &ENTRY_UNAPPETIZINGLY_3201479097994435826)],
        &[(0b10010, &ENTRY_UNAPPRIZED_6163150503750732162)],
        &[(0b01001, &ENTRY_UNAPPRIZED_6163150503750732162)],
    ],
    range: 6..=13,
};

static VARS_UNAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAN_CHILDREN),
    value: None,
};

pub static VARS_UNAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("alysable"),
        dictgen::InsensitiveStr::Ascii("alysed"),
        dictgen::InsensitiveStr::Ascii("alyzable"),
        dictgen::InsensitiveStr::Ascii("alyzed"),
        dictgen::InsensitiveStr::Ascii("atomisable"),
        dictgen::InsensitiveStr::Ascii("atomised"),
        dictgen::InsensitiveStr::Ascii("atomizable"),
        dictgen::InsensitiveStr::Ascii("atomized"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("imalised"),
        dictgen::InsensitiveStr::Ascii("imaliseds"),
        dictgen::InsensitiveStr::Ascii("imalized"),
        dictgen::InsensitiveStr::Ascii("imalizeds"),
        dictgen::InsensitiveStr::Ascii("tagonisable"),
        dictgen::InsensitiveStr::Ascii("tagonisabler"),
        dictgen::InsensitiveStr::Ascii("tagonisables"),
        dictgen::InsensitiveStr::Ascii("tagonisablest"),
        dictgen::InsensitiveStr::Ascii("tagonised"),
        dictgen::InsensitiveStr::Ascii("tagonisedder"),
        dictgen::InsensitiveStr::Ascii("tagoniseddest"),
        dictgen::InsensitiveStr::Ascii("tagonising"),
        dictgen::InsensitiveStr::Ascii("tagonisinger"),
        dictgen::InsensitiveStr::Ascii("tagonisingest"),
        dictgen::InsensitiveStr::Ascii("tagonizable"),
        dictgen::InsensitiveStr::Ascii("tagonizabler"),
        dictgen::InsensitiveStr::Ascii("tagonizables"),
        dictgen::InsensitiveStr::Ascii("tagonizablest"),
        dictgen::InsensitiveStr::Ascii("tagonized"),
        dictgen::InsensitiveStr::Ascii("tagonizedder"),
        dictgen::InsensitiveStr::Ascii("tagonizeddest"),
        dictgen::InsensitiveStr::Ascii("tagonizing"),
        dictgen::InsensitiveStr::Ascii("tagonizinger"),
        dictgen::InsensitiveStr::Ascii("tagonizingest"),
    ],
    values: &[
        &[(0b11010, &ENTRY_UNANEMIC_4893591374506498656)],
        &[(0b10010, &ENTRY_UNANALYZABLE_10185255751864420777)],
        &[(0b10010, &ENTRY_UNANALYZED_17631303651139984908)],
        &[(0b01001, &ENTRY_UNANALYZABLE_10185255751864420777)],
        &[(0b01001, &ENTRY_UNANALYZED_17631303651139984908)],
        &[(0b10010, &ENTRY_UNANATOMIZABLE_11481192287759636901)],
        &[(0b10010, &ENTRY_UNANATOMIZED_5758539222957914530)],
        &[(0b01001, &ENTRY_UNANATOMIZABLE_11481192287759636901)],
        &[(0b01001, &ENTRY_UNANATOMIZED_5758539222957914530)],
        &[(0b00001, &ENTRY_UNANEMIC_4893591374506498656)],
        &[(0b10010, &ENTRY_UNANIMALIZED_17517705032004401767)],
        &[(0b10010, &ENTRY_UNANIMALIZEDS_2714346462835359758)],
        &[(0b01001, &ENTRY_UNANIMALIZED_17517705032004401767)],
        &[(0b01001, &ENTRY_UNANIMALIZEDS_2714346462835359758)],
        &[(0b10010, &ENTRY_UNANTAGONIZABLE_4447516271806860740)],
        &[(0b10010, &ENTRY_UNANTAGONIZABLER_1805720993301381014)],
        &[(0b10010, &ENTRY_UNANTAGONIZABLES_18175548170494914576)],
        &[(0b10010, &ENTRY_UNANTAGONIZABLEST_3735825461795500564)],
        &[(0b10010, &ENTRY_UNANTAGONIZED_5216901107304039571)],
        &[(0b10010, &ENTRY_UNANTAGONIZEDDER_18165233424269243283)],
        &[(0b10010, &ENTRY_UNANTAGONIZEDDEST_5550155987501146316)],
        &[(0b10010, &ENTRY_UNANTAGONIZING_9261939565808222087)],
        &[(0b10010, &ENTRY_UNANTAGONIZINGER_13162794461334815421)],
        &[(0b10010, &ENTRY_UNANTAGONIZINGEST_1520014316091664854)],
        &[(0b01001, &ENTRY_UNANTAGONIZABLE_4447516271806860740)],
        &[(0b01001, &ENTRY_UNANTAGONIZABLER_1805720993301381014)],
        &[(0b01001, &ENTRY_UNANTAGONIZABLES_18175548170494914576)],
        &[(0b01001, &ENTRY_UNANTAGONIZABLEST_3735825461795500564)],
        &[(0b01001, &ENTRY_UNANTAGONIZED_5216901107304039571)],
        &[(0b01001, &ENTRY_UNANTAGONIZEDDER_18165233424269243283)],
        &[(0b01001, &ENTRY_UNANTAGONIZEDDEST_5550155987501146316)],
        &[(0b01001, &ENTRY_UNANTAGONIZING_9261939565808222087)],
        &[(0b01001, &ENTRY_UNANTAGONIZINGER_13162794461334815421)],
        &[(0b01001, &ENTRY_UNANTAGONIZINGEST_1520014316091664854)],
    ],
    range: 4..=13,
};

static VARS_UNAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAM_CHILDREN),
    value: None,
};

pub static VARS_UNAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ortisation"),
        dictgen::InsensitiveStr::Ascii("ortisations"),
        dictgen::InsensitiveStr::Ascii("ortised"),
        dictgen::InsensitiveStr::Ascii("ortization"),
        dictgen::InsensitiveStr::Ascii("ortizations"),
        dictgen::InsensitiveStr::Ascii("ortized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNAMORTIZATION_9895086701973992419)],
        &[(0b10010, &ENTRY_UNAMORTIZATIONS_7833890650778444360)],
        &[(0b10010, &ENTRY_UNAMORTIZED_11972025435236260926)],
        &[(0b01001, &ENTRY_UNAMORTIZATION_9895086701973992419)],
        &[(0b01001, &ENTRY_UNAMORTIZATIONS_7833890650778444360)],
        &[(0b01001, &ENTRY_UNAMORTIZED_11972025435236260926)],
    ],
    range: 7..=11,
};

static VARS_UNAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAL_CHILDREN),
    value: None,
};

pub static VARS_UNAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("coholised"),
        dictgen::InsensitiveStr::Ascii("coholisedder"),
        dictgen::InsensitiveStr::Ascii("coholiseddest"),
        dictgen::InsensitiveStr::Ascii("coholiseds"),
        dictgen::InsensitiveStr::Ascii("coholized"),
        dictgen::InsensitiveStr::Ascii("coholizedder"),
        dictgen::InsensitiveStr::Ascii("coholizeddest"),
        dictgen::InsensitiveStr::Ascii("coholizeds"),
        dictgen::InsensitiveStr::Ascii("phabetised"),
        dictgen::InsensitiveStr::Ascii("phabetized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNALCOHOLIZED_7475486806446169449)],
        &[(0b10010, &ENTRY_UNALCOHOLIZEDDER_13026382719695767769)],
        &[(0b10010, &ENTRY_UNALCOHOLIZEDDEST_17661502425886015635)],
        &[(0b10010, &ENTRY_UNALCOHOLIZEDS_12566648296272969844)],
        &[(0b01001, &ENTRY_UNALCOHOLIZED_7475486806446169449)],
        &[(0b01001, &ENTRY_UNALCOHOLIZEDDER_13026382719695767769)],
        &[(0b01001, &ENTRY_UNALCOHOLIZEDDEST_17661502425886015635)],
        &[(0b01001, &ENTRY_UNALCOHOLIZEDS_12566648296272969844)],
        &[(0b10010, &ENTRY_UNALPHABETIZED_12264077727491901794)],
        &[(0b01001, &ENTRY_UNALPHABETIZED_12264077727491901794)],
    ],
    range: 9..=13,
};

static VARS_UNAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAG_CHILDREN),
    value: None,
};

pub static VARS_UNAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNAGONIZE_3985839663605404087)],
        &[(0b01001, &ENTRY_UNAGONIZE_3985839663605404087)],
    ],
    range: 5..=5,
};

static VARS_UNAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAC_CHILDREN),
    value: None,
};

pub static VARS_UNAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("climatised"),
        dictgen::InsensitiveStr::Ascii("climatized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNACCLIMATIZED_14600148678249666016)],
        &[(0b01001, &ENTRY_UNACCLIMATIZED_14600148678249666016)],
    ],
    range: 10..=10,
};

static VARS_UL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UL_CHILDREN),
    value: None,
};

pub static VARS_UL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tracentraliser"),
        dictgen::InsensitiveStr::Ascii("tracentralisers"),
        dictgen::InsensitiveStr::Ascii("tracentralizer"),
        dictgen::InsensitiveStr::Ascii("tracentralizers"),
        dictgen::InsensitiveStr::Ascii("trahonorable"),
        dictgen::InsensitiveStr::Ascii("trahonorables"),
        dictgen::InsensitiveStr::Ascii("trahonourable"),
        dictgen::InsensitiveStr::Ascii("trahonourables"),
        dictgen::InsensitiveStr::Ascii("traspecialisation"),
        dictgen::InsensitiveStr::Ascii("traspecialisations"),
        dictgen::InsensitiveStr::Ascii("traspecialization"),
        dictgen::InsensitiveStr::Ascii("traspecializations"),
        dictgen::InsensitiveStr::Ascii("trastandardisation"),
        dictgen::InsensitiveStr::Ascii("trastandardisations"),
        dictgen::InsensitiveStr::Ascii("trastandardization"),
        dictgen::InsensitiveStr::Ascii("trastandardizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ULTRACENTRALIZER_1110134519737018003)],
        &[(0b10010, &ENTRY_ULTRACENTRALIZERS_9421251802721659846)],
        &[(0b01001, &ENTRY_ULTRACENTRALIZER_1110134519737018003)],
        &[(0b01001, &ENTRY_ULTRACENTRALIZERS_9421251802721659846)],
        &[(0b00001, &ENTRY_ULTRAHONORABLE_2858828412730743831)],
        &[(0b00001, &ENTRY_ULTRAHONORABLES_7561547150076074006)],
        &[(0b11010, &ENTRY_ULTRAHONORABLE_2858828412730743831)],
        &[(0b11010, &ENTRY_ULTRAHONORABLES_7561547150076074006)],
        &[(0b10010, &ENTRY_ULTRASPECIALIZATION_8391905615350246381)],
        &[(0b10010, &ENTRY_ULTRASPECIALIZATIONS_5732795204754657259)],
        &[(0b01001, &ENTRY_ULTRASPECIALIZATION_8391905615350246381)],
        &[(0b01001, &ENTRY_ULTRASPECIALIZATIONS_5732795204754657259)],
        &[(0b10010, &ENTRY_ULTRASTANDARDIZATION_16460010141823176416)],
        &[(0b10010, &ENTRY_ULTRASTANDARDIZATIONS_8293107802581753490)],
        &[(0b01001, &ENTRY_ULTRASTANDARDIZATION_16460010141823176416)],
        &[(0b01001, &ENTRY_ULTRASTANDARDIZATIONS_8293107802581753490)],
    ],
    range: 12..=19,
};

static VARS_T_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_T_CHILDREN),
    value: None,
};

static VARS_T_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_TA_NODE),
    None,
    None,
    None,
    Some(&VARS_TE_NODE),
    None,
    None,
    Some(&VARS_TH_NODE),
    Some(&VARS_TI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TO_NODE),
    None,
    None,
    Some(&VARS_TR_NODE),
    Some(&VARS_TS_NODE),
    None,
    Some(&VARS_TU_NODE),
    None,
    Some(&VARS_TW_NODE),
    None,
    Some(&VARS_TY_NODE),
    Some(&VARS_TZ_NODE),
];

static VARS_TZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TZ_CHILDREN),
    value: None,
};

pub static VARS_TZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ar"),
        dictgen::InsensitiveStr::Ascii("ars"),
    ],
    values: &[
        &[(0b10011, &ENTRY_CZAR_10918908885952851126)],
        &[(0b10011, &ENTRY_CZARS_17220740917194786378)],
    ],
    range: 2..=3,
};

static VARS_TY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TY_CHILDREN),
    value: None,
};

pub static VARS_TY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lerise"),
        dictgen::InsensitiveStr::Ascii("lerises"),
        dictgen::InsensitiveStr::Ascii("lerize"),
        dictgen::InsensitiveStr::Ascii("lerizes"),
        dictgen::InsensitiveStr::Ascii("phaemia"),
        dictgen::InsensitiveStr::Ascii("phemia"),
        dictgen::InsensitiveStr::Ascii("phlenteritis"),
        dictgen::InsensitiveStr::Ascii("phloenteritis"),
        dictgen::InsensitiveStr::Ascii("phoaemia"),
        dictgen::InsensitiveStr::Ascii("phoemia"),
        dictgen::InsensitiveStr::Ascii("rannise"),
        dictgen::InsensitiveStr::Ascii("rannised"),
        dictgen::InsensitiveStr::Ascii("ranniser"),
        dictgen::InsensitiveStr::Ascii("rannisers"),
        dictgen::InsensitiveStr::Ascii("rannises"),
        dictgen::InsensitiveStr::Ascii("rannising"),
        dictgen::InsensitiveStr::Ascii("rannisinglier"),
        dictgen::InsensitiveStr::Ascii("rannisingliest"),
        dictgen::InsensitiveStr::Ascii("rannisingly"),
        dictgen::InsensitiveStr::Ascii("rannisings"),
        dictgen::InsensitiveStr::Ascii("rannize"),
        dictgen::InsensitiveStr::Ascii("rannized"),
        dictgen::InsensitiveStr::Ascii("rannizer"),
        dictgen::InsensitiveStr::Ascii("rannizers"),
        dictgen::InsensitiveStr::Ascii("rannizes"),
        dictgen::InsensitiveStr::Ascii("rannizing"),
        dictgen::InsensitiveStr::Ascii("rannizinglier"),
        dictgen::InsensitiveStr::Ascii("rannizingliest"),
        dictgen::InsensitiveStr::Ascii("rannizingly"),
        dictgen::InsensitiveStr::Ascii("rannizings"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("reo"),
        dictgen::InsensitiveStr::Ascii("reos"),
        dictgen::InsensitiveStr::Ascii("res"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TYLERIZE_17929226921575671617)],
        &[(0b10010, &ENTRY_TYLERIZES_14012127742705433613)],
        &[(0b01001, &ENTRY_TYLERIZE_17929226921575671617)],
        &[(0b01001, &ENTRY_TYLERIZES_14012127742705433613)],
        &[(0b11010, &ENTRY_TYPHEMIA_11619953963433812261)],
        &[
            (0b00001, &ENTRY_TYPHEMIA_10653684295720787141),
            (0b00001, &ENTRY_TYPHEMIA_11619953963433812261),
        ],
        &[(0b00001, &ENTRY_TYPHLENTERITIS_2891708862956049172)],
        &[(0b11010, &ENTRY_TYPHLENTERITIS_2891708862956049172)],
        &[(0b11010, &ENTRY_TYPHOEMIA_10411131729213561042)],
        &[
            (0b11010, &ENTRY_TYPHEMIA_10653684295720787141),
            (0b00001, &ENTRY_TYPHOEMIA_10411131729213561042),
        ],
        &[(0b10010, &ENTRY_TYRANNIZE_1000053221538931404)],
        &[(0b10010, &ENTRY_TYRANNIZED_10508710200970438760)],
        &[(0b10010, &ENTRY_TYRANNIZER_1819969736083775933)],
        &[(0b10010, &ENTRY_TYRANNIZERS_17260544957894670455)],
        &[(0b10010, &ENTRY_TYRANNIZES_9564723788181665646)],
        &[(0b10010, &ENTRY_TYRANNIZING_1392868749194607551)],
        &[(0b10010, &ENTRY_TYRANNIZINGLIER_1267872557850447455)],
        &[(0b10010, &ENTRY_TYRANNIZINGLIEST_6866185442199362789)],
        &[(0b10010, &ENTRY_TYRANNIZINGLY_3301246314614084531)],
        &[(0b10010, &ENTRY_TYRANNIZINGS_338643871377770319)],
        &[(0b01001, &ENTRY_TYRANNIZE_1000053221538931404)],
        &[(0b01001, &ENTRY_TYRANNIZED_10508710200970438760)],
        &[(0b01001, &ENTRY_TYRANNIZER_1819969736083775933)],
        &[(0b01001, &ENTRY_TYRANNIZERS_17260544957894670455)],
        &[(0b01001, &ENTRY_TYRANNIZES_9564723788181665646)],
        &[(0b01001, &ENTRY_TYRANNIZING_1392868749194607551)],
        &[(0b01001, &ENTRY_TYRANNIZINGLIER_1267872557850447455)],
        &[(0b01001, &ENTRY_TYRANNIZINGLIEST_6866185442199362789)],
        &[(0b01001, &ENTRY_TYRANNIZINGLY_3301246314614084531)],
        &[(0b01001, &ENTRY_TYRANNIZINGS_338643871377770319)],
        &[(0b10010, &ENTRY_TIRE_6240813028329445155)],
        &[(0b00001, &ENTRY_TYRO_1794051950789040929)],
        &[(0b00001, &ENTRY_TYROS_10684341243330634223)],
        &[(0b10010, &ENTRY_TIRES_4841205171088418079)],
    ],
    range: 2..=14,
};

static VARS_TW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TW_CHILDREN),
    value: None,
};

pub static VARS_TW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ier"),
        dictgen::InsensitiveStr::Ascii("iers"),
        dictgen::InsensitiveStr::Ascii("ire"),
        dictgen::InsensitiveStr::Ascii("ires"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TWIER_15217813909340355710)],
        &[(0b00001, &ENTRY_TWIERS_16061495920010970718)],
        &[(0b11010, &ENTRY_TWIER_15217813909340355710)],
        &[(0b11010, &ENTRY_TWIERS_16061495920010970718)],
    ],
    range: 3..=4,
};

static VARS_TU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TU_CHILDREN),
    value: None,
};

static VARS_TU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_TUB_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TUL_NODE),
    Some(&VARS_TUM_NODE),
    Some(&VARS_TUN_NODE),
    None,
    None,
    None,
    Some(&VARS_TUR_NODE),
    Some(&VARS_TUS_NODE),
    Some(&VARS_TUT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_TUT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUT_CHILDREN),
    value: None,
};

pub static VARS_TUT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elae"),
        dictgen::InsensitiveStr::Ascii("ele"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TUTELE_12348649899581353745)],
        &[(0b00001, &ENTRY_TUTELE_12348649899581353745)],
        &[(0b10010, &ENTRY_TUTORIZATION_4877249596838258085)],
        &[(0b10010, &ENTRY_TUTORIZATIONS_15234613627004287155)],
        &[(0b10010, &ENTRY_TUTORIZE_6972247317790274058)],
        &[(0b10010, &ENTRY_TUTORIZED_12837178324286735725)],
        &[(0b10010, &ENTRY_TUTORIZES_17326633325460663696)],
        &[(0b10010, &ENTRY_TUTORIZING_1794860608282634904)],
        &[(0b01001, &ENTRY_TUTORIZATION_4877249596838258085)],
        &[(0b01001, &ENTRY_TUTORIZATIONS_15234613627004287155)],
        &[(0b01001, &ENTRY_TUTORIZE_6972247317790274058)],
        &[(0b01001, &ENTRY_TUTORIZED_12837178324286735725)],
        &[(0b01001, &ENTRY_TUTORIZES_17326633325460663696)],
        &[(0b01001, &ENTRY_TUTORIZING_1794860608282634904)],
    ],
    range: 3..=10,
};

static VARS_TUS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUS_CHILDREN),
    value: None,
};

pub static VARS_TUS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("canise"),
        dictgen::InsensitiveStr::Ascii("canises"),
        dictgen::InsensitiveStr::Ascii("canize"),
        dictgen::InsensitiveStr::Ascii("canizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TUSCANIZE_2884073206787212893)],
        &[(0b10010, &ENTRY_TUSCANIZES_17789792843875455131)],
        &[(0b01001, &ENTRY_TUSCANIZE_2884073206787212893)],
        &[(0b01001, &ENTRY_TUSCANIZES_17789792843875455131)],
    ],
    range: 6..=7,
};

static VARS_TUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUR_CHILDREN),
    value: None,
};

pub static VARS_TUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dinae"),
        dictgen::InsensitiveStr::Ascii("dine"),
        dictgen::InsensitiveStr::Ascii("kicise"),
        dictgen::InsensitiveStr::Ascii("kicised"),
        dictgen::InsensitiveStr::Ascii("kicises"),
        dictgen::InsensitiveStr::Ascii("kicising"),
        dictgen::InsensitiveStr::Ascii("kicize"),
        dictgen::InsensitiveStr::Ascii("kicized"),
        dictgen::InsensitiveStr::Ascii("kicizes"),
        dictgen::InsensitiveStr::Ascii("kicizing"),
        dictgen::InsensitiveStr::Ascii("kise"),
        dictgen::InsensitiveStr::Ascii("kises"),
        dictgen::InsensitiveStr::Ascii("kize"),
        dictgen::InsensitiveStr::Ascii("kizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TURDINE_10805567808377549809)],
        &[(0b00001, &ENTRY_TURDINE_10805567808377549809)],
        &[(0b10010, &ENTRY_TURKICIZE_11200064558982110888)],
        &[(0b10010, &ENTRY_TURKICIZED_18091702444540416526)],
        &[(0b10010, &ENTRY_TURKICIZES_12157500324270664376)],
        &[(0b10010, &ENTRY_TURKICIZING_15914584795237502956)],
        &[(0b01001, &ENTRY_TURKICIZE_11200064558982110888)],
        &[(0b01001, &ENTRY_TURKICIZED_18091702444540416526)],
        &[(0b01001, &ENTRY_TURKICIZES_12157500324270664376)],
        &[(0b01001, &ENTRY_TURKICIZING_15914584795237502956)],
        &[(0b10010, &ENTRY_TURKIZE_9146975708135188734)],
        &[(0b10010, &ENTRY_TURKIZES_12975476878808536800)],
        &[(0b01001, &ENTRY_TURKIZE_9146975708135188734)],
        &[(0b01001, &ENTRY_TURKIZES_12975476878808536800)],
    ],
    range: 4..=8,
};

static VARS_TUN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUN_CHILDREN),
    value: None,
};

pub static VARS_TUN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("neled"),
        dictgen::InsensitiveStr::Ascii("neler"),
        dictgen::InsensitiveStr::Ascii("nelers"),
        dictgen::InsensitiveStr::Ascii("neling"),
        dictgen::InsensitiveStr::Ascii("nelings"),
        dictgen::InsensitiveStr::Ascii("nelled"),
        dictgen::InsensitiveStr::Ascii("neller"),
        dictgen::InsensitiveStr::Ascii("nellers"),
        dictgen::InsensitiveStr::Ascii("nelling"),
        dictgen::InsensitiveStr::Ascii("nellings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TUNNELED_11370086013695475785)],
        &[(0b00001, &ENTRY_TUNNELER_14964877288873936262)],
        &[(0b00001, &ENTRY_TUNNELERS_17425429561485837672)],
        &[(0b00001, &ENTRY_TUNNELING_8449736644402875370)],
        &[(0b00001, &ENTRY_TUNNELINGS_14406089909159685424)],
        &[(0b11010, &ENTRY_TUNNELED_11370086013695475785)],
        &[(0b11010, &ENTRY_TUNNELER_14964877288873936262)],
        &[(0b11010, &ENTRY_TUNNELERS_17425429561485837672)],
        &[(0b11010, &ENTRY_TUNNELING_8449736644402875370)],
        &[(0b11010, &ENTRY_TUNNELINGS_14406089909159685424)],
    ],
    range: 5..=8,
};

static VARS_TUM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUM_CHILDREN),
    value: None,
};

pub static VARS_TUM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_TUMOR_18208195035577206669)],
        &[(0b00001, &ENTRY_TUMORED_16843203498038722198)],
        &[(0b11001, &ENTRY_TUMORS_823212688865744384)],
        &[(0b11010, &ENTRY_TUMOR_18208195035577206669)],
        &[(0b11010, &ENTRY_TUMORED_16843203498038722198)],
        &[(0b11010, &ENTRY_TUMORS_823212688865744384)],
    ],
    range: 2..=5,
};

static VARS_TUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUL_CHILDREN),
    value: None,
};

pub static VARS_TUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("araemia"),
        dictgen::InsensitiveStr::Ascii("araemias"),
        dictgen::InsensitiveStr::Ascii("araemic"),
        dictgen::InsensitiveStr::Ascii("aremia"),
        dictgen::InsensitiveStr::Ascii("aremias"),
        dictgen::InsensitiveStr::Ascii("aremic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TULAREMIA_15946480059849647392)],
        &[(0b11010, &ENTRY_TULAREMIAS_3114003671274129745)],
        &[(0b11010, &ENTRY_TULAREMIC_3583808281242513322)],
        &[(0b01001, &ENTRY_TULAREMIA_15946480059849647392)],
        &[(0b01001, &ENTRY_TULAREMIAS_3114003671274129745)],
        &[(0b00001, &ENTRY_TULAREMIC_3583808281242513322)],
    ],
    range: 6..=8,
};

static VARS_TUB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUB_CHILDREN),
    value: None,
};

pub static VARS_TUB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ercularisation"),
        dictgen::InsensitiveStr::Ascii("ercularise"),
        dictgen::InsensitiveStr::Ascii("ercularised"),
        dictgen::InsensitiveStr::Ascii("ercularising"),
        dictgen::InsensitiveStr::Ascii("ercularization"),
        dictgen::InsensitiveStr::Ascii("ercularize"),
        dictgen::InsensitiveStr::Ascii("ercularized"),
        dictgen::InsensitiveStr::Ascii("ercularizing"),
        dictgen::InsensitiveStr::Ascii("erculinisation"),
        dictgen::InsensitiveStr::Ascii("erculinisations"),
        dictgen::InsensitiveStr::Ascii("erculinise"),
        dictgen::InsensitiveStr::Ascii("erculinised"),
        dictgen::InsensitiveStr::Ascii("erculinises"),
        dictgen::InsensitiveStr::Ascii("erculinising"),
        dictgen::InsensitiveStr::Ascii("erculinization"),
        dictgen::InsensitiveStr::Ascii("erculinizations"),
        dictgen::InsensitiveStr::Ascii("erculinize"),
        dictgen::InsensitiveStr::Ascii("erculinized"),
        dictgen::InsensitiveStr::Ascii("erculinizes"),
        dictgen::InsensitiveStr::Ascii("erculinizing"),
        dictgen::InsensitiveStr::Ascii("erculisation"),
        dictgen::InsensitiveStr::Ascii("erculisations"),
        dictgen::InsensitiveStr::Ascii("erculise"),
        dictgen::InsensitiveStr::Ascii("erculised"),
        dictgen::InsensitiveStr::Ascii("erculises"),
        dictgen::InsensitiveStr::Ascii("erculising"),
        dictgen::InsensitiveStr::Ascii("erculization"),
        dictgen::InsensitiveStr::Ascii("erculizations"),
        dictgen::InsensitiveStr::Ascii("erculize"),
        dictgen::InsensitiveStr::Ascii("erculized"),
        dictgen::InsensitiveStr::Ascii("erculizes"),
        dictgen::InsensitiveStr::Ascii("erculizing"),
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("ulisation"),
        dictgen::InsensitiveStr::Ascii("ulisations"),
        dictgen::InsensitiveStr::Ascii("ulization"),
        dictgen::InsensitiveStr::Ascii("ulizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TUBERCULARIZATION_16282213177072308407)],
        &[(0b10010, &ENTRY_TUBERCULARIZE_375454583803761936)],
        &[(0b10010, &ENTRY_TUBERCULARIZED_12127734432961771885)],
        &[(0b10010, &ENTRY_TUBERCULARIZING_11598479791968421505)],
        &[(0b01001, &ENTRY_TUBERCULARIZATION_16282213177072308407)],
        &[(0b01001, &ENTRY_TUBERCULARIZE_375454583803761936)],
        &[(0b01001, &ENTRY_TUBERCULARIZED_12127734432961771885)],
        &[(0b01001, &ENTRY_TUBERCULARIZING_11598479791968421505)],
        &[(0b10010, &ENTRY_TUBERCULINIZATION_16825164027674017455)],
        &[(0b10010, &ENTRY_TUBERCULINIZATIONS_11324544919726547747)],
        &[(0b10010, &ENTRY_TUBERCULINIZE_3111780340548733278)],
        &[(0b10010, &ENTRY_TUBERCULINIZED_3468601096407728731)],
        &[(0b10010, &ENTRY_TUBERCULINIZES_17100839746190670900)],
        &[(0b10010, &ENTRY_TUBERCULINIZING_7306410957129592563)],
        &[(0b01001, &ENTRY_TUBERCULINIZATION_16825164027674017455)],
        &[(0b01001, &ENTRY_TUBERCULINIZATIONS_11324544919726547747)],
        &[(0b01001, &ENTRY_TUBERCULINIZE_3111780340548733278)],
        &[(0b01001, &ENTRY_TUBERCULINIZED_3468601096407728731)],
        &[(0b01001, &ENTRY_TUBERCULINIZES_17100839746190670900)],
        &[(0b01001, &ENTRY_TUBERCULINIZING_7306410957129592563)],
        &[(0b10010, &ENTRY_TUBERCULIZATION_9178477451489860203)],
        &[(0b10010, &ENTRY_TUBERCULIZATIONS_7601410696098087935)],
        &[(0b10010, &ENTRY_TUBERCULIZE_13543988884309523486)],
        &[(0b10010, &ENTRY_TUBERCULIZED_17282098119918700945)],
        &[(0b10010, &ENTRY_TUBERCULIZES_15600354817268651196)],
        &[(0b10010, &ENTRY_TUBERCULIZING_15007965539279942136)],
        &[(0b01001, &ENTRY_TUBERCULIZATION_9178477451489860203)],
        &[(0b01001, &ENTRY_TUBERCULIZATIONS_7601410696098087935)],
        &[(0b01001, &ENTRY_TUBERCULIZE_13543988884309523486)],
        &[(0b01001, &ENTRY_TUBERCULIZED_17282098119918700945)],
        &[(0b01001, &ENTRY_TUBERCULIZES_15600354817268651196)],
        &[(0b01001, &ENTRY_TUBERCULIZING_15007965539279942136)],
        &[(0b10010, &ENTRY_TUBERIZATION_18013492797265472869)],
        &[(0b10010, &ENTRY_TUBERIZATIONS_436245966155449153)],
        &[(0b10010, &ENTRY_TUBERIZE_13289124791090367946)],
        &[(0b10010, &ENTRY_TUBERIZES_8957289704531228507)],
        &[(0b01001, &ENTRY_TUBERIZATION_18013492797265472869)],
        &[(0b01001, &ENTRY_TUBERIZATIONS_436245966155449153)],
        &[(0b01001, &ENTRY_TUBERIZE_13289124791090367946)],
        &[(0b01001, &ENTRY_TUBERIZES_8957289704531228507)],
        &[(0b10010, &ENTRY_TUBULIZATION_7106526619239771563)],
        &[(0b10010, &ENTRY_TUBULIZATIONS_7424978890605027489)],
        &[(0b01001, &ENTRY_TUBULIZATION_7106526619239771563)],
        &[(0b01001, &ENTRY_TUBULIZATIONS_7424978890605027489)],
    ],
    range: 5..=15,
};

static VARS_TS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TS_CHILDREN),
    value: None,
};

pub static VARS_TS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oris"),
        dictgen::InsensitiveStr::Ascii("ouris"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TSORIS_4355452546295467104)],
        &[(0b11010, &ENTRY_TSORIS_4355452546295467104)],
    ],
    range: 4..=5,
};

static VARS_TR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TR_CHILDREN),
    value: None,
};

static VARS_TR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_TRA_NODE),
    None,
    None,
    None,
    Some(&VARS_TRE_NODE),
    None,
    None,
    None,
    Some(&VARS_TRI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TRO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TRU_NODE),
    None,
    None,
    None,
    Some(&VARS_TRY_NODE),
    None,
];

static VARS_TRY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRY_CHILDREN),
    value: None,
};

pub static VARS_TRY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("psinise"),
        dictgen::InsensitiveStr::Ascii("psinises"),
        dictgen::InsensitiveStr::Ascii("psinize"),
        dictgen::InsensitiveStr::Ascii("psinizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRYPSINIZE_10045098514426963634)],
        &[(0b10010, &ENTRY_TRYPSINIZES_16656487916141363425)],
        &[(0b01001, &ENTRY_TRYPSINIZE_10045098514426963634)],
        &[(0b01001, &ENTRY_TRYPSINIZES_16656487916141363425)],
    ],
    range: 7..=8,
};

static VARS_TRU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRU_CHILDREN),
    value: None,
};

pub static VARS_TRU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("benise"),
        dictgen::InsensitiveStr::Ascii("benised"),
        dictgen::InsensitiveStr::Ascii("benises"),
        dictgen::InsensitiveStr::Ascii("benising"),
        dictgen::InsensitiveStr::Ascii("benize"),
        dictgen::InsensitiveStr::Ascii("benized"),
        dictgen::InsensitiveStr::Ascii("benizes"),
        dictgen::InsensitiveStr::Ascii("benizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRUBENIZE_3208348265396414813)],
        &[(0b10010, &ENTRY_TRUBENIZED_13292664579470291193)],
        &[(0b10010, &ENTRY_TRUBENIZES_4849728788218049461)],
        &[(0b10010, &ENTRY_TRUBENIZING_6908243337876686290)],
        &[(0b01001, &ENTRY_TRUBENIZE_3208348265396414813)],
        &[(0b01001, &ENTRY_TRUBENIZED_13292664579470291193)],
        &[(0b01001, &ENTRY_TRUBENIZES_4849728788218049461)],
        &[(0b01001, &ENTRY_TRUBENIZING_6908243337876686290)],
    ],
    range: 6..=8,
};

static VARS_TRO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRO_CHILDREN),
    value: None,
};

pub static VARS_TRO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("llied"),
        dictgen::InsensitiveStr::Ascii("llies"),
        dictgen::InsensitiveStr::Ascii("lly"),
        dictgen::InsensitiveStr::Ascii("llying"),
        dictgen::InsensitiveStr::Ascii("paeolin"),
        dictgen::InsensitiveStr::Ascii("peolin"),
        dictgen::InsensitiveStr::Ascii("picalisation"),
        dictgen::InsensitiveStr::Ascii("picalisations"),
        dictgen::InsensitiveStr::Ascii("picalise"),
        dictgen::InsensitiveStr::Ascii("picalised"),
        dictgen::InsensitiveStr::Ascii("picalises"),
        dictgen::InsensitiveStr::Ascii("picalising"),
        dictgen::InsensitiveStr::Ascii("picalization"),
        dictgen::InsensitiveStr::Ascii("picalizations"),
        dictgen::InsensitiveStr::Ascii("picalize"),
        dictgen::InsensitiveStr::Ascii("picalized"),
        dictgen::InsensitiveStr::Ascii("picalizes"),
        dictgen::InsensitiveStr::Ascii("picalizing"),
        dictgen::InsensitiveStr::Ascii("weled"),
        dictgen::InsensitiveStr::Ascii("weler"),
        dictgen::InsensitiveStr::Ascii("welers"),
        dictgen::InsensitiveStr::Ascii("weling"),
        dictgen::InsensitiveStr::Ascii("welled"),
        dictgen::InsensitiveStr::Ascii("weller"),
        dictgen::InsensitiveStr::Ascii("wellers"),
        dictgen::InsensitiveStr::Ascii("welling"),
    ],
    values: &[
        &[(0b01001, &ENTRY_TROLLEYED_2326301207880015686)],
        &[(0b01001, &ENTRY_TROLLEYS_15846935468965102939)],
        &[(0b01001, &ENTRY_TROLLEY_2675453022762314926)],
        &[(0b01001, &ENTRY_TROLLEYING_17091158982650946031)],
        &[(0b11010, &ENTRY_TROPEOLIN_11129034624822593004)],
        &[(0b00001, &ENTRY_TROPEOLIN_11129034624822593004)],
        &[(0b10010, &ENTRY_TROPICALIZATION_18295465115231295361)],
        &[(0b10010, &ENTRY_TROPICALIZATIONS_3375832420561780384)],
        &[(0b10010, &ENTRY_TROPICALIZE_7545317329361009163)],
        &[(0b10010, &ENTRY_TROPICALIZED_589331846440359754)],
        &[(0b10010, &ENTRY_TROPICALIZES_14959220215274917474)],
        &[(0b10010, &ENTRY_TROPICALIZING_948054175332116966)],
        &[(0b01001, &ENTRY_TROPICALIZATION_18295465115231295361)],
        &[(0b01001, &ENTRY_TROPICALIZATIONS_3375832420561780384)],
        &[(0b01001, &ENTRY_TROPICALIZE_7545317329361009163)],
        &[(0b01001, &ENTRY_TROPICALIZED_589331846440359754)],
        &[(0b01001, &ENTRY_TROPICALIZES_14959220215274917474)],
        &[(0b01001, &ENTRY_TROPICALIZING_948054175332116966)],
        &[(0b00001, &ENTRY_TROWELED_16175988571968784498)],
        &[(0b00001, &ENTRY_TROWELER_2942313313867997998)],
        &[(0b00001, &ENTRY_TROWELERS_4785737354793055182)],
        &[(0b00001, &ENTRY_TROWELING_8006341101894809093)],
        &[(0b11010, &ENTRY_TROWELED_16175988571968784498)],
        &[(0b11010, &ENTRY_TROWELER_2942313313867997998)],
        &[(0b11010, &ENTRY_TROWELERS_4785737354793055182)],
        &[(0b11010, &ENTRY_TROWELING_8006341101894809093)],
    ],
    range: 3..=13,
};

static VARS_TRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TRI_CHILDREN),
    value: None,
};

static VARS_TRI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_TRIA_NODE),
    None,
    Some(&VARS_TRIC_NODE),
    None,
    Some(&VARS_TRIE_NODE),
    Some(&VARS_TRIF_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TRIL_NODE),
    Some(&VARS_TRIM_NODE),
    None,
    Some(&VARS_TRIO_NODE),
    Some(&VARS_TRIP_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TRIV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_TRIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIV_CHILDREN),
    value: None,
};

pub static VARS_TRIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialisation"),
        dictgen::InsensitiveStr::Ascii("ialisations"),
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialised"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialising"),
        dictgen::InsensitiveStr::Ascii("ialization"),
        dictgen::InsensitiveStr::Ascii("ializations"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ialized"),
        dictgen::InsensitiveStr::Ascii("ializes"),
        dictgen::InsensitiveStr::Ascii("ializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRIVIALIZATION_11133234604148815742)],
        &[(0b10010, &ENTRY_TRIVIALIZATIONS_17093718113863109033)],
        &[(0b10010, &ENTRY_TRIVIALIZE_13642761010371027521)],
        &[(0b10010, &ENTRY_TRIVIALIZED_8435647137273948084)],
        &[(0b10010, &ENTRY_TRIVIALIZES_11774779970344017336)],
        &[(0b10010, &ENTRY_TRIVIALIZING_17871312244441571781)],
        &[(0b01001, &ENTRY_TRIVIALIZATION_11133234604148815742)],
        &[(0b01001, &ENTRY_TRIVIALIZATIONS_17093718113863109033)],
        &[(0b01001, &ENTRY_TRIVIALIZE_13642761010371027521)],
        &[(0b01001, &ENTRY_TRIVIALIZED_8435647137273948084)],
        &[(0b01001, &ENTRY_TRIVIALIZES_11774779970344017336)],
        &[(0b01001, &ENTRY_TRIVIALIZING_17871312244441571781)],
    ],
    range: 6..=11,
};

static VARS_TRIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIP_CHILDREN),
    value: None,
};

pub static VARS_TRIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ylaean"),
        dictgen::InsensitiveStr::Ascii("ylean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TRIPYLEAN_1116498160287785389)],
        &[(0b00001, &ENTRY_TRIPYLEAN_1116498160287785389)],
    ],
    range: 5..=6,
};

static VARS_TRIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIO_CHILDREN),
    value: None,
};

pub static VARS_TRIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecious"),
        dictgen::InsensitiveStr::Ascii("eciously"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TRIECIOUS_3842029489913770676)],
        &[(0b11010, &ENTRY_TRIECIOUSLY_7922278146886669503)],
    ],
    range: 6..=8,
};

static VARS_TRIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIM_CHILDREN),
    value: None,
};

pub static VARS_TRIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRIMERIZATION_12367654888953950560)],
        &[(0b10010, &ENTRY_TRIMERIZATIONS_10322066681410269501)],
        &[(0b01001, &ENTRY_TRIMERIZATION_12367654888953950560)],
        &[(0b01001, &ENTRY_TRIMERIZATIONS_10322066681410269501)],
    ],
    range: 9..=10,
};

static VARS_TRIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIL_CHILDREN),
    value: None,
};

pub static VARS_TRIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lionise"),
        dictgen::InsensitiveStr::Ascii("lionises"),
        dictgen::InsensitiveStr::Ascii("lionize"),
        dictgen::InsensitiveStr::Ascii("lionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRILLIONIZE_4734097264302557230)],
        &[(0b10010, &ENTRY_TRILLIONIZES_13953946126184031801)],
        &[(0b01001, &ENTRY_TRILLIONIZE_4734097264302557230)],
        &[(0b01001, &ENTRY_TRILLIONIZES_13953946126184031801)],
    ],
    range: 7..=8,
};

static VARS_TRIF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIF_CHILDREN),
    value: None,
};

pub static VARS_TRIF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("luoride"),
        dictgen::InsensitiveStr::Ascii("luouride"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TRIFLUORIDE_17366033347483454107)],
        &[(0b11010, &ENTRY_TRIFLUORIDE_17366033347483454107)],
    ],
    range: 7..=8,
};

static VARS_TRIE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIE_CHILDREN),
    value: None,
};

pub static VARS_TRIE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cious"),
        dictgen::InsensitiveStr::Ascii("ciously"),
        dictgen::InsensitiveStr::Ascii("ne"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TRIECIOUS_3842029489913770676)],
        &[(0b00001, &ENTRY_TRIECIOUSLY_7922278146886669503)],
        &[(0b00001, &ENTRY_TRIENE_598294200440119271)],
    ],
    range: 2..=7,
};

static VARS_TRIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIC_CHILDREN),
    value: None,
};

pub static VARS_TRIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hinisation"),
        dictgen::InsensitiveStr::Ascii("hinisations"),
        dictgen::InsensitiveStr::Ascii("hinise"),
        dictgen::InsensitiveStr::Ascii("hinised"),
        dictgen::InsensitiveStr::Ascii("hinises"),
        dictgen::InsensitiveStr::Ascii("hinising"),
        dictgen::InsensitiveStr::Ascii("hinization"),
        dictgen::InsensitiveStr::Ascii("hinizations"),
        dictgen::InsensitiveStr::Ascii("hinize"),
        dictgen::InsensitiveStr::Ascii("hinized"),
        dictgen::InsensitiveStr::Ascii("hinizes"),
        dictgen::InsensitiveStr::Ascii("hinizing"),
        dictgen::InsensitiveStr::Ascii("hlorethylene"),
        dictgen::InsensitiveStr::Ascii("hlorethylenes"),
        dictgen::InsensitiveStr::Ascii("hloroethylene"),
        dictgen::InsensitiveStr::Ascii("hloroethylenes"),
        dictgen::InsensitiveStr::Ascii("hotomise"),
        dictgen::InsensitiveStr::Ascii("hotomised"),
        dictgen::InsensitiveStr::Ascii("hotomises"),
        dictgen::InsensitiveStr::Ascii("hotomising"),
        dictgen::InsensitiveStr::Ascii("hotomize"),
        dictgen::InsensitiveStr::Ascii("hotomized"),
        dictgen::InsensitiveStr::Ascii("hotomizes"),
        dictgen::InsensitiveStr::Ascii("hotomizing"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRICHINIZATION_12518130469368987248)],
        &[(0b10010, &ENTRY_TRICHINIZATIONS_13242264320111003982)],
        &[(0b10010, &ENTRY_TRICHINIZE_3923291936760431626)],
        &[(0b10010, &ENTRY_TRICHINIZED_10756252058763715248)],
        &[(0b10010, &ENTRY_TRICHINIZES_6073383250924787697)],
        &[(0b10010, &ENTRY_TRICHINIZING_2159439015116993657)],
        &[(0b01001, &ENTRY_TRICHINIZATION_12518130469368987248)],
        &[(0b01001, &ENTRY_TRICHINIZATIONS_13242264320111003982)],
        &[(0b01001, &ENTRY_TRICHINIZE_3923291936760431626)],
        &[(0b01001, &ENTRY_TRICHINIZED_10756252058763715248)],
        &[(0b01001, &ENTRY_TRICHINIZES_6073383250924787697)],
        &[(0b01001, &ENTRY_TRICHINIZING_2159439015116993657)],
        &[(0b00001, &ENTRY_TRICHLORETHYLENE_1062872366464151876)],
        &[(0b00001, &ENTRY_TRICHLORETHYLENES_6072021734774211936)],
        &[(0b11010, &ENTRY_TRICHLORETHYLENE_1062872366464151876)],
        &[(0b11010, &ENTRY_TRICHLORETHYLENES_6072021734774211936)],
        &[(0b10010, &ENTRY_TRICHOTOMIZE_15473320973771264574)],
        &[(0b10010, &ENTRY_TRICHOTOMIZED_9184703386860666893)],
        &[(0b10010, &ENTRY_TRICHOTOMIZES_12020126936108650104)],
        &[(0b10010, &ENTRY_TRICHOTOMIZING_8784936411896560417)],
        &[(0b01001, &ENTRY_TRICHOTOMIZE_15473320973771264574)],
        &[(0b01001, &ENTRY_TRICHOTOMIZED_9184703386860666893)],
        &[(0b01001, &ENTRY_TRICHOTOMIZES_12020126936108650104)],
        &[(0b01001, &ENTRY_TRICHOTOMIZING_8784936411896560417)],
        &[(0b00001, &ENTRY_TRICOLOR_6878353089897790870)],
        &[(0b00001, &ENTRY_TRICOLORED_12832711238932201350)],
        &[(0b00001, &ENTRY_TRICOLORS_317578575228167243)],
        &[(0b11010, &ENTRY_TRICOLOR_6878353089897790870)],
        &[(0b11010, &ENTRY_TRICOLORED_12832711238932201350)],
        &[(0b11010, &ENTRY_TRICOLORS_317578575228167243)],
    ],
    range: 4..=14,
};

static VARS_TRIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIA_CHILDREN),
    value: None,
};

pub static VARS_TRIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ene"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("ngularisation"),
        dictgen::InsensitiveStr::Ascii("ngularisations"),
        dictgen::InsensitiveStr::Ascii("ngularise"),
        dictgen::InsensitiveStr::Ascii("ngularised"),
        dictgen::InsensitiveStr::Ascii("ngularises"),
        dictgen::InsensitiveStr::Ascii("ngularising"),
        dictgen::InsensitiveStr::Ascii("ngularization"),
        dictgen::InsensitiveStr::Ascii("ngularizations"),
        dictgen::InsensitiveStr::Ascii("ngularize"),
        dictgen::InsensitiveStr::Ascii("ngularized"),
        dictgen::InsensitiveStr::Ascii("ngularizes"),
        dictgen::InsensitiveStr::Ascii("ngularizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TRIENE_598294200440119271)],
        &[(0b00001, &ENTRY_TRIALED_10369074344397465464)],
        &[(0b00001, &ENTRY_TRIALING_1943354202061564251)],
        &[(0b10010, &ENTRY_TRIALIZATION_7429749590733864558)],
        &[(0b01001, &ENTRY_TRIALIZATION_7429749590733864558)],
        &[(0b11010, &ENTRY_TRIALED_10369074344397465464)],
        &[(0b11010, &ENTRY_TRIALING_1943354202061564251)],
        &[(0b10010, &ENTRY_TRIANGULARIZATION_11880935622434099592)],
        &[(0b10010, &ENTRY_TRIANGULARIZATIONS_2847254552707906191)],
        &[(0b10010, &ENTRY_TRIANGULARIZE_5069515505643652473)],
        &[(0b10010, &ENTRY_TRIANGULARIZED_316621578848709902)],
        &[(0b10010, &ENTRY_TRIANGULARIZES_16630166476295389567)],
        &[(0b10010, &ENTRY_TRIANGULARIZING_7147507037724540086)],
        &[(0b01001, &ENTRY_TRIANGULARIZATION_11880935622434099592)],
        &[(0b01001, &ENTRY_TRIANGULARIZATIONS_2847254552707906191)],
        &[(0b01001, &ENTRY_TRIANGULARIZE_5069515505643652473)],
        &[(0b01001, &ENTRY_TRIANGULARIZED_316621578848709902)],
        &[(0b01001, &ENTRY_TRIANGULARIZES_16630166476295389567)],
        &[(0b01001, &ENTRY_TRIANGULARIZING_7147507037724540086)],
    ],
    range: 3..=14,
};

static VARS_TRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRE_CHILDREN),
    value: None,
};

pub static VARS_TRE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("f"),
        dictgen::InsensitiveStr::Ascii("ma"),
        dictgen::InsensitiveStr::Ascii("matic"),
        dictgen::InsensitiveStr::Ascii("ts"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TERF_10018438021336944491)],
        &[(0b11010, &ENTRY_TERMA_17003310983688444980)],
        &[(0b11010, &ENTRY_TERMATIC_12196187078337402107)],
        &[(0b11010, &ENTRY_TERTS_13499660719155856568)],
    ],
    range: 1..=5,
};

static VARS_TRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TRA_CHILDREN),
    value: None,
};

static VARS_TRA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_TRAB_NODE),
    Some(&VARS_TRAC_NODE),
    Some(&VARS_TRAD_NODE),
    None,
    None,
    Some(&VARS_TRAG_NODE),
    None,
    Some(&VARS_TRAI_NODE),
    None,
    None,
    None,
    Some(&VARS_TRAM_NODE),
    Some(&VARS_TRAN_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TRAU_NODE),
    Some(&VARS_TRAV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_TRAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAV_CHILDREN),
    value: None,
};

pub static VARS_TRAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
        dictgen::InsensitiveStr::Ascii("elog"),
        dictgen::InsensitiveStr::Ascii("elogs"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TRAVELED_435534264813308465)],
        &[(0b00001, &ENTRY_TRAVELER_10167238839538419147)],
        &[(0b00001, &ENTRY_TRAVELERS_16181301710981832055)],
        &[(0b00001, &ENTRY_TRAVELING_3424866904821184310)],
        &[(0b00001, &ENTRY_TRAVELINGS_6548611322609842336)],
        &[(0b11010, &ENTRY_TRAVELED_435534264813308465)],
        &[(0b11010, &ENTRY_TRAVELER_10167238839538419147)],
        &[(0b11010, &ENTRY_TRAVELERS_16181301710981832055)],
        &[(0b11010, &ENTRY_TRAVELING_3424866904821184310)],
        &[(0b11010, &ENTRY_TRAVELINGS_6548611322609842336)],
        &[(0b00001, &ENTRY_TRAVELOGUE_2518512371096354483)],
        &[(0b00001, &ENTRY_TRAVELOGUES_17520213145795989298)],
    ],
    range: 4..=7,
};

static VARS_TRAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAU_CHILDREN),
    value: None,
};

pub static VARS_TRAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matisation"),
        dictgen::InsensitiveStr::Ascii("matisations"),
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matization"),
        dictgen::InsensitiveStr::Ascii("matizations"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRAUMATIZATION_15736086621227074923)],
        &[(0b10010, &ENTRY_TRAUMATIZATIONS_4401483376475543285)],
        &[(0b10010, &ENTRY_TRAUMATIZE_7046895873965760654)],
        &[(0b10010, &ENTRY_TRAUMATIZED_625907274700949941)],
        &[(0b10010, &ENTRY_TRAUMATIZES_1060950316018981423)],
        &[(0b10010, &ENTRY_TRAUMATIZING_11107301809578264309)],
        &[(0b01001, &ENTRY_TRAUMATIZATION_15736086621227074923)],
        &[(0b01001, &ENTRY_TRAUMATIZATIONS_4401483376475543285)],
        &[(0b01001, &ENTRY_TRAUMATIZE_7046895873965760654)],
        &[(0b01001, &ENTRY_TRAUMATIZED_625907274700949941)],
        &[(0b01001, &ENTRY_TRAUMATIZES_1060950316018981423)],
        &[(0b01001, &ENTRY_TRAUMATIZING_11107301809578264309)],
    ],
    range: 6..=11,
};

static VARS_TRAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TRAN_CHILDREN),
    value: None,
};

static VARS_TRAN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TRANQ_NODE),
    None,
    Some(&VARS_TRANS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_TRANS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRANS_CHILDREN),
    value: None,
};

pub static VARS_TRANS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cendentalisation"),
        dictgen::InsensitiveStr::Ascii("cendentalise"),
        dictgen::InsensitiveStr::Ascii("cendentalised"),
        dictgen::InsensitiveStr::Ascii("cendentalises"),
        dictgen::InsensitiveStr::Ascii("cendentalising"),
        dictgen::InsensitiveStr::Ascii("cendentalization"),
        dictgen::InsensitiveStr::Ascii("cendentalize"),
        dictgen::InsensitiveStr::Ascii("cendentalized"),
        dictgen::InsensitiveStr::Ascii("cendentalizes"),
        dictgen::InsensitiveStr::Ascii("cendentalizing"),
        dictgen::InsensitiveStr::Ascii("color"),
        dictgen::InsensitiveStr::Ascii("coloration"),
        dictgen::InsensitiveStr::Ascii("colorations"),
        dictgen::InsensitiveStr::Ascii("colorrer"),
        dictgen::InsensitiveStr::Ascii("colorrest"),
        dictgen::InsensitiveStr::Ascii("colour"),
        dictgen::InsensitiveStr::Ascii("colouration"),
        dictgen::InsensitiveStr::Ascii("colourations"),
        dictgen::InsensitiveStr::Ascii("colourer"),
        dictgen::InsensitiveStr::Ascii("colourest"),
        dictgen::InsensitiveStr::Ascii("istorisation"),
        dictgen::InsensitiveStr::Ascii("istorisations"),
        dictgen::InsensitiveStr::Ascii("istorise"),
        dictgen::InsensitiveStr::Ascii("istorised"),
        dictgen::InsensitiveStr::Ascii("istorises"),
        dictgen::InsensitiveStr::Ascii("istorising"),
        dictgen::InsensitiveStr::Ascii("istorization"),
        dictgen::InsensitiveStr::Ascii("istorizations"),
        dictgen::InsensitiveStr::Ascii("istorize"),
        dictgen::InsensitiveStr::Ascii("istorized"),
        dictgen::InsensitiveStr::Ascii("istorizes"),
        dictgen::InsensitiveStr::Ascii("istorizing"),
        dictgen::InsensitiveStr::Ascii("parentise"),
        dictgen::InsensitiveStr::Ascii("parentises"),
        dictgen::InsensitiveStr::Ascii("parentize"),
        dictgen::InsensitiveStr::Ascii("parentizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRANSCENDENTALIZATION_6781743576453143825)],
        &[(0b10010, &ENTRY_TRANSCENDENTALIZE_13136573359465624270)],
        &[(0b10010, &ENTRY_TRANSCENDENTALIZED_13133269603388695422)],
        &[(0b10010, &ENTRY_TRANSCENDENTALIZES_12319891228277271967)],
        &[(0b10010, &ENTRY_TRANSCENDENTALIZING_8443717951335927533)],
        &[(0b01001, &ENTRY_TRANSCENDENTALIZATION_6781743576453143825)],
        &[(0b01001, &ENTRY_TRANSCENDENTALIZE_13136573359465624270)],
        &[(0b01001, &ENTRY_TRANSCENDENTALIZED_13133269603388695422)],
        &[(0b01001, &ENTRY_TRANSCENDENTALIZES_12319891228277271967)],
        &[(0b01001, &ENTRY_TRANSCENDENTALIZING_8443717951335927533)],
        &[(0b00001, &ENTRY_TRANSCOLOR_14513330795644506999)],
        &[(0b00001, &ENTRY_TRANSCOLORATION_12023847350297738149)],
        &[(0b00001, &ENTRY_TRANSCOLORATIONS_15325443151749901762)],
        &[(0b00001, &ENTRY_TRANSCOLORRER_685668977539818943)],
        &[(0b00001, &ENTRY_TRANSCOLORREST_14875749018909758575)],
        &[(0b11010, &ENTRY_TRANSCOLOR_14513330795644506999)],
        &[(0b11010, &ENTRY_TRANSCOLORATION_12023847350297738149)],
        &[(0b11010, &ENTRY_TRANSCOLORATIONS_15325443151749901762)],
        &[(0b11010, &ENTRY_TRANSCOLORRER_685668977539818943)],
        &[(0b11010, &ENTRY_TRANSCOLORREST_14875749018909758575)],
        &[(0b10010, &ENTRY_TRANSISTORIZATION_2213289518183297786)],
        &[(0b10010, &ENTRY_TRANSISTORIZATIONS_14253078267757725459)],
        &[(0b10010, &ENTRY_TRANSISTORIZE_10887604825192662062)],
        &[(0b10010, &ENTRY_TRANSISTORIZED_6257541205718300499)],
        &[(0b10010, &ENTRY_TRANSISTORIZES_5429831375135101974)],
        &[(0b10010, &ENTRY_TRANSISTORIZING_15414761324720715044)],
        &[(0b01001, &ENTRY_TRANSISTORIZATION_2213289518183297786)],
        &[(0b01001, &ENTRY_TRANSISTORIZATIONS_14253078267757725459)],
        &[(0b01001, &ENTRY_TRANSISTORIZE_10887604825192662062)],
        &[(0b01001, &ENTRY_TRANSISTORIZED_6257541205718300499)],
        &[(0b01001, &ENTRY_TRANSISTORIZES_5429831375135101974)],
        &[(0b01001, &ENTRY_TRANSISTORIZING_15414761324720715044)],
        &[(0b10010, &ENTRY_TRANSPARENTIZE_6759875278002638428)],
        &[(0b10010, &ENTRY_TRANSPARENTIZES_428422769291744990)],
        &[(0b01001, &ENTRY_TRANSPARENTIZE_6759875278002638428)],
        &[(0b01001, &ENTRY_TRANSPARENTIZES_428422769291744990)],
    ],
    range: 5..=16,
};

static VARS_TRANQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRANQ_CHILDREN),
    value: None,
};

pub static VARS_TRANQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uilisation"),
        dictgen::InsensitiveStr::Ascii("uilisations"),
        dictgen::InsensitiveStr::Ascii("uilisingly"),
        dictgen::InsensitiveStr::Ascii("uilization"),
        dictgen::InsensitiveStr::Ascii("uilizations"),
        dictgen::InsensitiveStr::Ascii("uilize"),
        dictgen::InsensitiveStr::Ascii("uilized"),
        dictgen::InsensitiveStr::Ascii("uilizer"),
        dictgen::InsensitiveStr::Ascii("uilizers"),
        dictgen::InsensitiveStr::Ascii("uilizes"),
        dictgen::InsensitiveStr::Ascii("uilizing"),
        dictgen::InsensitiveStr::Ascii("uilizingly"),
        dictgen::InsensitiveStr::Ascii("uilizings"),
        dictgen::InsensitiveStr::Ascii("uillisation"),
        dictgen::InsensitiveStr::Ascii("uillisations"),
        dictgen::InsensitiveStr::Ascii("uillise"),
        dictgen::InsensitiveStr::Ascii("uillised"),
        dictgen::InsensitiveStr::Ascii("uilliser"),
        dictgen::InsensitiveStr::Ascii("uillisers"),
        dictgen::InsensitiveStr::Ascii("uillises"),
        dictgen::InsensitiveStr::Ascii("uillising"),
        dictgen::InsensitiveStr::Ascii("uillisingly"),
        dictgen::InsensitiveStr::Ascii("uillisings"),
        dictgen::InsensitiveStr::Ascii("uillities"),
        dictgen::InsensitiveStr::Ascii("uillity"),
        dictgen::InsensitiveStr::Ascii("uillization"),
        dictgen::InsensitiveStr::Ascii("uillizations"),
        dictgen::InsensitiveStr::Ascii("uillize"),
        dictgen::InsensitiveStr::Ascii("uillized"),
        dictgen::InsensitiveStr::Ascii("uillizer"),
        dictgen::InsensitiveStr::Ascii("uillizers"),
        dictgen::InsensitiveStr::Ascii("uillizes"),
        dictgen::InsensitiveStr::Ascii("uillizing"),
        dictgen::InsensitiveStr::Ascii("uillizingly"),
        dictgen::InsensitiveStr::Ascii("uillizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRANQUILIZATION_5521617584193917818)],
        &[(0b10010, &ENTRY_TRANQUILIZATIONS_12380036249843910188)],
        &[(0b10010, &ENTRY_TRANQUILIZINGLY_8937506465456562211)],
        &[(0b01001, &ENTRY_TRANQUILIZATION_5521617584193917818)],
        &[(0b01001, &ENTRY_TRANQUILIZATIONS_12380036249843910188)],
        &[(0b01001, &ENTRY_TRANQUILIZE_2318549175902793795)],
        &[(0b01001, &ENTRY_TRANQUILIZED_12211443123255939369)],
        &[(0b01001, &ENTRY_TRANQUILIZER_4580963450554408865)],
        &[(0b01001, &ENTRY_TRANQUILIZERS_9011655985998697530)],
        &[(0b01001, &ENTRY_TRANQUILIZES_8944342824362588640)],
        &[(0b01001, &ENTRY_TRANQUILIZING_16473900108179388526)],
        &[(0b01001, &ENTRY_TRANQUILIZINGLY_8937506465456562211)],
        &[(0b01001, &ENTRY_TRANQUILIZINGS_14161142259051334768)],
        &[(0b10010, &ENTRY_TRANQUILLIZATION_3282376332675248379)],
        &[(0b10010, &ENTRY_TRANQUILLIZATIONS_15246245753023469100)],
        &[(0b11010, &ENTRY_TRANQUILIZE_2318549175902793795)],
        &[(0b11010, &ENTRY_TRANQUILIZED_12211443123255939369)],
        &[(0b11010, &ENTRY_TRANQUILIZER_4580963450554408865)],
        &[(0b11010, &ENTRY_TRANQUILIZERS_9011655985998697530)],
        &[(0b11010, &ENTRY_TRANQUILIZES_8944342824362588640)],
        &[(0b11010, &ENTRY_TRANQUILIZING_16473900108179388526)],
        &[(0b10010, &ENTRY_TRANQUILLIZINGLY_12353888190974020557)],
        &[(0b11010, &ENTRY_TRANQUILIZINGS_14161142259051334768)],
        &[(0b10011, &ENTRY_TRANQUILITIES_14597029814491190009)],
        &[(0b10011, &ENTRY_TRANQUILITY_17026669099016984269)],
        &[(0b01001, &ENTRY_TRANQUILLIZATION_3282376332675248379)],
        &[(0b01001, &ENTRY_TRANQUILLIZATIONS_15246245753023469100)],
        &[(0b01001, &ENTRY_TRANQUILIZE_2318549175902793795)],
        &[(0b01001, &ENTRY_TRANQUILIZED_12211443123255939369)],
        &[(0b01001, &ENTRY_TRANQUILIZER_4580963450554408865)],
        &[(0b01001, &ENTRY_TRANQUILIZERS_9011655985998697530)],
        &[(0b01001, &ENTRY_TRANQUILIZES_8944342824362588640)],
        &[(0b01001, &ENTRY_TRANQUILIZING_16473900108179388526)],
        &[(0b01001, &ENTRY_TRANQUILLIZINGLY_12353888190974020557)],
        &[(0b01001, &ENTRY_TRANQUILIZINGS_14161142259051334768)],
    ],
    range: 6..=12,
};

static VARS_TRAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAM_CHILDREN),
    value: None,
};

pub static VARS_TRAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("meled"),
        dictgen::InsensitiveStr::Ascii("meler"),
        dictgen::InsensitiveStr::Ascii("melers"),
        dictgen::InsensitiveStr::Ascii("meling"),
        dictgen::InsensitiveStr::Ascii("melled"),
        dictgen::InsensitiveStr::Ascii("meller"),
        dictgen::InsensitiveStr::Ascii("mellers"),
        dictgen::InsensitiveStr::Ascii("melling"),
    ],
    values: &[
        &[(0b01001, &ENTRY_TRAMMELED_8060808627087874636)],
        &[(0b00001, &ENTRY_TRAMMELER_9827725773053804702)],
        &[(0b00001, &ENTRY_TRAMMELERS_17026265261107245670)],
        &[(0b01001, &ENTRY_TRAMMELING_6888018546127671609)],
        &[(0b11010, &ENTRY_TRAMMELED_8060808627087874636)],
        &[(0b11010, &ENTRY_TRAMMELER_9827725773053804702)],
        &[(0b11010, &ENTRY_TRAMMELERS_17026265261107245670)],
        &[(0b11010, &ENTRY_TRAMMELING_6888018546127671609)],
    ],
    range: 5..=7,
};

static VARS_TRAI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAI_CHILDREN),
    value: None,
};

pub static VARS_TRAI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRAITORIZE_13903037963874437628)],
        &[(0b10010, &ENTRY_TRAITORIZES_6117010440470228630)],
        &[(0b01001, &ENTRY_TRAITORIZE_13903037963874437628)],
        &[(0b01001, &ENTRY_TRAITORIZES_6117010440470228630)],
    ],
    range: 6..=7,
};

static VARS_TRAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAG_CHILDREN),
    value: None,
};

pub static VARS_TRAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icolored"),
        dictgen::InsensitiveStr::Ascii("icoloured"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRAGICIZE_13682460226835988470)],
        &[(0b10010, &ENTRY_TRAGICIZES_3989913928010417742)],
        &[(0b01001, &ENTRY_TRAGICIZE_13682460226835988470)],
        &[(0b01001, &ENTRY_TRAGICIZES_3989913928010417742)],
        &[(0b00001, &ENTRY_TRAGICOLORED_2720904369140832474)],
        &[(0b11010, &ENTRY_TRAGICOLORED_2720904369140832474)],
    ],
    range: 5..=9,
};

static VARS_TRAD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAD_CHILDREN),
    value: None,
};

pub static VARS_TRAD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itionalise"),
        dictgen::InsensitiveStr::Ascii("itionalised"),
        dictgen::InsensitiveStr::Ascii("itionalises"),
        dictgen::InsensitiveStr::Ascii("itionalize"),
        dictgen::InsensitiveStr::Ascii("itionalized"),
        dictgen::InsensitiveStr::Ascii("itionalizes"),
        dictgen::InsensitiveStr::Ascii("itionise"),
        dictgen::InsensitiveStr::Ascii("itionises"),
        dictgen::InsensitiveStr::Ascii("itionize"),
        dictgen::InsensitiveStr::Ascii("itionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRADITIONALIZE_2456697841812175322)],
        &[(0b10010, &ENTRY_TRADITIONALIZED_7379142112845457397)],
        &[(0b10010, &ENTRY_TRADITIONALIZES_4915966875918551718)],
        &[(0b01001, &ENTRY_TRADITIONALIZE_2456697841812175322)],
        &[(0b01001, &ENTRY_TRADITIONALIZED_7379142112845457397)],
        &[(0b01001, &ENTRY_TRADITIONALIZES_4915966875918551718)],
        &[(0b10010, &ENTRY_TRADITIONIZE_5364897103719523136)],
        &[(0b10010, &ENTRY_TRADITIONIZES_8267674418394695252)],
        &[(0b01001, &ENTRY_TRADITIONIZE_5364897103719523136)],
        &[(0b01001, &ENTRY_TRADITIONIZES_8267674418394695252)],
    ],
    range: 8..=11,
};

static VARS_TRAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAC_CHILDREN),
    value: None,
};

pub static VARS_TRAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("torisation"),
        dictgen::InsensitiveStr::Ascii("torisations"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torization"),
        dictgen::InsensitiveStr::Ascii("torizations"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRACTORIZATION_10992127938217075731)],
        &[(0b10010, &ENTRY_TRACTORIZATIONS_339031056491180798)],
        &[(0b10010, &ENTRY_TRACTORIZE_2241099676594242440)],
        &[(0b10010, &ENTRY_TRACTORIZES_15847189337277496859)],
        &[(0b01001, &ENTRY_TRACTORIZATION_10992127938217075731)],
        &[(0b01001, &ENTRY_TRACTORIZATIONS_339031056491180798)],
        &[(0b01001, &ENTRY_TRACTORIZE_2241099676594242440)],
        &[(0b01001, &ENTRY_TRACTORIZES_15847189337277496859)],
    ],
    range: 6..=11,
};

static VARS_TRAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAB_CHILDREN),
    value: None,
};

pub static VARS_TRAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eatae"),
        dictgen::InsensitiveStr::Ascii("eate"),
        dictgen::InsensitiveStr::Ascii("eculae"),
        dictgen::InsensitiveStr::Ascii("ecule"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TRABEATE_483987459575339818)],
        &[(0b00001, &ENTRY_TRABEATE_483987459575339818)],
        &[(0b11010, &ENTRY_TRABECULE_15772862836097815)],
        &[(0b00001, &ENTRY_TRABECULE_15772862836097815)],
    ],
    range: 4..=6,
};

static VARS_TO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TO_CHILDREN),
    value: None,
};

static VARS_TO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TON_NODE),
    None,
    Some(&VARS_TOP_NODE),
    None,
    Some(&VARS_TOR_NODE),
    None,
    Some(&VARS_TOT_NODE),
    Some(&VARS_TOU_NODE),
    None,
    Some(&VARS_TOW_NODE),
    Some(&VARS_TOX_NODE),
    None,
    None,
];

static VARS_TOX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TOX_CHILDREN),
    value: None,
};

pub static VARS_TOX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("aemias"),
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("anaemia"),
        dictgen::InsensitiveStr::Ascii("anemia"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emias"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("icaemia"),
        dictgen::InsensitiveStr::Ascii("icemia"),
        dictgen::InsensitiveStr::Ascii("icohaemia"),
        dictgen::InsensitiveStr::Ascii("icohemia"),
        dictgen::InsensitiveStr::Ascii("ihaemia"),
        dictgen::InsensitiveStr::Ascii("ihemia"),
        dictgen::InsensitiveStr::Ascii("inaemia"),
        dictgen::InsensitiveStr::Ascii("inemia"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TOXEMIA_8507561579843698401)],
        &[(0b10010, &ENTRY_TOXEMIAS_6987620895652086802)],
        &[(0b10010, &ENTRY_TOXEMIC_11112870586226499459)],
        &[(0b11010, &ENTRY_TOXANEMIA_17135685765577589935)],
        &[(0b00001, &ENTRY_TOXANEMIA_17135685765577589935)],
        &[(0b11001, &ENTRY_TOXEMIA_8507561579843698401)],
        &[(0b11001, &ENTRY_TOXEMIAS_6987620895652086802)],
        &[(0b11001, &ENTRY_TOXEMIC_11112870586226499459)],
        &[(0b11010, &ENTRY_TOXICEMIA_8873423138860871823)],
        &[(0b00001, &ENTRY_TOXICEMIA_8873423138860871823)],
        &[(0b11010, &ENTRY_TOXICOHEMIA_4773459108436354364)],
        &[(0b00001, &ENTRY_TOXICOHEMIA_4773459108436354364)],
        &[(0b11010, &ENTRY_TOXIHEMIA_3647608395377073910)],
        &[(0b00001, &ENTRY_TOXIHEMIA_3647608395377073910)],
        &[(0b11010, &ENTRY_TOXINEMIA_15164755111459298400)],
        &[(0b00001, &ENTRY_TOXINEMIA_15164755111459298400)],
    ],
    range: 4..=9,
};

static VARS_TOW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TOW_CHILDREN),
    value: None,
};

pub static VARS_TOW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TOWELED_10940852459488171030)],
        &[(0b00001, &ENTRY_TOWELING_1180280283599091589)],
        &[(0b00001, &ENTRY_TOWELINGS_6040236374111337509)],
        &[(0b11010, &ENTRY_TOWELED_10940852459488171030)],
        &[(0b11010, &ENTRY_TOWELING_1180280283599091589)],
        &[(0b11010, &ENTRY_TOWELINGS_6040236374111337509)],
    ],
    range: 4..=7,
};

static VARS_TOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TOU_CHILDREN),
    value: None,
};

pub static VARS_TOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ret"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TORET_9300193947670512159)],
        &[(0b10010, &ENTRY_TOURIZE_8892565616062448746)],
        &[(0b10010, &ENTRY_TOURIZES_17389788493732868673)],
        &[(0b01001, &ENTRY_TOURIZE_8892565616062448746)],
        &[(0b01001, &ENTRY_TOURIZES_17389788493732868673)],
    ],
    range: 3..=5,
};

static VARS_TOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TOT_CHILDREN),
    value: None,
};

pub static VARS_TOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aled"),
        dictgen::InsensitiveStr::Ascii("aler"),
        dictgen::InsensitiveStr::Ascii("alers"),
        dictgen::InsensitiveStr::Ascii("aling"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alisator"),
        dictgen::InsensitiveStr::Ascii("alisators"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alitarianise"),
        dictgen::InsensitiveStr::Ascii("alitarianize"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alizator"),
        dictgen::InsensitiveStr::Ascii("alizators"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("alled"),
        dictgen::InsensitiveStr::Ascii("aller"),
        dictgen::InsensitiveStr::Ascii("allers"),
        dictgen::InsensitiveStr::Ascii("alling"),
        dictgen::InsensitiveStr::Ascii("emisation"),
        dictgen::InsensitiveStr::Ascii("emisations"),
        dictgen::InsensitiveStr::Ascii("emization"),
        dictgen::InsensitiveStr::Ascii("emizations"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TOTALED_16465945397491592065)],
        &[(0b00001, &ENTRY_TOTALER_13889474056076724285)],
        &[(0b00001, &ENTRY_TOTALERS_10161072248298040391)],
        &[(0b00001, &ENTRY_TOTALING_5708433697317878112)],
        &[(0b10010, &ENTRY_TOTALIZATION_677434854617719224)],
        &[(0b10010, &ENTRY_TOTALIZATIONS_12539779961057448289)],
        &[(0b11010, &ENTRY_TOTALIZATOR_4519528537104362408)],
        &[(0b11010, &ENTRY_TOTALIZATORS_1298582278316075613)],
        &[(0b10010, &ENTRY_TOTALIZE_15116326015710861314)],
        &[(0b10010, &ENTRY_TOTALIZED_5947312301455804043)],
        &[(0b10010, &ENTRY_TOTALIZER_9458208321837577997)],
        &[(0b10010, &ENTRY_TOTALIZERS_4514710132472904320)],
        &[(0b10010, &ENTRY_TOTALIZES_9293041034438278469)],
        &[(0b10010, &ENTRY_TOTALIZING_2151125471228422884)],
        &[(0b10010, &ENTRY_TOTALITARIANIZE_17279194250687480990)],
        &[(0b01001, &ENTRY_TOTALITARIANIZE_17279194250687480990)],
        &[(0b01001, &ENTRY_TOTALIZATION_677434854617719224)],
        &[(0b01001, &ENTRY_TOTALIZATIONS_12539779961057448289)],
        &[(0b00001, &ENTRY_TOTALIZATOR_4519528537104362408)],
        &[(0b00001, &ENTRY_TOTALIZATORS_1298582278316075613)],
        &[(0b01001, &ENTRY_TOTALIZE_15116326015710861314)],
        &[(0b01001, &ENTRY_TOTALIZED_5947312301455804043)],
        &[(0b01001, &ENTRY_TOTALIZER_9458208321837577997)],
        &[(0b01001, &ENTRY_TOTALIZERS_4514710132472904320)],
        &[(0b01001, &ENTRY_TOTALIZES_9293041034438278469)],
        &[(0b01001, &ENTRY_TOTALIZING_2151125471228422884)],
        &[(0b11010, &ENTRY_TOTALED_16465945397491592065)],
        &[(0b11010, &ENTRY_TOTALER_13889474056076724285)],
        &[(0b11010, &ENTRY_TOTALERS_10161072248298040391)],
        &[(0b11010, &ENTRY_TOTALING_5708433697317878112)],
        &[(0b10010, &ENTRY_TOTEMIZATION_5945650529175210425)],
        &[(0b10010, &ENTRY_TOTEMIZATIONS_3935483205280312961)],
        &[(0b01001, &ENTRY_TOTEMIZATION_5945650529175210425)],
        &[(0b01001, &ENTRY_TOTEMIZATIONS_3935483205280312961)],
    ],
    range: 4..=12,
};

static VARS_TOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TOR_CHILDREN),
    value: None,
};

pub static VARS_TOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("et"),
        dictgen::InsensitiveStr::Ascii("porise"),
        dictgen::InsensitiveStr::Ascii("porises"),
        dictgen::InsensitiveStr::Ascii("porize"),
        dictgen::InsensitiveStr::Ascii("porizes"),
        dictgen::InsensitiveStr::Ascii("yise"),
        dictgen::InsensitiveStr::Ascii("yises"),
        dictgen::InsensitiveStr::Ascii("yize"),
        dictgen::InsensitiveStr::Ascii("yizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TORET_9300193947670512159)],
        &[(0b10010, &ENTRY_TORPORIZE_18069353743945116344)],
        &[(0b10010, &ENTRY_TORPORIZES_13334911738014548028)],
        &[(0b01001, &ENTRY_TORPORIZE_18069353743945116344)],
        &[(0b01001, &ENTRY_TORPORIZES_13334911738014548028)],
        &[(0b10010, &ENTRY_TORYIZE_995538363033283697)],
        &[(0b10010, &ENTRY_TORYIZES_5132670899591153786)],
        &[(0b01001, &ENTRY_TORYIZE_995538363033283697)],
        &[(0b01001, &ENTRY_TORYIZES_5132670899591153786)],
    ],
    range: 2..=7,
};

static VARS_TOP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TOP_CHILDREN),
    value: None,
};

pub static VARS_TOP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TOPESTHESIA_942978545009231732)],
        &[(0b00001, &ENTRY_TOPESTHESIA_942978545009231732)],
    ],
    range: 8..=9,
};

static VARS_TON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TON_CHILDREN),
    value: None,
};

pub static VARS_TON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TONICIZE_14493332215083535444)],
        &[(0b10010, &ENTRY_TONICIZES_14086969720152558778)],
        &[(0b01001, &ENTRY_TONICIZE_14493332215083535444)],
        &[(0b01001, &ENTRY_TONICIZES_14086969720152558778)],
    ],
    range: 5..=6,
};

static VARS_TI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TI_CHILDREN),
    value: None,
};

pub static VARS_TI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dbit"),
        dictgen::InsensitiveStr::Ascii("dbits"),
        dictgen::InsensitiveStr::Ascii("llford"),
        dictgen::InsensitiveStr::Ascii("llfourd"),
        dictgen::InsensitiveStr::Ascii("monise"),
        dictgen::InsensitiveStr::Ascii("monised"),
        dictgen::InsensitiveStr::Ascii("monises"),
        dictgen::InsensitiveStr::Ascii("monising"),
        dictgen::InsensitiveStr::Ascii("monize"),
        dictgen::InsensitiveStr::Ascii("monized"),
        dictgen::InsensitiveStr::Ascii("monizes"),
        dictgen::InsensitiveStr::Ascii("monizing"),
        dictgen::InsensitiveStr::Ascii("mor"),
        dictgen::InsensitiveStr::Ascii("mour"),
        dictgen::InsensitiveStr::Ascii("nseled"),
        dictgen::InsensitiveStr::Ascii("nselier"),
        dictgen::InsensitiveStr::Ascii("nseliest"),
        dictgen::InsensitiveStr::Ascii("nseling"),
        dictgen::InsensitiveStr::Ascii("nselled"),
        dictgen::InsensitiveStr::Ascii("nsellier"),
        dictgen::InsensitiveStr::Ascii("nselliest"),
        dictgen::InsensitiveStr::Ascii("nselling"),
        dictgen::InsensitiveStr::Ascii("tbit"),
        dictgen::InsensitiveStr::Ascii("tbits"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tres"),
        dictgen::InsensitiveStr::Ascii("ttuped"),
        dictgen::InsensitiveStr::Ascii("ttuping"),
        dictgen::InsensitiveStr::Ascii("ttupped"),
        dictgen::InsensitiveStr::Ascii("ttupping"),
        dictgen::InsensitiveStr::Ascii("ttuppy"),
        dictgen::InsensitiveStr::Ascii("ttupy"),
    ],
    values: &[
        &[(0b01001, &ENTRY_TIDBIT_7805000089381014190)],
        &[(0b01001, &ENTRY_TIDBITS_16344615149357827521)],
        &[(0b00001, &ENTRY_TILLFORD_8277631863674555040)],
        &[(0b11010, &ENTRY_TILLFORD_8277631863674555040)],
        &[(0b10010, &ENTRY_TIMONIZE_17549986461978761475)],
        &[(0b10010, &ENTRY_TIMONIZED_8552612423976383697)],
        &[(0b10010, &ENTRY_TIMONIZES_16937469115549830749)],
        &[(0b10010, &ENTRY_TIMONIZING_4835714890422549178)],
        &[(0b01001, &ENTRY_TIMONIZE_17549986461978761475)],
        &[(0b01001, &ENTRY_TIMONIZED_8552612423976383697)],
        &[(0b01001, &ENTRY_TIMONIZES_16937469115549830749)],
        &[(0b01001, &ENTRY_TIMONIZING_4835714890422549178)],
        &[(0b00001, &ENTRY_TIMOR_2690216955682569292)],
        &[(0b11010, &ENTRY_TIMOR_2690216955682569292)],
        &[(0b01001, &ENTRY_TINSELED_3866509100193036989)],
        &[(0b00001, &ENTRY_TINSELIER_11585655450397053875)],
        &[(0b00001, &ENTRY_TINSELIEST_10668984252057983847)],
        &[(0b01001, &ENTRY_TINSELING_2103793771113344037)],
        &[(0b11010, &ENTRY_TINSELED_3866509100193036989)],
        &[(0b11010, &ENTRY_TINSELIER_11585655450397053875)],
        &[(0b11010, &ENTRY_TINSELIEST_10668984252057983847)],
        &[(0b11010, &ENTRY_TINSELING_2103793771113344037)],
        &[(0b10011, &ENTRY_TIDBIT_7805000089381014190)],
        &[(0b10011, &ENTRY_TIDBITS_16344615149357827521)],
        &[(0b01001, &ENTRY_TITER_8889184709551132501)],
        &[(0b01001, &ENTRY_TITERS_11786621739929986321)],
        &[(0b11010, &ENTRY_TITER_8889184709551132501)],
        &[(0b11010, &ENTRY_TITERS_11786621739929986321)],
        &[(0b00001, &ENTRY_TITTUPED_2906437008152483513)],
        &[(0b00001, &ENTRY_TITTUPING_10006138755530945025)],
        &[(0b11010, &ENTRY_TITTUPED_2906437008152483513)],
        &[(0b11010, &ENTRY_TITTUPING_10006138755530945025)],
        &[(0b11010, &ENTRY_TITTUPY_15226672837677900507)],
        &[(0b00001, &ENTRY_TITTUPY_15226672837677900507)],
    ],
    range: 3..=9,
};

static VARS_TH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TH_CHILDREN),
    value: None,
};

static VARS_TH_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_THA_NODE),
    None,
    None,
    None,
    Some(&VARS_THE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_THR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_THY_NODE),
    None,
];

static VARS_THY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THY_CHILDREN),
    value: None,
};

pub static VARS_THY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mectomise"),
        dictgen::InsensitiveStr::Ascii("mectomize"),
        dictgen::InsensitiveStr::Ascii("roidectomised"),
        dictgen::InsensitiveStr::Ascii("roidectomized"),
        dictgen::InsensitiveStr::Ascii("roidisation"),
        dictgen::InsensitiveStr::Ascii("roidisations"),
        dictgen::InsensitiveStr::Ascii("roidization"),
        dictgen::InsensitiveStr::Ascii("roidizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_THYMECTOMIZE_11505114453378889137)],
        &[(0b01001, &ENTRY_THYMECTOMIZE_11505114453378889137)],
        &[(0b10010, &ENTRY_THYROIDECTOMIZED_14073280712975578866)],
        &[(0b01001, &ENTRY_THYROIDECTOMIZED_14073280712975578866)],
        &[(0b10010, &ENTRY_THYROIDIZATION_3396351276247323991)],
        &[(0b10010, &ENTRY_THYROIDIZATIONS_15631291795213610526)],
        &[(0b01001, &ENTRY_THYROIDIZATION_3396351276247323991)],
        &[(0b01001, &ENTRY_THYROIDIZATIONS_15631291795213610526)],
    ],
    range: 9..=13,
};

static VARS_THR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THR_CHILDREN),
    value: None,
};

pub static VARS_THR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eap"),
        dictgen::InsensitiveStr::Ascii("eeness"),
        dictgen::InsensitiveStr::Ascii("eenesses"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("u"),
        dictgen::InsensitiveStr::Ascii("uway"),
        dictgen::InsensitiveStr::Ascii("uways"),
    ],
    values: &[
        &[(0b11010, &ENTRY_THERAP_9544025308390036027)],
        &[(0b11010, &ENTRY_THERENESS_9852552452824690186)],
        &[(0b11010, &ENTRY_THERENESSES_10801981187729653982)],
        &[(0b10010, &ENTRY_THRONIZE_281314801217953052)],
        &[(0b10010, &ENTRY_THRONIZES_15599592934515323866)],
        &[(0b01001, &ENTRY_THRONIZE_281314801217953052)],
        &[(0b01001, &ENTRY_THRONIZES_15599592934515323866)],
        &[(0b00001, &ENTRY_THROUGH_14009312703153313360)],
        &[(0b10011, &ENTRY_THRUWAY_390000294149739545)],
        &[(0b10011, &ENTRY_THRUWAYS_9243384191667191710)],
    ],
    range: 1..=8,
};

static VARS_THE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_THE_CHILDREN),
    value: None,
};

static VARS_THE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_THEA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_THEO_NODE),
    None,
    None,
    Some(&VARS_THER_NODE),
    Some(&VARS_THES_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_THES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THES_CHILDREN),
    value: None,
};

pub static VARS_THES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mothetae"),
        dictgen::InsensitiveStr::Ascii("mothete"),
    ],
    values: &[
        &[(0b11010, &ENTRY_THESMOTHETE_15046146759292701834)],
        &[(0b00001, &ENTRY_THESMOTHETE_15046146759292701834)],
    ],
    range: 7..=8,
};

static VARS_THER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THER_CHILDREN),
    value: None,
};

pub static VARS_THER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ap"),
        dictgen::InsensitiveStr::Ascii("eness"),
        dictgen::InsensitiveStr::Ascii("enesses"),
        dictgen::InsensitiveStr::Ascii("mae"),
        dictgen::InsensitiveStr::Ascii("malisation"),
        dictgen::InsensitiveStr::Ascii("malisations"),
        dictgen::InsensitiveStr::Ascii("malise"),
        dictgen::InsensitiveStr::Ascii("malised"),
        dictgen::InsensitiveStr::Ascii("malises"),
        dictgen::InsensitiveStr::Ascii("malising"),
        dictgen::InsensitiveStr::Ascii("malization"),
        dictgen::InsensitiveStr::Ascii("malizations"),
        dictgen::InsensitiveStr::Ascii("malize"),
        dictgen::InsensitiveStr::Ascii("malized"),
        dictgen::InsensitiveStr::Ascii("malizes"),
        dictgen::InsensitiveStr::Ascii("malizing"),
        dictgen::InsensitiveStr::Ascii("me"),
        dictgen::InsensitiveStr::Ascii("mesthesia"),
        dictgen::InsensitiveStr::Ascii("moanaesthesia"),
        dictgen::InsensitiveStr::Ascii("moanaesthesias"),
        dictgen::InsensitiveStr::Ascii("moanesthesia"),
        dictgen::InsensitiveStr::Ascii("moanesthesias"),
        dictgen::InsensitiveStr::Ascii("mometerise"),
        dictgen::InsensitiveStr::Ascii("mometerises"),
        dictgen::InsensitiveStr::Ascii("mometerize"),
        dictgen::InsensitiveStr::Ascii("mometerizes"),
        dictgen::InsensitiveStr::Ascii("mopolymerisation"),
        dictgen::InsensitiveStr::Ascii("mopolymerisations"),
        dictgen::InsensitiveStr::Ascii("mopolymerization"),
        dictgen::InsensitiveStr::Ascii("mopolymerizations"),
        dictgen::InsensitiveStr::Ascii("mosiphon"),
        dictgen::InsensitiveStr::Ascii("mosiphons"),
        dictgen::InsensitiveStr::Ascii("mosyphon"),
        dictgen::InsensitiveStr::Ascii("mosyphons"),
    ],
    values: &[
        &[(0b00001, &ENTRY_THERAP_9544025308390036027)],
        &[(0b00001, &ENTRY_THERENESS_9852552452824690186)],
        &[(0b00001, &ENTRY_THERENESSES_10801981187729653982)],
        &[(0b11010, &ENTRY_THERME_4628895801679564218)],
        &[(0b10010, &ENTRY_THERMALIZATION_16496082479527814110)],
        &[(0b10010, &ENTRY_THERMALIZATIONS_8288894113771008081)],
        &[(0b10010, &ENTRY_THERMALIZE_13967008816461896974)],
        &[(0b10010, &ENTRY_THERMALIZED_2624600087787570463)],
        &[(0b10010, &ENTRY_THERMALIZES_9233370697763280406)],
        &[(0b10010, &ENTRY_THERMALIZING_2527773938442619633)],
        &[(0b01001, &ENTRY_THERMALIZATION_16496082479527814110)],
        &[(0b01001, &ENTRY_THERMALIZATIONS_8288894113771008081)],
        &[(0b01001, &ENTRY_THERMALIZE_13967008816461896974)],
        &[(0b01001, &ENTRY_THERMALIZED_2624600087787570463)],
        &[(0b01001, &ENTRY_THERMALIZES_9233370697763280406)],
        &[(0b01001, &ENTRY_THERMALIZING_2527773938442619633)],
        &[(0b00001, &ENTRY_THERME_4628895801679564218)],
        &[(0b00001, &ENTRY_THERMESTHESIA_3863490653735583135)],
        &[(0b11010, &ENTRY_THERMOANESTHESIA_10535525771166290918)],
        &[(0b11010, &ENTRY_THERMOANESTHESIAS_9860040313830784109)],
        &[(0b00001, &ENTRY_THERMOANESTHESIA_10535525771166290918)],
        &[(0b00001, &ENTRY_THERMOANESTHESIAS_9860040313830784109)],
        &[(0b10010, &ENTRY_THERMOMETERIZE_5609847558691367828)],
        &[(0b10010, &ENTRY_THERMOMETERIZES_15743806572499862572)],
        &[(0b01001, &ENTRY_THERMOMETERIZE_5609847558691367828)],
        &[(0b01001, &ENTRY_THERMOMETERIZES_15743806572499862572)],
        &[(0b10010, &ENTRY_THERMOPOLYMERIZATION_10152681254881200049)],
        &[(0b10010, &ENTRY_THERMOPOLYMERIZATIONS_11816137734797485190)],
        &[(0b01001, &ENTRY_THERMOPOLYMERIZATION_10152681254881200049)],
        &[(0b01001, &ENTRY_THERMOPOLYMERIZATIONS_11816137734797485190)],
        &[(0b00001, &ENTRY_THERMOSIPHON_13567630129328954909)],
        &[(0b00001, &ENTRY_THERMOSIPHONS_4618042359977478493)],
        &[(0b11010, &ENTRY_THERMOSIPHON_13567630129328954909)],
        &[(0b11010, &ENTRY_THERMOSIPHONS_4618042359977478493)],
    ],
    range: 2..=17,
};

static VARS_THEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THEO_CHILDREN),
    value: None,
};

pub static VARS_THEO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("logisation"),
        dictgen::InsensitiveStr::Ascii("logisations"),
        dictgen::InsensitiveStr::Ascii("logise"),
        dictgen::InsensitiveStr::Ascii("logised"),
        dictgen::InsensitiveStr::Ascii("logiser"),
        dictgen::InsensitiveStr::Ascii("logisers"),
        dictgen::InsensitiveStr::Ascii("logises"),
        dictgen::InsensitiveStr::Ascii("logising"),
        dictgen::InsensitiveStr::Ascii("logization"),
        dictgen::InsensitiveStr::Ascii("logizations"),
        dictgen::InsensitiveStr::Ascii("logize"),
        dictgen::InsensitiveStr::Ascii("logized"),
        dictgen::InsensitiveStr::Ascii("logizer"),
        dictgen::InsensitiveStr::Ascii("logizers"),
        dictgen::InsensitiveStr::Ascii("logizes"),
        dictgen::InsensitiveStr::Ascii("logizing"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("noe"),
        dictgen::InsensitiveStr::Ascii("risation"),
        dictgen::InsensitiveStr::Ascii("risations"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("riser"),
        dictgen::InsensitiveStr::Ascii("risers"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rization"),
        dictgen::InsensitiveStr::Ascii("rizations"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizer"),
        dictgen::InsensitiveStr::Ascii("rizers"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
        dictgen::InsensitiveStr::Ascii("sophise"),
        dictgen::InsensitiveStr::Ascii("sophised"),
        dictgen::InsensitiveStr::Ascii("sophises"),
        dictgen::InsensitiveStr::Ascii("sophising"),
        dictgen::InsensitiveStr::Ascii("sophize"),
        dictgen::InsensitiveStr::Ascii("sophized"),
        dictgen::InsensitiveStr::Ascii("sophizes"),
        dictgen::InsensitiveStr::Ascii("sophizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_THEOLOGIZATION_7152403949351806099)],
        &[(0b10010, &ENTRY_THEOLOGIZATIONS_8755931201308113045)],
        &[(0b10010, &ENTRY_THEOLOGIZE_12039512331849672306)],
        &[(0b10010, &ENTRY_THEOLOGIZED_10310177154314243592)],
        &[(0b10010, &ENTRY_THEOLOGIZER_10090989839655321620)],
        &[(0b10010, &ENTRY_THEOLOGIZERS_14696166776167600970)],
        &[(0b10010, &ENTRY_THEOLOGIZES_11032972148839634053)],
        &[(0b10010, &ENTRY_THEOLOGIZING_7504945621285245915)],
        &[(0b01001, &ENTRY_THEOLOGIZATION_7152403949351806099)],
        &[(0b01001, &ENTRY_THEOLOGIZATIONS_8755931201308113045)],
        &[(0b01001, &ENTRY_THEOLOGIZE_12039512331849672306)],
        &[(0b01001, &ENTRY_THEOLOGIZED_10310177154314243592)],
        &[(0b01001, &ENTRY_THEOLOGIZER_10090989839655321620)],
        &[(0b01001, &ENTRY_THEOLOGIZERS_14696166776167600970)],
        &[(0b01001, &ENTRY_THEOLOGIZES_11032972148839634053)],
        &[(0b01001, &ENTRY_THEOLOGIZING_7504945621285245915)],
        &[(0b00001, &ENTRY_THEONE_15120851021086460108)],
        &[(0b11010, &ENTRY_THEONE_15120851021086460108)],
        &[(0b10010, &ENTRY_THEORIZATION_12059838448730918530)],
        &[(0b10010, &ENTRY_THEORIZATIONS_14753566303904725274)],
        &[(0b10010, &ENTRY_THEORIZE_7590366607759932540)],
        &[(0b10010, &ENTRY_THEORIZED_15807114832316720521)],
        &[(0b10010, &ENTRY_THEORIZER_16504744998921729475)],
        &[(0b10010, &ENTRY_THEORIZERS_11381755780951206742)],
        &[(0b10010, &ENTRY_THEORIZES_8680815198827974415)],
        &[(0b10010, &ENTRY_THEORIZING_12129998359159098514)],
        &[(0b01001, &ENTRY_THEORIZATION_12059838448730918530)],
        &[(0b01001, &ENTRY_THEORIZATIONS_14753566303904725274)],
        &[(0b01001, &ENTRY_THEORIZE_7590366607759932540)],
        &[(0b01001, &ENTRY_THEORIZED_15807114832316720521)],
        &[(0b01001, &ENTRY_THEORIZER_16504744998921729475)],
        &[(0b01001, &ENTRY_THEORIZERS_11381755780951206742)],
        &[(0b01001, &ENTRY_THEORIZES_8680815198827974415)],
        &[(0b01001, &ENTRY_THEORIZING_12129998359159098514)],
        &[(0b10010, &ENTRY_THEOSOPHIZE_4763429583533636802)],
        &[(0b10010, &ENTRY_THEOSOPHIZED_13107432553508855295)],
        &[(0b10010, &ENTRY_THEOSOPHIZES_8474550672328978106)],
        &[(0b10010, &ENTRY_THEOSOPHIZING_8407612924930104080)],
        &[(0b01001, &ENTRY_THEOSOPHIZE_4763429583533636802)],
        &[(0b01001, &ENTRY_THEOSOPHIZED_13107432553508855295)],
        &[(0b01001, &ENTRY_THEOSOPHIZES_8474550672328978106)],
        &[(0b01001, &ENTRY_THEOSOPHIZING_8407612924930104080)],
    ],
    range: 2..=11,
};

static VARS_THEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THEA_CHILDREN),
    value: None,
};

pub static VARS_THEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tergoer"),
        dictgen::InsensitiveStr::Ascii("tergoers"),
        dictgen::InsensitiveStr::Ascii("tergoing"),
        dictgen::InsensitiveStr::Ascii("tergoings"),
        dictgen::InsensitiveStr::Ascii("terless"),
        dictgen::InsensitiveStr::Ascii("terlesses"),
        dictgen::InsensitiveStr::Ascii("terlike"),
        dictgen::InsensitiveStr::Ascii("terlikes"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tregoer"),
        dictgen::InsensitiveStr::Ascii("tregoers"),
        dictgen::InsensitiveStr::Ascii("tregoing"),
        dictgen::InsensitiveStr::Ascii("tregoings"),
        dictgen::InsensitiveStr::Ascii("treless"),
        dictgen::InsensitiveStr::Ascii("trelesses"),
        dictgen::InsensitiveStr::Ascii("trelike"),
        dictgen::InsensitiveStr::Ascii("trelikes"),
        dictgen::InsensitiveStr::Ascii("tres"),
        dictgen::InsensitiveStr::Ascii("tricalisation"),
        dictgen::InsensitiveStr::Ascii("tricalisations"),
        dictgen::InsensitiveStr::Ascii("tricalise"),
        dictgen::InsensitiveStr::Ascii("tricalised"),
        dictgen::InsensitiveStr::Ascii("tricalises"),
        dictgen::InsensitiveStr::Ascii("tricalising"),
        dictgen::InsensitiveStr::Ascii("tricalization"),
        dictgen::InsensitiveStr::Ascii("tricalizations"),
        dictgen::InsensitiveStr::Ascii("tricalize"),
        dictgen::InsensitiveStr::Ascii("tricalized"),
        dictgen::InsensitiveStr::Ascii("tricalizes"),
        dictgen::InsensitiveStr::Ascii("tricalizing"),
        dictgen::InsensitiveStr::Ascii("tricise"),
        dictgen::InsensitiveStr::Ascii("tricised"),
        dictgen::InsensitiveStr::Ascii("tricises"),
        dictgen::InsensitiveStr::Ascii("tricising"),
        dictgen::InsensitiveStr::Ascii("tricize"),
        dictgen::InsensitiveStr::Ascii("tricized"),
        dictgen::InsensitiveStr::Ascii("tricizes"),
        dictgen::InsensitiveStr::Ascii("tricizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_THEATER_7475041782659424938)],
        &[(0b00001, &ENTRY_THEATERGOER_13508908798164743655)],
        &[(0b00001, &ENTRY_THEATERGOERS_5559625776188799969)],
        &[(0b00001, &ENTRY_THEATERGOING_2013024560518217436)],
        &[(0b00001, &ENTRY_THEATERGOINGS_15343856177156795772)],
        &[(0b00001, &ENTRY_THEATERLESS_9897874198880950215)],
        &[(0b00001, &ENTRY_THEATERLESSES_13355329845366484082)],
        &[(0b00001, &ENTRY_THEATERLIKE_17383240736384944394)],
        &[(0b00001, &ENTRY_THEATERLIKES_9843968538207930637)],
        &[(0b01001, &ENTRY_THEATERS_7003357064188297631)],
        &[(0b11010, &ENTRY_THEATER_7475041782659424938)],
        &[(0b11010, &ENTRY_THEATERGOER_13508908798164743655)],
        &[(0b11010, &ENTRY_THEATERGOERS_5559625776188799969)],
        &[(0b11010, &ENTRY_THEATERGOING_2013024560518217436)],
        &[(0b11010, &ENTRY_THEATERGOINGS_15343856177156795772)],
        &[(0b11010, &ENTRY_THEATERLESS_9897874198880950215)],
        &[(0b11010, &ENTRY_THEATERLESSES_13355329845366484082)],
        &[(0b11010, &ENTRY_THEATERLIKE_17383240736384944394)],
        &[(0b11010, &ENTRY_THEATERLIKES_9843968538207930637)],
        &[(0b11010, &ENTRY_THEATERS_7003357064188297631)],
        &[(0b10010, &ENTRY_THEATRICALIZATION_5100192476801019805)],
        &[(0b10010, &ENTRY_THEATRICALIZATIONS_9847157477732689589)],
        &[(0b10010, &ENTRY_THEATRICALIZE_7879311001018696669)],
        &[(0b10010, &ENTRY_THEATRICALIZED_1898586809778434070)],
        &[(0b10010, &ENTRY_THEATRICALIZES_13227757208676141045)],
        &[(0b10010, &ENTRY_THEATRICALIZING_18213572522629992498)],
        &[(0b01001, &ENTRY_THEATRICALIZATION_5100192476801019805)],
        &[(0b01001, &ENTRY_THEATRICALIZATIONS_9847157477732689589)],
        &[(0b01001, &ENTRY_THEATRICALIZE_7879311001018696669)],
        &[(0b01001, &ENTRY_THEATRICALIZED_1898586809778434070)],
        &[(0b01001, &ENTRY_THEATRICALIZES_13227757208676141045)],
        &[(0b01001, &ENTRY_THEATRICALIZING_18213572522629992498)],
        &[(0b10010, &ENTRY_THEATRICIZE_11791979948757453878)],
        &[(0b10010, &ENTRY_THEATRICIZED_4634839439233392959)],
        &[(0b10010, &ENTRY_THEATRICIZES_2910136151023698070)],
        &[(0b10010, &ENTRY_THEATRICIZING_18012556106152152017)],
        &[(0b01001, &ENTRY_THEATRICIZE_11791979948757453878)],
        &[(0b01001, &ENTRY_THEATRICIZED_4634839439233392959)],
        &[(0b01001, &ENTRY_THEATRICIZES_2910136151023698070)],
        &[(0b01001, &ENTRY_THEATRICIZING_18012556106152152017)],
    ],
    range: 3..=14,
};

static VARS_THA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THA_CHILDREN),
    value: None,
};

pub static VARS_THA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lamocele"),
        dictgen::InsensitiveStr::Ascii("lamocoele"),
        dictgen::InsensitiveStr::Ascii("lassaemia"),
        dictgen::InsensitiveStr::Ascii("lassaemias"),
        dictgen::InsensitiveStr::Ascii("lassaemic"),
        dictgen::InsensitiveStr::Ascii("lassemia"),
        dictgen::InsensitiveStr::Ascii("lassemias"),
        dictgen::InsensitiveStr::Ascii("lassemic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_THALAMOCELE_6877568201362530055)],
        &[(0b11010, &ENTRY_THALAMOCELE_6877568201362530055)],
        &[(0b11010, &ENTRY_THALASSEMIA_4313522697929453494)],
        &[(0b11010, &ENTRY_THALASSEMIAS_12002727284526494170)],
        &[(0b11010, &ENTRY_THALASSEMIC_6553136861220895911)],
        &[(0b00001, &ENTRY_THALASSEMIA_4313522697929453494)],
        &[(0b00001, &ENTRY_THALASSEMIAS_12002727284526494170)],
        &[(0b00001, &ENTRY_THALASSEMIC_6553136861220895911)],
    ],
    range: 8..=10,
};

static VARS_TE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_TE_3678231452906120781)]),
};

static VARS_TE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_TEA_NODE),
    Some(&VARS_TEB_NODE),
    Some(&VARS_TEC_NODE),
    None,
    Some(&VARS_TEE_NODE),
    None,
    Some(&VARS_TEG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_TEL_NODE),
    Some(&VARS_TEM_NODE),
    Some(&VARS_TEN_NODE),
    None,
    None,
    None,
    Some(&VARS_TER_NODE),
    Some(&VARS_TES_NODE),
    Some(&VARS_TET_NODE),
    Some(&VARS_TEU_NODE),
    None,
    None,
    Some(&VARS_TEX_NODE),
    None,
    None,
];

static VARS_TEX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEX_CHILDREN),
    value: None,
};

pub static VARS_TEX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("turise"),
        dictgen::InsensitiveStr::Ascii("turised"),
        dictgen::InsensitiveStr::Ascii("turises"),
        dictgen::InsensitiveStr::Ascii("turising"),
        dictgen::InsensitiveStr::Ascii("turize"),
        dictgen::InsensitiveStr::Ascii("turized"),
        dictgen::InsensitiveStr::Ascii("turizes"),
        dictgen::InsensitiveStr::Ascii("turizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TEXTURIZE_16745696432837818203)],
        &[(0b10010, &ENTRY_TEXTURIZED_13336952192214416477)],
        &[(0b10010, &ENTRY_TEXTURIZES_11082666773590293557)],
        &[(0b10010, &ENTRY_TEXTURIZING_13353456070689850489)],
        &[(0b01001, &ENTRY_TEXTURIZE_16745696432837818203)],
        &[(0b01001, &ENTRY_TEXTURIZED_13336952192214416477)],
        &[(0b01001, &ENTRY_TEXTURIZES_11082666773590293557)],
        &[(0b01001, &ENTRY_TEXTURIZING_13353456070689850489)],
    ],
    range: 6..=8,
};

static VARS_TEU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEU_CHILDREN),
    value: None,
};

pub static VARS_TEU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tonisation"),
        dictgen::InsensitiveStr::Ascii("tonise"),
        dictgen::InsensitiveStr::Ascii("tonised"),
        dictgen::InsensitiveStr::Ascii("tonises"),
        dictgen::InsensitiveStr::Ascii("tonising"),
        dictgen::InsensitiveStr::Ascii("tonization"),
        dictgen::InsensitiveStr::Ascii("tonize"),
        dictgen::InsensitiveStr::Ascii("tonized"),
        dictgen::InsensitiveStr::Ascii("tonizes"),
        dictgen::InsensitiveStr::Ascii("tonizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TEUTONIZATION_6292454241854286943)],
        &[(0b10010, &ENTRY_TEUTONIZE_11056261029352359900)],
        &[(0b10010, &ENTRY_TEUTONIZED_11271380910684387893)],
        &[(0b10010, &ENTRY_TEUTONIZES_4927618306679970592)],
        &[(0b10010, &ENTRY_TEUTONIZING_11530030305824710733)],
        &[(0b01001, &ENTRY_TEUTONIZATION_6292454241854286943)],
        &[(0b01001, &ENTRY_TEUTONIZE_11056261029352359900)],
        &[(0b01001, &ENTRY_TEUTONIZED_11271380910684387893)],
        &[(0b01001, &ENTRY_TEUTONIZES_4927618306679970592)],
        &[(0b01001, &ENTRY_TEUTONIZING_11530030305824710733)],
    ],
    range: 6..=10,
};

static VARS_TET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TET_CHILDREN),
    value: None,
};

pub static VARS_TET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anisations"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anizations"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("rachlorethylene"),
        dictgen::InsensitiveStr::Ascii("rachlorethylenes"),
        dictgen::InsensitiveStr::Ascii("rachloroethylene"),
        dictgen::InsensitiveStr::Ascii("rachloroethylenes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TETANIZATION_644441807826043153)],
        &[(0b10010, &ENTRY_TETANIZATIONS_4717934429082095797)],
        &[(0b10010, &ENTRY_TETANIZE_16968084563752369509)],
        &[(0b10010, &ENTRY_TETANIZED_4812837442844439806)],
        &[(0b10010, &ENTRY_TETANIZES_14522346757244125769)],
        &[(0b10010, &ENTRY_TETANIZING_10656947870602533649)],
        &[(0b01001, &ENTRY_TETANIZATION_644441807826043153)],
        &[(0b01001, &ENTRY_TETANIZATIONS_4717934429082095797)],
        &[(0b01001, &ENTRY_TETANIZE_16968084563752369509)],
        &[(0b01001, &ENTRY_TETANIZED_4812837442844439806)],
        &[(0b01001, &ENTRY_TETANIZES_14522346757244125769)],
        &[(0b01001, &ENTRY_TETANIZING_10656947870602533649)],
        &[(0b00001, &ENTRY_TETRACHLORETHYLENE_16525989969636196009)],
        &[(0b00001, &ENTRY_TETRACHLORETHYLENES_4836279453043134015)],
        &[(0b11010, &ENTRY_TETRACHLORETHYLENE_16525989969636196009)],
        &[(0b11010, &ENTRY_TETRACHLORETHYLENES_4836279453043134015)],
    ],
    range: 5..=17,
};

static VARS_TES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TES_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_TES_2695854084624117978)]),
};

pub static VARS_TES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("timonialisation"),
        dictgen::InsensitiveStr::Ascii("timonialisations"),
        dictgen::InsensitiveStr::Ascii("timonialise"),
        dictgen::InsensitiveStr::Ascii("timonialised"),
        dictgen::InsensitiveStr::Ascii("timonialiser"),
        dictgen::InsensitiveStr::Ascii("timonialisers"),
        dictgen::InsensitiveStr::Ascii("timonialises"),
        dictgen::InsensitiveStr::Ascii("timonialising"),
        dictgen::InsensitiveStr::Ascii("timonialization"),
        dictgen::InsensitiveStr::Ascii("timonializations"),
        dictgen::InsensitiveStr::Ascii("timonialize"),
        dictgen::InsensitiveStr::Ascii("timonialized"),
        dictgen::InsensitiveStr::Ascii("timonializer"),
        dictgen::InsensitiveStr::Ascii("timonializers"),
        dictgen::InsensitiveStr::Ascii("timonializes"),
        dictgen::InsensitiveStr::Ascii("timonializing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TESTE_1918146112764431205)],
        &[(0b00001, &ENTRY_TESTE_1918146112764431205)],
        &[(0b10010, &ENTRY_TESTIMONIALIZATION_12919331762639910549)],
        &[(0b10010, &ENTRY_TESTIMONIALIZATIONS_4398798063194809999)],
        &[(0b10010, &ENTRY_TESTIMONIALIZE_11938560871448602026)],
        &[(0b10010, &ENTRY_TESTIMONIALIZED_1092271798636725121)],
        &[(0b10010, &ENTRY_TESTIMONIALIZER_6224529587979908189)],
        &[(0b10010, &ENTRY_TESTIMONIALIZERS_8453724888025105330)],
        &[(0b10010, &ENTRY_TESTIMONIALIZES_6019622939234728555)],
        &[(0b10010, &ENTRY_TESTIMONIALIZING_9654494111547138024)],
        &[(0b01001, &ENTRY_TESTIMONIALIZATION_12919331762639910549)],
        &[(0b01001, &ENTRY_TESTIMONIALIZATIONS_4398798063194809999)],
        &[(0b01001, &ENTRY_TESTIMONIALIZE_11938560871448602026)],
        &[(0b01001, &ENTRY_TESTIMONIALIZED_1092271798636725121)],
        &[(0b01001, &ENTRY_TESTIMONIALIZER_6224529587979908189)],
        &[(0b01001, &ENTRY_TESTIMONIALIZERS_8453724888025105330)],
        &[(0b01001, &ENTRY_TESTIMONIALIZES_6019622939234728555)],
        &[(0b01001, &ENTRY_TESTIMONIALIZING_9654494111547138024)],
    ],
    range: 2..=16,
};

static VARS_TER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TER_CHILDREN),
    value: None,
};

pub static VARS_TER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("f"),
        dictgen::InsensitiveStr::Ascii("ma"),
        dictgen::InsensitiveStr::Ascii("matic"),
        dictgen::InsensitiveStr::Ascii("minalisation"),
        dictgen::InsensitiveStr::Ascii("minalisations"),
        dictgen::InsensitiveStr::Ascii("minalised"),
        dictgen::InsensitiveStr::Ascii("minaliseds"),
        dictgen::InsensitiveStr::Ascii("minalization"),
        dictgen::InsensitiveStr::Ascii("minalizations"),
        dictgen::InsensitiveStr::Ascii("minalized"),
        dictgen::InsensitiveStr::Ascii("minalizeds"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("rae"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("restrialise"),
        dictgen::InsensitiveStr::Ascii("restrialises"),
        dictgen::InsensitiveStr::Ascii("restrialize"),
        dictgen::InsensitiveStr::Ascii("restrializes"),
        dictgen::InsensitiveStr::Ascii("ritorialisation"),
        dictgen::InsensitiveStr::Ascii("ritorialisations"),
        dictgen::InsensitiveStr::Ascii("ritorialise"),
        dictgen::InsensitiveStr::Ascii("ritorialised"),
        dictgen::InsensitiveStr::Ascii("ritorialises"),
        dictgen::InsensitiveStr::Ascii("ritorialising"),
        dictgen::InsensitiveStr::Ascii("ritorialization"),
        dictgen::InsensitiveStr::Ascii("ritorializations"),
        dictgen::InsensitiveStr::Ascii("ritorialize"),
        dictgen::InsensitiveStr::Ascii("ritorialized"),
        dictgen::InsensitiveStr::Ascii("ritorializes"),
        dictgen::InsensitiveStr::Ascii("ritorializing"),
        dictgen::InsensitiveStr::Ascii("rorisation"),
        dictgen::InsensitiveStr::Ascii("rorisations"),
        dictgen::InsensitiveStr::Ascii("rorise"),
        dictgen::InsensitiveStr::Ascii("rorised"),
        dictgen::InsensitiveStr::Ascii("roriser"),
        dictgen::InsensitiveStr::Ascii("rorisers"),
        dictgen::InsensitiveStr::Ascii("rorises"),
        dictgen::InsensitiveStr::Ascii("rorising"),
        dictgen::InsensitiveStr::Ascii("rorization"),
        dictgen::InsensitiveStr::Ascii("rorizations"),
        dictgen::InsensitiveStr::Ascii("rorize"),
        dictgen::InsensitiveStr::Ascii("rorized"),
        dictgen::InsensitiveStr::Ascii("rorizer"),
        dictgen::InsensitiveStr::Ascii("rorizers"),
        dictgen::InsensitiveStr::Ascii("rorizes"),
        dictgen::InsensitiveStr::Ascii("rorizing"),
        dictgen::InsensitiveStr::Ascii("ts"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TEERS_11274051796412043660)],
        &[(0b00001, &ENTRY_TERF_10018438021336944491)],
        &[(0b00001, &ENTRY_TERMA_17003310983688444980)],
        &[(0b00001, &ENTRY_TERMATIC_12196187078337402107)],
        &[(0b10010, &ENTRY_TERMINALIZATION_227245526230759228)],
        &[(0b10010, &ENTRY_TERMINALIZATIONS_397057651180534160)],
        &[(0b10010, &ENTRY_TERMINALIZED_4320197084396986952)],
        &[(0b10010, &ENTRY_TERMINALIZEDS_13721584241698605404)],
        &[(0b01001, &ENTRY_TERMINALIZATION_227245526230759228)],
        &[(0b01001, &ENTRY_TERMINALIZATIONS_397057651180534160)],
        &[(0b01001, &ENTRY_TERMINALIZED_4320197084396986952)],
        &[(0b01001, &ENTRY_TERMINALIZEDS_13721584241698605404)],
        &[(0b10010, &ENTRY_TERNIZE_12838808144005550317)],
        &[(0b10010, &ENTRY_TERNIZES_9684916395709955397)],
        &[(0b01001, &ENTRY_TERNIZE_12838808144005550317)],
        &[(0b01001, &ENTRY_TERNIZES_9684916395709955397)],
        &[(0b11010, &ENTRY_TERRE_7897526856583781149)],
        &[(0b00001, &ENTRY_TERRE_7897526856583781149)],
        &[(0b10010, &ENTRY_TERRESTRIALIZE_1578168346523607051)],
        &[(0b10010, &ENTRY_TERRESTRIALIZES_17535593305487765718)],
        &[(0b01001, &ENTRY_TERRESTRIALIZE_1578168346523607051)],
        &[(0b01001, &ENTRY_TERRESTRIALIZES_17535593305487765718)],
        &[(0b10010, &ENTRY_TERRITORIALIZATION_5626612094734884596)],
        &[(0b10010, &ENTRY_TERRITORIALIZATIONS_17071036319359279295)],
        &[(0b10010, &ENTRY_TERRITORIALIZE_10884994209419008460)],
        &[(0b10010, &ENTRY_TERRITORIALIZED_9407140238111760381)],
        &[(0b10010, &ENTRY_TERRITORIALIZES_10880031642015296195)],
        &[(0b10010, &ENTRY_TERRITORIALIZING_7810154802700054163)],
        &[(0b01001, &ENTRY_TERRITORIALIZATION_5626612094734884596)],
        &[(0b01001, &ENTRY_TERRITORIALIZATIONS_17071036319359279295)],
        &[(0b01001, &ENTRY_TERRITORIALIZE_10884994209419008460)],
        &[(0b01001, &ENTRY_TERRITORIALIZED_9407140238111760381)],
        &[(0b01001, &ENTRY_TERRITORIALIZES_10880031642015296195)],
        &[(0b01001, &ENTRY_TERRITORIALIZING_7810154802700054163)],
        &[(0b10010, &ENTRY_TERRORIZATION_12021859426492103552)],
        &[(0b10010, &ENTRY_TERRORIZATIONS_5594943151771816976)],
        &[(0b10010, &ENTRY_TERRORIZE_4433495255228210158)],
        &[(0b10010, &ENTRY_TERRORIZED_4215828528050644298)],
        &[(0b10010, &ENTRY_TERRORIZER_11495874779372458995)],
        &[(0b10010, &ENTRY_TERRORIZERS_10990127721251926592)],
        &[(0b10010, &ENTRY_TERRORIZES_14794147503379380662)],
        &[(0b10010, &ENTRY_TERRORIZING_10081605138431727816)],
        &[(0b01001, &ENTRY_TERRORIZATION_12021859426492103552)],
        &[(0b01001, &ENTRY_TERRORIZATIONS_5594943151771816976)],
        &[(0b01001, &ENTRY_TERRORIZE_4433495255228210158)],
        &[(0b01001, &ENTRY_TERRORIZED_4215828528050644298)],
        &[(0b01001, &ENTRY_TERRORIZER_11495874779372458995)],
        &[(0b01001, &ENTRY_TERRORIZERS_10990127721251926592)],
        &[(0b01001, &ENTRY_TERRORIZES_14794147503379380662)],
        &[(0b01001, &ENTRY_TERRORIZING_10081605138431727816)],
        &[(0b00001, &ENTRY_TERTS_13499660719155856568)],
    ],
    range: 1..=16,
};

static VARS_TEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEN_CHILDREN),
    value: None,
};

pub static VARS_TEN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("derisation"),
        dictgen::InsensitiveStr::Ascii("derisations"),
        dictgen::InsensitiveStr::Ascii("derise"),
        dictgen::InsensitiveStr::Ascii("derised"),
        dictgen::InsensitiveStr::Ascii("deriser"),
        dictgen::InsensitiveStr::Ascii("derisers"),
        dictgen::InsensitiveStr::Ascii("derises"),
        dictgen::InsensitiveStr::Ascii("derising"),
        dictgen::InsensitiveStr::Ascii("derization"),
        dictgen::InsensitiveStr::Ascii("derizations"),
        dictgen::InsensitiveStr::Ascii("derize"),
        dictgen::InsensitiveStr::Ascii("derized"),
        dictgen::InsensitiveStr::Ascii("derizer"),
        dictgen::InsensitiveStr::Ascii("derizers"),
        dictgen::InsensitiveStr::Ascii("derizes"),
        dictgen::InsensitiveStr::Ascii("derizing"),
        dictgen::InsensitiveStr::Ascii("driled"),
        dictgen::InsensitiveStr::Ascii("drilled"),
        dictgen::InsensitiveStr::Ascii("ementisation"),
        dictgen::InsensitiveStr::Ascii("ementisations"),
        dictgen::InsensitiveStr::Ascii("ementise"),
        dictgen::InsensitiveStr::Ascii("ementises"),
        dictgen::InsensitiveStr::Ascii("ementization"),
        dictgen::InsensitiveStr::Ascii("ementizations"),
        dictgen::InsensitiveStr::Ascii("ementize"),
        dictgen::InsensitiveStr::Ascii("ementizes"),
        dictgen::InsensitiveStr::Ascii("ia"),
        dictgen::InsensitiveStr::Ascii("iacidal"),
        dictgen::InsensitiveStr::Ascii("iacide"),
        dictgen::InsensitiveStr::Ascii("iacides"),
        dictgen::InsensitiveStr::Ascii("iae"),
        dictgen::InsensitiveStr::Ascii("iafuge"),
        dictgen::InsensitiveStr::Ascii("iafuges"),
        dictgen::InsensitiveStr::Ascii("ias"),
        dictgen::InsensitiveStr::Ascii("iases"),
        dictgen::InsensitiveStr::Ascii("iasis"),
        dictgen::InsensitiveStr::Ascii("ioid"),
        dictgen::InsensitiveStr::Ascii("thmeter"),
        dictgen::InsensitiveStr::Ascii("thmetre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TENDERIZATION_7750334074937606325)],
        &[(0b10010, &ENTRY_TENDERIZATIONS_17721506842521904935)],
        &[(0b10010, &ENTRY_TENDERIZE_3531288944634226086)],
        &[(0b10010, &ENTRY_TENDERIZED_13718535317658548812)],
        &[(0b10010, &ENTRY_TENDERIZER_17224224602025748842)],
        &[(0b10010, &ENTRY_TENDERIZERS_13914793532536564520)],
        &[(0b10010, &ENTRY_TENDERIZES_13464919051528220037)],
        &[(0b10010, &ENTRY_TENDERIZING_9684594006719958471)],
        &[(0b01001, &ENTRY_TENDERIZATION_7750334074937606325)],
        &[(0b01001, &ENTRY_TENDERIZATIONS_17721506842521904935)],
        &[(0b01001, &ENTRY_TENDERIZE_3531288944634226086)],
        &[(0b01001, &ENTRY_TENDERIZED_13718535317658548812)],
        &[(0b01001, &ENTRY_TENDERIZER_17224224602025748842)],
        &[(0b01001, &ENTRY_TENDERIZERS_13914793532536564520)],
        &[(0b01001, &ENTRY_TENDERIZES_13464919051528220037)],
        &[(0b01001, &ENTRY_TENDERIZING_9684594006719958471)],
        &[(0b00001, &ENTRY_TENDRILED_3703626707361065691)],
        &[(0b11010, &ENTRY_TENDRILED_3703626707361065691)],
        &[(0b10010, &ENTRY_TENEMENTIZATION_16373597570752442861)],
        &[(0b10010, &ENTRY_TENEMENTIZATIONS_1184744289790632274)],
        &[(0b10010, &ENTRY_TENEMENTIZE_15184658096585226001)],
        &[(0b10010, &ENTRY_TENEMENTIZES_2482418667298355530)],
        &[(0b01001, &ENTRY_TENEMENTIZATION_16373597570752442861)],
        &[(0b01001, &ENTRY_TENEMENTIZATIONS_1184744289790632274)],
        &[(0b01001, &ENTRY_TENEMENTIZE_15184658096585226001)],
        &[(0b01001, &ENTRY_TENEMENTIZES_2482418667298355530)],
        &[(0b00001, &ENTRY_TENIA_3590031604576778490)],
        &[(0b00001, &ENTRY_TENIACIDAL_541970291786449225)],
        &[(0b00001, &ENTRY_TENIACIDE_9272287110828061667)],
        &[(0b00001, &ENTRY_TENIACIDES_9085014004304381530)],
        &[(0b00001, &ENTRY_TENIAE_2460733953776370015)],
        &[(0b00001, &ENTRY_TENIAFUGE_11053879169809004952)],
        &[(0b00001, &ENTRY_TENIAFUGES_8258613951057794683)],
        &[(0b00001, &ENTRY_TENIAS_15863770479015006574)],
        &[(0b00001, &ENTRY_TENIASES_4082434292313003269)],
        &[(0b00001, &ENTRY_TENIASIS_11176202135157856401)],
        &[(0b00001, &ENTRY_TENIOID_6487095486830194346)],
        &[(0b00001, &ENTRY_TENTHMETER_191273811277521832)],
        &[(0b11010, &ENTRY_TENTHMETER_191273811277521832)],
    ],
    range: 2..=13,
};

static VARS_TEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEM_CHILDREN),
    value: None,
};

pub static VARS_TEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("plise"),
        dictgen::InsensitiveStr::Ascii("plises"),
        dictgen::InsensitiveStr::Ascii("plize"),
        dictgen::InsensitiveStr::Ascii("plizes"),
        dictgen::InsensitiveStr::Ascii("poralise"),
        dictgen::InsensitiveStr::Ascii("poralised"),
        dictgen::InsensitiveStr::Ascii("poralises"),
        dictgen::InsensitiveStr::Ascii("poralising"),
        dictgen::InsensitiveStr::Ascii("poralize"),
        dictgen::InsensitiveStr::Ascii("poralized"),
        dictgen::InsensitiveStr::Ascii("poralizes"),
        dictgen::InsensitiveStr::Ascii("poralizing"),
        dictgen::InsensitiveStr::Ascii("porisation"),
        dictgen::InsensitiveStr::Ascii("porisations"),
        dictgen::InsensitiveStr::Ascii("porise"),
        dictgen::InsensitiveStr::Ascii("porised"),
        dictgen::InsensitiveStr::Ascii("poriser"),
        dictgen::InsensitiveStr::Ascii("porisers"),
        dictgen::InsensitiveStr::Ascii("porises"),
        dictgen::InsensitiveStr::Ascii("porising"),
        dictgen::InsensitiveStr::Ascii("porisinglier"),
        dictgen::InsensitiveStr::Ascii("porisingliest"),
        dictgen::InsensitiveStr::Ascii("porisingly"),
        dictgen::InsensitiveStr::Ascii("porisings"),
        dictgen::InsensitiveStr::Ascii("porization"),
        dictgen::InsensitiveStr::Ascii("porizations"),
        dictgen::InsensitiveStr::Ascii("porize"),
        dictgen::InsensitiveStr::Ascii("porized"),
        dictgen::InsensitiveStr::Ascii("porizer"),
        dictgen::InsensitiveStr::Ascii("porizers"),
        dictgen::InsensitiveStr::Ascii("porizes"),
        dictgen::InsensitiveStr::Ascii("porizing"),
        dictgen::InsensitiveStr::Ascii("porizinglier"),
        dictgen::InsensitiveStr::Ascii("porizingliest"),
        dictgen::InsensitiveStr::Ascii("porizingly"),
        dictgen::InsensitiveStr::Ascii("porizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TEMPLIZE_11960826038010417307)],
        &[(0b10010, &ENTRY_TEMPLIZES_45876823756782777)],
        &[(0b01001, &ENTRY_TEMPLIZE_11960826038010417307)],
        &[(0b01001, &ENTRY_TEMPLIZES_45876823756782777)],
        &[(0b10010, &ENTRY_TEMPORALIZE_6928564539981991859)],
        &[(0b10010, &ENTRY_TEMPORALIZED_12716643461351758871)],
        &[(0b10010, &ENTRY_TEMPORALIZES_16816934998491265240)],
        &[(0b10010, &ENTRY_TEMPORALIZING_6073863398214069624)],
        &[(0b01001, &ENTRY_TEMPORALIZE_6928564539981991859)],
        &[(0b01001, &ENTRY_TEMPORALIZED_12716643461351758871)],
        &[(0b01001, &ENTRY_TEMPORALIZES_16816934998491265240)],
        &[(0b01001, &ENTRY_TEMPORALIZING_6073863398214069624)],
        &[(0b10010, &ENTRY_TEMPORIZATION_4135233642498941184)],
        &[(0b10010, &ENTRY_TEMPORIZATIONS_2987472207501959609)],
        &[(0b10010, &ENTRY_TEMPORIZE_7694977824627458983)],
        &[(0b10010, &ENTRY_TEMPORIZED_4964570364177704531)],
        &[(0b10010, &ENTRY_TEMPORIZER_6688110462298171935)],
        &[(0b10010, &ENTRY_TEMPORIZERS_18437130794992057942)],
        &[(0b10010, &ENTRY_TEMPORIZES_11341794494418625299)],
        &[(0b10010, &ENTRY_TEMPORIZING_16023698398897725311)],
        &[(0b10010, &ENTRY_TEMPORIZINGLIER_9849548925384135646)],
        &[(0b10010, &ENTRY_TEMPORIZINGLIEST_11242662133505129984)],
        &[(0b10010, &ENTRY_TEMPORIZINGLY_6983715160792083876)],
        &[(0b10010, &ENTRY_TEMPORIZINGS_16954412101165281486)],
        &[(0b01001, &ENTRY_TEMPORIZATION_4135233642498941184)],
        &[(0b01001, &ENTRY_TEMPORIZATIONS_2987472207501959609)],
        &[(0b01001, &ENTRY_TEMPORIZE_7694977824627458983)],
        &[(0b01001, &ENTRY_TEMPORIZED_4964570364177704531)],
        &[(0b01001, &ENTRY_TEMPORIZER_6688110462298171935)],
        &[(0b01001, &ENTRY_TEMPORIZERS_18437130794992057942)],
        &[(0b01001, &ENTRY_TEMPORIZES_11341794494418625299)],
        &[(0b01001, &ENTRY_TEMPORIZING_16023698398897725311)],
        &[(0b01001, &ENTRY_TEMPORIZINGLIER_9849548925384135646)],
        &[(0b01001, &ENTRY_TEMPORIZINGLIEST_11242662133505129984)],
        &[(0b01001, &ENTRY_TEMPORIZINGLY_6983715160792083876)],
        &[(0b01001, &ENTRY_TEMPORIZINGS_16954412101165281486)],
    ],
    range: 5..=13,
};

static VARS_TEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEL_CHILDREN),
    value: None,
};

pub static VARS_TEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("aesthesias"),
        dictgen::InsensitiveStr::Ascii("aesthetic"),
        dictgen::InsensitiveStr::Ascii("aestheticer"),
        dictgen::InsensitiveStr::Ascii("aestheticest"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("epathise"),
        dictgen::InsensitiveStr::Ascii("epathised"),
        dictgen::InsensitiveStr::Ascii("epathises"),
        dictgen::InsensitiveStr::Ascii("epathising"),
        dictgen::InsensitiveStr::Ascii("epathize"),
        dictgen::InsensitiveStr::Ascii("epathized"),
        dictgen::InsensitiveStr::Ascii("epathizes"),
        dictgen::InsensitiveStr::Ascii("epathizing"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthesias"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
        dictgen::InsensitiveStr::Ascii("estheticer"),
        dictgen::InsensitiveStr::Ascii("estheticest"),
        dictgen::InsensitiveStr::Ascii("lurise"),
        dictgen::InsensitiveStr::Ascii("lurised"),
        dictgen::InsensitiveStr::Ascii("lurises"),
        dictgen::InsensitiveStr::Ascii("lurising"),
        dictgen::InsensitiveStr::Ascii("lurize"),
        dictgen::InsensitiveStr::Ascii("lurized"),
        dictgen::InsensitiveStr::Ascii("lurizes"),
        dictgen::InsensitiveStr::Ascii("lurizing"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TELE_4870161772147898913)],
        &[(0b11010, &ENTRY_TELESTHESIA_3608004104658756833)],
        &[(0b11010, &ENTRY_TELESTHESIAS_3007363512145448149)],
        &[(0b11010, &ENTRY_TELESTHETIC_1552205400640102007)],
        &[(0b11010, &ENTRY_TELESTHETICER_3205209910306797838)],
        &[(0b11010, &ENTRY_TELESTHETICEST_1745115383802501612)],
        &[(0b00001, &ENTRY_TELE_4870161772147898913)],
        &[(0b10010, &ENTRY_TELEPATHIZE_13335072343576542252)],
        &[(0b10010, &ENTRY_TELEPATHIZED_421824987955665986)],
        &[(0b10010, &ENTRY_TELEPATHIZES_15648096053049257080)],
        &[(0b10010, &ENTRY_TELEPATHIZING_13360070708521360949)],
        &[(0b01001, &ENTRY_TELEPATHIZE_13335072343576542252)],
        &[(0b01001, &ENTRY_TELEPATHIZED_421824987955665986)],
        &[(0b01001, &ENTRY_TELEPATHIZES_15648096053049257080)],
        &[(0b01001, &ENTRY_TELEPATHIZING_13360070708521360949)],
        &[(0b00001, &ENTRY_TELESTHESIA_3608004104658756833)],
        &[(0b00001, &ENTRY_TELESTHESIAS_3007363512145448149)],
        &[(0b00001, &ENTRY_TELESTHETIC_1552205400640102007)],
        &[(0b00001, &ENTRY_TELESTHETICER_3205209910306797838)],
        &[(0b00001, &ENTRY_TELESTHETICEST_1745115383802501612)],
        &[(0b10010, &ENTRY_TELLURIZE_5057943107852940207)],
        &[(0b10010, &ENTRY_TELLURIZED_2742921626249039404)],
        &[(0b10010, &ENTRY_TELLURIZES_17233285317678254256)],
        &[(0b10010, &ENTRY_TELLURIZING_2423876315883018831)],
        &[(0b01001, &ENTRY_TELLURIZE_5057943107852940207)],
        &[(0b01001, &ENTRY_TELLURIZED_2742921626249039404)],
        &[(0b01001, &ENTRY_TELLURIZES_17233285317678254256)],
        &[(0b01001, &ENTRY_TELLURIZING_2423876315883018831)],
        &[(0b00001, &ENTRY_TELS_10786558087438067092)],
    ],
    range: 1..=12,
};

static VARS_TEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEG_CHILDREN),
    value: None,
};

pub static VARS_TEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("u")],
    values: &[&[(0b00001, &ENTRY_TEGU_580355573665292940)]],
    range: 1..=1,
};

static VARS_TEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEE_CHILDREN),
    value: None,
};

pub static VARS_TEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("totaled"),
        dictgen::InsensitiveStr::Ascii("totaler"),
        dictgen::InsensitiveStr::Ascii("totalers"),
        dictgen::InsensitiveStr::Ascii("totaling"),
        dictgen::InsensitiveStr::Ascii("totalled"),
        dictgen::InsensitiveStr::Ascii("totaller"),
        dictgen::InsensitiveStr::Ascii("totallers"),
        dictgen::InsensitiveStr::Ascii("totalling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TEER_13683881861614668793)],
        &[(0b00001, &ENTRY_TEERS_11274051796412043660)],
        &[(0b00001, &ENTRY_TEETOTALED_7326361194719148925)],
        &[(0b00001, &ENTRY_TEETOTALER_9642485742897840895)],
        &[(0b00001, &ENTRY_TEETOTALERS_5250373658369188480)],
        &[(0b00001, &ENTRY_TEETOTALING_7136232887691143617)],
        &[(0b11010, &ENTRY_TEETOTALED_7326361194719148925)],
        &[(0b11010, &ENTRY_TEETOTALER_9642485742897840895)],
        &[(0b11010, &ENTRY_TEETOTALERS_5250373658369188480)],
        &[(0b11010, &ENTRY_TEETOTALING_7136232887691143617)],
    ],
    range: 1..=9,
};

static VARS_TEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEC_CHILDREN),
    value: None,
};

pub static VARS_TEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hnicalisation"),
        dictgen::InsensitiveStr::Ascii("hnicalise"),
        dictgen::InsensitiveStr::Ascii("hnicalises"),
        dictgen::InsensitiveStr::Ascii("hnicalization"),
        dictgen::InsensitiveStr::Ascii("hnicalize"),
        dictgen::InsensitiveStr::Ascii("hnicalizes"),
        dictgen::InsensitiveStr::Ascii("hnicise"),
        dictgen::InsensitiveStr::Ascii("hnicised"),
        dictgen::InsensitiveStr::Ascii("hnicises"),
        dictgen::InsensitiveStr::Ascii("hnicising"),
        dictgen::InsensitiveStr::Ascii("hnicize"),
        dictgen::InsensitiveStr::Ascii("hnicized"),
        dictgen::InsensitiveStr::Ascii("hnicizes"),
        dictgen::InsensitiveStr::Ascii("hnicizing"),
        dictgen::InsensitiveStr::Ascii("hnicolour"),
        dictgen::InsensitiveStr::Ascii("hnicoloured"),
        dictgen::InsensitiveStr::Ascii("hnicolours"),
        dictgen::InsensitiveStr::Ascii("hnologise"),
        dictgen::InsensitiveStr::Ascii("hnologize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TECHNICALIZATION_3557036272115507954)],
        &[(0b10010, &ENTRY_TECHNICALIZE_8472562129396247230)],
        &[(0b10010, &ENTRY_TECHNICALIZES_5739924387814270714)],
        &[(0b01001, &ENTRY_TECHNICALIZATION_3557036272115507954)],
        &[(0b01001, &ENTRY_TECHNICALIZE_8472562129396247230)],
        &[(0b01001, &ENTRY_TECHNICALIZES_5739924387814270714)],
        &[(0b10010, &ENTRY_TECHNICIZE_2858109795308766008)],
        &[(0b10010, &ENTRY_TECHNICIZED_1670496041758587203)],
        &[(0b10010, &ENTRY_TECHNICIZES_12876743451060139748)],
        &[(0b10010, &ENTRY_TECHNICIZING_12855780479462350606)],
        &[(0b01001, &ENTRY_TECHNICIZE_2858109795308766008)],
        &[(0b01001, &ENTRY_TECHNICIZED_1670496041758587203)],
        &[(0b01001, &ENTRY_TECHNICIZES_12876743451060139748)],
        &[(0b01001, &ENTRY_TECHNICIZING_12855780479462350606)],
        &[
            (0b11010, &ENTRY_TECHNICOLOR_15713729011025864853),
            (0b11010, &ENTRY_TECHNICOLOR_5654403922354832142),
        ],
        &[(0b11010, &ENTRY_TECHNICOLORED_7154232169686816579)],
        &[(0b11010, &ENTRY_TECHNICOLORS_2621716821548091481)],
        &[(0b10010, &ENTRY_TECHNOLOGIZE_18224160162322835759)],
        &[(0b01001, &ENTRY_TECHNOLOGIZE_18224160162322835759)],
    ],
    range: 7..=13,
};

static VARS_TEB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEB_CHILDREN),
    value: None,
};

pub static VARS_TEB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TEBILIZE_12357160300142853828)],
        &[(0b10010, &ENTRY_TEBILIZED_16281892748394878341)],
        &[(0b10010, &ENTRY_TEBILIZES_1009779906267613643)],
        &[(0b10010, &ENTRY_TEBILIZING_6941003510869745519)],
        &[(0b01001, &ENTRY_TEBILIZE_12357160300142853828)],
        &[(0b01001, &ENTRY_TEBILIZED_16281892748394878341)],
        &[(0b01001, &ENTRY_TEBILIZES_1009779906267613643)],
        &[(0b01001, &ENTRY_TEBILIZING_6941003510869745519)],
    ],
    range: 5..=7,
};

static VARS_TEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEA_CHILDREN),
    value: None,
};

pub static VARS_TEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("selled"),
        dictgen::InsensitiveStr::Ascii("seller"),
        dictgen::InsensitiveStr::Ascii("sellers"),
        dictgen::InsensitiveStr::Ascii("selling"),
        dictgen::InsensitiveStr::Ascii("sellings"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TEER_13683881861614668793)],
        &[(0b00001, &ENTRY_TEASELED_2404281669479955994)],
        &[(0b00001, &ENTRY_TEASELER_15816628167253312937)],
        &[(0b00001, &ENTRY_TEASELERS_12811270860239416974)],
        &[
            (0b00001, &ENTRY_TEASELING_3193421888859226649),
            (0b00001, &ENTRY_TEASELING_6449109682441957740),
        ],
        &[(0b00001, &ENTRY_TEASELINGS_7138615751835008671)],
    ],
    range: 2..=8,
};

static VARS_TA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TA_CHILDREN),
    value: None,
};

static VARS_TA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_TAB_NODE),
    Some(&VARS_TAC_NODE),
    None,
    Some(&VARS_TAE_NODE),
    Some(&VARS_TAF_NODE),
    None,
    None,
    Some(&VARS_TAI_NODE),
    None,
    None,
    Some(&VARS_TAL_NODE),
    Some(&VARS_TAM_NODE),
    Some(&VARS_TAN_NODE),
    None,
    None,
    None,
    Some(&VARS_TAR_NODE),
    Some(&VARS_TAS_NODE),
    None,
    Some(&VARS_TAU_NODE),
    Some(&VARS_TAV_NODE),
    None,
    Some(&VARS_TAX_NODE),
    Some(&VARS_TAY_NODE),
    None,
];

static VARS_TAY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAY_CHILDREN),
    value: None,
};

pub static VARS_TAY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lorise"),
        dictgen::InsensitiveStr::Ascii("lorises"),
        dictgen::InsensitiveStr::Ascii("lorize"),
        dictgen::InsensitiveStr::Ascii("lorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TAYLORIZE_3865542100918562173)],
        &[(0b10010, &ENTRY_TAYLORIZES_566769959974370306)],
        &[(0b01001, &ENTRY_TAYLORIZE_3865542100918562173)],
        &[(0b01001, &ENTRY_TAYLORIZES_566769959974370306)],
    ],
    range: 6..=7,
};

static VARS_TAX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAX_CHILDREN),
    value: None,
};

pub static VARS_TAX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("idermise"),
        dictgen::InsensitiveStr::Ascii("idermised"),
        dictgen::InsensitiveStr::Ascii("idermises"),
        dictgen::InsensitiveStr::Ascii("idermising"),
        dictgen::InsensitiveStr::Ascii("idermize"),
        dictgen::InsensitiveStr::Ascii("idermized"),
        dictgen::InsensitiveStr::Ascii("idermizes"),
        dictgen::InsensitiveStr::Ascii("idermizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TAXIDERMIZE_15950544350323027010)],
        &[(0b10010, &ENTRY_TAXIDERMIZED_13935298856865523155)],
        &[(0b10010, &ENTRY_TAXIDERMIZES_719088270981053986)],
        &[(0b10010, &ENTRY_TAXIDERMIZING_5626284540207255110)],
        &[(0b01001, &ENTRY_TAXIDERMIZE_15950544350323027010)],
        &[(0b01001, &ENTRY_TAXIDERMIZED_13935298856865523155)],
        &[(0b01001, &ENTRY_TAXIDERMIZES_719088270981053986)],
        &[(0b01001, &ENTRY_TAXIDERMIZING_5626284540207255110)],
    ],
    range: 8..=10,
};

static VARS_TAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAV_CHILDREN),
    value: None,
};

pub static VARS_TAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ernise"),
        dictgen::InsensitiveStr::Ascii("ernises"),
        dictgen::InsensitiveStr::Ascii("ernize"),
        dictgen::InsensitiveStr::Ascii("ernizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TAVERNIZE_6260853173296204981)],
        &[(0b10010, &ENTRY_TAVERNIZES_6063364600175481171)],
        &[(0b01001, &ENTRY_TAVERNIZE_6260853173296204981)],
        &[(0b01001, &ENTRY_TAVERNIZES_6063364600175481171)],
    ],
    range: 6..=7,
};

static VARS_TAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAU_CHILDREN),
    value: None,
};

pub static VARS_TAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tologise"),
        dictgen::InsensitiveStr::Ascii("tologised"),
        dictgen::InsensitiveStr::Ascii("tologises"),
        dictgen::InsensitiveStr::Ascii("tologising"),
        dictgen::InsensitiveStr::Ascii("tologize"),
        dictgen::InsensitiveStr::Ascii("tologized"),
        dictgen::InsensitiveStr::Ascii("tologizes"),
        dictgen::InsensitiveStr::Ascii("tologizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TAUTOLOGIZE_11478929002088519989)],
        &[(0b10010, &ENTRY_TAUTOLOGIZED_1863604812276127359)],
        &[(0b10010, &ENTRY_TAUTOLOGIZES_13343636725490349506)],
        &[(0b10010, &ENTRY_TAUTOLOGIZING_15254400746085954202)],
        &[(0b01001, &ENTRY_TAUTOLOGIZE_11478929002088519989)],
        &[(0b01001, &ENTRY_TAUTOLOGIZED_1863604812276127359)],
        &[(0b01001, &ENTRY_TAUTOLOGIZES_13343636725490349506)],
        &[(0b01001, &ENTRY_TAUTOLOGIZING_15254400746085954202)],
    ],
    range: 8..=10,
};

static VARS_TAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAS_CHILDREN),
    value: None,
};

pub static VARS_TAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("seled"),
        dictgen::InsensitiveStr::Ascii("seling"),
        dictgen::InsensitiveStr::Ascii("selled"),
        dictgen::InsensitiveStr::Ascii("selling"),
        dictgen::InsensitiveStr::Ascii("sells"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TASSELED_4679022262489379669)],
        &[(0b00001, &ENTRY_TASSELING_10007583439810610023)],
        &[(0b11010, &ENTRY_TASSELED_4679022262489379669)],
        &[(0b11010, &ENTRY_TASSELING_10007583439810610023)],
        &[(0b11010, &ENTRY_TASSELS_13976945035735097519)],
    ],
    range: 5..=7,
};

static VARS_TAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAR_CHILDREN),
    value: None,
};

pub static VARS_TAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iffise"),
        dictgen::InsensitiveStr::Ascii("iffises"),
        dictgen::InsensitiveStr::Ascii("iffize"),
        dictgen::InsensitiveStr::Ascii("iffizes"),
        dictgen::InsensitiveStr::Ascii("tarisation"),
        dictgen::InsensitiveStr::Ascii("tarisations"),
        dictgen::InsensitiveStr::Ascii("tarise"),
        dictgen::InsensitiveStr::Ascii("tarised"),
        dictgen::InsensitiveStr::Ascii("tarises"),
        dictgen::InsensitiveStr::Ascii("tarising"),
        dictgen::InsensitiveStr::Ascii("tarization"),
        dictgen::InsensitiveStr::Ascii("tarizations"),
        dictgen::InsensitiveStr::Ascii("tarize"),
        dictgen::InsensitiveStr::Ascii("tarized"),
        dictgen::InsensitiveStr::Ascii("tarizes"),
        dictgen::InsensitiveStr::Ascii("tarizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TARIFFIZE_6403869543544376740)],
        &[(0b10010, &ENTRY_TARIFFIZES_17636207388435873185)],
        &[(0b01001, &ENTRY_TARIFFIZE_6403869543544376740)],
        &[(0b01001, &ENTRY_TARIFFIZES_17636207388435873185)],
        &[(0b10010, &ENTRY_TARTARIZATION_7985288754441644773)],
        &[(0b10010, &ENTRY_TARTARIZATIONS_4539095683795989062)],
        &[(0b10010, &ENTRY_TARTARIZE_5229224382783206477)],
        &[(0b10010, &ENTRY_TARTARIZED_17484118332732038381)],
        &[(0b10010, &ENTRY_TARTARIZES_5464843505270674625)],
        &[(0b10010, &ENTRY_TARTARIZING_6992530598749611494)],
        &[(0b01001, &ENTRY_TARTARIZATION_7985288754441644773)],
        &[(0b01001, &ENTRY_TARTARIZATIONS_4539095683795989062)],
        &[(0b01001, &ENTRY_TARTARIZE_5229224382783206477)],
        &[(0b01001, &ENTRY_TARTARIZED_17484118332732038381)],
        &[(0b01001, &ENTRY_TARTARIZES_5464843505270674625)],
        &[(0b01001, &ENTRY_TARTARIZING_6992530598749611494)],
    ],
    range: 6..=11,
};

static VARS_TAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAN_CHILDREN),
    value: None,
};

pub static VARS_TAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("demise"),
        dictgen::InsensitiveStr::Ascii("demises"),
        dictgen::InsensitiveStr::Ascii("demize"),
        dictgen::InsensitiveStr::Ascii("demizes"),
        dictgen::InsensitiveStr::Ascii("talisation"),
        dictgen::InsensitiveStr::Ascii("talisations"),
        dictgen::InsensitiveStr::Ascii("talise"),
        dictgen::InsensitiveStr::Ascii("talised"),
        dictgen::InsensitiveStr::Ascii("taliser"),
        dictgen::InsensitiveStr::Ascii("talisers"),
        dictgen::InsensitiveStr::Ascii("talises"),
        dictgen::InsensitiveStr::Ascii("talising"),
        dictgen::InsensitiveStr::Ascii("talisinglier"),
        dictgen::InsensitiveStr::Ascii("talisinglies"),
        dictgen::InsensitiveStr::Ascii("talisingliest"),
        dictgen::InsensitiveStr::Ascii("talisingly"),
        dictgen::InsensitiveStr::Ascii("talisingness"),
        dictgen::InsensitiveStr::Ascii("talisingnesses"),
        dictgen::InsensitiveStr::Ascii("talisings"),
        dictgen::InsensitiveStr::Ascii("talization"),
        dictgen::InsensitiveStr::Ascii("talizations"),
        dictgen::InsensitiveStr::Ascii("talize"),
        dictgen::InsensitiveStr::Ascii("talized"),
        dictgen::InsensitiveStr::Ascii("talizer"),
        dictgen::InsensitiveStr::Ascii("talizers"),
        dictgen::InsensitiveStr::Ascii("talizes"),
        dictgen::InsensitiveStr::Ascii("talizing"),
        dictgen::InsensitiveStr::Ascii("talizinglier"),
        dictgen::InsensitiveStr::Ascii("talizinglies"),
        dictgen::InsensitiveStr::Ascii("talizingliest"),
        dictgen::InsensitiveStr::Ascii("talizingly"),
        dictgen::InsensitiveStr::Ascii("talizingness"),
        dictgen::InsensitiveStr::Ascii("talizingnesses"),
        dictgen::InsensitiveStr::Ascii("talizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TANALIZED_12866045393181097657)],
        &[(0b01001, &ENTRY_TANALIZED_12866045393181097657)],
        &[(0b10010, &ENTRY_TANDEMIZE_12627845627665749987)],
        &[(0b10010, &ENTRY_TANDEMIZES_6195252162933518434)],
        &[(0b01001, &ENTRY_TANDEMIZE_12627845627665749987)],
        &[(0b01001, &ENTRY_TANDEMIZES_6195252162933518434)],
        &[(0b10010, &ENTRY_TANTALIZATION_11251308735880559440)],
        &[(0b10010, &ENTRY_TANTALIZATIONS_4202766685588417911)],
        &[(0b10010, &ENTRY_TANTALIZE_18432661058571036826)],
        &[(0b10010, &ENTRY_TANTALIZED_8361102485824684408)],
        &[(0b10010, &ENTRY_TANTALIZER_16233188677397603167)],
        &[(0b10010, &ENTRY_TANTALIZERS_15046066302558840427)],
        &[(0b10010, &ENTRY_TANTALIZES_11631837874131073727)],
        &[(0b10010, &ENTRY_TANTALIZING_1104308605989653249)],
        &[(0b10010, &ENTRY_TANTALIZINGLIER_7583695578673101293)],
        &[(0b10010, &ENTRY_TANTALIZINGLIES_9817814848083768632)],
        &[(0b10010, &ENTRY_TANTALIZINGLIEST_10330928641973270079)],
        &[(0b10010, &ENTRY_TANTALIZINGLY_6966920924649933678)],
        &[(0b10010, &ENTRY_TANTALIZINGNESS_15204799924965484070)],
        &[(0b10010, &ENTRY_TANTALIZINGNESSES_7303683745241052669)],
        &[(0b10010, &ENTRY_TANTALIZINGS_2351246836151437376)],
        &[(0b01001, &ENTRY_TANTALIZATION_11251308735880559440)],
        &[(0b01001, &ENTRY_TANTALIZATIONS_4202766685588417911)],
        &[(0b01001, &ENTRY_TANTALIZE_18432661058571036826)],
        &[(0b01001, &ENTRY_TANTALIZED_8361102485824684408)],
        &[(0b01001, &ENTRY_TANTALIZER_16233188677397603167)],
        &[(0b01001, &ENTRY_TANTALIZERS_15046066302558840427)],
        &[(0b01001, &ENTRY_TANTALIZES_11631837874131073727)],
        &[(0b01001, &ENTRY_TANTALIZING_1104308605989653249)],
        &[(0b01001, &ENTRY_TANTALIZINGLIER_7583695578673101293)],
        &[(0b01001, &ENTRY_TANTALIZINGLIES_9817814848083768632)],
        &[(0b01001, &ENTRY_TANTALIZINGLIEST_10330928641973270079)],
        &[(0b01001, &ENTRY_TANTALIZINGLY_6966920924649933678)],
        &[(0b01001, &ENTRY_TANTALIZINGNESS_15204799924965484070)],
        &[(0b01001, &ENTRY_TANTALIZINGNESSES_7303683745241052669)],
        &[(0b01001, &ENTRY_TANTALIZINGS_2351246836151437376)],
    ],
    range: 6..=14,
};

static VARS_TAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAM_CHILDREN),
    value: None,
};

pub static VARS_TAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("boura"),
        dictgen::InsensitiveStr::Ascii("bouras"),
        dictgen::InsensitiveStr::Ascii("manyise"),
        dictgen::InsensitiveStr::Ascii("manyises"),
        dictgen::InsensitiveStr::Ascii("manyize"),
        dictgen::InsensitiveStr::Ascii("manyizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TAMBURA_10774020505110351537)],
        &[(0b11010, &ENTRY_TAMBURAS_3622963385462333423)],
        &[(0b10010, &ENTRY_TAMMANYIZE_7790980244874688921)],
        &[(0b10010, &ENTRY_TAMMANYIZES_12831368891226385045)],
        &[(0b01001, &ENTRY_TAMMANYIZE_7790980244874688921)],
        &[(0b01001, &ENTRY_TAMMANYIZES_12831368891226385045)],
    ],
    range: 5..=8,
};

static VARS_TAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAL_CHILDREN),
    value: None,
};

pub static VARS_TAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mudisation"),
        dictgen::InsensitiveStr::Ascii("mudisations"),
        dictgen::InsensitiveStr::Ascii("mudise"),
        dictgen::InsensitiveStr::Ascii("mudises"),
        dictgen::InsensitiveStr::Ascii("mudization"),
        dictgen::InsensitiveStr::Ascii("mudizations"),
        dictgen::InsensitiveStr::Ascii("mudize"),
        dictgen::InsensitiveStr::Ascii("mudizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TALMUDIZATION_14002522770997155406)],
        &[(0b10010, &ENTRY_TALMUDIZATIONS_7131355692075902201)],
        &[(0b10010, &ENTRY_TALMUDIZE_2141569203942597251)],
        &[(0b10010, &ENTRY_TALMUDIZES_9309757235637123822)],
        &[(0b01001, &ENTRY_TALMUDIZATION_14002522770997155406)],
        &[(0b01001, &ENTRY_TALMUDIZATIONS_7131355692075902201)],
        &[(0b01001, &ENTRY_TALMUDIZE_2141569203942597251)],
        &[(0b01001, &ENTRY_TALMUDIZES_9309757235637123822)],
    ],
    range: 6..=11,
};

static VARS_TAI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAI_CHILDREN),
    value: None,
};

pub static VARS_TAI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lorisation"),
        dictgen::InsensitiveStr::Ascii("lorisations"),
        dictgen::InsensitiveStr::Ascii("lorise"),
        dictgen::InsensitiveStr::Ascii("lorises"),
        dictgen::InsensitiveStr::Ascii("lorization"),
        dictgen::InsensitiveStr::Ascii("lorizations"),
        dictgen::InsensitiveStr::Ascii("lorize"),
        dictgen::InsensitiveStr::Ascii("lorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TAILORIZATION_8550094274360323304)],
        &[(0b10010, &ENTRY_TAILORIZATIONS_12806791765528330193)],
        &[(0b10010, &ENTRY_TAILORIZE_16488488043819591099)],
        &[(0b10010, &ENTRY_TAILORIZES_11228159220737478922)],
        &[(0b01001, &ENTRY_TAILORIZATION_8550094274360323304)],
        &[(0b01001, &ENTRY_TAILORIZATIONS_12806791765528330193)],
        &[(0b01001, &ENTRY_TAILORIZE_16488488043819591099)],
        &[(0b01001, &ENTRY_TAILORIZES_11228159220737478922)],
    ],
    range: 6..=11,
};

static VARS_TAF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAF_CHILDREN),
    value: None,
};

pub static VARS_TAF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fetised"),
        dictgen::InsensitiveStr::Ascii("fetized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TAFFETIZED_13217162182378469791)],
        &[(0b01001, &ENTRY_TAFFETIZED_13217162182378469791)],
    ],
    range: 7..=7,
};

static VARS_TAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_TE_3678231452906120781)]),
};

pub static VARS_TAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gu"),
        dictgen::InsensitiveStr::Ascii("ls"),
        dictgen::InsensitiveStr::Ascii("nia"),
        dictgen::InsensitiveStr::Ascii("niacidal"),
        dictgen::InsensitiveStr::Ascii("niacide"),
        dictgen::InsensitiveStr::Ascii("niacides"),
        dictgen::InsensitiveStr::Ascii("niae"),
        dictgen::InsensitiveStr::Ascii("niafuge"),
        dictgen::InsensitiveStr::Ascii("niafuges"),
        dictgen::InsensitiveStr::Ascii("nias"),
        dictgen::InsensitiveStr::Ascii("niases"),
        dictgen::InsensitiveStr::Ascii("niasis"),
        dictgen::InsensitiveStr::Ascii("nioid"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TEGU_580355573665292940)],
        &[(0b11010, &ENTRY_TELS_10786558087438067092)],
        &[(0b11010, &ENTRY_TENIA_3590031604576778490)],
        &[(0b11010, &ENTRY_TENIACIDAL_541970291786449225)],
        &[(0b11010, &ENTRY_TENIACIDE_9272287110828061667)],
        &[(0b11010, &ENTRY_TENIACIDES_9085014004304381530)],
        &[(0b11010, &ENTRY_TENIAE_2460733953776370015)],
        &[(0b11010, &ENTRY_TENIAFUGE_11053879169809004952)],
        &[(0b11010, &ENTRY_TENIAFUGES_8258613951057794683)],
        &[(0b11010, &ENTRY_TENIAS_15863770479015006574)],
        &[(0b11010, &ENTRY_TENIASES_4082434292313003269)],
        &[(0b11010, &ENTRY_TENIASIS_11176202135157856401)],
        &[(0b11010, &ENTRY_TENIOID_6487095486830194346)],
        &[(0b11010, &ENTRY_TES_2695854084624117978)],
    ],
    range: 1..=8,
};

static VARS_TAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAC_CHILDREN),
    value: None,
};

pub static VARS_TAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hypnea"),
        dictgen::InsensitiveStr::Ascii("hypneas"),
        dictgen::InsensitiveStr::Ascii("hypneic"),
        dictgen::InsensitiveStr::Ascii("hypnoea"),
        dictgen::InsensitiveStr::Ascii("hypnoeas"),
        dictgen::InsensitiveStr::Ascii("hypnoeic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TACHYPNEA_2816290035207751824)],
        &[(0b00001, &ENTRY_TACHYPNEAS_4617184722695613958)],
        &[(0b00001, &ENTRY_TACHYPNEIC_363899473331751956)],
        &[(0b11010, &ENTRY_TACHYPNEA_2816290035207751824)],
        &[(0b11010, &ENTRY_TACHYPNEAS_4617184722695613958)],
        &[(0b11010, &ENTRY_TACHYPNEIC_363899473331751956)],
    ],
    range: 6..=8,
};

static VARS_TAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAB_CHILDREN),
    value: None,
};

pub static VARS_TAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("orer"),
        dictgen::InsensitiveStr::Ascii("orers"),
        dictgen::InsensitiveStr::Ascii("oret"),
        dictgen::InsensitiveStr::Ascii("orets"),
        dictgen::InsensitiveStr::Ascii("orin"),
        dictgen::InsensitiveStr::Ascii("orine"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("orins"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ourer"),
        dictgen::InsensitiveStr::Ascii("ourers"),
        dictgen::InsensitiveStr::Ascii("ouret"),
        dictgen::InsensitiveStr::Ascii("ourets"),
        dictgen::InsensitiveStr::Ascii("ourin"),
        dictgen::InsensitiveStr::Ascii("ourine"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ourins"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularisations"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularised"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularising"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularizations"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularized"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("ularizing"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TABORED_11641595972971132305)],
        &[(0b00001, &ENTRY_TABORER_13534394124897973316)],
        &[(0b00001, &ENTRY_TABORERS_2809101557456620449)],
        &[(0b00001, &ENTRY_TABORET_390741665248154587)],
        &[(0b00001, &ENTRY_TABORETS_12270021431498110056)],
        &[(0b00001, &ENTRY_TABORIN_5348657649342981597)],
        &[(0b00001, &ENTRY_TABORINE_3147952014201829383)],
        &[(0b00001, &ENTRY_TABORING_16755842556933914882)],
        &[(0b00001, &ENTRY_TABORINS_6392269866504402204)],
        &[(0b11010, &ENTRY_TABORED_11641595972971132305)],
        &[(0b11010, &ENTRY_TABORER_13534394124897973316)],
        &[(0b11010, &ENTRY_TABORERS_2809101557456620449)],
        &[(0b11010, &ENTRY_TABORET_390741665248154587)],
        &[(0b11010, &ENTRY_TABORETS_12270021431498110056)],
        &[(0b11010, &ENTRY_TABORIN_5348657649342981597)],
        &[(0b11010, &ENTRY_TABORINE_3147952014201829383)],
        &[(0b11010, &ENTRY_TABORING_16755842556933914882)],
        &[(0b11010, &ENTRY_TABORINS_6392269866504402204)],
        &[(0b11010, &ENTRY_TABULE_12901214361938682762)],
        &[(0b10010, &ENTRY_TABULARIZATION_12129488971307934801)],
        &[(0b10010, &ENTRY_TABULARIZATIONS_13558146837461796765)],
        &[(0b10010, &ENTRY_TABULARIZE_4197635393214144129)],
        &[(0b10010, &ENTRY_TABULARIZED_17222285384170548479)],
        &[(0b10010, &ENTRY_TABULARIZES_1451938906251727691)],
        &[(0b10010, &ENTRY_TABULARIZING_6952271340201339560)],
        &[(0b01001, &ENTRY_TABULARIZATION_12129488971307934801)],
        &[(0b01001, &ENTRY_TABULARIZATIONS_13558146837461796765)],
        &[(0b01001, &ENTRY_TABULARIZE_4197635393214144129)],
        &[(0b01001, &ENTRY_TABULARIZED_17222285384170548479)],
        &[(0b01001, &ENTRY_TABULARIZES_1451938906251727691)],
        &[(0b01001, &ENTRY_TABULARIZING_6952271340201339560)],
        &[(0b00001, &ENTRY_TABULE_12901214361938682762)],
    ],
    range: 3..=12,
};

static VARS_S_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_S_CHILDREN),
    value: None,
};

static VARS_S_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SA_NODE),
    None,
    Some(&VARS_SC_NODE),
    None,
    Some(&VARS_SE_NODE),
    None,
    None,
    Some(&VARS_SH_NODE),
    Some(&VARS_SI_NODE),
    None,
    Some(&VARS_SK_NODE),
    Some(&VARS_SL_NODE),
    Some(&VARS_SM_NODE),
    Some(&VARS_SN_NODE),
    Some(&VARS_SO_NODE),
    Some(&VARS_SP_NODE),
    Some(&VARS_SQ_NODE),
    None,
    None,
    Some(&VARS_ST_NODE),
    Some(&VARS_SU_NODE),
    None,
    Some(&VARS_SW_NODE),
    None,
    Some(&VARS_SY_NODE),
    None,
];

static VARS_SY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SY_CHILDREN),
    value: None,
};

static VARS_SY_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_SYC_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SYL_NODE),
    Some(&VARS_SYM_NODE),
    Some(&VARS_SYN_NODE),
    None,
    Some(&VARS_SYP_NODE),
    None,
    Some(&VARS_SYR_NODE),
    Some(&VARS_SYS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SYS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYS_CHILDREN),
    value: None,
};

pub static VARS_SYS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tematisation"),
        dictgen::InsensitiveStr::Ascii("tematisations"),
        dictgen::InsensitiveStr::Ascii("tematise"),
        dictgen::InsensitiveStr::Ascii("tematised"),
        dictgen::InsensitiveStr::Ascii("tematiser"),
        dictgen::InsensitiveStr::Ascii("tematisers"),
        dictgen::InsensitiveStr::Ascii("tematises"),
        dictgen::InsensitiveStr::Ascii("tematising"),
        dictgen::InsensitiveStr::Ascii("tematization"),
        dictgen::InsensitiveStr::Ascii("tematizations"),
        dictgen::InsensitiveStr::Ascii("tematize"),
        dictgen::InsensitiveStr::Ascii("tematized"),
        dictgen::InsensitiveStr::Ascii("tematizer"),
        dictgen::InsensitiveStr::Ascii("tematizers"),
        dictgen::InsensitiveStr::Ascii("tematizes"),
        dictgen::InsensitiveStr::Ascii("tematizing"),
        dictgen::InsensitiveStr::Ascii("temisable"),
        dictgen::InsensitiveStr::Ascii("temisabler"),
        dictgen::InsensitiveStr::Ascii("temisables"),
        dictgen::InsensitiveStr::Ascii("temisablest"),
        dictgen::InsensitiveStr::Ascii("temisation"),
        dictgen::InsensitiveStr::Ascii("temisations"),
        dictgen::InsensitiveStr::Ascii("temise"),
        dictgen::InsensitiveStr::Ascii("temised"),
        dictgen::InsensitiveStr::Ascii("temiser"),
        dictgen::InsensitiveStr::Ascii("temisers"),
        dictgen::InsensitiveStr::Ascii("temises"),
        dictgen::InsensitiveStr::Ascii("temising"),
        dictgen::InsensitiveStr::Ascii("temizable"),
        dictgen::InsensitiveStr::Ascii("temizabler"),
        dictgen::InsensitiveStr::Ascii("temizables"),
        dictgen::InsensitiveStr::Ascii("temizablest"),
        dictgen::InsensitiveStr::Ascii("temization"),
        dictgen::InsensitiveStr::Ascii("temizations"),
        dictgen::InsensitiveStr::Ascii("temize"),
        dictgen::InsensitiveStr::Ascii("temized"),
        dictgen::InsensitiveStr::Ascii("temizer"),
        dictgen::InsensitiveStr::Ascii("temizers"),
        dictgen::InsensitiveStr::Ascii("temizes"),
        dictgen::InsensitiveStr::Ascii("temizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYSTEMATIZATION_3107776542992770160)],
        &[(0b10010, &ENTRY_SYSTEMATIZATIONS_3352523032353611097)],
        &[(0b10010, &ENTRY_SYSTEMATIZE_16900057715370037545)],
        &[(0b10010, &ENTRY_SYSTEMATIZED_4844953296714238844)],
        &[(0b10010, &ENTRY_SYSTEMATIZER_5303654505244699756)],
        &[(0b10010, &ENTRY_SYSTEMATIZERS_15772744122736196869)],
        &[(0b10010, &ENTRY_SYSTEMATIZES_14036170375607791421)],
        &[(0b10010, &ENTRY_SYSTEMATIZING_13014106459165883860)],
        &[(0b01001, &ENTRY_SYSTEMATIZATION_3107776542992770160)],
        &[(0b01001, &ENTRY_SYSTEMATIZATIONS_3352523032353611097)],
        &[(0b01001, &ENTRY_SYSTEMATIZE_16900057715370037545)],
        &[(0b01001, &ENTRY_SYSTEMATIZED_4844953296714238844)],
        &[(0b01001, &ENTRY_SYSTEMATIZER_5303654505244699756)],
        &[(0b01001, &ENTRY_SYSTEMATIZERS_15772744122736196869)],
        &[(0b01001, &ENTRY_SYSTEMATIZES_14036170375607791421)],
        &[(0b01001, &ENTRY_SYSTEMATIZING_13014106459165883860)],
        &[(0b10010, &ENTRY_SYSTEMIZABLE_12189882081280949549)],
        &[(0b10010, &ENTRY_SYSTEMIZABLER_14523778083190592144)],
        &[(0b10010, &ENTRY_SYSTEMIZABLES_10780606996651648121)],
        &[(0b10010, &ENTRY_SYSTEMIZABLEST_17247488239403991289)],
        &[(0b10010, &ENTRY_SYSTEMIZATION_14190190500089956604)],
        &[(0b10010, &ENTRY_SYSTEMIZATIONS_4121671049363517727)],
        &[(0b10010, &ENTRY_SYSTEMIZE_6906592582631805748)],
        &[(0b10010, &ENTRY_SYSTEMIZED_6678000876435289660)],
        &[(0b10010, &ENTRY_SYSTEMIZER_11174811386299123332)],
        &[(0b10010, &ENTRY_SYSTEMIZERS_127559560082533162)],
        &[(0b10010, &ENTRY_SYSTEMIZES_17547677193703511225)],
        &[(0b10010, &ENTRY_SYSTEMIZING_11854782298171599250)],
        &[(0b01001, &ENTRY_SYSTEMIZABLE_12189882081280949549)],
        &[(0b01001, &ENTRY_SYSTEMIZABLER_14523778083190592144)],
        &[(0b01001, &ENTRY_SYSTEMIZABLES_10780606996651648121)],
        &[(0b01001, &ENTRY_SYSTEMIZABLEST_17247488239403991289)],
        &[(0b01001, &ENTRY_SYSTEMIZATION_14190190500089956604)],
        &[(0b01001, &ENTRY_SYSTEMIZATIONS_4121671049363517727)],
        &[(0b01001, &ENTRY_SYSTEMIZE_6906592582631805748)],
        &[(0b01001, &ENTRY_SYSTEMIZED_6678000876435289660)],
        &[(0b01001, &ENTRY_SYSTEMIZER_11174811386299123332)],
        &[(0b01001, &ENTRY_SYSTEMIZERS_127559560082533162)],
        &[(0b01001, &ENTRY_SYSTEMIZES_17547677193703511225)],
        &[(0b01001, &ENTRY_SYSTEMIZING_11854782298171599250)],
    ],
    range: 6..=13,
};

static VARS_SYR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYR_CHILDREN),
    value: None,
};

pub static VARS_SYR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ianise"),
        dictgen::InsensitiveStr::Ascii("ianises"),
        dictgen::InsensitiveStr::Ascii("ianize"),
        dictgen::InsensitiveStr::Ascii("ianizes"),
        dictgen::InsensitiveStr::Ascii("ingocele"),
        dictgen::InsensitiveStr::Ascii("ingocoele"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYRIANIZE_17228276156196119846)],
        &[(0b10010, &ENTRY_SYRIANIZES_14522632119731991691)],
        &[(0b01001, &ENTRY_SYRIANIZE_17228276156196119846)],
        &[(0b01001, &ENTRY_SYRIANIZES_14522632119731991691)],
        &[(0b00001, &ENTRY_SYRINGOCELE_10888948771227714414)],
        &[(0b11010, &ENTRY_SYRINGOCELE_10888948771227714414)],
    ],
    range: 6..=9,
};

static VARS_SYP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYP_CHILDREN),
    value: None,
};

pub static VARS_SYP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hilisation"),
        dictgen::InsensitiveStr::Ascii("hilisations"),
        dictgen::InsensitiveStr::Ascii("hilise"),
        dictgen::InsensitiveStr::Ascii("hilised"),
        dictgen::InsensitiveStr::Ascii("hilising"),
        dictgen::InsensitiveStr::Ascii("hilization"),
        dictgen::InsensitiveStr::Ascii("hilizations"),
        dictgen::InsensitiveStr::Ascii("hilize"),
        dictgen::InsensitiveStr::Ascii("hilized"),
        dictgen::InsensitiveStr::Ascii("hilizing"),
        dictgen::InsensitiveStr::Ascii("hon"),
        dictgen::InsensitiveStr::Ascii("honed"),
        dictgen::InsensitiveStr::Ascii("honing"),
        dictgen::InsensitiveStr::Ascii("honless"),
        dictgen::InsensitiveStr::Ascii("honlesses"),
        dictgen::InsensitiveStr::Ascii("honlike"),
        dictgen::InsensitiveStr::Ascii("honlikes"),
        dictgen::InsensitiveStr::Ascii("honophore"),
        dictgen::InsensitiveStr::Ascii("honostele"),
        dictgen::InsensitiveStr::Ascii("honostelic"),
        dictgen::InsensitiveStr::Ascii("honostely"),
        dictgen::InsensitiveStr::Ascii("hons"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYPHILIZATION_685514641017091080)],
        &[(0b10010, &ENTRY_SYPHILIZATIONS_2454124626789606498)],
        &[(0b10010, &ENTRY_SYPHILIZE_11883878391147817953)],
        &[(0b10010, &ENTRY_SYPHILIZED_5261656973931907777)],
        &[(0b10010, &ENTRY_SYPHILIZING_18203920249482546717)],
        &[(0b01001, &ENTRY_SYPHILIZATION_685514641017091080)],
        &[(0b01001, &ENTRY_SYPHILIZATIONS_2454124626789606498)],
        &[(0b01001, &ENTRY_SYPHILIZE_11883878391147817953)],
        &[(0b01001, &ENTRY_SYPHILIZED_5261656973931907777)],
        &[(0b01001, &ENTRY_SYPHILIZING_18203920249482546717)],
        &[(0b10010, &ENTRY_SIPHON_3485864798732184416)],
        &[(0b10010, &ENTRY_SIPHONED_18424232856912206813)],
        &[(0b10010, &ENTRY_SIPHONING_18027669453640804145)],
        &[(0b11010, &ENTRY_SIPHONLESS_7516308130535648893)],
        &[(0b11010, &ENTRY_SIPHONLESSES_11205420378358153772)],
        &[(0b11010, &ENTRY_SIPHONLIKE_2457173542292581609)],
        &[(0b11010, &ENTRY_SIPHONLIKES_6790689669445612801)],
        &[(0b11010, &ENTRY_SIPHONOPHORE_15949385627332107665)],
        &[(0b11010, &ENTRY_SIPHONOSTELE_10717604967543113626)],
        &[(0b11010, &ENTRY_SIPHONOSTELIC_6553079768516739732)],
        &[(0b11010, &ENTRY_SIPHONOSTELY_14373795432163872344)],
        &[(0b10010, &ENTRY_SIPHONS_3803350051205365845)],
    ],
    range: 3..=11,
};

static VARS_SYN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SYN_CHILDREN),
    value: None,
};

static VARS_SYN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SYNA_NODE),
    None,
    Some(&VARS_SYNC_NODE),
    Some(&VARS_SYND_NODE),
    Some(&VARS_SYNE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SYNO_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_SYNT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SYNT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYNT_CHILDREN),
    value: None,
};

pub static VARS_SYNT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hesisation"),
        dictgen::InsensitiveStr::Ascii("hesisations"),
        dictgen::InsensitiveStr::Ascii("hesise"),
        dictgen::InsensitiveStr::Ascii("hesised"),
        dictgen::InsensitiveStr::Ascii("hesiser"),
        dictgen::InsensitiveStr::Ascii("hesisers"),
        dictgen::InsensitiveStr::Ascii("hesises"),
        dictgen::InsensitiveStr::Ascii("hesising"),
        dictgen::InsensitiveStr::Ascii("hesization"),
        dictgen::InsensitiveStr::Ascii("hesizations"),
        dictgen::InsensitiveStr::Ascii("hesize"),
        dictgen::InsensitiveStr::Ascii("hesized"),
        dictgen::InsensitiveStr::Ascii("hesizes"),
        dictgen::InsensitiveStr::Ascii("hesizing"),
        dictgen::InsensitiveStr::Ascii("hetisation"),
        dictgen::InsensitiveStr::Ascii("hetiser"),
        dictgen::InsensitiveStr::Ascii("hetisers"),
        dictgen::InsensitiveStr::Ascii("hetization"),
        dictgen::InsensitiveStr::Ascii("hetize"),
        dictgen::InsensitiveStr::Ascii("hetized"),
        dictgen::InsensitiveStr::Ascii("hetizer"),
        dictgen::InsensitiveStr::Ascii("hetizers"),
        dictgen::InsensitiveStr::Ascii("hetizes"),
        dictgen::InsensitiveStr::Ascii("hetizing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYNTHESIZATION_13196049594166668291)],
        &[(0b10010, &ENTRY_SYNTHESIZATIONS_1034524582277813291)],
        &[(0b10010, &ENTRY_SYNTHESIZE_12842132831652901179)],
        &[(0b10010, &ENTRY_SYNTHESIZED_2719272835003500056)],
        &[(0b11010, &ENTRY_SYNTHESIZER_8049018325598125114)],
        &[(0b11010, &ENTRY_SYNTHESIZERS_6048422950398681894)],
        &[(0b10010, &ENTRY_SYNTHESIZES_8265650206703294571)],
        &[(0b10010, &ENTRY_SYNTHESIZING_16486290831466977941)],
        &[(0b01001, &ENTRY_SYNTHESIZATION_13196049594166668291)],
        &[(0b01001, &ENTRY_SYNTHESIZATIONS_1034524582277813291)],
        &[(0b01001, &ENTRY_SYNTHESIZE_12842132831652901179)],
        &[(0b01001, &ENTRY_SYNTHESIZED_2719272835003500056)],
        &[(0b01001, &ENTRY_SYNTHESIZES_8265650206703294571)],
        &[(0b01001, &ENTRY_SYNTHESIZING_16486290831466977941)],
        &[(0b10010, &ENTRY_SYNTHETIZATION_2620902099305510053)],
        &[(0b10010, &ENTRY_SYNTHETIZER_8576848661966983685)],
        &[(0b10010, &ENTRY_SYNTHETIZERS_4526066773883425812)],
        &[(0b01001, &ENTRY_SYNTHETIZATION_2620902099305510053)],
        &[(0b01000, &ENTRY_SYNTHESIZE_12842132831652901179)],
        &[(0b01000, &ENTRY_SYNTHESIZED_2719272835003500056)],
        &[(0b01001, &ENTRY_SYNTHETIZER_8576848661966983685)],
        &[(0b01001, &ENTRY_SYNTHETIZERS_4526066773883425812)],
        &[(0b01000, &ENTRY_SYNTHESIZES_8265650206703294571)],
        &[(0b01000, &ENTRY_SYNTHESIZING_16486290831466977941)],
        &[(0b10010, &ENTRY_SYNTONIZATION_4336252829609097315)],
        &[(0b10010, &ENTRY_SYNTONIZE_2546944290925786520)],
        &[(0b10010, &ENTRY_SYNTONIZED_8335662339289943784)],
        &[(0b10010, &ENTRY_SYNTONIZES_15432398599799360313)],
        &[(0b10010, &ENTRY_SYNTONIZING_4468391907517453561)],
        &[(0b01001, &ENTRY_SYNTONIZATION_4336252829609097315)],
        &[(0b01001, &ENTRY_SYNTONIZE_2546944290925786520)],
        &[(0b01001, &ENTRY_SYNTONIZED_8335662339289943784)],
        &[(0b01001, &ENTRY_SYNTONIZES_15432398599799360313)],
        &[(0b01001, &ENTRY_SYNTONIZING_4468391907517453561)],
    ],
    range: 5..=11,
};

static VARS_SYNO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYNO_CHILDREN),
    value: None,
};

pub static VARS_SYNO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecious"),
        dictgen::InsensitiveStr::Ascii("ecise"),
        dictgen::InsensitiveStr::Ascii("ecised"),
        dictgen::InsensitiveStr::Ascii("ecises"),
        dictgen::InsensitiveStr::Ascii("ecising"),
        dictgen::InsensitiveStr::Ascii("ecize"),
        dictgen::InsensitiveStr::Ascii("ecized"),
        dictgen::InsensitiveStr::Ascii("ecizes"),
        dictgen::InsensitiveStr::Ascii("ecizing"),
        dictgen::InsensitiveStr::Ascii("ecologies"),
        dictgen::InsensitiveStr::Ascii("ecology"),
        dictgen::InsensitiveStr::Ascii("etic"),
        dictgen::InsensitiveStr::Ascii("nymise"),
        dictgen::InsensitiveStr::Ascii("nymised"),
        dictgen::InsensitiveStr::Ascii("nymises"),
        dictgen::InsensitiveStr::Ascii("nymising"),
        dictgen::InsensitiveStr::Ascii("nymize"),
        dictgen::InsensitiveStr::Ascii("nymized"),
        dictgen::InsensitiveStr::Ascii("nymizes"),
        dictgen::InsensitiveStr::Ascii("nymizing"),
        dictgen::InsensitiveStr::Ascii("psise"),
        dictgen::InsensitiveStr::Ascii("psised"),
        dictgen::InsensitiveStr::Ascii("psises"),
        dictgen::InsensitiveStr::Ascii("psising"),
        dictgen::InsensitiveStr::Ascii("psize"),
        dictgen::InsensitiveStr::Ascii("psized"),
        dictgen::InsensitiveStr::Ascii("psizes"),
        dictgen::InsensitiveStr::Ascii("psizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SYNECIOUS_2488312687708968247)],
        &[(0b10010, &ENTRY_SYNOECIZE_3344223646530853168)],
        &[(0b10010, &ENTRY_SYNOECIZED_17602852031281858968)],
        &[(0b10010, &ENTRY_SYNOECIZES_11901914731015412038)],
        &[(0b10010, &ENTRY_SYNOECIZING_1090383705013158957)],
        &[(0b01001, &ENTRY_SYNOECIZE_3344223646530853168)],
        &[(0b01001, &ENTRY_SYNOECIZED_17602852031281858968)],
        &[(0b01001, &ENTRY_SYNOECIZES_11901914731015412038)],
        &[(0b01001, &ENTRY_SYNOECIZING_1090383705013158957)],
        &[(0b11010, &ENTRY_SYNECOLOGIES_8832429084009892084)],
        &[(0b11010, &ENTRY_SYNECOLOGY_6453378821906719817)],
        &[(0b11010, &ENTRY_SYNETIC_6742608842823378317)],
        &[(0b10010, &ENTRY_SYNONYMIZE_12944042058907607588)],
        &[(0b10010, &ENTRY_SYNONYMIZED_15711127227445279789)],
        &[(0b10010, &ENTRY_SYNONYMIZES_12611470414491051552)],
        &[(0b10010, &ENTRY_SYNONYMIZING_15525725868933153025)],
        &[(0b01001, &ENTRY_SYNONYMIZE_12944042058907607588)],
        &[(0b01001, &ENTRY_SYNONYMIZED_15711127227445279789)],
        &[(0b01001, &ENTRY_SYNONYMIZES_12611470414491051552)],
        &[(0b01001, &ENTRY_SYNONYMIZING_15525725868933153025)],
        &[(0b10010, &ENTRY_SYNOPSIZE_17024762574525177281)],
        &[(0b10010, &ENTRY_SYNOPSIZED_13456249660267777970)],
        &[(0b10010, &ENTRY_SYNOPSIZES_3670003564639771417)],
        &[(0b10010, &ENTRY_SYNOPSIZING_16020823300312837540)],
        &[(0b01001, &ENTRY_SYNOPSIZE_17024762574525177281)],
        &[(0b01001, &ENTRY_SYNOPSIZED_13456249660267777970)],
        &[(0b01001, &ENTRY_SYNOPSIZES_3670003564639771417)],
        &[(0b01001, &ENTRY_SYNOPSIZING_16020823300312837540)],
    ],
    range: 4..=9,
};

static VARS_SYNE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYNE_CHILDREN),
    value: None,
};

pub static VARS_SYNE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cious"),
        dictgen::InsensitiveStr::Ascii("cologies"),
        dictgen::InsensitiveStr::Ascii("cology"),
        dictgen::InsensitiveStr::Ascii("reses"),
        dictgen::InsensitiveStr::Ascii("resis"),
        dictgen::InsensitiveStr::Ascii("rgise"),
        dictgen::InsensitiveStr::Ascii("rgised"),
        dictgen::InsensitiveStr::Ascii("rgises"),
        dictgen::InsensitiveStr::Ascii("rgising"),
        dictgen::InsensitiveStr::Ascii("rgize"),
        dictgen::InsensitiveStr::Ascii("rgized"),
        dictgen::InsensitiveStr::Ascii("rgizes"),
        dictgen::InsensitiveStr::Ascii("rgizing"),
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
        dictgen::InsensitiveStr::Ascii("stheticer"),
        dictgen::InsensitiveStr::Ascii("stheticest"),
        dictgen::InsensitiveStr::Ascii("tic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SYNECIOUS_2488312687708968247)],
        &[(0b00001, &ENTRY_SYNECOLOGIES_8832429084009892084)],
        &[(0b00001, &ENTRY_SYNECOLOGY_6453378821906719817)],
        &[(0b00001, &ENTRY_SYNERESES_13126424202136241020)],
        &[(0b00001, &ENTRY_SYNERESIS_10309821654309135710)],
        &[(0b10010, &ENTRY_SYNERGIZE_5752966859548761839)],
        &[(0b10010, &ENTRY_SYNERGIZED_13406458228702999875)],
        &[(0b10010, &ENTRY_SYNERGIZES_17525458019004180925)],
        &[(0b10010, &ENTRY_SYNERGIZING_7507828822392518971)],
        &[(0b01001, &ENTRY_SYNERGIZE_5752966859548761839)],
        &[(0b01001, &ENTRY_SYNERGIZED_13406458228702999875)],
        &[(0b01001, &ENTRY_SYNERGIZES_17525458019004180925)],
        &[(0b01001, &ENTRY_SYNERGIZING_7507828822392518971)],
        &[(0b10001, &ENTRY_SYNESTHESIA_4530326969815539991)],
        &[(0b10001, &ENTRY_SYNESTHESIAS_7150977045966888877)],
        &[(0b10001, &ENTRY_SYNESTHETIC_17660261808766860040)],
        &[(0b10001, &ENTRY_SYNESTHETICER_13349227782355059881)],
        &[(0b10001, &ENTRY_SYNESTHETICEST_9784873845724873096)],
        &[(0b00001, &ENTRY_SYNETIC_6742608842823378317)],
    ],
    range: 3..=10,
};

static VARS_SYND_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYND_CHILDREN),
    value: None,
};

pub static VARS_SYND_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icalise"),
        dictgen::InsensitiveStr::Ascii("icalises"),
        dictgen::InsensitiveStr::Ascii("icalize"),
        dictgen::InsensitiveStr::Ascii("icalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYNDICALIZE_9263618425732181107)],
        &[(0b10010, &ENTRY_SYNDICALIZES_6354822701141617267)],
        &[(0b01001, &ENTRY_SYNDICALIZE_9263618425732181107)],
        &[(0b01001, &ENTRY_SYNDICALIZES_6354822701141617267)],
    ],
    range: 7..=8,
};

static VARS_SYNC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYNC_CHILDREN),
    value: None,
};

pub static VARS_SYNC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hronisable"),
        dictgen::InsensitiveStr::Ascii("hronisables"),
        dictgen::InsensitiveStr::Ascii("hronisation"),
        dictgen::InsensitiveStr::Ascii("hronisations"),
        dictgen::InsensitiveStr::Ascii("hronise"),
        dictgen::InsensitiveStr::Ascii("hronised"),
        dictgen::InsensitiveStr::Ascii("hroniser"),
        dictgen::InsensitiveStr::Ascii("hronisers"),
        dictgen::InsensitiveStr::Ascii("hronises"),
        dictgen::InsensitiveStr::Ascii("hronising"),
        dictgen::InsensitiveStr::Ascii("hronizable"),
        dictgen::InsensitiveStr::Ascii("hronizables"),
        dictgen::InsensitiveStr::Ascii("hronization"),
        dictgen::InsensitiveStr::Ascii("hronizations"),
        dictgen::InsensitiveStr::Ascii("hronize"),
        dictgen::InsensitiveStr::Ascii("hronized"),
        dictgen::InsensitiveStr::Ascii("hronizer"),
        dictgen::InsensitiveStr::Ascii("hronizers"),
        dictgen::InsensitiveStr::Ascii("hronizes"),
        dictgen::InsensitiveStr::Ascii("hronizing"),
        dictgen::InsensitiveStr::Ascii("retise"),
        dictgen::InsensitiveStr::Ascii("retised"),
        dictgen::InsensitiveStr::Ascii("retises"),
        dictgen::InsensitiveStr::Ascii("retising"),
        dictgen::InsensitiveStr::Ascii("retize"),
        dictgen::InsensitiveStr::Ascii("retized"),
        dictgen::InsensitiveStr::Ascii("retizes"),
        dictgen::InsensitiveStr::Ascii("retizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYNCHRONIZABLE_5225268197215049174)],
        &[(0b10010, &ENTRY_SYNCHRONIZABLES_6259281414279265566)],
        &[(0b10010, &ENTRY_SYNCHRONIZATION_15433063296853954842)],
        &[(0b10010, &ENTRY_SYNCHRONIZATIONS_11173757005398448736)],
        &[(0b10010, &ENTRY_SYNCHRONIZE_4051274325149144681)],
        &[(0b10010, &ENTRY_SYNCHRONIZED_11809698306854658807)],
        &[(0b10010, &ENTRY_SYNCHRONIZER_16183643797162044552)],
        &[(0b10010, &ENTRY_SYNCHRONIZERS_5513142999037450686)],
        &[(0b10010, &ENTRY_SYNCHRONIZES_14508130385940854115)],
        &[(0b10010, &ENTRY_SYNCHRONIZING_10768676641182362541)],
        &[(0b01001, &ENTRY_SYNCHRONIZABLE_5225268197215049174)],
        &[(0b01001, &ENTRY_SYNCHRONIZABLES_6259281414279265566)],
        &[(0b01001, &ENTRY_SYNCHRONIZATION_15433063296853954842)],
        &[(0b01001, &ENTRY_SYNCHRONIZATIONS_11173757005398448736)],
        &[(0b01001, &ENTRY_SYNCHRONIZE_4051274325149144681)],
        &[(0b01001, &ENTRY_SYNCHRONIZED_11809698306854658807)],
        &[(0b01001, &ENTRY_SYNCHRONIZER_16183643797162044552)],
        &[(0b01001, &ENTRY_SYNCHRONIZERS_5513142999037450686)],
        &[(0b01001, &ENTRY_SYNCHRONIZES_14508130385940854115)],
        &[(0b01001, &ENTRY_SYNCHRONIZING_10768676641182362541)],
        &[(0b10010, &ENTRY_SYNCRETIZE_882464552271583194)],
        &[(0b10010, &ENTRY_SYNCRETIZED_2883269728087305484)],
        &[(0b10010, &ENTRY_SYNCRETIZES_10622149550205968342)],
        &[(0b10010, &ENTRY_SYNCRETIZING_4094600194477609283)],
        &[(0b01001, &ENTRY_SYNCRETIZE_882464552271583194)],
        &[(0b01001, &ENTRY_SYNCRETIZED_2883269728087305484)],
        &[(0b01001, &ENTRY_SYNCRETIZES_10622149550205968342)],
        &[(0b01001, &ENTRY_SYNCRETIZING_4094600194477609283)],
    ],
    range: 6..=12,
};

static VARS_SYNA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYNA_CHILDREN),
    value: None,
};

pub static VARS_SYNA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ereses"),
        dictgen::InsensitiveStr::Ascii("eresis"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthesias"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
        dictgen::InsensitiveStr::Ascii("estheticer"),
        dictgen::InsensitiveStr::Ascii("estheticest"),
        dictgen::InsensitiveStr::Ascii("lepha"),
        dictgen::InsensitiveStr::Ascii("lephas"),
        dictgen::InsensitiveStr::Ascii("lephe"),
        dictgen::InsensitiveStr::Ascii("loepha"),
        dictgen::InsensitiveStr::Ascii("loephas"),
        dictgen::InsensitiveStr::Ascii("loephe"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SYNERESES_13126424202136241020)],
        &[(0b11010, &ENTRY_SYNERESIS_10309821654309135710)],
        &[(0b11010, &ENTRY_SYNESTHESIA_4530326969815539991)],
        &[(0b11010, &ENTRY_SYNESTHESIAS_7150977045966888877)],
        &[(0b11010, &ENTRY_SYNESTHETIC_17660261808766860040)],
        &[(0b11010, &ENTRY_SYNESTHETICER_13349227782355059881)],
        &[(0b11010, &ENTRY_SYNESTHETICEST_9784873845724873096)],
        &[(0b00001, &ENTRY_SYNALEPHA_16666023941858348102)],
        &[(0b00001, &ENTRY_SYNALEPHAS_3091471690052949119)],
        &[(0b00001, &ENTRY_SYNALEPHE_10251411566424510733)],
        &[(0b11010, &ENTRY_SYNALEPHA_16666023941858348102)],
        &[(0b11010, &ENTRY_SYNALEPHAS_3091471690052949119)],
        &[(0b11010, &ENTRY_SYNALEPHE_10251411566424510733)],
    ],
    range: 5..=11,
};

static VARS_SYM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SYM_CHILDREN),
    value: None,
};

static VARS_SYM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_SYMB_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SYMM_NODE),
    None,
    None,
    Some(&VARS_SYMP_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SYMP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYMP_CHILDREN),
    value: None,
};

pub static VARS_SYMP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("athise"),
        dictgen::InsensitiveStr::Ascii("athised"),
        dictgen::InsensitiveStr::Ascii("athiser"),
        dictgen::InsensitiveStr::Ascii("athisers"),
        dictgen::InsensitiveStr::Ascii("athises"),
        dictgen::InsensitiveStr::Ascii("athising"),
        dictgen::InsensitiveStr::Ascii("athisinglier"),
        dictgen::InsensitiveStr::Ascii("athisingliest"),
        dictgen::InsensitiveStr::Ascii("athisingly"),
        dictgen::InsensitiveStr::Ascii("athisings"),
        dictgen::InsensitiveStr::Ascii("athize"),
        dictgen::InsensitiveStr::Ascii("athized"),
        dictgen::InsensitiveStr::Ascii("athizer"),
        dictgen::InsensitiveStr::Ascii("athizers"),
        dictgen::InsensitiveStr::Ascii("athizes"),
        dictgen::InsensitiveStr::Ascii("athizing"),
        dictgen::InsensitiveStr::Ascii("athizinglier"),
        dictgen::InsensitiveStr::Ascii("athizingliest"),
        dictgen::InsensitiveStr::Ascii("athizingly"),
        dictgen::InsensitiveStr::Ascii("athizings"),
        dictgen::InsensitiveStr::Ascii("honisation"),
        dictgen::InsensitiveStr::Ascii("honise"),
        dictgen::InsensitiveStr::Ascii("honised"),
        dictgen::InsensitiveStr::Ascii("honising"),
        dictgen::InsensitiveStr::Ascii("honization"),
        dictgen::InsensitiveStr::Ascii("honize"),
        dictgen::InsensitiveStr::Ascii("honized"),
        dictgen::InsensitiveStr::Ascii("honizing"),
        dictgen::InsensitiveStr::Ascii("tomatise"),
        dictgen::InsensitiveStr::Ascii("tomatised"),
        dictgen::InsensitiveStr::Ascii("tomatises"),
        dictgen::InsensitiveStr::Ascii("tomatising"),
        dictgen::InsensitiveStr::Ascii("tomatize"),
        dictgen::InsensitiveStr::Ascii("tomatized"),
        dictgen::InsensitiveStr::Ascii("tomatizes"),
        dictgen::InsensitiveStr::Ascii("tomatizing"),
        dictgen::InsensitiveStr::Ascii("tomise"),
        dictgen::InsensitiveStr::Ascii("tomises"),
        dictgen::InsensitiveStr::Ascii("tomize"),
        dictgen::InsensitiveStr::Ascii("tomizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYMPATHIZE_14904500675501907799)],
        &[(0b10010, &ENTRY_SYMPATHIZED_6861363094123974820)],
        &[(0b10010, &ENTRY_SYMPATHIZER_13267697269507764406)],
        &[(0b10010, &ENTRY_SYMPATHIZERS_13386252484170054055)],
        &[(0b10010, &ENTRY_SYMPATHIZES_12347458223414813053)],
        &[(0b10010, &ENTRY_SYMPATHIZING_15316845270723087051)],
        &[(0b10010, &ENTRY_SYMPATHIZINGLIER_6375343851035596544)],
        &[(0b10010, &ENTRY_SYMPATHIZINGLIEST_2489322714478535735)],
        &[(0b10010, &ENTRY_SYMPATHIZINGLY_3895503812492133479)],
        &[(0b10010, &ENTRY_SYMPATHIZINGS_14912483334972090994)],
        &[(0b01001, &ENTRY_SYMPATHIZE_14904500675501907799)],
        &[(0b01001, &ENTRY_SYMPATHIZED_6861363094123974820)],
        &[(0b01001, &ENTRY_SYMPATHIZER_13267697269507764406)],
        &[(0b01001, &ENTRY_SYMPATHIZERS_13386252484170054055)],
        &[(0b01001, &ENTRY_SYMPATHIZES_12347458223414813053)],
        &[(0b01001, &ENTRY_SYMPATHIZING_15316845270723087051)],
        &[(0b01001, &ENTRY_SYMPATHIZINGLIER_6375343851035596544)],
        &[(0b01001, &ENTRY_SYMPATHIZINGLIEST_2489322714478535735)],
        &[(0b01001, &ENTRY_SYMPATHIZINGLY_3895503812492133479)],
        &[(0b01001, &ENTRY_SYMPATHIZINGS_14912483334972090994)],
        &[(0b10010, &ENTRY_SYMPHONIZATION_18317507523394103294)],
        &[(0b10010, &ENTRY_SYMPHONIZE_16989149248275555829)],
        &[(0b10010, &ENTRY_SYMPHONIZED_2043962099079758147)],
        &[(0b10010, &ENTRY_SYMPHONIZING_1647574775766247984)],
        &[(0b01001, &ENTRY_SYMPHONIZATION_18317507523394103294)],
        &[(0b01001, &ENTRY_SYMPHONIZE_16989149248275555829)],
        &[(0b01001, &ENTRY_SYMPHONIZED_2043962099079758147)],
        &[(0b01001, &ENTRY_SYMPHONIZING_1647574775766247984)],
        &[(0b10010, &ENTRY_SYMPTOMATIZE_6373443412857664838)],
        &[(0b10010, &ENTRY_SYMPTOMATIZED_4111737967123760822)],
        &[(0b10010, &ENTRY_SYMPTOMATIZES_709089293223559225)],
        &[(0b10010, &ENTRY_SYMPTOMATIZING_5206952739753002785)],
        &[(0b01001, &ENTRY_SYMPTOMATIZE_6373443412857664838)],
        &[(0b01001, &ENTRY_SYMPTOMATIZED_4111737967123760822)],
        &[(0b01001, &ENTRY_SYMPTOMATIZES_709089293223559225)],
        &[(0b01001, &ENTRY_SYMPTOMATIZING_5206952739753002785)],
        &[(0b10010, &ENTRY_SYMPTOMIZE_14715848522228834460)],
        &[(0b10010, &ENTRY_SYMPTOMIZES_2271031168315508299)],
        &[(0b01001, &ENTRY_SYMPTOMIZE_14715848522228834460)],
        &[(0b01001, &ENTRY_SYMPTOMIZES_2271031168315508299)],
    ],
    range: 6..=13,
};

static VARS_SYMM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYMM_CHILDREN),
    value: None,
};

pub static VARS_SYMM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etricly"),
        dictgen::InsensitiveStr::Ascii("etrisation"),
        dictgen::InsensitiveStr::Ascii("etrisations"),
        dictgen::InsensitiveStr::Ascii("etrise"),
        dictgen::InsensitiveStr::Ascii("etrised"),
        dictgen::InsensitiveStr::Ascii("etrises"),
        dictgen::InsensitiveStr::Ascii("etrising"),
        dictgen::InsensitiveStr::Ascii("etrization"),
        dictgen::InsensitiveStr::Ascii("etrizations"),
        dictgen::InsensitiveStr::Ascii("etrize"),
        dictgen::InsensitiveStr::Ascii("etrized"),
        dictgen::InsensitiveStr::Ascii("etrizes"),
        dictgen::InsensitiveStr::Ascii("etrizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SYMMETRICALLY_6141818263074127947)],
        &[(0b10010, &ENTRY_SYMMETRIZATION_15193129513805117628)],
        &[(0b10010, &ENTRY_SYMMETRIZATIONS_6985293843333697661)],
        &[(0b10010, &ENTRY_SYMMETRIZE_16248404151674446594)],
        &[(0b10010, &ENTRY_SYMMETRIZED_15665190699389382501)],
        &[(0b10010, &ENTRY_SYMMETRIZES_13244460606866139100)],
        &[(0b10010, &ENTRY_SYMMETRIZING_3371155737907396072)],
        &[(0b01001, &ENTRY_SYMMETRIZATION_15193129513805117628)],
        &[(0b01001, &ENTRY_SYMMETRIZATIONS_6985293843333697661)],
        &[(0b01001, &ENTRY_SYMMETRIZE_16248404151674446594)],
        &[(0b01001, &ENTRY_SYMMETRIZED_15665190699389382501)],
        &[(0b01001, &ENTRY_SYMMETRIZES_13244460606866139100)],
        &[(0b01001, &ENTRY_SYMMETRIZING_3371155737907396072)],
    ],
    range: 6..=11,
};

static VARS_SYMB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYMB_CHILDREN),
    value: None,
};

pub static VARS_SYMB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oled"),
        dictgen::InsensitiveStr::Ascii("oling"),
        dictgen::InsensitiveStr::Ascii("olisation"),
        dictgen::InsensitiveStr::Ascii("olisations"),
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("oliser"),
        dictgen::InsensitiveStr::Ascii("olisers"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olization"),
        dictgen::InsensitiveStr::Ascii("olizations"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizer"),
        dictgen::InsensitiveStr::Ascii("olizers"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
        dictgen::InsensitiveStr::Ascii("olled"),
        dictgen::InsensitiveStr::Ascii("olling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SYMBOLED_8647395887479826115)],
        &[(0b00001, &ENTRY_SYMBOLING_7617437864969100096)],
        &[(0b10010, &ENTRY_SYMBOLIZATION_183719897408488449)],
        &[(0b10010, &ENTRY_SYMBOLIZATIONS_11456355786708744140)],
        &[(0b10010, &ENTRY_SYMBOLIZE_10234132787766621474)],
        &[(0b10010, &ENTRY_SYMBOLIZED_10774231202089876919)],
        &[(0b10010, &ENTRY_SYMBOLIZER_4027009846211024737)],
        &[(0b10010, &ENTRY_SYMBOLIZERS_891087008054921613)],
        &[(0b10010, &ENTRY_SYMBOLIZES_16079471803221884218)],
        &[(0b10010, &ENTRY_SYMBOLIZING_3483608355906583358)],
        &[(0b01001, &ENTRY_SYMBOLIZATION_183719897408488449)],
        &[(0b01001, &ENTRY_SYMBOLIZATIONS_11456355786708744140)],
        &[(0b01001, &ENTRY_SYMBOLIZE_10234132787766621474)],
        &[(0b01001, &ENTRY_SYMBOLIZED_10774231202089876919)],
        &[(0b01001, &ENTRY_SYMBOLIZER_4027009846211024737)],
        &[(0b01001, &ENTRY_SYMBOLIZERS_891087008054921613)],
        &[(0b01001, &ENTRY_SYMBOLIZES_16079471803221884218)],
        &[(0b01001, &ENTRY_SYMBOLIZING_3483608355906583358)],
        &[(0b11010, &ENTRY_SYMBOLED_8647395887479826115)],
        &[(0b11010, &ENTRY_SYMBOLING_7617437864969100096)],
    ],
    range: 4..=10,
};

static VARS_SYL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYL_CHILDREN),
    value: None,
};

pub static VARS_SYL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("labise"),
        dictgen::InsensitiveStr::Ascii("labised"),
        dictgen::InsensitiveStr::Ascii("labises"),
        dictgen::InsensitiveStr::Ascii("labising"),
        dictgen::InsensitiveStr::Ascii("labize"),
        dictgen::InsensitiveStr::Ascii("labized"),
        dictgen::InsensitiveStr::Ascii("labizes"),
        dictgen::InsensitiveStr::Ascii("labizing"),
        dictgen::InsensitiveStr::Ascii("logisation"),
        dictgen::InsensitiveStr::Ascii("logisations"),
        dictgen::InsensitiveStr::Ascii("logise"),
        dictgen::InsensitiveStr::Ascii("logised"),
        dictgen::InsensitiveStr::Ascii("logiser"),
        dictgen::InsensitiveStr::Ascii("logisers"),
        dictgen::InsensitiveStr::Ascii("logises"),
        dictgen::InsensitiveStr::Ascii("logising"),
        dictgen::InsensitiveStr::Ascii("logization"),
        dictgen::InsensitiveStr::Ascii("logizations"),
        dictgen::InsensitiveStr::Ascii("logize"),
        dictgen::InsensitiveStr::Ascii("logized"),
        dictgen::InsensitiveStr::Ascii("logizer"),
        dictgen::InsensitiveStr::Ascii("logizers"),
        dictgen::InsensitiveStr::Ascii("logizes"),
        dictgen::InsensitiveStr::Ascii("logizing"),
        dictgen::InsensitiveStr::Ascii("vanise"),
        dictgen::InsensitiveStr::Ascii("vanises"),
        dictgen::InsensitiveStr::Ascii("vanize"),
        dictgen::InsensitiveStr::Ascii("vanizes"),
        dictgen::InsensitiveStr::Ascii("viinae"),
        dictgen::InsensitiveStr::Ascii("viine"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYLLABIZE_8311221770764080536)],
        &[(0b10010, &ENTRY_SYLLABIZED_12280190710023663969)],
        &[(0b10010, &ENTRY_SYLLABIZES_7491957200438406322)],
        &[(0b10010, &ENTRY_SYLLABIZING_5950775546479042598)],
        &[(0b01001, &ENTRY_SYLLABIZE_8311221770764080536)],
        &[(0b01001, &ENTRY_SYLLABIZED_12280190710023663969)],
        &[(0b01001, &ENTRY_SYLLABIZES_7491957200438406322)],
        &[(0b01001, &ENTRY_SYLLABIZING_5950775546479042598)],
        &[(0b10010, &ENTRY_SYLLOGIZATION_6273384756475739006)],
        &[(0b10010, &ENTRY_SYLLOGIZATIONS_14385881756548234112)],
        &[(0b10010, &ENTRY_SYLLOGIZE_8982419159006310572)],
        &[(0b10010, &ENTRY_SYLLOGIZED_9577236679427493870)],
        &[(0b10010, &ENTRY_SYLLOGIZER_15171477961371626417)],
        &[(0b10010, &ENTRY_SYLLOGIZERS_7670389343290303641)],
        &[(0b10010, &ENTRY_SYLLOGIZES_6778886382501204195)],
        &[(0b10010, &ENTRY_SYLLOGIZING_14604366328538691091)],
        &[(0b01001, &ENTRY_SYLLOGIZATION_6273384756475739006)],
        &[(0b01001, &ENTRY_SYLLOGIZATIONS_14385881756548234112)],
        &[(0b01001, &ENTRY_SYLLOGIZE_8982419159006310572)],
        &[(0b01001, &ENTRY_SYLLOGIZED_9577236679427493870)],
        &[(0b01001, &ENTRY_SYLLOGIZER_15171477961371626417)],
        &[(0b01001, &ENTRY_SYLLOGIZERS_7670389343290303641)],
        &[(0b01001, &ENTRY_SYLLOGIZES_6778886382501204195)],
        &[(0b01001, &ENTRY_SYLLOGIZING_14604366328538691091)],
        &[(0b10010, &ENTRY_SYLVANIZE_6218277727635267502)],
        &[(0b10010, &ENTRY_SYLVANIZES_8364417100363860769)],
        &[(0b01001, &ENTRY_SYLVANIZE_6218277727635267502)],
        &[(0b01001, &ENTRY_SYLVANIZES_8364417100363860769)],
        &[(0b11010, &ENTRY_SYLVIINE_1558661518759171190)],
        &[(0b00001, &ENTRY_SYLVIINE_1558661518759171190)],
    ],
    range: 5..=11,
};

static VARS_SYC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYC_CHILDREN),
    value: None,
};

pub static VARS_SYC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ophantise"),
        dictgen::InsensitiveStr::Ascii("ophantised"),
        dictgen::InsensitiveStr::Ascii("ophantises"),
        dictgen::InsensitiveStr::Ascii("ophantising"),
        dictgen::InsensitiveStr::Ascii("ophantize"),
        dictgen::InsensitiveStr::Ascii("ophantized"),
        dictgen::InsensitiveStr::Ascii("ophantizes"),
        dictgen::InsensitiveStr::Ascii("ophantizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYCOPHANTIZE_10383539428432006516)],
        &[(0b10010, &ENTRY_SYCOPHANTIZED_17903678022051333437)],
        &[(0b10010, &ENTRY_SYCOPHANTIZES_7655400992232908749)],
        &[(0b10010, &ENTRY_SYCOPHANTIZING_14455754812538167914)],
        &[(0b01001, &ENTRY_SYCOPHANTIZE_10383539428432006516)],
        &[(0b01001, &ENTRY_SYCOPHANTIZED_17903678022051333437)],
        &[(0b01001, &ENTRY_SYCOPHANTIZES_7655400992232908749)],
        &[(0b01001, &ENTRY_SYCOPHANTIZING_14455754812538167914)],
    ],
    range: 9..=11,
};

static VARS_SW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SW_CHILDREN),
    value: None,
};

pub static VARS_SW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iveled"),
        dictgen::InsensitiveStr::Ascii("iveling"),
        dictgen::InsensitiveStr::Ascii("ivelled"),
        dictgen::InsensitiveStr::Ascii("ivelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SWIVELED_12677672287636743928)],
        &[(0b00001, &ENTRY_SWIVELING_14921165234587300041)],
        &[(0b11010, &ENTRY_SWIVELED_12677672287636743928)],
        &[(0b11010, &ENTRY_SWIVELING_14921165234587300041)],
    ],
    range: 6..=8,
};

static VARS_SU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SU_CHILDREN),
    value: None,
};

static VARS_SU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_SUB_NODE),
    Some(&VARS_SUC_NODE),
    None,
    Some(&VARS_SUE_NODE),
    None,
    Some(&VARS_SUG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_SUL_NODE),
    Some(&VARS_SUM_NODE),
    None,
    None,
    Some(&VARS_SUP_NODE),
    None,
    Some(&VARS_SUR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUR_CHILDREN),
    value: None,
};

pub static VARS_SUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("gerise"),
        dictgen::InsensitiveStr::Ascii("gerises"),
        dictgen::InsensitiveStr::Ascii("gerize"),
        dictgen::InsensitiveStr::Ascii("gerizes"),
        dictgen::InsensitiveStr::Ascii("prisal"),
        dictgen::InsensitiveStr::Ascii("prizal"),
        dictgen::InsensitiveStr::Ascii("sise"),
        dictgen::InsensitiveStr::Ascii("size"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SUERS_10799148117412208703)],
        &[(0b10010, &ENTRY_SURGERIZE_1472434802402972710)],
        &[(0b10010, &ENTRY_SURGERIZES_12042123533998947443)],
        &[(0b01001, &ENTRY_SURGERIZE_1472434802402972710)],
        &[(0b01001, &ENTRY_SURGERIZES_12042123533998947443)],
        &[(0b10010, &ENTRY_SURPRIZAL_13355491429284184035)],
        &[(0b01001, &ENTRY_SURPRIZAL_13355491429284184035)],
        &[(0b10010, &ENTRY_SURSIZE_13083590681279299029)],
        &[(0b01001, &ENTRY_SURSIZE_13083590681279299029)],
    ],
    range: 2..=7,
};

static VARS_SUP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SUP_CHILDREN),
    value: None,
};

static VARS_SUP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_SUPE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SUPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SUPE_CHILDREN),
    value: None,
};

static VARS_SUPE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SUPER_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SUPER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SUPER_CHILDREN),
    value: None,
};

static VARS_SUPER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SUPERA_NODE),
    None,
    Some(&VARS_SUPERC_NODE),
    None,
    Some(&VARS_SUPERE_NODE),
    Some(&VARS_SUPERF_NODE),
    None,
    Some(&VARS_SUPERH_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SUPERN_NODE),
    Some(&VARS_SUPERO_NODE),
    None,
    None,
    None,
    Some(&VARS_SUPERS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SUPERS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERS_CHILDREN),
    value: None,
};

pub static VARS_SUPERS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ensitisation"),
        dictgen::InsensitiveStr::Ascii("ensitisations"),
        dictgen::InsensitiveStr::Ascii("ensitise"),
        dictgen::InsensitiveStr::Ascii("ensitised"),
        dictgen::InsensitiveStr::Ascii("ensitising"),
        dictgen::InsensitiveStr::Ascii("ensitization"),
        dictgen::InsensitiveStr::Ascii("ensitizations"),
        dictgen::InsensitiveStr::Ascii("ensitize"),
        dictgen::InsensitiveStr::Ascii("ensitized"),
        dictgen::InsensitiveStr::Ascii("ensitizing"),
        dictgen::InsensitiveStr::Ascii("pecialise"),
        dictgen::InsensitiveStr::Ascii("pecialises"),
        dictgen::InsensitiveStr::Ascii("pecialize"),
        dictgen::InsensitiveStr::Ascii("pecializes"),
        dictgen::InsensitiveStr::Ascii("ubtilised"),
        dictgen::InsensitiveStr::Ascii("ubtiliseds"),
        dictgen::InsensitiveStr::Ascii("ubtilized"),
        dictgen::InsensitiveStr::Ascii("ubtilizeds"),
        dictgen::InsensitiveStr::Ascii("ulphurise"),
        dictgen::InsensitiveStr::Ascii("ulphurises"),
        dictgen::InsensitiveStr::Ascii("ulphurize"),
        dictgen::InsensitiveStr::Ascii("ulphurizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUPERSENSITIZATION_13265729929436654234)],
        &[(0b10010, &ENTRY_SUPERSENSITIZATIONS_16229529539567958697)],
        &[(0b10010, &ENTRY_SUPERSENSITIZE_13394449974043516101)],
        &[(0b10010, &ENTRY_SUPERSENSITIZED_5251978935582245961)],
        &[(0b10010, &ENTRY_SUPERSENSITIZING_3421712530072007911)],
        &[(0b01001, &ENTRY_SUPERSENSITIZATION_13265729929436654234)],
        &[(0b01001, &ENTRY_SUPERSENSITIZATIONS_16229529539567958697)],
        &[(0b01001, &ENTRY_SUPERSENSITIZE_13394449974043516101)],
        &[(0b01001, &ENTRY_SUPERSENSITIZED_5251978935582245961)],
        &[(0b01001, &ENTRY_SUPERSENSITIZING_3421712530072007911)],
        &[(0b10010, &ENTRY_SUPERSPECIALIZE_14865803918277147544)],
        &[(0b10010, &ENTRY_SUPERSPECIALIZES_2203952443654557156)],
        &[(0b01001, &ENTRY_SUPERSPECIALIZE_14865803918277147544)],
        &[(0b01001, &ENTRY_SUPERSPECIALIZES_2203952443654557156)],
        &[(0b10010, &ENTRY_SUPERSUBTILIZED_191391172908983614)],
        &[(0b10010, &ENTRY_SUPERSUBTILIZEDS_13035467917751159683)],
        &[(0b01001, &ENTRY_SUPERSUBTILIZED_191391172908983614)],
        &[(0b01001, &ENTRY_SUPERSUBTILIZEDS_13035467917751159683)],
        &[(0b10010, &ENTRY_SUPERSULPHURIZE_7872635294612482254)],
        &[(0b10010, &ENTRY_SUPERSULPHURIZES_17967493374873041386)],
        &[(0b01001, &ENTRY_SUPERSULPHURIZE_7872635294612482254)],
        &[(0b01001, &ENTRY_SUPERSULPHURIZES_17967493374873041386)],
    ],
    range: 8..=13,
};

static VARS_SUPERO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERO_CHILDREN),
    value: None,
};

pub static VARS_SUPERO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganise"),
        dictgen::InsensitiveStr::Ascii("rganises"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("rganize"),
        dictgen::InsensitiveStr::Ascii("rganizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUPERORGANIZATION_16256428592681090251)],
        &[(0b10010, &ENTRY_SUPERORGANIZATIONS_7920692777226694340)],
        &[(0b10010, &ENTRY_SUPERORGANIZE_6873964070386925575)],
        &[(0b10010, &ENTRY_SUPERORGANIZES_6908853305975248236)],
        &[(0b01001, &ENTRY_SUPERORGANIZATION_16256428592681090251)],
        &[(0b01001, &ENTRY_SUPERORGANIZATIONS_7920692777226694340)],
        &[(0b01001, &ENTRY_SUPERORGANIZE_6873964070386925575)],
        &[(0b01001, &ENTRY_SUPERORGANIZES_6908853305975248236)],
    ],
    range: 7..=12,
};

static VARS_SUPERN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERN_CHILDREN),
    value: None,
};

pub static VARS_SUPERN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aturalise"),
        dictgen::InsensitiveStr::Ascii("aturalised"),
        dictgen::InsensitiveStr::Ascii("aturalises"),
        dictgen::InsensitiveStr::Ascii("aturalising"),
        dictgen::InsensitiveStr::Ascii("aturalize"),
        dictgen::InsensitiveStr::Ascii("aturalized"),
        dictgen::InsensitiveStr::Ascii("aturalizes"),
        dictgen::InsensitiveStr::Ascii("aturalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUPERNATURALIZE_1888217581153989902)],
        &[(0b10010, &ENTRY_SUPERNATURALIZED_1928759394283114442)],
        &[(0b10010, &ENTRY_SUPERNATURALIZES_13003909341630049259)],
        &[(0b10010, &ENTRY_SUPERNATURALIZING_12355223763201031189)],
        &[(0b01001, &ENTRY_SUPERNATURALIZE_1888217581153989902)],
        &[(0b01001, &ENTRY_SUPERNATURALIZED_1928759394283114442)],
        &[(0b01001, &ENTRY_SUPERNATURALIZES_13003909341630049259)],
        &[(0b01001, &ENTRY_SUPERNATURALIZING_12355223763201031189)],
    ],
    range: 9..=11,
};

static VARS_SUPERH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERH_CHILDREN),
    value: None,
};

pub static VARS_SUPERH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("umanise"),
        dictgen::InsensitiveStr::Ascii("umanised"),
        dictgen::InsensitiveStr::Ascii("umanises"),
        dictgen::InsensitiveStr::Ascii("umanising"),
        dictgen::InsensitiveStr::Ascii("umanize"),
        dictgen::InsensitiveStr::Ascii("umanized"),
        dictgen::InsensitiveStr::Ascii("umanizes"),
        dictgen::InsensitiveStr::Ascii("umanizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUPERHUMANIZE_3907028277789439524)],
        &[(0b10010, &ENTRY_SUPERHUMANIZED_13295231816777999016)],
        &[(0b10010, &ENTRY_SUPERHUMANIZES_8763034129839149008)],
        &[(0b10010, &ENTRY_SUPERHUMANIZING_13287141753608663171)],
        &[(0b01001, &ENTRY_SUPERHUMANIZE_3907028277789439524)],
        &[(0b01001, &ENTRY_SUPERHUMANIZED_13295231816777999016)],
        &[(0b01001, &ENTRY_SUPERHUMANIZES_8763034129839149008)],
        &[(0b01001, &ENTRY_SUPERHUMANIZING_13287141753608663171)],
    ],
    range: 7..=9,
};

static VARS_SUPERF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERF_CHILDREN),
    value: None,
};

pub static VARS_SUPERF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etation"),
        dictgen::InsensitiveStr::Ascii("etations"),
        dictgen::InsensitiveStr::Ascii("icialise"),
        dictgen::InsensitiveStr::Ascii("icialised"),
        dictgen::InsensitiveStr::Ascii("icialises"),
        dictgen::InsensitiveStr::Ascii("icialising"),
        dictgen::InsensitiveStr::Ascii("icialize"),
        dictgen::InsensitiveStr::Ascii("icialized"),
        dictgen::InsensitiveStr::Ascii("icializes"),
        dictgen::InsensitiveStr::Ascii("icializing"),
        dictgen::InsensitiveStr::Ascii("oetation"),
        dictgen::InsensitiveStr::Ascii("oetations"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SUPERFETATION_8769492329398167353)],
        &[(0b00001, &ENTRY_SUPERFETATIONS_13845937589834211720)],
        &[(0b10010, &ENTRY_SUPERFICIALIZE_4878826183094302727)],
        &[(0b10010, &ENTRY_SUPERFICIALIZED_3400177078863086539)],
        &[(0b10010, &ENTRY_SUPERFICIALIZES_8682644560012007515)],
        &[(0b10010, &ENTRY_SUPERFICIALIZING_17281557816321612365)],
        &[(0b01001, &ENTRY_SUPERFICIALIZE_4878826183094302727)],
        &[(0b01001, &ENTRY_SUPERFICIALIZED_3400177078863086539)],
        &[(0b01001, &ENTRY_SUPERFICIALIZES_8682644560012007515)],
        &[(0b01001, &ENTRY_SUPERFICIALIZING_17281557816321612365)],
        &[(0b11010, &ENTRY_SUPERFETATION_8769492329398167353)],
        &[(0b11010, &ENTRY_SUPERFETATIONS_13845937589834211720)],
    ],
    range: 7..=10,
};

static VARS_SUPERE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERE_CHILDREN),
    value: None,
};

pub static VARS_SUPERE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUPEREMPHASIZE_14765293780803106865)],
        &[(0b10010, &ENTRY_SUPEREMPHASIZES_9334071145444228469)],
        &[(0b01001, &ENTRY_SUPEREMPHASIZE_14765293780803106865)],
        &[(0b01001, &ENTRY_SUPEREMPHASIZES_9334071145444228469)],
    ],
    range: 8..=9,
};

static VARS_SUPERC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERC_CHILDREN),
    value: None,
};

pub static VARS_SUPERC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anonisation"),
        dictgen::InsensitiveStr::Ascii("anonisations"),
        dictgen::InsensitiveStr::Ascii("anonization"),
        dictgen::InsensitiveStr::Ascii("anonizations"),
        dictgen::InsensitiveStr::Ascii("arbonisation"),
        dictgen::InsensitiveStr::Ascii("arbonisations"),
        dictgen::InsensitiveStr::Ascii("arbonise"),
        dictgen::InsensitiveStr::Ascii("arbonises"),
        dictgen::InsensitiveStr::Ascii("arbonization"),
        dictgen::InsensitiveStr::Ascii("arbonizations"),
        dictgen::InsensitiveStr::Ascii("arbonize"),
        dictgen::InsensitiveStr::Ascii("arbonizes"),
        dictgen::InsensitiveStr::Ascii("ivilisation"),
        dictgen::InsensitiveStr::Ascii("ivilisations"),
        dictgen::InsensitiveStr::Ascii("ivilised"),
        dictgen::InsensitiveStr::Ascii("iviliseds"),
        dictgen::InsensitiveStr::Ascii("ivilization"),
        dictgen::InsensitiveStr::Ascii("ivilizations"),
        dictgen::InsensitiveStr::Ascii("ivilized"),
        dictgen::InsensitiveStr::Ascii("ivilizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUPERCANONIZATION_17683305064053601136)],
        &[(0b10010, &ENTRY_SUPERCANONIZATIONS_1119676930445903493)],
        &[(0b01001, &ENTRY_SUPERCANONIZATION_17683305064053601136)],
        &[(0b01001, &ENTRY_SUPERCANONIZATIONS_1119676930445903493)],
        &[(0b10010, &ENTRY_SUPERCARBONIZATION_6095551176388121901)],
        &[(0b10010, &ENTRY_SUPERCARBONIZATIONS_3247843337047706639)],
        &[(0b10010, &ENTRY_SUPERCARBONIZE_9134949404520115058)],
        &[(0b10010, &ENTRY_SUPERCARBONIZES_4714606489710886222)],
        &[(0b01001, &ENTRY_SUPERCARBONIZATION_6095551176388121901)],
        &[(0b01001, &ENTRY_SUPERCARBONIZATIONS_3247843337047706639)],
        &[(0b01001, &ENTRY_SUPERCARBONIZE_9134949404520115058)],
        &[(0b01001, &ENTRY_SUPERCARBONIZES_4714606489710886222)],
        &[(0b10010, &ENTRY_SUPERCIVILIZATION_17594967252879848979)],
        &[(0b10010, &ENTRY_SUPERCIVILIZATIONS_13936444365054891455)],
        &[(0b10010, &ENTRY_SUPERCIVILIZED_14265601213590631881)],
        &[(0b10010, &ENTRY_SUPERCIVILIZEDS_9933421721846909294)],
        &[(0b01001, &ENTRY_SUPERCIVILIZATION_17594967252879848979)],
        &[(0b01001, &ENTRY_SUPERCIVILIZATIONS_13936444365054891455)],
        &[(0b01001, &ENTRY_SUPERCIVILIZED_14265601213590631881)],
        &[(0b01001, &ENTRY_SUPERCIVILIZEDS_9933421721846909294)],
    ],
    range: 8..=13,
};

static VARS_SUPERA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERA_CHILDREN),
    value: None,
};

pub static VARS_SUPERA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cknowledgement"),
        dictgen::InsensitiveStr::Ascii("cknowledgements"),
        dictgen::InsensitiveStr::Ascii("cknowledgment"),
        dictgen::InsensitiveStr::Ascii("cknowledgments"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SUPERACKNOWLEDGMENT_16445420068922742152)],
        &[(0b11010, &ENTRY_SUPERACKNOWLEDGMENTS_4098865423626000036)],
        &[(0b00001, &ENTRY_SUPERACKNOWLEDGMENT_16445420068922742152)],
        &[(0b00001, &ENTRY_SUPERACKNOWLEDGMENTS_4098865423626000036)],
    ],
    range: 13..=15,
};

static VARS_SUM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUM_CHILDREN),
    value: None,
};

pub static VARS_SUM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("marisable"),
        dictgen::InsensitiveStr::Ascii("marisation"),
        dictgen::InsensitiveStr::Ascii("marisations"),
        dictgen::InsensitiveStr::Ascii("marise"),
        dictgen::InsensitiveStr::Ascii("marised"),
        dictgen::InsensitiveStr::Ascii("mariser"),
        dictgen::InsensitiveStr::Ascii("marisers"),
        dictgen::InsensitiveStr::Ascii("marises"),
        dictgen::InsensitiveStr::Ascii("marising"),
        dictgen::InsensitiveStr::Ascii("marizable"),
        dictgen::InsensitiveStr::Ascii("marization"),
        dictgen::InsensitiveStr::Ascii("marizations"),
        dictgen::InsensitiveStr::Ascii("marize"),
        dictgen::InsensitiveStr::Ascii("marized"),
        dictgen::InsensitiveStr::Ascii("marizer"),
        dictgen::InsensitiveStr::Ascii("marizers"),
        dictgen::InsensitiveStr::Ascii("marizes"),
        dictgen::InsensitiveStr::Ascii("marizing"),
        dictgen::InsensitiveStr::Ascii("merise"),
        dictgen::InsensitiveStr::Ascii("merises"),
        dictgen::InsensitiveStr::Ascii("merize"),
        dictgen::InsensitiveStr::Ascii("merizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUMMARIZABLE_11797340382217227203)],
        &[(0b10010, &ENTRY_SUMMARIZATION_9281770067935535362)],
        &[(0b10010, &ENTRY_SUMMARIZATIONS_6327594643920428186)],
        &[(0b10010, &ENTRY_SUMMARIZE_7205302793340192646)],
        &[(0b10010, &ENTRY_SUMMARIZED_16717521893464613077)],
        &[(0b10010, &ENTRY_SUMMARIZER_11266733895685449964)],
        &[(0b10010, &ENTRY_SUMMARIZERS_8415819060575461568)],
        &[(0b10010, &ENTRY_SUMMARIZES_7904661076957850623)],
        &[(0b10010, &ENTRY_SUMMARIZING_12169215762339627229)],
        &[(0b01001, &ENTRY_SUMMARIZABLE_11797340382217227203)],
        &[(0b01001, &ENTRY_SUMMARIZATION_9281770067935535362)],
        &[(0b01001, &ENTRY_SUMMARIZATIONS_6327594643920428186)],
        &[(0b01001, &ENTRY_SUMMARIZE_7205302793340192646)],
        &[(0b01001, &ENTRY_SUMMARIZED_16717521893464613077)],
        &[(0b01001, &ENTRY_SUMMARIZER_11266733895685449964)],
        &[(0b01001, &ENTRY_SUMMARIZERS_8415819060575461568)],
        &[(0b01001, &ENTRY_SUMMARIZES_7904661076957850623)],
        &[(0b01001, &ENTRY_SUMMARIZING_12169215762339627229)],
        &[(0b10010, &ENTRY_SUMMERIZE_10663979453286201359)],
        &[(0b10010, &ENTRY_SUMMERIZES_3040653270422312241)],
        &[(0b01001, &ENTRY_SUMMERIZE_10663979453286201359)],
        &[(0b01001, &ENTRY_SUMMERIZES_3040653270422312241)],
    ],
    range: 6..=11,
};

static VARS_SUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUL_CHILDREN),
    value: None,
};

pub static VARS_SUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("calise"),
        dictgen::InsensitiveStr::Ascii("calised"),
        dictgen::InsensitiveStr::Ascii("calises"),
        dictgen::InsensitiveStr::Ascii("calising"),
        dictgen::InsensitiveStr::Ascii("calize"),
        dictgen::InsensitiveStr::Ascii("calized"),
        dictgen::InsensitiveStr::Ascii("calizes"),
        dictgen::InsensitiveStr::Ascii("calizing"),
        dictgen::InsensitiveStr::Ascii("fate"),
        dictgen::InsensitiveStr::Ascii("fates"),
        dictgen::InsensitiveStr::Ascii("fatise"),
        dictgen::InsensitiveStr::Ascii("fatises"),
        dictgen::InsensitiveStr::Ascii("fatize"),
        dictgen::InsensitiveStr::Ascii("fatizes"),
        dictgen::InsensitiveStr::Ascii("fide"),
        dictgen::InsensitiveStr::Ascii("fides"),
        dictgen::InsensitiveStr::Ascii("furic"),
        dictgen::InsensitiveStr::Ascii("furization"),
        dictgen::InsensitiveStr::Ascii("furizations"),
        dictgen::InsensitiveStr::Ascii("furize"),
        dictgen::InsensitiveStr::Ascii("furized"),
        dictgen::InsensitiveStr::Ascii("furizes"),
        dictgen::InsensitiveStr::Ascii("furizing"),
        dictgen::InsensitiveStr::Ascii("furous"),
        dictgen::InsensitiveStr::Ascii("phate"),
        dictgen::InsensitiveStr::Ascii("phates"),
        dictgen::InsensitiveStr::Ascii("phide"),
        dictgen::InsensitiveStr::Ascii("phides"),
        dictgen::InsensitiveStr::Ascii("phur"),
        dictgen::InsensitiveStr::Ascii("phured"),
        dictgen::InsensitiveStr::Ascii("phuric"),
        dictgen::InsensitiveStr::Ascii("phuring"),
        dictgen::InsensitiveStr::Ascii("phurisation"),
        dictgen::InsensitiveStr::Ascii("phurisations"),
        dictgen::InsensitiveStr::Ascii("phurise"),
        dictgen::InsensitiveStr::Ascii("phurised"),
        dictgen::InsensitiveStr::Ascii("phurises"),
        dictgen::InsensitiveStr::Ascii("phurising"),
        dictgen::InsensitiveStr::Ascii("phurization"),
        dictgen::InsensitiveStr::Ascii("phurizations"),
        dictgen::InsensitiveStr::Ascii("phurize"),
        dictgen::InsensitiveStr::Ascii("phurized"),
        dictgen::InsensitiveStr::Ascii("phurizes"),
        dictgen::InsensitiveStr::Ascii("phurizing"),
        dictgen::InsensitiveStr::Ascii("phurous"),
        dictgen::InsensitiveStr::Ascii("phurs"),
        dictgen::InsensitiveStr::Ascii("tanise"),
        dictgen::InsensitiveStr::Ascii("tanises"),
        dictgen::InsensitiveStr::Ascii("tanize"),
        dictgen::InsensitiveStr::Ascii("tanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SULCALIZE_2938309778844562772)],
        &[(0b10010, &ENTRY_SULCALIZED_13504221656842077518)],
        &[(0b10010, &ENTRY_SULCALIZES_9396799022900306191)],
        &[(0b10010, &ENTRY_SULCALIZING_15642492133518955698)],
        &[(0b01001, &ENTRY_SULCALIZE_2938309778844562772)],
        &[(0b01001, &ENTRY_SULCALIZED_13504221656842077518)],
        &[(0b01001, &ENTRY_SULCALIZES_9396799022900306191)],
        &[(0b01001, &ENTRY_SULCALIZING_15642492133518955698)],
        &[(0b01001, &ENTRY_SULFATE_5597431207872465349)],
        &[(0b01001, &ENTRY_SULFATES_8796950330452912058)],
        &[(0b10010, &ENTRY_SULFATIZE_16108553705217849389)],
        &[(0b10010, &ENTRY_SULFATIZES_11692908458573934003)],
        &[(0b01001, &ENTRY_SULFATIZE_16108553705217849389)],
        &[(0b01001, &ENTRY_SULFATIZES_11692908458573934003)],
        &[(0b01001, &ENTRY_SULFIDE_9727735702512693147)],
        &[(0b01001, &ENTRY_SULFIDES_13405158617155232434)],
        &[(0b11001, &ENTRY_SULFURIC_10293656358970420214)],
        &[(0b00001, &ENTRY_SULFURIZATION_797568185517141197)],
        &[(0b00001, &ENTRY_SULFURIZATIONS_9408911189702855813)],
        &[(0b00001, &ENTRY_SULFURIZE_8846852934236096730)],
        &[(0b00001, &ENTRY_SULFURIZED_3822416265235130962)],
        &[(0b00001, &ENTRY_SULFURIZES_932516641833566211)],
        &[(0b00001, &ENTRY_SULFURIZING_12427710021489862632)],
        &[(0b01001, &ENTRY_SULFUROUS_15394058625634122012)],
        &[(0b11010, &ENTRY_SULFATE_5597431207872465349)],
        &[(0b11010, &ENTRY_SULFATES_8796950330452912058)],
        &[(0b11010, &ENTRY_SULFIDE_9727735702512693147)],
        &[(0b11010, &ENTRY_SULFIDES_13405158617155232434)],
        &[(0b11010, &ENTRY_SULFUR_3036232781385162519)],
        &[(0b11010, &ENTRY_SULFURED_11124029077762090229)],
        &[(0b11010, &ENTRY_SULFURIC_10293656358970420214)],
        &[(0b11010, &ENTRY_SULFURING_14046967905068039328)],
        &[(0b10010, &ENTRY_SULFURIZATION_797568185517141197)],
        &[(0b10010, &ENTRY_SULFURIZATIONS_9408911189702855813)],
        &[(0b10010, &ENTRY_SULFURIZE_8846852934236096730)],
        &[(0b10010, &ENTRY_SULFURIZED_3822416265235130962)],
        &[(0b10010, &ENTRY_SULFURIZES_932516641833566211)],
        &[(0b10010, &ENTRY_SULFURIZING_12427710021489862632)],
        &[(0b01000, &ENTRY_SULFURIZATION_797568185517141197)],
        &[(0b01000, &ENTRY_SULFURIZATIONS_9408911189702855813)],
        &[(0b01000, &ENTRY_SULFURIZE_8846852934236096730)],
        &[(0b01000, &ENTRY_SULFURIZED_3822416265235130962)],
        &[(0b01000, &ENTRY_SULFURIZES_932516641833566211)],
        &[(0b01000, &ENTRY_SULFURIZING_12427710021489862632)],
        &[(0b11010, &ENTRY_SULFUROUS_15394058625634122012)],
        &[(0b11010, &ENTRY_SULFURS_6162252460689699663)],
        &[(0b10010, &ENTRY_SULTANIZE_4089644632105301224)],
        &[(0b10010, &ENTRY_SULTANIZES_5504812872942776048)],
        &[(0b01001, &ENTRY_SULTANIZE_4089644632105301224)],
        &[(0b01001, &ENTRY_SULTANIZES_5504812872942776048)],
    ],
    range: 4..=12,
};

static VARS_SUG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUG_CHILDREN),
    value: None,
};

pub static VARS_SUG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gestionise"),
        dictgen::InsensitiveStr::Ascii("gestionises"),
        dictgen::InsensitiveStr::Ascii("gestionize"),
        dictgen::InsensitiveStr::Ascii("gestionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUGGESTIONIZE_14021259995286429862)],
        &[(0b10010, &ENTRY_SUGGESTIONIZES_8428442750421813025)],
        &[(0b01001, &ENTRY_SUGGESTIONIZE_14021259995286429862)],
        &[(0b01001, &ENTRY_SUGGESTIONIZES_8428442750421813025)],
    ],
    range: 10..=11,
};

static VARS_SUE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUE_CHILDREN),
    value: None,
};

pub static VARS_SUE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("rs")],
    values: &[&[(0b00001, &ENTRY_SUERS_10799148117412208703)]],
    range: 2..=2,
};

static VARS_SUC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUC_CHILDREN),
    value: None,
};

pub static VARS_SUC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cor"),
        dictgen::InsensitiveStr::Ascii("corable"),
        dictgen::InsensitiveStr::Ascii("corables"),
        dictgen::InsensitiveStr::Ascii("cored"),
        dictgen::InsensitiveStr::Ascii("corer"),
        dictgen::InsensitiveStr::Ascii("corers"),
        dictgen::InsensitiveStr::Ascii("corful"),
        dictgen::InsensitiveStr::Ascii("coring"),
        dictgen::InsensitiveStr::Ascii("corless"),
        dictgen::InsensitiveStr::Ascii("corlesses"),
        dictgen::InsensitiveStr::Ascii("corrhea"),
        dictgen::InsensitiveStr::Ascii("corrhoea"),
        dictgen::InsensitiveStr::Ascii("cors"),
        dictgen::InsensitiveStr::Ascii("cour"),
        dictgen::InsensitiveStr::Ascii("courable"),
        dictgen::InsensitiveStr::Ascii("courables"),
        dictgen::InsensitiveStr::Ascii("coured"),
        dictgen::InsensitiveStr::Ascii("courer"),
        dictgen::InsensitiveStr::Ascii("courers"),
        dictgen::InsensitiveStr::Ascii("courful"),
        dictgen::InsensitiveStr::Ascii("couring"),
        dictgen::InsensitiveStr::Ascii("courless"),
        dictgen::InsensitiveStr::Ascii("courlesses"),
        dictgen::InsensitiveStr::Ascii("cours"),
        dictgen::InsensitiveStr::Ascii("cubae"),
        dictgen::InsensitiveStr::Ascii("cube"),
    ],
    values: &[
        &[(0b10001, &ENTRY_SUCCOR_17748336429959042470)],
        &[(0b10001, &ENTRY_SUCCORABLE_8193040169819434674)],
        &[(0b10001, &ENTRY_SUCCORABLES_10056192329668029969)],
        &[(0b10001, &ENTRY_SUCCORED_5734881716933621932)],
        &[(0b10001, &ENTRY_SUCCORER_13160971653163440928)],
        &[(0b10001, &ENTRY_SUCCORERS_1481818548982553037)],
        &[(0b10001, &ENTRY_SUCCORFUL_6831680557192624315)],
        &[(0b10001, &ENTRY_SUCCORING_2368336012653392444)],
        &[(0b10001, &ENTRY_SUCCORLESS_1279983428236022133)],
        &[(0b00001, &ENTRY_SUCCORLESSES_14511871674951354789)],
        &[(0b00001, &ENTRY_SUCCORRHEA_11639508368864631200)],
        &[(0b11010, &ENTRY_SUCCORRHEA_11639508368864631200)],
        &[(0b10001, &ENTRY_SUCCORS_12549649896393872866)],
        &[(0b11010, &ENTRY_SUCCOR_17748336429959042470)],
        &[(0b11010, &ENTRY_SUCCORABLE_8193040169819434674)],
        &[(0b11010, &ENTRY_SUCCORABLES_10056192329668029969)],
        &[(0b11010, &ENTRY_SUCCORED_5734881716933621932)],
        &[(0b11010, &ENTRY_SUCCORER_13160971653163440928)],
        &[(0b11010, &ENTRY_SUCCORERS_1481818548982553037)],
        &[(0b11010, &ENTRY_SUCCORFUL_6831680557192624315)],
        &[(0b11010, &ENTRY_SUCCORING_2368336012653392444)],
        &[(0b11010, &ENTRY_SUCCORLESS_1279983428236022133)],
        &[(0b11010, &ENTRY_SUCCORLESSES_14511871674951354789)],
        &[(0b11010, &ENTRY_SUCCORS_12549649896393872866)],
        &[(0b11010, &ENTRY_SUCCUBE_6000773581681008450)],
        &[(0b00001, &ENTRY_SUCCUBE_6000773581681008450)],
    ],
    range: 3..=10,
};

static VARS_SUB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SUB_CHILDREN),
    value: None,
};

static VARS_SUB_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SUBA_NODE),
    None,
    Some(&VARS_SUBC_NODE),
    Some(&VARS_SUBD_NODE),
    Some(&VARS_SUBE_NODE),
    Some(&VARS_SUBF_NODE),
    None,
    None,
    Some(&VARS_SUBI_NODE),
    Some(&VARS_SUBJ_NODE),
    None,
    Some(&VARS_SUBL_NODE),
    Some(&VARS_SUBM_NODE),
    None,
    Some(&VARS_SUBO_NODE),
    Some(&VARS_SUBP_NODE),
    None,
    None,
    Some(&VARS_SUBS_NODE),
    Some(&VARS_SUBT_NODE),
    Some(&VARS_SUBU_NODE),
    Some(&VARS_SUBV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_SUBV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBV_CHILDREN),
    value: None,
};

pub static VARS_SUBV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("italisation"),
        dictgen::InsensitiveStr::Ascii("italised"),
        dictgen::InsensitiveStr::Ascii("italisedder"),
        dictgen::InsensitiveStr::Ascii("italiseddest"),
        dictgen::InsensitiveStr::Ascii("italiseds"),
        dictgen::InsensitiveStr::Ascii("italization"),
        dictgen::InsensitiveStr::Ascii("italized"),
        dictgen::InsensitiveStr::Ascii("italizedder"),
        dictgen::InsensitiveStr::Ascii("italizeddest"),
        dictgen::InsensitiveStr::Ascii("italizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBVITALIZATION_2234121536923804898)],
        &[(0b10010, &ENTRY_SUBVITALIZED_11390686209800763194)],
        &[(0b10010, &ENTRY_SUBVITALIZEDDER_16935286009271794249)],
        &[(0b10010, &ENTRY_SUBVITALIZEDDEST_14140395937370435021)],
        &[(0b10010, &ENTRY_SUBVITALIZEDS_16695614298676695891)],
        &[(0b01001, &ENTRY_SUBVITALIZATION_2234121536923804898)],
        &[(0b01001, &ENTRY_SUBVITALIZED_11390686209800763194)],
        &[(0b01001, &ENTRY_SUBVITALIZEDDER_16935286009271794249)],
        &[(0b01001, &ENTRY_SUBVITALIZEDDEST_14140395937370435021)],
        &[(0b01001, &ENTRY_SUBVITALIZEDS_16695614298676695891)],
    ],
    range: 8..=12,
};

static VARS_SUBU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBU_CHILDREN),
    value: None,
};

pub static VARS_SUBU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rbanisation"),
        dictgen::InsensitiveStr::Ascii("rbanisations"),
        dictgen::InsensitiveStr::Ascii("rbanise"),
        dictgen::InsensitiveStr::Ascii("rbanised"),
        dictgen::InsensitiveStr::Ascii("rbanises"),
        dictgen::InsensitiveStr::Ascii("rbanising"),
        dictgen::InsensitiveStr::Ascii("rbanization"),
        dictgen::InsensitiveStr::Ascii("rbanizations"),
        dictgen::InsensitiveStr::Ascii("rbanize"),
        dictgen::InsensitiveStr::Ascii("rbanized"),
        dictgen::InsensitiveStr::Ascii("rbanizes"),
        dictgen::InsensitiveStr::Ascii("rbanizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBURBANIZATION_3414694287850191476)],
        &[(0b10010, &ENTRY_SUBURBANIZATIONS_11288460981948975469)],
        &[(0b10010, &ENTRY_SUBURBANIZE_8705753901311457396)],
        &[(0b10010, &ENTRY_SUBURBANIZED_14463903828300157975)],
        &[(0b10010, &ENTRY_SUBURBANIZES_1453459705211408783)],
        &[(0b10010, &ENTRY_SUBURBANIZING_10298908135687396391)],
        &[(0b01001, &ENTRY_SUBURBANIZATION_3414694287850191476)],
        &[(0b01001, &ENTRY_SUBURBANIZATIONS_11288460981948975469)],
        &[(0b01001, &ENTRY_SUBURBANIZE_8705753901311457396)],
        &[(0b01001, &ENTRY_SUBURBANIZED_14463903828300157975)],
        &[(0b01001, &ENTRY_SUBURBANIZES_1453459705211408783)],
        &[(0b01001, &ENTRY_SUBURBANIZING_10298908135687396391)],
    ],
    range: 7..=12,
};

static VARS_SUBT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBT_CHILDREN),
    value: None,
};

pub static VARS_SUBT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erraneanise"),
        dictgen::InsensitiveStr::Ascii("erraneanises"),
        dictgen::InsensitiveStr::Ascii("erraneanize"),
        dictgen::InsensitiveStr::Ascii("erraneanizes"),
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("iliser"),
        dictgen::InsensitiveStr::Ascii("ilisers"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizer"),
        dictgen::InsensitiveStr::Ascii("ilizers"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
        dictgen::InsensitiveStr::Ascii("otaled"),
        dictgen::InsensitiveStr::Ascii("otaling"),
        dictgen::InsensitiveStr::Ascii("otalled"),
        dictgen::InsensitiveStr::Ascii("otalling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBTERRANEANIZE_4933036662972416297)],
        &[(0b10010, &ENTRY_SUBTERRANEANIZES_11453052809587097988)],
        &[(0b01001, &ENTRY_SUBTERRANEANIZE_4933036662972416297)],
        &[(0b01001, &ENTRY_SUBTERRANEANIZES_11453052809587097988)],
        &[(0b10010, &ENTRY_SUBTILIZATION_1777218873123835692)],
        &[(0b10010, &ENTRY_SUBTILIZATIONS_17765701698989538260)],
        &[(0b10010, &ENTRY_SUBTILIZE_14600672625543696252)],
        &[(0b10010, &ENTRY_SUBTILIZED_6481039469260968556)],
        &[(0b10010, &ENTRY_SUBTILIZER_13298729605235827690)],
        &[(0b10010, &ENTRY_SUBTILIZERS_6535260454278612470)],
        &[(0b10010, &ENTRY_SUBTILIZES_13403038892595792400)],
        &[(0b10010, &ENTRY_SUBTILIZING_2257348183132014726)],
        &[(0b01001, &ENTRY_SUBTILIZATION_1777218873123835692)],
        &[(0b01001, &ENTRY_SUBTILIZATIONS_17765701698989538260)],
        &[(0b01001, &ENTRY_SUBTILIZE_14600672625543696252)],
        &[(0b01001, &ENTRY_SUBTILIZED_6481039469260968556)],
        &[(0b01001, &ENTRY_SUBTILIZER_13298729605235827690)],
        &[(0b01001, &ENTRY_SUBTILIZERS_6535260454278612470)],
        &[(0b01001, &ENTRY_SUBTILIZES_13403038892595792400)],
        &[(0b01001, &ENTRY_SUBTILIZING_2257348183132014726)],
        &[(0b00001, &ENTRY_SUBTOTALED_2297106669732865188)],
        &[(0b00001, &ENTRY_SUBTOTALING_6150888332120898834)],
        &[(0b11010, &ENTRY_SUBTOTALED_2297106669732865188)],
        &[(0b11010, &ENTRY_SUBTOTALING_6150888332120898834)],
    ],
    range: 5..=12,
};

static VARS_SUBS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBS_CHILDREN),
    value: None,
};

pub static VARS_SUBS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("idisable"),
        dictgen::InsensitiveStr::Ascii("idisables"),
        dictgen::InsensitiveStr::Ascii("idisation"),
        dictgen::InsensitiveStr::Ascii("idisations"),
        dictgen::InsensitiveStr::Ascii("idise"),
        dictgen::InsensitiveStr::Ascii("idised"),
        dictgen::InsensitiveStr::Ascii("idiser"),
        dictgen::InsensitiveStr::Ascii("idisers"),
        dictgen::InsensitiveStr::Ascii("idises"),
        dictgen::InsensitiveStr::Ascii("idising"),
        dictgen::InsensitiveStr::Ascii("idizable"),
        dictgen::InsensitiveStr::Ascii("idizables"),
        dictgen::InsensitiveStr::Ascii("idization"),
        dictgen::InsensitiveStr::Ascii("idizations"),
        dictgen::InsensitiveStr::Ascii("idize"),
        dictgen::InsensitiveStr::Ascii("idized"),
        dictgen::InsensitiveStr::Ascii("idizer"),
        dictgen::InsensitiveStr::Ascii("idizers"),
        dictgen::InsensitiveStr::Ascii("idizes"),
        dictgen::InsensitiveStr::Ascii("idizing"),
        dictgen::InsensitiveStr::Ascii("pecialise"),
        dictgen::InsensitiveStr::Ascii("pecialises"),
        dictgen::InsensitiveStr::Ascii("pecialities"),
        dictgen::InsensitiveStr::Ascii("peciality"),
        dictgen::InsensitiveStr::Ascii("pecialize"),
        dictgen::InsensitiveStr::Ascii("pecializes"),
        dictgen::InsensitiveStr::Ascii("pecialties"),
        dictgen::InsensitiveStr::Ascii("pecialty"),
        dictgen::InsensitiveStr::Ascii("tandardise"),
        dictgen::InsensitiveStr::Ascii("tandardises"),
        dictgen::InsensitiveStr::Ascii("tandardize"),
        dictgen::InsensitiveStr::Ascii("tandardizes"),
        dictgen::InsensitiveStr::Ascii("tantialise"),
        dictgen::InsensitiveStr::Ascii("tantialised"),
        dictgen::InsensitiveStr::Ascii("tantialises"),
        dictgen::InsensitiveStr::Ascii("tantialising"),
        dictgen::InsensitiveStr::Ascii("tantialize"),
        dictgen::InsensitiveStr::Ascii("tantialized"),
        dictgen::InsensitiveStr::Ascii("tantializes"),
        dictgen::InsensitiveStr::Ascii("tantializing"),
        dictgen::InsensitiveStr::Ascii("tantivise"),
        dictgen::InsensitiveStr::Ascii("tantivised"),
        dictgen::InsensitiveStr::Ascii("tantivises"),
        dictgen::InsensitiveStr::Ascii("tantivising"),
        dictgen::InsensitiveStr::Ascii("tantivize"),
        dictgen::InsensitiveStr::Ascii("tantivized"),
        dictgen::InsensitiveStr::Ascii("tantivizes"),
        dictgen::InsensitiveStr::Ascii("tantivizing"),
        dictgen::InsensitiveStr::Ascii("terilisation"),
        dictgen::InsensitiveStr::Ascii("terilization"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBSIDIZABLE_7909557660059621352)],
        &[(0b10010, &ENTRY_SUBSIDIZABLES_3230006499890888386)],
        &[(0b10010, &ENTRY_SUBSIDIZATION_7432910440349917685)],
        &[(0b10010, &ENTRY_SUBSIDIZATIONS_4486482297001394355)],
        &[(0b10010, &ENTRY_SUBSIDIZE_8108840583723309870)],
        &[(0b10010, &ENTRY_SUBSIDIZED_12233822221943616893)],
        &[(0b10010, &ENTRY_SUBSIDIZER_1594720106549650311)],
        &[(0b10010, &ENTRY_SUBSIDIZERS_16869546055076390406)],
        &[(0b10010, &ENTRY_SUBSIDIZES_12108807615198513181)],
        &[(0b10010, &ENTRY_SUBSIDIZING_2003367098489373574)],
        &[(0b01001, &ENTRY_SUBSIDIZABLE_7909557660059621352)],
        &[(0b01001, &ENTRY_SUBSIDIZABLES_3230006499890888386)],
        &[(0b01001, &ENTRY_SUBSIDIZATION_7432910440349917685)],
        &[(0b01001, &ENTRY_SUBSIDIZATIONS_4486482297001394355)],
        &[(0b01001, &ENTRY_SUBSIDIZE_8108840583723309870)],
        &[(0b01001, &ENTRY_SUBSIDIZED_12233822221943616893)],
        &[(0b01001, &ENTRY_SUBSIDIZER_1594720106549650311)],
        &[(0b01001, &ENTRY_SUBSIDIZERS_16869546055076390406)],
        &[(0b01001, &ENTRY_SUBSIDIZES_12108807615198513181)],
        &[(0b01001, &ENTRY_SUBSIDIZING_2003367098489373574)],
        &[(0b10010, &ENTRY_SUBSPECIALIZE_13734659418809213289)],
        &[(0b10010, &ENTRY_SUBSPECIALIZES_16872835233018448770)],
        &[(0b11010, &ENTRY_SUBSPECIALTIES_2578544006462378304)],
        &[(0b11010, &ENTRY_SUBSPECIALTY_8060605560355986087)],
        &[(0b01001, &ENTRY_SUBSPECIALIZE_13734659418809213289)],
        &[(0b01001, &ENTRY_SUBSPECIALIZES_16872835233018448770)],
        &[(0b00001, &ENTRY_SUBSPECIALTIES_2578544006462378304)],
        &[(0b00001, &ENTRY_SUBSPECIALTY_8060605560355986087)],
        &[(0b10010, &ENTRY_SUBSTANDARDIZE_2480873768266314489)],
        &[(0b10010, &ENTRY_SUBSTANDARDIZES_12565775678053536739)],
        &[(0b01001, &ENTRY_SUBSTANDARDIZE_2480873768266314489)],
        &[(0b01001, &ENTRY_SUBSTANDARDIZES_12565775678053536739)],
        &[(0b10010, &ENTRY_SUBSTANTIALIZE_1127374552134288399)],
        &[(0b10010, &ENTRY_SUBSTANTIALIZED_9556338489115014542)],
        &[(0b10010, &ENTRY_SUBSTANTIALIZES_3032789098283567833)],
        &[(0b10010, &ENTRY_SUBSTANTIALIZING_3707317163949415405)],
        &[(0b01001, &ENTRY_SUBSTANTIALIZE_1127374552134288399)],
        &[(0b01001, &ENTRY_SUBSTANTIALIZED_9556338489115014542)],
        &[(0b01001, &ENTRY_SUBSTANTIALIZES_3032789098283567833)],
        &[(0b01001, &ENTRY_SUBSTANTIALIZING_3707317163949415405)],
        &[(0b10010, &ENTRY_SUBSTANTIVIZE_8369841284330486062)],
        &[(0b10010, &ENTRY_SUBSTANTIVIZED_9375791663725833847)],
        &[(0b10010, &ENTRY_SUBSTANTIVIZES_11922834391647562292)],
        &[(0b10010, &ENTRY_SUBSTANTIVIZING_16343156662998297538)],
        &[(0b01001, &ENTRY_SUBSTANTIVIZE_8369841284330486062)],
        &[(0b01001, &ENTRY_SUBSTANTIVIZED_9375791663725833847)],
        &[(0b01001, &ENTRY_SUBSTANTIVIZES_11922834391647562292)],
        &[(0b01001, &ENTRY_SUBSTANTIVIZING_16343156662998297538)],
        &[(0b10010, &ENTRY_SUBSTERILIZATION_3889547521413232121)],
        &[(0b01001, &ENTRY_SUBSTERILIZATION_3889547521413232121)],
    ],
    range: 5..=12,
};

static VARS_SUBP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBP_CHILDREN),
    value: None,
};

pub static VARS_SUBP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ulveriser"),
        dictgen::InsensitiveStr::Ascii("ulverisers"),
        dictgen::InsensitiveStr::Ascii("ulverizer"),
        dictgen::InsensitiveStr::Ascii("ulverizers"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBPULVERIZER_12169609575785620518)],
        &[(0b10010, &ENTRY_SUBPULVERIZERS_11573273933022945510)],
        &[(0b01001, &ENTRY_SUBPULVERIZER_12169609575785620518)],
        &[(0b01001, &ENTRY_SUBPULVERIZERS_11573273933022945510)],
    ],
    range: 9..=10,
};

static VARS_SUBO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBO_CHILDREN),
    value: None,
};

pub static VARS_SUBO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("esophageal")],
    values: &[&[(0b11010, &ENTRY_SUBESOPHAGEAL_6106301781363912390)]],
    range: 10..=10,
};

static VARS_SUBM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBM_CHILDREN),
    value: None,
};

pub static VARS_SUBM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iniaturisation"),
        dictgen::InsensitiveStr::Ascii("iniaturise"),
        dictgen::InsensitiveStr::Ascii("iniaturised"),
        dictgen::InsensitiveStr::Ascii("iniaturises"),
        dictgen::InsensitiveStr::Ascii("iniaturising"),
        dictgen::InsensitiveStr::Ascii("iniaturization"),
        dictgen::InsensitiveStr::Ascii("iniaturize"),
        dictgen::InsensitiveStr::Ascii("iniaturized"),
        dictgen::InsensitiveStr::Ascii("iniaturizes"),
        dictgen::InsensitiveStr::Ascii("iniaturizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBMINIATURIZATION_10556185094969044985)],
        &[(0b10010, &ENTRY_SUBMINIATURIZE_5999865733995238861)],
        &[(0b10010, &ENTRY_SUBMINIATURIZED_16328822871246757770)],
        &[(0b10010, &ENTRY_SUBMINIATURIZES_7040258188390121080)],
        &[(0b10010, &ENTRY_SUBMINIATURIZING_8376505957619603505)],
        &[(0b01001, &ENTRY_SUBMINIATURIZATION_10556185094969044985)],
        &[(0b01001, &ENTRY_SUBMINIATURIZE_5999865733995238861)],
        &[(0b01001, &ENTRY_SUBMINIATURIZED_16328822871246757770)],
        &[(0b01001, &ENTRY_SUBMINIATURIZES_7040258188390121080)],
        &[(0b01001, &ENTRY_SUBMINIATURIZING_8376505957619603505)],
    ],
    range: 10..=14,
};

static VARS_SUBL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBL_CHILDREN),
    value: None,
};

pub static VARS_SUBL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("imise"),
        dictgen::InsensitiveStr::Ascii("imised"),
        dictgen::InsensitiveStr::Ascii("imises"),
        dictgen::InsensitiveStr::Ascii("imising"),
        dictgen::InsensitiveStr::Ascii("imize"),
        dictgen::InsensitiveStr::Ascii("imized"),
        dictgen::InsensitiveStr::Ascii("imizes"),
        dictgen::InsensitiveStr::Ascii("imizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBLIMIZE_4455186032578780941)],
        &[(0b10010, &ENTRY_SUBLIMIZED_15642013700880675817)],
        &[(0b10010, &ENTRY_SUBLIMIZES_15236401821727981401)],
        &[(0b10010, &ENTRY_SUBLIMIZING_1361129763961634185)],
        &[(0b01001, &ENTRY_SUBLIMIZE_4455186032578780941)],
        &[(0b01001, &ENTRY_SUBLIMIZED_15642013700880675817)],
        &[(0b01001, &ENTRY_SUBLIMIZES_15236401821727981401)],
        &[(0b01001, &ENTRY_SUBLIMIZING_1361129763961634185)],
    ],
    range: 5..=7,
};

static VARS_SUBJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBJ_CHILDREN),
    value: None,
};

pub static VARS_SUBJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectivisation"),
        dictgen::InsensitiveStr::Ascii("ectivisations"),
        dictgen::InsensitiveStr::Ascii("ectivise"),
        dictgen::InsensitiveStr::Ascii("ectivised"),
        dictgen::InsensitiveStr::Ascii("ectivises"),
        dictgen::InsensitiveStr::Ascii("ectivising"),
        dictgen::InsensitiveStr::Ascii("ectivization"),
        dictgen::InsensitiveStr::Ascii("ectivizations"),
        dictgen::InsensitiveStr::Ascii("ectivize"),
        dictgen::InsensitiveStr::Ascii("ectivized"),
        dictgen::InsensitiveStr::Ascii("ectivizes"),
        dictgen::InsensitiveStr::Ascii("ectivizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBJECTIVIZATION_6885863457754335689)],
        &[(0b10010, &ENTRY_SUBJECTIVIZATIONS_2654941212096447523)],
        &[(0b10010, &ENTRY_SUBJECTIVIZE_9063057077838112531)],
        &[(0b10010, &ENTRY_SUBJECTIVIZED_2336514392929461039)],
        &[(0b10010, &ENTRY_SUBJECTIVIZES_15781894181825728740)],
        &[(0b10010, &ENTRY_SUBJECTIVIZING_10470471665341546903)],
        &[(0b01001, &ENTRY_SUBJECTIVIZATION_6885863457754335689)],
        &[(0b01001, &ENTRY_SUBJECTIVIZATIONS_2654941212096447523)],
        &[(0b01001, &ENTRY_SUBJECTIVIZE_9063057077838112531)],
        &[(0b01001, &ENTRY_SUBJECTIVIZED_2336514392929461039)],
        &[(0b01001, &ENTRY_SUBJECTIVIZES_15781894181825728740)],
        &[(0b01001, &ENTRY_SUBJECTIVIZING_10470471665341546903)],
    ],
    range: 8..=13,
};

static VARS_SUBI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBI_CHILDREN),
    value: None,
};

pub static VARS_SUBI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBITIZE_2500800531029112377)],
        &[(0b10010, &ENTRY_SUBITIZED_7501997579797246264)],
        &[(0b10010, &ENTRY_SUBITIZES_14667322345356948294)],
        &[(0b10010, &ENTRY_SUBITIZING_14779207785252328909)],
        &[(0b01001, &ENTRY_SUBITIZE_2500800531029112377)],
        &[(0b01001, &ENTRY_SUBITIZED_7501997579797246264)],
        &[(0b01001, &ENTRY_SUBITIZES_14667322345356948294)],
        &[(0b01001, &ENTRY_SUBITIZING_14779207785252328909)],
    ],
    range: 4..=6,
};

static VARS_SUBF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBF_CHILDREN),
    value: None,
};

pub static VARS_SUBF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lavor"),
        dictgen::InsensitiveStr::Ascii("lavors"),
        dictgen::InsensitiveStr::Ascii("lavour"),
        dictgen::InsensitiveStr::Ascii("lavours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SUBFLAVOR_8131995189965449489)],
        &[(0b00001, &ENTRY_SUBFLAVORS_4181079619994568530)],
        &[(0b11010, &ENTRY_SUBFLAVOR_8131995189965449489)],
        &[(0b11010, &ENTRY_SUBFLAVORS_4181079619994568530)],
    ],
    range: 5..=7,
};

static VARS_SUBE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBE_CHILDREN),
    value: None,
};

pub static VARS_SUBE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rate"),
        dictgen::InsensitiveStr::Ascii("risation"),
        dictgen::InsensitiveStr::Ascii("risations"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rization"),
        dictgen::InsensitiveStr::Ascii("rizations"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
        dictgen::InsensitiveStr::Ascii("sophageal"),
        dictgen::InsensitiveStr::Ascii("theric"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SUBERATE_13033646582163882584)],
        &[(0b10010, &ENTRY_SUBERIZATION_13270039726229410996)],
        &[(0b10010, &ENTRY_SUBERIZATIONS_11122919473658548263)],
        &[(0b10010, &ENTRY_SUBERIZE_9315879378118843248)],
        &[(0b10010, &ENTRY_SUBERIZED_5285782219644888811)],
        &[(0b10010, &ENTRY_SUBERIZES_13278889375914696842)],
        &[(0b10010, &ENTRY_SUBERIZING_18249078846570846131)],
        &[(0b01001, &ENTRY_SUBERIZATION_13270039726229410996)],
        &[(0b01001, &ENTRY_SUBERIZATIONS_11122919473658548263)],
        &[(0b01001, &ENTRY_SUBERIZE_9315879378118843248)],
        &[(0b01001, &ENTRY_SUBERIZED_5285782219644888811)],
        &[(0b01001, &ENTRY_SUBERIZES_13278889375914696842)],
        &[(0b01001, &ENTRY_SUBERIZING_18249078846570846131)],
        &[(0b00001, &ENTRY_SUBESOPHAGEAL_6106301781363912390)],
        &[(0b00001, &ENTRY_SUBETHERIC_3831523759918158602)],
    ],
    range: 4..=9,
};

static VARS_SUBD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBD_CHILDREN),
    value: None,
};

pub static VARS_SUBD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uer"),
        dictgen::InsensitiveStr::Ascii("ure"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SUBDUER_1073236083878073402)],
        &[(0b11010, &ENTRY_SUBDUER_1073236083878073402)],
    ],
    range: 3..=3,
};

static VARS_SUBC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBC_CHILDREN),
    value: None,
};

pub static VARS_SUBC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aliber"),
        dictgen::InsensitiveStr::Ascii("alibre"),
        dictgen::InsensitiveStr::Ascii("ategorising"),
        dictgen::InsensitiveStr::Ascii("ategorizing"),
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("entre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SUBCALIBER_10763578646516555123)],
        &[(0b11010, &ENTRY_SUBCALIBER_10763578646516555123)],
        &[(0b10010, &ENTRY_SUBCATEGORIZING_559546594663443201)],
        &[(0b01001, &ENTRY_SUBCATEGORIZING_559546594663443201)],
        &[(0b00001, &ENTRY_SUBCENTER_16599153427473361658)],
        &[(0b11010, &ENTRY_SUBCENTER_16599153427473361658)],
    ],
    range: 5..=11,
};

static VARS_SUBA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBA_CHILDREN),
    value: None,
};

pub static VARS_SUBA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erate"),
        dictgen::InsensitiveStr::Ascii("etheric"),
        dictgen::InsensitiveStr::Ascii("rmor"),
        dictgen::InsensitiveStr::Ascii("rmors"),
        dictgen::InsensitiveStr::Ascii("rmour"),
        dictgen::InsensitiveStr::Ascii("rmours"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SUBERATE_13033646582163882584)],
        &[(0b11010, &ENTRY_SUBETHERIC_3831523759918158602)],
        &[(0b00001, &ENTRY_SUBARMOR_14689004097074153351)],
        &[(0b00001, &ENTRY_SUBARMORS_17961946408548270853)],
        &[(0b11010, &ENTRY_SUBARMOR_14689004097074153351)],
        &[(0b11010, &ENTRY_SUBARMORS_17961946408548270853)],
    ],
    range: 4..=7,
};

static VARS_ST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ST_CHILDREN),
    value: None,
};

static VARS_ST_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_STA_NODE),
    None,
    None,
    None,
    Some(&VARS_STE_NODE),
    None,
    None,
    None,
    Some(&VARS_STI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_STO_NODE),
    None,
    None,
    Some(&VARS_STR_NODE),
    None,
    None,
    Some(&VARS_STU_NODE),
    None,
    None,
    None,
    Some(&VARS_STY_NODE),
    None,
];

static VARS_STY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STY_CHILDREN),
    value: None,
};

pub static VARS_STY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("liser"),
        dictgen::InsensitiveStr::Ascii("lisers"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizer"),
        dictgen::InsensitiveStr::Ascii("lizers"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
        dictgen::InsensitiveStr::Ascii("lopised"),
        dictgen::InsensitiveStr::Ascii("lopized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_STYLIZATION_6235644091145662258)],
        &[(0b10010, &ENTRY_STYLIZATIONS_2138820429543216253)],
        &[(0b10010, &ENTRY_STYLIZE_13371282579615467796)],
        &[(0b10010, &ENTRY_STYLIZED_4847869505285666329)],
        &[(0b10010, &ENTRY_STYLIZER_13982978292394626940)],
        &[(0b10010, &ENTRY_STYLIZERS_15139738520592840604)],
        &[(0b10010, &ENTRY_STYLIZES_2600387667375095470)],
        &[(0b10010, &ENTRY_STYLIZING_10937898920006317214)],
        &[(0b01001, &ENTRY_STYLIZATION_6235644091145662258)],
        &[(0b01001, &ENTRY_STYLIZATIONS_2138820429543216253)],
        &[(0b01001, &ENTRY_STYLIZE_13371282579615467796)],
        &[(0b01001, &ENTRY_STYLIZED_4847869505285666329)],
        &[(0b01001, &ENTRY_STYLIZER_13982978292394626940)],
        &[(0b01001, &ENTRY_STYLIZERS_15139738520592840604)],
        &[(0b01001, &ENTRY_STYLIZES_2600387667375095470)],
        &[(0b01001, &ENTRY_STYLIZING_10937898920006317214)],
        &[(0b10010, &ENTRY_STYLOPIZED_2650877490960920576)],
        &[(0b01001, &ENTRY_STYLOPIZED_2650877490960920576)],
    ],
    range: 4..=9,
};

static VARS_STU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STU_CHILDREN),
    value: None,
};

pub static VARS_STU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mor"),
        dictgen::InsensitiveStr::Ascii("mour"),
    ],
    values: &[
        &[(0b00001, &ENTRY_STUMOR_17411403876305618946)],
        &[(0b11010, &ENTRY_STUMOR_17411403876305618946)],
    ],
    range: 3..=4,
};

static VARS_STR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STR_CHILDREN),
    value: None,
};

pub static VARS_STR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ee"),
        dictgen::InsensitiveStr::Ascii("et"),
        dictgen::InsensitiveStr::Ascii("obilae"),
        dictgen::InsensitiveStr::Ascii("obile"),
        dictgen::InsensitiveStr::Ascii("obilisation"),
        dictgen::InsensitiveStr::Ascii("obilisations"),
        dictgen::InsensitiveStr::Ascii("obilization"),
        dictgen::InsensitiveStr::Ascii("obilizations"),
        dictgen::InsensitiveStr::Ascii("ucturalisation"),
        dictgen::InsensitiveStr::Ascii("ucturalisations"),
        dictgen::InsensitiveStr::Ascii("ucturalise"),
        dictgen::InsensitiveStr::Ascii("ucturalises"),
        dictgen::InsensitiveStr::Ascii("ucturalization"),
        dictgen::InsensitiveStr::Ascii("ucturalizations"),
        dictgen::InsensitiveStr::Ascii("ucturalize"),
        dictgen::InsensitiveStr::Ascii("ucturalizes"),
        dictgen::InsensitiveStr::Ascii("ychninisation"),
        dictgen::InsensitiveStr::Ascii("ychninisations"),
        dictgen::InsensitiveStr::Ascii("ychninise"),
        dictgen::InsensitiveStr::Ascii("ychninises"),
        dictgen::InsensitiveStr::Ascii("ychninization"),
        dictgen::InsensitiveStr::Ascii("ychninizations"),
        dictgen::InsensitiveStr::Ascii("ychninize"),
        dictgen::InsensitiveStr::Ascii("ychninizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_STERE_13708659892245045900)],
        &[(0b11010, &ENTRY_STERT_2568239910800832856)],
        &[(0b11010, &ENTRY_STROBILE_2455104557109757172)],
        &[(0b00001, &ENTRY_STROBILE_2455104557109757172)],
        &[(0b10010, &ENTRY_STROBILIZATION_16555130605778279996)],
        &[(0b10010, &ENTRY_STROBILIZATIONS_18024846533503451402)],
        &[(0b01001, &ENTRY_STROBILIZATION_16555130605778279996)],
        &[(0b01001, &ENTRY_STROBILIZATIONS_18024846533503451402)],
        &[(0b10010, &ENTRY_STRUCTURALIZATION_1517772601489028195)],
        &[(0b10010, &ENTRY_STRUCTURALIZATIONS_2871497142594857048)],
        &[(0b10010, &ENTRY_STRUCTURALIZE_14863509506371740395)],
        &[(0b10010, &ENTRY_STRUCTURALIZES_2020936801127552663)],
        &[(0b01001, &ENTRY_STRUCTURALIZATION_1517772601489028195)],
        &[(0b01001, &ENTRY_STRUCTURALIZATIONS_2871497142594857048)],
        &[(0b01001, &ENTRY_STRUCTURALIZE_14863509506371740395)],
        &[(0b01001, &ENTRY_STRUCTURALIZES_2020936801127552663)],
        &[(0b10010, &ENTRY_STRYCHNINIZATION_4279485397335566578)],
        &[(0b10010, &ENTRY_STRYCHNINIZATIONS_13851139297011899199)],
        &[(0b10010, &ENTRY_STRYCHNINIZE_9141667085528007172)],
        &[(0b10010, &ENTRY_STRYCHNINIZES_18398688944091938655)],
        &[(0b01001, &ENTRY_STRYCHNINIZATION_4279485397335566578)],
        &[(0b01001, &ENTRY_STRYCHNINIZATIONS_13851139297011899199)],
        &[(0b01001, &ENTRY_STRYCHNINIZE_9141667085528007172)],
        &[(0b01001, &ENTRY_STRYCHNINIZES_18398688944091938655)],
    ],
    range: 2..=15,
};

static VARS_STO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STO_CHILDREN),
    value: None,
};

pub static VARS_STO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matodaeum"),
        dictgen::InsensitiveStr::Ascii("matodeum"),
        dictgen::InsensitiveStr::Ascii("modaea"),
        dictgen::InsensitiveStr::Ascii("modaeal"),
        dictgen::InsensitiveStr::Ascii("modaeum"),
        dictgen::InsensitiveStr::Ascii("modaeums"),
        dictgen::InsensitiveStr::Ascii("modea"),
        dictgen::InsensitiveStr::Ascii("modeal"),
        dictgen::InsensitiveStr::Ascii("modeum"),
        dictgen::InsensitiveStr::Ascii("modeums"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rier"),
        dictgen::InsensitiveStr::Ascii("ur"),
        dictgen::InsensitiveStr::Ascii("urier"),
        dictgen::InsensitiveStr::Ascii("wer"),
        dictgen::InsensitiveStr::Ascii("wers"),
        dictgen::InsensitiveStr::Ascii("wre"),
        dictgen::InsensitiveStr::Ascii("wres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_STOMATODEUM_6433297792284142688)],
        &[(0b00001, &ENTRY_STOMATODEUM_6433297792284142688)],
        &[(0b11010, &ENTRY_STOMODEA_15996517343876980077)],
        &[(0b11010, &ENTRY_STOMODEAL_3023016665616811727)],
        &[(0b11010, &ENTRY_STOMODEUM_7621915820620375624)],
        &[(0b11010, &ENTRY_STOMODEUMS_12837659428832608446)],
        &[(0b00001, &ENTRY_STOMODEA_15996517343876980077)],
        &[(0b00001, &ENTRY_STOMODEAL_3023016665616811727)],
        &[(0b00001, &ENTRY_STOMODEUM_7621915820620375624)],
        &[(0b00001, &ENTRY_STOMODEUMS_12837659428832608446)],
        &[(0b11010, &ENTRY_STOR_3765799085742567098)],
        &[(0b00001, &ENTRY_STOR_3765799085742567098)],
        &[(0b00001, &ENTRY_STORIER_1555627284462772417)],
        &[(0b11010, &ENTRY_STOR_3765799085742567098)],
        &[(0b11010, &ENTRY_STORIER_1555627284462772417)],
        &[(0b00001, &ENTRY_STOWER_9642465002851641994)],
        &[(0b00001, &ENTRY_STOWERS_113381365985354937)],
        &[(0b11010, &ENTRY_STOWER_9642465002851641994)],
        &[(0b11010, &ENTRY_STOWERS_113381365985354937)],
    ],
    range: 1..=9,
};

static VARS_STI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STI_CHILDREN),
    value: None,
};

pub static VARS_STI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gmatisation"),
        dictgen::InsensitiveStr::Ascii("gmatisations"),
        dictgen::InsensitiveStr::Ascii("gmatise"),
        dictgen::InsensitiveStr::Ascii("gmatised"),
        dictgen::InsensitiveStr::Ascii("gmatiser"),
        dictgen::InsensitiveStr::Ascii("gmatisers"),
        dictgen::InsensitiveStr::Ascii("gmatises"),
        dictgen::InsensitiveStr::Ascii("gmatising"),
        dictgen::InsensitiveStr::Ascii("gmatization"),
        dictgen::InsensitiveStr::Ascii("gmatizations"),
        dictgen::InsensitiveStr::Ascii("gmatize"),
        dictgen::InsensitiveStr::Ascii("gmatized"),
        dictgen::InsensitiveStr::Ascii("gmatizer"),
        dictgen::InsensitiveStr::Ascii("gmatizers"),
        dictgen::InsensitiveStr::Ascii("gmatizes"),
        dictgen::InsensitiveStr::Ascii("gmatizing"),
        dictgen::InsensitiveStr::Ascii("lbestrol"),
        dictgen::InsensitiveStr::Ascii("lbestrols"),
        dictgen::InsensitiveStr::Ascii("lboestrol"),
        dictgen::InsensitiveStr::Ascii("lboestrols"),
        dictgen::InsensitiveStr::Ascii("pulae"),
        dictgen::InsensitiveStr::Ascii("pule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_STIGMATIZATION_15367665650808291201)],
        &[(0b10010, &ENTRY_STIGMATIZATIONS_4419626284437647049)],
        &[(0b10010, &ENTRY_STIGMATIZE_5799619399576330013)],
        &[(0b10010, &ENTRY_STIGMATIZED_2708765122033987200)],
        &[(0b10010, &ENTRY_STIGMATIZER_12628918335125666337)],
        &[(0b10010, &ENTRY_STIGMATIZERS_3465759938789898503)],
        &[(0b10010, &ENTRY_STIGMATIZES_14729433263129115837)],
        &[(0b10010, &ENTRY_STIGMATIZING_1440308166481676994)],
        &[(0b01001, &ENTRY_STIGMATIZATION_15367665650808291201)],
        &[(0b01001, &ENTRY_STIGMATIZATIONS_4419626284437647049)],
        &[(0b01001, &ENTRY_STIGMATIZE_5799619399576330013)],
        &[(0b01001, &ENTRY_STIGMATIZED_2708765122033987200)],
        &[(0b01001, &ENTRY_STIGMATIZER_12628918335125666337)],
        &[(0b01001, &ENTRY_STIGMATIZERS_3465759938789898503)],
        &[(0b01001, &ENTRY_STIGMATIZES_14729433263129115837)],
        &[(0b01001, &ENTRY_STIGMATIZING_1440308166481676994)],
        &[(0b00001, &ENTRY_STILBESTROL_16450491116589325148)],
        &[(0b00001, &ENTRY_STILBESTROLS_4304462747026806842)],
        &[(0b11010, &ENTRY_STILBESTROL_16450491116589325148)],
        &[(0b11010, &ENTRY_STILBESTROLS_4304462747026806842)],
        &[(0b11010, &ENTRY_STIPULE_18061101307220428275)],
        &[(0b00001, &ENTRY_STIPULE_18061101307220428275)],
    ],
    range: 4..=12,
};

static VARS_STE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STE_CHILDREN),
    value: None,
};

pub static VARS_STE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arrhea"),
        dictgen::InsensitiveStr::Ascii("arrhoea"),
        dictgen::InsensitiveStr::Ascii("atorrhea"),
        dictgen::InsensitiveStr::Ascii("atorrheas"),
        dictgen::InsensitiveStr::Ascii("atorrhoea"),
        dictgen::InsensitiveStr::Ascii("atorrhoeas"),
        dictgen::InsensitiveStr::Ascii("lae"),
        dictgen::InsensitiveStr::Ascii("le"),
        dictgen::InsensitiveStr::Ascii("nciled"),
        dictgen::InsensitiveStr::Ascii("nciler"),
        dictgen::InsensitiveStr::Ascii("ncilers"),
        dictgen::InsensitiveStr::Ascii("nciling"),
        dictgen::InsensitiveStr::Ascii("ncilise"),
        dictgen::InsensitiveStr::Ascii("ncilize"),
        dictgen::InsensitiveStr::Ascii("ncilled"),
        dictgen::InsensitiveStr::Ascii("nciller"),
        dictgen::InsensitiveStr::Ascii("ncillers"),
        dictgen::InsensitiveStr::Ascii("ncilling"),
        dictgen::InsensitiveStr::Ascii("nopaeic"),
        dictgen::InsensitiveStr::Ascii("nopeic"),
        dictgen::InsensitiveStr::Ascii("ntor"),
        dictgen::InsensitiveStr::Ascii("ntors"),
        dictgen::InsensitiveStr::Ascii("ntour"),
        dictgen::InsensitiveStr::Ascii("ntours"),
        dictgen::InsensitiveStr::Ascii("rcoraemia"),
        dictgen::InsensitiveStr::Ascii("rcoremia"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("rilisabilities"),
        dictgen::InsensitiveStr::Ascii("rilisability"),
        dictgen::InsensitiveStr::Ascii("rilisable"),
        dictgen::InsensitiveStr::Ascii("rilisabler"),
        dictgen::InsensitiveStr::Ascii("rilisables"),
        dictgen::InsensitiveStr::Ascii("rilisablest"),
        dictgen::InsensitiveStr::Ascii("rilisation"),
        dictgen::InsensitiveStr::Ascii("rilisations"),
        dictgen::InsensitiveStr::Ascii("rilise"),
        dictgen::InsensitiveStr::Ascii("rilised"),
        dictgen::InsensitiveStr::Ascii("riliser"),
        dictgen::InsensitiveStr::Ascii("rilisers"),
        dictgen::InsensitiveStr::Ascii("rilises"),
        dictgen::InsensitiveStr::Ascii("rilising"),
        dictgen::InsensitiveStr::Ascii("rilizabilities"),
        dictgen::InsensitiveStr::Ascii("rilizability"),
        dictgen::InsensitiveStr::Ascii("rilizable"),
        dictgen::InsensitiveStr::Ascii("rilizabler"),
        dictgen::InsensitiveStr::Ascii("rilizables"),
        dictgen::InsensitiveStr::Ascii("rilizablest"),
        dictgen::InsensitiveStr::Ascii("rilization"),
        dictgen::InsensitiveStr::Ascii("rilizations"),
        dictgen::InsensitiveStr::Ascii("rilize"),
        dictgen::InsensitiveStr::Ascii("rilized"),
        dictgen::InsensitiveStr::Ascii("rilizer"),
        dictgen::InsensitiveStr::Ascii("rilizers"),
        dictgen::InsensitiveStr::Ascii("rilizes"),
        dictgen::InsensitiveStr::Ascii("rilizing"),
        dictgen::InsensitiveStr::Ascii("rt"),
    ],
    values: &[
        &[(0b00001, &ENTRY_STEARRHEA_11431771010957771750)],
        &[(0b11010, &ENTRY_STEARRHEA_11431771010957771750)],
        &[(0b00001, &ENTRY_STEATORRHEA_16005206938373142642)],
        &[(0b00001, &ENTRY_STEATORRHEAS_8820213659684170958)],
        &[(0b11010, &ENTRY_STEATORRHEA_16005206938373142642)],
        &[(0b11010, &ENTRY_STEATORRHEAS_8820213659684170958)],
        &[(0b11010, &ENTRY_STELE_8010967670342221719)],
        &[(0b00001, &ENTRY_STELE_8010967670342221719)],
        &[(0b00001, &ENTRY_STENCILED_18358466251443584244)],
        &[(0b00001, &ENTRY_STENCILER_12441732772591791835)],
        &[(0b00001, &ENTRY_STENCILERS_1017708152015244225)],
        &[(0b00001, &ENTRY_STENCILING_16009278311382010932)],
        &[(0b10010, &ENTRY_STENCILIZE_1883877954556953319)],
        &[(0b01001, &ENTRY_STENCILIZE_1883877954556953319)],
        &[(0b11010, &ENTRY_STENCILED_18358466251443584244)],
        &[(0b11010, &ENTRY_STENCILER_12441732772591791835)],
        &[(0b11010, &ENTRY_STENCILERS_1017708152015244225)],
        &[(0b11010, &ENTRY_STENCILING_16009278311382010932)],
        &[(0b11010, &ENTRY_STENOPEIC_2539738485702057539)],
        &[(0b00001, &ENTRY_STENOPEIC_2539738485702057539)],
        &[(0b00001, &ENTRY_STENTOR_10286318464720816144)],
        &[(0b00001, &ENTRY_STENTORS_9771830217471162933)],
        &[(0b11010, &ENTRY_STENTOR_10286318464720816144)],
        &[(0b11010, &ENTRY_STENTORS_9771830217471162933)],
        &[(0b11010, &ENTRY_STERCOREMIA_10730723271527231669)],
        &[(0b00001, &ENTRY_STERCOREMIA_10730723271527231669)],
        &[(0b00001, &ENTRY_STERE_13708659892245045900)],
        &[(0b10010, &ENTRY_STERILIZABILITIES_16689990744951863819)],
        &[(0b10010, &ENTRY_STERILIZABILITY_11176247869362156533)],
        &[(0b10010, &ENTRY_STERILIZABLE_12001563571902655950)],
        &[(0b10010, &ENTRY_STERILIZABLER_2981777391612929274)],
        &[(0b10010, &ENTRY_STERILIZABLES_9392344777525592572)],
        &[(0b10010, &ENTRY_STERILIZABLEST_12402421338830249014)],
        &[(0b10010, &ENTRY_STERILIZATION_8065625074540222478)],
        &[(0b10010, &ENTRY_STERILIZATIONS_6145032887986296344)],
        &[(0b10010, &ENTRY_STERILIZE_1847097589172243146)],
        &[(0b10010, &ENTRY_STERILIZED_17543306694251609885)],
        &[(0b10010, &ENTRY_STERILIZER_14841880991277730478)],
        &[(0b10010, &ENTRY_STERILIZERS_3377446126211900294)],
        &[(0b10010, &ENTRY_STERILIZES_4362381845943247126)],
        &[(0b10010, &ENTRY_STERILIZING_8492025091236842001)],
        &[(0b01001, &ENTRY_STERILIZABILITIES_16689990744951863819)],
        &[(0b01001, &ENTRY_STERILIZABILITY_11176247869362156533)],
        &[(0b01001, &ENTRY_STERILIZABLE_12001563571902655950)],
        &[(0b01001, &ENTRY_STERILIZABLER_2981777391612929274)],
        &[(0b01001, &ENTRY_STERILIZABLES_9392344777525592572)],
        &[(0b01001, &ENTRY_STERILIZABLEST_12402421338830249014)],
        &[(0b01001, &ENTRY_STERILIZATION_8065625074540222478)],
        &[(0b01001, &ENTRY_STERILIZATIONS_6145032887986296344)],
        &[(0b01001, &ENTRY_STERILIZE_1847097589172243146)],
        &[(0b01001, &ENTRY_STERILIZED_17543306694251609885)],
        &[(0b01001, &ENTRY_STERILIZER_14841880991277730478)],
        &[(0b01001, &ENTRY_STERILIZERS_3377446126211900294)],
        &[(0b01001, &ENTRY_STERILIZES_4362381845943247126)],
        &[(0b01001, &ENTRY_STERILIZING_8492025091236842001)],
        &[(0b00001, &ENTRY_STERT_2568239910800832856)],
    ],
    range: 2..=14,
};

static VARS_STA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STA_CHILDREN),
    value: None,
};

pub static VARS_STA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilisable"),
        dictgen::InsensitiveStr::Ascii("bilisation"),
        dictgen::InsensitiveStr::Ascii("bilisations"),
        dictgen::InsensitiveStr::Ascii("bilisator"),
        dictgen::InsensitiveStr::Ascii("bilisators"),
        dictgen::InsensitiveStr::Ascii("bilise"),
        dictgen::InsensitiveStr::Ascii("bilised"),
        dictgen::InsensitiveStr::Ascii("biliser"),
        dictgen::InsensitiveStr::Ascii("bilisers"),
        dictgen::InsensitiveStr::Ascii("bilises"),
        dictgen::InsensitiveStr::Ascii("bilising"),
        dictgen::InsensitiveStr::Ascii("bilizable"),
        dictgen::InsensitiveStr::Ascii("bilization"),
        dictgen::InsensitiveStr::Ascii("bilizations"),
        dictgen::InsensitiveStr::Ascii("bilizator"),
        dictgen::InsensitiveStr::Ascii("bilizators"),
        dictgen::InsensitiveStr::Ascii("bilize"),
        dictgen::InsensitiveStr::Ascii("bilized"),
        dictgen::InsensitiveStr::Ascii("bilizer"),
        dictgen::InsensitiveStr::Ascii("bilizers"),
        dictgen::InsensitiveStr::Ascii("bilizes"),
        dictgen::InsensitiveStr::Ascii("bilizing"),
        dictgen::InsensitiveStr::Ascii("llionise"),
        dictgen::InsensitiveStr::Ascii("llionises"),
        dictgen::InsensitiveStr::Ascii("llionize"),
        dictgen::InsensitiveStr::Ascii("llionizes"),
        dictgen::InsensitiveStr::Ascii("lwartise"),
        dictgen::InsensitiveStr::Ascii("lwartises"),
        dictgen::InsensitiveStr::Ascii("lwartize"),
        dictgen::InsensitiveStr::Ascii("lwartizes"),
        dictgen::InsensitiveStr::Ascii("mmelcolor"),
        dictgen::InsensitiveStr::Ascii("mmelcolour"),
        dictgen::InsensitiveStr::Ascii("ndardisable"),
        dictgen::InsensitiveStr::Ascii("ndardisables"),
        dictgen::InsensitiveStr::Ascii("ndardisation"),
        dictgen::InsensitiveStr::Ascii("ndardisations"),
        dictgen::InsensitiveStr::Ascii("ndardise"),
        dictgen::InsensitiveStr::Ascii("ndardised"),
        dictgen::InsensitiveStr::Ascii("ndardiser"),
        dictgen::InsensitiveStr::Ascii("ndardisers"),
        dictgen::InsensitiveStr::Ascii("ndardises"),
        dictgen::InsensitiveStr::Ascii("ndardising"),
        dictgen::InsensitiveStr::Ascii("ndardizable"),
        dictgen::InsensitiveStr::Ascii("ndardizables"),
        dictgen::InsensitiveStr::Ascii("ndardization"),
        dictgen::InsensitiveStr::Ascii("ndardizations"),
        dictgen::InsensitiveStr::Ascii("ndardize"),
        dictgen::InsensitiveStr::Ascii("ndardized"),
        dictgen::InsensitiveStr::Ascii("ndardizer"),
        dictgen::InsensitiveStr::Ascii("ndardizers"),
        dictgen::InsensitiveStr::Ascii("ndardizes"),
        dictgen::InsensitiveStr::Ascii("ndardizing"),
        dictgen::InsensitiveStr::Ascii("nzes"),
        dictgen::InsensitiveStr::Ascii("nzoes"),
        dictgen::InsensitiveStr::Ascii("pedectomised"),
        dictgen::InsensitiveStr::Ascii("pedectomized"),
        dictgen::InsensitiveStr::Ascii("phyledema"),
        dictgen::InsensitiveStr::Ascii("phyloedema"),
        dictgen::InsensitiveStr::Ascii("tisticise"),
        dictgen::InsensitiveStr::Ascii("tisticises"),
        dictgen::InsensitiveStr::Ascii("tisticize"),
        dictgen::InsensitiveStr::Ascii("tisticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_STABILIZABLE_4932218987124928483)],
        &[(0b10010, &ENTRY_STABILIZATION_8501631360615854418)],
        &[(0b10010, &ENTRY_STABILIZATIONS_11866129248341293272)],
        &[(0b10010, &ENTRY_STABILIZATOR_18070208100981423639)],
        &[(0b10010, &ENTRY_STABILIZATORS_14857459698219243705)],
        &[(0b10010, &ENTRY_STABILIZE_11592021559489637588)],
        &[(0b10010, &ENTRY_STABILIZED_11637850169426450316)],
        &[(0b10010, &ENTRY_STABILIZER_10839686795364476539)],
        &[(0b10010, &ENTRY_STABILIZERS_6342146151996925299)],
        &[(0b10010, &ENTRY_STABILIZES_14273493638532544927)],
        &[(0b10010, &ENTRY_STABILIZING_12133357303799134695)],
        &[(0b01001, &ENTRY_STABILIZABLE_4932218987124928483)],
        &[(0b01001, &ENTRY_STABILIZATION_8501631360615854418)],
        &[(0b01001, &ENTRY_STABILIZATIONS_11866129248341293272)],
        &[(0b01001, &ENTRY_STABILIZATOR_18070208100981423639)],
        &[(0b01001, &ENTRY_STABILIZATORS_14857459698219243705)],
        &[(0b01001, &ENTRY_STABILIZE_11592021559489637588)],
        &[(0b01001, &ENTRY_STABILIZED_11637850169426450316)],
        &[(0b01001, &ENTRY_STABILIZER_10839686795364476539)],
        &[(0b01001, &ENTRY_STABILIZERS_6342146151996925299)],
        &[(0b01001, &ENTRY_STABILIZES_14273493638532544927)],
        &[(0b01001, &ENTRY_STABILIZING_12133357303799134695)],
        &[(0b10010, &ENTRY_STALLIONIZE_12958078712384484715)],
        &[(0b10010, &ENTRY_STALLIONIZES_6605755236481804236)],
        &[(0b01001, &ENTRY_STALLIONIZE_12958078712384484715)],
        &[(0b01001, &ENTRY_STALLIONIZES_6605755236481804236)],
        &[(0b10010, &ENTRY_STALWARTIZE_12610260529647003762)],
        &[(0b10010, &ENTRY_STALWARTIZES_11962685134317049994)],
        &[(0b01001, &ENTRY_STALWARTIZE_12610260529647003762)],
        &[(0b01001, &ENTRY_STALWARTIZES_11962685134317049994)],
        &[(0b00001, &ENTRY_STAMMELCOLOR_10970254609910766177)],
        &[(0b11010, &ENTRY_STAMMELCOLOR_10970254609910766177)],
        &[(0b10010, &ENTRY_STANDARDIZABLE_2567320277491222618)],
        &[(0b10010, &ENTRY_STANDARDIZABLES_826096383236335749)],
        &[(0b10010, &ENTRY_STANDARDIZATION_15383021445373007707)],
        &[(0b10010, &ENTRY_STANDARDIZATIONS_332063199494197132)],
        &[(0b10010, &ENTRY_STANDARDIZE_16594334550448089105)],
        &[(0b10010, &ENTRY_STANDARDIZED_7943764922032376919)],
        &[(0b10010, &ENTRY_STANDARDIZER_6962886130708807895)],
        &[(0b10010, &ENTRY_STANDARDIZERS_10454017961970777389)],
        &[(0b10010, &ENTRY_STANDARDIZES_7893289976137443900)],
        &[(0b10010, &ENTRY_STANDARDIZING_8802579594080422420)],
        &[(0b01001, &ENTRY_STANDARDIZABLE_2567320277491222618)],
        &[(0b01001, &ENTRY_STANDARDIZABLES_826096383236335749)],
        &[(0b01001, &ENTRY_STANDARDIZATION_15383021445373007707)],
        &[(0b01001, &ENTRY_STANDARDIZATIONS_332063199494197132)],
        &[(0b01001, &ENTRY_STANDARDIZE_16594334550448089105)],
        &[(0b01001, &ENTRY_STANDARDIZED_7943764922032376919)],
        &[(0b01001, &ENTRY_STANDARDIZER_6962886130708807895)],
        &[(0b01001, &ENTRY_STANDARDIZERS_10454017961970777389)],
        &[(0b01001, &ENTRY_STANDARDIZES_7893289976137443900)],
        &[(0b01001, &ENTRY_STANDARDIZING_8802579594080422420)],
        &[(0b00001, &ENTRY_STANZES_12485556301551814937)],
        &[(0b11010, &ENTRY_STANZES_12485556301551814937)],
        &[(0b10010, &ENTRY_STAPEDECTOMIZED_9197906406180557938)],
        &[(0b01001, &ENTRY_STAPEDECTOMIZED_9197906406180557938)],
        &[(0b00001, &ENTRY_STAPHYLEDEMA_8250830785224943987)],
        &[(0b11010, &ENTRY_STAPHYLEDEMA_8250830785224943987)],
        &[(0b10010, &ENTRY_STATISTICIZE_11912040955141081885)],
        &[(0b10010, &ENTRY_STATISTICIZES_13089056342446105826)],
        &[(0b01001, &ENTRY_STATISTICIZE_11912040955141081885)],
        &[(0b01001, &ENTRY_STATISTICIZES_13089056342446105826)],
    ],
    range: 4..=13,
};

static VARS_SQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SQ_CHILDREN),
    value: None,
};

pub static VARS_SQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uamae"),
        dictgen::InsensitiveStr::Ascii("uame"),
        dictgen::InsensitiveStr::Ascii("uamulae"),
        dictgen::InsensitiveStr::Ascii("uamule"),
        dictgen::InsensitiveStr::Ascii("uier"),
        dictgen::InsensitiveStr::Ascii("uire"),
        dictgen::InsensitiveStr::Ascii("uirreled"),
        dictgen::InsensitiveStr::Ascii("uirreling"),
        dictgen::InsensitiveStr::Ascii("uirrelled"),
        dictgen::InsensitiveStr::Ascii("uirrelling"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SQUAME_3213388851075891116)],
        &[(0b00001, &ENTRY_SQUAME_3213388851075891116)],
        &[(0b11010, &ENTRY_SQUAMULE_6064011923198120224)],
        &[(0b00001, &ENTRY_SQUAMULE_6064011923198120224)],
        &[(0b00001, &ENTRY_SQUIER_15203146461303476056)],
        &[(0b11010, &ENTRY_SQUIER_15203146461303476056)],
        &[(0b01001, &ENTRY_SQUIRRELED_18389953608476203741)],
        &[(0b01001, &ENTRY_SQUIRRELING_2889119631030338646)],
        &[(0b11010, &ENTRY_SQUIRRELED_18389953608476203741)],
        &[(0b11010, &ENTRY_SQUIRRELING_2889119631030338646)],
    ],
    range: 4..=10,
};

static VARS_SP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SP_CHILDREN),
    value: None,
};

static VARS_SP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SPA_NODE),
    None,
    None,
    None,
    Some(&VARS_SPE_NODE),
    None,
    None,
    Some(&VARS_SPH_NODE),
    Some(&VARS_SPI_NODE),
    None,
    None,
    Some(&VARS_SPL_NODE),
    None,
    None,
    Some(&VARS_SPO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SPY_NODE),
    None,
];

static VARS_SPY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPY_CHILDREN),
    value: None,
};

pub static VARS_SPY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SPYER_12225595747130603215)],
        &[(0b11010, &ENTRY_SPYER_12225595747130603215)],
    ],
    range: 2..=2,
};

static VARS_SPO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPO_CHILDREN),
    value: None,
};

pub static VARS_SPO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ilt")],
    values: &[&[(0b11010, &ENTRY_SPOILED_924892233379569654)]],
    range: 3..=3,
};

static VARS_SPL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPL_CHILDREN),
    value: None,
};

pub static VARS_SPL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anchnocele"),
        dictgen::InsensitiveStr::Ascii("anchnocoele"),
        dictgen::InsensitiveStr::Ascii("endor"),
        dictgen::InsensitiveStr::Ascii("endorproof"),
        dictgen::InsensitiveStr::Ascii("endors"),
        dictgen::InsensitiveStr::Ascii("endour"),
        dictgen::InsensitiveStr::Ascii("endourproof"),
        dictgen::InsensitiveStr::Ascii("endours"),
        dictgen::InsensitiveStr::Ascii("enectomised"),
        dictgen::InsensitiveStr::Ascii("enectomized"),
        dictgen::InsensitiveStr::Ascii("enisation"),
        dictgen::InsensitiveStr::Ascii("enisations"),
        dictgen::InsensitiveStr::Ascii("enization"),
        dictgen::InsensitiveStr::Ascii("enizations"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SPLANCHNOCELE_13922332607993579794)],
        &[(0b11010, &ENTRY_SPLANCHNOCELE_13922332607993579794)],
        &[(0b11001, &ENTRY_SPLENDOR_8664416655036864719)],
        &[(0b00001, &ENTRY_SPLENDORPROOF_5461754752834589608)],
        &[(0b11001, &ENTRY_SPLENDORS_5940678279727313679)],
        &[(0b11010, &ENTRY_SPLENDOR_8664416655036864719)],
        &[(0b11010, &ENTRY_SPLENDORPROOF_5461754752834589608)],
        &[(0b11010, &ENTRY_SPLENDORS_5940678279727313679)],
        &[(0b10010, &ENTRY_SPLENECTOMIZED_614544978128859415)],
        &[(0b01001, &ENTRY_SPLENECTOMIZED_614544978128859415)],
        &[(0b10010, &ENTRY_SPLENIZATION_18282593558114333381)],
        &[(0b10010, &ENTRY_SPLENIZATIONS_4900696190905604499)],
        &[(0b01001, &ENTRY_SPLENIZATION_18282593558114333381)],
        &[(0b01001, &ENTRY_SPLENIZATIONS_4900696190905604499)],
    ],
    range: 5..=11,
};

static VARS_SPI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPI_CHILDREN),
    value: None,
};

pub static VARS_SPI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("nulae"),
        dictgen::InsensitiveStr::Ascii("nule"),
        dictgen::InsensitiveStr::Ascii("raled"),
        dictgen::InsensitiveStr::Ascii("raling"),
        dictgen::InsensitiveStr::Ascii("ralisation"),
        dictgen::InsensitiveStr::Ascii("ralisations"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralization"),
        dictgen::InsensitiveStr::Ascii("ralizations"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralled"),
        dictgen::InsensitiveStr::Ascii("ralling"),
        dictgen::InsensitiveStr::Ascii("rea"),
        dictgen::InsensitiveStr::Ascii("reas"),
        dictgen::InsensitiveStr::Ascii("res"),
        dictgen::InsensitiveStr::Ascii("ritise"),
        dictgen::InsensitiveStr::Ascii("ritises"),
        dictgen::InsensitiveStr::Ascii("ritize"),
        dictgen::InsensitiveStr::Ascii("ritizes"),
        dictgen::InsensitiveStr::Ascii("ritualisation"),
        dictgen::InsensitiveStr::Ascii("ritualisations"),
        dictgen::InsensitiveStr::Ascii("ritualise"),
        dictgen::InsensitiveStr::Ascii("ritualised"),
        dictgen::InsensitiveStr::Ascii("ritualiser"),
        dictgen::InsensitiveStr::Ascii("ritualisers"),
        dictgen::InsensitiveStr::Ascii("ritualises"),
        dictgen::InsensitiveStr::Ascii("ritualising"),
        dictgen::InsensitiveStr::Ascii("ritualization"),
        dictgen::InsensitiveStr::Ascii("ritualizations"),
        dictgen::InsensitiveStr::Ascii("ritualize"),
        dictgen::InsensitiveStr::Ascii("ritualized"),
        dictgen::InsensitiveStr::Ascii("ritualizer"),
        dictgen::InsensitiveStr::Ascii("ritualizers"),
        dictgen::InsensitiveStr::Ascii("ritualizes"),
        dictgen::InsensitiveStr::Ascii("ritualizing"),
        dictgen::InsensitiveStr::Ascii("rochaetal"),
        dictgen::InsensitiveStr::Ascii("rochaete"),
        dictgen::InsensitiveStr::Ascii("rochaetes"),
        dictgen::InsensitiveStr::Ascii("rochaetoses"),
        dictgen::InsensitiveStr::Ascii("rochaetosis"),
        dictgen::InsensitiveStr::Ascii("rochaetotic"),
        dictgen::InsensitiveStr::Ascii("rochetal"),
        dictgen::InsensitiveStr::Ascii("rochete"),
        dictgen::InsensitiveStr::Ascii("rochetes"),
        dictgen::InsensitiveStr::Ascii("rochetoses"),
        dictgen::InsensitiveStr::Ascii("rochetosis"),
        dictgen::InsensitiveStr::Ascii("rochetotic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SPIERS_9403741506204571610)],
        &[(0b11010, &ENTRY_SPINULE_14289210505662966609)],
        &[(0b00001, &ENTRY_SPINULE_14289210505662966609)],
        &[(0b01001, &ENTRY_SPIRALED_16325472687253851967)],
        &[(0b01001, &ENTRY_SPIRALING_17847046296192692592)],
        &[(0b10010, &ENTRY_SPIRALIZATION_14526564309233419768)],
        &[(0b10010, &ENTRY_SPIRALIZATIONS_13076784845071161777)],
        &[(0b10010, &ENTRY_SPIRALIZE_3447519808027951591)],
        &[(0b10010, &ENTRY_SPIRALIZES_10710220071293796216)],
        &[(0b01001, &ENTRY_SPIRALIZATION_14526564309233419768)],
        &[(0b01001, &ENTRY_SPIRALIZATIONS_13076784845071161777)],
        &[(0b01001, &ENTRY_SPIRALIZE_3447519808027951591)],
        &[(0b01001, &ENTRY_SPIRALIZES_10710220071293796216)],
        &[(0b11010, &ENTRY_SPIRALED_16325472687253851967)],
        &[(0b11010, &ENTRY_SPIRALING_17847046296192692592)],
        &[(0b01001, &ENTRY_SPIREA_8481146863445432200)],
        &[(0b01001, &ENTRY_SPIREAS_2974152297943195596)],
        &[(0b11010, &ENTRY_SPIERS_9403741506204571610)],
        &[(0b10010, &ENTRY_SPIRITIZE_9805541284124148336)],
        &[(0b10010, &ENTRY_SPIRITIZES_8526314939083109501)],
        &[(0b01001, &ENTRY_SPIRITIZE_9805541284124148336)],
        &[(0b01001, &ENTRY_SPIRITIZES_8526314939083109501)],
        &[(0b10010, &ENTRY_SPIRITUALIZATION_9220466398088529072)],
        &[(0b10010, &ENTRY_SPIRITUALIZATIONS_17245892670567210801)],
        &[(0b10010, &ENTRY_SPIRITUALIZE_12814212072235396435)],
        &[(0b10010, &ENTRY_SPIRITUALIZED_15163734331617007407)],
        &[(0b10010, &ENTRY_SPIRITUALIZER_3452155405302964460)],
        &[(0b10010, &ENTRY_SPIRITUALIZERS_9374370261250047870)],
        &[(0b10010, &ENTRY_SPIRITUALIZES_15228536253347259988)],
        &[(0b10010, &ENTRY_SPIRITUALIZING_3491733202887639865)],
        &[(0b01001, &ENTRY_SPIRITUALIZATION_9220466398088529072)],
        &[(0b01001, &ENTRY_SPIRITUALIZATIONS_17245892670567210801)],
        &[(0b01001, &ENTRY_SPIRITUALIZE_12814212072235396435)],
        &[(0b01001, &ENTRY_SPIRITUALIZED_15163734331617007407)],
        &[(0b01001, &ENTRY_SPIRITUALIZER_3452155405302964460)],
        &[(0b01001, &ENTRY_SPIRITUALIZERS_9374370261250047870)],
        &[(0b01001, &ENTRY_SPIRITUALIZES_15228536253347259988)],
        &[(0b01001, &ENTRY_SPIRITUALIZING_3491733202887639865)],
        &[(0b11010, &ENTRY_SPIROCHETAL_15517952665892700942)],
        &[(0b10010, &ENTRY_SPIROCHETE_7516750690687611615)],
        &[(0b10010, &ENTRY_SPIROCHETES_7149420395283644676)],
        &[(0b11010, &ENTRY_SPIROCHETOSES_8527932054069113609)],
        &[(0b11010, &ENTRY_SPIROCHETOSIS_15823604220446153605)],
        &[(0b11010, &ENTRY_SPIROCHETOTIC_7192851043013496969)],
        &[(0b00001, &ENTRY_SPIROCHETAL_15517952665892700942)],
        &[(0b01001, &ENTRY_SPIROCHETE_7516750690687611615)],
        &[(0b01001, &ENTRY_SPIROCHETES_7149420395283644676)],
        &[(0b00001, &ENTRY_SPIROCHETOSES_8527932054069113609)],
        &[(0b00001, &ENTRY_SPIROCHETOSIS_15823604220446153605)],
        &[(0b00001, &ENTRY_SPIROCHETOTIC_7192851043013496969)],
    ],
    range: 3..=14,
};

static VARS_SPH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPH_CHILDREN),
    value: None,
};

pub static VARS_SPH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aerocrystal"),
        dictgen::InsensitiveStr::Ascii("aerosome"),
        dictgen::InsensitiveStr::Ascii("enethmoid"),
        dictgen::InsensitiveStr::Ascii("enethmoidal"),
        dictgen::InsensitiveStr::Ascii("enoethmoid"),
        dictgen::InsensitiveStr::Ascii("enoethmoidal"),
        dictgen::InsensitiveStr::Ascii("erocrystal"),
        dictgen::InsensitiveStr::Ascii("eroidisation"),
        dictgen::InsensitiveStr::Ascii("eroidisations"),
        dictgen::InsensitiveStr::Ascii("eroidise"),
        dictgen::InsensitiveStr::Ascii("eroidised"),
        dictgen::InsensitiveStr::Ascii("eroidises"),
        dictgen::InsensitiveStr::Ascii("eroidising"),
        dictgen::InsensitiveStr::Ascii("eroidization"),
        dictgen::InsensitiveStr::Ascii("eroidizations"),
        dictgen::InsensitiveStr::Ascii("eroidize"),
        dictgen::InsensitiveStr::Ascii("eroidized"),
        dictgen::InsensitiveStr::Ascii("eroidizes"),
        dictgen::InsensitiveStr::Ascii("eroidizing"),
        dictgen::InsensitiveStr::Ascii("erosome"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SPHEROCRYSTAL_13932713915466541286)],
        &[(0b11010, &ENTRY_SPHEROSOME_9093290394436122389)],
        &[(0b00001, &ENTRY_SPHENETHMOID_3344554427813149122)],
        &[(0b00001, &ENTRY_SPHENETHMOIDAL_15095592789700320199)],
        &[(0b11010, &ENTRY_SPHENETHMOID_3344554427813149122)],
        &[(0b11010, &ENTRY_SPHENETHMOIDAL_15095592789700320199)],
        &[(0b00001, &ENTRY_SPHEROCRYSTAL_13932713915466541286)],
        &[(0b10010, &ENTRY_SPHEROIDIZATION_5744466853986400727)],
        &[(0b10010, &ENTRY_SPHEROIDIZATIONS_14295978134258099517)],
        &[(0b10010, &ENTRY_SPHEROIDIZE_14518292079831405966)],
        &[(0b10010, &ENTRY_SPHEROIDIZED_13765691704944125686)],
        &[(0b10010, &ENTRY_SPHEROIDIZES_14751177492930435556)],
        &[(0b10010, &ENTRY_SPHEROIDIZING_16138304032840348269)],
        &[(0b01001, &ENTRY_SPHEROIDIZATION_5744466853986400727)],
        &[(0b01001, &ENTRY_SPHEROIDIZATIONS_14295978134258099517)],
        &[(0b01001, &ENTRY_SPHEROIDIZE_14518292079831405966)],
        &[(0b01001, &ENTRY_SPHEROIDIZED_13765691704944125686)],
        &[(0b01001, &ENTRY_SPHEROIDIZES_14751177492930435556)],
        &[(0b01001, &ENTRY_SPHEROIDIZING_16138304032840348269)],
        &[(0b00001, &ENTRY_SPHEROSOME_9093290394436122389)],
    ],
    range: 7..=13,
};

static VARS_SPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPE_CHILDREN),
    value: None,
};

pub static VARS_SPE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cialisation"),
        dictgen::InsensitiveStr::Ascii("cialisations"),
        dictgen::InsensitiveStr::Ascii("cialise"),
        dictgen::InsensitiveStr::Ascii("cialised"),
        dictgen::InsensitiveStr::Ascii("cialiser"),
        dictgen::InsensitiveStr::Ascii("cialisers"),
        dictgen::InsensitiveStr::Ascii("cialises"),
        dictgen::InsensitiveStr::Ascii("cialising"),
        dictgen::InsensitiveStr::Ascii("cialities"),
        dictgen::InsensitiveStr::Ascii("ciality"),
        dictgen::InsensitiveStr::Ascii("cialization"),
        dictgen::InsensitiveStr::Ascii("cializations"),
        dictgen::InsensitiveStr::Ascii("cialize"),
        dictgen::InsensitiveStr::Ascii("cialized"),
        dictgen::InsensitiveStr::Ascii("cializer"),
        dictgen::InsensitiveStr::Ascii("cializers"),
        dictgen::InsensitiveStr::Ascii("cializes"),
        dictgen::InsensitiveStr::Ascii("cializing"),
        dictgen::InsensitiveStr::Ascii("cialties"),
        dictgen::InsensitiveStr::Ascii("cialty"),
        dictgen::InsensitiveStr::Ascii("cificise"),
        dictgen::InsensitiveStr::Ascii("cificises"),
        dictgen::InsensitiveStr::Ascii("cificize"),
        dictgen::InsensitiveStr::Ascii("cificizes"),
        dictgen::InsensitiveStr::Ascii("cimenise"),
        dictgen::InsensitiveStr::Ascii("cimenises"),
        dictgen::InsensitiveStr::Ascii("cimenize"),
        dictgen::InsensitiveStr::Ascii("cimenizes"),
        dictgen::InsensitiveStr::Ascii("cter"),
        dictgen::InsensitiveStr::Ascii("ctered"),
        dictgen::InsensitiveStr::Ascii("cterlike"),
        dictgen::InsensitiveStr::Ascii("cterlikes"),
        dictgen::InsensitiveStr::Ascii("cters"),
        dictgen::InsensitiveStr::Ascii("ctre"),
        dictgen::InsensitiveStr::Ascii("ctred"),
        dictgen::InsensitiveStr::Ascii("ctrelike"),
        dictgen::InsensitiveStr::Ascii("ctrelikes"),
        dictgen::InsensitiveStr::Ascii("ctres"),
        dictgen::InsensitiveStr::Ascii("ctrocolorimetry"),
        dictgen::InsensitiveStr::Ascii("ctrocolourimetry"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("laean"),
        dictgen::InsensitiveStr::Ascii("laeological"),
        dictgen::InsensitiveStr::Ascii("laeothem"),
        dictgen::InsensitiveStr::Ascii("laeothems"),
        dictgen::InsensitiveStr::Ascii("lean"),
        dictgen::InsensitiveStr::Ascii("leothem"),
        dictgen::InsensitiveStr::Ascii("leothems"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("rmatorrhea"),
        dictgen::InsensitiveStr::Ascii("rmatorrheas"),
        dictgen::InsensitiveStr::Ascii("rmatorrhoea"),
        dictgen::InsensitiveStr::Ascii("rmatorrhoeas"),
        dictgen::InsensitiveStr::Ascii("ronares"),
        dictgen::InsensitiveStr::Ascii("ronaroes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SPECIALIZATION_6120455718688591089)],
        &[(0b10010, &ENTRY_SPECIALIZATIONS_8996872983896742236)],
        &[(0b10010, &ENTRY_SPECIALIZE_11882111573270244369)],
        &[(0b10010, &ENTRY_SPECIALIZED_16208307633714518784)],
        &[(0b10010, &ENTRY_SPECIALIZER_11921648751057504779)],
        &[(0b10010, &ENTRY_SPECIALIZERS_9633520764605881875)],
        &[(0b10010, &ENTRY_SPECIALIZES_8324377090323742106)],
        &[(0b10010, &ENTRY_SPECIALIZING_313518186697576164)],
        &[(0b10010, &ENTRY_SPECIALTIES_4384906624021484771)],
        &[(0b10010, &ENTRY_SPECIALTY_7072505085373556831)],
        &[(0b01001, &ENTRY_SPECIALIZATION_6120455718688591089)],
        &[(0b01001, &ENTRY_SPECIALIZATIONS_8996872983896742236)],
        &[(0b01001, &ENTRY_SPECIALIZE_11882111573270244369)],
        &[(0b01001, &ENTRY_SPECIALIZED_16208307633714518784)],
        &[(0b01001, &ENTRY_SPECIALIZER_11921648751057504779)],
        &[(0b01001, &ENTRY_SPECIALIZERS_9633520764605881875)],
        &[(0b01001, &ENTRY_SPECIALIZES_8324377090323742106)],
        &[(0b01001, &ENTRY_SPECIALIZING_313518186697576164)],
        &[(0b01001, &ENTRY_SPECIALTIES_4384906624021484771)],
        &[(0b01001, &ENTRY_SPECIALTY_7072505085373556831)],
        &[(0b10010, &ENTRY_SPECIFICIZE_8694015960566697924)],
        &[(0b10010, &ENTRY_SPECIFICIZES_11252709195406863154)],
        &[(0b01001, &ENTRY_SPECIFICIZE_8694015960566697924)],
        &[(0b01001, &ENTRY_SPECIFICIZES_11252709195406863154)],
        &[(0b10010, &ENTRY_SPECIMENIZE_15854679138652311678)],
        &[(0b10010, &ENTRY_SPECIMENIZES_8054030914250793962)],
        &[(0b01001, &ENTRY_SPECIMENIZE_15854679138652311678)],
        &[(0b01001, &ENTRY_SPECIMENIZES_8054030914250793962)],
        &[(0b00001, &ENTRY_SPECTER_6975611216022022799)],
        &[(0b00001, &ENTRY_SPECTERED_12261702122507455629)],
        &[(0b00001, &ENTRY_SPECTERLIKE_14755283384607298035)],
        &[(0b00001, &ENTRY_SPECTERLIKES_2606014956854784004)],
        &[(0b00001, &ENTRY_SPECTERS_5015013310557036380)],
        &[(0b11010, &ENTRY_SPECTER_6975611216022022799)],
        &[(0b11010, &ENTRY_SPECTERED_12261702122507455629)],
        &[(0b11010, &ENTRY_SPECTERLIKE_14755283384607298035)],
        &[(0b11010, &ENTRY_SPECTERLIKES_2606014956854784004)],
        &[(0b11010, &ENTRY_SPECTERS_5015013310557036380)],
        &[(0b00001, &ENTRY_SPECTROCOLORIMETRY_10424259053223609880)],
        &[(0b11010, &ENTRY_SPECTROCOLORIMETRY_10424259053223609880)],
        &[(0b00001, &ENTRY_SPEER_7360372930438810102)],
        &[(0b11010, &ENTRY_SPELEAN_12346771822163467823)],
        &[(0b11010, &ENTRY_SPELEOLOGICAL_5030814757410755163)],
        &[(0b11010, &ENTRY_SPELEOTHEM_16440817073388704217)],
        &[(0b11010, &ENTRY_SPELEOTHEMS_7444361922553408895)],
        &[(0b00001, &ENTRY_SPELEAN_12346771822163467823)],
        &[(0b00001, &ENTRY_SPELEOTHEM_16440817073388704217)],
        &[(0b00001, &ENTRY_SPELEOTHEMS_7444361922553408895)],
        &[(0b11010, &ENTRY_SPEER_7360372930438810102)],
        &[(0b00001, &ENTRY_SPERMATORRHEA_8028285969078435945)],
        &[(0b00001, &ENTRY_SPERMATORRHEAS_5238224579203778804)],
        &[(0b11010, &ENTRY_SPERMATORRHEA_8028285969078435945)],
        &[(0b11010, &ENTRY_SPERMATORRHEAS_5238224579203778804)],
        &[(0b00001, &ENTRY_SPERONARES_17413089710620250879)],
        &[(0b11010, &ENTRY_SPERONARES_17413089710620250879)],
    ],
    range: 2..=16,
};

static VARS_SPA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPA_CHILDREN),
    value: None,
};

pub static VARS_SPA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("naemia"),
        dictgen::InsensitiveStr::Ascii("naemic"),
        dictgen::InsensitiveStr::Ascii("nemia"),
        dictgen::InsensitiveStr::Ascii("nemic"),
        dictgen::InsensitiveStr::Ascii("niardisation"),
        dictgen::InsensitiveStr::Ascii("niardisations"),
        dictgen::InsensitiveStr::Ascii("niardise"),
        dictgen::InsensitiveStr::Ascii("niardises"),
        dictgen::InsensitiveStr::Ascii("niardization"),
        dictgen::InsensitiveStr::Ascii("niardizations"),
        dictgen::InsensitiveStr::Ascii("niardize"),
        dictgen::InsensitiveStr::Ascii("niardizes"),
        dictgen::InsensitiveStr::Ascii("niolise"),
        dictgen::InsensitiveStr::Ascii("niolised"),
        dictgen::InsensitiveStr::Ascii("niolises"),
        dictgen::InsensitiveStr::Ascii("niolising"),
        dictgen::InsensitiveStr::Ascii("niolize"),
        dictgen::InsensitiveStr::Ascii("niolized"),
        dictgen::InsensitiveStr::Ascii("niolizes"),
        dictgen::InsensitiveStr::Ascii("niolizing"),
        dictgen::InsensitiveStr::Ascii("nishise"),
        dictgen::InsensitiveStr::Ascii("nishises"),
        dictgen::InsensitiveStr::Ascii("nishize"),
        dictgen::InsensitiveStr::Ascii("nishizes"),
        dictgen::InsensitiveStr::Ascii("nopnea"),
        dictgen::InsensitiveStr::Ascii("nopnoea"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("rres"),
        dictgen::InsensitiveStr::Ascii("rtanise"),
        dictgen::InsensitiveStr::Ascii("rtanises"),
        dictgen::InsensitiveStr::Ascii("rtanize"),
        dictgen::InsensitiveStr::Ascii("rtanizes"),
        dictgen::InsensitiveStr::Ascii("tialisation"),
        dictgen::InsensitiveStr::Ascii("tialisations"),
        dictgen::InsensitiveStr::Ascii("tialise"),
        dictgen::InsensitiveStr::Ascii("tialises"),
        dictgen::InsensitiveStr::Ascii("tialization"),
        dictgen::InsensitiveStr::Ascii("tializations"),
        dictgen::InsensitiveStr::Ascii("tialize"),
        dictgen::InsensitiveStr::Ascii("tializes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SPANEMIA_922888539006433588)],
        &[(0b11010, &ENTRY_SPANEMIC_3971348550038618561)],
        &[(0b00001, &ENTRY_SPANEMIA_922888539006433588)],
        &[(0b00001, &ENTRY_SPANEMIC_3971348550038618561)],
        &[(0b10010, &ENTRY_SPANIARDIZATION_11817299560808553859)],
        &[(0b10010, &ENTRY_SPANIARDIZATIONS_1586989072442973142)],
        &[(0b10010, &ENTRY_SPANIARDIZE_3885557966001306111)],
        &[(0b10010, &ENTRY_SPANIARDIZES_9329878137611411598)],
        &[(0b01001, &ENTRY_SPANIARDIZATION_11817299560808553859)],
        &[(0b01001, &ENTRY_SPANIARDIZATIONS_1586989072442973142)],
        &[(0b01001, &ENTRY_SPANIARDIZE_3885557966001306111)],
        &[(0b01001, &ENTRY_SPANIARDIZES_9329878137611411598)],
        &[(0b10010, &ENTRY_SPANIOLIZE_2565179938529738131)],
        &[(0b10010, &ENTRY_SPANIOLIZED_5875906605727578891)],
        &[(0b10010, &ENTRY_SPANIOLIZES_10707148102344223944)],
        &[(0b10010, &ENTRY_SPANIOLIZING_11882230655915610816)],
        &[(0b01001, &ENTRY_SPANIOLIZE_2565179938529738131)],
        &[(0b01001, &ENTRY_SPANIOLIZED_5875906605727578891)],
        &[(0b01001, &ENTRY_SPANIOLIZES_10707148102344223944)],
        &[(0b01001, &ENTRY_SPANIOLIZING_11882230655915610816)],
        &[(0b10010, &ENTRY_SPANISHIZE_11603707337679635198)],
        &[(0b10010, &ENTRY_SPANISHIZES_18186475755228969865)],
        &[(0b01001, &ENTRY_SPANISHIZE_11603707337679635198)],
        &[(0b01001, &ENTRY_SPANISHIZES_18186475755228969865)],
        &[(0b00001, &ENTRY_SPANOPNEA_145137094678149677)],
        &[(0b11010, &ENTRY_SPANOPNEA_145137094678149677)],
        &[(0b00001, &ENTRY_SPARERS_16992181547853461019)],
        &[(0b11010, &ENTRY_SPARERS_16992181547853461019)],
        &[(0b10010, &ENTRY_SPARTANIZE_4628148206066142517)],
        &[(0b10010, &ENTRY_SPARTANIZES_9419600589579198560)],
        &[(0b01001, &ENTRY_SPARTANIZE_4628148206066142517)],
        &[(0b01001, &ENTRY_SPARTANIZES_9419600589579198560)],
        &[(0b10010, &ENTRY_SPATIALIZATION_4087066301429942262)],
        &[(0b10010, &ENTRY_SPATIALIZATIONS_1671848756975382904)],
        &[(0b10010, &ENTRY_SPATIALIZE_15447037881145049281)],
        &[(0b10010, &ENTRY_SPATIALIZES_12158813954747942290)],
        &[(0b01001, &ENTRY_SPATIALIZATION_4087066301429942262)],
        &[(0b01001, &ENTRY_SPATIALIZATIONS_1671848756975382904)],
        &[(0b01001, &ENTRY_SPATIALIZE_15447037881145049281)],
        &[(0b01001, &ENTRY_SPATIALIZES_12158813954747942290)],
    ],
    range: 4..=13,
};

static VARS_SO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SO_CHILDREN),
    value: None,
};

static VARS_SO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_SOB_NODE),
    Some(&VARS_SOC_NODE),
    Some(&VARS_SOD_NODE),
    Some(&VARS_SOE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SOL_NODE),
    Some(&VARS_SOM_NODE),
    Some(&VARS_SON_NODE),
    None,
    None,
    None,
    Some(&VARS_SOR_NODE),
    None,
    None,
    Some(&VARS_SOU_NODE),
    Some(&VARS_SOV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_SOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOV_CHILDREN),
    value: None,
};

pub static VARS_SOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ietisation"),
        dictgen::InsensitiveStr::Ascii("ietisations"),
        dictgen::InsensitiveStr::Ascii("ietise"),
        dictgen::InsensitiveStr::Ascii("ietised"),
        dictgen::InsensitiveStr::Ascii("ietises"),
        dictgen::InsensitiveStr::Ascii("ietising"),
        dictgen::InsensitiveStr::Ascii("ietization"),
        dictgen::InsensitiveStr::Ascii("ietizations"),
        dictgen::InsensitiveStr::Ascii("ietize"),
        dictgen::InsensitiveStr::Ascii("ietized"),
        dictgen::InsensitiveStr::Ascii("ietizes"),
        dictgen::InsensitiveStr::Ascii("ietizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOVIETIZATION_12298078635242896286)],
        &[(0b10010, &ENTRY_SOVIETIZATIONS_4958691907677433643)],
        &[(0b10010, &ENTRY_SOVIETIZE_4186406491577376479)],
        &[(0b10010, &ENTRY_SOVIETIZED_14659307059412841290)],
        &[(0b10010, &ENTRY_SOVIETIZES_17217850242167584748)],
        &[(0b10010, &ENTRY_SOVIETIZING_1809586830086781112)],
        &[(0b01001, &ENTRY_SOVIETIZATION_12298078635242896286)],
        &[(0b01001, &ENTRY_SOVIETIZATIONS_4958691907677433643)],
        &[(0b01001, &ENTRY_SOVIETIZE_4186406491577376479)],
        &[(0b01001, &ENTRY_SOVIETIZED_14659307059412841290)],
        &[(0b01001, &ENTRY_SOVIETIZES_17217850242167584748)],
        &[(0b01001, &ENTRY_SOVIETIZING_1809586830086781112)],
    ],
    range: 6..=11,
};

static VARS_SOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOU_CHILDREN),
    value: None,
};

pub static VARS_SOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fflaed"),
        dictgen::InsensitiveStr::Ascii("ffled"),
        dictgen::InsensitiveStr::Ascii("lter"),
        dictgen::InsensitiveStr::Ascii("ltre"),
        dictgen::InsensitiveStr::Ascii("rd"),
        dictgen::InsensitiveStr::Ascii("rdine"),
        dictgen::InsensitiveStr::Ascii("rdines"),
        dictgen::InsensitiveStr::Ascii("ry"),
        dictgen::InsensitiveStr::Ascii("thernise"),
        dictgen::InsensitiveStr::Ascii("thernised"),
        dictgen::InsensitiveStr::Ascii("thernises"),
        dictgen::InsensitiveStr::Ascii("thernising"),
        dictgen::InsensitiveStr::Ascii("thernize"),
        dictgen::InsensitiveStr::Ascii("thernized"),
        dictgen::InsensitiveStr::Ascii("thernizes"),
        dictgen::InsensitiveStr::Ascii("thernizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SOUFFLED_4248191495032262509)],
        &[(0b00001, &ENTRY_SOUFFLED_4248191495032262509)],
        &[(0b00001, &ENTRY_SOULTER_2831536725912973940)],
        &[(0b11010, &ENTRY_SOULTER_2831536725912973940)],
        &[(0b11010, &ENTRY_SORD_12541754408432709068)],
        &[(0b11010, &ENTRY_SORDINE_10174285465421407112)],
        &[(0b11010, &ENTRY_SORDINES_4854100779964973237)],
        &[(0b11010, &ENTRY_SORY_18130745314578295052)],
        &[(0b10010, &ENTRY_SOUTHERNIZE_5352868721449585244)],
        &[(0b10010, &ENTRY_SOUTHERNIZED_13583675455448911323)],
        &[(0b10010, &ENTRY_SOUTHERNIZES_16080540880462627833)],
        &[(0b10010, &ENTRY_SOUTHERNIZING_8286693634683754384)],
        &[(0b01001, &ENTRY_SOUTHERNIZE_5352868721449585244)],
        &[(0b01001, &ENTRY_SOUTHERNIZED_13583675455448911323)],
        &[(0b01001, &ENTRY_SOUTHERNIZES_16080540880462627833)],
        &[(0b01001, &ENTRY_SOUTHERNIZING_8286693634683754384)],
    ],
    range: 2..=10,
};

static VARS_SOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOR_CHILDREN),
    value: None,
};

pub static VARS_SOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bitisation"),
        dictgen::InsensitiveStr::Ascii("bitisations"),
        dictgen::InsensitiveStr::Ascii("bitise"),
        dictgen::InsensitiveStr::Ascii("bitised"),
        dictgen::InsensitiveStr::Ascii("bitises"),
        dictgen::InsensitiveStr::Ascii("bitising"),
        dictgen::InsensitiveStr::Ascii("bitization"),
        dictgen::InsensitiveStr::Ascii("bitizations"),
        dictgen::InsensitiveStr::Ascii("bitize"),
        dictgen::InsensitiveStr::Ascii("bitized"),
        dictgen::InsensitiveStr::Ascii("bitizes"),
        dictgen::InsensitiveStr::Ascii("bitizing"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("dine"),
        dictgen::InsensitiveStr::Ascii("dines"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
        dictgen::InsensitiveStr::Ascii("y"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SORBITIZATION_286678615652162287)],
        &[(0b10010, &ENTRY_SORBITIZATIONS_13164463647504490756)],
        &[(0b10010, &ENTRY_SORBITIZE_6846144076367658714)],
        &[(0b10010, &ENTRY_SORBITIZED_14569008759464807319)],
        &[(0b10010, &ENTRY_SORBITIZES_10577485183083089288)],
        &[(0b10010, &ENTRY_SORBITIZING_5713523379346241024)],
        &[(0b01001, &ENTRY_SORBITIZATION_286678615652162287)],
        &[(0b01001, &ENTRY_SORBITIZATIONS_13164463647504490756)],
        &[(0b01001, &ENTRY_SORBITIZE_6846144076367658714)],
        &[(0b01001, &ENTRY_SORBITIZED_14569008759464807319)],
        &[(0b01001, &ENTRY_SORBITIZES_10577485183083089288)],
        &[(0b01001, &ENTRY_SORBITIZING_5713523379346241024)],
        &[(0b00001, &ENTRY_SORD_12541754408432709068)],
        &[(0b00001, &ENTRY_SORDINE_10174285465421407112)],
        &[(0b00001, &ENTRY_SORDINES_4854100779964973237)],
        &[(0b10010, &ENTRY_SORORIZE_16170717109896239759)],
        &[(0b10010, &ENTRY_SORORIZED_11733033323347420043)],
        &[(0b10010, &ENTRY_SORORIZES_9620501314832330750)],
        &[(0b10010, &ENTRY_SORORIZING_4125981476974090908)],
        &[(0b01001, &ENTRY_SORORIZE_16170717109896239759)],
        &[(0b01001, &ENTRY_SORORIZED_11733033323347420043)],
        &[(0b01001, &ENTRY_SORORIZES_9620501314832330750)],
        &[(0b01001, &ENTRY_SORORIZING_4125981476974090908)],
        &[(0b00001, &ENTRY_SORY_18130745314578295052)],
    ],
    range: 1..=11,
};

static VARS_SON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SON_CHILDREN),
    value: None,
};

pub static VARS_SON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("antised"),
        dictgen::InsensitiveStr::Ascii("antiseds"),
        dictgen::InsensitiveStr::Ascii("antized"),
        dictgen::InsensitiveStr::Ascii("antizeds"),
        dictgen::InsensitiveStr::Ascii("netisation"),
        dictgen::InsensitiveStr::Ascii("netise"),
        dictgen::InsensitiveStr::Ascii("netised"),
        dictgen::InsensitiveStr::Ascii("netises"),
        dictgen::InsensitiveStr::Ascii("netising"),
        dictgen::InsensitiveStr::Ascii("netization"),
        dictgen::InsensitiveStr::Ascii("netize"),
        dictgen::InsensitiveStr::Ascii("netized"),
        dictgen::InsensitiveStr::Ascii("netizes"),
        dictgen::InsensitiveStr::Ascii("netizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SONANTIZED_8552816854534321230)],
        &[(0b10010, &ENTRY_SONANTIZEDS_14474845156317286221)],
        &[(0b01001, &ENTRY_SONANTIZED_8552816854534321230)],
        &[(0b01001, &ENTRY_SONANTIZEDS_14474845156317286221)],
        &[(0b10010, &ENTRY_SONNETIZATION_3238230146445769080)],
        &[(0b10010, &ENTRY_SONNETIZE_16502381925297255059)],
        &[(0b10010, &ENTRY_SONNETIZED_10277905536142803942)],
        &[(0b10010, &ENTRY_SONNETIZES_3719563389684057577)],
        &[(0b10010, &ENTRY_SONNETIZING_10321042710859016957)],
        &[(0b01001, &ENTRY_SONNETIZATION_3238230146445769080)],
        &[(0b01001, &ENTRY_SONNETIZE_16502381925297255059)],
        &[(0b01001, &ENTRY_SONNETIZED_10277905536142803942)],
        &[(0b01001, &ENTRY_SONNETIZES_3719563389684057577)],
        &[(0b01001, &ENTRY_SONNETIZING_10321042710859016957)],
    ],
    range: 6..=10,
};

static VARS_SOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOM_CHILDREN),
    value: None,
};

pub static VARS_SOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("aesthesis"),
        dictgen::InsensitiveStr::Ascii("ber"),
        dictgen::InsensitiveStr::Ascii("berer"),
        dictgen::InsensitiveStr::Ascii("berest"),
        dictgen::InsensitiveStr::Ascii("berish"),
        dictgen::InsensitiveStr::Ascii("berly"),
        dictgen::InsensitiveStr::Ascii("berness"),
        dictgen::InsensitiveStr::Ascii("bernesses"),
        dictgen::InsensitiveStr::Ascii("breish"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthesis"),
        dictgen::InsensitiveStr::Ascii("niloquise"),
        dictgen::InsensitiveStr::Ascii("niloquised"),
        dictgen::InsensitiveStr::Ascii("niloquises"),
        dictgen::InsensitiveStr::Ascii("niloquising"),
        dictgen::InsensitiveStr::Ascii("niloquize"),
        dictgen::InsensitiveStr::Ascii("niloquized"),
        dictgen::InsensitiveStr::Ascii("niloquizes"),
        dictgen::InsensitiveStr::Ascii("niloquizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SOMESTHESIA_696036815504224013)],
        &[(0b11010, &ENTRY_SOMESTHESIS_9625244055976929614)],
        &[(0b00001, &ENTRY_SOMBER_7545143144533743661)],
        &[(0b00001, &ENTRY_SOMBERER_5923083299459142321)],
        &[(0b00001, &ENTRY_SOMBEREST_13920553234454816213)],
        &[(0b00001, &ENTRY_SOMBERISH_9199090735234253330)],
        &[(0b00001, &ENTRY_SOMBERLY_8543050585429649865)],
        &[(0b00001, &ENTRY_SOMBERNESS_15776453114536814910)],
        &[(0b00001, &ENTRY_SOMBERNESSES_37120742853890215)],
        &[(0b11010, &ENTRY_SOMBERISH_9199090735234253330)],
        &[(0b00001, &ENTRY_SOMESTHESIA_696036815504224013)],
        &[(0b00001, &ENTRY_SOMESTHESIS_9625244055976929614)],
        &[(0b10010, &ENTRY_SOMNILOQUIZE_4534972985140538230)],
        &[(0b10010, &ENTRY_SOMNILOQUIZED_1808918933902905273)],
        &[(0b10010, &ENTRY_SOMNILOQUIZES_6303227745377820257)],
        &[(0b10010, &ENTRY_SOMNILOQUIZING_3623890958713154097)],
        &[(0b01001, &ENTRY_SOMNILOQUIZE_4534972985140538230)],
        &[(0b01001, &ENTRY_SOMNILOQUIZED_1808918933902905273)],
        &[(0b01001, &ENTRY_SOMNILOQUIZES_6303227745377820257)],
        &[(0b01001, &ENTRY_SOMNILOQUIZING_3623890958713154097)],
    ],
    range: 3..=11,
};

static VARS_SOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SOL_CHILDREN),
    value: None,
};

static VARS_SOL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SOLA_NODE),
    None,
    None,
    Some(&VARS_SOLD_NODE),
    Some(&VARS_SOLE_NODE),
    None,
    None,
    None,
    Some(&VARS_SOLI_NODE),
    None,
    None,
    None,
    Some(&VARS_SOLM_NODE),
    None,
    Some(&VARS_SOLO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SOLU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_SOLU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLU_CHILDREN),
    value: None,
};

pub static VARS_SOLU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilisation"),
        dictgen::InsensitiveStr::Ascii("bilisations"),
        dictgen::InsensitiveStr::Ascii("bilise"),
        dictgen::InsensitiveStr::Ascii("bilised"),
        dictgen::InsensitiveStr::Ascii("bilises"),
        dictgen::InsensitiveStr::Ascii("bilising"),
        dictgen::InsensitiveStr::Ascii("bilization"),
        dictgen::InsensitiveStr::Ascii("bilizations"),
        dictgen::InsensitiveStr::Ascii("bilize"),
        dictgen::InsensitiveStr::Ascii("bilized"),
        dictgen::InsensitiveStr::Ascii("bilizes"),
        dictgen::InsensitiveStr::Ascii("bilizing"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tiser"),
        dictgen::InsensitiveStr::Ascii("tisers"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tizer"),
        dictgen::InsensitiveStr::Ascii("tizers"),
        dictgen::InsensitiveStr::Ascii("tizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLUBILIZATION_10580055016658346926)],
        &[(0b10010, &ENTRY_SOLUBILIZATIONS_4955462430772240177)],
        &[(0b10010, &ENTRY_SOLUBILIZE_1673521634914384541)],
        &[(0b10010, &ENTRY_SOLUBILIZED_10156344475132002791)],
        &[(0b10010, &ENTRY_SOLUBILIZES_12208892698399982158)],
        &[(0b10010, &ENTRY_SOLUBILIZING_5913383570927297322)],
        &[(0b01001, &ENTRY_SOLUBILIZATION_10580055016658346926)],
        &[(0b01001, &ENTRY_SOLUBILIZATIONS_4955462430772240177)],
        &[(0b01001, &ENTRY_SOLUBILIZE_1673521634914384541)],
        &[(0b01001, &ENTRY_SOLUBILIZED_10156344475132002791)],
        &[(0b01001, &ENTRY_SOLUBILIZES_12208892698399982158)],
        &[(0b01001, &ENTRY_SOLUBILIZING_5913383570927297322)],
        &[(0b10010, &ENTRY_SOLUTIZE_4089193342836063440)],
        &[(0b10010, &ENTRY_SOLUTIZER_7736710185825875415)],
        &[(0b10010, &ENTRY_SOLUTIZERS_10254868232218021370)],
        &[(0b10010, &ENTRY_SOLUTIZES_17457446370787935768)],
        &[(0b01001, &ENTRY_SOLUTIZE_4089193342836063440)],
        &[(0b01001, &ENTRY_SOLUTIZER_7736710185825875415)],
        &[(0b01001, &ENTRY_SOLUTIZERS_10254868232218021370)],
        &[(0b01001, &ENTRY_SOLUTIZES_17457446370787935768)],
    ],
    range: 4..=11,
};

static VARS_SOLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLO_CHILDREN),
    value: None,
};

pub static VARS_SOLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLONIZATION_10730000459604020887)],
        &[(0b10010, &ENTRY_SOLONIZATIONS_3376302484656071644)],
        &[(0b01001, &ENTRY_SOLONIZATION_10730000459604020887)],
        &[(0b01001, &ENTRY_SOLONIZATIONS_3376302484656071644)],
    ],
    range: 8..=9,
};

static VARS_SOLM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLM_CHILDREN),
    value: None,
};

pub static VARS_SOLM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLMIZATION_12587274322609700335)],
        &[(0b10010, &ENTRY_SOLMIZATIONS_13644603279878977752)],
        &[(0b01001, &ENTRY_SOLMIZATION_12587274322609700335)],
        &[(0b01001, &ENTRY_SOLMIZATIONS_13644603279878977752)],
    ],
    range: 7..=8,
};

static VARS_SOLI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLI_CHILDREN),
    value: None,
};

pub static VARS_SOLI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("loquisation"),
        dictgen::InsensitiveStr::Ascii("loquise"),
        dictgen::InsensitiveStr::Ascii("loquised"),
        dictgen::InsensitiveStr::Ascii("loquiser"),
        dictgen::InsensitiveStr::Ascii("loquisers"),
        dictgen::InsensitiveStr::Ascii("loquises"),
        dictgen::InsensitiveStr::Ascii("loquising"),
        dictgen::InsensitiveStr::Ascii("loquisingly"),
        dictgen::InsensitiveStr::Ascii("loquisings"),
        dictgen::InsensitiveStr::Ascii("loquization"),
        dictgen::InsensitiveStr::Ascii("loquize"),
        dictgen::InsensitiveStr::Ascii("loquized"),
        dictgen::InsensitiveStr::Ascii("loquizer"),
        dictgen::InsensitiveStr::Ascii("loquizers"),
        dictgen::InsensitiveStr::Ascii("loquizes"),
        dictgen::InsensitiveStr::Ascii("loquizing"),
        dictgen::InsensitiveStr::Ascii("loquizingly"),
        dictgen::InsensitiveStr::Ascii("loquizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLILOQUIZATION_18296763197929133122)],
        &[(0b10010, &ENTRY_SOLILOQUIZE_14417000719223788095)],
        &[(0b10010, &ENTRY_SOLILOQUIZED_4881410725010799917)],
        &[(0b10010, &ENTRY_SOLILOQUIZER_8690726398071022002)],
        &[(0b10010, &ENTRY_SOLILOQUIZERS_4675842551561535988)],
        &[(0b10010, &ENTRY_SOLILOQUIZES_409834577954225605)],
        &[(0b10010, &ENTRY_SOLILOQUIZING_9233664287673036156)],
        &[(0b10010, &ENTRY_SOLILOQUIZINGLY_11096800081567827210)],
        &[(0b10010, &ENTRY_SOLILOQUIZINGS_16981301693070525140)],
        &[(0b01001, &ENTRY_SOLILOQUIZATION_18296763197929133122)],
        &[(0b01001, &ENTRY_SOLILOQUIZE_14417000719223788095)],
        &[(0b01001, &ENTRY_SOLILOQUIZED_4881410725010799917)],
        &[(0b01001, &ENTRY_SOLILOQUIZER_8690726398071022002)],
        &[(0b01001, &ENTRY_SOLILOQUIZERS_4675842551561535988)],
        &[(0b01001, &ENTRY_SOLILOQUIZES_409834577954225605)],
        &[(0b01001, &ENTRY_SOLILOQUIZING_9233664287673036156)],
        &[(0b01001, &ENTRY_SOLILOQUIZINGLY_11096800081567827210)],
        &[(0b01001, &ENTRY_SOLILOQUIZINGS_16981301693070525140)],
    ],
    range: 7..=11,
};

static VARS_SOLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLE_CHILDREN),
    value: None,
};

pub static VARS_SOLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cise"),
        dictgen::InsensitiveStr::Ascii("cised"),
        dictgen::InsensitiveStr::Ascii("cises"),
        dictgen::InsensitiveStr::Ascii("cising"),
        dictgen::InsensitiveStr::Ascii("cize"),
        dictgen::InsensitiveStr::Ascii("cized"),
        dictgen::InsensitiveStr::Ascii("cizes"),
        dictgen::InsensitiveStr::Ascii("cizing"),
        dictgen::InsensitiveStr::Ascii("mnisation"),
        dictgen::InsensitiveStr::Ascii("mnisations"),
        dictgen::InsensitiveStr::Ascii("mnise"),
        dictgen::InsensitiveStr::Ascii("mnised"),
        dictgen::InsensitiveStr::Ascii("mniser"),
        dictgen::InsensitiveStr::Ascii("mnisers"),
        dictgen::InsensitiveStr::Ascii("mnises"),
        dictgen::InsensitiveStr::Ascii("mnising"),
        dictgen::InsensitiveStr::Ascii("mnization"),
        dictgen::InsensitiveStr::Ascii("mnizations"),
        dictgen::InsensitiveStr::Ascii("mnize"),
        dictgen::InsensitiveStr::Ascii("mnized"),
        dictgen::InsensitiveStr::Ascii("mnizer"),
        dictgen::InsensitiveStr::Ascii("mnizers"),
        dictgen::InsensitiveStr::Ascii("mnizes"),
        dictgen::InsensitiveStr::Ascii("mnizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLECIZE_1902296975492568965)],
        &[(0b10010, &ENTRY_SOLECIZED_12860558242481667749)],
        &[(0b10010, &ENTRY_SOLECIZES_1903589863923647169)],
        &[(0b10010, &ENTRY_SOLECIZING_4096581158238808815)],
        &[(0b01001, &ENTRY_SOLECIZE_1902296975492568965)],
        &[(0b01001, &ENTRY_SOLECIZED_12860558242481667749)],
        &[(0b01001, &ENTRY_SOLECIZES_1903589863923647169)],
        &[(0b01001, &ENTRY_SOLECIZING_4096581158238808815)],
        &[(0b10010, &ENTRY_SOLEMNIZATION_11065823287402873495)],
        &[(0b10010, &ENTRY_SOLEMNIZATIONS_10033372229920712112)],
        &[(0b10010, &ENTRY_SOLEMNIZE_15679717866562504473)],
        &[(0b10010, &ENTRY_SOLEMNIZED_224034548114018910)],
        &[(0b10010, &ENTRY_SOLEMNIZER_14558116154158912985)],
        &[(0b10010, &ENTRY_SOLEMNIZERS_7502930185041648303)],
        &[(0b10010, &ENTRY_SOLEMNIZES_12952089326401148902)],
        &[(0b10010, &ENTRY_SOLEMNIZING_630145090956262150)],
        &[(0b01001, &ENTRY_SOLEMNIZATION_11065823287402873495)],
        &[(0b01001, &ENTRY_SOLEMNIZATIONS_10033372229920712112)],
        &[(0b01001, &ENTRY_SOLEMNIZE_15679717866562504473)],
        &[(0b01001, &ENTRY_SOLEMNIZED_224034548114018910)],
        &[(0b01001, &ENTRY_SOLEMNIZER_14558116154158912985)],
        &[(0b01001, &ENTRY_SOLEMNIZERS_7502930185041648303)],
        &[(0b01001, &ENTRY_SOLEMNIZES_12952089326401148902)],
        &[(0b01001, &ENTRY_SOLEMNIZING_630145090956262150)],
    ],
    range: 4..=10,
};

static VARS_SOLD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLD_CHILDREN),
    value: None,
};

pub static VARS_SOLD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ierise"),
        dictgen::InsensitiveStr::Ascii("ierises"),
        dictgen::InsensitiveStr::Ascii("ierize"),
        dictgen::InsensitiveStr::Ascii("ierizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLDIERIZE_9036042748338606942)],
        &[(0b10010, &ENTRY_SOLDIERIZES_8050837834439993245)],
        &[(0b01001, &ENTRY_SOLDIERIZE_9036042748338606942)],
        &[(0b01001, &ENTRY_SOLDIERIZES_8050837834439993245)],
    ],
    range: 6..=7,
};

static VARS_SOLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLA_CHILDREN),
    value: None,
};

pub static VARS_SOLA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("risation"),
        dictgen::InsensitiveStr::Ascii("risations"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rization"),
        dictgen::InsensitiveStr::Ascii("rizations"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLARIZATION_4885912231243718586)],
        &[(0b10010, &ENTRY_SOLARIZATIONS_11436810758858977879)],
        &[(0b10010, &ENTRY_SOLARIZE_5717478759034003221)],
        &[(0b10010, &ENTRY_SOLARIZED_4040826558854876151)],
        &[(0b10010, &ENTRY_SOLARIZES_4506803855717626619)],
        &[(0b10010, &ENTRY_SOLARIZING_8595599809624415698)],
        &[(0b01001, &ENTRY_SOLARIZATION_4885912231243718586)],
        &[(0b01001, &ENTRY_SOLARIZATIONS_11436810758858977879)],
        &[(0b01001, &ENTRY_SOLARIZE_5717478759034003221)],
        &[(0b01001, &ENTRY_SOLARIZED_4040826558854876151)],
        &[(0b01001, &ENTRY_SOLARIZES_4506803855717626619)],
        &[(0b01001, &ENTRY_SOLARIZING_8595599809624415698)],
    ],
    range: 4..=9,
};

static VARS_SOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_SE_7678721039302187964)]),
};

pub static VARS_SOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_SOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOD_CHILDREN),
    value: None,
};

pub static VARS_SOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("omise"),
        dictgen::InsensitiveStr::Ascii("omised"),
        dictgen::InsensitiveStr::Ascii("omises"),
        dictgen::InsensitiveStr::Ascii("omising"),
        dictgen::InsensitiveStr::Ascii("omize"),
        dictgen::InsensitiveStr::Ascii("omized"),
        dictgen::InsensitiveStr::Ascii("omizes"),
        dictgen::InsensitiveStr::Ascii("omizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SODOMIZE_8989273429049313613)],
        &[(0b10010, &ENTRY_SODOMIZED_14987743408591553330)],
        &[(0b10010, &ENTRY_SODOMIZES_13961547799680688282)],
        &[(0b10010, &ENTRY_SODOMIZING_17930954299621224444)],
        &[(0b01001, &ENTRY_SODOMIZE_8989273429049313613)],
        &[(0b01001, &ENTRY_SODOMIZED_14987743408591553330)],
        &[(0b01001, &ENTRY_SODOMIZES_13961547799680688282)],
        &[(0b01001, &ENTRY_SODOMIZING_17930954299621224444)],
    ],
    range: 5..=7,
};

static VARS_SOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOC_CHILDREN),
    value: None,
};

pub static VARS_SOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialisation"),
        dictgen::InsensitiveStr::Ascii("ialisations"),
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialised"),
        dictgen::InsensitiveStr::Ascii("ialiser"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialising"),
        dictgen::InsensitiveStr::Ascii("ialization"),
        dictgen::InsensitiveStr::Ascii("ializations"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ialized"),
        dictgen::InsensitiveStr::Ascii("ializer"),
        dictgen::InsensitiveStr::Ascii("ializes"),
        dictgen::InsensitiveStr::Ascii("ializing"),
        dictgen::InsensitiveStr::Ascii("kdologising"),
        dictgen::InsensitiveStr::Ascii("kdologizing"),
        dictgen::InsensitiveStr::Ascii("ratise"),
        dictgen::InsensitiveStr::Ascii("ratised"),
        dictgen::InsensitiveStr::Ascii("ratises"),
        dictgen::InsensitiveStr::Ascii("ratising"),
        dictgen::InsensitiveStr::Ascii("ratize"),
        dictgen::InsensitiveStr::Ascii("ratized"),
        dictgen::InsensitiveStr::Ascii("ratizes"),
        dictgen::InsensitiveStr::Ascii("ratizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOCIALIZATION_4031789440864790681)],
        &[(0b10010, &ENTRY_SOCIALIZATIONS_2850800344346221828)],
        &[(0b10010, &ENTRY_SOCIALIZE_7608316723437121057)],
        &[(0b10010, &ENTRY_SOCIALIZED_6519290214037545163)],
        &[(0b10010, &ENTRY_SOCIALIZER_13597908573496978215)],
        &[(0b10010, &ENTRY_SOCIALIZES_17008876412249563437)],
        &[(0b10010, &ENTRY_SOCIALIZING_5892971976061278726)],
        &[(0b01001, &ENTRY_SOCIALIZATION_4031789440864790681)],
        &[(0b01001, &ENTRY_SOCIALIZATIONS_2850800344346221828)],
        &[(0b01001, &ENTRY_SOCIALIZE_7608316723437121057)],
        &[(0b01001, &ENTRY_SOCIALIZED_6519290214037545163)],
        &[(0b01001, &ENTRY_SOCIALIZER_13597908573496978215)],
        &[(0b01001, &ENTRY_SOCIALIZES_17008876412249563437)],
        &[(0b01001, &ENTRY_SOCIALIZING_5892971976061278726)],
        &[(0b10010, &ENTRY_SOCKDOLOGIZING_8246826191842133500)],
        &[(0b01001, &ENTRY_SOCKDOLOGIZING_8246826191842133500)],
        &[(0b10010, &ENTRY_SOCRATIZE_7163114728746981046)],
        &[(0b10010, &ENTRY_SOCRATIZED_6374519054168187154)],
        &[(0b10010, &ENTRY_SOCRATIZES_1074905976057709485)],
        &[(0b10010, &ENTRY_SOCRATIZING_13388626729978739793)],
        &[(0b01001, &ENTRY_SOCRATIZE_7163114728746981046)],
        &[(0b01001, &ENTRY_SOCRATIZED_6374519054168187154)],
        &[(0b01001, &ENTRY_SOCRATIZES_1074905976057709485)],
        &[(0b01001, &ENTRY_SOCRATIZING_13388626729978739793)],
    ],
    range: 6..=11,
};

static VARS_SOB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOB_CHILDREN),
    value: None,
};

pub static VARS_SOB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erising"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("erizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOBERIZE_7002273929401547239)],
        &[(0b10010, &ENTRY_SOBERIZED_14314548196946162318)],
        &[(0b10010, &ENTRY_SOBERIZES_12819350931337248082)],
        &[(0b10010, &ENTRY_SOBERIZING_10979506276481353733)],
        &[(0b01001, &ENTRY_SOBERIZE_7002273929401547239)],
        &[(0b01001, &ENTRY_SOBERIZED_14314548196946162318)],
        &[(0b01001, &ENTRY_SOBERIZES_12819350931337248082)],
        &[(0b01001, &ENTRY_SOBERIZING_10979506276481353733)],
    ],
    range: 5..=7,
};

static VARS_SN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SN_CHILDREN),
    value: None,
};

pub static VARS_SN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iveled"),
        dictgen::InsensitiveStr::Ascii("iveler"),
        dictgen::InsensitiveStr::Ascii("ivelers"),
        dictgen::InsensitiveStr::Ascii("iveling"),
        dictgen::InsensitiveStr::Ascii("ivelings"),
        dictgen::InsensitiveStr::Ascii("ivelled"),
        dictgen::InsensitiveStr::Ascii("iveller"),
        dictgen::InsensitiveStr::Ascii("ivellers"),
        dictgen::InsensitiveStr::Ascii("ivelling"),
        dictgen::InsensitiveStr::Ascii("ivellings"),
        dictgen::InsensitiveStr::Ascii("obsniveling"),
        dictgen::InsensitiveStr::Ascii("obsnivelling"),
        dictgen::InsensitiveStr::Ascii("orkeled"),
        dictgen::InsensitiveStr::Ascii("orkeling"),
        dictgen::InsensitiveStr::Ascii("orkelled"),
        dictgen::InsensitiveStr::Ascii("orkelling"),
        dictgen::InsensitiveStr::Ascii("owplough"),
        dictgen::InsensitiveStr::Ascii("owploughs"),
        dictgen::InsensitiveStr::Ascii("owplow"),
        dictgen::InsensitiveStr::Ascii("owplows"),
        dictgen::InsensitiveStr::Ascii("owshed"),
        dictgen::InsensitiveStr::Ascii("owshoed"),
        dictgen::InsensitiveStr::Ascii("uffcolored"),
        dictgen::InsensitiveStr::Ascii("uffcoloured"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SNIVELED_4241225854345991490)],
        &[(0b00001, &ENTRY_SNIVELER_7636471678868749639)],
        &[(0b00001, &ENTRY_SNIVELERS_10785023557653793627)],
        &[(0b00001, &ENTRY_SNIVELING_5513010514012383062)],
        &[(0b00001, &ENTRY_SNIVELINGS_8577178711179056074)],
        &[(0b11010, &ENTRY_SNIVELED_4241225854345991490)],
        &[(0b11010, &ENTRY_SNIVELER_7636471678868749639)],
        &[(0b11010, &ENTRY_SNIVELERS_10785023557653793627)],
        &[(0b11010, &ENTRY_SNIVELING_5513010514012383062)],
        &[(0b11010, &ENTRY_SNIVELINGS_8577178711179056074)],
        &[(0b00001, &ENTRY_SNOBSNIVELING_2007838763037803063)],
        &[(0b11010, &ENTRY_SNOBSNIVELING_2007838763037803063)],
        &[(0b01001, &ENTRY_SNORKELED_8473613528721477540)],
        &[(0b01001, &ENTRY_SNORKELING_13852650475536131090)],
        &[(0b11010, &ENTRY_SNORKELED_8473613528721477540)],
        &[(0b11010, &ENTRY_SNORKELING_13852650475536131090)],
        &[(0b11010, &ENTRY_SNOWPLOW_2634183079313653004)],
        &[(0b11010, &ENTRY_SNOWPLOWS_6320103518456053512)],
        &[(0b01001, &ENTRY_SNOWPLOW_2634183079313653004)],
        &[(0b01001, &ENTRY_SNOWPLOWS_6320103518456053512)],
        &[(0b00001, &ENTRY_SNOWSHED_5252480350190238030)],
        &[(0b11010, &ENTRY_SNOWSHED_5252480350190238030)],
        &[(0b00001, &ENTRY_SNUFFCOLORED_9191723066471236543)],
        &[(0b11010, &ENTRY_SNUFFCOLORED_9191723066471236543)],
    ],
    range: 6..=12,
};

static VARS_SM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SM_CHILDREN),
    value: None,
};

pub static VARS_SM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("idge"),
        dictgen::InsensitiveStr::Ascii("idges"),
        dictgen::InsensitiveStr::Ascii("older"),
        dictgen::InsensitiveStr::Ascii("oldered"),
        dictgen::InsensitiveStr::Ascii("oldering"),
        dictgen::InsensitiveStr::Ascii("olders"),
    ],
    values: &[
        &[(0b01001, &ENTRY_SMIDGEN_1020835176028070080)],
        &[(0b01001, &ENTRY_SMIDGENS_12067204132214853089)],
        &[(0b01001, &ENTRY_SMOLDER_18206679862651421040)],
        &[(0b01001, &ENTRY_SMOLDERED_525255363028764433)],
        &[(0b01001, &ENTRY_SMOLDERING_1321144217497101015)],
        &[(0b01001, &ENTRY_SMOLDERS_5811778710193840809)],
    ],
    range: 4..=8,
};

static VARS_SL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SL_CHILDREN),
    value: None,
};

pub static VARS_SL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("avicise"),
        dictgen::InsensitiveStr::Ascii("avicises"),
        dictgen::InsensitiveStr::Ascii("avicize"),
        dictgen::InsensitiveStr::Ascii("avicizes"),
        dictgen::InsensitiveStr::Ascii("avisation"),
        dictgen::InsensitiveStr::Ascii("avisations"),
        dictgen::InsensitiveStr::Ascii("avise"),
        dictgen::InsensitiveStr::Ascii("avises"),
        dictgen::InsensitiveStr::Ascii("avization"),
        dictgen::InsensitiveStr::Ascii("avizations"),
        dictgen::InsensitiveStr::Ascii("avize"),
        dictgen::InsensitiveStr::Ascii("avizes"),
        dictgen::InsensitiveStr::Ascii("avonicise"),
        dictgen::InsensitiveStr::Ascii("avonicised"),
        dictgen::InsensitiveStr::Ascii("avonicises"),
        dictgen::InsensitiveStr::Ascii("avonicising"),
        dictgen::InsensitiveStr::Ascii("avonicize"),
        dictgen::InsensitiveStr::Ascii("avonicized"),
        dictgen::InsensitiveStr::Ascii("avonicizes"),
        dictgen::InsensitiveStr::Ascii("avonicizing"),
        dictgen::InsensitiveStr::Ascii("avonise"),
        dictgen::InsensitiveStr::Ascii("avonised"),
        dictgen::InsensitiveStr::Ascii("avonises"),
        dictgen::InsensitiveStr::Ascii("avonising"),
        dictgen::InsensitiveStr::Ascii("avonize"),
        dictgen::InsensitiveStr::Ascii("avonized"),
        dictgen::InsensitiveStr::Ascii("avonizes"),
        dictgen::InsensitiveStr::Ascii("avonizing"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("enderise"),
        dictgen::InsensitiveStr::Ascii("enderised"),
        dictgen::InsensitiveStr::Ascii("enderises"),
        dictgen::InsensitiveStr::Ascii("enderising"),
        dictgen::InsensitiveStr::Ascii("enderize"),
        dictgen::InsensitiveStr::Ascii("enderized"),
        dictgen::InsensitiveStr::Ascii("enderizes"),
        dictgen::InsensitiveStr::Ascii("enderizing"),
        dictgen::InsensitiveStr::Ascii("ier"),
        dictgen::InsensitiveStr::Ascii("iest"),
        dictgen::InsensitiveStr::Ascii("ily"),
        dictgen::InsensitiveStr::Ascii("oganise"),
        dictgen::InsensitiveStr::Ascii("oganised"),
        dictgen::InsensitiveStr::Ascii("oganises"),
        dictgen::InsensitiveStr::Ascii("oganising"),
        dictgen::InsensitiveStr::Ascii("oganisings"),
        dictgen::InsensitiveStr::Ascii("oganize"),
        dictgen::InsensitiveStr::Ascii("oganized"),
        dictgen::InsensitiveStr::Ascii("oganizes"),
        dictgen::InsensitiveStr::Ascii("oganizing"),
        dictgen::InsensitiveStr::Ascii("oganizings"),
        dictgen::InsensitiveStr::Ascii("uggardise"),
        dictgen::InsensitiveStr::Ascii("uggardised"),
        dictgen::InsensitiveStr::Ascii("uggardises"),
        dictgen::InsensitiveStr::Ascii("uggardising"),
        dictgen::InsensitiveStr::Ascii("uggardize"),
        dictgen::InsensitiveStr::Ascii("uggardized"),
        dictgen::InsensitiveStr::Ascii("uggardizes"),
        dictgen::InsensitiveStr::Ascii("uggardizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SLE_17010563809824244033)],
        &[(0b10010, &ENTRY_SLAVICIZE_4863650478255717151)],
        &[(0b10010, &ENTRY_SLAVICIZES_9333045619587626033)],
        &[(0b01001, &ENTRY_SLAVICIZE_4863650478255717151)],
        &[(0b01001, &ENTRY_SLAVICIZES_9333045619587626033)],
        &[(0b10010, &ENTRY_SLAVIZATION_11709614021110971430)],
        &[(0b10010, &ENTRY_SLAVIZATIONS_15770441737620994218)],
        &[(0b10010, &ENTRY_SLAVIZE_18312974609644738377)],
        &[(0b10010, &ENTRY_SLAVIZES_3510132077149346979)],
        &[(0b01001, &ENTRY_SLAVIZATION_11709614021110971430)],
        &[(0b01001, &ENTRY_SLAVIZATIONS_15770441737620994218)],
        &[(0b01001, &ENTRY_SLAVIZE_18312974609644738377)],
        &[(0b01001, &ENTRY_SLAVIZES_3510132077149346979)],
        &[(0b10010, &ENTRY_SLAVONICIZE_6476323453849856832)],
        &[(0b10010, &ENTRY_SLAVONICIZED_8850052358113287660)],
        &[(0b10010, &ENTRY_SLAVONICIZES_16371616437362071351)],
        &[(0b10010, &ENTRY_SLAVONICIZING_12706848732597660283)],
        &[(0b01001, &ENTRY_SLAVONICIZE_6476323453849856832)],
        &[(0b01001, &ENTRY_SLAVONICIZED_8850052358113287660)],
        &[(0b01001, &ENTRY_SLAVONICIZES_16371616437362071351)],
        &[(0b01001, &ENTRY_SLAVONICIZING_12706848732597660283)],
        &[(0b10010, &ENTRY_SLAVONIZE_3789552220052397911)],
        &[(0b10010, &ENTRY_SLAVONIZED_9750176016831413177)],
        &[(0b10010, &ENTRY_SLAVONIZES_1386680960388327198)],
        &[(0b10010, &ENTRY_SLAVONIZING_15622203327519072554)],
        &[(0b01001, &ENTRY_SLAVONIZE_3789552220052397911)],
        &[(0b01001, &ENTRY_SLAVONIZED_9750176016831413177)],
        &[(0b01001, &ENTRY_SLAVONIZES_1386680960388327198)],
        &[(0b01001, &ENTRY_SLAVONIZING_15622203327519072554)],
        &[(0b00001, &ENTRY_SLE_17010563809824244033)],
        &[(0b10010, &ENTRY_SLENDERIZE_8450406323160278788)],
        &[(0b10010, &ENTRY_SLENDERIZED_12017380378072055827)],
        &[(0b10010, &ENTRY_SLENDERIZES_3290303620172743698)],
        &[(0b10010, &ENTRY_SLENDERIZING_16035225838163229483)],
        &[(0b01001, &ENTRY_SLENDERIZE_8450406323160278788)],
        &[(0b01001, &ENTRY_SLENDERIZED_12017380378072055827)],
        &[(0b01001, &ENTRY_SLENDERIZES_3290303620172743698)],
        &[(0b01001, &ENTRY_SLENDERIZING_16035225838163229483)],
        &[(0b00001, &ENTRY_SLIER_9265750496896058833)],
        &[(0b00001, &ENTRY_SLIEST_15096652467551200006)],
        &[(0b10011, &ENTRY_SLYLY_17796644133630896913)],
        &[(0b10010, &ENTRY_SLOGANIZE_17724147607334488119)],
        &[(0b10010, &ENTRY_SLOGANIZED_9832955101225402459)],
        &[(0b10010, &ENTRY_SLOGANIZES_3411813491582108245)],
        &[(0b10010, &ENTRY_SLOGANIZING_15622195225709846156)],
        &[(0b10010, &ENTRY_SLOGANIZINGS_15730703019261096083)],
        &[(0b01001, &ENTRY_SLOGANIZE_17724147607334488119)],
        &[(0b01001, &ENTRY_SLOGANIZED_9832955101225402459)],
        &[(0b01001, &ENTRY_SLOGANIZES_3411813491582108245)],
        &[(0b01001, &ENTRY_SLOGANIZING_15622195225709846156)],
        &[(0b01001, &ENTRY_SLOGANIZINGS_15730703019261096083)],
        &[(0b10010, &ENTRY_SLUGGARDIZE_9332680492168745395)],
        &[(0b10010, &ENTRY_SLUGGARDIZED_1660128103363949603)],
        &[(0b10010, &ENTRY_SLUGGARDIZES_12896575143246072039)],
        &[(0b10010, &ENTRY_SLUGGARDIZING_10482718795351653891)],
        &[(0b01001, &ENTRY_SLUGGARDIZE_9332680492168745395)],
        &[(0b01001, &ENTRY_SLUGGARDIZED_1660128103363949603)],
        &[(0b01001, &ENTRY_SLUGGARDIZES_12896575143246072039)],
        &[(0b01001, &ENTRY_SLUGGARDIZING_10482718795351653891)],
    ],
    range: 1..=11,
};

static VARS_SK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SK_CHILDREN),
    value: None,
};

pub static VARS_SK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eer"),
        dictgen::InsensitiveStr::Ascii("eletonisation"),
        dictgen::InsensitiveStr::Ascii("eletonisations"),
        dictgen::InsensitiveStr::Ascii("eletonise"),
        dictgen::InsensitiveStr::Ascii("eletonised"),
        dictgen::InsensitiveStr::Ascii("eletoniser"),
        dictgen::InsensitiveStr::Ascii("eletonisers"),
        dictgen::InsensitiveStr::Ascii("eletonises"),
        dictgen::InsensitiveStr::Ascii("eletonising"),
        dictgen::InsensitiveStr::Ascii("eletonization"),
        dictgen::InsensitiveStr::Ascii("eletonizations"),
        dictgen::InsensitiveStr::Ascii("eletonize"),
        dictgen::InsensitiveStr::Ascii("eletonized"),
        dictgen::InsensitiveStr::Ascii("eletonizer"),
        dictgen::InsensitiveStr::Ascii("eletonizers"),
        dictgen::InsensitiveStr::Ascii("eletonizes"),
        dictgen::InsensitiveStr::Ascii("eletonizing"),
        dictgen::InsensitiveStr::Ascii("eptic"),
        dictgen::InsensitiveStr::Ascii("eptical"),
        dictgen::InsensitiveStr::Ascii("epticaler"),
        dictgen::InsensitiveStr::Ascii("epticalest"),
        dictgen::InsensitiveStr::Ascii("eptically"),
        dictgen::InsensitiveStr::Ascii("epticer"),
        dictgen::InsensitiveStr::Ascii("epticest"),
        dictgen::InsensitiveStr::Ascii("epticise"),
        dictgen::InsensitiveStr::Ascii("epticises"),
        dictgen::InsensitiveStr::Ascii("epticism"),
        dictgen::InsensitiveStr::Ascii("epticisms"),
        dictgen::InsensitiveStr::Ascii("epticize"),
        dictgen::InsensitiveStr::Ascii("epticizes"),
        dictgen::InsensitiveStr::Ascii("eptics"),
        dictgen::InsensitiveStr::Ascii("ere"),
        dictgen::InsensitiveStr::Ascii("ilful"),
        dictgen::InsensitiveStr::Ascii("ilfully"),
        dictgen::InsensitiveStr::Ascii("ilfulness"),
        dictgen::InsensitiveStr::Ascii("illful"),
        dictgen::InsensitiveStr::Ascii("illfully"),
        dictgen::InsensitiveStr::Ascii("illfulness"),
        dictgen::InsensitiveStr::Ascii("yer"),
        dictgen::InsensitiveStr::Ascii("yers"),
        dictgen::InsensitiveStr::Ascii("yre"),
        dictgen::InsensitiveStr::Ascii("yres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SKEER_10694090215216405498)],
        &[(0b10010, &ENTRY_SKELETONIZATION_14703001244565805609)],
        &[(0b10010, &ENTRY_SKELETONIZATIONS_18147907457760273537)],
        &[(0b10010, &ENTRY_SKELETONIZE_14753576006665240012)],
        &[(0b10010, &ENTRY_SKELETONIZED_4399400631763960495)],
        &[(0b10010, &ENTRY_SKELETONIZER_11148122379923017190)],
        &[(0b10010, &ENTRY_SKELETONIZERS_2179019747423126437)],
        &[(0b10010, &ENTRY_SKELETONIZES_11609077896679678595)],
        &[(0b10010, &ENTRY_SKELETONIZING_17453924223738698796)],
        &[(0b01001, &ENTRY_SKELETONIZATION_14703001244565805609)],
        &[(0b01001, &ENTRY_SKELETONIZATIONS_18147907457760273537)],
        &[(0b01001, &ENTRY_SKELETONIZE_14753576006665240012)],
        &[(0b01001, &ENTRY_SKELETONIZED_4399400631763960495)],
        &[(0b01001, &ENTRY_SKELETONIZER_11148122379923017190)],
        &[(0b01001, &ENTRY_SKELETONIZERS_2179019747423126437)],
        &[(0b01001, &ENTRY_SKELETONIZES_11609077896679678595)],
        &[(0b01001, &ENTRY_SKELETONIZING_17453924223738698796)],
        &[(0b11001, &ENTRY_SKEPTIC_9815313097030140436)],
        &[(0b11001, &ENTRY_SKEPTICAL_17849179356584176691)],
        &[(0b11001, &ENTRY_SKEPTICALER_10497826709555834276)],
        &[(0b11001, &ENTRY_SKEPTICALEST_4980384681338816222)],
        &[(0b11001, &ENTRY_SKEPTICALLY_1022245430766512126)],
        &[(0b11001, &ENTRY_SKEPTICER_17239131044137588151)],
        &[(0b11001, &ENTRY_SKEPTICEST_7590086531147625946)],
        &[(0b10010, &ENTRY_SKEPTICIZE_9491002066487960132)],
        &[(0b10010, &ENTRY_SKEPTICIZES_12906322393300835503)],
        &[(0b11001, &ENTRY_SKEPTICISM_14105128952227011757)],
        &[(0b11001, &ENTRY_SKEPTICISMS_4642865009100445057)],
        &[(0b01001, &ENTRY_SKEPTICIZE_9491002066487960132)],
        &[(0b01001, &ENTRY_SKEPTICIZES_12906322393300835503)],
        &[(0b11001, &ENTRY_SKEPTICS_10828965990171531904)],
        &[(0b11010, &ENTRY_SKEER_10694090215216405498)],
        &[(0b11010, &ENTRY_SKILLFUL_2422177896744237002)],
        &[(0b11010, &ENTRY_SKILLFULLY_1794448316056971900)],
        &[(0b11010, &ENTRY_SKILLFULNESS_6885795773212202933)],
        &[(0b10001, &ENTRY_SKILLFUL_2422177896744237002)],
        &[(0b10001, &ENTRY_SKILLFULLY_1794448316056971900)],
        &[(0b10001, &ENTRY_SKILLFULNESS_6885795773212202933)],
        &[(0b00001, &ENTRY_SKYER_219848130793374202)],
        &[(0b00001, &ENTRY_SKYERS_14692226131287693314)],
        &[(0b11010, &ENTRY_SKYER_219848130793374202)],
        &[(0b11010, &ENTRY_SKYERS_14692226131287693314)],
    ],
    range: 3..=14,
};

static VARS_SI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SI_CHILDREN),
    value: None,
};

static VARS_SI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SIA_NODE),
    None,
    None,
    Some(&VARS_SID_NODE),
    None,
    None,
    Some(&VARS_SIG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_SIL_NODE),
    Some(&VARS_SIM_NODE),
    Some(&VARS_SIN_NODE),
    None,
    None,
    None,
    Some(&VARS_SIR_NODE),
    Some(&VARS_SIS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SIZ_NODE),
];

static VARS_SIZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIZ_CHILDREN),
    value: None,
};

pub static VARS_SIZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ably"),
        dictgen::InsensitiveStr::Ascii("eably"),
        dictgen::InsensitiveStr::Ascii("el"),
    ],
    values: &[
        &[(0b01001, &ENTRY_SIZABLY_12301409967193602959)],
        &[(0b10011, &ENTRY_SIZABLY_12301409967193602959)],
        &[(0b01001, &ENTRY_SIZEL_12038396317173133117)],
    ],
    range: 2..=5,
};

static VARS_SIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIS_CHILDREN),
    value: None,
};

pub static VARS_SIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("el"),
        dictgen::InsensitiveStr::Ascii("terise"),
        dictgen::InsensitiveStr::Ascii("terises"),
        dictgen::InsensitiveStr::Ascii("terize"),
        dictgen::InsensitiveStr::Ascii("terizes"),
        dictgen::InsensitiveStr::Ascii("tern"),
        dictgen::InsensitiveStr::Ascii("tren"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SIZEL_12038396317173133117)],
        &[(0b10010, &ENTRY_SISTERIZE_18228472873291960908)],
        &[(0b10010, &ENTRY_SISTERIZES_3585073858517133756)],
        &[(0b01001, &ENTRY_SISTERIZE_18228472873291960908)],
        &[(0b01001, &ENTRY_SISTERIZES_3585073858517133756)],
        &[(0b00001, &ENTRY_SISTERN_3589216592434306959)],
        &[(0b11010, &ENTRY_SISTERN_3589216592434306959)],
    ],
    range: 2..=7,
};

static VARS_SIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIR_CHILDREN),
    value: None,
};

pub static VARS_SIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("enised"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enising"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enized"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("enizing"),
        dictgen::InsensitiveStr::Ascii("up"),
        dictgen::InsensitiveStr::Ascii("ups"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SIRENIZE_4401588392569843591)],
        &[(0b10010, &ENTRY_SIRENIZED_17241413740995154727)],
        &[(0b10010, &ENTRY_SIRENIZES_6775435871825963686)],
        &[(0b10010, &ENTRY_SIRENIZING_14907055541353627309)],
        &[(0b01001, &ENTRY_SIRENIZE_4401588392569843591)],
        &[(0b01001, &ENTRY_SIRENIZED_17241413740995154727)],
        &[(0b01001, &ENTRY_SIRENIZES_6775435871825963686)],
        &[(0b01001, &ENTRY_SIRENIZING_14907055541353627309)],
        &[(0b00001, &ENTRY_SYRUP_11479307931259416998)],
        &[(0b00001, &ENTRY_SYRUPS_6494928060225946043)],
    ],
    range: 2..=7,
};

static VARS_SIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIN_CHILDREN),
    value: None,
};

pub static VARS_SIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("gularisation"),
        dictgen::InsensitiveStr::Ascii("gularisations"),
        dictgen::InsensitiveStr::Ascii("gularise"),
        dictgen::InsensitiveStr::Ascii("gularised"),
        dictgen::InsensitiveStr::Ascii("gularises"),
        dictgen::InsensitiveStr::Ascii("gularising"),
        dictgen::InsensitiveStr::Ascii("gularization"),
        dictgen::InsensitiveStr::Ascii("gularizations"),
        dictgen::InsensitiveStr::Ascii("gularize"),
        dictgen::InsensitiveStr::Ascii("gularized"),
        dictgen::InsensitiveStr::Ascii("gularizes"),
        dictgen::InsensitiveStr::Ascii("gularizing"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SINE_2527591790023124121)],
        &[(0b00001, &ENTRY_SINE_2527591790023124121)],
        &[(0b10010, &ENTRY_SINGULARIZATION_8500018865289525170)],
        &[(0b10010, &ENTRY_SINGULARIZATIONS_13878245436318237762)],
        &[(0b10010, &ENTRY_SINGULARIZE_11329575142831190791)],
        &[(0b10010, &ENTRY_SINGULARIZED_15088538269088551750)],
        &[(0b10010, &ENTRY_SINGULARIZES_9740292182667737407)],
        &[(0b10010, &ENTRY_SINGULARIZING_922470838749445662)],
        &[(0b01001, &ENTRY_SINGULARIZATION_8500018865289525170)],
        &[(0b01001, &ENTRY_SINGULARIZATIONS_13878245436318237762)],
        &[(0b01001, &ENTRY_SINGULARIZE_11329575142831190791)],
        &[(0b01001, &ENTRY_SINGULARIZED_15088538269088551750)],
        &[(0b01001, &ENTRY_SINGULARIZES_9740292182667737407)],
        &[(0b01001, &ENTRY_SINGULARIZING_922470838749445662)],
        &[(0b10010, &ENTRY_SINICIZE_18094969636027054415)],
        &[(0b10010, &ENTRY_SINICIZED_10860435760613269568)],
        &[(0b10010, &ENTRY_SINICIZES_8865802893263500137)],
        &[(0b10010, &ENTRY_SINICIZING_356924263573679617)],
        &[(0b01001, &ENTRY_SINICIZE_18094969636027054415)],
        &[(0b01001, &ENTRY_SINICIZED_10860435760613269568)],
        &[(0b01001, &ENTRY_SINICIZES_8865802893263500137)],
        &[(0b01001, &ENTRY_SINICIZING_356924263573679617)],
    ],
    range: 1..=13,
};

static VARS_SIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIM_CHILDREN),
    value: None,
};

pub static VARS_SIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilarise"),
        dictgen::InsensitiveStr::Ascii("ilarises"),
        dictgen::InsensitiveStr::Ascii("ilarize"),
        dictgen::InsensitiveStr::Ascii("ilarizes"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SIMILARIZE_16496852244210265562)],
        &[(0b10010, &ENTRY_SIMILARIZES_1632917830904082830)],
        &[(0b01001, &ENTRY_SIMILARIZE_16496852244210265562)],
        &[(0b01001, &ENTRY_SIMILARIZES_1632917830904082830)],
        &[(0b10010, &ENTRY_SIMILIZE_8574054999037710134)],
        &[(0b10010, &ENTRY_SIMILIZED_9710059990909892597)],
        &[(0b10010, &ENTRY_SIMILIZES_901429705138016982)],
        &[(0b10010, &ENTRY_SIMILIZING_5963188162030464608)],
        &[(0b01001, &ENTRY_SIMILIZE_8574054999037710134)],
        &[(0b01001, &ENTRY_SIMILIZED_9710059990909892597)],
        &[(0b01001, &ENTRY_SIMILIZES_901429705138016982)],
        &[(0b01001, &ENTRY_SIMILIZING_5963188162030464608)],
        &[(0b10010, &ENTRY_SIMONIZE_16191243326536881919)],
        &[(0b01001, &ENTRY_SIMONIZE_16191243326536881919)],
    ],
    range: 5..=8,
};

static VARS_SIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIL_CHILDREN),
    value: None,
};

pub static VARS_SIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("icatisation"),
        dictgen::InsensitiveStr::Ascii("icatisations"),
        dictgen::InsensitiveStr::Ascii("icatization"),
        dictgen::InsensitiveStr::Ascii("icatizations"),
        dictgen::InsensitiveStr::Ascii("icidise"),
        dictgen::InsensitiveStr::Ascii("icidises"),
        dictgen::InsensitiveStr::Ascii("icidize"),
        dictgen::InsensitiveStr::Ascii("icidizes"),
        dictgen::InsensitiveStr::Ascii("iconise"),
        dictgen::InsensitiveStr::Ascii("iconises"),
        dictgen::InsensitiveStr::Ascii("iconize"),
        dictgen::InsensitiveStr::Ascii("iconizes"),
        dictgen::InsensitiveStr::Ascii("iculae"),
        dictgen::InsensitiveStr::Ascii("icule"),
        dictgen::InsensitiveStr::Ascii("iquae"),
        dictgen::InsensitiveStr::Ascii("ique"),
        dictgen::InsensitiveStr::Ascii("oed"),
        dictgen::InsensitiveStr::Ascii("verise"),
        dictgen::InsensitiveStr::Ascii("verised"),
        dictgen::InsensitiveStr::Ascii("veriser"),
        dictgen::InsensitiveStr::Ascii("verisers"),
        dictgen::InsensitiveStr::Ascii("verises"),
        dictgen::InsensitiveStr::Ascii("verising"),
        dictgen::InsensitiveStr::Ascii("verize"),
        dictgen::InsensitiveStr::Ascii("verized"),
        dictgen::InsensitiveStr::Ascii("verizer"),
        dictgen::InsensitiveStr::Ascii("verizers"),
        dictgen::InsensitiveStr::Ascii("verizes"),
        dictgen::InsensitiveStr::Ascii("verizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SILED_12381586547309486387)],
        &[(0b10010, &ENTRY_SILICATIZATION_8334937031623361793)],
        &[(0b10010, &ENTRY_SILICATIZATIONS_14537460292946065713)],
        &[(0b01001, &ENTRY_SILICATIZATION_8334937031623361793)],
        &[(0b01001, &ENTRY_SILICATIZATIONS_14537460292946065713)],
        &[(0b10010, &ENTRY_SILICIDIZE_10105932126743433094)],
        &[(0b10010, &ENTRY_SILICIDIZES_8451599320490244745)],
        &[(0b01001, &ENTRY_SILICIDIZE_10105932126743433094)],
        &[(0b01001, &ENTRY_SILICIDIZES_8451599320490244745)],
        &[(0b10010, &ENTRY_SILICONIZE_13405622030239987984)],
        &[(0b10010, &ENTRY_SILICONIZES_13223727835681004529)],
        &[(0b01001, &ENTRY_SILICONIZE_13405622030239987984)],
        &[(0b01001, &ENTRY_SILICONIZES_13223727835681004529)],
        &[(0b11010, &ENTRY_SILICULE_8819087303829031645)],
        &[(0b00001, &ENTRY_SILICULE_8819087303829031645)],
        &[(0b11010, &ENTRY_SILIQUE_14167905731780673955)],
        &[(0b00001, &ENTRY_SILIQUE_14167905731780673955)],
        &[(0b11010, &ENTRY_SILED_12381586547309486387)],
        &[(0b10010, &ENTRY_SILVERIZE_17319102720364227407)],
        &[(0b10010, &ENTRY_SILVERIZED_6745009401833341902)],
        &[(0b10010, &ENTRY_SILVERIZER_9176727189423966849)],
        &[(0b10010, &ENTRY_SILVERIZERS_6400030913024008221)],
        &[(0b10010, &ENTRY_SILVERIZES_8743524383539922781)],
        &[(0b10010, &ENTRY_SILVERIZING_5788670803723424943)],
        &[(0b01001, &ENTRY_SILVERIZE_17319102720364227407)],
        &[(0b01001, &ENTRY_SILVERIZED_6745009401833341902)],
        &[(0b01001, &ENTRY_SILVERIZER_9176727189423966849)],
        &[(0b01001, &ENTRY_SILVERIZERS_6400030913024008221)],
        &[(0b01001, &ENTRY_SILVERIZES_8743524383539922781)],
        &[(0b01001, &ENTRY_SILVERIZING_5788670803723424943)],
    ],
    range: 2..=12,
};

static VARS_SIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIG_CHILDREN),
    value: None,
};

pub static VARS_SIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("naled"),
        dictgen::InsensitiveStr::Ascii("naler"),
        dictgen::InsensitiveStr::Ascii("nalers"),
        dictgen::InsensitiveStr::Ascii("naling"),
        dictgen::InsensitiveStr::Ascii("nalisation"),
        dictgen::InsensitiveStr::Ascii("nalise"),
        dictgen::InsensitiveStr::Ascii("nalised"),
        dictgen::InsensitiveStr::Ascii("nalises"),
        dictgen::InsensitiveStr::Ascii("nalising"),
        dictgen::InsensitiveStr::Ascii("nalization"),
        dictgen::InsensitiveStr::Ascii("nalize"),
        dictgen::InsensitiveStr::Ascii("nalized"),
        dictgen::InsensitiveStr::Ascii("nalizes"),
        dictgen::InsensitiveStr::Ascii("nalizing"),
        dictgen::InsensitiveStr::Ascii("nalled"),
        dictgen::InsensitiveStr::Ascii("naller"),
        dictgen::InsensitiveStr::Ascii("nallers"),
        dictgen::InsensitiveStr::Ascii("nalling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SIGNALED_3243424452669156037)],
        &[(0b00001, &ENTRY_SIGNALER_16546374588847832384)],
        &[(0b00001, &ENTRY_SIGNALERS_12534746997930214169)],
        &[(0b00001, &ENTRY_SIGNALING_10001000836087480137)],
        &[(0b10010, &ENTRY_SIGNALIZATION_13938195653404510955)],
        &[(0b10010, &ENTRY_SIGNALIZE_12255243066024468014)],
        &[(0b10010, &ENTRY_SIGNALIZED_5398549010551729806)],
        &[(0b10010, &ENTRY_SIGNALIZES_1856971438891156446)],
        &[(0b10010, &ENTRY_SIGNALIZING_2418286646902711346)],
        &[(0b01001, &ENTRY_SIGNALIZATION_13938195653404510955)],
        &[(0b01001, &ENTRY_SIGNALIZE_12255243066024468014)],
        &[(0b01001, &ENTRY_SIGNALIZED_5398549010551729806)],
        &[(0b01001, &ENTRY_SIGNALIZES_1856971438891156446)],
        &[(0b01001, &ENTRY_SIGNALIZING_2418286646902711346)],
        &[(0b11010, &ENTRY_SIGNALED_3243424452669156037)],
        &[(0b11010, &ENTRY_SIGNALER_16546374588847832384)],
        &[(0b11010, &ENTRY_SIGNALERS_12534746997930214169)],
        &[(0b11010, &ENTRY_SIGNALING_10001000836087480137)],
    ],
    range: 5..=10,
};

static VARS_SID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SID_CHILDREN),
    value: None,
};

pub static VARS_SID_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erealise"),
        dictgen::InsensitiveStr::Ascii("erealises"),
        dictgen::InsensitiveStr::Ascii("erealize"),
        dictgen::InsensitiveStr::Ascii("erealizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SIDEREALIZE_12293095375311999620)],
        &[(0b10010, &ENTRY_SIDEREALIZES_1405854832835173047)],
        &[(0b01001, &ENTRY_SIDEREALIZE_12293095375311999620)],
        &[(0b01001, &ENTRY_SIDEREALIZES_1405854832835173047)],
    ],
    range: 8..=9,
};

static VARS_SIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIA_CHILDREN),
    value: None,
};

pub static VARS_SIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lorrhea"),
        dictgen::InsensitiveStr::Ascii("lorrhoea"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SIALORRHEA_9719044074471805009)],
        &[(0b11010, &ENTRY_SIALORRHEA_9719044074471805009)],
    ],
    range: 7..=8,
};

static VARS_SH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SH_CHILDREN),
    value: None,
};

pub static VARS_SH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aikh"),
        dictgen::InsensitiveStr::Ascii("aikhs"),
        dictgen::InsensitiveStr::Ascii("akespearise"),
        dictgen::InsensitiveStr::Ascii("akespearises"),
        dictgen::InsensitiveStr::Ascii("akespearize"),
        dictgen::InsensitiveStr::Ascii("akespearizes"),
        dictgen::InsensitiveStr::Ascii("epherdise"),
        dictgen::InsensitiveStr::Ascii("epherdises"),
        dictgen::InsensitiveStr::Ascii("epherdize"),
        dictgen::InsensitiveStr::Ascii("epherdizes"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("erardise"),
        dictgen::InsensitiveStr::Ascii("erardised"),
        dictgen::InsensitiveStr::Ascii("erardises"),
        dictgen::InsensitiveStr::Ascii("erardising"),
        dictgen::InsensitiveStr::Ascii("erardize"),
        dictgen::InsensitiveStr::Ascii("erardized"),
        dictgen::InsensitiveStr::Ascii("erardizes"),
        dictgen::InsensitiveStr::Ascii("erardizing"),
        dictgen::InsensitiveStr::Ascii("ere"),
        dictgen::InsensitiveStr::Ascii("intoise"),
        dictgen::InsensitiveStr::Ascii("intoises"),
        dictgen::InsensitiveStr::Ascii("intoize"),
        dictgen::InsensitiveStr::Ascii("intoizes"),
        dictgen::InsensitiveStr::Ascii("kodaer"),
        dictgen::InsensitiveStr::Ascii("koder"),
        dictgen::InsensitiveStr::Ascii("oer"),
        dictgen::InsensitiveStr::Ascii("oveled"),
        dictgen::InsensitiveStr::Ascii("oveler"),
        dictgen::InsensitiveStr::Ascii("ovelers"),
        dictgen::InsensitiveStr::Ascii("oveling"),
        dictgen::InsensitiveStr::Ascii("ovelled"),
        dictgen::InsensitiveStr::Ascii("oveller"),
        dictgen::InsensitiveStr::Ascii("ovellers"),
        dictgen::InsensitiveStr::Ascii("ovelling"),
        dictgen::InsensitiveStr::Ascii("ree"),
        dictgen::InsensitiveStr::Ascii("riveled"),
        dictgen::InsensitiveStr::Ascii("riveling"),
        dictgen::InsensitiveStr::Ascii("rivelled"),
        dictgen::InsensitiveStr::Ascii("rivelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SHEIKH_9141106394100021739)],
        &[(0b00001, &ENTRY_SHEIKHS_15546350165137358568)],
        &[(0b10010, &ENTRY_SHAKESPEARIZE_16270945198431067427)],
        &[(0b10010, &ENTRY_SHAKESPEARIZES_13232054948447801950)],
        &[(0b01001, &ENTRY_SHAKESPEARIZE_16270945198431067427)],
        &[(0b01001, &ENTRY_SHAKESPEARIZES_13232054948447801950)],
        &[(0b10010, &ENTRY_SHEPHERDIZE_1030130588786935026)],
        &[(0b10010, &ENTRY_SHEPHERDIZES_6181398903864334578)],
        &[(0b01001, &ENTRY_SHEPHERDIZE_1030130588786935026)],
        &[(0b01001, &ENTRY_SHEPHERDIZES_6181398903864334578)],
        &[(0b00001, &ENTRY_SHER_11001556963296793208)],
        &[(0b10010, &ENTRY_SHERARDIZE_1843370089394724312)],
        &[(0b10010, &ENTRY_SHERARDIZED_18190646217667716189)],
        &[(0b10010, &ENTRY_SHERARDIZES_13290046997374044082)],
        &[(0b10010, &ENTRY_SHERARDIZING_16862661672440469221)],
        &[(0b01001, &ENTRY_SHERARDIZE_1843370089394724312)],
        &[(0b01001, &ENTRY_SHERARDIZED_18190646217667716189)],
        &[(0b01001, &ENTRY_SHERARDIZES_13290046997374044082)],
        &[(0b01001, &ENTRY_SHERARDIZING_16862661672440469221)],
        &[(0b00001, &ENTRY_SHERE_2828859166071306026)],
        &[(0b10010, &ENTRY_SHINTOIZE_8949418280207264230)],
        &[(0b10010, &ENTRY_SHINTOIZES_13727928026222091373)],
        &[(0b01001, &ENTRY_SHINTOIZE_8949418280207264230)],
        &[(0b01001, &ENTRY_SHINTOIZES_13727928026222091373)],
        &[(0b11010, &ENTRY_SHKODER_16753247486709071984)],
        &[(0b00001, &ENTRY_SHKODER_16753247486709071984)],
        &[(0b11010, &ENTRY_SHER_11001556963296793208)],
        &[(0b00001, &ENTRY_SHOVELED_10216188925046182061)],
        &[(0b01001, &ENTRY_SHOVELER_16005482335483577091)],
        &[(0b01001, &ENTRY_SHOVELERS_9645466719000067881)],
        &[(0b00001, &ENTRY_SHOVELING_6097820986538846736)],
        &[(0b11010, &ENTRY_SHOVELED_10216188925046182061)],
        &[(0b11010, &ENTRY_SHOVELER_16005482335483577091)],
        &[(0b11010, &ENTRY_SHOVELERS_9645466719000067881)],
        &[(0b11010, &ENTRY_SHOVELING_6097820986538846736)],
        &[(0b11010, &ENTRY_SHERE_2828859166071306026)],
        &[(0b00001, &ENTRY_SHRIVELED_14279328409283350057)],
        &[(0b00001, &ENTRY_SHRIVELING_7338996136982496684)],
        &[(0b11010, &ENTRY_SHRIVELED_14279328409283350057)],
        &[(0b11010, &ENTRY_SHRIVELING_7338996136982496684)],
    ],
    range: 2..=12,
};

static VARS_SE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SE_CHILDREN),
    value: Some(&[
        (0b00001, &ENTRY_SE_11935408519795320676),
        (0b00001, &ENTRY_SE_7678721039302187964),
    ]),
};

static VARS_SE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_SEB_NODE),
    Some(&VARS_SEC_NODE),
    None,
    Some(&VARS_SEE_NODE),
    None,
    None,
    None,
    Some(&VARS_SEI_NODE),
    None,
    None,
    Some(&VARS_SEL_NODE),
    Some(&VARS_SEM_NODE),
    Some(&VARS_SEN_NODE),
    None,
    Some(&VARS_SEP_NODE),
    Some(&VARS_SEQ_NODE),
    Some(&VARS_SER_NODE),
    None,
    Some(&VARS_SET_NODE),
    None,
    Some(&VARS_SEV_NODE),
    None,
    Some(&VARS_SEX_NODE),
    None,
    None,
];

static VARS_SEX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEX_CHILDREN),
    value: None,
};

pub static VARS_SEX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEXUALIZATION_6593254506734364117)],
        &[(0b10010, &ENTRY_SEXUALIZATIONS_15890042718324864455)],
        &[(0b10010, &ENTRY_SEXUALIZE_17072767684675942947)],
        &[(0b10010, &ENTRY_SEXUALIZED_7233396045217103694)],
        &[(0b10010, &ENTRY_SEXUALIZES_17468618530381395484)],
        &[(0b10010, &ENTRY_SEXUALIZING_6218289575449577000)],
        &[(0b01001, &ENTRY_SEXUALIZATION_6593254506734364117)],
        &[(0b01001, &ENTRY_SEXUALIZATIONS_15890042718324864455)],
        &[(0b01001, &ENTRY_SEXUALIZE_17072767684675942947)],
        &[(0b01001, &ENTRY_SEXUALIZED_7233396045217103694)],
        &[(0b01001, &ENTRY_SEXUALIZES_17468618530381395484)],
        &[(0b01001, &ENTRY_SEXUALIZING_6218289575449577000)],
    ],
    range: 6..=11,
};

static VARS_SEV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEV_CHILDREN),
    value: None,
};

pub static VARS_SEV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEVERALIZE_14052775679136748529)],
        &[(0b10010, &ENTRY_SEVERALIZES_5073872488479172899)],
        &[(0b01001, &ENTRY_SEVERALIZE_14052775679136748529)],
        &[(0b01001, &ENTRY_SEVERALIZES_5073872488479172899)],
        &[(0b10010, &ENTRY_SEVERIZATION_1893546899787607297)],
        &[(0b10010, &ENTRY_SEVERIZATIONS_5864988201028711544)],
        &[(0b10010, &ENTRY_SEVERIZE_10295931794707417929)],
        &[(0b10010, &ENTRY_SEVERIZES_16060800636195176489)],
        &[(0b01001, &ENTRY_SEVERIZATION_1893546899787607297)],
        &[(0b01001, &ENTRY_SEVERIZATIONS_5864988201028711544)],
        &[(0b01001, &ENTRY_SEVERIZE_10295931794707417929)],
        &[(0b01001, &ENTRY_SEVERIZES_16060800636195176489)],
    ],
    range: 5..=10,
};

static VARS_SET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SET_CHILDREN),
    value: None,
};

pub static VARS_SET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SETA_4750865609556121705)],
        &[(0b11010, &ENTRY_SETULE_15910434941710819225)],
        &[(0b00001, &ENTRY_SETULE_15910434941710819225)],
    ],
    range: 1..=4,
};

static VARS_SER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SER_CHILDREN),
    value: None,
};

static VARS_SER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_SERE_NODE),
    None,
    None,
    None,
    Some(&VARS_SERI_NODE),
    None,
    None,
    None,
    Some(&VARS_SERM_NODE),
    None,
    Some(&VARS_SERO_NODE),
    Some(&VARS_SERP_NODE),
    None,
    Some(&VARS_SERR_NODE),
    None,
    None,
    None,
    Some(&VARS_SERV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_SERV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERV_CHILDREN),
    value: None,
};

pub static VARS_SERV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SERVILIZE_4512021424516865543)],
        &[(0b10010, &ENTRY_SERVILIZES_7385999730899631756)],
        &[(0b01001, &ENTRY_SERVILIZE_4512021424516865543)],
        &[(0b01001, &ENTRY_SERVILIZES_7385999730899631756)],
    ],
    range: 5..=6,
};

static VARS_SERR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERR_CHILDREN),
    value: None,
};

pub static VARS_SERR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SERRE_6762410384344039142)],
        &[(0b00001, &ENTRY_SERRE_6762410384344039142)],
    ],
    range: 1..=2,
};

static VARS_SERP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERP_CHILDREN),
    value: None,
};

pub static VARS_SERP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entinisation"),
        dictgen::InsensitiveStr::Ascii("entinisations"),
        dictgen::InsensitiveStr::Ascii("entinise"),
        dictgen::InsensitiveStr::Ascii("entinised"),
        dictgen::InsensitiveStr::Ascii("entinises"),
        dictgen::InsensitiveStr::Ascii("entinising"),
        dictgen::InsensitiveStr::Ascii("entinization"),
        dictgen::InsensitiveStr::Ascii("entinizations"),
        dictgen::InsensitiveStr::Ascii("entinize"),
        dictgen::InsensitiveStr::Ascii("entinized"),
        dictgen::InsensitiveStr::Ascii("entinizes"),
        dictgen::InsensitiveStr::Ascii("entinizing"),
        dictgen::InsensitiveStr::Ascii("entise"),
        dictgen::InsensitiveStr::Ascii("entised"),
        dictgen::InsensitiveStr::Ascii("entises"),
        dictgen::InsensitiveStr::Ascii("entising"),
        dictgen::InsensitiveStr::Ascii("entize"),
        dictgen::InsensitiveStr::Ascii("entized"),
        dictgen::InsensitiveStr::Ascii("entizes"),
        dictgen::InsensitiveStr::Ascii("entizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SERPENTINIZATION_9829957253632791760)],
        &[(0b10010, &ENTRY_SERPENTINIZATIONS_3391153694184367633)],
        &[(0b10010, &ENTRY_SERPENTINIZE_1811085745125406816)],
        &[(0b10010, &ENTRY_SERPENTINIZED_12473002222530130063)],
        &[(0b10010, &ENTRY_SERPENTINIZES_16474636750177010671)],
        &[(0b10010, &ENTRY_SERPENTINIZING_9060243995269023975)],
        &[(0b01001, &ENTRY_SERPENTINIZATION_9829957253632791760)],
        &[(0b01001, &ENTRY_SERPENTINIZATIONS_3391153694184367633)],
        &[(0b01001, &ENTRY_SERPENTINIZE_1811085745125406816)],
        &[(0b01001, &ENTRY_SERPENTINIZED_12473002222530130063)],
        &[(0b01001, &ENTRY_SERPENTINIZES_16474636750177010671)],
        &[(0b01001, &ENTRY_SERPENTINIZING_9060243995269023975)],
        &[(0b10010, &ENTRY_SERPENTIZE_9368493021913509820)],
        &[(0b10010, &ENTRY_SERPENTIZED_5901889149718624116)],
        &[(0b10010, &ENTRY_SERPENTIZES_15216974143628036729)],
        &[(0b10010, &ENTRY_SERPENTIZING_16905186458845868642)],
        &[(0b01001, &ENTRY_SERPENTIZE_9368493021913509820)],
        &[(0b01001, &ENTRY_SERPENTIZED_5901889149718624116)],
        &[(0b01001, &ENTRY_SERPENTIZES_15216974143628036729)],
        &[(0b01001, &ENTRY_SERPENTIZING_16905186458845868642)],
    ],
    range: 6..=13,
};

static VARS_SERO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERO_CHILDREN),
    value: None,
};

pub static VARS_SERO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sae"),
        dictgen::InsensitiveStr::Ascii("se"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SEROSE_15041909330080212209)],
        &[(0b00001, &ENTRY_SEROSE_15041909330080212209)],
    ],
    range: 2..=3,
};

static VARS_SERM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERM_CHILDREN),
    value: None,
};

pub static VARS_SERM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniser"),
        dictgen::InsensitiveStr::Ascii("onisers"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizer"),
        dictgen::InsensitiveStr::Ascii("onizers"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SERMONIZE_18313527686432697628)],
        &[(0b10010, &ENTRY_SERMONIZED_16528095817328710811)],
        &[(0b10010, &ENTRY_SERMONIZER_16673411385474735084)],
        &[(0b10010, &ENTRY_SERMONIZERS_8038249026909210325)],
        &[(0b10010, &ENTRY_SERMONIZES_6019643563928317531)],
        &[(0b10010, &ENTRY_SERMONIZING_11733933952570021776)],
        &[(0b01001, &ENTRY_SERMONIZE_18313527686432697628)],
        &[(0b01001, &ENTRY_SERMONIZED_16528095817328710811)],
        &[(0b01001, &ENTRY_SERMONIZER_16673411385474735084)],
        &[(0b01001, &ENTRY_SERMONIZERS_8038249026909210325)],
        &[(0b01001, &ENTRY_SERMONIZES_6019643563928317531)],
        &[(0b01001, &ENTRY_SERMONIZING_11733933952570021776)],
    ],
    range: 5..=7,
};

static VARS_SERI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERI_CHILDREN),
    value: None,
};

pub static VARS_SERI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisability"),
        dictgen::InsensitiveStr::Ascii("alisable"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alizability"),
        dictgen::InsensitiveStr::Ascii("alizable"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("citisation"),
        dictgen::InsensitiveStr::Ascii("citisations"),
        dictgen::InsensitiveStr::Ascii("citization"),
        dictgen::InsensitiveStr::Ascii("citizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SERIALIZABILITY_2901340955314747428)],
        &[(0b10010, &ENTRY_SERIALIZABLE_14197036745650348974)],
        &[(0b10010, &ENTRY_SERIALIZATION_9018956433699872037)],
        &[(0b10010, &ENTRY_SERIALIZATIONS_706918596756843003)],
        &[(0b10010, &ENTRY_SERIALIZE_14877336825166275236)],
        &[(0b10010, &ENTRY_SERIALIZED_8728958192744003140)],
        &[(0b10010, &ENTRY_SERIALIZES_3430793096929337696)],
        &[(0b10010, &ENTRY_SERIALIZING_2676257449327141209)],
        &[(0b01001, &ENTRY_SERIALIZABILITY_2901340955314747428)],
        &[(0b01001, &ENTRY_SERIALIZABLE_14197036745650348974)],
        &[(0b01001, &ENTRY_SERIALIZATION_9018956433699872037)],
        &[(0b01001, &ENTRY_SERIALIZATIONS_706918596756843003)],
        &[(0b01001, &ENTRY_SERIALIZE_14877336825166275236)],
        &[(0b01001, &ENTRY_SERIALIZED_8728958192744003140)],
        &[(0b01001, &ENTRY_SERIALIZES_3430793096929337696)],
        &[(0b01001, &ENTRY_SERIALIZING_2676257449327141209)],
        &[(0b10010, &ENTRY_SERICITIZATION_6928797851395804305)],
        &[(0b10010, &ENTRY_SERICITIZATIONS_5772088053388220545)],
        &[(0b01001, &ENTRY_SERICITIZATION_6928797851395804305)],
        &[(0b01001, &ENTRY_SERICITIZATIONS_5772088053388220545)],
    ],
    range: 5..=11,
};

static VARS_SERE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERE_CHILDREN),
    value: None,
};

pub static VARS_SERE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SERENIZE_12001453234621020080)],
        &[(0b10010, &ENTRY_SERENIZES_14020572670898554700)],
        &[(0b01001, &ENTRY_SERENIZE_12001453234621020080)],
        &[(0b01001, &ENTRY_SERENIZES_14020572670898554700)],
    ],
    range: 4..=5,
};

static VARS_SEQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEQ_CHILDREN),
    value: None,
};

pub static VARS_SEQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uentialise"),
        dictgen::InsensitiveStr::Ascii("uentialised"),
        dictgen::InsensitiveStr::Ascii("uentialises"),
        dictgen::InsensitiveStr::Ascii("uentialising"),
        dictgen::InsensitiveStr::Ascii("uentialize"),
        dictgen::InsensitiveStr::Ascii("uentialized"),
        dictgen::InsensitiveStr::Ascii("uentializes"),
        dictgen::InsensitiveStr::Ascii("uentializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEQUENTIALIZE_4889381684174254167)],
        &[(0b10010, &ENTRY_SEQUENTIALIZED_5743547481042663813)],
        &[(0b10010, &ENTRY_SEQUENTIALIZES_6402661231343709343)],
        &[(0b10010, &ENTRY_SEQUENTIALIZING_10448549330716259346)],
        &[(0b01001, &ENTRY_SEQUENTIALIZE_4889381684174254167)],
        &[(0b01001, &ENTRY_SEQUENTIALIZED_5743547481042663813)],
        &[(0b01001, &ENTRY_SEQUENTIALIZES_6402661231343709343)],
        &[(0b01001, &ENTRY_SEQUENTIALIZING_10448549330716259346)],
    ],
    range: 10..=12,
};

static VARS_SEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEP_CHILDREN),
    value: None,
};

pub static VARS_SEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aled"),
        dictgen::InsensitiveStr::Ascii("aledder"),
        dictgen::InsensitiveStr::Ascii("aleddest"),
        dictgen::InsensitiveStr::Ascii("alled"),
        dictgen::InsensitiveStr::Ascii("alledder"),
        dictgen::InsensitiveStr::Ascii("alleddest"),
        dictgen::InsensitiveStr::Ascii("taemia"),
        dictgen::InsensitiveStr::Ascii("tembriser"),
        dictgen::InsensitiveStr::Ascii("tembrisers"),
        dictgen::InsensitiveStr::Ascii("tembrizer"),
        dictgen::InsensitiveStr::Ascii("tembrizers"),
        dictgen::InsensitiveStr::Ascii("temia"),
        dictgen::InsensitiveStr::Ascii("ticaemia"),
        dictgen::InsensitiveStr::Ascii("ticaemias"),
        dictgen::InsensitiveStr::Ascii("ticaemic"),
        dictgen::InsensitiveStr::Ascii("ticemia"),
        dictgen::InsensitiveStr::Ascii("ticemias"),
        dictgen::InsensitiveStr::Ascii("ticemic"),
        dictgen::InsensitiveStr::Ascii("ticisation"),
        dictgen::InsensitiveStr::Ascii("ticisations"),
        dictgen::InsensitiveStr::Ascii("ticization"),
        dictgen::InsensitiveStr::Ascii("ticizations"),
        dictgen::InsensitiveStr::Ascii("ticolored"),
        dictgen::InsensitiveStr::Ascii("ticoloured"),
        dictgen::InsensitiveStr::Ascii("ulcher"),
        dictgen::InsensitiveStr::Ascii("ulchered"),
        dictgen::InsensitiveStr::Ascii("ulchering"),
        dictgen::InsensitiveStr::Ascii("ulchers"),
        dictgen::InsensitiveStr::Ascii("ulchralise"),
        dictgen::InsensitiveStr::Ascii("ulchralises"),
        dictgen::InsensitiveStr::Ascii("ulchralize"),
        dictgen::InsensitiveStr::Ascii("ulchralizes"),
        dictgen::InsensitiveStr::Ascii("ulchre"),
        dictgen::InsensitiveStr::Ascii("ulchred"),
        dictgen::InsensitiveStr::Ascii("ulchres"),
        dictgen::InsensitiveStr::Ascii("ulchring"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SEPALED_15484596063198794816)],
        &[(0b00001, &ENTRY_SEPALEDDER_6673085543385038929)],
        &[(0b00001, &ENTRY_SEPALEDDEST_12097552973541005872)],
        &[(0b11010, &ENTRY_SEPALED_15484596063198794816)],
        &[(0b11010, &ENTRY_SEPALEDDER_6673085543385038929)],
        &[(0b11010, &ENTRY_SEPALEDDEST_12097552973541005872)],
        &[(0b11010, &ENTRY_SEPTEMIA_9642046550000795259)],
        &[(0b10010, &ENTRY_SEPTEMBRIZER_16399780356335894385)],
        &[(0b10010, &ENTRY_SEPTEMBRIZERS_10748414663128787013)],
        &[(0b01001, &ENTRY_SEPTEMBRIZER_16399780356335894385)],
        &[(0b01001, &ENTRY_SEPTEMBRIZERS_10748414663128787013)],
        &[(0b00001, &ENTRY_SEPTEMIA_9642046550000795259)],
        &[(0b10010, &ENTRY_SEPTICEMIA_15776803637197261182)],
        &[(0b10010, &ENTRY_SEPTICEMIAS_8755899979809830376)],
        &[(0b10010, &ENTRY_SEPTICEMIC_16980008368837900987)],
        &[(0b01001, &ENTRY_SEPTICEMIA_15776803637197261182)],
        &[(0b01001, &ENTRY_SEPTICEMIAS_8755899979809830376)],
        &[(0b01001, &ENTRY_SEPTICEMIC_16980008368837900987)],
        &[(0b10010, &ENTRY_SEPTICIZATION_3461417299775827388)],
        &[(0b10010, &ENTRY_SEPTICIZATIONS_13575411557314464650)],
        &[(0b01001, &ENTRY_SEPTICIZATION_3461417299775827388)],
        &[(0b01001, &ENTRY_SEPTICIZATIONS_13575411557314464650)],
        &[(0b00001, &ENTRY_SEPTICOLORED_11519724559149837993)],
        &[(0b11010, &ENTRY_SEPTICOLORED_11519724559149837993)],
        &[(0b00001, &ENTRY_SEPULCHER_18098224318037396545)],
        &[(0b00001, &ENTRY_SEPULCHERED_6261011539804735837)],
        &[(0b00001, &ENTRY_SEPULCHERING_13256373528547912718)],
        &[(0b00001, &ENTRY_SEPULCHERS_1058787016282390839)],
        &[(0b10010, &ENTRY_SEPULCHRALIZE_3486930743664728261)],
        &[(0b10010, &ENTRY_SEPULCHRALIZES_1315744044961412030)],
        &[(0b01001, &ENTRY_SEPULCHRALIZE_3486930743664728261)],
        &[(0b01001, &ENTRY_SEPULCHRALIZES_1315744044961412030)],
        &[(0b11010, &ENTRY_SEPULCHER_18098224318037396545)],
        &[(0b11010, &ENTRY_SEPULCHERED_6261011539804735837)],
        &[(0b11010, &ENTRY_SEPULCHERS_1058787016282390839)],
        &[(0b11010, &ENTRY_SEPULCHERING_13256373528547912718)],
    ],
    range: 4..=11,
};

static VARS_SEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SEN_CHILDREN),
    value: None,
};

static VARS_SEN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SENI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SENS_NODE),
    Some(&VARS_SENT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SENT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SENT_CHILDREN),
    value: None,
};

pub static VARS_SENT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("imentalisation"),
        dictgen::InsensitiveStr::Ascii("imentalisations"),
        dictgen::InsensitiveStr::Ascii("imentalise"),
        dictgen::InsensitiveStr::Ascii("imentalised"),
        dictgen::InsensitiveStr::Ascii("imentaliser"),
        dictgen::InsensitiveStr::Ascii("imentalisers"),
        dictgen::InsensitiveStr::Ascii("imentalises"),
        dictgen::InsensitiveStr::Ascii("imentalising"),
        dictgen::InsensitiveStr::Ascii("imentalization"),
        dictgen::InsensitiveStr::Ascii("imentalizations"),
        dictgen::InsensitiveStr::Ascii("imentalize"),
        dictgen::InsensitiveStr::Ascii("imentalized"),
        dictgen::InsensitiveStr::Ascii("imentalizer"),
        dictgen::InsensitiveStr::Ascii("imentalizers"),
        dictgen::InsensitiveStr::Ascii("imentalizes"),
        dictgen::InsensitiveStr::Ascii("imentalizing"),
        dictgen::InsensitiveStr::Ascii("ineled"),
        dictgen::InsensitiveStr::Ascii("ineling"),
        dictgen::InsensitiveStr::Ascii("inelled"),
        dictgen::InsensitiveStr::Ascii("inelling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SENTIMENTALIZATION_5296627102104537727)],
        &[(0b10010, &ENTRY_SENTIMENTALIZATIONS_13391940016403046982)],
        &[(0b10010, &ENTRY_SENTIMENTALIZE_12182871308532479588)],
        &[(0b10010, &ENTRY_SENTIMENTALIZED_16225167419707712005)],
        &[(0b10010, &ENTRY_SENTIMENTALIZER_4660675232906083328)],
        &[(0b10010, &ENTRY_SENTIMENTALIZERS_13129655732030104575)],
        &[(0b10010, &ENTRY_SENTIMENTALIZES_16806348349169501348)],
        &[(0b10010, &ENTRY_SENTIMENTALIZING_5876768100471681381)],
        &[(0b01001, &ENTRY_SENTIMENTALIZATION_5296627102104537727)],
        &[(0b01001, &ENTRY_SENTIMENTALIZATIONS_13391940016403046982)],
        &[(0b01001, &ENTRY_SENTIMENTALIZE_12182871308532479588)],
        &[(0b01001, &ENTRY_SENTIMENTALIZED_16225167419707712005)],
        &[(0b01001, &ENTRY_SENTIMENTALIZER_4660675232906083328)],
        &[(0b01001, &ENTRY_SENTIMENTALIZERS_13129655732030104575)],
        &[(0b01001, &ENTRY_SENTIMENTALIZES_16806348349169501348)],
        &[(0b01001, &ENTRY_SENTIMENTALIZING_5876768100471681381)],
        &[(0b00001, &ENTRY_SENTINELED_6442518344888461295)],
        &[(0b00001, &ENTRY_SENTINELING_14720322458455305272)],
        &[(0b11010, &ENTRY_SENTINELED_6442518344888461295)],
        &[(0b11010, &ENTRY_SENTINELING_14720322458455305272)],
    ],
    range: 6..=15,
};

static VARS_SENS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SENS_CHILDREN),
    value: None,
};

pub static VARS_SENS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ationalise"),
        dictgen::InsensitiveStr::Ascii("ationalised"),
        dictgen::InsensitiveStr::Ascii("ationalises"),
        dictgen::InsensitiveStr::Ascii("ationalising"),
        dictgen::InsensitiveStr::Ascii("ationalize"),
        dictgen::InsensitiveStr::Ascii("ationalized"),
        dictgen::InsensitiveStr::Ascii("ationalizes"),
        dictgen::InsensitiveStr::Ascii("ationalizing"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("itisation"),
        dictgen::InsensitiveStr::Ascii("itisations"),
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itiser"),
        dictgen::InsensitiveStr::Ascii("itisers"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itization"),
        dictgen::InsensitiveStr::Ascii("itizations"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizer"),
        dictgen::InsensitiveStr::Ascii("itizers"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SENSATIONALIZE_4701218119855164579)],
        &[(0b10010, &ENTRY_SENSATIONALIZED_806729255320749316)],
        &[(0b10010, &ENTRY_SENSATIONALIZES_1873975152603613564)],
        &[(0b10010, &ENTRY_SENSATIONALIZING_16018544793631553710)],
        &[(0b01001, &ENTRY_SENSATIONALIZE_4701218119855164579)],
        &[(0b01001, &ENTRY_SENSATIONALIZED_806729255320749316)],
        &[(0b01001, &ENTRY_SENSATIONALIZES_1873975152603613564)],
        &[(0b01001, &ENTRY_SENSATIONALIZING_16018544793631553710)],
        &[(0b10010, &ENTRY_SENSIZE_8524073416014383146)],
        &[(0b10010, &ENTRY_SENSIZES_14356006171802679244)],
        &[(0b10010, &ENTRY_SENSITIZATION_17980445782706254952)],
        &[(0b10010, &ENTRY_SENSITIZATIONS_3771550480827878176)],
        &[(0b10010, &ENTRY_SENSITIZE_16896529045122621888)],
        &[(0b10010, &ENTRY_SENSITIZED_3723688270446372923)],
        &[(0b10010, &ENTRY_SENSITIZER_13590195476574032900)],
        &[(0b10010, &ENTRY_SENSITIZERS_837347902048952541)],
        &[(0b10010, &ENTRY_SENSITIZES_1732547089436557908)],
        &[(0b10010, &ENTRY_SENSITIZING_2002820405955253385)],
        &[(0b01001, &ENTRY_SENSITIZATION_17980445782706254952)],
        &[(0b01001, &ENTRY_SENSITIZATIONS_3771550480827878176)],
        &[(0b01001, &ENTRY_SENSITIZE_16896529045122621888)],
        &[(0b01001, &ENTRY_SENSITIZED_3723688270446372923)],
        &[(0b01001, &ENTRY_SENSITIZER_13590195476574032900)],
        &[(0b01001, &ENTRY_SENSITIZERS_837347902048952541)],
        &[(0b01001, &ENTRY_SENSITIZES_1732547089436557908)],
        &[(0b01001, &ENTRY_SENSITIZING_2002820405955253385)],
        &[(0b01001, &ENTRY_SENSIZE_8524073416014383146)],
        &[(0b01001, &ENTRY_SENSIZES_14356006171802679244)],
        &[(0b10010, &ENTRY_SENSUALIZATION_1493652745290082889)],
        &[(0b10010, &ENTRY_SENSUALIZATIONS_5360556874155531727)],
        &[(0b10010, &ENTRY_SENSUALIZE_430137685449901167)],
        &[(0b10010, &ENTRY_SENSUALIZED_5037909159991545251)],
        &[(0b10010, &ENTRY_SENSUALIZES_276828862031219211)],
        &[(0b10010, &ENTRY_SENSUALIZING_5522084897844086892)],
        &[(0b01001, &ENTRY_SENSUALIZATION_1493652745290082889)],
        &[(0b01001, &ENTRY_SENSUALIZATIONS_5360556874155531727)],
        &[(0b01001, &ENTRY_SENSUALIZE_430137685449901167)],
        &[(0b01001, &ENTRY_SENSUALIZED_5037909159991545251)],
        &[(0b01001, &ENTRY_SENSUALIZES_276828862031219211)],
        &[(0b01001, &ENTRY_SENSUALIZING_5522084897844086892)],
    ],
    range: 3..=12,
};

static VARS_SENI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SENI_CHILDREN),
    value: None,
};

pub static VARS_SENI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SENILIZE_12369499446345492928)],
        &[(0b10010, &ENTRY_SENILIZES_2053465569367189725)],
        &[(0b01001, &ENTRY_SENILIZE_12369499446345492928)],
        &[(0b01001, &ENTRY_SENILIZES_2053465569367189725)],
    ],
    range: 4..=5,
};

static VARS_SEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SEM_CHILDREN),
    value: None,
};

static VARS_SEM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SEMA_NODE),
    None,
    None,
    None,
    Some(&VARS_SEME_NODE),
    None,
    None,
    None,
    Some(&VARS_SEMI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SEMP_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SEMP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMP_CHILDREN),
    value: None,
};

pub static VARS_SEMP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SEMPER_10634656891860887703)],
        &[(0b11010, &ENTRY_SEMPER_10634656891860887703)],
    ],
    range: 2..=2,
};

static VARS_SEMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SEMI_CHILDREN),
    value: None,
};

static VARS_SEMI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SEMIA_NODE),
    None,
    Some(&VARS_SEMIC_NODE),
    None,
    None,
    Some(&VARS_SEMIF_NODE),
    None,
    Some(&VARS_SEMIH_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_SEMIM_NODE),
    Some(&VARS_SEMIN_NODE),
    Some(&VARS_SEMIO_NODE),
    Some(&VARS_SEMIP_NODE),
    None,
    None,
    None,
    Some(&VARS_SEMIT_NODE),
    None,
    Some(&VARS_SEMIV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_SEMIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIV_CHILDREN),
    value: None,
};

pub static VARS_SEMIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ulcanised"),
        dictgen::InsensitiveStr::Ascii("ulcaniseds"),
        dictgen::InsensitiveStr::Ascii("ulcanized"),
        dictgen::InsensitiveStr::Ascii("ulcanizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMIVULCANIZED_282808961308474752)],
        &[(0b10010, &ENTRY_SEMIVULCANIZEDS_8588430062086262347)],
        &[(0b01001, &ENTRY_SEMIVULCANIZED_282808961308474752)],
        &[(0b01001, &ENTRY_SEMIVULCANIZEDS_8588430062086262347)],
    ],
    range: 9..=10,
};

static VARS_SEMIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIT_CHILDREN),
    value: None,
};

pub static VARS_SEMIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SEMITE_11088742112426344288)],
        &[(0b00001, &ENTRY_SEMITE_11088742112426344288)],
        &[(0b10010, &ENTRY_SEMITICIZE_14062898150721821296)],
        &[(0b10010, &ENTRY_SEMITICIZES_1495676230430654195)],
        &[(0b01001, &ENTRY_SEMITICIZE_14062898150721821296)],
        &[(0b01001, &ENTRY_SEMITICIZES_1495676230430654195)],
        &[(0b10010, &ENTRY_SEMITIZATION_8277205050971024513)],
        &[(0b10010, &ENTRY_SEMITIZATIONS_12431457653239318845)],
        &[(0b10010, &ENTRY_SEMITIZE_8166397051897052089)],
        &[(0b10010, &ENTRY_SEMITIZED_11743352918617854492)],
        &[(0b10010, &ENTRY_SEMITIZES_6676886808639923004)],
        &[(0b10010, &ENTRY_SEMITIZING_8744181270211508639)],
        &[(0b01001, &ENTRY_SEMITIZATION_8277205050971024513)],
        &[(0b01001, &ENTRY_SEMITIZATIONS_12431457653239318845)],
        &[(0b01001, &ENTRY_SEMITIZE_8166397051897052089)],
        &[(0b01001, &ENTRY_SEMITIZED_11743352918617854492)],
        &[(0b01001, &ENTRY_SEMITIZES_6676886808639923004)],
        &[(0b01001, &ENTRY_SEMITIZING_8744181270211508639)],
    ],
    range: 1..=8,
};

static VARS_SEMIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIP_CHILDREN),
    value: None,
};

pub static VARS_SEMIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rofessionalised"),
        dictgen::InsensitiveStr::Ascii("rofessionaliseds"),
        dictgen::InsensitiveStr::Ascii("rofessionalized"),
        dictgen::InsensitiveStr::Ascii("rofessionalizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMIPROFESSIONALIZED_928014397042474559)],
        &[(0b10010, &ENTRY_SEMIPROFESSIONALIZEDS_5400190535233560894)],
        &[(0b01001, &ENTRY_SEMIPROFESSIONALIZED_928014397042474559)],
        &[(0b01001, &ENTRY_SEMIPROFESSIONALIZEDS_5400190535233560894)],
    ],
    range: 15..=16,
};

static VARS_SEMIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIO_CHILDREN),
    value: None,
};

pub static VARS_SEMIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rganised"),
        dictgen::InsensitiveStr::Ascii("rganiseds"),
        dictgen::InsensitiveStr::Ascii("rganized"),
        dictgen::InsensitiveStr::Ascii("rganizeds"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidiseds"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizeds"),
        dictgen::InsensitiveStr::Ascii("xygenised"),
        dictgen::InsensitiveStr::Ascii("xygeniseds"),
        dictgen::InsensitiveStr::Ascii("xygenized"),
        dictgen::InsensitiveStr::Ascii("xygenizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMIORGANIZED_18310435920283296471)],
        &[(0b10010, &ENTRY_SEMIORGANIZEDS_16199433115149437804)],
        &[(0b01001, &ENTRY_SEMIORGANIZED_18310435920283296471)],
        &[(0b01001, &ENTRY_SEMIORGANIZEDS_16199433115149437804)],
        &[(0b10010, &ENTRY_SEMIOXIDIZED_2254782022495988687)],
        &[(0b10010, &ENTRY_SEMIOXIDIZEDS_10078920474925941546)],
        &[(0b01001, &ENTRY_SEMIOXIDIZED_2254782022495988687)],
        &[(0b01001, &ENTRY_SEMIOXIDIZEDS_10078920474925941546)],
        &[(0b10010, &ENTRY_SEMIOXYGENIZED_15102443189044001018)],
        &[(0b10010, &ENTRY_SEMIOXYGENIZEDS_3977169223060896833)],
        &[(0b01001, &ENTRY_SEMIOXYGENIZED_15102443189044001018)],
        &[(0b01001, &ENTRY_SEMIOXYGENIZEDS_3977169223060896833)],
    ],
    range: 7..=10,
};

static VARS_SEMIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIN_CHILDREN),
    value: None,
};

pub static VARS_SEMIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("ationalisation"),
        dictgen::InsensitiveStr::Ascii("ationalisations"),
        dictgen::InsensitiveStr::Ascii("ationalization"),
        dictgen::InsensitiveStr::Ascii("ationalizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMINARIZE_5202720038995798338)],
        &[(0b10010, &ENTRY_SEMINARIZES_16026061575781055708)],
        &[(0b01001, &ENTRY_SEMINARIZE_5202720038995798338)],
        &[(0b01001, &ENTRY_SEMINARIZES_16026061575781055708)],
        &[(0b10010, &ENTRY_SEMINATIONALIZATION_825484772724238043)],
        &[(0b10010, &ENTRY_SEMINATIONALIZATIONS_1834004725503573613)],
        &[(0b01001, &ENTRY_SEMINATIONALIZATION_825484772724238043)],
        &[(0b01001, &ENTRY_SEMINATIONALIZATIONS_1834004725503573613)],
    ],
    range: 5..=15,
};

static VARS_SEMIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIM_CHILDREN),
    value: None,
};

pub static VARS_SEMIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ercerised"),
        dictgen::InsensitiveStr::Ascii("erceriseds"),
        dictgen::InsensitiveStr::Ascii("ercerized"),
        dictgen::InsensitiveStr::Ascii("ercerizeds"),
        dictgen::InsensitiveStr::Ascii("ineralised"),
        dictgen::InsensitiveStr::Ascii("ineraliseds"),
        dictgen::InsensitiveStr::Ascii("ineralized"),
        dictgen::InsensitiveStr::Ascii("ineralizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMIMERCERIZED_9589423828734279207)],
        &[(0b10010, &ENTRY_SEMIMERCERIZEDS_8976044764636489500)],
        &[(0b01001, &ENTRY_SEMIMERCERIZED_9589423828734279207)],
        &[(0b01001, &ENTRY_SEMIMERCERIZEDS_8976044764636489500)],
        &[(0b10010, &ENTRY_SEMIMINERALIZED_7730798044526104284)],
        &[(0b10010, &ENTRY_SEMIMINERALIZEDS_10516461058680893657)],
        &[(0b01001, &ENTRY_SEMIMINERALIZED_7730798044526104284)],
        &[(0b01001, &ENTRY_SEMIMINERALIZEDS_10516461058680893657)],
    ],
    range: 9..=11,
};

static VARS_SEMIH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIH_CHILDREN),
    value: None,
};

pub static VARS_SEMIH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onor"),
        dictgen::InsensitiveStr::Ascii("onors"),
        dictgen::InsensitiveStr::Ascii("onour"),
        dictgen::InsensitiveStr::Ascii("onours"),
        dictgen::InsensitiveStr::Ascii("umanised"),
        dictgen::InsensitiveStr::Ascii("umaniseds"),
        dictgen::InsensitiveStr::Ascii("umanized"),
        dictgen::InsensitiveStr::Ascii("umanizeds"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SEMIHONOR_15368829156943900844)],
        &[(0b00001, &ENTRY_SEMIHONORS_17348811193976953216)],
        &[(0b11010, &ENTRY_SEMIHONOR_15368829156943900844)],
        &[(0b11010, &ENTRY_SEMIHONORS_17348811193976953216)],
        &[(0b10010, &ENTRY_SEMIHUMANIZED_2914623020115279300)],
        &[(0b10010, &ENTRY_SEMIHUMANIZEDS_8011721709170453644)],
        &[(0b01001, &ENTRY_SEMIHUMANIZED_2914623020115279300)],
        &[(0b01001, &ENTRY_SEMIHUMANIZEDS_8011721709170453644)],
    ],
    range: 4..=9,
};

static VARS_SEMIF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIF_CHILDREN),
    value: None,
};

pub static VARS_SEMIF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ossilised"),
        dictgen::InsensitiveStr::Ascii("ossiliseds"),
        dictgen::InsensitiveStr::Ascii("ossilized"),
        dictgen::InsensitiveStr::Ascii("ossilizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMIFOSSILIZED_3016621275622865217)],
        &[(0b10010, &ENTRY_SEMIFOSSILIZEDS_9469407920545194818)],
        &[(0b01001, &ENTRY_SEMIFOSSILIZED_3016621275622865217)],
        &[(0b01001, &ENTRY_SEMIFOSSILIZEDS_9469407920545194818)],
    ],
    range: 9..=10,
};

static VARS_SEMIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIC_CHILDREN),
    value: None,
};

pub static VARS_SEMIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arbonise"),
        dictgen::InsensitiveStr::Ascii("arbonises"),
        dictgen::InsensitiveStr::Ascii("arbonize"),
        dictgen::InsensitiveStr::Ascii("arbonizes"),
        dictgen::InsensitiveStr::Ascii("ivilisation"),
        dictgen::InsensitiveStr::Ascii("ivilisations"),
        dictgen::InsensitiveStr::Ascii("ivilised"),
        dictgen::InsensitiveStr::Ascii("iviliseds"),
        dictgen::InsensitiveStr::Ascii("ivilization"),
        dictgen::InsensitiveStr::Ascii("ivilizations"),
        dictgen::InsensitiveStr::Ascii("ivilized"),
        dictgen::InsensitiveStr::Ascii("ivilizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMICARBONIZE_13810009207773718216)],
        &[(0b10010, &ENTRY_SEMICARBONIZES_3707173180511878930)],
        &[(0b01001, &ENTRY_SEMICARBONIZE_13810009207773718216)],
        &[(0b01001, &ENTRY_SEMICARBONIZES_3707173180511878930)],
        &[(0b10010, &ENTRY_SEMICIVILIZATION_13989863526603166121)],
        &[(0b10010, &ENTRY_SEMICIVILIZATIONS_7291536769974182399)],
        &[(0b10010, &ENTRY_SEMICIVILIZED_15979322498261290823)],
        &[(0b10010, &ENTRY_SEMICIVILIZEDS_623045016921370057)],
        &[(0b01001, &ENTRY_SEMICIVILIZATION_13989863526603166121)],
        &[(0b01001, &ENTRY_SEMICIVILIZATIONS_7291536769974182399)],
        &[(0b01001, &ENTRY_SEMICIVILIZED_15979322498261290823)],
        &[(0b01001, &ENTRY_SEMICIVILIZEDS_623045016921370057)],
    ],
    range: 8..=12,
};

static VARS_SEMIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIA_CHILDREN),
    value: None,
};

pub static VARS_SEMIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("naesthetic"),
        dictgen::InsensitiveStr::Ascii("nesthetic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SEMIANESTHETIC_823301937707971043)],
        &[(0b00001, &ENTRY_SEMIANESTHETIC_823301937707971043)],
    ],
    range: 9..=10,
};

static VARS_SEME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEME_CHILDREN),
    value: None,
};

pub static VARS_SEME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("nov")],
    values: &[&[(0b00001, &ENTRY_SEMENOV_14619117840146490347)]],
    range: 3..=3,
};

static VARS_SEMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMA_CHILDREN),
    value: None,
};

pub static VARS_SEMA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("enov")],
    values: &[&[(0b11010, &ENTRY_SEMENOV_14619117840146490347)]],
    range: 4..=4,
};

static VARS_SEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEL_CHILDREN),
    value: None,
};

pub static VARS_SEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lae"),
        dictgen::InsensitiveStr::Ascii("le"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SELLE_11301556179355309569)],
        &[(0b00001, &ENTRY_SELLE_11301556179355309569)],
    ],
    range: 2..=3,
};

static VARS_SEI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEI_CHILDREN),
    value: None,
};

pub static VARS_SEI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sable"),
        dictgen::InsensitiveStr::Ascii("ser"),
        dictgen::InsensitiveStr::Ascii("sers"),
        dictgen::InsensitiveStr::Ascii("sin"),
        dictgen::InsensitiveStr::Ascii("sings"),
        dictgen::InsensitiveStr::Ascii("sins"),
        dictgen::InsensitiveStr::Ascii("zable"),
        dictgen::InsensitiveStr::Ascii("zer"),
        dictgen::InsensitiveStr::Ascii("zers"),
        dictgen::InsensitiveStr::Ascii("zin"),
        dictgen::InsensitiveStr::Ascii("zings"),
        dictgen::InsensitiveStr::Ascii("zins"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEIZABLE_1855846888387564832)],
        &[(0b10010, &ENTRY_SEIZER_9955492685377349774)],
        &[(0b10010, &ENTRY_SEIZERS_7950705537771035669)],
        &[(0b10010, &ENTRY_SEIZIN_6525758187177594826)],
        &[(0b10010, &ENTRY_SEIZINGS_13728841224695757549)],
        &[(0b10010, &ENTRY_SEIZINS_14830746986050367965)],
        &[(0b01001, &ENTRY_SEIZABLE_1855846888387564832)],
        &[(0b01001, &ENTRY_SEIZER_9955492685377349774)],
        &[(0b01001, &ENTRY_SEIZERS_7950705537771035669)],
        &[(0b01001, &ENTRY_SEIZIN_6525758187177594826)],
        &[(0b01001, &ENTRY_SEIZINGS_13728841224695757549)],
        &[(0b01001, &ENTRY_SEIZINS_14830746986050367965)],
    ],
    range: 3..=5,
};

static VARS_SEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEE_CHILDREN),
    value: None,
};

pub static VARS_SEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("d")],
    values: &[&[(0b00001, &ENTRY_SEED_14453242621235594627)]],
    range: 1..=1,
};

static VARS_SEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SEC_CHILDREN),
    value: None,
};

static VARS_SEC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SECT_NODE),
    Some(&VARS_SECU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_SECU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SECU_CHILDREN),
    value: None,
};

pub static VARS_SECU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("larisation"),
        dictgen::InsensitiveStr::Ascii("larisations"),
        dictgen::InsensitiveStr::Ascii("larise"),
        dictgen::InsensitiveStr::Ascii("larised"),
        dictgen::InsensitiveStr::Ascii("lariser"),
        dictgen::InsensitiveStr::Ascii("larisers"),
        dictgen::InsensitiveStr::Ascii("larises"),
        dictgen::InsensitiveStr::Ascii("larising"),
        dictgen::InsensitiveStr::Ascii("larization"),
        dictgen::InsensitiveStr::Ascii("larizations"),
        dictgen::InsensitiveStr::Ascii("larize"),
        dictgen::InsensitiveStr::Ascii("larized"),
        dictgen::InsensitiveStr::Ascii("larizer"),
        dictgen::InsensitiveStr::Ascii("larizers"),
        dictgen::InsensitiveStr::Ascii("larizes"),
        dictgen::InsensitiveStr::Ascii("larizing"),
        dictgen::InsensitiveStr::Ascii("lum"),
        dictgen::InsensitiveStr::Ascii("lums"),
        dictgen::InsensitiveStr::Ascii("ritisation"),
        dictgen::InsensitiveStr::Ascii("ritisations"),
        dictgen::InsensitiveStr::Ascii("ritise"),
        dictgen::InsensitiveStr::Ascii("ritised"),
        dictgen::InsensitiveStr::Ascii("ritises"),
        dictgen::InsensitiveStr::Ascii("ritising"),
        dictgen::InsensitiveStr::Ascii("ritization"),
        dictgen::InsensitiveStr::Ascii("ritizations"),
        dictgen::InsensitiveStr::Ascii("ritize"),
        dictgen::InsensitiveStr::Ascii("ritized"),
        dictgen::InsensitiveStr::Ascii("ritizes"),
        dictgen::InsensitiveStr::Ascii("ritizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SECULARIZATION_1401194994331432655)],
        &[(0b10010, &ENTRY_SECULARIZATIONS_4846586083503105748)],
        &[(0b10010, &ENTRY_SECULARIZE_7264705334185351711)],
        &[(0b10010, &ENTRY_SECULARIZED_161249998284362054)],
        &[(0b10010, &ENTRY_SECULARIZER_703425234980326759)],
        &[(0b10010, &ENTRY_SECULARIZERS_12036202493887613006)],
        &[(0b10010, &ENTRY_SECULARIZES_14861150832754880137)],
        &[(0b10010, &ENTRY_SECULARIZING_13366387235044393553)],
        &[(0b01001, &ENTRY_SECULARIZATION_1401194994331432655)],
        &[(0b01001, &ENTRY_SECULARIZATIONS_4846586083503105748)],
        &[(0b01001, &ENTRY_SECULARIZE_7264705334185351711)],
        &[(0b01001, &ENTRY_SECULARIZED_161249998284362054)],
        &[(0b01001, &ENTRY_SECULARIZER_703425234980326759)],
        &[(0b01001, &ENTRY_SECULARIZERS_12036202493887613006)],
        &[(0b01001, &ENTRY_SECULARIZES_14861150832754880137)],
        &[(0b01001, &ENTRY_SECULARIZING_13366387235044393553)],
        &[(0b00001, &ENTRY_SECULUM_12179969068630184099)],
        &[(0b00001, &ENTRY_SECULUMS_12763686042400892321)],
        &[(0b10010, &ENTRY_SECURITIZATION_5956894235563326762)],
        &[(0b10010, &ENTRY_SECURITIZATIONS_5197658227648288767)],
        &[(0b10010, &ENTRY_SECURITIZE_2115071445948266576)],
        &[(0b10010, &ENTRY_SECURITIZED_6896218099194090741)],
        &[(0b10010, &ENTRY_SECURITIZES_8193678999474929494)],
        &[(0b10010, &ENTRY_SECURITIZING_10755138514200328235)],
        &[(0b01001, &ENTRY_SECURITIZATION_5956894235563326762)],
        &[(0b01001, &ENTRY_SECURITIZATIONS_5197658227648288767)],
        &[(0b01001, &ENTRY_SECURITIZE_2115071445948266576)],
        &[(0b01001, &ENTRY_SECURITIZED_6896218099194090741)],
        &[(0b01001, &ENTRY_SECURITIZES_8193678999474929494)],
        &[(0b01001, &ENTRY_SECURITIZING_10755138514200328235)],
    ],
    range: 3..=11,
};

static VARS_SECT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SECT_CHILDREN),
    value: None,
};

pub static VARS_SECT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arianisation"),
        dictgen::InsensitiveStr::Ascii("arianise"),
        dictgen::InsensitiveStr::Ascii("arianised"),
        dictgen::InsensitiveStr::Ascii("arianises"),
        dictgen::InsensitiveStr::Ascii("arianising"),
        dictgen::InsensitiveStr::Ascii("arianization"),
        dictgen::InsensitiveStr::Ascii("arianize"),
        dictgen::InsensitiveStr::Ascii("arianized"),
        dictgen::InsensitiveStr::Ascii("arianizes"),
        dictgen::InsensitiveStr::Ascii("arianizing"),
        dictgen::InsensitiveStr::Ascii("ionalisation"),
        dictgen::InsensitiveStr::Ascii("ionalisations"),
        dictgen::InsensitiveStr::Ascii("ionalise"),
        dictgen::InsensitiveStr::Ascii("ionalised"),
        dictgen::InsensitiveStr::Ascii("ionalises"),
        dictgen::InsensitiveStr::Ascii("ionalising"),
        dictgen::InsensitiveStr::Ascii("ionalization"),
        dictgen::InsensitiveStr::Ascii("ionalizations"),
        dictgen::InsensitiveStr::Ascii("ionalize"),
        dictgen::InsensitiveStr::Ascii("ionalized"),
        dictgen::InsensitiveStr::Ascii("ionalizes"),
        dictgen::InsensitiveStr::Ascii("ionalizing"),
        dictgen::InsensitiveStr::Ascii("ionisation"),
        dictgen::InsensitiveStr::Ascii("ionisations"),
        dictgen::InsensitiveStr::Ascii("ionise"),
        dictgen::InsensitiveStr::Ascii("ionised"),
        dictgen::InsensitiveStr::Ascii("ionises"),
        dictgen::InsensitiveStr::Ascii("ionising"),
        dictgen::InsensitiveStr::Ascii("ionization"),
        dictgen::InsensitiveStr::Ascii("ionizations"),
        dictgen::InsensitiveStr::Ascii("ionize"),
        dictgen::InsensitiveStr::Ascii("ionized"),
        dictgen::InsensitiveStr::Ascii("ionizes"),
        dictgen::InsensitiveStr::Ascii("ionizing"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SECTARIANIZATION_12976072257453381050)],
        &[(0b10010, &ENTRY_SECTARIANIZE_16393083304666129607)],
        &[(0b10010, &ENTRY_SECTARIANIZED_6103010511807662986)],
        &[(0b10010, &ENTRY_SECTARIANIZES_7057053753718900411)],
        &[(0b10010, &ENTRY_SECTARIANIZING_3380018019808154089)],
        &[(0b01001, &ENTRY_SECTARIANIZATION_12976072257453381050)],
        &[(0b01001, &ENTRY_SECTARIANIZE_16393083304666129607)],
        &[(0b01001, &ENTRY_SECTARIANIZED_6103010511807662986)],
        &[(0b01001, &ENTRY_SECTARIANIZES_7057053753718900411)],
        &[(0b01001, &ENTRY_SECTARIANIZING_3380018019808154089)],
        &[(0b10010, &ENTRY_SECTIONALIZATION_8994143807969832046)],
        &[(0b10010, &ENTRY_SECTIONALIZATIONS_16931298674891549325)],
        &[(0b10010, &ENTRY_SECTIONALIZE_2892469613560393091)],
        &[(0b10010, &ENTRY_SECTIONALIZED_5043821153558608530)],
        &[(0b10010, &ENTRY_SECTIONALIZES_11528039426529780489)],
        &[(0b10010, &ENTRY_SECTIONALIZING_17081195346063464372)],
        &[(0b01001, &ENTRY_SECTIONALIZATION_8994143807969832046)],
        &[(0b01001, &ENTRY_SECTIONALIZATIONS_16931298674891549325)],
        &[(0b01001, &ENTRY_SECTIONALIZE_2892469613560393091)],
        &[(0b01001, &ENTRY_SECTIONALIZED_5043821153558608530)],
        &[(0b01001, &ENTRY_SECTIONALIZES_11528039426529780489)],
        &[(0b01001, &ENTRY_SECTIONALIZING_17081195346063464372)],
        &[(0b10010, &ENTRY_SECTIONIZATION_3542203323287588618)],
        &[(0b10010, &ENTRY_SECTIONIZATIONS_7729239148133443161)],
        &[(0b10010, &ENTRY_SECTIONIZE_135702157013527579)],
        &[(0b10010, &ENTRY_SECTIONIZED_9100640351478690576)],
        &[(0b10010, &ENTRY_SECTIONIZES_8159979574067150824)],
        &[(0b10010, &ENTRY_SECTIONIZING_10971605985402823462)],
        &[(0b01001, &ENTRY_SECTIONIZATION_3542203323287588618)],
        &[(0b01001, &ENTRY_SECTIONIZATIONS_7729239148133443161)],
        &[(0b01001, &ENTRY_SECTIONIZE_135702157013527579)],
        &[(0b01001, &ENTRY_SECTIONIZED_9100640351478690576)],
        &[(0b01001, &ENTRY_SECTIONIZES_8159979574067150824)],
        &[(0b01001, &ENTRY_SECTIONIZING_10971605985402823462)],
        &[(0b10010, &ENTRY_SECTORIZATION_12059149390774064762)],
        &[(0b10010, &ENTRY_SECTORIZATIONS_9647595832033172889)],
        &[(0b10010, &ENTRY_SECTORIZE_4436943247784100905)],
        &[(0b10010, &ENTRY_SECTORIZED_663771891983790592)],
        &[(0b10010, &ENTRY_SECTORIZES_10751018475745966003)],
        &[(0b10010, &ENTRY_SECTORIZING_17569875759145214364)],
        &[(0b01001, &ENTRY_SECTORIZATION_12059149390774064762)],
        &[(0b01001, &ENTRY_SECTORIZATIONS_9647595832033172889)],
        &[(0b01001, &ENTRY_SECTORIZE_4436943247784100905)],
        &[(0b01001, &ENTRY_SECTORIZED_663771891983790592)],
        &[(0b01001, &ENTRY_SECTORIZES_10751018475745966003)],
        &[(0b01001, &ENTRY_SECTORIZING_17569875759145214364)],
    ],
    range: 5..=13,
};

static VARS_SEB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEB_CHILDREN),
    value: None,
};

pub static VARS_SEB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orrhea"),
        dictgen::InsensitiveStr::Ascii("orrheas"),
        dictgen::InsensitiveStr::Ascii("orrheic"),
        dictgen::InsensitiveStr::Ascii("orrhoea"),
        dictgen::InsensitiveStr::Ascii("orrhoeas"),
        dictgen::InsensitiveStr::Ascii("orrhoeic"),
    ],
    values: &[
        &[(0b01001, &ENTRY_SEBORRHEA_8596487171579042968)],
        &[(0b01001, &ENTRY_SEBORRHEAS_17664504842211561857)],
        &[(0b01001, &ENTRY_SEBORRHEIC_14630913311363871280)],
        &[(0b10010, &ENTRY_SEBORRHEA_8596487171579042968)],
        &[(0b10010, &ENTRY_SEBORRHEAS_17664504842211561857)],
        &[(0b10010, &ENTRY_SEBORRHEIC_14630913311363871280)],
    ],
    range: 6..=8,
};

static VARS_SC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SC_CHILDREN),
    value: None,
};

static VARS_SC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SCA_NODE),
    None,
    None,
    None,
    Some(&VARS_SCE_NODE),
    None,
    None,
    Some(&VARS_SCH_NODE),
    Some(&VARS_SCI_NODE),
    None,
    None,
    Some(&VARS_SCL_NODE),
    None,
    None,
    Some(&VARS_SCO_NODE),
    None,
    None,
    Some(&VARS_SCR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SCR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCR_CHILDREN),
    value: None,
};

pub static VARS_SCR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ipturalise"),
        dictgen::InsensitiveStr::Ascii("ipturalises"),
        dictgen::InsensitiveStr::Ascii("ipturalize"),
        dictgen::InsensitiveStr::Ascii("ipturalizes"),
        dictgen::InsensitiveStr::Ascii("utinisation"),
        dictgen::InsensitiveStr::Ascii("utinisations"),
        dictgen::InsensitiveStr::Ascii("utinise"),
        dictgen::InsensitiveStr::Ascii("utinised"),
        dictgen::InsensitiveStr::Ascii("utiniser"),
        dictgen::InsensitiveStr::Ascii("utinisers"),
        dictgen::InsensitiveStr::Ascii("utinises"),
        dictgen::InsensitiveStr::Ascii("utinising"),
        dictgen::InsensitiveStr::Ascii("utinisinglies"),
        dictgen::InsensitiveStr::Ascii("utinisingly"),
        dictgen::InsensitiveStr::Ascii("utinization"),
        dictgen::InsensitiveStr::Ascii("utinizations"),
        dictgen::InsensitiveStr::Ascii("utinize"),
        dictgen::InsensitiveStr::Ascii("utinized"),
        dictgen::InsensitiveStr::Ascii("utinizer"),
        dictgen::InsensitiveStr::Ascii("utinizers"),
        dictgen::InsensitiveStr::Ascii("utinizes"),
        dictgen::InsensitiveStr::Ascii("utinizing"),
        dictgen::InsensitiveStr::Ascii("utinizinglies"),
        dictgen::InsensitiveStr::Ascii("utinizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SCRIPTURALIZE_15833657682700552011)],
        &[(0b10010, &ENTRY_SCRIPTURALIZES_14898839521389524664)],
        &[(0b01001, &ENTRY_SCRIPTURALIZE_15833657682700552011)],
        &[(0b01001, &ENTRY_SCRIPTURALIZES_14898839521389524664)],
        &[(0b10010, &ENTRY_SCRUTINIZATION_16840609583662225122)],
        &[(0b10010, &ENTRY_SCRUTINIZATIONS_15493523410837117880)],
        &[(0b10010, &ENTRY_SCRUTINIZE_11520578540425679510)],
        &[(0b10010, &ENTRY_SCRUTINIZED_2329669763243403883)],
        &[(0b10010, &ENTRY_SCRUTINIZER_1548201174107564828)],
        &[(0b10010, &ENTRY_SCRUTINIZERS_4674596638392471916)],
        &[(0b10010, &ENTRY_SCRUTINIZES_7393741262112863368)],
        &[(0b10010, &ENTRY_SCRUTINIZING_3883358635901547505)],
        &[(0b10010, &ENTRY_SCRUTINIZINGLIES_5389671481721987146)],
        &[(0b10010, &ENTRY_SCRUTINIZINGLY_13749041840105641359)],
        &[(0b01001, &ENTRY_SCRUTINIZATION_16840609583662225122)],
        &[(0b01001, &ENTRY_SCRUTINIZATIONS_15493523410837117880)],
        &[(0b01001, &ENTRY_SCRUTINIZE_11520578540425679510)],
        &[(0b01001, &ENTRY_SCRUTINIZED_2329669763243403883)],
        &[(0b01001, &ENTRY_SCRUTINIZER_1548201174107564828)],
        &[(0b01001, &ENTRY_SCRUTINIZERS_4674596638392471916)],
        &[(0b01001, &ENTRY_SCRUTINIZES_7393741262112863368)],
        &[(0b01001, &ENTRY_SCRUTINIZING_3883358635901547505)],
        &[(0b01001, &ENTRY_SCRUTINIZINGLIES_5389671481721987146)],
        &[(0b01001, &ENTRY_SCRUTINIZINGLY_13749041840105641359)],
    ],
    range: 7..=13,
};

static VARS_SCO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCO_CHILDREN),
    value: None,
};

pub static VARS_SCO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rse"),
        dictgen::InsensitiveStr::Ascii("rsed"),
        dictgen::InsensitiveStr::Ascii("rses"),
        dictgen::InsensitiveStr::Ascii("rsing"),
        dictgen::InsensitiveStr::Ascii("tticise"),
        dictgen::InsensitiveStr::Ascii("tticised"),
        dictgen::InsensitiveStr::Ascii("tticises"),
        dictgen::InsensitiveStr::Ascii("tticising"),
        dictgen::InsensitiveStr::Ascii("tticize"),
        dictgen::InsensitiveStr::Ascii("tticized"),
        dictgen::InsensitiveStr::Ascii("tticizes"),
        dictgen::InsensitiveStr::Ascii("tticizing"),
        dictgen::InsensitiveStr::Ascii("urse"),
        dictgen::InsensitiveStr::Ascii("ursed"),
        dictgen::InsensitiveStr::Ascii("urses"),
        dictgen::InsensitiveStr::Ascii("ursing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SCORSE_6425350851486428184)],
        &[(0b00001, &ENTRY_SCORSED_17476659339722088518)],
        &[(0b00001, &ENTRY_SCORSES_2194337448738300709)],
        &[(0b00001, &ENTRY_SCORSING_14138313440896393142)],
        &[(0b10010, &ENTRY_SCOTTICIZE_9983137950923071608)],
        &[(0b10010, &ENTRY_SCOTTICIZED_17337295302968105240)],
        &[(0b10010, &ENTRY_SCOTTICIZES_4917016627492614689)],
        &[(0b10010, &ENTRY_SCOTTICIZING_13323308695498031831)],
        &[(0b01001, &ENTRY_SCOTTICIZE_9983137950923071608)],
        &[(0b01001, &ENTRY_SCOTTICIZED_17337295302968105240)],
        &[(0b01001, &ENTRY_SCOTTICIZES_4917016627492614689)],
        &[(0b01001, &ENTRY_SCOTTICIZING_13323308695498031831)],
        &[(0b11010, &ENTRY_SCORSE_6425350851486428184)],
        &[(0b11010, &ENTRY_SCORSED_17476659339722088518)],
        &[(0b11010, &ENTRY_SCORSES_2194337448738300709)],
        &[(0b11010, &ENTRY_SCORSING_14138313440896393142)],
    ],
    range: 3..=9,
};

static VARS_SCL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCL_CHILDREN),
    value: None,
};

pub static VARS_SCL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erae"),
        dictgen::InsensitiveStr::Ascii("ere"),
        dictgen::InsensitiveStr::Ascii("erotisation"),
        dictgen::InsensitiveStr::Ascii("erotise"),
        dictgen::InsensitiveStr::Ascii("erotised"),
        dictgen::InsensitiveStr::Ascii("erotises"),
        dictgen::InsensitiveStr::Ascii("erotising"),
        dictgen::InsensitiveStr::Ascii("erotization"),
        dictgen::InsensitiveStr::Ascii("erotize"),
        dictgen::InsensitiveStr::Ascii("erotized"),
        dictgen::InsensitiveStr::Ascii("erotizes"),
        dictgen::InsensitiveStr::Ascii("erotizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SCLERE_3253698441819495003)],
        &[(0b00001, &ENTRY_SCLERE_3253698441819495003)],
        &[(0b10010, &ENTRY_SCLEROTIZATION_12132292602417583411)],
        &[(0b10010, &ENTRY_SCLEROTIZE_11947136539548445360)],
        &[(0b10010, &ENTRY_SCLEROTIZED_6920544013290794768)],
        &[(0b10010, &ENTRY_SCLEROTIZES_7771756203222170673)],
        &[(0b10010, &ENTRY_SCLEROTIZING_14715970191611020497)],
        &[(0b01001, &ENTRY_SCLEROTIZATION_12132292602417583411)],
        &[(0b01001, &ENTRY_SCLEROTIZE_11947136539548445360)],
        &[(0b01001, &ENTRY_SCLEROTIZED_6920544013290794768)],
        &[(0b01001, &ENTRY_SCLEROTIZES_7771756203222170673)],
        &[(0b01001, &ENTRY_SCLEROTIZING_14715970191611020497)],
    ],
    range: 3..=11,
};

static VARS_SCI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCI_CHILDREN),
    value: None,
};

pub static VARS_SCI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entise"),
        dictgen::InsensitiveStr::Ascii("entised"),
        dictgen::InsensitiveStr::Ascii("entises"),
        dictgen::InsensitiveStr::Ascii("entising"),
        dictgen::InsensitiveStr::Ascii("entize"),
        dictgen::InsensitiveStr::Ascii("entized"),
        dictgen::InsensitiveStr::Ascii("entizes"),
        dictgen::InsensitiveStr::Ascii("entizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SCIENTIZE_3015765919608850300)],
        &[(0b10010, &ENTRY_SCIENTIZED_8795047136761378602)],
        &[(0b10010, &ENTRY_SCIENTIZES_14454037718685233406)],
        &[(0b10010, &ENTRY_SCIENTIZING_15664058513727181609)],
        &[(0b01001, &ENTRY_SCIENTIZE_3015765919608850300)],
        &[(0b01001, &ENTRY_SCIENTIZED_8795047136761378602)],
        &[(0b01001, &ENTRY_SCIENTIZES_14454037718685233406)],
        &[(0b01001, &ENTRY_SCIENTIZING_15664058513727181609)],
    ],
    range: 6..=8,
};

static VARS_SCH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCH_CHILDREN),
    value: None,
};

pub static VARS_SCH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edulise"),
        dictgen::InsensitiveStr::Ascii("edulises"),
        dictgen::InsensitiveStr::Ascii("edulize"),
        dictgen::InsensitiveStr::Ascii("edulizes"),
        dictgen::InsensitiveStr::Ascii("ematisation"),
        dictgen::InsensitiveStr::Ascii("ematisations"),
        dictgen::InsensitiveStr::Ascii("ematise"),
        dictgen::InsensitiveStr::Ascii("ematised"),
        dictgen::InsensitiveStr::Ascii("ematiser"),
        dictgen::InsensitiveStr::Ascii("ematisers"),
        dictgen::InsensitiveStr::Ascii("ematises"),
        dictgen::InsensitiveStr::Ascii("ematising"),
        dictgen::InsensitiveStr::Ascii("ematization"),
        dictgen::InsensitiveStr::Ascii("ematizations"),
        dictgen::InsensitiveStr::Ascii("ematize"),
        dictgen::InsensitiveStr::Ascii("ematized"),
        dictgen::InsensitiveStr::Ascii("ematizer"),
        dictgen::InsensitiveStr::Ascii("ematizers"),
        dictgen::InsensitiveStr::Ascii("ematizes"),
        dictgen::InsensitiveStr::Ascii("ematizing"),
        dictgen::InsensitiveStr::Ascii("illerisation"),
        dictgen::InsensitiveStr::Ascii("illerisations"),
        dictgen::InsensitiveStr::Ascii("illerise"),
        dictgen::InsensitiveStr::Ascii("illerised"),
        dictgen::InsensitiveStr::Ascii("illerises"),
        dictgen::InsensitiveStr::Ascii("illerising"),
        dictgen::InsensitiveStr::Ascii("illerization"),
        dictgen::InsensitiveStr::Ascii("illerizations"),
        dictgen::InsensitiveStr::Ascii("illerize"),
        dictgen::InsensitiveStr::Ascii("illerized"),
        dictgen::InsensitiveStr::Ascii("illerizes"),
        dictgen::InsensitiveStr::Ascii("illerizing"),
        dictgen::InsensitiveStr::Ascii("ismatise"),
        dictgen::InsensitiveStr::Ascii("ismatised"),
        dictgen::InsensitiveStr::Ascii("ismatises"),
        dictgen::InsensitiveStr::Ascii("ismatising"),
        dictgen::InsensitiveStr::Ascii("ismatize"),
        dictgen::InsensitiveStr::Ascii("ismatized"),
        dictgen::InsensitiveStr::Ascii("ismatizes"),
        dictgen::InsensitiveStr::Ascii("ismatizing"),
        dictgen::InsensitiveStr::Ascii("istocelia"),
        dictgen::InsensitiveStr::Ascii("istocoelia"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SCHEDULIZE_10874935272495009679)],
        &[(0b10010, &ENTRY_SCHEDULIZES_7182811045941826740)],
        &[(0b01001, &ENTRY_SCHEDULIZE_10874935272495009679)],
        &[(0b01001, &ENTRY_SCHEDULIZES_7182811045941826740)],
        &[(0b10010, &ENTRY_SCHEMATIZATION_1676990775754888542)],
        &[(0b10010, &ENTRY_SCHEMATIZATIONS_6437769711305203183)],
        &[(0b10010, &ENTRY_SCHEMATIZE_16415111007074766296)],
        &[(0b10010, &ENTRY_SCHEMATIZED_16870559659839470180)],
        &[(0b10010, &ENTRY_SCHEMATIZER_9401704870795199962)],
        &[(0b10010, &ENTRY_SCHEMATIZERS_6139126226910745642)],
        &[(0b10010, &ENTRY_SCHEMATIZES_5455806020883567582)],
        &[(0b10010, &ENTRY_SCHEMATIZING_17927667405052965293)],
        &[(0b01001, &ENTRY_SCHEMATIZATION_1676990775754888542)],
        &[(0b01001, &ENTRY_SCHEMATIZATIONS_6437769711305203183)],
        &[(0b01001, &ENTRY_SCHEMATIZE_16415111007074766296)],
        &[(0b01001, &ENTRY_SCHEMATIZED_16870559659839470180)],
        &[(0b01001, &ENTRY_SCHEMATIZER_9401704870795199962)],
        &[(0b01001, &ENTRY_SCHEMATIZERS_6139126226910745642)],
        &[(0b01001, &ENTRY_SCHEMATIZES_5455806020883567582)],
        &[(0b01001, &ENTRY_SCHEMATIZING_17927667405052965293)],
        &[(0b10010, &ENTRY_SCHILLERIZATION_134316338122380470)],
        &[(0b10010, &ENTRY_SCHILLERIZATIONS_2065739841216795641)],
        &[(0b10010, &ENTRY_SCHILLERIZE_16984821653905669407)],
        &[(0b10010, &ENTRY_SCHILLERIZED_12056315487174553805)],
        &[(0b10010, &ENTRY_SCHILLERIZES_15680797582738987873)],
        &[(0b10010, &ENTRY_SCHILLERIZING_6452935797140422184)],
        &[(0b01001, &ENTRY_SCHILLERIZATION_134316338122380470)],
        &[(0b01001, &ENTRY_SCHILLERIZATIONS_2065739841216795641)],
        &[(0b01001, &ENTRY_SCHILLERIZE_16984821653905669407)],
        &[(0b01001, &ENTRY_SCHILLERIZED_12056315487174553805)],
        &[(0b01001, &ENTRY_SCHILLERIZES_15680797582738987873)],
        &[(0b01001, &ENTRY_SCHILLERIZING_6452935797140422184)],
        &[(0b10010, &ENTRY_SCHISMATIZE_789908240245008611)],
        &[(0b10010, &ENTRY_SCHISMATIZED_16555774757396136554)],
        &[(0b10010, &ENTRY_SCHISMATIZES_15571943244118334631)],
        &[(0b10010, &ENTRY_SCHISMATIZING_159281964687958140)],
        &[(0b01001, &ENTRY_SCHISMATIZE_789908240245008611)],
        &[(0b01001, &ENTRY_SCHISMATIZED_16555774757396136554)],
        &[(0b01001, &ENTRY_SCHISMATIZES_15571943244118334631)],
        &[(0b01001, &ENTRY_SCHISMATIZING_159281964687958140)],
        &[(0b00001, &ENTRY_SCHISTOCELIA_10700792843711130495)],
        &[(0b11010, &ENTRY_SCHISTOCELIA_10700792843711130495)],
    ],
    range: 7..=13,
};

static VARS_SCE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCE_CHILDREN),
    value: None,
};

pub static VARS_SCE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("na"),
        dictgen::InsensitiveStr::Ascii("narioisation"),
        dictgen::InsensitiveStr::Ascii("narioisations"),
        dictgen::InsensitiveStr::Ascii("narioise"),
        dictgen::InsensitiveStr::Ascii("narioises"),
        dictgen::InsensitiveStr::Ascii("narioization"),
        dictgen::InsensitiveStr::Ascii("narioizations"),
        dictgen::InsensitiveStr::Ascii("narioize"),
        dictgen::InsensitiveStr::Ascii("narioizes"),
        dictgen::InsensitiveStr::Ascii("narisation"),
        dictgen::InsensitiveStr::Ascii("narisations"),
        dictgen::InsensitiveStr::Ascii("narise"),
        dictgen::InsensitiveStr::Ascii("narised"),
        dictgen::InsensitiveStr::Ascii("narises"),
        dictgen::InsensitiveStr::Ascii("narising"),
        dictgen::InsensitiveStr::Ascii("narization"),
        dictgen::InsensitiveStr::Ascii("narizations"),
        dictgen::InsensitiveStr::Ascii("narize"),
        dictgen::InsensitiveStr::Ascii("narized"),
        dictgen::InsensitiveStr::Ascii("narizes"),
        dictgen::InsensitiveStr::Ascii("narizing"),
        dictgen::InsensitiveStr::Ascii("pter"),
        dictgen::InsensitiveStr::Ascii("pterdom"),
        dictgen::InsensitiveStr::Ascii("ptered"),
        dictgen::InsensitiveStr::Ascii("ptering"),
        dictgen::InsensitiveStr::Ascii("pterless"),
        dictgen::InsensitiveStr::Ascii("pterlesses"),
        dictgen::InsensitiveStr::Ascii("pters"),
        dictgen::InsensitiveStr::Ascii("ptic"),
        dictgen::InsensitiveStr::Ascii("ptical"),
        dictgen::InsensitiveStr::Ascii("pticaler"),
        dictgen::InsensitiveStr::Ascii("pticalest"),
        dictgen::InsensitiveStr::Ascii("ptically"),
        dictgen::InsensitiveStr::Ascii("pticer"),
        dictgen::InsensitiveStr::Ascii("pticest"),
        dictgen::InsensitiveStr::Ascii("pticism"),
        dictgen::InsensitiveStr::Ascii("pticisms"),
        dictgen::InsensitiveStr::Ascii("ptics"),
        dictgen::InsensitiveStr::Ascii("ptre"),
        dictgen::InsensitiveStr::Ascii("ptred"),
        dictgen::InsensitiveStr::Ascii("ptredom"),
        dictgen::InsensitiveStr::Ascii("ptreless"),
        dictgen::InsensitiveStr::Ascii("ptrelesses"),
        dictgen::InsensitiveStr::Ascii("ptres"),
        dictgen::InsensitiveStr::Ascii("ptring"),
        dictgen::InsensitiveStr::Ascii("vor"),
        dictgen::InsensitiveStr::Ascii("vour"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SCENA_7141663492630230804)],
        &[(0b10010, &ENTRY_SCENARIOIZATION_16935700652672688357)],
        &[(0b10010, &ENTRY_SCENARIOIZATIONS_6488389628134041935)],
        &[(0b10010, &ENTRY_SCENARIOIZE_6929875542220577836)],
        &[(0b10010, &ENTRY_SCENARIOIZES_17849661175418143802)],
        &[(0b01001, &ENTRY_SCENARIOIZATION_16935700652672688357)],
        &[(0b01001, &ENTRY_SCENARIOIZATIONS_6488389628134041935)],
        &[(0b01001, &ENTRY_SCENARIOIZE_6929875542220577836)],
        &[(0b01001, &ENTRY_SCENARIOIZES_17849661175418143802)],
        &[(0b10010, &ENTRY_SCENARIZATION_16780333325852212901)],
        &[(0b10010, &ENTRY_SCENARIZATIONS_8416960904420962205)],
        &[(0b10010, &ENTRY_SCENARIZE_612234156285031284)],
        &[(0b10010, &ENTRY_SCENARIZED_16018713122754577556)],
        &[(0b10010, &ENTRY_SCENARIZES_5261391273725049523)],
        &[(0b10010, &ENTRY_SCENARIZING_14502398664421762166)],
        &[(0b01001, &ENTRY_SCENARIZATION_16780333325852212901)],
        &[(0b01001, &ENTRY_SCENARIZATIONS_8416960904420962205)],
        &[(0b01001, &ENTRY_SCENARIZE_612234156285031284)],
        &[(0b01001, &ENTRY_SCENARIZED_16018713122754577556)],
        &[(0b01001, &ENTRY_SCENARIZES_5261391273725049523)],
        &[(0b01001, &ENTRY_SCENARIZING_14502398664421762166)],
        &[(0b00001, &ENTRY_SCEPTER_10836268721579569022)],
        &[(0b00001, &ENTRY_SCEPTERDOM_17153671406151972298)],
        &[(0b00001, &ENTRY_SCEPTERED_2583853657518887848)],
        &[(0b00001, &ENTRY_SCEPTERING_12898998411155997054)],
        &[(0b00001, &ENTRY_SCEPTERLESS_1514965292752739127)],
        &[(0b00001, &ENTRY_SCEPTERLESSES_259863808993366250)],
        &[(0b00001, &ENTRY_SCEPTERS_11825573776001921342)],
        &[(0b11010, &ENTRY_SKEPTIC_9815313097030140436)],
        &[(0b11010, &ENTRY_SKEPTICAL_17849179356584176691)],
        &[(0b11010, &ENTRY_SKEPTICALER_10497826709555834276)],
        &[(0b11010, &ENTRY_SKEPTICALEST_4980384681338816222)],
        &[(0b11010, &ENTRY_SKEPTICALLY_1022245430766512126)],
        &[(0b11010, &ENTRY_SKEPTICER_17239131044137588151)],
        &[(0b11010, &ENTRY_SKEPTICEST_7590086531147625946)],
        &[(0b11010, &ENTRY_SKEPTICISM_14105128952227011757)],
        &[(0b11010, &ENTRY_SKEPTICISMS_4642865009100445057)],
        &[(0b11010, &ENTRY_SKEPTICS_10828965990171531904)],
        &[(0b11010, &ENTRY_SCEPTER_10836268721579569022)],
        &[(0b11010, &ENTRY_SCEPTERED_2583853657518887848)],
        &[(0b11010, &ENTRY_SCEPTERDOM_17153671406151972298)],
        &[(0b11010, &ENTRY_SCEPTERLESS_1514965292752739127)],
        &[(0b11010, &ENTRY_SCEPTERLESSES_259863808993366250)],
        &[(0b11010, &ENTRY_SCEPTERS_11825573776001921342)],
        &[(0b11010, &ENTRY_SCEPTERING_12898998411155997054)],
        &[(0b00001, &ENTRY_SCEVOR_10280777061871375909)],
        &[(0b11010, &ENTRY_SCEVOR_10280777061871375909)],
    ],
    range: 2..=13,
};

static VARS_SCA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCA_CHILDREN),
    value: None,
};

pub static VARS_SCA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ena"),
        dictgen::InsensitiveStr::Ascii("ndaled"),
        dictgen::InsensitiveStr::Ascii("ndaling"),
        dictgen::InsensitiveStr::Ascii("ndalisation"),
        dictgen::InsensitiveStr::Ascii("ndalisations"),
        dictgen::InsensitiveStr::Ascii("ndalise"),
        dictgen::InsensitiveStr::Ascii("ndalised"),
        dictgen::InsensitiveStr::Ascii("ndaliser"),
        dictgen::InsensitiveStr::Ascii("ndalisers"),
        dictgen::InsensitiveStr::Ascii("ndalises"),
        dictgen::InsensitiveStr::Ascii("ndalising"),
        dictgen::InsensitiveStr::Ascii("ndalization"),
        dictgen::InsensitiveStr::Ascii("ndalizations"),
        dictgen::InsensitiveStr::Ascii("ndalize"),
        dictgen::InsensitiveStr::Ascii("ndalized"),
        dictgen::InsensitiveStr::Ascii("ndalizer"),
        dictgen::InsensitiveStr::Ascii("ndalizers"),
        dictgen::InsensitiveStr::Ascii("ndalizes"),
        dictgen::InsensitiveStr::Ascii("ndalizing"),
        dictgen::InsensitiveStr::Ascii("ndalled"),
        dictgen::InsensitiveStr::Ascii("ndalling"),
        dictgen::InsensitiveStr::Ascii("paed"),
        dictgen::InsensitiveStr::Ascii("ped"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SCENA_7141663492630230804)],
        &[(0b00001, &ENTRY_SCANDALED_13447508330318483061)],
        &[(0b00001, &ENTRY_SCANDALING_17381730195382733089)],
        &[(0b10010, &ENTRY_SCANDALIZATION_9222246912531140529)],
        &[(0b10010, &ENTRY_SCANDALIZATIONS_18070074398119088194)],
        &[(0b10010, &ENTRY_SCANDALIZE_13541782947542016266)],
        &[(0b10010, &ENTRY_SCANDALIZED_1748801122543387716)],
        &[(0b10010, &ENTRY_SCANDALIZER_8949328602594471198)],
        &[(0b10010, &ENTRY_SCANDALIZERS_10866026711851385946)],
        &[(0b10010, &ENTRY_SCANDALIZES_16055760817318112159)],
        &[(0b10010, &ENTRY_SCANDALIZING_11160701382824581155)],
        &[(0b01001, &ENTRY_SCANDALIZATION_9222246912531140529)],
        &[(0b01001, &ENTRY_SCANDALIZATIONS_18070074398119088194)],
        &[(0b01001, &ENTRY_SCANDALIZE_13541782947542016266)],
        &[(0b01001, &ENTRY_SCANDALIZED_1748801122543387716)],
        &[(0b01001, &ENTRY_SCANDALIZER_8949328602594471198)],
        &[(0b01001, &ENTRY_SCANDALIZERS_10866026711851385946)],
        &[(0b01001, &ENTRY_SCANDALIZES_16055760817318112159)],
        &[(0b01001, &ENTRY_SCANDALIZING_11160701382824581155)],
        &[(0b11010, &ENTRY_SCANDALED_13447508330318483061)],
        &[(0b11010, &ENTRY_SCANDALING_17381730195382733089)],
        &[(0b11010, &ENTRY_SCAPED_5422571681233921706)],
        &[(0b00001, &ENTRY_SCAPED_5422571681233921706)],
    ],
    range: 3..=12,
};

static VARS_SA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SA_CHILDREN),
    value: None,
};

static VARS_SA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_SAB_NODE),
    Some(&VARS_SAC_NODE),
    None,
    Some(&VARS_SAE_NODE),
    Some(&VARS_SAF_NODE),
    None,
    None,
    Some(&VARS_SAI_NODE),
    None,
    None,
    Some(&VARS_SAL_NODE),
    None,
    Some(&VARS_SAN_NODE),
    None,
    Some(&VARS_SAP_NODE),
    None,
    Some(&VARS_SAR_NODE),
    Some(&VARS_SAS_NODE),
    Some(&VARS_SAT_NODE),
    None,
    Some(&VARS_SAV_NODE),
    None,
    Some(&VARS_SAX_NODE),
    None,
    None,
];

static VARS_SAX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAX_CHILDREN),
    value: None,
};

pub static VARS_SAX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SAXONIZATION_674457868558304958)],
        &[(0b10010, &ENTRY_SAXONIZATIONS_15660259626164087490)],
        &[(0b10010, &ENTRY_SAXONIZE_13364212151002980649)],
        &[(0b10010, &ENTRY_SAXONIZED_9838442939668117474)],
        &[(0b10010, &ENTRY_SAXONIZES_7697261235217292710)],
        &[(0b10010, &ENTRY_SAXONIZING_8544121589253566200)],
        &[(0b01001, &ENTRY_SAXONIZATION_674457868558304958)],
        &[(0b01001, &ENTRY_SAXONIZATIONS_15660259626164087490)],
        &[(0b01001, &ENTRY_SAXONIZE_13364212151002980649)],
        &[(0b01001, &ENTRY_SAXONIZED_9838442939668117474)],
        &[(0b01001, &ENTRY_SAXONIZES_7697261235217292710)],
        &[(0b01001, &ENTRY_SAXONIZING_8544121589253566200)],
    ],
    range: 5..=10,
};

static VARS_SAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SAV_CHILDREN),
    value: None,
};

static VARS_SAV_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SAVA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SAVI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SAVO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SAVO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAVO_CHILDREN),
    value: None,
};

pub static VARS_SAVO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("rier"),
        dictgen::InsensitiveStr::Ascii("ries"),
        dictgen::InsensitiveStr::Ascii("riest"),
        dictgen::InsensitiveStr::Ascii("rilies"),
        dictgen::InsensitiveStr::Ascii("rily"),
        dictgen::InsensitiveStr::Ascii("riness"),
        dictgen::InsensitiveStr::Ascii("rinesses"),
        dictgen::InsensitiveStr::Ascii("ring"),
        dictgen::InsensitiveStr::Ascii("ringlier"),
        dictgen::InsensitiveStr::Ascii("ringlies"),
        dictgen::InsensitiveStr::Ascii("ringliest"),
        dictgen::InsensitiveStr::Ascii("ringly"),
        dictgen::InsensitiveStr::Ascii("rless"),
        dictgen::InsensitiveStr::Ascii("rlesser"),
        dictgen::InsensitiveStr::Ascii("rlesses"),
        dictgen::InsensitiveStr::Ascii("rlessest"),
        dictgen::InsensitiveStr::Ascii("rly"),
        dictgen::InsensitiveStr::Ascii("rous"),
        dictgen::InsensitiveStr::Ascii("rouser"),
        dictgen::InsensitiveStr::Ascii("rousest"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("ry"),
        dictgen::InsensitiveStr::Ascii("ur"),
        dictgen::InsensitiveStr::Ascii("ured"),
        dictgen::InsensitiveStr::Ascii("urer"),
        dictgen::InsensitiveStr::Ascii("urers"),
        dictgen::InsensitiveStr::Ascii("urier"),
        dictgen::InsensitiveStr::Ascii("uries"),
        dictgen::InsensitiveStr::Ascii("uriest"),
        dictgen::InsensitiveStr::Ascii("urilies"),
        dictgen::InsensitiveStr::Ascii("urily"),
        dictgen::InsensitiveStr::Ascii("uriness"),
        dictgen::InsensitiveStr::Ascii("urinesses"),
        dictgen::InsensitiveStr::Ascii("uring"),
        dictgen::InsensitiveStr::Ascii("uringlier"),
        dictgen::InsensitiveStr::Ascii("uringlies"),
        dictgen::InsensitiveStr::Ascii("uringliest"),
        dictgen::InsensitiveStr::Ascii("uringly"),
        dictgen::InsensitiveStr::Ascii("urless"),
        dictgen::InsensitiveStr::Ascii("urlesser"),
        dictgen::InsensitiveStr::Ascii("urlesses"),
        dictgen::InsensitiveStr::Ascii("urlessest"),
        dictgen::InsensitiveStr::Ascii("urly"),
        dictgen::InsensitiveStr::Ascii("urous"),
        dictgen::InsensitiveStr::Ascii("urouser"),
        dictgen::InsensitiveStr::Ascii("urousest"),
        dictgen::InsensitiveStr::Ascii("urs"),
        dictgen::InsensitiveStr::Ascii("ury"),
    ],
    values: &[
        &[(0b11001, &ENTRY_SAVOR_2009903601214458496)],
        &[(0b11001, &ENTRY_SAVORED_10072117720481381746)],
        &[(0b11001, &ENTRY_SAVORER_8012219220700235569)],
        &[(0b11001, &ENTRY_SAVORERS_1332704043262552655)],
        &[(0b11001, &ENTRY_SAVORIER_3288635659178747397)],
        &[(0b11001, &ENTRY_SAVORIES_17238888817605202369)],
        &[(0b11001, &ENTRY_SAVORIEST_5279619332722860135)],
        &[(0b11001, &ENTRY_SAVORILIES_12504192655922635406)],
        &[(0b11001, &ENTRY_SAVORILY_9272760762798011467)],
        &[(0b11001, &ENTRY_SAVORINESS_14234013341609684681)],
        &[(0b11001, &ENTRY_SAVORINESSES_8162276890626615)],
        &[(0b11001, &ENTRY_SAVORING_7676890325408701864)],
        &[(0b11001, &ENTRY_SAVORINGLIER_6030440039940731860)],
        &[(0b11001, &ENTRY_SAVORINGLIES_6159637740908517522)],
        &[(0b11001, &ENTRY_SAVORINGLIEST_3273409680061825250)],
        &[(0b11001, &ENTRY_SAVORINGLY_16392721850542159930)],
        &[(0b11001, &ENTRY_SAVORLESS_16913507828862527408)],
        &[(0b11001, &ENTRY_SAVORLESSER_5411670158498378508)],
        &[(0b11001, &ENTRY_SAVORLESSES_968943861955442838)],
        &[(0b11001, &ENTRY_SAVORLESSEST_13669214750218952880)],
        &[(0b11001, &ENTRY_SAVORLY_4451952026972836425)],
        &[(0b00001, &ENTRY_SAVOROUS_6562669852519896030)],
        &[(0b00001, &ENTRY_SAVOROUSER_7582639087690097285)],
        &[(0b00001, &ENTRY_SAVOROUSEST_7872022404790033872)],
        &[(0b11001, &ENTRY_SAVORS_13144818916465986619)],
        &[(0b11001, &ENTRY_SAVORY_10419005726511351932)],
        &[(0b11010, &ENTRY_SAVOR_2009903601214458496)],
        &[(0b11010, &ENTRY_SAVORED_10072117720481381746)],
        &[(0b11010, &ENTRY_SAVORER_8012219220700235569)],
        &[(0b11010, &ENTRY_SAVORERS_1332704043262552655)],
        &[(0b11010, &ENTRY_SAVORIER_3288635659178747397)],
        &[(0b11010, &ENTRY_SAVORIES_17238888817605202369)],
        &[(0b11010, &ENTRY_SAVORIEST_5279619332722860135)],
        &[(0b11010, &ENTRY_SAVORILIES_12504192655922635406)],
        &[(0b11010, &ENTRY_SAVORILY_9272760762798011467)],
        &[(0b11010, &ENTRY_SAVORINESS_14234013341609684681)],
        &[(0b11010, &ENTRY_SAVORINESSES_8162276890626615)],
        &[(0b11010, &ENTRY_SAVORING_7676890325408701864)],
        &[(0b11010, &ENTRY_SAVORINGLIER_6030440039940731860)],
        &[(0b11010, &ENTRY_SAVORINGLIES_6159637740908517522)],
        &[(0b11010, &ENTRY_SAVORINGLIEST_3273409680061825250)],
        &[(0b11010, &ENTRY_SAVORINGLY_16392721850542159930)],
        &[(0b11010, &ENTRY_SAVORLESS_16913507828862527408)],
        &[(0b11010, &ENTRY_SAVORLESSER_5411670158498378508)],
        &[(0b11010, &ENTRY_SAVORLESSES_968943861955442838)],
        &[(0b11010, &ENTRY_SAVORLESSEST_13669214750218952880)],
        &[(0b11010, &ENTRY_SAVORLY_4451952026972836425)],
        &[(0b11010, &ENTRY_SAVOROUS_6562669852519896030)],
        &[(0b11010, &ENTRY_SAVOROUSER_7582639087690097285)],
        &[(0b11010, &ENTRY_SAVOROUSEST_7872022404790033872)],
        &[(0b11010, &ENTRY_SAVORS_13144818916465986619)],
        &[(0b11010, &ENTRY_SAVORY_10419005726511351932)],
    ],
    range: 1..=10,
};

static VARS_SAVI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAVI_CHILDREN),
    value: None,
};

pub static VARS_SAVI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("oress"),
        dictgen::InsensitiveStr::Ascii("orhood"),
        dictgen::InsensitiveStr::Ascii("orhoods"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("orship"),
        dictgen::InsensitiveStr::Ascii("orships"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ouress"),
        dictgen::InsensitiveStr::Ascii("ourhood"),
        dictgen::InsensitiveStr::Ascii("ourhoods"),
        dictgen::InsensitiveStr::Ascii("ours"),
        dictgen::InsensitiveStr::Ascii("ourship"),
        dictgen::InsensitiveStr::Ascii("ourships"),
    ],
    values: &[
        &[(0b11001, &ENTRY_SAVIOR_9168066282007531402)],
        &[(0b00001, &ENTRY_SAVIORESS_16737550475718607104)],
        &[(0b11001, &ENTRY_SAVIORHOOD_13479211680309492690)],
        &[(0b11001, &ENTRY_SAVIORHOODS_17183410712600577741)],
        &[(0b11001, &ENTRY_SAVIORS_678195616807904094)],
        &[(0b11001, &ENTRY_SAVIORSHIP_17492156220076413092)],
        &[(0b11001, &ENTRY_SAVIORSHIPS_10540252863037861490)],
        &[(0b11010, &ENTRY_SAVIOR_9168066282007531402)],
        &[(0b11010, &ENTRY_SAVIORESS_16737550475718607104)],
        &[(0b11010, &ENTRY_SAVIORHOOD_13479211680309492690)],
        &[(0b11010, &ENTRY_SAVIORHOODS_17183410712600577741)],
        &[(0b11010, &ENTRY_SAVIORS_678195616807904094)],
        &[(0b11010, &ENTRY_SAVIORSHIP_17492156220076413092)],
        &[(0b11010, &ENTRY_SAVIORSHIPS_10540252863037861490)],
    ],
    range: 2..=8,
};

static VARS_SAVA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAVA_CHILDREN),
    value: None,
};

pub static VARS_SAVA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gise"),
        dictgen::InsensitiveStr::Ascii("gises"),
        dictgen::InsensitiveStr::Ascii("gize"),
        dictgen::InsensitiveStr::Ascii("gizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SAVAGIZE_9253788959378260781)],
        &[(0b10010, &ENTRY_SAVAGIZES_2456827584264233392)],
        &[(0b01001, &ENTRY_SAVAGIZE_9253788959378260781)],
        &[(0b01001, &ENTRY_SAVAGIZES_2456827584264233392)],
    ],
    range: 4..=5,
};

static VARS_SAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAT_CHILDREN),
    value: None,
};

pub static VARS_SAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("ellitise"),
        dictgen::InsensitiveStr::Ascii("ellitised"),
        dictgen::InsensitiveStr::Ascii("ellitises"),
        dictgen::InsensitiveStr::Ascii("ellitising"),
        dictgen::InsensitiveStr::Ascii("ellitize"),
        dictgen::InsensitiveStr::Ascii("ellitized"),
        dictgen::InsensitiveStr::Ascii("ellitizes"),
        dictgen::InsensitiveStr::Ascii("ellitizing"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("irisable"),
        dictgen::InsensitiveStr::Ascii("irisables"),
        dictgen::InsensitiveStr::Ascii("irisation"),
        dictgen::InsensitiveStr::Ascii("irise"),
        dictgen::InsensitiveStr::Ascii("irised"),
        dictgen::InsensitiveStr::Ascii("iriser"),
        dictgen::InsensitiveStr::Ascii("irisers"),
        dictgen::InsensitiveStr::Ascii("irises"),
        dictgen::InsensitiveStr::Ascii("irising"),
        dictgen::InsensitiveStr::Ascii("irizable"),
        dictgen::InsensitiveStr::Ascii("irizables"),
        dictgen::InsensitiveStr::Ascii("irization"),
        dictgen::InsensitiveStr::Ascii("irize"),
        dictgen::InsensitiveStr::Ascii("irized"),
        dictgen::InsensitiveStr::Ascii("irizer"),
        dictgen::InsensitiveStr::Ascii("irizers"),
        dictgen::InsensitiveStr::Ascii("irizes"),
        dictgen::InsensitiveStr::Ascii("irizing"),
        dictgen::InsensitiveStr::Ascii("ivae"),
        dictgen::InsensitiveStr::Ascii("ive"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SATANIZE_13800030973770952717)],
        &[(0b10010, &ENTRY_SATANIZES_15523201590267219023)],
        &[(0b01001, &ENTRY_SATANIZE_13800030973770952717)],
        &[(0b01001, &ENTRY_SATANIZES_15523201590267219023)],
        &[(0b10010, &ENTRY_SATELLITIZE_9577005869118714843)],
        &[(0b10010, &ENTRY_SATELLITIZED_12147676221618104985)],
        &[(0b10010, &ENTRY_SATELLITIZES_14259618482943348896)],
        &[(0b10010, &ENTRY_SATELLITIZING_7035209722236285234)],
        &[(0b01001, &ENTRY_SATELLITIZE_9577005869118714843)],
        &[(0b01001, &ENTRY_SATELLITIZED_12147676221618104985)],
        &[(0b01001, &ENTRY_SATELLITIZES_14259618482943348896)],
        &[(0b01001, &ENTRY_SATELLITIZING_7035209722236285234)],
        &[(0b10010, &ENTRY_SATINIZE_5954102382726369151)],
        &[(0b10010, &ENTRY_SATINIZES_13360217491878629150)],
        &[(0b01001, &ENTRY_SATINIZE_5954102382726369151)],
        &[(0b01001, &ENTRY_SATINIZES_13360217491878629150)],
        &[(0b10010, &ENTRY_SATIRIZABLE_16109104170385816610)],
        &[(0b10010, &ENTRY_SATIRIZABLES_17724622533636018383)],
        &[(0b10010, &ENTRY_SATIRIZATION_7570569320271471416)],
        &[(0b10010, &ENTRY_SATIRIZE_6448100415548150058)],
        &[(0b10010, &ENTRY_SATIRIZED_2609000629009969840)],
        &[(0b10010, &ENTRY_SATIRIZER_2790987711694827808)],
        &[(0b10010, &ENTRY_SATIRIZERS_12978388605451018478)],
        &[(0b10010, &ENTRY_SATIRIZES_5832579008425684994)],
        &[(0b10010, &ENTRY_SATIRIZING_4490066541734347659)],
        &[(0b01001, &ENTRY_SATIRIZABLE_16109104170385816610)],
        &[(0b01001, &ENTRY_SATIRIZABLES_17724622533636018383)],
        &[(0b01001, &ENTRY_SATIRIZATION_7570569320271471416)],
        &[(0b01001, &ENTRY_SATIRIZE_6448100415548150058)],
        &[(0b01001, &ENTRY_SATIRIZED_2609000629009969840)],
        &[(0b01001, &ENTRY_SATIRIZER_2790987711694827808)],
        &[(0b01001, &ENTRY_SATIRIZERS_12978388605451018478)],
        &[(0b01001, &ENTRY_SATIRIZES_5832579008425684994)],
        &[(0b01001, &ENTRY_SATIRIZING_4490066541734347659)],
        &[(0b11010, &ENTRY_SATIVE_17240933363041642707)],
        &[(0b00001, &ENTRY_SATIVE_17240933363041642707)],
    ],
    range: 3..=10,
};

static VARS_SAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAS_CHILDREN),
    value: None,
};

pub static VARS_SAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sanidae"),
        dictgen::InsensitiveStr::Ascii("sanide"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SASSANIDE_2666523513348378135)],
        &[(0b00001, &ENTRY_SASSANIDE_2666523513348378135)],
    ],
    range: 6..=7,
};

static VARS_SAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAR_CHILDREN),
    value: None,
};

pub static VARS_SAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cinae"),
        dictgen::InsensitiveStr::Ascii("cine"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SARCINE_17958233134687681150)],
        &[(0b00001, &ENTRY_SARCINE_17958233134687681150)],
    ],
    range: 4..=5,
};

static VARS_SAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAP_CHILDREN),
    value: None,
};

pub static VARS_SAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ientise"),
        dictgen::InsensitiveStr::Ascii("ientises"),
        dictgen::InsensitiveStr::Ascii("ientize"),
        dictgen::InsensitiveStr::Ascii("ientizes"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ours"),
        dictgen::InsensitiveStr::Ascii("raemia"),
        dictgen::InsensitiveStr::Ascii("raemias"),
        dictgen::InsensitiveStr::Ascii("raemic"),
        dictgen::InsensitiveStr::Ascii("remia"),
        dictgen::InsensitiveStr::Ascii("remias"),
        dictgen::InsensitiveStr::Ascii("remic"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SAPIENTIZE_13669220548988379710)],
        &[(0b10010, &ENTRY_SAPIENTIZES_16514816122173887376)],
        &[(0b01001, &ENTRY_SAPIENTIZE_13669220548988379710)],
        &[(0b01001, &ENTRY_SAPIENTIZES_16514816122173887376)],
        &[(0b00001, &ENTRY_SAPOR_11915420262708866035)],
        &[(0b00001, &ENTRY_SAPORS_4058358747036807109)],
        &[(0b11010, &ENTRY_SAPOR_11915420262708866035)],
        &[(0b11010, &ENTRY_SAPORS_4058358747036807109)],
        &[(0b11010, &ENTRY_SAPREMIA_12542934405933026855)],
        &[(0b11010, &ENTRY_SAPREMIAS_1881316800069031084)],
        &[(0b11010, &ENTRY_SAPREMIC_10220063281186365505)],
        &[(0b00001, &ENTRY_SAPREMIA_12542934405933026855)],
        &[(0b00001, &ENTRY_SAPREMIAS_1881316800069031084)],
        &[(0b00001, &ENTRY_SAPREMIC_10220063281186365505)],
    ],
    range: 2..=8,
};

static VARS_SAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAN_CHILDREN),
    value: None,
};

pub static VARS_SAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ctuarise"),
        dictgen::InsensitiveStr::Ascii("ctuarised"),
        dictgen::InsensitiveStr::Ascii("ctuarises"),
        dictgen::InsensitiveStr::Ascii("ctuarising"),
        dictgen::InsensitiveStr::Ascii("ctuarize"),
        dictgen::InsensitiveStr::Ascii("ctuarized"),
        dictgen::InsensitiveStr::Ascii("ctuarizes"),
        dictgen::InsensitiveStr::Ascii("ctuarizing"),
        dictgen::InsensitiveStr::Ascii("daled"),
        dictgen::InsensitiveStr::Ascii("daling"),
        dictgen::InsensitiveStr::Ascii("dalled"),
        dictgen::InsensitiveStr::Ascii("dalling"),
        dictgen::InsensitiveStr::Ascii("ferd"),
        dictgen::InsensitiveStr::Ascii("forise"),
        dictgen::InsensitiveStr::Ascii("forises"),
        dictgen::InsensitiveStr::Ascii("forising"),
        dictgen::InsensitiveStr::Ascii("forize"),
        dictgen::InsensitiveStr::Ascii("forizes"),
        dictgen::InsensitiveStr::Ascii("forizing"),
        dictgen::InsensitiveStr::Ascii("fred"),
        dictgen::InsensitiveStr::Ascii("itisation"),
        dictgen::InsensitiveStr::Ascii("itisations"),
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itiser"),
        dictgen::InsensitiveStr::Ascii("itisers"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itization"),
        dictgen::InsensitiveStr::Ascii("itizations"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizer"),
        dictgen::InsensitiveStr::Ascii("itizers"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
        dictgen::InsensitiveStr::Ascii("skritise"),
        dictgen::InsensitiveStr::Ascii("skritize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SANCTUARIZE_2357144985856368070)],
        &[(0b10010, &ENTRY_SANCTUARIZED_637812459100527648)],
        &[(0b10010, &ENTRY_SANCTUARIZES_11733292486141379371)],
        &[(0b10010, &ENTRY_SANCTUARIZING_8432215645688259160)],
        &[(0b01001, &ENTRY_SANCTUARIZE_2357144985856368070)],
        &[(0b01001, &ENTRY_SANCTUARIZED_637812459100527648)],
        &[(0b01001, &ENTRY_SANCTUARIZES_11733292486141379371)],
        &[(0b01001, &ENTRY_SANCTUARIZING_8432215645688259160)],
        &[(0b00001, &ENTRY_SANDALED_9300809745501373029)],
        &[(0b00001, &ENTRY_SANDALING_9906711963656843788)],
        &[(0b11010, &ENTRY_SANDALED_9300809745501373029)],
        &[(0b11010, &ENTRY_SANDALING_9906711963656843788)],
        &[(0b00001, &ENTRY_SANFERD_3004088950569415557)],
        &[(0b10010, &ENTRY_SANFORIZE_11059351431020143233)],
        &[(0b10010, &ENTRY_SANFORIZES_1821656617081894930)],
        &[(0b10010, &ENTRY_SANFORIZING_11411332451649842663)],
        &[(0b01001, &ENTRY_SANFORIZE_11059351431020143233)],
        &[(0b01001, &ENTRY_SANFORIZES_1821656617081894930)],
        &[(0b01001, &ENTRY_SANFORIZING_11411332451649842663)],
        &[(0b11010, &ENTRY_SANFERD_3004088950569415557)],
        &[(0b10010, &ENTRY_SANITIZATION_6597368949679247898)],
        &[(0b10010, &ENTRY_SANITIZATIONS_2020024074797942758)],
        &[(0b10010, &ENTRY_SANITIZE_13579713832357769834)],
        &[(0b10010, &ENTRY_SANITIZED_16038727043373480177)],
        &[(0b10010, &ENTRY_SANITIZER_2612058493574762426)],
        &[(0b10010, &ENTRY_SANITIZERS_15061258670919139218)],
        &[(0b10010, &ENTRY_SANITIZES_6782686809683998201)],
        &[(0b10010, &ENTRY_SANITIZING_8219973274341078569)],
        &[(0b01001, &ENTRY_SANITIZATION_6597368949679247898)],
        &[(0b01001, &ENTRY_SANITIZATIONS_2020024074797942758)],
        &[(0b01001, &ENTRY_SANITIZE_13579713832357769834)],
        &[(0b01001, &ENTRY_SANITIZED_16038727043373480177)],
        &[(0b01001, &ENTRY_SANITIZER_2612058493574762426)],
        &[(0b01001, &ENTRY_SANITIZERS_15061258670919139218)],
        &[(0b01001, &ENTRY_SANITIZES_6782686809683998201)],
        &[(0b01001, &ENTRY_SANITIZING_8219973274341078569)],
        &[(0b10010, &ENTRY_SANSKRITIZE_15760731619975739051)],
        &[(0b01001, &ENTRY_SANSKRITIZE_15760731619975739051)],
    ],
    range: 4..=10,
};

static VARS_SAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAL_CHILDREN),
    value: None,
};

pub static VARS_SAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("able"),
        dictgen::InsensitiveStr::Ascii("abler"),
        dictgen::InsensitiveStr::Ascii("ablest"),
        dictgen::InsensitiveStr::Ascii("inisation"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inization"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("tiers"),
        dictgen::InsensitiveStr::Ascii("tierwise"),
        dictgen::InsensitiveStr::Ascii("tires"),
        dictgen::InsensitiveStr::Ascii("tirewise"),
        dictgen::InsensitiveStr::Ascii("tpeter"),
        dictgen::InsensitiveStr::Ascii("tpeters"),
        dictgen::InsensitiveStr::Ascii("tpetre"),
        dictgen::InsensitiveStr::Ascii("tpetres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SALABLE_9416288983668269251)],
        &[(0b00001, &ENTRY_SALABLER_12436535119147435528)],
        &[(0b00001, &ENTRY_SALABLEST_11800233581075881251)],
        &[(0b10010, &ENTRY_SALINIZATION_13266963897300307508)],
        &[(0b10010, &ENTRY_SALINIZE_4347778676362138703)],
        &[(0b10010, &ENTRY_SALINIZES_10928451094016890368)],
        &[(0b01001, &ENTRY_SALINIZATION_13266963897300307508)],
        &[(0b01001, &ENTRY_SALINIZE_4347778676362138703)],
        &[(0b01001, &ENTRY_SALINIZES_10928451094016890368)],
        &[(0b00001, &ENTRY_SALTIERS_5634822252830887819)],
        &[(0b00001, &ENTRY_SALTIERWISE_17950423467476799477)],
        &[(0b11010, &ENTRY_SALTIERS_5634822252830887819)],
        &[(0b11010, &ENTRY_SALTIERWISE_17950423467476799477)],
        &[(0b00001, &ENTRY_SALTPETER_173602624950229471)],
        &[(0b00001, &ENTRY_SALTPETERS_6897362156960271547)],
        &[(0b11010, &ENTRY_SALTPETER_173602624950229471)],
        &[(0b11010, &ENTRY_SALTPETERS_6897362156960271547)],
    ],
    range: 4..=9,
};

static VARS_SAI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAI_CHILDREN),
    value: None,
};

pub static VARS_SAI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lorising"),
        dictgen::InsensitiveStr::Ascii("lorisings"),
        dictgen::InsensitiveStr::Ascii("lorizing"),
        dictgen::InsensitiveStr::Ascii("lorizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SAILORIZING_15355602670663398084)],
        &[(0b10010, &ENTRY_SAILORIZINGS_12371047336413895803)],
        &[(0b01001, &ENTRY_SAILORIZING_15355602670663398084)],
        &[(0b01001, &ENTRY_SAILORIZINGS_12371047336413895803)],
    ],
    range: 8..=9,
};

static VARS_SAF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAF_CHILDREN),
    value: None,
};

pub static VARS_SAF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ier"),
        dictgen::InsensitiveStr::Ascii("ire"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SAFIER_9789114026361208044)],
        &[(0b11010, &ENTRY_SAFIER_9789114026361208044)],
    ],
    range: 3..=3,
};

static VARS_SAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_SE_11935408519795320676)]),
};

pub static VARS_SAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("culum"),
        dictgen::InsensitiveStr::Ascii("culums"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("ta"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SECULUM_12179969068630184099)],
        &[(0b11010, &ENTRY_SECULUMS_12763686042400892321)],
        &[(0b11010, &ENTRY_SEED_14453242621235594627)],
        &[(0b11010, &ENTRY_SETA_4750865609556121705)],
    ],
    range: 2..=6,
};

static VARS_SAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAC_CHILDREN),
    value: None,
};

pub static VARS_SAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("charisation"),
        dictgen::InsensitiveStr::Ascii("charisations"),
        dictgen::InsensitiveStr::Ascii("charise"),
        dictgen::InsensitiveStr::Ascii("charised"),
        dictgen::InsensitiveStr::Ascii("charises"),
        dictgen::InsensitiveStr::Ascii("charising"),
        dictgen::InsensitiveStr::Ascii("charization"),
        dictgen::InsensitiveStr::Ascii("charizations"),
        dictgen::InsensitiveStr::Ascii("charize"),
        dictgen::InsensitiveStr::Ascii("charized"),
        dictgen::InsensitiveStr::Ascii("charizes"),
        dictgen::InsensitiveStr::Ascii("charizing"),
        dictgen::InsensitiveStr::Ascii("erdotalise"),
        dictgen::InsensitiveStr::Ascii("erdotalised"),
        dictgen::InsensitiveStr::Ascii("erdotalises"),
        dictgen::InsensitiveStr::Ascii("erdotalising"),
        dictgen::InsensitiveStr::Ascii("erdotalize"),
        dictgen::InsensitiveStr::Ascii("erdotalized"),
        dictgen::InsensitiveStr::Ascii("erdotalizes"),
        dictgen::InsensitiveStr::Ascii("erdotalizing"),
        dictgen::InsensitiveStr::Ascii("ralisation"),
        dictgen::InsensitiveStr::Ascii("ralisations"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralised"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralising"),
        dictgen::InsensitiveStr::Ascii("ralization"),
        dictgen::InsensitiveStr::Ascii("ralizations"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralized"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralizing"),
        dictgen::InsensitiveStr::Ascii("ramentise"),
        dictgen::InsensitiveStr::Ascii("ramentises"),
        dictgen::InsensitiveStr::Ascii("ramentize"),
        dictgen::InsensitiveStr::Ascii("ramentizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SACCHARIZATION_16067598677360548774)],
        &[(0b10010, &ENTRY_SACCHARIZATIONS_7465718845212875510)],
        &[(0b10010, &ENTRY_SACCHARIZE_15985938828367437759)],
        &[(0b10010, &ENTRY_SACCHARIZED_2066975935540578216)],
        &[(0b10010, &ENTRY_SACCHARIZES_12303619626250431982)],
        &[(0b10010, &ENTRY_SACCHARIZING_9152474624171075193)],
        &[(0b01001, &ENTRY_SACCHARIZATION_16067598677360548774)],
        &[(0b01001, &ENTRY_SACCHARIZATIONS_7465718845212875510)],
        &[(0b01001, &ENTRY_SACCHARIZE_15985938828367437759)],
        &[(0b01001, &ENTRY_SACCHARIZED_2066975935540578216)],
        &[(0b01001, &ENTRY_SACCHARIZES_12303619626250431982)],
        &[(0b01001, &ENTRY_SACCHARIZING_9152474624171075193)],
        &[(0b10010, &ENTRY_SACERDOTALIZE_3961802349220485517)],
        &[(0b10010, &ENTRY_SACERDOTALIZED_3947529897566908444)],
        &[(0b10010, &ENTRY_SACERDOTALIZES_9709179734322016707)],
        &[(0b10010, &ENTRY_SACERDOTALIZING_2005953003908602761)],
        &[(0b01001, &ENTRY_SACERDOTALIZE_3961802349220485517)],
        &[(0b01001, &ENTRY_SACERDOTALIZED_3947529897566908444)],
        &[(0b01001, &ENTRY_SACERDOTALIZES_9709179734322016707)],
        &[(0b01001, &ENTRY_SACERDOTALIZING_2005953003908602761)],
        &[(0b10010, &ENTRY_SACRALIZATION_10975549769050558226)],
        &[(0b10010, &ENTRY_SACRALIZATIONS_14552724704204688953)],
        &[(0b10010, &ENTRY_SACRALIZE_9629490668937081632)],
        &[(0b10010, &ENTRY_SACRALIZED_7406626079934925607)],
        &[(0b10010, &ENTRY_SACRALIZES_12289949097436420802)],
        &[(0b10010, &ENTRY_SACRALIZING_13224927129267811542)],
        &[(0b01001, &ENTRY_SACRALIZATION_10975549769050558226)],
        &[(0b01001, &ENTRY_SACRALIZATIONS_14552724704204688953)],
        &[(0b01001, &ENTRY_SACRALIZE_9629490668937081632)],
        &[(0b01001, &ENTRY_SACRALIZED_7406626079934925607)],
        &[(0b01001, &ENTRY_SACRALIZES_12289949097436420802)],
        &[(0b01001, &ENTRY_SACRALIZING_13224927129267811542)],
        &[(0b10010, &ENTRY_SACRAMENTIZE_4727143733704695641)],
        &[(0b10010, &ENTRY_SACRAMENTIZES_94291517496052865)],
        &[(0b01001, &ENTRY_SACRAMENTIZE_4727143733704695641)],
        &[(0b01001, &ENTRY_SACRAMENTIZES_94291517496052865)],
    ],
    range: 6..=12,
};

static VARS_SAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAB_CHILDREN),
    value: None,
};

pub static VARS_SAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aean"),
        dictgen::InsensitiveStr::Ascii("aeans"),
        dictgen::InsensitiveStr::Ascii("bathise"),
        dictgen::InsensitiveStr::Ascii("bathises"),
        dictgen::InsensitiveStr::Ascii("bathize"),
        dictgen::InsensitiveStr::Ascii("bathizes"),
        dictgen::InsensitiveStr::Ascii("batise"),
        dictgen::InsensitiveStr::Ascii("batised"),
        dictgen::InsensitiveStr::Ascii("batises"),
        dictgen::InsensitiveStr::Ascii("batising"),
        dictgen::InsensitiveStr::Ascii("batize"),
        dictgen::InsensitiveStr::Ascii("batized"),
        dictgen::InsensitiveStr::Ascii("batizes"),
        dictgen::InsensitiveStr::Ascii("batizing"),
        dictgen::InsensitiveStr::Ascii("ean"),
        dictgen::InsensitiveStr::Ascii("eans"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("erbill"),
        dictgen::InsensitiveStr::Ascii("ered"),
        dictgen::InsensitiveStr::Ascii("ering"),
        dictgen::InsensitiveStr::Ascii("erlike"),
        dictgen::InsensitiveStr::Ascii("erlikes"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("ertooth"),
        dictgen::InsensitiveStr::Ascii("rebill"),
        dictgen::InsensitiveStr::Ascii("relike"),
        dictgen::InsensitiveStr::Ascii("relikes"),
        dictgen::InsensitiveStr::Ascii("retooth"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SABEAN_17515878016028553161)],
        &[(0b11010, &ENTRY_SABEANS_16355459180629636797)],
        &[(0b10010, &ENTRY_SABBATHIZE_11967605322963658497)],
        &[(0b10010, &ENTRY_SABBATHIZES_17109057526061439868)],
        &[(0b01001, &ENTRY_SABBATHIZE_11967605322963658497)],
        &[(0b01001, &ENTRY_SABBATHIZES_17109057526061439868)],
        &[(0b10010, &ENTRY_SABBATIZE_15657255968552732741)],
        &[(0b10010, &ENTRY_SABBATIZED_15483584318942973231)],
        &[(0b10010, &ENTRY_SABBATIZES_14966685950973844938)],
        &[(0b10010, &ENTRY_SABBATIZING_7613295799085050565)],
        &[(0b01001, &ENTRY_SABBATIZE_15657255968552732741)],
        &[(0b01001, &ENTRY_SABBATIZED_15483584318942973231)],
        &[(0b01001, &ENTRY_SABBATIZES_14966685950973844938)],
        &[(0b01001, &ENTRY_SABBATIZING_7613295799085050565)],
        &[(0b00001, &ENTRY_SABEAN_17515878016028553161)],
        &[(0b00001, &ENTRY_SABEANS_16355459180629636797)],
        &[(0b00001, &ENTRY_SABER_11215537798592835960)],
        &[(0b00001, &ENTRY_SABERBILL_14244790750611534132)],
        &[(0b00001, &ENTRY_SABERED_354016476875728649)],
        &[(0b00001, &ENTRY_SABERING_4510522223387135900)],
        &[(0b00001, &ENTRY_SABERLIKE_9533101026022249155)],
        &[(0b00001, &ENTRY_SABERLIKES_8784912257296046319)],
        &[(0b00001, &ENTRY_SABERS_17469384891487410695)],
        &[(0b00001, &ENTRY_SABERTOOTH_4035092162600296855)],
        &[(0b11010, &ENTRY_SABERBILL_14244790750611534132)],
        &[(0b11010, &ENTRY_SABERLIKE_9533101026022249155)],
        &[(0b11010, &ENTRY_SABERLIKES_8784912257296046319)],
        &[(0b11010, &ENTRY_SABERTOOTH_4035092162600296855)],
    ],
    range: 2..=8,
};

static VARS_R_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_R_CHILDREN),
    value: None,
};

static VARS_R_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_RA_NODE),
    None,
    None,
    None,
    Some(&VARS_RE_NODE),
    None,
    None,
    Some(&VARS_RH_NODE),
    Some(&VARS_RI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_RU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RU_CHILDREN),
    value: None,
};

static VARS_RU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_RUB_NODE),
    None,
    None,
    None,
    Some(&VARS_RUF_NODE),
    Some(&VARS_RUG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RUM_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_RUR_NODE),
    Some(&VARS_RUS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_RUS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RUS_CHILDREN),
    value: None,
};

pub static VARS_RUS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sianisation"),
        dictgen::InsensitiveStr::Ascii("sianisations"),
        dictgen::InsensitiveStr::Ascii("sianise"),
        dictgen::InsensitiveStr::Ascii("sianised"),
        dictgen::InsensitiveStr::Ascii("sianises"),
        dictgen::InsensitiveStr::Ascii("sianising"),
        dictgen::InsensitiveStr::Ascii("sianization"),
        dictgen::InsensitiveStr::Ascii("sianizations"),
        dictgen::InsensitiveStr::Ascii("sianize"),
        dictgen::InsensitiveStr::Ascii("sianized"),
        dictgen::InsensitiveStr::Ascii("sianizes"),
        dictgen::InsensitiveStr::Ascii("sianizing"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticised"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticising"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticized"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
        dictgen::InsensitiveStr::Ascii("ticizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RUSSIANIZATION_15115261889071660936)],
        &[(0b10010, &ENTRY_RUSSIANIZATIONS_16674015372829185946)],
        &[(0b10010, &ENTRY_RUSSIANIZE_282987153219396042)],
        &[(0b10010, &ENTRY_RUSSIANIZED_16004967225929046214)],
        &[(0b10010, &ENTRY_RUSSIANIZES_3164883107359350862)],
        &[(0b10010, &ENTRY_RUSSIANIZING_18238432049983406277)],
        &[(0b01001, &ENTRY_RUSSIANIZATION_15115261889071660936)],
        &[(0b01001, &ENTRY_RUSSIANIZATIONS_16674015372829185946)],
        &[(0b01001, &ENTRY_RUSSIANIZE_282987153219396042)],
        &[(0b01001, &ENTRY_RUSSIANIZED_16004967225929046214)],
        &[(0b01001, &ENTRY_RUSSIANIZES_3164883107359350862)],
        &[(0b01001, &ENTRY_RUSSIANIZING_18238432049983406277)],
        &[(0b10010, &ENTRY_RUSTICIZE_944744519473975444)],
        &[(0b10010, &ENTRY_RUSTICIZED_1941250008396625115)],
        &[(0b10010, &ENTRY_RUSTICIZES_600312242923138898)],
        &[(0b10010, &ENTRY_RUSTICIZING_7143440747019626934)],
        &[(0b01001, &ENTRY_RUSTICIZE_944744519473975444)],
        &[(0b01001, &ENTRY_RUSTICIZED_1941250008396625115)],
        &[(0b01001, &ENTRY_RUSTICIZES_600312242923138898)],
        &[(0b01001, &ENTRY_RUSTICIZING_7143440747019626934)],
    ],
    range: 6..=12,
};

static VARS_RUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RUR_CHILDREN),
    value: None,
};

pub static VARS_RUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RURALIZATION_12580175398492738873)],
        &[(0b10010, &ENTRY_RURALIZATIONS_13674767207069067961)],
        &[(0b10010, &ENTRY_RURALIZE_15119229364207745147)],
        &[(0b10010, &ENTRY_RURALIZED_3311773382035084319)],
        &[(0b10010, &ENTRY_RURALIZES_1476309458742854492)],
        &[(0b10010, &ENTRY_RURALIZING_421101365792616220)],
        &[(0b01001, &ENTRY_RURALIZATION_12580175398492738873)],
        &[(0b01001, &ENTRY_RURALIZATIONS_13674767207069067961)],
        &[(0b01001, &ENTRY_RURALIZE_15119229364207745147)],
        &[(0b01001, &ENTRY_RURALIZED_3311773382035084319)],
        &[(0b01001, &ENTRY_RURALIZES_1476309458742854492)],
        &[(0b01001, &ENTRY_RURALIZING_421101365792616220)],
    ],
    range: 5..=10,
};

static VARS_RUM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RUM_CHILDREN),
    value: None,
};

pub static VARS_RUM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("orer"),
        dictgen::InsensitiveStr::Ascii("orers"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("ormonger"),
        dictgen::InsensitiveStr::Ascii("ormongers"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ourer"),
        dictgen::InsensitiveStr::Ascii("ourers"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ourmonger"),
        dictgen::InsensitiveStr::Ascii("ourmongers"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_RUMOR_14879871972679734791)],
        &[(0b11001, &ENTRY_RUMORED_440192285504422993)],
        &[(0b00001, &ENTRY_RUMORER_13710023131538812640)],
        &[(0b00001, &ENTRY_RUMORERS_18193676553916096837)],
        &[(0b11001, &ENTRY_RUMORING_6988773240152687435)],
        &[(0b10001, &ENTRY_RUMORMONGER_16571412941503356230)],
        &[(0b10001, &ENTRY_RUMORMONGERS_3640300238053765249)],
        &[(0b11001, &ENTRY_RUMORS_12062925234185208276)],
        &[(0b11010, &ENTRY_RUMOR_14879871972679734791)],
        &[(0b11010, &ENTRY_RUMORED_440192285504422993)],
        &[(0b11010, &ENTRY_RUMORER_13710023131538812640)],
        &[(0b11010, &ENTRY_RUMORERS_18193676553916096837)],
        &[(0b11010, &ENTRY_RUMORING_6988773240152687435)],
        &[(0b11010, &ENTRY_RUMORMONGER_16571412941503356230)],
        &[(0b11010, &ENTRY_RUMORMONGERS_3640300238053765249)],
        &[(0b11010, &ENTRY_RUMORS_12062925234185208276)],
    ],
    range: 2..=10,
};

static VARS_RUG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RUG_CHILDREN),
    value: None,
};

pub static VARS_RUG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gedisation"),
        dictgen::InsensitiveStr::Ascii("gedisations"),
        dictgen::InsensitiveStr::Ascii("gedise"),
        dictgen::InsensitiveStr::Ascii("gedised"),
        dictgen::InsensitiveStr::Ascii("gedises"),
        dictgen::InsensitiveStr::Ascii("gedising"),
        dictgen::InsensitiveStr::Ascii("gedization"),
        dictgen::InsensitiveStr::Ascii("gedizations"),
        dictgen::InsensitiveStr::Ascii("gedize"),
        dictgen::InsensitiveStr::Ascii("gedized"),
        dictgen::InsensitiveStr::Ascii("gedizes"),
        dictgen::InsensitiveStr::Ascii("gedizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RUGGEDIZATION_4464441313619036075)],
        &[(0b10010, &ENTRY_RUGGEDIZATIONS_15043895672134591753)],
        &[(0b10010, &ENTRY_RUGGEDIZE_217104043935831127)],
        &[(0b10010, &ENTRY_RUGGEDIZED_1442579612275114612)],
        &[(0b10010, &ENTRY_RUGGEDIZES_4636586194651066833)],
        &[(0b10010, &ENTRY_RUGGEDIZING_16816901556445020337)],
        &[(0b01001, &ENTRY_RUGGEDIZATION_4464441313619036075)],
        &[(0b01001, &ENTRY_RUGGEDIZATIONS_15043895672134591753)],
        &[(0b01001, &ENTRY_RUGGEDIZE_217104043935831127)],
        &[(0b01001, &ENTRY_RUGGEDIZED_1442579612275114612)],
        &[(0b01001, &ENTRY_RUGGEDIZES_4636586194651066833)],
        &[(0b01001, &ENTRY_RUGGEDIZING_16816901556445020337)],
    ],
    range: 6..=11,
};

static VARS_RUF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RUF_CHILDREN),
    value: None,
};

pub static VARS_RUF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fianise"),
        dictgen::InsensitiveStr::Ascii("fianises"),
        dictgen::InsensitiveStr::Ascii("fianize"),
        dictgen::InsensitiveStr::Ascii("fianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RUFFIANIZE_17478335968439303687)],
        &[(0b10010, &ENTRY_RUFFIANIZES_10939149941590833833)],
        &[(0b01001, &ENTRY_RUFFIANIZE_17478335968439303687)],
        &[(0b01001, &ENTRY_RUFFIANIZES_10939149941590833833)],
    ],
    range: 7..=8,
};

static VARS_RUB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RUB_CHILDREN),
    value: None,
};

pub static VARS_RUB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("berisation"),
        dictgen::InsensitiveStr::Ascii("berise"),
        dictgen::InsensitiveStr::Ascii("berised"),
        dictgen::InsensitiveStr::Ascii("berises"),
        dictgen::InsensitiveStr::Ascii("berising"),
        dictgen::InsensitiveStr::Ascii("berization"),
        dictgen::InsensitiveStr::Ascii("berize"),
        dictgen::InsensitiveStr::Ascii("berized"),
        dictgen::InsensitiveStr::Ascii("berizes"),
        dictgen::InsensitiveStr::Ascii("berizing"),
        dictgen::InsensitiveStr::Ascii("le"),
        dictgen::InsensitiveStr::Ascii("les"),
        dictgen::InsensitiveStr::Ascii("ricise"),
        dictgen::InsensitiveStr::Ascii("ricises"),
        dictgen::InsensitiveStr::Ascii("ricize"),
        dictgen::InsensitiveStr::Ascii("ricizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RUBBERIZATION_14360156161763362735)],
        &[(0b10010, &ENTRY_RUBBERIZE_12684219161328931610)],
        &[(0b10010, &ENTRY_RUBBERIZED_14611155806859179613)],
        &[(0b10010, &ENTRY_RUBBERIZES_2448401715198131266)],
        &[(0b10010, &ENTRY_RUBBERIZING_11711303490733810019)],
        &[(0b01001, &ENTRY_RUBBERIZATION_14360156161763362735)],
        &[(0b01001, &ENTRY_RUBBERIZE_12684219161328931610)],
        &[(0b01001, &ENTRY_RUBBERIZED_14611155806859179613)],
        &[(0b01001, &ENTRY_RUBBERIZES_2448401715198131266)],
        &[(0b01001, &ENTRY_RUBBERIZING_11711303490733810019)],
        &[(0b00001, &ENTRY_RUBLE_8353986414758489699)],
        &[(0b00001, &ENTRY_RUBLES_7609381998397963857)],
        &[(0b10010, &ENTRY_RUBRICIZE_18249275085584055504)],
        &[(0b10010, &ENTRY_RUBRICIZES_17489389230499978799)],
        &[(0b01001, &ENTRY_RUBRICIZE_18249275085584055504)],
        &[(0b01001, &ENTRY_RUBRICIZES_17489389230499978799)],
    ],
    range: 2..=10,
};

static VARS_RO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RO_CHILDREN),
    value: None,
};

static VARS_RO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_ROB_NODE),
    None,
    None,
    Some(&VARS_ROE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ROM_NODE),
    None,
    Some(&VARS_ROO_NODE),
    None,
    None,
    Some(&VARS_ROR_NODE),
    None,
    None,
    Some(&VARS_ROU_NODE),
    None,
    Some(&VARS_ROW_NODE),
    None,
    Some(&VARS_ROY_NODE),
    None,
];

static VARS_ROY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROY_CHILDREN),
    value: None,
};

pub static VARS_ROY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ROYALIZATION_16468895854636177158)],
        &[(0b10010, &ENTRY_ROYALIZATIONS_6505735151644810987)],
        &[(0b10010, &ENTRY_ROYALIZE_5734251532222541359)],
        &[(0b10010, &ENTRY_ROYALIZED_14657222300341657167)],
        &[(0b10010, &ENTRY_ROYALIZES_17689369586059121910)],
        &[(0b10010, &ENTRY_ROYALIZING_3947400302119184294)],
        &[(0b01001, &ENTRY_ROYALIZATION_16468895854636177158)],
        &[(0b01001, &ENTRY_ROYALIZATIONS_6505735151644810987)],
        &[(0b01001, &ENTRY_ROYALIZE_5734251532222541359)],
        &[(0b01001, &ENTRY_ROYALIZED_14657222300341657167)],
        &[(0b01001, &ENTRY_ROYALIZES_17689369586059121910)],
        &[(0b01001, &ENTRY_ROYALIZING_3947400302119184294)],
    ],
    range: 5..=10,
};

static VARS_ROW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROW_CHILDREN),
    value: None,
};

pub static VARS_ROW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
    ],
    values: &[
        &[(0b01001, &ENTRY_ROWELED_12947825968091277960)],
        &[(0b01001, &ENTRY_ROWELING_3646767635271162596)],
        &[(0b11010, &ENTRY_ROWELED_12947825968091277960)],
        &[(0b11010, &ENTRY_ROWELING_3646767635271162596)],
    ],
    range: 4..=6,
};

static VARS_ROU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROU_CHILDREN),
    value: None,
};

pub static VARS_ROU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ble"),
        dictgen::InsensitiveStr::Ascii("bles"),
        dictgen::InsensitiveStr::Ascii("mania"),
        dictgen::InsensitiveStr::Ascii("manias"),
        dictgen::InsensitiveStr::Ascii("tinisation"),
        dictgen::InsensitiveStr::Ascii("tinisations"),
        dictgen::InsensitiveStr::Ascii("tinise"),
        dictgen::InsensitiveStr::Ascii("tinised"),
        dictgen::InsensitiveStr::Ascii("tinises"),
        dictgen::InsensitiveStr::Ascii("tinising"),
        dictgen::InsensitiveStr::Ascii("tinization"),
        dictgen::InsensitiveStr::Ascii("tinizations"),
        dictgen::InsensitiveStr::Ascii("tinize"),
        dictgen::InsensitiveStr::Ascii("tinized"),
        dictgen::InsensitiveStr::Ascii("tinizes"),
        dictgen::InsensitiveStr::Ascii("tinizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_RUBLE_8353986414758489699)],
        &[(0b11010, &ENTRY_RUBLES_7609381998397963857)],
        &[(0b11010, &ENTRY_ROMANIA_4320567788734412103)],
        &[(0b11010, &ENTRY_ROMANIAS_12237588174128982109)],
        &[(0b10010, &ENTRY_ROUTINIZATION_17863253035896437203)],
        &[(0b10010, &ENTRY_ROUTINIZATIONS_2795005236388921160)],
        &[(0b10010, &ENTRY_ROUTINIZE_7572489982015879408)],
        &[(0b10010, &ENTRY_ROUTINIZED_4682046108054080633)],
        &[(0b10010, &ENTRY_ROUTINIZES_17936070643930576806)],
        &[(0b10010, &ENTRY_ROUTINIZING_807124837692788271)],
        &[(0b01001, &ENTRY_ROUTINIZATION_17863253035896437203)],
        &[(0b01001, &ENTRY_ROUTINIZATIONS_2795005236388921160)],
        &[(0b01001, &ENTRY_ROUTINIZE_7572489982015879408)],
        &[(0b01001, &ENTRY_ROUTINIZED_4682046108054080633)],
        &[(0b01001, &ENTRY_ROUTINIZES_17936070643930576806)],
        &[(0b01001, &ENTRY_ROUTINIZING_807124837692788271)],
    ],
    range: 3..=11,
};

static VARS_ROR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROR_CHILDREN),
    value: None,
};

pub static VARS_ROR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b11010, &ENTRY_ROER_2952923842519664515)]],
    range: 1..=1,
};

static VARS_ROO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROO_CHILDREN),
    value: None,
};

pub static VARS_ROO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ed")],
    values: &[&[(0b11010, &ENTRY_ROED_4005322299752850400)]],
    range: 2..=2,
};

static VARS_ROM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROM_CHILDREN),
    value: None,
};

pub static VARS_ROM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ania"),
        dictgen::InsensitiveStr::Ascii("anias"),
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anisations"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("aniser"),
        dictgen::InsensitiveStr::Ascii("anisers"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anizations"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizer"),
        dictgen::InsensitiveStr::Ascii("anizers"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("anticisation"),
        dictgen::InsensitiveStr::Ascii("anticisations"),
        dictgen::InsensitiveStr::Ascii("anticise"),
        dictgen::InsensitiveStr::Ascii("anticised"),
        dictgen::InsensitiveStr::Ascii("anticises"),
        dictgen::InsensitiveStr::Ascii("anticising"),
        dictgen::InsensitiveStr::Ascii("anticization"),
        dictgen::InsensitiveStr::Ascii("anticizations"),
        dictgen::InsensitiveStr::Ascii("anticize"),
        dictgen::InsensitiveStr::Ascii("anticized"),
        dictgen::InsensitiveStr::Ascii("anticizes"),
        dictgen::InsensitiveStr::Ascii("anticizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ROMANIA_4320567788734412103)],
        &[(0b00001, &ENTRY_ROMANIAS_12237588174128982109)],
        &[(0b10010, &ENTRY_ROMANIZATION_8560046577492680615)],
        &[(0b10010, &ENTRY_ROMANIZATIONS_870204756988951102)],
        &[(0b10010, &ENTRY_ROMANIZE_17828022341300623695)],
        &[(0b10010, &ENTRY_ROMANIZED_11325302352054785292)],
        &[(0b10010, &ENTRY_ROMANIZER_11428635145822485637)],
        &[(0b10010, &ENTRY_ROMANIZERS_16309654375180006599)],
        &[(0b10010, &ENTRY_ROMANIZES_14316864401141443537)],
        &[(0b10010, &ENTRY_ROMANIZING_6533972516331684265)],
        &[(0b01001, &ENTRY_ROMANIZATION_8560046577492680615)],
        &[(0b01001, &ENTRY_ROMANIZATIONS_870204756988951102)],
        &[(0b01001, &ENTRY_ROMANIZE_17828022341300623695)],
        &[(0b01001, &ENTRY_ROMANIZED_11325302352054785292)],
        &[(0b01001, &ENTRY_ROMANIZER_11428635145822485637)],
        &[(0b01001, &ENTRY_ROMANIZERS_16309654375180006599)],
        &[(0b01001, &ENTRY_ROMANIZES_14316864401141443537)],
        &[(0b01001, &ENTRY_ROMANIZING_6533972516331684265)],
        &[(0b10010, &ENTRY_ROMANTICIZATION_98519846053872295)],
        &[(0b10010, &ENTRY_ROMANTICIZATIONS_14917933992160685773)],
        &[(0b10010, &ENTRY_ROMANTICIZE_12085162654923168482)],
        &[(0b10010, &ENTRY_ROMANTICIZED_6690263810463145292)],
        &[(0b10010, &ENTRY_ROMANTICIZES_7010079394357286132)],
        &[(0b10010, &ENTRY_ROMANTICIZING_7886244968785418156)],
        &[(0b01001, &ENTRY_ROMANTICIZATION_98519846053872295)],
        &[(0b01001, &ENTRY_ROMANTICIZATIONS_14917933992160685773)],
        &[(0b01001, &ENTRY_ROMANTICIZE_12085162654923168482)],
        &[(0b01001, &ENTRY_ROMANTICIZED_6690263810463145292)],
        &[(0b01001, &ENTRY_ROMANTICIZES_7010079394357286132)],
        &[(0b01001, &ENTRY_ROMANTICIZING_7886244968785418156)],
    ],
    range: 4..=13,
};

static VARS_ROE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROE_CHILDREN),
    value: None,
};

pub static VARS_ROE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("hm"),
        dictgen::InsensitiveStr::Ascii("ntgenise"),
        dictgen::InsensitiveStr::Ascii("ntgenize"),
        dictgen::InsensitiveStr::Ascii("r"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ROED_4005322299752850400)],
        &[(0b11010, &ENTRY_REHM_3696542319302039545)],
        &[(0b10010, &ENTRY_ROENTGENIZE_2577537657952804248)],
        &[(0b01001, &ENTRY_ROENTGENIZE_2577537657952804248)],
        &[(0b00001, &ENTRY_ROER_2952923842519664515)],
    ],
    range: 1..=8,
};

static VARS_ROB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROB_CHILDREN),
    value: None,
};

pub static VARS_ROB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("otisation"),
        dictgen::InsensitiveStr::Ascii("otisations"),
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otised"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otising"),
        dictgen::InsensitiveStr::Ascii("otization"),
        dictgen::InsensitiveStr::Ascii("otizations"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otized"),
        dictgen::InsensitiveStr::Ascii("otizes"),
        dictgen::InsensitiveStr::Ascii("otizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ROBOTIZATION_10850862175275622758)],
        &[(0b10010, &ENTRY_ROBOTIZATIONS_17425010007834309500)],
        &[(0b10010, &ENTRY_ROBOTIZE_12113166233450095442)],
        &[(0b10010, &ENTRY_ROBOTIZED_5530996200469975174)],
        &[(0b10010, &ENTRY_ROBOTIZES_6429276732898466559)],
        &[(0b10010, &ENTRY_ROBOTIZING_16303228955863605624)],
        &[(0b01001, &ENTRY_ROBOTIZATION_10850862175275622758)],
        &[(0b01001, &ENTRY_ROBOTIZATIONS_17425010007834309500)],
        &[(0b01001, &ENTRY_ROBOTIZE_12113166233450095442)],
        &[(0b01001, &ENTRY_ROBOTIZED_5530996200469975174)],
        &[(0b01001, &ENTRY_ROBOTIZES_6429276732898466559)],
        &[(0b01001, &ENTRY_ROBOTIZING_16303228955863605624)],
    ],
    range: 5..=10,
};

static VARS_RI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RI_CHILDREN),
    value: None,
};

pub static VARS_RI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("diculise"),
        dictgen::InsensitiveStr::Ascii("diculises"),
        dictgen::InsensitiveStr::Ascii("diculize"),
        dictgen::InsensitiveStr::Ascii("diculizes"),
        dictgen::InsensitiveStr::Ascii("gidise"),
        dictgen::InsensitiveStr::Ascii("gidised"),
        dictgen::InsensitiveStr::Ascii("gidises"),
        dictgen::InsensitiveStr::Ascii("gidising"),
        dictgen::InsensitiveStr::Ascii("gidize"),
        dictgen::InsensitiveStr::Ascii("gidized"),
        dictgen::InsensitiveStr::Ascii("gidizes"),
        dictgen::InsensitiveStr::Ascii("gidizing"),
        dictgen::InsensitiveStr::Ascii("gor"),
        dictgen::InsensitiveStr::Ascii("gorism"),
        dictgen::InsensitiveStr::Ascii("gorist"),
        dictgen::InsensitiveStr::Ascii("goristic"),
        dictgen::InsensitiveStr::Ascii("gors"),
        dictgen::InsensitiveStr::Ascii("gour"),
        dictgen::InsensitiveStr::Ascii("gourism"),
        dictgen::InsensitiveStr::Ascii("gourist"),
        dictgen::InsensitiveStr::Ascii("gouristic"),
        dictgen::InsensitiveStr::Ascii("gours"),
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otizes"),
        dictgen::InsensitiveStr::Ascii("tornelle"),
        dictgen::InsensitiveStr::Ascii("tornelles"),
        dictgen::InsensitiveStr::Ascii("tournelle"),
        dictgen::InsensitiveStr::Ascii("tournelles"),
        dictgen::InsensitiveStr::Ascii("tualisation"),
        dictgen::InsensitiveStr::Ascii("tualisations"),
        dictgen::InsensitiveStr::Ascii("tualise"),
        dictgen::InsensitiveStr::Ascii("tualised"),
        dictgen::InsensitiveStr::Ascii("tualises"),
        dictgen::InsensitiveStr::Ascii("tualising"),
        dictgen::InsensitiveStr::Ascii("tualization"),
        dictgen::InsensitiveStr::Ascii("tualizations"),
        dictgen::InsensitiveStr::Ascii("tualize"),
        dictgen::InsensitiveStr::Ascii("tualized"),
        dictgen::InsensitiveStr::Ascii("tualizes"),
        dictgen::InsensitiveStr::Ascii("tualizing"),
        dictgen::InsensitiveStr::Ascii("valed"),
        dictgen::InsensitiveStr::Ascii("valess"),
        dictgen::InsensitiveStr::Ascii("valesses"),
        dictgen::InsensitiveStr::Ascii("valing"),
        dictgen::InsensitiveStr::Ascii("valise"),
        dictgen::InsensitiveStr::Ascii("valised"),
        dictgen::InsensitiveStr::Ascii("valises"),
        dictgen::InsensitiveStr::Ascii("valising"),
        dictgen::InsensitiveStr::Ascii("valize"),
        dictgen::InsensitiveStr::Ascii("valized"),
        dictgen::InsensitiveStr::Ascii("valizes"),
        dictgen::InsensitiveStr::Ascii("valizing"),
        dictgen::InsensitiveStr::Ascii("valled"),
        dictgen::InsensitiveStr::Ascii("valless"),
        dictgen::InsensitiveStr::Ascii("vallesses"),
        dictgen::InsensitiveStr::Ascii("valling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RIDICULIZE_11800231737801084094)],
        &[(0b10010, &ENTRY_RIDICULIZES_6019689684453486199)],
        &[(0b01001, &ENTRY_RIDICULIZE_11800231737801084094)],
        &[(0b01001, &ENTRY_RIDICULIZES_6019689684453486199)],
        &[(0b10010, &ENTRY_RIGIDIZE_13876511868517551670)],
        &[(0b10010, &ENTRY_RIGIDIZED_10283429518521342894)],
        &[(0b10010, &ENTRY_RIGIDIZES_14178846988626829524)],
        &[(0b10010, &ENTRY_RIGIDIZING_12179399956370664115)],
        &[(0b01001, &ENTRY_RIGIDIZE_13876511868517551670)],
        &[(0b01001, &ENTRY_RIGIDIZED_10283429518521342894)],
        &[(0b01001, &ENTRY_RIGIDIZES_14178846988626829524)],
        &[(0b01001, &ENTRY_RIGIDIZING_12179399956370664115)],
        &[(0b11001, &ENTRY_RIGOR_13840324324485661310)],
        &[(0b00001, &ENTRY_RIGORISM_13132314746805145944)],
        &[(0b00001, &ENTRY_RIGORIST_9002163466917196639)],
        &[(0b00001, &ENTRY_RIGORISTIC_2875620626641348885)],
        &[(0b11001, &ENTRY_RIGORS_3068318220888831390)],
        &[(0b11010, &ENTRY_RIGOR_13840324324485661310)],
        &[(0b11010, &ENTRY_RIGORISM_13132314746805145944)],
        &[(0b11010, &ENTRY_RIGORIST_9002163466917196639)],
        &[(0b11010, &ENTRY_RIGORISTIC_2875620626641348885)],
        &[(0b11010, &ENTRY_RIGORS_3068318220888831390)],
        &[(0b10010, &ENTRY_RIOTIZE_9780442096384725615)],
        &[(0b10010, &ENTRY_RIOTIZES_2377945734094166848)],
        &[(0b01001, &ENTRY_RIOTIZE_9780442096384725615)],
        &[(0b01001, &ENTRY_RIOTIZES_2377945734094166848)],
        &[(0b00001, &ENTRY_RITORNELLE_7468653839028445523)],
        &[(0b00001, &ENTRY_RITORNELLES_14904170523270958508)],
        &[(0b11010, &ENTRY_RITORNELLE_7468653839028445523)],
        &[(0b11010, &ENTRY_RITORNELLES_14904170523270958508)],
        &[(0b10010, &ENTRY_RITUALIZATION_17342697987838586636)],
        &[(0b10010, &ENTRY_RITUALIZATIONS_8869257737053182647)],
        &[(0b10010, &ENTRY_RITUALIZE_12932718365597780903)],
        &[(0b10010, &ENTRY_RITUALIZED_4837360641797207469)],
        &[(0b10010, &ENTRY_RITUALIZES_17901433018773934503)],
        &[(0b10010, &ENTRY_RITUALIZING_17963863299966783179)],
        &[(0b01001, &ENTRY_RITUALIZATION_17342697987838586636)],
        &[(0b01001, &ENTRY_RITUALIZATIONS_8869257737053182647)],
        &[(0b01001, &ENTRY_RITUALIZE_12932718365597780903)],
        &[(0b01001, &ENTRY_RITUALIZED_4837360641797207469)],
        &[(0b01001, &ENTRY_RITUALIZES_17901433018773934503)],
        &[(0b01001, &ENTRY_RITUALIZING_17963863299966783179)],
        &[(0b00001, &ENTRY_RIVALED_10007684086261671851)],
        &[(0b00001, &ENTRY_RIVALESS_5502653831370349272)],
        &[(0b00001, &ENTRY_RIVALESSES_17509619766008391554)],
        &[(0b00001, &ENTRY_RIVALING_9971938631235821729)],
        &[(0b10010, &ENTRY_RIVALIZE_1647304959804156795)],
        &[(0b10010, &ENTRY_RIVALIZED_8927862304000561016)],
        &[(0b10010, &ENTRY_RIVALIZES_16489774221336799701)],
        &[(0b10010, &ENTRY_RIVALIZING_2604324608436302981)],
        &[(0b01001, &ENTRY_RIVALIZE_1647304959804156795)],
        &[(0b01001, &ENTRY_RIVALIZED_8927862304000561016)],
        &[(0b01001, &ENTRY_RIVALIZES_16489774221336799701)],
        &[(0b01001, &ENTRY_RIVALIZING_2604324608436302981)],
        &[(0b11010, &ENTRY_RIVALED_10007684086261671851)],
        &[(0b11010, &ENTRY_RIVALESS_5502653831370349272)],
        &[(0b11010, &ENTRY_RIVALESSES_17509619766008391554)],
        &[(0b11010, &ENTRY_RIVALING_9971938631235821729)],
    ],
    range: 3..=12,
};

static VARS_RH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RH_CHILDREN),
    value: None,
};

static VARS_RH_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_RHA_NODE),
    None,
    None,
    None,
    Some(&VARS_RHE_NODE),
    None,
    None,
    None,
    Some(&VARS_RHI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RHO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RHY_NODE),
    None,
];

static VARS_RHY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RHY_CHILDREN),
    value: None,
};

pub static VARS_RHY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thmicise"),
        dictgen::InsensitiveStr::Ascii("thmicises"),
        dictgen::InsensitiveStr::Ascii("thmicize"),
        dictgen::InsensitiveStr::Ascii("thmicizes"),
        dictgen::InsensitiveStr::Ascii("thmisable"),
        dictgen::InsensitiveStr::Ascii("thmisables"),
        dictgen::InsensitiveStr::Ascii("thmisation"),
        dictgen::InsensitiveStr::Ascii("thmisations"),
        dictgen::InsensitiveStr::Ascii("thmise"),
        dictgen::InsensitiveStr::Ascii("thmised"),
        dictgen::InsensitiveStr::Ascii("thmises"),
        dictgen::InsensitiveStr::Ascii("thmising"),
        dictgen::InsensitiveStr::Ascii("thmizable"),
        dictgen::InsensitiveStr::Ascii("thmizables"),
        dictgen::InsensitiveStr::Ascii("thmization"),
        dictgen::InsensitiveStr::Ascii("thmizations"),
        dictgen::InsensitiveStr::Ascii("thmize"),
        dictgen::InsensitiveStr::Ascii("thmized"),
        dictgen::InsensitiveStr::Ascii("thmizes"),
        dictgen::InsensitiveStr::Ascii("thmizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RHYTHMICIZE_2568291653869163877)],
        &[(0b10010, &ENTRY_RHYTHMICIZES_6750605402374538800)],
        &[(0b01001, &ENTRY_RHYTHMICIZE_2568291653869163877)],
        &[(0b01001, &ENTRY_RHYTHMICIZES_6750605402374538800)],
        &[(0b10010, &ENTRY_RHYTHMIZABLE_1579755278846162123)],
        &[(0b10010, &ENTRY_RHYTHMIZABLES_16724509145153469612)],
        &[(0b10010, &ENTRY_RHYTHMIZATION_6091508663979892277)],
        &[(0b10010, &ENTRY_RHYTHMIZATIONS_2864181387444036458)],
        &[(0b10010, &ENTRY_RHYTHMIZE_9209031730374842797)],
        &[(0b10010, &ENTRY_RHYTHMIZED_12905954271885700288)],
        &[(0b10010, &ENTRY_RHYTHMIZES_15972108371856453286)],
        &[(0b10010, &ENTRY_RHYTHMIZING_1031028778051496999)],
        &[(0b01001, &ENTRY_RHYTHMIZABLE_1579755278846162123)],
        &[(0b01001, &ENTRY_RHYTHMIZABLES_16724509145153469612)],
        &[(0b01001, &ENTRY_RHYTHMIZATION_6091508663979892277)],
        &[(0b01001, &ENTRY_RHYTHMIZATIONS_2864181387444036458)],
        &[(0b01001, &ENTRY_RHYTHMIZE_9209031730374842797)],
        &[(0b01001, &ENTRY_RHYTHMIZED_12905954271885700288)],
        &[(0b01001, &ENTRY_RHYTHMIZES_15972108371856453286)],
        &[(0b01001, &ENTRY_RHYTHMIZING_1031028778051496999)],
    ],
    range: 6..=11,
};

static VARS_RHO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RHO_CHILDREN),
    value: None,
};

pub static VARS_RHO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("danise"),
        dictgen::InsensitiveStr::Ascii("danised"),
        dictgen::InsensitiveStr::Ascii("danises"),
        dictgen::InsensitiveStr::Ascii("danising"),
        dictgen::InsensitiveStr::Ascii("danize"),
        dictgen::InsensitiveStr::Ascii("danized"),
        dictgen::InsensitiveStr::Ascii("danizes"),
        dictgen::InsensitiveStr::Ascii("danizing"),
        dictgen::InsensitiveStr::Ascii("eadine"),
        dictgen::InsensitiveStr::Ascii("tacise"),
        dictgen::InsensitiveStr::Ascii("tacised"),
        dictgen::InsensitiveStr::Ascii("tacises"),
        dictgen::InsensitiveStr::Ascii("tacising"),
        dictgen::InsensitiveStr::Ascii("tacize"),
        dictgen::InsensitiveStr::Ascii("tacized"),
        dictgen::InsensitiveStr::Ascii("tacizes"),
        dictgen::InsensitiveStr::Ascii("tacizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RHODANIZE_4028147647059435010)],
        &[(0b10010, &ENTRY_RHODANIZED_1994856248412297421)],
        &[(0b10010, &ENTRY_RHODANIZES_16723502090569823135)],
        &[(0b10010, &ENTRY_RHODANIZING_6600196086306540651)],
        &[(0b01001, &ENTRY_RHODANIZE_4028147647059435010)],
        &[(0b01001, &ENTRY_RHODANIZED_1994856248412297421)],
        &[(0b01001, &ENTRY_RHODANIZES_16723502090569823135)],
        &[(0b01001, &ENTRY_RHODANIZING_6600196086306540651)],
        &[(0b11010, &ENTRY_RHEADINE_17572840070808796479)],
        &[(0b10010, &ENTRY_RHOTACIZE_2252201772265866826)],
        &[(0b10010, &ENTRY_RHOTACIZED_2852510490082790029)],
        &[(0b10010, &ENTRY_RHOTACIZES_7282806474686539140)],
        &[(0b10010, &ENTRY_RHOTACIZING_5983232023338121234)],
        &[(0b01001, &ENTRY_RHOTACIZE_2252201772265866826)],
        &[(0b01001, &ENTRY_RHOTACIZED_2852510490082790029)],
        &[(0b01001, &ENTRY_RHOTACIZES_7282806474686539140)],
        &[(0b01001, &ENTRY_RHOTACIZING_5983232023338121234)],
    ],
    range: 6..=8,
};

static VARS_RHI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RHI_CHILDREN),
    value: None,
};

pub static VARS_RHI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nocele"),
        dictgen::InsensitiveStr::Ascii("nocelian"),
        dictgen::InsensitiveStr::Ascii("nocoele"),
        dictgen::InsensitiveStr::Ascii("nocoelian"),
        dictgen::InsensitiveStr::Ascii("norrhea"),
        dictgen::InsensitiveStr::Ascii("norrheal"),
        dictgen::InsensitiveStr::Ascii("norrhoea"),
        dictgen::InsensitiveStr::Ascii("norrhoeal"),
    ],
    values: &[
        &[(0b00001, &ENTRY_RHINOCELE_174829405093096946)],
        &[(0b00001, &ENTRY_RHINOCELIAN_16591957799590718552)],
        &[(0b11010, &ENTRY_RHINOCELE_174829405093096946)],
        &[(0b11010, &ENTRY_RHINOCELIAN_16591957799590718552)],
        &[(0b00001, &ENTRY_RHINORRHEA_7736143842252392789)],
        &[(0b00001, &ENTRY_RHINORRHEAL_6431844651516367333)],
        &[(0b11010, &ENTRY_RHINORRHEA_7736143842252392789)],
        &[(0b11010, &ENTRY_RHINORRHEAL_6431844651516367333)],
    ],
    range: 6..=9,
};

static VARS_RHE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RHE_CHILDREN),
    value: None,
};

pub static VARS_RHE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("adine"),
        dictgen::InsensitiveStr::Ascii("bosis"),
        dictgen::InsensitiveStr::Ascii("tian"),
        dictgen::InsensitiveStr::Ascii("tic"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torised"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torising"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torized"),
        dictgen::InsensitiveStr::Ascii("torizes"),
        dictgen::InsensitiveStr::Ascii("torizing"),
        dictgen::InsensitiveStr::Ascii("umatise"),
        dictgen::InsensitiveStr::Ascii("umatised"),
        dictgen::InsensitiveStr::Ascii("umatises"),
        dictgen::InsensitiveStr::Ascii("umatising"),
        dictgen::InsensitiveStr::Ascii("umatize"),
        dictgen::InsensitiveStr::Ascii("umatized"),
        dictgen::InsensitiveStr::Ascii("umatizes"),
        dictgen::InsensitiveStr::Ascii("umatizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_RHEADINE_17572840070808796479)],
        &[(0b00001, &ENTRY_RHEBOSIS_15346112661104796425)],
        &[(0b00001, &ENTRY_RHETIAN_534728823910367064)],
        &[(0b00001, &ENTRY_RHETIC_12924080598897141505)],
        &[(0b10010, &ENTRY_RHETORIZE_2537262982948879204)],
        &[(0b10010, &ENTRY_RHETORIZED_11335389769662920882)],
        &[(0b10010, &ENTRY_RHETORIZES_11133222000386712600)],
        &[(0b10010, &ENTRY_RHETORIZING_12662060917901718915)],
        &[(0b01001, &ENTRY_RHETORIZE_2537262982948879204)],
        &[(0b01001, &ENTRY_RHETORIZED_11335389769662920882)],
        &[(0b01001, &ENTRY_RHETORIZES_11133222000386712600)],
        &[(0b01001, &ENTRY_RHETORIZING_12662060917901718915)],
        &[(0b10010, &ENTRY_RHEUMATIZE_17276783343159397264)],
        &[(0b10010, &ENTRY_RHEUMATIZED_6912521646064787206)],
        &[(0b10010, &ENTRY_RHEUMATIZES_16882230147167842816)],
        &[(0b10010, &ENTRY_RHEUMATIZING_5948133421182699653)],
        &[(0b01001, &ENTRY_RHEUMATIZE_17276783343159397264)],
        &[(0b01001, &ENTRY_RHEUMATIZED_6912521646064787206)],
        &[(0b01001, &ENTRY_RHEUMATIZES_16882230147167842816)],
        &[(0b01001, &ENTRY_RHEUMATIZING_5948133421182699653)],
    ],
    range: 3..=9,
};

static VARS_RHA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RHA_CHILDREN),
    value: None,
};

pub static VARS_RHA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ebosis"),
        dictgen::InsensitiveStr::Ascii("etian"),
        dictgen::InsensitiveStr::Ascii("etic"),
        dictgen::InsensitiveStr::Ascii("phae"),
        dictgen::InsensitiveStr::Ascii("phe"),
        dictgen::InsensitiveStr::Ascii("psodise"),
        dictgen::InsensitiveStr::Ascii("psodised"),
        dictgen::InsensitiveStr::Ascii("psodises"),
        dictgen::InsensitiveStr::Ascii("psodising"),
        dictgen::InsensitiveStr::Ascii("psodize"),
        dictgen::InsensitiveStr::Ascii("psodized"),
        dictgen::InsensitiveStr::Ascii("psodizes"),
        dictgen::InsensitiveStr::Ascii("psodizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_RHEBOSIS_15346112661104796425)],
        &[(0b11010, &ENTRY_RHETIAN_534728823910367064)],
        &[(0b11010, &ENTRY_RHETIC_12924080598897141505)],
        &[(0b11010, &ENTRY_RHAPHE_3287184404322248274)],
        &[(0b00001, &ENTRY_RHAPHE_3287184404322248274)],
        &[(0b10010, &ENTRY_RHAPSODIZE_8592901551161811550)],
        &[(0b10010, &ENTRY_RHAPSODIZED_16882300059855716248)],
        &[(0b10010, &ENTRY_RHAPSODIZES_8543334345807282409)],
        &[(0b10010, &ENTRY_RHAPSODIZING_9325748671831046103)],
        &[(0b01001, &ENTRY_RHAPSODIZE_8592901551161811550)],
        &[(0b01001, &ENTRY_RHAPSODIZED_16882300059855716248)],
        &[(0b01001, &ENTRY_RHAPSODIZES_8543334345807282409)],
        &[(0b01001, &ENTRY_RHAPSODIZING_9325748671831046103)],
    ],
    range: 3..=9,
};

static VARS_RE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RE_CHILDREN),
    value: None,
};

static VARS_RE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_REA_NODE),
    Some(&VARS_REB_NODE),
    Some(&VARS_REC_NODE),
    Some(&VARS_RED_NODE),
    Some(&VARS_REE_NODE),
    Some(&VARS_REF_NODE),
    Some(&VARS_REG_NODE),
    Some(&VARS_REH_NODE),
    Some(&VARS_REI_NODE),
    Some(&VARS_REJ_NODE),
    Some(&VARS_REK_NODE),
    Some(&VARS_REL_NODE),
    Some(&VARS_REM_NODE),
    Some(&VARS_REN_NODE),
    Some(&VARS_REO_NODE),
    Some(&VARS_REP_NODE),
    None,
    Some(&VARS_RER_NODE),
    Some(&VARS_RES_NODE),
    Some(&VARS_RET_NODE),
    Some(&VARS_REU_NODE),
    Some(&VARS_REV_NODE),
    None,
    Some(&VARS_REX_NODE),
    None,
    None,
];

static VARS_REX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REX_CHILDREN),
    value: None,
};

pub static VARS_REX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ford"),
        dictgen::InsensitiveStr::Ascii("fourd"),
    ],
    values: &[
        &[(0b00001, &ENTRY_REXFORD_592979619748065087)],
        &[(0b11010, &ENTRY_REXFORD_592979619748065087)],
    ],
    range: 4..=5,
};

static VARS_REV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_REV_CHILDREN),
    value: None,
};

static VARS_REV_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_REVA_NODE),
    None,
    None,
    None,
    Some(&VARS_REVE_NODE),
    None,
    None,
    None,
    Some(&VARS_REVI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_REVO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_REVO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REVO_CHILDREN),
    value: None,
};

pub static VARS_REVO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("latilise"),
        dictgen::InsensitiveStr::Ascii("latilises"),
        dictgen::InsensitiveStr::Ascii("latilize"),
        dictgen::InsensitiveStr::Ascii("latilizes"),
        dictgen::InsensitiveStr::Ascii("lutionise"),
        dictgen::InsensitiveStr::Ascii("lutionised"),
        dictgen::InsensitiveStr::Ascii("lutionisement"),
        dictgen::InsensitiveStr::Ascii("lutionisements"),
        dictgen::InsensitiveStr::Ascii("lutioniser"),
        dictgen::InsensitiveStr::Ascii("lutionisers"),
        dictgen::InsensitiveStr::Ascii("lutionises"),
        dictgen::InsensitiveStr::Ascii("lutionising"),
        dictgen::InsensitiveStr::Ascii("lutionize"),
        dictgen::InsensitiveStr::Ascii("lutionized"),
        dictgen::InsensitiveStr::Ascii("lutionizement"),
        dictgen::InsensitiveStr::Ascii("lutionizements"),
        dictgen::InsensitiveStr::Ascii("lutionizer"),
        dictgen::InsensitiveStr::Ascii("lutionizers"),
        dictgen::InsensitiveStr::Ascii("lutionizes"),
        dictgen::InsensitiveStr::Ascii("lutionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REVOLATILIZE_15213340201484859604)],
        &[(0b10010, &ENTRY_REVOLATILIZES_12548329149855212611)],
        &[(0b01001, &ENTRY_REVOLATILIZE_15213340201484859604)],
        &[(0b01001, &ENTRY_REVOLATILIZES_12548329149855212611)],
        &[(0b10010, &ENTRY_REVOLUTIONIZE_3470055274275469616)],
        &[(0b10010, &ENTRY_REVOLUTIONIZED_17229010415616229254)],
        &[(0b10010, &ENTRY_REVOLUTIONIZEMENT_16990519803204481080)],
        &[(0b10010, &ENTRY_REVOLUTIONIZEMENTS_9485600286916070301)],
        &[(0b10010, &ENTRY_REVOLUTIONIZER_13676086032738364882)],
        &[(0b10010, &ENTRY_REVOLUTIONIZERS_16952271029767079136)],
        &[(0b10010, &ENTRY_REVOLUTIONIZES_11138653471155510637)],
        &[(0b10010, &ENTRY_REVOLUTIONIZING_12791238819359973912)],
        &[(0b01001, &ENTRY_REVOLUTIONIZE_3470055274275469616)],
        &[(0b01001, &ENTRY_REVOLUTIONIZED_17229010415616229254)],
        &[(0b01001, &ENTRY_REVOLUTIONIZEMENT_16990519803204481080)],
        &[(0b01001, &ENTRY_REVOLUTIONIZEMENTS_9485600286916070301)],
        &[(0b01001, &ENTRY_REVOLUTIONIZER_13676086032738364882)],
        &[(0b01001, &ENTRY_REVOLUTIONIZERS_16952271029767079136)],
        &[(0b01001, &ENTRY_REVOLUTIONIZES_11138653471155510637)],
        &[(0b01001, &ENTRY_REVOLUTIONIZING_12791238819359973912)],
    ],
    range: 8..=14,
};

static VARS_REVI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REVI_CHILDREN),
    value: None,
};

pub static VARS_REVI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gor"),
        dictgen::InsensitiveStr::Ascii("gour"),
        dictgen::InsensitiveStr::Ascii("sualisation"),
        dictgen::InsensitiveStr::Ascii("sualisations"),
        dictgen::InsensitiveStr::Ascii("sualise"),
        dictgen::InsensitiveStr::Ascii("sualises"),
        dictgen::InsensitiveStr::Ascii("sualization"),
        dictgen::InsensitiveStr::Ascii("sualizations"),
        dictgen::InsensitiveStr::Ascii("sualize"),
        dictgen::InsensitiveStr::Ascii("sualizes"),
        dictgen::InsensitiveStr::Ascii("talisation"),
        dictgen::InsensitiveStr::Ascii("talisations"),
        dictgen::InsensitiveStr::Ascii("talise"),
        dictgen::InsensitiveStr::Ascii("talised"),
        dictgen::InsensitiveStr::Ascii("taliser"),
        dictgen::InsensitiveStr::Ascii("talisers"),
        dictgen::InsensitiveStr::Ascii("talises"),
        dictgen::InsensitiveStr::Ascii("talising"),
        dictgen::InsensitiveStr::Ascii("talization"),
        dictgen::InsensitiveStr::Ascii("talizations"),
        dictgen::InsensitiveStr::Ascii("talize"),
        dictgen::InsensitiveStr::Ascii("talized"),
        dictgen::InsensitiveStr::Ascii("talizer"),
        dictgen::InsensitiveStr::Ascii("talizers"),
        dictgen::InsensitiveStr::Ascii("talizes"),
        dictgen::InsensitiveStr::Ascii("talizing"),
        dictgen::InsensitiveStr::Ascii("valise"),
        dictgen::InsensitiveStr::Ascii("valises"),
        dictgen::InsensitiveStr::Ascii("valize"),
        dictgen::InsensitiveStr::Ascii("valizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_REVIGOR_2801049938904171472)],
        &[(0b11010, &ENTRY_REVIGOR_2801049938904171472)],
        &[(0b10010, &ENTRY_REVISUALIZATION_4385706580546598224)],
        &[(0b10010, &ENTRY_REVISUALIZATIONS_12115779584679618149)],
        &[(0b10010, &ENTRY_REVISUALIZE_1804017224578296798)],
        &[(0b10010, &ENTRY_REVISUALIZES_12799696931941951677)],
        &[(0b01001, &ENTRY_REVISUALIZATION_4385706580546598224)],
        &[(0b01001, &ENTRY_REVISUALIZATIONS_12115779584679618149)],
        &[(0b01001, &ENTRY_REVISUALIZE_1804017224578296798)],
        &[(0b01001, &ENTRY_REVISUALIZES_12799696931941951677)],
        &[(0b10010, &ENTRY_REVITALIZATION_16085757167990752927)],
        &[(0b10010, &ENTRY_REVITALIZATIONS_18307091255909150620)],
        &[(0b10010, &ENTRY_REVITALIZE_6139669234338764878)],
        &[(0b10010, &ENTRY_REVITALIZED_150745644348740042)],
        &[(0b10010, &ENTRY_REVITALIZER_3537189352148158886)],
        &[(0b10010, &ENTRY_REVITALIZERS_3771612271540013270)],
        &[(0b10010, &ENTRY_REVITALIZES_636040321623977777)],
        &[(0b10010, &ENTRY_REVITALIZING_2708402192275645435)],
        &[(0b01001, &ENTRY_REVITALIZATION_16085757167990752927)],
        &[(0b01001, &ENTRY_REVITALIZATIONS_18307091255909150620)],
        &[(0b01001, &ENTRY_REVITALIZE_6139669234338764878)],
        &[(0b01001, &ENTRY_REVITALIZED_150745644348740042)],
        &[(0b01001, &ENTRY_REVITALIZER_3537189352148158886)],
        &[(0b01001, &ENTRY_REVITALIZERS_3771612271540013270)],
        &[(0b01001, &ENTRY_REVITALIZES_636040321623977777)],
        &[(0b01001, &ENTRY_REVITALIZING_2708402192275645435)],
        &[(0b10010, &ENTRY_REVIVALIZE_9628710875428300128)],
        &[(0b10010, &ENTRY_REVIVALIZES_10827402937094948947)],
        &[(0b01001, &ENTRY_REVIVALIZE_9628710875428300128)],
        &[(0b01001, &ENTRY_REVIVALIZES_10827402937094948947)],
    ],
    range: 3..=12,
};

static VARS_REVE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REVE_CHILDREN),
    value: None,
};

pub static VARS_REVE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lationise"),
        dictgen::InsensitiveStr::Ascii("lationises"),
        dictgen::InsensitiveStr::Ascii("lationize"),
        dictgen::InsensitiveStr::Ascii("lationizes"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lings"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("ller"),
        dictgen::InsensitiveStr::Ascii("llers"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("llings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REVELATIONIZE_2525772824776587394)],
        &[(0b10010, &ENTRY_REVELATIONIZES_7348701606986945383)],
        &[(0b01001, &ENTRY_REVELATIONIZE_2525772824776587394)],
        &[(0b01001, &ENTRY_REVELATIONIZES_7348701606986945383)],
        &[(0b00001, &ENTRY_REVELED_10192387357620140676)],
        &[(0b00001, &ENTRY_REVELER_8384109924943712265)],
        &[(0b00001, &ENTRY_REVELERS_9470175687026840)],
        &[(0b00001, &ENTRY_REVELING_59082295884336446)],
        &[(0b00001, &ENTRY_REVELINGS_4220623056617091529)],
        &[(0b11010, &ENTRY_REVELED_10192387357620140676)],
        &[(0b11010, &ENTRY_REVELER_8384109924943712265)],
        &[(0b11010, &ENTRY_REVELERS_9470175687026840)],
        &[(0b11010, &ENTRY_REVELING_59082295884336446)],
        &[(0b11010, &ENTRY_REVELINGS_4220623056617091529)],
    ],
    range: 3..=10,
};

static VARS_REVA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REVA_CHILDREN),
    value: None,
};

pub static VARS_REVA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lenta"),
        dictgen::InsensitiveStr::Ascii("lentas"),
        dictgen::InsensitiveStr::Ascii("lorisation"),
        dictgen::InsensitiveStr::Ascii("lorisations"),
        dictgen::InsensitiveStr::Ascii("lorise"),
        dictgen::InsensitiveStr::Ascii("lorised"),
        dictgen::InsensitiveStr::Ascii("lorises"),
        dictgen::InsensitiveStr::Ascii("lorising"),
        dictgen::InsensitiveStr::Ascii("lorization"),
        dictgen::InsensitiveStr::Ascii("lorizations"),
        dictgen::InsensitiveStr::Ascii("lorize"),
        dictgen::InsensitiveStr::Ascii("lorized"),
        dictgen::InsensitiveStr::Ascii("lorizes"),
        dictgen::InsensitiveStr::Ascii("lorizing"),
        dictgen::InsensitiveStr::Ascii("porise"),
        dictgen::InsensitiveStr::Ascii("porises"),
        dictgen::InsensitiveStr::Ascii("porization"),
        dictgen::InsensitiveStr::Ascii("porizations"),
        dictgen::InsensitiveStr::Ascii("porize"),
        dictgen::InsensitiveStr::Ascii("porizes"),
        dictgen::InsensitiveStr::Ascii("pourisation"),
        dictgen::InsensitiveStr::Ascii("pourisations"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ERVALENTA_7976991325469128987)],
        &[(0b11010, &ENTRY_ERVALENTAS_767903353833953973)],
        &[(0b10010, &ENTRY_REVALORIZATION_5701449448493716997)],
        &[(0b10010, &ENTRY_REVALORIZATIONS_5122168154265204918)],
        &[(0b10010, &ENTRY_REVALORIZE_13432734546345955232)],
        &[(0b10010, &ENTRY_REVALORIZED_6828044791293710522)],
        &[(0b10010, &ENTRY_REVALORIZES_10083482437118858511)],
        &[(0b10010, &ENTRY_REVALORIZING_5229021357735833367)],
        &[(0b01001, &ENTRY_REVALORIZATION_5701449448493716997)],
        &[(0b01001, &ENTRY_REVALORIZATIONS_5122168154265204918)],
        &[(0b01001, &ENTRY_REVALORIZE_13432734546345955232)],
        &[(0b01001, &ENTRY_REVALORIZED_6828044791293710522)],
        &[(0b01001, &ENTRY_REVALORIZES_10083482437118858511)],
        &[(0b01001, &ENTRY_REVALORIZING_5229021357735833367)],
        &[(0b10010, &ENTRY_REVAPORIZE_1420746351021754910)],
        &[(0b10010, &ENTRY_REVAPORIZES_4392344872150334367)],
        &[(0b01001, &ENTRY_REVAPORIZATION_5713403552715329985)],
        &[(0b01001, &ENTRY_REVAPORIZATIONS_18170062103842338938)],
        &[(0b01001, &ENTRY_REVAPORIZE_1420746351021754910)],
        &[(0b01001, &ENTRY_REVAPORIZES_4392344872150334367)],
        &[(0b10010, &ENTRY_REVAPORIZATION_5713403552715329985)],
        &[(0b10010, &ENTRY_REVAPORIZATIONS_18170062103842338938)],
    ],
    range: 5..=12,
};

static VARS_REU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REU_CHILDREN),
    value: None,
};

pub static VARS_REU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tilisation"),
        dictgen::InsensitiveStr::Ascii("tilise"),
        dictgen::InsensitiveStr::Ascii("tilised"),
        dictgen::InsensitiveStr::Ascii("tilises"),
        dictgen::InsensitiveStr::Ascii("tilising"),
        dictgen::InsensitiveStr::Ascii("tilization"),
        dictgen::InsensitiveStr::Ascii("tilize"),
        dictgen::InsensitiveStr::Ascii("tilized"),
        dictgen::InsensitiveStr::Ascii("tilizes"),
        dictgen::InsensitiveStr::Ascii("tilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REUTILIZATION_9745892820516663582)],
        &[(0b10010, &ENTRY_REUTILIZE_13673617136512063543)],
        &[(0b10010, &ENTRY_REUTILIZED_18168564318255574596)],
        &[(0b10010, &ENTRY_REUTILIZES_8457401336909667479)],
        &[(0b10010, &ENTRY_REUTILIZING_9731337986765731618)],
        &[(0b01001, &ENTRY_REUTILIZATION_9745892820516663582)],
        &[(0b01001, &ENTRY_REUTILIZE_13673617136512063543)],
        &[(0b01001, &ENTRY_REUTILIZED_18168564318255574596)],
        &[(0b01001, &ENTRY_REUTILIZES_8457401336909667479)],
        &[(0b01001, &ENTRY_REUTILIZING_9731337986765731618)],
    ],
    range: 6..=10,
};

static VARS_RET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RET_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_ERT_16435602001912306536)]),
};

pub static VARS_RET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inulae"),
        dictgen::InsensitiveStr::Ascii("inule"),
        dictgen::InsensitiveStr::Ascii("ranquilise"),
        dictgen::InsensitiveStr::Ascii("ranquilises"),
        dictgen::InsensitiveStr::Ascii("ranquilize"),
        dictgen::InsensitiveStr::Ascii("ranquilizes"),
        dictgen::InsensitiveStr::Ascii("rocaecal"),
        dictgen::InsensitiveStr::Ascii("rocecal"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RETINIZE_17581287987493530595)],
        &[(0b10010, &ENTRY_RETINIZES_11324886815290155312)],
        &[(0b01001, &ENTRY_RETINIZE_17581287987493530595)],
        &[(0b01001, &ENTRY_RETINIZES_11324886815290155312)],
        &[(0b11010, &ENTRY_RETINULE_483575137353236213)],
        &[(0b00001, &ENTRY_RETINULE_483575137353236213)],
        &[(0b10010, &ENTRY_RETRANQUILIZE_2393764178790597866)],
        &[(0b10010, &ENTRY_RETRANQUILIZES_13108673185455158074)],
        &[(0b01001, &ENTRY_RETRANQUILIZE_2393764178790597866)],
        &[(0b01001, &ENTRY_RETRANQUILIZES_13108673185455158074)],
        &[(0b11010, &ENTRY_RETROCECAL_12918263239510680574)],
        &[(0b00001, &ENTRY_RETROCECAL_12918263239510680574)],
    ],
    range: 5..=11,
};

static VARS_RES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RES_CHILDREN),
    value: None,
};

static VARS_RES_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_RESE_NODE),
    None,
    None,
    Some(&VARS_RESH_NODE),
    Some(&VARS_RESI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RESO_NODE),
    Some(&VARS_RESP_NODE),
    None,
    None,
    None,
    Some(&VARS_REST_NODE),
    Some(&VARS_RESU_NODE),
    None,
    None,
    None,
    Some(&VARS_RESY_NODE),
    None,
];

static VARS_RESY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESY_CHILDREN),
    value: None,
};

pub static VARS_RESY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mbolisation"),
        dictgen::InsensitiveStr::Ascii("mbolisations"),
        dictgen::InsensitiveStr::Ascii("mbolise"),
        dictgen::InsensitiveStr::Ascii("mbolises"),
        dictgen::InsensitiveStr::Ascii("mbolization"),
        dictgen::InsensitiveStr::Ascii("mbolizations"),
        dictgen::InsensitiveStr::Ascii("mbolize"),
        dictgen::InsensitiveStr::Ascii("mbolizes"),
        dictgen::InsensitiveStr::Ascii("nchronisation"),
        dictgen::InsensitiveStr::Ascii("nchronisations"),
        dictgen::InsensitiveStr::Ascii("nchronise"),
        dictgen::InsensitiveStr::Ascii("nchronised"),
        dictgen::InsensitiveStr::Ascii("nchronises"),
        dictgen::InsensitiveStr::Ascii("nchronising"),
        dictgen::InsensitiveStr::Ascii("nchronization"),
        dictgen::InsensitiveStr::Ascii("nchronizations"),
        dictgen::InsensitiveStr::Ascii("nchronize"),
        dictgen::InsensitiveStr::Ascii("nchronized"),
        dictgen::InsensitiveStr::Ascii("nchronizes"),
        dictgen::InsensitiveStr::Ascii("nchronizing"),
        dictgen::InsensitiveStr::Ascii("nthesise"),
        dictgen::InsensitiveStr::Ascii("nthesises"),
        dictgen::InsensitiveStr::Ascii("nthesize"),
        dictgen::InsensitiveStr::Ascii("nthesizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESYMBOLIZATION_2100868676093885176)],
        &[(0b10010, &ENTRY_RESYMBOLIZATIONS_2380115742438706012)],
        &[(0b10010, &ENTRY_RESYMBOLIZE_8753563960356797081)],
        &[(0b10010, &ENTRY_RESYMBOLIZES_7954720080205261516)],
        &[(0b01001, &ENTRY_RESYMBOLIZATION_2100868676093885176)],
        &[(0b01001, &ENTRY_RESYMBOLIZATIONS_2380115742438706012)],
        &[(0b01001, &ENTRY_RESYMBOLIZE_8753563960356797081)],
        &[(0b01001, &ENTRY_RESYMBOLIZES_7954720080205261516)],
        &[(0b10010, &ENTRY_RESYNCHRONIZATION_12193175582486124507)],
        &[(0b10010, &ENTRY_RESYNCHRONIZATIONS_14065477339743221001)],
        &[(0b10010, &ENTRY_RESYNCHRONIZE_545307253918691066)],
        &[(0b10010, &ENTRY_RESYNCHRONIZED_4863905219189490366)],
        &[(0b10010, &ENTRY_RESYNCHRONIZES_9271033675927450378)],
        &[(0b10010, &ENTRY_RESYNCHRONIZING_16185596301498314052)],
        &[(0b01001, &ENTRY_RESYNCHRONIZATION_12193175582486124507)],
        &[(0b01001, &ENTRY_RESYNCHRONIZATIONS_14065477339743221001)],
        &[(0b01001, &ENTRY_RESYNCHRONIZE_545307253918691066)],
        &[(0b01001, &ENTRY_RESYNCHRONIZED_4863905219189490366)],
        &[(0b01001, &ENTRY_RESYNCHRONIZES_9271033675927450378)],
        &[(0b01001, &ENTRY_RESYNCHRONIZING_16185596301498314052)],
        &[(0b10010, &ENTRY_RESYNTHESIZE_4007881474356038538)],
        &[(0b10010, &ENTRY_RESYNTHESIZES_401853670456804331)],
        &[(0b01001, &ENTRY_RESYNTHESIZE_4007881474356038538)],
        &[(0b01001, &ENTRY_RESYNTHESIZES_401853670456804331)],
    ],
    range: 7..=14,
};

static VARS_RESU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESU_CHILDREN),
    value: None,
};

pub static VARS_RESU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rrectionise"),
        dictgen::InsensitiveStr::Ascii("rrectionised"),
        dictgen::InsensitiveStr::Ascii("rrectionises"),
        dictgen::InsensitiveStr::Ascii("rrectionising"),
        dictgen::InsensitiveStr::Ascii("rrectionize"),
        dictgen::InsensitiveStr::Ascii("rrectionized"),
        dictgen::InsensitiveStr::Ascii("rrectionizes"),
        dictgen::InsensitiveStr::Ascii("rrectionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESURRECTIONIZE_18191101438815173543)],
        &[(0b10010, &ENTRY_RESURRECTIONIZED_16010155854797625509)],
        &[(0b10010, &ENTRY_RESURRECTIONIZES_4867863049510136884)],
        &[(0b10010, &ENTRY_RESURRECTIONIZING_9856716748644242638)],
        &[(0b01001, &ENTRY_RESURRECTIONIZE_18191101438815173543)],
        &[(0b01001, &ENTRY_RESURRECTIONIZED_16010155854797625509)],
        &[(0b01001, &ENTRY_RESURRECTIONIZES_4867863049510136884)],
        &[(0b01001, &ENTRY_RESURRECTIONIZING_9856716748644242638)],
    ],
    range: 11..=13,
};

static VARS_REST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REST_CHILDREN),
    value: None,
};

pub static VARS_REST_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("andardisation"),
        dictgen::InsensitiveStr::Ascii("andardisations"),
        dictgen::InsensitiveStr::Ascii("andardise"),
        dictgen::InsensitiveStr::Ascii("andardises"),
        dictgen::InsensitiveStr::Ascii("andardization"),
        dictgen::InsensitiveStr::Ascii("andardizations"),
        dictgen::InsensitiveStr::Ascii("andardize"),
        dictgen::InsensitiveStr::Ascii("andardizes"),
        dictgen::InsensitiveStr::Ascii("erilise"),
        dictgen::InsensitiveStr::Ascii("erilises"),
        dictgen::InsensitiveStr::Ascii("erilize"),
        dictgen::InsensitiveStr::Ascii("erilizes"),
        dictgen::InsensitiveStr::Ascii("igmatise"),
        dictgen::InsensitiveStr::Ascii("igmatises"),
        dictgen::InsensitiveStr::Ascii("igmatize"),
        dictgen::InsensitiveStr::Ascii("igmatizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESTANDARDIZATION_9030893141063647769)],
        &[(0b10010, &ENTRY_RESTANDARDIZATIONS_11635991554309473900)],
        &[(0b10010, &ENTRY_RESTANDARDIZE_6569003756104157164)],
        &[(0b10010, &ENTRY_RESTANDARDIZES_15236443555135015074)],
        &[(0b01001, &ENTRY_RESTANDARDIZATION_9030893141063647769)],
        &[(0b01001, &ENTRY_RESTANDARDIZATIONS_11635991554309473900)],
        &[(0b01001, &ENTRY_RESTANDARDIZE_6569003756104157164)],
        &[(0b01001, &ENTRY_RESTANDARDIZES_15236443555135015074)],
        &[(0b10010, &ENTRY_RESTERILIZE_1058883548124310506)],
        &[(0b10010, &ENTRY_RESTERILIZES_14558059425194970009)],
        &[(0b01001, &ENTRY_RESTERILIZE_1058883548124310506)],
        &[(0b01001, &ENTRY_RESTERILIZES_14558059425194970009)],
        &[(0b10010, &ENTRY_RESTIGMATIZE_9870430244279744417)],
        &[(0b10010, &ENTRY_RESTIGMATIZES_10031838899695361673)],
        &[(0b01001, &ENTRY_RESTIGMATIZE_9870430244279744417)],
        &[(0b01001, &ENTRY_RESTIGMATIZES_10031838899695361673)],
    ],
    range: 7..=14,
};

static VARS_RESP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESP_CHILDREN),
    value: None,
};

pub static VARS_RESP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectabilise"),
        dictgen::InsensitiveStr::Ascii("ectabilised"),
        dictgen::InsensitiveStr::Ascii("ectabilises"),
        dictgen::InsensitiveStr::Ascii("ectabilising"),
        dictgen::InsensitiveStr::Ascii("ectabilize"),
        dictgen::InsensitiveStr::Ascii("ectabilized"),
        dictgen::InsensitiveStr::Ascii("ectabilizes"),
        dictgen::InsensitiveStr::Ascii("ectabilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESPECTABILIZE_10595326802229476923)],
        &[(0b10010, &ENTRY_RESPECTABILIZED_8954718152460687227)],
        &[(0b10010, &ENTRY_RESPECTABILIZES_14381893260923468938)],
        &[(0b10010, &ENTRY_RESPECTABILIZING_6174060590866761157)],
        &[(0b01001, &ENTRY_RESPECTABILIZE_10595326802229476923)],
        &[(0b01001, &ENTRY_RESPECTABILIZED_8954718152460687227)],
        &[(0b01001, &ENTRY_RESPECTABILIZES_14381893260923468938)],
        &[(0b01001, &ENTRY_RESPECTABILIZING_6174060590866761157)],
    ],
    range: 10..=12,
};

static VARS_RESO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESO_CHILDREN),
    value: None,
};

pub static VARS_RESO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lemnise"),
        dictgen::InsensitiveStr::Ascii("lemnises"),
        dictgen::InsensitiveStr::Ascii("lemnize"),
        dictgen::InsensitiveStr::Ascii("lemnizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESOLEMNIZE_7621946404155195924)],
        &[(0b10010, &ENTRY_RESOLEMNIZES_15124492163143131014)],
        &[(0b01001, &ENTRY_RESOLEMNIZE_7621946404155195924)],
        &[(0b01001, &ENTRY_RESOLEMNIZES_15124492163143131014)],
    ],
    range: 7..=8,
};

static VARS_RESI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESI_CHILDREN),
    value: None,
};

pub static VARS_RESI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESINIZE_1480770915914903907)],
        &[(0b10010, &ENTRY_RESINIZED_4777093769847272514)],
        &[(0b10010, &ENTRY_RESINIZES_10912813887426118565)],
        &[(0b10010, &ENTRY_RESINIZING_6093523061083374265)],
        &[(0b01001, &ENTRY_RESINIZE_1480770915914903907)],
        &[(0b01001, &ENTRY_RESINIZED_4777093769847272514)],
        &[(0b01001, &ENTRY_RESINIZES_10912813887426118565)],
        &[(0b01001, &ENTRY_RESINIZING_6093523061083374265)],
    ],
    range: 4..=6,
};

static VARS_RESH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESH_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_ERSH_7419460282608909511)]),
};

pub static VARS_RESH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("oes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_RESHES_5020890085510396612)],
        &[(0b11010, &ENTRY_RESHES_5020890085510396612)],
    ],
    range: 2..=3,
};

static VARS_RESE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESE_CHILDREN),
    value: None,
};

pub static VARS_RESE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("iser"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("izer"),
        dictgen::InsensitiveStr::Ascii("nsitisation"),
        dictgen::InsensitiveStr::Ascii("nsitisations"),
        dictgen::InsensitiveStr::Ascii("nsitise"),
        dictgen::InsensitiveStr::Ascii("nsitises"),
        dictgen::InsensitiveStr::Ascii("nsitization"),
        dictgen::InsensitiveStr::Ascii("nsitizations"),
        dictgen::InsensitiveStr::Ascii("nsitize"),
        dictgen::InsensitiveStr::Ascii("nsitizes"),
        dictgen::InsensitiveStr::Ascii("pulcher"),
        dictgen::InsensitiveStr::Ascii("pulchers"),
        dictgen::InsensitiveStr::Ascii("pulchre"),
        dictgen::InsensitiveStr::Ascii("pulchres"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESEIZE_15699853521189401525)],
        &[(0b10010, &ENTRY_RESEIZER_15625229687087097248)],
        &[(0b01001, &ENTRY_RESEIZE_15699853521189401525)],
        &[(0b01001, &ENTRY_RESEIZER_15625229687087097248)],
        &[(0b10010, &ENTRY_RESENSITIZATION_328250918864571061)],
        &[(0b10010, &ENTRY_RESENSITIZATIONS_1355216907329993341)],
        &[(0b10010, &ENTRY_RESENSITIZE_8699626569397120118)],
        &[(0b10010, &ENTRY_RESENSITIZES_174065648769692022)],
        &[(0b01001, &ENTRY_RESENSITIZATION_328250918864571061)],
        &[(0b01001, &ENTRY_RESENSITIZATIONS_1355216907329993341)],
        &[(0b01001, &ENTRY_RESENSITIZE_8699626569397120118)],
        &[(0b01001, &ENTRY_RESENSITIZES_174065648769692022)],
        &[(0b00001, &ENTRY_RESEPULCHER_17387769772026974673)],
        &[(0b00001, &ENTRY_RESEPULCHERS_5499679363891548693)],
        &[(0b11010, &ENTRY_RESEPULCHER_17387769772026974673)],
        &[(0b11010, &ENTRY_RESEPULCHERS_5499679363891548693)],
        &[(0b11010, &ENTRY_ERSES_7688907969133909794)],
    ],
    range: 1..=12,
};

static VARS_RER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RER_CHILDREN),
    value: None,
};

pub static VARS_RER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oyalise"),
        dictgen::InsensitiveStr::Ascii("oyalises"),
        dictgen::InsensitiveStr::Ascii("oyalize"),
        dictgen::InsensitiveStr::Ascii("oyalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REROYALIZE_1484093252419274152)],
        &[(0b10010, &ENTRY_REROYALIZES_1631845483021508078)],
        &[(0b01001, &ENTRY_REROYALIZE_1484093252419274152)],
        &[(0b01001, &ENTRY_REROYALIZES_1631845483021508078)],
    ],
    range: 7..=8,
};

static VARS_REP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_REP_CHILDREN),
    value: None,
};

static VARS_REP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_REPA_NODE),
    None,
    None,
    None,
    Some(&VARS_REPE_NODE),
    None,
    None,
    Some(&VARS_REPH_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_REPO_NODE),
    None,
    None,
    Some(&VARS_REPR_NODE),
    None,
    None,
    Some(&VARS_REPU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_REPU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REPU_CHILDREN),
    value: None,
};

pub static VARS_REPU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("blicanisation"),
        dictgen::InsensitiveStr::Ascii("blicanisations"),
        dictgen::InsensitiveStr::Ascii("blicanise"),
        dictgen::InsensitiveStr::Ascii("blicanised"),
        dictgen::InsensitiveStr::Ascii("blicaniser"),
        dictgen::InsensitiveStr::Ascii("blicanisers"),
        dictgen::InsensitiveStr::Ascii("blicanises"),
        dictgen::InsensitiveStr::Ascii("blicanising"),
        dictgen::InsensitiveStr::Ascii("blicanization"),
        dictgen::InsensitiveStr::Ascii("blicanizations"),
        dictgen::InsensitiveStr::Ascii("blicanize"),
        dictgen::InsensitiveStr::Ascii("blicanized"),
        dictgen::InsensitiveStr::Ascii("blicanizer"),
        dictgen::InsensitiveStr::Ascii("blicanizers"),
        dictgen::InsensitiveStr::Ascii("blicanizes"),
        dictgen::InsensitiveStr::Ascii("blicanizing"),
        dictgen::InsensitiveStr::Ascii("lverise"),
        dictgen::InsensitiveStr::Ascii("lverises"),
        dictgen::InsensitiveStr::Ascii("lverize"),
        dictgen::InsensitiveStr::Ascii("lverizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REPUBLICANIZATION_10038049154044772944)],
        &[(0b10010, &ENTRY_REPUBLICANIZATIONS_3818904481431306569)],
        &[(0b10010, &ENTRY_REPUBLICANIZE_15644682830452937216)],
        &[(0b10010, &ENTRY_REPUBLICANIZED_13862085982527150471)],
        &[(0b10010, &ENTRY_REPUBLICANIZER_15179876901660882417)],
        &[(0b10010, &ENTRY_REPUBLICANIZERS_16705289270906196892)],
        &[(0b10010, &ENTRY_REPUBLICANIZES_3772351389249623570)],
        &[(0b10010, &ENTRY_REPUBLICANIZING_13352721204980193511)],
        &[(0b01001, &ENTRY_REPUBLICANIZATION_10038049154044772944)],
        &[(0b01001, &ENTRY_REPUBLICANIZATIONS_3818904481431306569)],
        &[(0b01001, &ENTRY_REPUBLICANIZE_15644682830452937216)],
        &[(0b01001, &ENTRY_REPUBLICANIZED_13862085982527150471)],
        &[(0b01001, &ENTRY_REPUBLICANIZER_15179876901660882417)],
        &[(0b01001, &ENTRY_REPUBLICANIZERS_16705289270906196892)],
        &[(0b01001, &ENTRY_REPUBLICANIZES_3772351389249623570)],
        &[(0b01001, &ENTRY_REPUBLICANIZING_13352721204980193511)],
        &[(0b10010, &ENTRY_REPULVERIZE_16485974152085073820)],
        &[(0b10010, &ENTRY_REPULVERIZES_16931782906920663266)],
        &[(0b01001, &ENTRY_REPULVERIZE_16485974152085073820)],
        &[(0b01001, &ENTRY_REPULVERIZES_16931782906920663266)],
    ],
    range: 7..=14,
};

static VARS_REPR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REPR_CHILDREN),
    value: None,
};

pub static VARS_REPR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ivatisation"),
        dictgen::InsensitiveStr::Ascii("ivatisations"),
        dictgen::InsensitiveStr::Ascii("ivatise"),
        dictgen::InsensitiveStr::Ascii("ivatised"),
        dictgen::InsensitiveStr::Ascii("ivatises"),
        dictgen::InsensitiveStr::Ascii("ivatising"),
        dictgen::InsensitiveStr::Ascii("ivatization"),
        dictgen::InsensitiveStr::Ascii("ivatizations"),
        dictgen::InsensitiveStr::Ascii("ivatize"),
        dictgen::InsensitiveStr::Ascii("ivatized"),
        dictgen::InsensitiveStr::Ascii("ivatizes"),
        dictgen::InsensitiveStr::Ascii("ivatizing"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("ogramme"),
        dictgen::InsensitiveStr::Ascii("ogrammes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REPRIZED_9731045061331574876)],
        &[(0b10010, &ENTRY_REPRIVATIZATION_17472098476399059170)],
        &[(0b10010, &ENTRY_REPRIVATIZATIONS_16407372455946700494)],
        &[(0b10010, &ENTRY_REPRIVATIZE_9664078646546954379)],
        &[(0b10010, &ENTRY_REPRIVATIZED_10983370266238812583)],
        &[(0b10010, &ENTRY_REPRIVATIZES_3010080685531048079)],
        &[(0b10010, &ENTRY_REPRIVATIZING_12502052463163065567)],
        &[(0b01001, &ENTRY_REPRIVATIZATION_17472098476399059170)],
        &[(0b01001, &ENTRY_REPRIVATIZATIONS_16407372455946700494)],
        &[(0b01001, &ENTRY_REPRIVATIZE_9664078646546954379)],
        &[(0b01001, &ENTRY_REPRIVATIZED_10983370266238812583)],
        &[(0b01001, &ENTRY_REPRIVATIZES_3010080685531048079)],
        &[(0b01001, &ENTRY_REPRIVATIZING_12502052463163065567)],
        &[(0b01001, &ENTRY_REPRIZED_9731045061331574876)],
        &[(0b11010, &ENTRY_REPROGRAM_11078775064421802261)],
        &[(0b11010, &ENTRY_REPROGRAMS_17888173972796244259)],
    ],
    range: 4..=12,
};

static VARS_REPO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REPO_CHILDREN),
    value: None,
};

pub static VARS_REPO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lymerisation"),
        dictgen::InsensitiveStr::Ascii("lymerisations"),
        dictgen::InsensitiveStr::Ascii("lymerise"),
        dictgen::InsensitiveStr::Ascii("lymerises"),
        dictgen::InsensitiveStr::Ascii("lymerization"),
        dictgen::InsensitiveStr::Ascii("lymerizations"),
        dictgen::InsensitiveStr::Ascii("lymerize"),
        dictgen::InsensitiveStr::Ascii("lymerizes"),
        dictgen::InsensitiveStr::Ascii("pularise"),
        dictgen::InsensitiveStr::Ascii("pularize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REPOLYMERIZATION_4569616079512322793)],
        &[(0b10010, &ENTRY_REPOLYMERIZATIONS_12357293932990101773)],
        &[(0b10010, &ENTRY_REPOLYMERIZE_17274626487116515248)],
        &[(0b10010, &ENTRY_REPOLYMERIZES_5749554008771698648)],
        &[(0b01001, &ENTRY_REPOLYMERIZATION_4569616079512322793)],
        &[(0b01001, &ENTRY_REPOLYMERIZATIONS_12357293932990101773)],
        &[(0b01001, &ENTRY_REPOLYMERIZE_17274626487116515248)],
        &[(0b01001, &ENTRY_REPOLYMERIZES_5749554008771698648)],
        &[(0b10010, &ENTRY_REPOPULARIZE_14940546663082185084)],
        &[(0b01001, &ENTRY_REPOPULARIZE_14940546663082185084)],
    ],
    range: 8..=13,
};

static VARS_REPH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REPH_CHILDREN),
    value: None,
};

pub static VARS_REPH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("osphorisation"),
        dictgen::InsensitiveStr::Ascii("osphorisations"),
        dictgen::InsensitiveStr::Ascii("osphorise"),
        dictgen::InsensitiveStr::Ascii("osphorises"),
        dictgen::InsensitiveStr::Ascii("osphorization"),
        dictgen::InsensitiveStr::Ascii("osphorizations"),
        dictgen::InsensitiveStr::Ascii("osphorize"),
        dictgen::InsensitiveStr::Ascii("osphorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REPHOSPHORIZATION_9333856126640113461)],
        &[(0b10010, &ENTRY_REPHOSPHORIZATIONS_12340313224750194997)],
        &[(0b10010, &ENTRY_REPHOSPHORIZE_8849140144759637290)],
        &[(0b10010, &ENTRY_REPHOSPHORIZES_10207595657667846100)],
        &[(0b01001, &ENTRY_REPHOSPHORIZATION_9333856126640113461)],
        &[(0b01001, &ENTRY_REPHOSPHORIZATIONS_12340313224750194997)],
        &[(0b01001, &ENTRY_REPHOSPHORIZE_8849140144759637290)],
        &[(0b01001, &ENTRY_REPHOSPHORIZES_10207595657667846100)],
    ],
    range: 9..=14,
};

static VARS_REPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REPE_CHILDREN),
    value: None,
};

pub static VARS_REPE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rsonalise"),
        dictgen::InsensitiveStr::Ascii("rsonalize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REPERSONALIZE_15402376780199132756)],
        &[(0b01001, &ENTRY_REPERSONALIZE_15402376780199132756)],
    ],
    range: 9..=9,
};

static VARS_REPA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REPA_CHILDREN),
    value: None,
};

pub static VARS_REPA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ganisation"),
        dictgen::InsensitiveStr::Ascii("ganisations"),
        dictgen::InsensitiveStr::Ascii("ganise"),
        dictgen::InsensitiveStr::Ascii("ganiser"),
        dictgen::InsensitiveStr::Ascii("ganisers"),
        dictgen::InsensitiveStr::Ascii("ganises"),
        dictgen::InsensitiveStr::Ascii("ganization"),
        dictgen::InsensitiveStr::Ascii("ganizations"),
        dictgen::InsensitiveStr::Ascii("ganize"),
        dictgen::InsensitiveStr::Ascii("ganizer"),
        dictgen::InsensitiveStr::Ascii("ganizers"),
        dictgen::InsensitiveStr::Ascii("ganizes"),
        dictgen::InsensitiveStr::Ascii("tronise"),
        dictgen::InsensitiveStr::Ascii("tronises"),
        dictgen::InsensitiveStr::Ascii("tronize"),
        dictgen::InsensitiveStr::Ascii("tronizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REPAGANIZATION_10722808462424730668)],
        &[(0b10010, &ENTRY_REPAGANIZATIONS_14831045305658827434)],
        &[(0b10010, &ENTRY_REPAGANIZE_15633051587401367664)],
        &[(0b10010, &ENTRY_REPAGANIZER_17013688811730877026)],
        &[(0b10010, &ENTRY_REPAGANIZERS_5457673805973373581)],
        &[(0b10010, &ENTRY_REPAGANIZES_11158057579415390595)],
        &[(0b01001, &ENTRY_REPAGANIZATION_10722808462424730668)],
        &[(0b01001, &ENTRY_REPAGANIZATIONS_14831045305658827434)],
        &[(0b01001, &ENTRY_REPAGANIZE_15633051587401367664)],
        &[(0b01001, &ENTRY_REPAGANIZER_17013688811730877026)],
        &[(0b01001, &ENTRY_REPAGANIZERS_5457673805973373581)],
        &[(0b01001, &ENTRY_REPAGANIZES_11158057579415390595)],
        &[(0b10010, &ENTRY_REPATRONIZE_815740053535532228)],
        &[(0b10010, &ENTRY_REPATRONIZES_6398567070067672365)],
        &[(0b01001, &ENTRY_REPATRONIZE_815740053535532228)],
        &[(0b01001, &ENTRY_REPATRONIZES_6398567070067672365)],
    ],
    range: 6..=11,
};

static VARS_REO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REO_CHILDREN),
    value: None,
};

pub static VARS_REO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bjectivisation"),
        dictgen::InsensitiveStr::Ascii("bjectivisations"),
        dictgen::InsensitiveStr::Ascii("bjectivise"),
        dictgen::InsensitiveStr::Ascii("bjectivises"),
        dictgen::InsensitiveStr::Ascii("bjectivization"),
        dictgen::InsensitiveStr::Ascii("bjectivizations"),
        dictgen::InsensitiveStr::Ascii("bjectivize"),
        dictgen::InsensitiveStr::Ascii("bjectivizes"),
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisational"),
        dictgen::InsensitiveStr::Ascii("rganisationist"),
        dictgen::InsensitiveStr::Ascii("rganisationists"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganise"),
        dictgen::InsensitiveStr::Ascii("rganised"),
        dictgen::InsensitiveStr::Ascii("rganiser"),
        dictgen::InsensitiveStr::Ascii("rganisers"),
        dictgen::InsensitiveStr::Ascii("rganises"),
        dictgen::InsensitiveStr::Ascii("rganising"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizational"),
        dictgen::InsensitiveStr::Ascii("rganizationist"),
        dictgen::InsensitiveStr::Ascii("rganizationists"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("rganize"),
        dictgen::InsensitiveStr::Ascii("rganized"),
        dictgen::InsensitiveStr::Ascii("rganizer"),
        dictgen::InsensitiveStr::Ascii("rganizers"),
        dictgen::InsensitiveStr::Ascii("rganizes"),
        dictgen::InsensitiveStr::Ascii("rganizing"),
        dictgen::InsensitiveStr::Ascii("xidise"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidises"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidize"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizes"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
        dictgen::InsensitiveStr::Ascii("xygenise"),
        dictgen::InsensitiveStr::Ascii("xygenises"),
        dictgen::InsensitiveStr::Ascii("xygenize"),
        dictgen::InsensitiveStr::Ascii("xygenizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REOBJECTIVIZATION_10107972743956340012)],
        &[(0b10010, &ENTRY_REOBJECTIVIZATIONS_12832085308515471284)],
        &[(0b10010, &ENTRY_REOBJECTIVIZE_6566624772590074686)],
        &[(0b10010, &ENTRY_REOBJECTIVIZES_6122442709447882043)],
        &[(0b01001, &ENTRY_REOBJECTIVIZATION_10107972743956340012)],
        &[(0b01001, &ENTRY_REOBJECTIVIZATIONS_12832085308515471284)],
        &[(0b01001, &ENTRY_REOBJECTIVIZE_6566624772590074686)],
        &[(0b01001, &ENTRY_REOBJECTIVIZES_6122442709447882043)],
        &[(0b10010, &ENTRY_REORGANIZATION_1151969410969297489)],
        &[(0b10010, &ENTRY_REORGANIZATIONAL_12969120263070544967)],
        &[(0b10010, &ENTRY_REORGANIZATIONIST_1712329988947469684)],
        &[(0b10010, &ENTRY_REORGANIZATIONISTS_17830319312761048019)],
        &[(0b10010, &ENTRY_REORGANIZATIONS_11667766387551531150)],
        &[(0b10010, &ENTRY_REORGANIZE_2389493382480671527)],
        &[(0b10010, &ENTRY_REORGANIZED_11646562196618885024)],
        &[(0b10010, &ENTRY_REORGANIZER_11200739295922273776)],
        &[(0b10010, &ENTRY_REORGANIZERS_18113843032605671569)],
        &[(0b10010, &ENTRY_REORGANIZES_16934615739192478647)],
        &[(0b10010, &ENTRY_REORGANIZING_12928416874346171218)],
        &[(0b01001, &ENTRY_REORGANIZATION_1151969410969297489)],
        &[(0b01001, &ENTRY_REORGANIZATIONAL_12969120263070544967)],
        &[(0b01001, &ENTRY_REORGANIZATIONIST_1712329988947469684)],
        &[(0b01001, &ENTRY_REORGANIZATIONISTS_17830319312761048019)],
        &[(0b01001, &ENTRY_REORGANIZATIONS_11667766387551531150)],
        &[(0b01001, &ENTRY_REORGANIZE_2389493382480671527)],
        &[(0b01001, &ENTRY_REORGANIZED_11646562196618885024)],
        &[(0b01001, &ENTRY_REORGANIZER_11200739295922273776)],
        &[(0b01001, &ENTRY_REORGANIZERS_18113843032605671569)],
        &[(0b01001, &ENTRY_REORGANIZES_16934615739192478647)],
        &[(0b01001, &ENTRY_REORGANIZING_12928416874346171218)],
        &[(0b10010, &ENTRY_REOXIDIZE_11987238980825996393)],
        &[(0b10010, &ENTRY_REOXIDIZED_16926234084032226889)],
        &[(0b10010, &ENTRY_REOXIDIZES_17400786414594541662)],
        &[(0b10010, &ENTRY_REOXIDIZING_16376639746858829917)],
        &[(0b01001, &ENTRY_REOXIDIZE_11987238980825996393)],
        &[(0b01001, &ENTRY_REOXIDIZED_16926234084032226889)],
        &[(0b01001, &ENTRY_REOXIDIZES_17400786414594541662)],
        &[(0b01001, &ENTRY_REOXIDIZING_16376639746858829917)],
        &[(0b10010, &ENTRY_REOXYGENIZE_15109191346848713927)],
        &[(0b10010, &ENTRY_REOXYGENIZES_881529392879167791)],
        &[(0b01001, &ENTRY_REOXYGENIZE_15109191346848713927)],
        &[(0b01001, &ENTRY_REOXYGENIZES_881529392879167791)],
    ],
    range: 6..=15,
};

static VARS_REN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REN_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_ERN_104294260841087582)]),
};

pub static VARS_REN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ationalise"),
        dictgen::InsensitiveStr::Ascii("ationalised"),
        dictgen::InsensitiveStr::Ascii("ationalises"),
        dictgen::InsensitiveStr::Ascii("ationalising"),
        dictgen::InsensitiveStr::Ascii("ationalize"),
        dictgen::InsensitiveStr::Ascii("ationalized"),
        dictgen::InsensitiveStr::Ascii("ationalizes"),
        dictgen::InsensitiveStr::Ascii("ationalizing"),
        dictgen::InsensitiveStr::Ascii("contre"),
        dictgen::InsensitiveStr::Ascii("counter"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("est"),
        dictgen::InsensitiveStr::Ascii("ferd"),
        dictgen::InsensitiveStr::Ascii("fred"),
        dictgen::InsensitiveStr::Ascii("ormalisation"),
        dictgen::InsensitiveStr::Ascii("ormalisations"),
        dictgen::InsensitiveStr::Ascii("ormalise"),
        dictgen::InsensitiveStr::Ascii("ormalised"),
        dictgen::InsensitiveStr::Ascii("ormalises"),
        dictgen::InsensitiveStr::Ascii("ormalising"),
        dictgen::InsensitiveStr::Ascii("ormalization"),
        dictgen::InsensitiveStr::Ascii("ormalizations"),
        dictgen::InsensitiveStr::Ascii("ormalize"),
        dictgen::InsensitiveStr::Ascii("ormalized"),
        dictgen::InsensitiveStr::Ascii("ormalizes"),
        dictgen::InsensitiveStr::Ascii("ormalizing"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RENATIONALIZE_17849451892856589339)],
        &[(0b10010, &ENTRY_RENATIONALIZED_2249870200933481729)],
        &[(0b10010, &ENTRY_RENATIONALIZES_16850633933237806477)],
        &[(0b10010, &ENTRY_RENATIONALIZING_8517915481673110200)],
        &[(0b01001, &ENTRY_RENATIONALIZE_17849451892856589339)],
        &[(0b01001, &ENTRY_RENATIONALIZED_2249870200933481729)],
        &[(0b01001, &ENTRY_RENATIONALIZES_16850633933237806477)],
        &[(0b01001, &ENTRY_RENATIONALIZING_8517915481673110200)],
        &[(0b11010, &ENTRY_RENCOUNTER_9110752423620509524)],
        &[(0b00001, &ENTRY_RENCOUNTER_9110752423620509524)],
        &[(0b11010, &ENTRY_ERNES_5463728212363901261)],
        &[(0b11010, &ENTRY_ERNEST_15293673726653605695)],
        &[(0b00001, &ENTRY_RENFERD_4784459740983886586)],
        &[(0b11010, &ENTRY_RENFERD_4784459740983886586)],
        &[(0b10010, &ENTRY_RENORMALIZATION_8391867486821314919)],
        &[(0b10010, &ENTRY_RENORMALIZATIONS_4425052903321597928)],
        &[(0b10010, &ENTRY_RENORMALIZE_4416109336888521166)],
        &[(0b10010, &ENTRY_RENORMALIZED_8111399403491757307)],
        &[(0b10010, &ENTRY_RENORMALIZES_11361886570375678072)],
        &[(0b10010, &ENTRY_RENORMALIZING_9450744988355213284)],
        &[(0b01001, &ENTRY_RENORMALIZATION_8391867486821314919)],
        &[(0b01001, &ENTRY_RENORMALIZATIONS_4425052903321597928)],
        &[(0b01001, &ENTRY_RENORMALIZE_4416109336888521166)],
        &[(0b01001, &ENTRY_RENORMALIZED_8111399403491757307)],
        &[(0b01001, &ENTRY_RENORMALIZES_11361886570375678072)],
        &[(0b01001, &ENTRY_RENORMALIZING_9450744988355213284)],
        &[(0b11010, &ENTRY_ERNS_12150371209659416497)],
    ],
    range: 1..=13,
};

static VARS_REM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_REM_CHILDREN),
    value: None,
};

static VARS_REM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_REMA_NODE),
    None,
    None,
    None,
    Some(&VARS_REME_NODE),
    None,
    None,
    None,
    Some(&VARS_REMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_REMO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_REMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REMO_CHILDREN),
    value: None,
};

pub static VARS_REMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilisation"),
        dictgen::InsensitiveStr::Ascii("bilisations"),
        dictgen::InsensitiveStr::Ascii("bilise"),
        dictgen::InsensitiveStr::Ascii("bilises"),
        dictgen::InsensitiveStr::Ascii("bilization"),
        dictgen::InsensitiveStr::Ascii("bilizations"),
        dictgen::InsensitiveStr::Ascii("bilize"),
        dictgen::InsensitiveStr::Ascii("bilizes"),
        dictgen::InsensitiveStr::Ascii("deled"),
        dictgen::InsensitiveStr::Ascii("deling"),
        dictgen::InsensitiveStr::Ascii("delled"),
        dictgen::InsensitiveStr::Ascii("delling"),
        dictgen::InsensitiveStr::Ascii("ld"),
        dictgen::InsensitiveStr::Ascii("lded"),
        dictgen::InsensitiveStr::Ascii("lding"),
        dictgen::InsensitiveStr::Ascii("lds"),
        dictgen::InsensitiveStr::Ascii("netisation"),
        dictgen::InsensitiveStr::Ascii("netisations"),
        dictgen::InsensitiveStr::Ascii("netise"),
        dictgen::InsensitiveStr::Ascii("netised"),
        dictgen::InsensitiveStr::Ascii("netises"),
        dictgen::InsensitiveStr::Ascii("netising"),
        dictgen::InsensitiveStr::Ascii("netization"),
        dictgen::InsensitiveStr::Ascii("netizations"),
        dictgen::InsensitiveStr::Ascii("netize"),
        dictgen::InsensitiveStr::Ascii("netized"),
        dictgen::InsensitiveStr::Ascii("netizes"),
        dictgen::InsensitiveStr::Ascii("netizing"),
        dictgen::InsensitiveStr::Ascii("ralisation"),
        dictgen::InsensitiveStr::Ascii("ralisations"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralised"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralising"),
        dictgen::InsensitiveStr::Ascii("ralization"),
        dictgen::InsensitiveStr::Ascii("ralizations"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralized"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralizing"),
        dictgen::InsensitiveStr::Ascii("uld"),
        dictgen::InsensitiveStr::Ascii("ulded"),
        dictgen::InsensitiveStr::Ascii("ulding"),
        dictgen::InsensitiveStr::Ascii("ulds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REMOBILIZATION_3911424510662839151)],
        &[(0b10010, &ENTRY_REMOBILIZATIONS_9875854726841835980)],
        &[(0b10010, &ENTRY_REMOBILIZE_15961403419796848444)],
        &[(0b10010, &ENTRY_REMOBILIZES_11952460500996091588)],
        &[(0b01001, &ENTRY_REMOBILIZATION_3911424510662839151)],
        &[(0b01001, &ENTRY_REMOBILIZATIONS_9875854726841835980)],
        &[(0b01001, &ENTRY_REMOBILIZE_15961403419796848444)],
        &[(0b01001, &ENTRY_REMOBILIZES_11952460500996091588)],
        &[(0b00001, &ENTRY_REMODELED_12570106397455685821)],
        &[(0b00001, &ENTRY_REMODELING_4879706051317551240)],
        &[(0b11010, &ENTRY_REMODELED_12570106397455685821)],
        &[(0b11010, &ENTRY_REMODELING_4879706051317551240)],
        &[(0b01001, &ENTRY_REMOLD_13068228302489147488)],
        &[(0b01001, &ENTRY_REMOLDED_10738250144723767360)],
        &[(0b01001, &ENTRY_REMOLDING_8712026113000611166)],
        &[(0b01001, &ENTRY_REMOLDS_15039385602131518728)],
        &[(0b10010, &ENTRY_REMONETIZATION_831081512167517541)],
        &[(0b10010, &ENTRY_REMONETIZATIONS_14205365778472515850)],
        &[(0b10010, &ENTRY_REMONETIZE_10990206227698645890)],
        &[(0b10010, &ENTRY_REMONETIZED_2395653370814126143)],
        &[(0b10010, &ENTRY_REMONETIZES_11180625770457207300)],
        &[(0b10010, &ENTRY_REMONETIZING_8513334196658791361)],
        &[(0b01001, &ENTRY_REMONETIZATION_831081512167517541)],
        &[(0b01001, &ENTRY_REMONETIZATIONS_14205365778472515850)],
        &[(0b01001, &ENTRY_REMONETIZE_10990206227698645890)],
        &[(0b01001, &ENTRY_REMONETIZED_2395653370814126143)],
        &[(0b01001, &ENTRY_REMONETIZES_11180625770457207300)],
        &[(0b01001, &ENTRY_REMONETIZING_8513334196658791361)],
        &[(0b10010, &ENTRY_REMORALIZATION_7004946949634897130)],
        &[(0b10010, &ENTRY_REMORALIZATIONS_15063711158296572611)],
        &[(0b10010, &ENTRY_REMORALIZE_15359671937061114910)],
        &[(0b10010, &ENTRY_REMORALIZED_18212275141128252646)],
        &[(0b10010, &ENTRY_REMORALIZES_3604598684002769634)],
        &[(0b10010, &ENTRY_REMORALIZING_6424531846961576072)],
        &[(0b01001, &ENTRY_REMORALIZATION_7004946949634897130)],
        &[(0b01001, &ENTRY_REMORALIZATIONS_15063711158296572611)],
        &[(0b01001, &ENTRY_REMORALIZE_15359671937061114910)],
        &[(0b01001, &ENTRY_REMORALIZED_18212275141128252646)],
        &[(0b01001, &ENTRY_REMORALIZES_3604598684002769634)],
        &[(0b01001, &ENTRY_REMORALIZING_6424531846961576072)],
        &[(0b11010, &ENTRY_REMOLD_13068228302489147488)],
        &[(0b11010, &ENTRY_REMOLDED_10738250144723767360)],
        &[(0b11010, &ENTRY_REMOLDING_8712026113000611166)],
        &[(0b11010, &ENTRY_REMOLDS_15039385602131518728)],
    ],
    range: 2..=11,
};

static VARS_REMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REMI_CHILDREN),
    value: None,
};

pub static VARS_REMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("litarisation"),
        dictgen::InsensitiveStr::Ascii("litarisations"),
        dictgen::InsensitiveStr::Ascii("litarise"),
        dictgen::InsensitiveStr::Ascii("litarised"),
        dictgen::InsensitiveStr::Ascii("litarises"),
        dictgen::InsensitiveStr::Ascii("litarising"),
        dictgen::InsensitiveStr::Ascii("litarization"),
        dictgen::InsensitiveStr::Ascii("litarizations"),
        dictgen::InsensitiveStr::Ascii("litarize"),
        dictgen::InsensitiveStr::Ascii("litarized"),
        dictgen::InsensitiveStr::Ascii("litarizes"),
        dictgen::InsensitiveStr::Ascii("litarizing"),
        dictgen::InsensitiveStr::Ascii("neralisation"),
        dictgen::InsensitiveStr::Ascii("neralisations"),
        dictgen::InsensitiveStr::Ascii("neralise"),
        dictgen::InsensitiveStr::Ascii("neralised"),
        dictgen::InsensitiveStr::Ascii("neralises"),
        dictgen::InsensitiveStr::Ascii("neralising"),
        dictgen::InsensitiveStr::Ascii("neralization"),
        dictgen::InsensitiveStr::Ascii("neralizations"),
        dictgen::InsensitiveStr::Ascii("neralize"),
        dictgen::InsensitiveStr::Ascii("neralized"),
        dictgen::InsensitiveStr::Ascii("neralizes"),
        dictgen::InsensitiveStr::Ascii("neralizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REMILITARIZATION_15249091069445077797)],
        &[(0b10010, &ENTRY_REMILITARIZATIONS_531606789856002103)],
        &[(0b10010, &ENTRY_REMILITARIZE_14754939446158944749)],
        &[(0b10010, &ENTRY_REMILITARIZED_10537511245367310817)],
        &[(0b10010, &ENTRY_REMILITARIZES_17237274561496848809)],
        &[(0b10010, &ENTRY_REMILITARIZING_8375538189428365870)],
        &[(0b01001, &ENTRY_REMILITARIZATION_15249091069445077797)],
        &[(0b01001, &ENTRY_REMILITARIZATIONS_531606789856002103)],
        &[(0b01001, &ENTRY_REMILITARIZE_14754939446158944749)],
        &[(0b01001, &ENTRY_REMILITARIZED_10537511245367310817)],
        &[(0b01001, &ENTRY_REMILITARIZES_17237274561496848809)],
        &[(0b01001, &ENTRY_REMILITARIZING_8375538189428365870)],
        &[(0b10010, &ENTRY_REMINERALIZATION_9052677584861193778)],
        &[(0b10010, &ENTRY_REMINERALIZATIONS_1665273317667343865)],
        &[(0b10010, &ENTRY_REMINERALIZE_14492190323706730551)],
        &[(0b10010, &ENTRY_REMINERALIZED_4335820429382500925)],
        &[(0b10010, &ENTRY_REMINERALIZES_9596344004419798191)],
        &[(0b10010, &ENTRY_REMINERALIZING_2872679279373295313)],
        &[(0b01001, &ENTRY_REMINERALIZATION_9052677584861193778)],
        &[(0b01001, &ENTRY_REMINERALIZATIONS_1665273317667343865)],
        &[(0b01001, &ENTRY_REMINERALIZE_14492190323706730551)],
        &[(0b01001, &ENTRY_REMINERALIZED_4335820429382500925)],
        &[(0b01001, &ENTRY_REMINERALIZES_9596344004419798191)],
        &[(0b01001, &ENTRY_REMINERALIZING_2872679279373295313)],
    ],
    range: 8..=13,
};

static VARS_REME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REME_CHILDREN),
    value: None,
};

pub static VARS_REME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("morise"),
        dictgen::InsensitiveStr::Ascii("morises"),
        dictgen::InsensitiveStr::Ascii("morize"),
        dictgen::InsensitiveStr::Ascii("morizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REMEMORIZE_16548707727691595328)],
        &[(0b10010, &ENTRY_REMEMORIZES_14072378698037238090)],
        &[(0b01001, &ENTRY_REMEMORIZE_16548707727691595328)],
        &[(0b01001, &ENTRY_REMEMORIZES_14072378698037238090)],
    ],
    range: 6..=7,
};

static VARS_REMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REMA_CHILDREN),
    value: None,
};

pub static VARS_REMA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gnetisation"),
        dictgen::InsensitiveStr::Ascii("gnetisations"),
        dictgen::InsensitiveStr::Ascii("gnetise"),
        dictgen::InsensitiveStr::Ascii("gnetises"),
        dictgen::InsensitiveStr::Ascii("gnetization"),
        dictgen::InsensitiveStr::Ascii("gnetizations"),
        dictgen::InsensitiveStr::Ascii("gnetize"),
        dictgen::InsensitiveStr::Ascii("gnetizes"),
        dictgen::InsensitiveStr::Ascii("terialise"),
        dictgen::InsensitiveStr::Ascii("terialised"),
        dictgen::InsensitiveStr::Ascii("terialises"),
        dictgen::InsensitiveStr::Ascii("terialize"),
        dictgen::InsensitiveStr::Ascii("terialized"),
        dictgen::InsensitiveStr::Ascii("terializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REMAGNETIZATION_12108075581079874038)],
        &[(0b10010, &ENTRY_REMAGNETIZATIONS_4956643680125853179)],
        &[(0b10010, &ENTRY_REMAGNETIZE_9085965881774024693)],
        &[(0b10010, &ENTRY_REMAGNETIZES_17679918670334606563)],
        &[(0b01001, &ENTRY_REMAGNETIZATION_12108075581079874038)],
        &[(0b01001, &ENTRY_REMAGNETIZATIONS_4956643680125853179)],
        &[(0b01001, &ENTRY_REMAGNETIZE_9085965881774024693)],
        &[(0b01001, &ENTRY_REMAGNETIZES_17679918670334606563)],
        &[(0b10010, &ENTRY_REMATERIALIZE_17390301741591532210)],
        &[(0b10010, &ENTRY_REMATERIALIZED_1799928130089984946)],
        &[(0b10010, &ENTRY_REMATERIALIZES_1652697384383833477)],
        &[(0b01001, &ENTRY_REMATERIALIZE_17390301741591532210)],
        &[(0b01001, &ENTRY_REMATERIALIZED_1799928130089984946)],
        &[(0b01001, &ENTRY_REMATERIALIZES_1652697384383833477)],
    ],
    range: 7..=12,
};

static VARS_REL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REL_CHILDREN),
    value: None,
};

pub static VARS_REL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abeled"),
        dictgen::InsensitiveStr::Ascii("abeler"),
        dictgen::InsensitiveStr::Ascii("abelers"),
        dictgen::InsensitiveStr::Ascii("abeling"),
        dictgen::InsensitiveStr::Ascii("abelled"),
        dictgen::InsensitiveStr::Ascii("abeller"),
        dictgen::InsensitiveStr::Ascii("abellers"),
        dictgen::InsensitiveStr::Ascii("abelling"),
        dictgen::InsensitiveStr::Ascii("ativisation"),
        dictgen::InsensitiveStr::Ascii("ativisations"),
        dictgen::InsensitiveStr::Ascii("ativise"),
        dictgen::InsensitiveStr::Ascii("ativised"),
        dictgen::InsensitiveStr::Ascii("ativises"),
        dictgen::InsensitiveStr::Ascii("ativising"),
        dictgen::InsensitiveStr::Ascii("ativization"),
        dictgen::InsensitiveStr::Ascii("ativizations"),
        dictgen::InsensitiveStr::Ascii("ativize"),
        dictgen::InsensitiveStr::Ascii("ativized"),
        dictgen::InsensitiveStr::Ascii("ativizes"),
        dictgen::InsensitiveStr::Ascii("ativizing"),
        dictgen::InsensitiveStr::Ascii("igionise"),
        dictgen::InsensitiveStr::Ascii("igionised"),
        dictgen::InsensitiveStr::Ascii("igionises"),
        dictgen::InsensitiveStr::Ascii("igionising"),
        dictgen::InsensitiveStr::Ascii("igionize"),
        dictgen::InsensitiveStr::Ascii("igionized"),
        dictgen::InsensitiveStr::Ascii("igionizes"),
        dictgen::InsensitiveStr::Ascii("igionizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_RELABELED_2578292475214170813)],
        &[(0b00001, &ENTRY_RELABELER_15090670262055734242)],
        &[(0b00001, &ENTRY_RELABELERS_16758078482434965857)],
        &[(0b00001, &ENTRY_RELABELING_5038377902363081991)],
        &[(0b11010, &ENTRY_RELABELED_2578292475214170813)],
        &[(0b11010, &ENTRY_RELABELER_15090670262055734242)],
        &[(0b11010, &ENTRY_RELABELERS_16758078482434965857)],
        &[(0b11010, &ENTRY_RELABELING_5038377902363081991)],
        &[(0b10010, &ENTRY_RELATIVIZATION_7062869909836897887)],
        &[(0b10010, &ENTRY_RELATIVIZATIONS_5362517281385024225)],
        &[(0b10010, &ENTRY_RELATIVIZE_10808045875347801764)],
        &[(0b10010, &ENTRY_RELATIVIZED_11759925488764903476)],
        &[(0b10010, &ENTRY_RELATIVIZES_786585049191494591)],
        &[(0b10010, &ENTRY_RELATIVIZING_1902231948164306511)],
        &[(0b01001, &ENTRY_RELATIVIZATION_7062869909836897887)],
        &[(0b01001, &ENTRY_RELATIVIZATIONS_5362517281385024225)],
        &[(0b01001, &ENTRY_RELATIVIZE_10808045875347801764)],
        &[(0b01001, &ENTRY_RELATIVIZED_11759925488764903476)],
        &[(0b01001, &ENTRY_RELATIVIZES_786585049191494591)],
        &[(0b01001, &ENTRY_RELATIVIZING_1902231948164306511)],
        &[(0b10010, &ENTRY_RELIGIONIZE_15332825418680356090)],
        &[(0b10010, &ENTRY_RELIGIONIZED_18310835726693613969)],
        &[(0b10010, &ENTRY_RELIGIONIZES_8491731464364398865)],
        &[(0b10010, &ENTRY_RELIGIONIZING_7615913217845991921)],
        &[(0b01001, &ENTRY_RELIGIONIZE_15332825418680356090)],
        &[(0b01001, &ENTRY_RELIGIONIZED_18310835726693613969)],
        &[(0b01001, &ENTRY_RELIGIONIZES_8491731464364398865)],
        &[(0b01001, &ENTRY_RELIGIONIZING_7615913217845991921)],
    ],
    range: 6..=12,
};

static VARS_REK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REK_CHILDREN),
    value: None,
};

pub static VARS_REK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b11010, &ENTRY_ERKE_8619846018234689500)]],
    range: 1..=1,
};

static VARS_REJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REJ_CHILDREN),
    value: None,
};

pub static VARS_REJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uvenise"),
        dictgen::InsensitiveStr::Ascii("uvenised"),
        dictgen::InsensitiveStr::Ascii("uvenises"),
        dictgen::InsensitiveStr::Ascii("uvenising"),
        dictgen::InsensitiveStr::Ascii("uvenize"),
        dictgen::InsensitiveStr::Ascii("uvenized"),
        dictgen::InsensitiveStr::Ascii("uvenizes"),
        dictgen::InsensitiveStr::Ascii("uvenizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REJUVENIZE_12105031031242834344)],
        &[(0b10010, &ENTRY_REJUVENIZED_5208500295865110171)],
        &[(0b10010, &ENTRY_REJUVENIZES_5396862514715717646)],
        &[(0b10010, &ENTRY_REJUVENIZING_3153196577493666230)],
        &[(0b01001, &ENTRY_REJUVENIZE_12105031031242834344)],
        &[(0b01001, &ENTRY_REJUVENIZED_5208500295865110171)],
        &[(0b01001, &ENTRY_REJUVENIZES_5396862514715717646)],
        &[(0b01001, &ENTRY_REJUVENIZING_3153196577493666230)],
    ],
    range: 7..=9,
};

static VARS_REI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REI_CHILDREN),
    value: None,
};

pub static VARS_REI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ndustrialisation"),
        dictgen::InsensitiveStr::Ascii("ndustrialisations"),
        dictgen::InsensitiveStr::Ascii("ndustrialise"),
        dictgen::InsensitiveStr::Ascii("ndustrialised"),
        dictgen::InsensitiveStr::Ascii("ndustrialises"),
        dictgen::InsensitiveStr::Ascii("ndustrialising"),
        dictgen::InsensitiveStr::Ascii("ndustrialization"),
        dictgen::InsensitiveStr::Ascii("ndustrializations"),
        dictgen::InsensitiveStr::Ascii("ndustrialize"),
        dictgen::InsensitiveStr::Ascii("ndustrialized"),
        dictgen::InsensitiveStr::Ascii("ndustrializes"),
        dictgen::InsensitiveStr::Ascii("ndustrializing"),
        dictgen::InsensitiveStr::Ascii("nitialisation"),
        dictgen::InsensitiveStr::Ascii("nitialise"),
        dictgen::InsensitiveStr::Ascii("nitialised"),
        dictgen::InsensitiveStr::Ascii("nitialises"),
        dictgen::InsensitiveStr::Ascii("nitialising"),
        dictgen::InsensitiveStr::Ascii("nitialization"),
        dictgen::InsensitiveStr::Ascii("nitialize"),
        dictgen::InsensitiveStr::Ascii("nitialized"),
        dictgen::InsensitiveStr::Ascii("nitializes"),
        dictgen::InsensitiveStr::Ascii("nitializing"),
        dictgen::InsensitiveStr::Ascii("temise"),
        dictgen::InsensitiveStr::Ascii("temises"),
        dictgen::InsensitiveStr::Ascii("temize"),
        dictgen::InsensitiveStr::Ascii("temizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REINDUSTRIALIZATION_14063114145961761637)],
        &[(0b10010, &ENTRY_REINDUSTRIALIZATIONS_8961658400240110657)],
        &[(0b10010, &ENTRY_REINDUSTRIALIZE_8979958347078953594)],
        &[(0b10010, &ENTRY_REINDUSTRIALIZED_15225180291686207380)],
        &[(0b10010, &ENTRY_REINDUSTRIALIZES_204913172101098343)],
        &[(0b10010, &ENTRY_REINDUSTRIALIZING_8817124278906281224)],
        &[(0b01001, &ENTRY_REINDUSTRIALIZATION_14063114145961761637)],
        &[(0b01001, &ENTRY_REINDUSTRIALIZATIONS_8961658400240110657)],
        &[(0b01001, &ENTRY_REINDUSTRIALIZE_8979958347078953594)],
        &[(0b01001, &ENTRY_REINDUSTRIALIZED_15225180291686207380)],
        &[(0b01001, &ENTRY_REINDUSTRIALIZES_204913172101098343)],
        &[(0b01001, &ENTRY_REINDUSTRIALIZING_8817124278906281224)],
        &[(0b10010, &ENTRY_REINITIALIZATION_16441849804286021867)],
        &[(0b10010, &ENTRY_REINITIALIZE_8538870993340819866)],
        &[(0b10010, &ENTRY_REINITIALIZED_15858716417914176338)],
        &[(0b10010, &ENTRY_REINITIALIZES_2046725879231214867)],
        &[(0b10010, &ENTRY_REINITIALIZING_15549187143453765429)],
        &[(0b01001, &ENTRY_REINITIALIZATION_16441849804286021867)],
        &[(0b01001, &ENTRY_REINITIALIZE_8538870993340819866)],
        &[(0b01001, &ENTRY_REINITIALIZED_15858716417914176338)],
        &[(0b01001, &ENTRY_REINITIALIZES_2046725879231214867)],
        &[(0b01001, &ENTRY_REINITIALIZING_15549187143453765429)],
        &[(0b10010, &ENTRY_REITEMIZE_156766827430890551)],
        &[(0b10010, &ENTRY_REITEMIZES_1352221978277612629)],
        &[(0b01001, &ENTRY_REITEMIZE_156766827430890551)],
        &[(0b01001, &ENTRY_REITEMIZES_1352221978277612629)],
    ],
    range: 6..=17,
};

static VARS_REH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REH_CHILDREN),
    value: None,
};

pub static VARS_REH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("armonisation"),
        dictgen::InsensitiveStr::Ascii("armonise"),
        dictgen::InsensitiveStr::Ascii("armonises"),
        dictgen::InsensitiveStr::Ascii("armonization"),
        dictgen::InsensitiveStr::Ascii("armonize"),
        dictgen::InsensitiveStr::Ascii("armonizes"),
        dictgen::InsensitiveStr::Ascii("m"),
        dictgen::InsensitiveStr::Ascii("onor"),
        dictgen::InsensitiveStr::Ascii("onors"),
        dictgen::InsensitiveStr::Ascii("onour"),
        dictgen::InsensitiveStr::Ascii("onours"),
        dictgen::InsensitiveStr::Ascii("umanisation"),
        dictgen::InsensitiveStr::Ascii("umanise"),
        dictgen::InsensitiveStr::Ascii("umanises"),
        dictgen::InsensitiveStr::Ascii("umanization"),
        dictgen::InsensitiveStr::Ascii("umanize"),
        dictgen::InsensitiveStr::Ascii("umanizes"),
        dictgen::InsensitiveStr::Ascii("ybridise"),
        dictgen::InsensitiveStr::Ascii("ybridises"),
        dictgen::InsensitiveStr::Ascii("ybridize"),
        dictgen::InsensitiveStr::Ascii("ybridizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REHARMONIZATION_17308313781502035145)],
        &[(0b10010, &ENTRY_REHARMONIZE_16334624218440972733)],
        &[(0b10010, &ENTRY_REHARMONIZES_3120273689150694896)],
        &[(0b01001, &ENTRY_REHARMONIZATION_17308313781502035145)],
        &[(0b01001, &ENTRY_REHARMONIZE_16334624218440972733)],
        &[(0b01001, &ENTRY_REHARMONIZES_3120273689150694896)],
        &[(0b00001, &ENTRY_REHM_3696542319302039545)],
        &[(0b00001, &ENTRY_REHONOR_1473315212950437033)],
        &[(0b00001, &ENTRY_REHONORS_18330568768132505982)],
        &[(0b11010, &ENTRY_REHONOR_1473315212950437033)],
        &[(0b11010, &ENTRY_REHONORS_18330568768132505982)],
        &[(0b10010, &ENTRY_REHUMANIZATION_918946253825032389)],
        &[(0b10010, &ENTRY_REHUMANIZE_15895248355910889063)],
        &[(0b10010, &ENTRY_REHUMANIZES_10927403786683544720)],
        &[(0b01001, &ENTRY_REHUMANIZATION_918946253825032389)],
        &[(0b01001, &ENTRY_REHUMANIZE_15895248355910889063)],
        &[(0b01001, &ENTRY_REHUMANIZES_10927403786683544720)],
        &[(0b10010, &ENTRY_REHYBRIDIZE_1218918356413465326)],
        &[(0b10010, &ENTRY_REHYBRIDIZES_12835702250917460390)],
        &[(0b01001, &ENTRY_REHYBRIDIZE_1218918356413465326)],
        &[(0b01001, &ENTRY_REHYBRIDIZES_12835702250917460390)],
    ],
    range: 1..=12,
};

static VARS_REG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REG_CHILDREN),
    value: None,
};

pub static VARS_REG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alvanisation"),
        dictgen::InsensitiveStr::Ascii("alvanisations"),
        dictgen::InsensitiveStr::Ascii("alvanise"),
        dictgen::InsensitiveStr::Ascii("alvanises"),
        dictgen::InsensitiveStr::Ascii("alvanization"),
        dictgen::InsensitiveStr::Ascii("alvanizations"),
        dictgen::InsensitiveStr::Ascii("alvanize"),
        dictgen::InsensitiveStr::Ascii("alvanizes"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("ionalisation"),
        dictgen::InsensitiveStr::Ascii("ionalisations"),
        dictgen::InsensitiveStr::Ascii("ionalise"),
        dictgen::InsensitiveStr::Ascii("ionalised"),
        dictgen::InsensitiveStr::Ascii("ionalises"),
        dictgen::InsensitiveStr::Ascii("ionalising"),
        dictgen::InsensitiveStr::Ascii("ionalization"),
        dictgen::InsensitiveStr::Ascii("ionalizations"),
        dictgen::InsensitiveStr::Ascii("ionalize"),
        dictgen::InsensitiveStr::Ascii("ionalized"),
        dictgen::InsensitiveStr::Ascii("ionalizes"),
        dictgen::InsensitiveStr::Ascii("ionalizing"),
        dictgen::InsensitiveStr::Ascii("oes"),
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularisations"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularised"),
        dictgen::InsensitiveStr::Ascii("ulariser"),
        dictgen::InsensitiveStr::Ascii("ularisers"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularising"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularizations"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularized"),
        dictgen::InsensitiveStr::Ascii("ularizer"),
        dictgen::InsensitiveStr::Ascii("ularizers"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("ularizing"),
        dictgen::InsensitiveStr::Ascii("ulise"),
        dictgen::InsensitiveStr::Ascii("ulised"),
        dictgen::InsensitiveStr::Ascii("ulises"),
        dictgen::InsensitiveStr::Ascii("ulising"),
        dictgen::InsensitiveStr::Ascii("ulize"),
        dictgen::InsensitiveStr::Ascii("ulized"),
        dictgen::InsensitiveStr::Ascii("ulizes"),
        dictgen::InsensitiveStr::Ascii("ulizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REGALIZE_18349192053449291058)],
        &[(0b10010, &ENTRY_REGALIZES_3383647071657330941)],
        &[(0b01001, &ENTRY_REGALIZE_18349192053449291058)],
        &[(0b01001, &ENTRY_REGALIZES_3383647071657330941)],
        &[(0b10010, &ENTRY_REGALVANIZATION_14770688122729122519)],
        &[(0b10010, &ENTRY_REGALVANIZATIONS_919543378143743050)],
        &[(0b10010, &ENTRY_REGALVANIZE_7301359009315947153)],
        &[(0b10010, &ENTRY_REGALVANIZES_304667118914813165)],
        &[(0b01001, &ENTRY_REGALVANIZATION_14770688122729122519)],
        &[(0b01001, &ENTRY_REGALVANIZATIONS_919543378143743050)],
        &[(0b01001, &ENTRY_REGALVANIZE_7301359009315947153)],
        &[(0b01001, &ENTRY_REGALVANIZES_304667118914813165)],
        &[(0b00001, &ENTRY_REGES_17152610849705018518)],
        &[(0b10010, &ENTRY_REGIONALIZATION_16472696414278810321)],
        &[(0b10010, &ENTRY_REGIONALIZATIONS_10627536877093646880)],
        &[(0b10010, &ENTRY_REGIONALIZE_8680940214045371061)],
        &[(0b10010, &ENTRY_REGIONALIZED_1480282105596309948)],
        &[(0b10010, &ENTRY_REGIONALIZES_17696703383650639100)],
        &[(0b10010, &ENTRY_REGIONALIZING_10614276366240882376)],
        &[(0b01001, &ENTRY_REGIONALIZATION_16472696414278810321)],
        &[(0b01001, &ENTRY_REGIONALIZATIONS_10627536877093646880)],
        &[(0b01001, &ENTRY_REGIONALIZE_8680940214045371061)],
        &[(0b01001, &ENTRY_REGIONALIZED_1480282105596309948)],
        &[(0b01001, &ENTRY_REGIONALIZES_17696703383650639100)],
        &[(0b01001, &ENTRY_REGIONALIZING_10614276366240882376)],
        &[(0b11010, &ENTRY_REGES_17152610849705018518)],
        &[(0b10010, &ENTRY_REGULARIZATION_612324028625749871)],
        &[(0b10010, &ENTRY_REGULARIZATIONS_14630290664482038867)],
        &[(0b10010, &ENTRY_REGULARIZE_1740270232233444369)],
        &[(0b10010, &ENTRY_REGULARIZED_812906416837862635)],
        &[(0b10010, &ENTRY_REGULARIZER_7977815819407633965)],
        &[(0b10010, &ENTRY_REGULARIZERS_16153254867995397548)],
        &[(0b10010, &ENTRY_REGULARIZES_12868817085662467445)],
        &[(0b10010, &ENTRY_REGULARIZING_11742129379425728272)],
        &[(0b01001, &ENTRY_REGULARIZATION_612324028625749871)],
        &[(0b01001, &ENTRY_REGULARIZATIONS_14630290664482038867)],
        &[(0b01001, &ENTRY_REGULARIZE_1740270232233444369)],
        &[(0b01001, &ENTRY_REGULARIZED_812906416837862635)],
        &[(0b01001, &ENTRY_REGULARIZER_7977815819407633965)],
        &[(0b01001, &ENTRY_REGULARIZERS_16153254867995397548)],
        &[(0b01001, &ENTRY_REGULARIZES_12868817085662467445)],
        &[(0b01001, &ENTRY_REGULARIZING_11742129379425728272)],
        &[(0b10010, &ENTRY_REGULIZE_17135713958101181770)],
        &[(0b10010, &ENTRY_REGULIZED_17448363826454849500)],
        &[(0b10010, &ENTRY_REGULIZES_5556416535406963250)],
        &[(0b10010, &ENTRY_REGULIZING_5539648899231396734)],
        &[(0b01001, &ENTRY_REGULIZE_17135713958101181770)],
        &[(0b01001, &ENTRY_REGULIZED_17448363826454849500)],
        &[(0b01001, &ENTRY_REGULIZES_5556416535406963250)],
        &[(0b01001, &ENTRY_REGULIZING_5539648899231396734)],
    ],
    range: 2..=13,
};

static VARS_REF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REF_CHILDREN),
    value: None,
};

pub static VARS_REF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avor"),
        dictgen::InsensitiveStr::Ascii("avors"),
        dictgen::InsensitiveStr::Ascii("avour"),
        dictgen::InsensitiveStr::Ascii("avours"),
        dictgen::InsensitiveStr::Ascii("ertilisation"),
        dictgen::InsensitiveStr::Ascii("ertilisations"),
        dictgen::InsensitiveStr::Ascii("ertilise"),
        dictgen::InsensitiveStr::Ascii("ertilises"),
        dictgen::InsensitiveStr::Ascii("ertilization"),
        dictgen::InsensitiveStr::Ascii("ertilizations"),
        dictgen::InsensitiveStr::Ascii("ertilize"),
        dictgen::InsensitiveStr::Ascii("ertilizes"),
        dictgen::InsensitiveStr::Ascii("lectorise"),
        dictgen::InsensitiveStr::Ascii("lectorised"),
        dictgen::InsensitiveStr::Ascii("lectorises"),
        dictgen::InsensitiveStr::Ascii("lectorising"),
        dictgen::InsensitiveStr::Ascii("lectorize"),
        dictgen::InsensitiveStr::Ascii("lectorized"),
        dictgen::InsensitiveStr::Ascii("lectorizes"),
        dictgen::InsensitiveStr::Ascii("lectorizing"),
        dictgen::InsensitiveStr::Ascii("orestisation"),
        dictgen::InsensitiveStr::Ascii("orestise"),
        dictgen::InsensitiveStr::Ascii("orestises"),
        dictgen::InsensitiveStr::Ascii("orestization"),
        dictgen::InsensitiveStr::Ascii("orestize"),
        dictgen::InsensitiveStr::Ascii("orestizes"),
        dictgen::InsensitiveStr::Ascii("ormades"),
        dictgen::InsensitiveStr::Ascii("ormadoes"),
        dictgen::InsensitiveStr::Ascii("ueled"),
        dictgen::InsensitiveStr::Ascii("ueling"),
        dictgen::InsensitiveStr::Ascii("uelled"),
        dictgen::InsensitiveStr::Ascii("uelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_REFAVOR_440381483212661455)],
        &[(0b00001, &ENTRY_REFAVORS_14196253739054548629)],
        &[(0b11010, &ENTRY_REFAVOR_440381483212661455)],
        &[(0b11010, &ENTRY_REFAVORS_14196253739054548629)],
        &[(0b10010, &ENTRY_REFERTILIZATION_676826337167581216)],
        &[(0b10010, &ENTRY_REFERTILIZATIONS_5261991687493344165)],
        &[(0b10010, &ENTRY_REFERTILIZE_17084950143875772419)],
        &[(0b10010, &ENTRY_REFERTILIZES_17288465948629672736)],
        &[(0b01001, &ENTRY_REFERTILIZATION_676826337167581216)],
        &[(0b01001, &ENTRY_REFERTILIZATIONS_5261991687493344165)],
        &[(0b01001, &ENTRY_REFERTILIZE_17084950143875772419)],
        &[(0b01001, &ENTRY_REFERTILIZES_17288465948629672736)],
        &[(0b10010, &ENTRY_REFLECTORIZE_11371162249639935954)],
        &[(0b10010, &ENTRY_REFLECTORIZED_4589985131677101025)],
        &[(0b10010, &ENTRY_REFLECTORIZES_12344080187436028943)],
        &[(0b10010, &ENTRY_REFLECTORIZING_5244281938466548182)],
        &[(0b01001, &ENTRY_REFLECTORIZE_11371162249639935954)],
        &[(0b01001, &ENTRY_REFLECTORIZED_4589985131677101025)],
        &[(0b01001, &ENTRY_REFLECTORIZES_12344080187436028943)],
        &[(0b01001, &ENTRY_REFLECTORIZING_5244281938466548182)],
        &[(0b10010, &ENTRY_REFORESTIZATION_6515267701529405724)],
        &[(0b10010, &ENTRY_REFORESTIZE_16668544380286953646)],
        &[(0b10010, &ENTRY_REFORESTIZES_11145631211548453896)],
        &[(0b01001, &ENTRY_REFORESTIZATION_6515267701529405724)],
        &[(0b01001, &ENTRY_REFORESTIZE_16668544380286953646)],
        &[(0b01001, &ENTRY_REFORESTIZES_11145631211548453896)],
        &[(0b00001, &ENTRY_REFORMADES_15587228082588481869)],
        &[(0b11010, &ENTRY_REFORMADES_15587228082588481869)],
        &[(0b00001, &ENTRY_REFUELED_4168397973029836713)],
        &[(0b00001, &ENTRY_REFUELING_10201954940304240886)],
        &[(0b11010, &ENTRY_REFUELED_4168397973029836713)],
        &[(0b11010, &ENTRY_REFUELING_10201954940304240886)],
    ],
    range: 4..=13,
};

static VARS_REE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REE_CHILDREN),
    value: None,
};

pub static VARS_REE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dified"),
        dictgen::InsensitiveStr::Ascii("difies"),
        dictgen::InsensitiveStr::Ascii("dify"),
        dictgen::InsensitiveStr::Ascii("difying"),
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasised"),
        dictgen::InsensitiveStr::Ascii("mphasiser"),
        dictgen::InsensitiveStr::Ascii("mphasisers"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasising"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasized"),
        dictgen::InsensitiveStr::Ascii("mphasizer"),
        dictgen::InsensitiveStr::Ascii("mphasizers"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
        dictgen::InsensitiveStr::Ascii("mphasizing"),
        dictgen::InsensitiveStr::Ascii("nforce"),
        dictgen::InsensitiveStr::Ascii("nforced"),
        dictgen::InsensitiveStr::Ascii("nforces"),
        dictgen::InsensitiveStr::Ascii("nforcing"),
        dictgen::InsensitiveStr::Ascii("ntrance"),
        dictgen::InsensitiveStr::Ascii("xportation"),
        dictgen::InsensitiveStr::Ascii("xporter"),
    ],
    values: &[
        &[(0b00001, &ENTRY_REEDIFIED_16744059649461415199)],
        &[(0b00001, &ENTRY_REEDIFIES_1966686662934617271)],
        &[(0b00001, &ENTRY_REEDIFY_5917708217519330521)],
        &[(0b00001, &ENTRY_REEDIFYING_5914929745473328575)],
        &[(0b10010, &ENTRY_REEMPHASIZE_2517327899033107994)],
        &[(0b10010, &ENTRY_REEMPHASIZED_11315249846841914363)],
        &[(0b10010, &ENTRY_REEMPHASIZER_4949541383479229465)],
        &[(0b10010, &ENTRY_REEMPHASIZERS_18299626552564956821)],
        &[(0b10010, &ENTRY_REEMPHASIZES_16400475206506338440)],
        &[(0b10010, &ENTRY_REEMPHASIZING_14767153264578218470)],
        &[(0b01001, &ENTRY_REEMPHASIZE_2517327899033107994)],
        &[(0b01001, &ENTRY_REEMPHASIZED_11315249846841914363)],
        &[(0b01001, &ENTRY_REEMPHASIZER_4949541383479229465)],
        &[(0b01001, &ENTRY_REEMPHASIZERS_18299626552564956821)],
        &[(0b01001, &ENTRY_REEMPHASIZES_16400475206506338440)],
        &[(0b01001, &ENTRY_REEMPHASIZING_14767153264578218470)],
        &[(0b00001, &ENTRY_REINFORCE_7852553905371384184)],
        &[(0b00001, &ENTRY_REINFORCED_4138373865022379291)],
        &[(0b00001, &ENTRY_REINFORCES_16061889159840988630)],
        &[(0b00001, &ENTRY_REINFORCING_895373427829466869)],
        &[(0b00001, &ENTRY_REENTRANCE_9955645890849905473)],
        &[(0b00001, &ENTRY_REEXPORTATION_15204503066819424789)],
        &[(0b00001, &ENTRY_REEXPORTER_3504356768607899599)],
    ],
    range: 4..=10,
};

static VARS_RED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RED_CHILDREN),
    value: None,
};

pub static VARS_RED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialed"),
        dictgen::InsensitiveStr::Ascii("ialer"),
        dictgen::InsensitiveStr::Ascii("ialing"),
        dictgen::InsensitiveStr::Ascii("ialled"),
        dictgen::InsensitiveStr::Ascii("ialler"),
        dictgen::InsensitiveStr::Ascii("ialling"),
        dictgen::InsensitiveStr::Ascii("isseise"),
        dictgen::InsensitiveStr::Ascii("isseisin"),
        dictgen::InsensitiveStr::Ascii("isseize"),
        dictgen::InsensitiveStr::Ascii("isseizin"),
    ],
    values: &[
        &[(0b01001, &ENTRY_REDIALED_11643369836594380113)],
        &[(0b00001, &ENTRY_REDIALER_5768833298059308208)],
        &[(0b01001, &ENTRY_REDIALING_15990642980268023127)],
        &[(0b11010, &ENTRY_REDIALED_11643369836594380113)],
        &[(0b11010, &ENTRY_REDIALER_5768833298059308208)],
        &[(0b11010, &ENTRY_REDIALING_15990642980268023127)],
        &[(0b10010, &ENTRY_REDISSEIZE_1150055887803215000)],
        &[(0b10010, &ENTRY_REDISSEIZIN_14496928078206365288)],
        &[(0b01001, &ENTRY_REDISSEIZE_1150055887803215000)],
        &[(0b01001, &ENTRY_REDISSEIZIN_14496928078206365288)],
    ],
    range: 5..=8,
};

static VARS_REC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_REC_CHILDREN),
    value: None,
};

static VARS_REC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_RECA_NODE),
    None,
    None,
    None,
    Some(&VARS_RECE_NODE),
    None,
    None,
    None,
    Some(&VARS_RECI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RECO_NODE),
    None,
    None,
    Some(&VARS_RECR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_RECR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECR_CHILDREN),
    value: None,
};

pub static VARS_RECR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iticise"),
        dictgen::InsensitiveStr::Ascii("iticises"),
        dictgen::InsensitiveStr::Ascii("iticize"),
        dictgen::InsensitiveStr::Ascii("iticizes"),
        dictgen::InsensitiveStr::Ascii("ystallisation"),
        dictgen::InsensitiveStr::Ascii("ystallisations"),
        dictgen::InsensitiveStr::Ascii("ystallise"),
        dictgen::InsensitiveStr::Ascii("ystallised"),
        dictgen::InsensitiveStr::Ascii("ystallises"),
        dictgen::InsensitiveStr::Ascii("ystallising"),
        dictgen::InsensitiveStr::Ascii("ystallization"),
        dictgen::InsensitiveStr::Ascii("ystallizations"),
        dictgen::InsensitiveStr::Ascii("ystallize"),
        dictgen::InsensitiveStr::Ascii("ystallized"),
        dictgen::InsensitiveStr::Ascii("ystallizes"),
        dictgen::InsensitiveStr::Ascii("ystallizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECRITICIZE_7964740355475163401)],
        &[(0b10010, &ENTRY_RECRITICIZES_5757238584671293335)],
        &[(0b01001, &ENTRY_RECRITICIZE_7964740355475163401)],
        &[(0b01001, &ENTRY_RECRITICIZES_5757238584671293335)],
        &[(0b10010, &ENTRY_RECRYSTALLIZATION_14277360853186621414)],
        &[(0b10010, &ENTRY_RECRYSTALLIZATIONS_18324758641447629783)],
        &[(0b10010, &ENTRY_RECRYSTALLIZE_5091534275098388159)],
        &[(0b10010, &ENTRY_RECRYSTALLIZED_3447073258705239305)],
        &[(0b10010, &ENTRY_RECRYSTALLIZES_17463114497549275489)],
        &[(0b10010, &ENTRY_RECRYSTALLIZING_9560544457842789721)],
        &[(0b01001, &ENTRY_RECRYSTALLIZATION_14277360853186621414)],
        &[(0b01001, &ENTRY_RECRYSTALLIZATIONS_18324758641447629783)],
        &[(0b01001, &ENTRY_RECRYSTALLIZE_5091534275098388159)],
        &[(0b01001, &ENTRY_RECRYSTALLIZED_3447073258705239305)],
        &[(0b01001, &ENTRY_RECRYSTALLIZES_17463114497549275489)],
        &[(0b01001, &ENTRY_RECRYSTALLIZING_9560544457842789721)],
    ],
    range: 7..=14,
};

static VARS_RECO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RECO_CHILDREN),
    value: None,
};

static VARS_RECO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RECOG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_RECOL_NODE),
    None,
    Some(&VARS_RECON_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_RECON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECON_CHILDREN),
    value: None,
};

pub static VARS_RECON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ceptualisation"),
        dictgen::InsensitiveStr::Ascii("ceptualising"),
        dictgen::InsensitiveStr::Ascii("ceptualization"),
        dictgen::InsensitiveStr::Ascii("ceptualizing"),
        dictgen::InsensitiveStr::Ascii("noiter"),
        dictgen::InsensitiveStr::Ascii("noitered"),
        dictgen::InsensitiveStr::Ascii("noiterer"),
        dictgen::InsensitiveStr::Ascii("noiterers"),
        dictgen::InsensitiveStr::Ascii("noitering"),
        dictgen::InsensitiveStr::Ascii("noiters"),
        dictgen::InsensitiveStr::Ascii("noitre"),
        dictgen::InsensitiveStr::Ascii("noitred"),
        dictgen::InsensitiveStr::Ascii("noitrer"),
        dictgen::InsensitiveStr::Ascii("noitrers"),
        dictgen::InsensitiveStr::Ascii("noitres"),
        dictgen::InsensitiveStr::Ascii("noitring"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECONCEPTUALIZATION_5115077883005130043)],
        &[(0b10010, &ENTRY_RECONCEPTUALIZING_7225078240238716102)],
        &[(0b01001, &ENTRY_RECONCEPTUALIZATION_5115077883005130043)],
        &[(0b01001, &ENTRY_RECONCEPTUALIZING_7225078240238716102)],
        &[(0b01001, &ENTRY_RECONNOITER_5276997216676634421)],
        &[(0b01001, &ENTRY_RECONNOITERED_2213490465207030464)],
        &[(0b00001, &ENTRY_RECONNOITERER_15649698041969515450)],
        &[(0b00001, &ENTRY_RECONNOITERERS_10708801058031695478)],
        &[(0b01001, &ENTRY_RECONNOITERING_445941575931390448)],
        &[(0b01001, &ENTRY_RECONNOITERS_525334200628355206)],
        &[(0b11010, &ENTRY_RECONNOITER_5276997216676634421)],
        &[(0b11010, &ENTRY_RECONNOITERED_2213490465207030464)],
        &[(0b11010, &ENTRY_RECONNOITERER_15649698041969515450)],
        &[(0b11010, &ENTRY_RECONNOITERERS_10708801058031695478)],
        &[(0b11010, &ENTRY_RECONNOITERS_525334200628355206)],
        &[(0b11010, &ENTRY_RECONNOITERING_445941575931390448)],
    ],
    range: 6..=14,
};

static VARS_RECOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECOL_CHILDREN),
    value: None,
};

pub static VARS_RECOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("oration"),
        dictgen::InsensitiveStr::Ascii("orations"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ouration"),
        dictgen::InsensitiveStr::Ascii("ourations"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECOLONIZATION_6967476021876992825)],
        &[(0b10010, &ENTRY_RECOLONIZATIONS_1558253647578378818)],
        &[(0b10010, &ENTRY_RECOLONIZE_8041961132234757613)],
        &[(0b10010, &ENTRY_RECOLONIZED_13885306844450340179)],
        &[(0b10010, &ENTRY_RECOLONIZES_2544530612567301872)],
        &[(0b10010, &ENTRY_RECOLONIZING_4581044221369467580)],
        &[(0b01001, &ENTRY_RECOLONIZATION_6967476021876992825)],
        &[(0b01001, &ENTRY_RECOLONIZATIONS_1558253647578378818)],
        &[(0b01001, &ENTRY_RECOLONIZE_8041961132234757613)],
        &[(0b01001, &ENTRY_RECOLONIZED_13885306844450340179)],
        &[(0b01001, &ENTRY_RECOLONIZES_2544530612567301872)],
        &[(0b01001, &ENTRY_RECOLONIZING_4581044221369467580)],
        &[(0b10001, &ENTRY_RECOLOR_618293369258486297)],
        &[(0b00001, &ENTRY_RECOLORATION_8940303655719757865)],
        &[(0b00001, &ENTRY_RECOLORATIONS_7653541374003132098)],
        &[(0b10001, &ENTRY_RECOLORED_15377054535466872394)],
        &[(0b10001, &ENTRY_RECOLORING_2640269906145220161)],
        &[(0b10001, &ENTRY_RECOLORS_12626939234404298398)],
        &[(0b11010, &ENTRY_RECOLOR_618293369258486297)],
        &[(0b11010, &ENTRY_RECOLORATION_8940303655719757865)],
        &[(0b11010, &ENTRY_RECOLORATIONS_7653541374003132098)],
        &[(0b11010, &ENTRY_RECOLORED_15377054535466872394)],
        &[(0b11010, &ENTRY_RECOLORING_2640269906145220161)],
        &[(0b11010, &ENTRY_RECOLORS_12626939234404298398)],
    ],
    range: 2..=10,
};

static VARS_RECOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECOG_CHILDREN),
    value: None,
};

pub static VARS_RECOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisability"),
        dictgen::InsensitiveStr::Ascii("nisable"),
        dictgen::InsensitiveStr::Ascii("nisabler"),
        dictgen::InsensitiveStr::Ascii("nisablest"),
        dictgen::InsensitiveStr::Ascii("nisably"),
        dictgen::InsensitiveStr::Ascii("nisance"),
        dictgen::InsensitiveStr::Ascii("nisances"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("nisedlies"),
        dictgen::InsensitiveStr::Ascii("nisedly"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nisinglies"),
        dictgen::InsensitiveStr::Ascii("nisingly"),
        dictgen::InsensitiveStr::Ascii("nizability"),
        dictgen::InsensitiveStr::Ascii("nizable"),
        dictgen::InsensitiveStr::Ascii("nizabler"),
        dictgen::InsensitiveStr::Ascii("nizablest"),
        dictgen::InsensitiveStr::Ascii("nizably"),
        dictgen::InsensitiveStr::Ascii("nizance"),
        dictgen::InsensitiveStr::Ascii("nizances"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizedlies"),
        dictgen::InsensitiveStr::Ascii("nizedly"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
        dictgen::InsensitiveStr::Ascii("nizinglies"),
        dictgen::InsensitiveStr::Ascii("nizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECOGNIZABILITY_10357285971929431711)],
        &[(0b10010, &ENTRY_RECOGNIZABLE_7613722258514271208)],
        &[(0b10010, &ENTRY_RECOGNIZABLER_4263942192681001064)],
        &[(0b10010, &ENTRY_RECOGNIZABLEST_4777556240445602065)],
        &[(0b10010, &ENTRY_RECOGNIZABLY_5262242687840057985)],
        &[(0b10010, &ENTRY_RECOGNIZANCE_4728169876554590520)],
        &[(0b10010, &ENTRY_RECOGNIZANCES_1889737239613628316)],
        &[(0b10010, &ENTRY_RECOGNIZE_2951534439364429088)],
        &[(0b10010, &ENTRY_RECOGNIZED_8994678971763803574)],
        &[(0b10010, &ENTRY_RECOGNIZEDLIES_10785782978004508775)],
        &[(0b10010, &ENTRY_RECOGNIZEDLY_1378498050623081604)],
        &[(0b10010, &ENTRY_RECOGNIZER_8837107831671387344)],
        &[(0b10010, &ENTRY_RECOGNIZERS_12071383181262313264)],
        &[(0b10010, &ENTRY_RECOGNIZES_4631719440910592363)],
        &[(0b10010, &ENTRY_RECOGNIZING_7647130431971528373)],
        &[(0b10010, &ENTRY_RECOGNIZINGLIES_10760710242279148374)],
        &[(0b10010, &ENTRY_RECOGNIZINGLY_3477993105941224267)],
        &[(0b01001, &ENTRY_RECOGNIZABILITY_10357285971929431711)],
        &[(0b01001, &ENTRY_RECOGNIZABLE_7613722258514271208)],
        &[(0b01001, &ENTRY_RECOGNIZABLER_4263942192681001064)],
        &[(0b01001, &ENTRY_RECOGNIZABLEST_4777556240445602065)],
        &[(0b01001, &ENTRY_RECOGNIZABLY_5262242687840057985)],
        &[(0b01001, &ENTRY_RECOGNIZANCE_4728169876554590520)],
        &[(0b01001, &ENTRY_RECOGNIZANCES_1889737239613628316)],
        &[(0b01001, &ENTRY_RECOGNIZE_2951534439364429088)],
        &[(0b01001, &ENTRY_RECOGNIZED_8994678971763803574)],
        &[(0b01001, &ENTRY_RECOGNIZEDLIES_10785782978004508775)],
        &[(0b01001, &ENTRY_RECOGNIZEDLY_1378498050623081604)],
        &[(0b01001, &ENTRY_RECOGNIZER_8837107831671387344)],
        &[(0b01001, &ENTRY_RECOGNIZERS_12071383181262313264)],
        &[(0b01001, &ENTRY_RECOGNIZES_4631719440910592363)],
        &[(0b01001, &ENTRY_RECOGNIZING_7647130431971528373)],
        &[(0b01001, &ENTRY_RECOGNIZINGLIES_10760710242279148374)],
        &[(0b01001, &ENTRY_RECOGNIZINGLY_3477993105941224267)],
    ],
    range: 4..=10,
};

static VARS_RECI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECI_CHILDREN),
    value: None,
};

pub static VARS_RECI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("procalise"),
        dictgen::InsensitiveStr::Ascii("procalises"),
        dictgen::InsensitiveStr::Ascii("procalize"),
        dictgen::InsensitiveStr::Ascii("procalizes"),
        dictgen::InsensitiveStr::Ascii("vilisation"),
        dictgen::InsensitiveStr::Ascii("vilisations"),
        dictgen::InsensitiveStr::Ascii("vilise"),
        dictgen::InsensitiveStr::Ascii("vilises"),
        dictgen::InsensitiveStr::Ascii("vilization"),
        dictgen::InsensitiveStr::Ascii("vilizations"),
        dictgen::InsensitiveStr::Ascii("vilize"),
        dictgen::InsensitiveStr::Ascii("vilizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECIPROCALIZE_8911765288022758420)],
        &[(0b10010, &ENTRY_RECIPROCALIZES_14749039714160587750)],
        &[(0b01001, &ENTRY_RECIPROCALIZE_8911765288022758420)],
        &[(0b01001, &ENTRY_RECIPROCALIZES_14749039714160587750)],
        &[(0b10010, &ENTRY_RECIVILIZATION_11740291015500736416)],
        &[(0b10010, &ENTRY_RECIVILIZATIONS_9694916523307178397)],
        &[(0b10010, &ENTRY_RECIVILIZE_10748548005142278107)],
        &[(0b10010, &ENTRY_RECIVILIZES_15097987385833073137)],
        &[(0b01001, &ENTRY_RECIVILIZATION_11740291015500736416)],
        &[(0b01001, &ENTRY_RECIVILIZATIONS_9694916523307178397)],
        &[(0b01001, &ENTRY_RECIVILIZE_10748548005142278107)],
        &[(0b01001, &ENTRY_RECIVILIZES_15097987385833073137)],
    ],
    range: 6..=11,
};

static VARS_RECE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECE_CHILDREN),
    value: None,
};

pub static VARS_RECE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ntralisation"),
        dictgen::InsensitiveStr::Ascii("ntralisations"),
        dictgen::InsensitiveStr::Ascii("ntralise"),
        dictgen::InsensitiveStr::Ascii("ntralises"),
        dictgen::InsensitiveStr::Ascii("ntralization"),
        dictgen::InsensitiveStr::Ascii("ntralizations"),
        dictgen::InsensitiveStr::Ascii("ntralize"),
        dictgen::InsensitiveStr::Ascii("ntralizes"),
        dictgen::InsensitiveStr::Ascii("rcelae"),
        dictgen::InsensitiveStr::Ascii("rcele"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECENTRALIZATION_4468587086381460845)],
        &[(0b10010, &ENTRY_RECENTRALIZATIONS_17645646173969394267)],
        &[(0b10010, &ENTRY_RECENTRALIZE_5617717555693360915)],
        &[(0b10010, &ENTRY_RECENTRALIZES_3639828701303018823)],
        &[(0b01001, &ENTRY_RECENTRALIZATION_4468587086381460845)],
        &[(0b01001, &ENTRY_RECENTRALIZATIONS_17645646173969394267)],
        &[(0b01001, &ENTRY_RECENTRALIZE_5617717555693360915)],
        &[(0b01001, &ENTRY_RECENTRALIZES_3639828701303018823)],
        &[(0b11010, &ENTRY_RECERCELE_9448895248888457782)],
        &[(0b00001, &ENTRY_RECERCELE_9448895248888457782)],
    ],
    range: 5..=13,
};

static VARS_RECA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECA_CHILDREN),
    value: None,
};

pub static VARS_RECA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nalisation"),
        dictgen::InsensitiveStr::Ascii("nalization"),
        dictgen::InsensitiveStr::Ascii("pitalisation"),
        dictgen::InsensitiveStr::Ascii("pitalisations"),
        dictgen::InsensitiveStr::Ascii("pitalise"),
        dictgen::InsensitiveStr::Ascii("pitalised"),
        dictgen::InsensitiveStr::Ascii("pitalises"),
        dictgen::InsensitiveStr::Ascii("pitalising"),
        dictgen::InsensitiveStr::Ascii("pitalization"),
        dictgen::InsensitiveStr::Ascii("pitalizations"),
        dictgen::InsensitiveStr::Ascii("pitalize"),
        dictgen::InsensitiveStr::Ascii("pitalized"),
        dictgen::InsensitiveStr::Ascii("pitalizes"),
        dictgen::InsensitiveStr::Ascii("pitalizing"),
        dictgen::InsensitiveStr::Ascii("rbonisation"),
        dictgen::InsensitiveStr::Ascii("rbonisations"),
        dictgen::InsensitiveStr::Ascii("rbonise"),
        dictgen::InsensitiveStr::Ascii("rboniser"),
        dictgen::InsensitiveStr::Ascii("rbonisers"),
        dictgen::InsensitiveStr::Ascii("rbonises"),
        dictgen::InsensitiveStr::Ascii("rbonization"),
        dictgen::InsensitiveStr::Ascii("rbonizations"),
        dictgen::InsensitiveStr::Ascii("rbonize"),
        dictgen::InsensitiveStr::Ascii("rbonizer"),
        dictgen::InsensitiveStr::Ascii("rbonizers"),
        dictgen::InsensitiveStr::Ascii("rbonizes"),
        dictgen::InsensitiveStr::Ascii("tegorised"),
        dictgen::InsensitiveStr::Ascii("tegorized"),
        dictgen::InsensitiveStr::Ascii("usticise"),
        dictgen::InsensitiveStr::Ascii("usticises"),
        dictgen::InsensitiveStr::Ascii("usticize"),
        dictgen::InsensitiveStr::Ascii("usticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECANALIZATION_4336985207748089706)],
        &[(0b01001, &ENTRY_RECANALIZATION_4336985207748089706)],
        &[(0b10010, &ENTRY_RECAPITALIZATION_10508729055647744364)],
        &[(0b10010, &ENTRY_RECAPITALIZATIONS_4437798653748561592)],
        &[(0b10010, &ENTRY_RECAPITALIZE_7414811184860400912)],
        &[(0b10010, &ENTRY_RECAPITALIZED_14061551312028988978)],
        &[(0b10010, &ENTRY_RECAPITALIZES_15012732459360105212)],
        &[(0b10010, &ENTRY_RECAPITALIZING_11777631663823328319)],
        &[(0b01001, &ENTRY_RECAPITALIZATION_10508729055647744364)],
        &[(0b01001, &ENTRY_RECAPITALIZATIONS_4437798653748561592)],
        &[(0b01001, &ENTRY_RECAPITALIZE_7414811184860400912)],
        &[(0b01001, &ENTRY_RECAPITALIZED_14061551312028988978)],
        &[(0b01001, &ENTRY_RECAPITALIZES_15012732459360105212)],
        &[(0b01001, &ENTRY_RECAPITALIZING_11777631663823328319)],
        &[(0b10010, &ENTRY_RECARBONIZATION_17410364536713786606)],
        &[(0b10010, &ENTRY_RECARBONIZATIONS_7855928618560079253)],
        &[(0b10010, &ENTRY_RECARBONIZE_11574813584574021407)],
        &[(0b10010, &ENTRY_RECARBONIZER_583963286812209805)],
        &[(0b10010, &ENTRY_RECARBONIZERS_16664024814142242342)],
        &[(0b10010, &ENTRY_RECARBONIZES_1917047137495020788)],
        &[(0b01001, &ENTRY_RECARBONIZATION_17410364536713786606)],
        &[(0b01001, &ENTRY_RECARBONIZATIONS_7855928618560079253)],
        &[(0b01001, &ENTRY_RECARBONIZE_11574813584574021407)],
        &[(0b01001, &ENTRY_RECARBONIZER_583963286812209805)],
        &[(0b01001, &ENTRY_RECARBONIZERS_16664024814142242342)],
        &[(0b01001, &ENTRY_RECARBONIZES_1917047137495020788)],
        &[(0b10010, &ENTRY_RECATEGORIZED_4396871015069911592)],
        &[(0b01001, &ENTRY_RECATEGORIZED_4396871015069911592)],
        &[(0b10010, &ENTRY_RECAUSTICIZE_6187488483013956168)],
        &[(0b10010, &ENTRY_RECAUSTICIZES_8611668027402828974)],
        &[(0b01001, &ENTRY_RECAUSTICIZE_6187488483013956168)],
        &[(0b01001, &ENTRY_RECAUSTICIZES_8611668027402828974)],
    ],
    range: 7..=13,
};

static VARS_REB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REB_CHILDREN),
    value: None,
};

pub static VARS_REB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aptisation"),
        dictgen::InsensitiveStr::Ascii("aptisations"),
        dictgen::InsensitiveStr::Ascii("aptise"),
        dictgen::InsensitiveStr::Ascii("aptised"),
        dictgen::InsensitiveStr::Ascii("aptises"),
        dictgen::InsensitiveStr::Ascii("aptising"),
        dictgen::InsensitiveStr::Ascii("aptization"),
        dictgen::InsensitiveStr::Ascii("aptizations"),
        dictgen::InsensitiveStr::Ascii("aptize"),
        dictgen::InsensitiveStr::Ascii("aptized"),
        dictgen::InsensitiveStr::Ascii("aptizes"),
        dictgen::InsensitiveStr::Ascii("aptizing"),
        dictgen::InsensitiveStr::Ascii("ia"),
        dictgen::InsensitiveStr::Ascii("ias"),
        dictgen::InsensitiveStr::Ascii("ourbonise"),
        dictgen::InsensitiveStr::Ascii("ourbonises"),
        dictgen::InsensitiveStr::Ascii("ourbonize"),
        dictgen::InsensitiveStr::Ascii("ourbonizes"),
        dictgen::InsensitiveStr::Ascii("rutalise"),
        dictgen::InsensitiveStr::Ascii("rutalises"),
        dictgen::InsensitiveStr::Ascii("rutalize"),
        dictgen::InsensitiveStr::Ascii("rutalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REBAPTIZATION_3181157675116561447)],
        &[(0b10010, &ENTRY_REBAPTIZATIONS_17812907935091196418)],
        &[(0b10010, &ENTRY_REBAPTIZE_8763418228695127451)],
        &[(0b10010, &ENTRY_REBAPTIZED_11796464946138226291)],
        &[(0b10010, &ENTRY_REBAPTIZES_17975768782687735566)],
        &[(0b10010, &ENTRY_REBAPTIZING_15159798223591665010)],
        &[(0b01001, &ENTRY_REBAPTIZATION_3181157675116561447)],
        &[(0b01001, &ENTRY_REBAPTIZATIONS_17812907935091196418)],
        &[(0b01001, &ENTRY_REBAPTIZE_8763418228695127451)],
        &[(0b01001, &ENTRY_REBAPTIZED_11796464946138226291)],
        &[(0b01001, &ENTRY_REBAPTIZES_17975768782687735566)],
        &[(0b01001, &ENTRY_REBAPTIZING_15159798223591665010)],
        &[(0b11010, &ENTRY_ERBIA_9464736826289357890)],
        &[(0b11010, &ENTRY_ERBIAS_13402989534594842592)],
        &[(0b10010, &ENTRY_REBOURBONIZE_5536931585817561068)],
        &[(0b10010, &ENTRY_REBOURBONIZES_76067254702802558)],
        &[(0b01001, &ENTRY_REBOURBONIZE_5536931585817561068)],
        &[(0b01001, &ENTRY_REBOURBONIZES_76067254702802558)],
        &[(0b10010, &ENTRY_REBRUTALIZE_15615381416038865669)],
        &[(0b10010, &ENTRY_REBRUTALIZES_3911771308757750270)],
        &[(0b01001, &ENTRY_REBRUTALIZE_15615381416038865669)],
        &[(0b01001, &ENTRY_REBRUTALIZES_3911771308757750270)],
    ],
    range: 2..=11,
};

static VARS_REA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_REA_CHILDREN),
    value: None,
};

static VARS_REA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_REAC_NODE),
    Some(&VARS_READ_NODE),
    Some(&VARS_REAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_REAL_NODE),
    None,
    Some(&VARS_REAN_NODE),
    None,
    Some(&VARS_REAP_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_REAU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_REAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REAU_CHILDREN),
    value: None,
};

pub static VARS_REAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thorisation"),
        dictgen::InsensitiveStr::Ascii("thorisations"),
        dictgen::InsensitiveStr::Ascii("thorise"),
        dictgen::InsensitiveStr::Ascii("thorises"),
        dictgen::InsensitiveStr::Ascii("thorization"),
        dictgen::InsensitiveStr::Ascii("thorizations"),
        dictgen::InsensitiveStr::Ascii("thorize"),
        dictgen::InsensitiveStr::Ascii("thorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REAUTHORIZATION_17955151986421375503)],
        &[(0b10010, &ENTRY_REAUTHORIZATIONS_11163266872832391485)],
        &[(0b10010, &ENTRY_REAUTHORIZE_1656466035075118852)],
        &[(0b10010, &ENTRY_REAUTHORIZES_7279740540043941481)],
        &[(0b01001, &ENTRY_REAUTHORIZATION_17955151986421375503)],
        &[(0b01001, &ENTRY_REAUTHORIZATIONS_11163266872832391485)],
        &[(0b01001, &ENTRY_REAUTHORIZE_1656466035075118852)],
        &[(0b01001, &ENTRY_REAUTHORIZES_7279740540043941481)],
    ],
    range: 7..=12,
};

static VARS_REAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REAP_CHILDREN),
    value: None,
};

pub static VARS_REAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ologise"),
        dictgen::InsensitiveStr::Ascii("ologises"),
        dictgen::InsensitiveStr::Ascii("ologize"),
        dictgen::InsensitiveStr::Ascii("ologizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REAPOLOGIZE_11605068466350684535)],
        &[(0b10010, &ENTRY_REAPOLOGIZES_5630570346849612644)],
        &[(0b01001, &ENTRY_REAPOLOGIZE_11605068466350684535)],
        &[(0b01001, &ENTRY_REAPOLOGIZES_5630570346849612644)],
    ],
    range: 7..=8,
};

static VARS_REAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REAN_CHILDREN),
    value: None,
};

pub static VARS_REAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alyse"),
        dictgen::InsensitiveStr::Ascii("alysed"),
        dictgen::InsensitiveStr::Ascii("alyser"),
        dictgen::InsensitiveStr::Ascii("alysers"),
        dictgen::InsensitiveStr::Ascii("alysing"),
        dictgen::InsensitiveStr::Ascii("alyze"),
        dictgen::InsensitiveStr::Ascii("alyzed"),
        dictgen::InsensitiveStr::Ascii("alyzer"),
        dictgen::InsensitiveStr::Ascii("alyzers"),
        dictgen::InsensitiveStr::Ascii("alyzes"),
        dictgen::InsensitiveStr::Ascii("alyzing"),
        dictgen::InsensitiveStr::Ascii("imalise"),
        dictgen::InsensitiveStr::Ascii("imalises"),
        dictgen::InsensitiveStr::Ascii("imalize"),
        dictgen::InsensitiveStr::Ascii("imalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REANALYZE_1610229560390845063)],
        &[(0b10010, &ENTRY_REANALYZED_5684089744805187690)],
        &[(0b10010, &ENTRY_REANALYZER_7279112787130410746)],
        &[(0b10010, &ENTRY_REANALYZERS_18352290434303600135)],
        &[(0b10010, &ENTRY_REANALYZING_10344228664173305161)],
        &[(0b01001, &ENTRY_REANALYZE_1610229560390845063)],
        &[(0b01001, &ENTRY_REANALYZED_5684089744805187690)],
        &[(0b01001, &ENTRY_REANALYZER_7279112787130410746)],
        &[(0b01001, &ENTRY_REANALYZERS_18352290434303600135)],
        &[(0b01001, &ENTRY_REANALYZES_2618902483948124452)],
        &[(0b01001, &ENTRY_REANALYZING_10344228664173305161)],
        &[(0b10010, &ENTRY_REANIMALIZE_6983429568354275323)],
        &[(0b10010, &ENTRY_REANIMALIZES_7317637500851915762)],
        &[(0b01001, &ENTRY_REANIMALIZE_6983429568354275323)],
        &[(0b01001, &ENTRY_REANIMALIZES_7317637500851915762)],
    ],
    range: 5..=8,
};

static VARS_REAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REAL_CHILDREN),
    value: None,
};

pub static VARS_REAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isabilities"),
        dictgen::InsensitiveStr::Ascii("isability"),
        dictgen::InsensitiveStr::Ascii("isable"),
        dictgen::InsensitiveStr::Ascii("isableness"),
        dictgen::InsensitiveStr::Ascii("isabler"),
        dictgen::InsensitiveStr::Ascii("isables"),
        dictgen::InsensitiveStr::Ascii("isablest"),
        dictgen::InsensitiveStr::Ascii("isablies"),
        dictgen::InsensitiveStr::Ascii("isably"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("iser"),
        dictgen::InsensitiveStr::Ascii("isers"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("isingly"),
        dictgen::InsensitiveStr::Ascii("isings"),
        dictgen::InsensitiveStr::Ascii("isticise"),
        dictgen::InsensitiveStr::Ascii("isticises"),
        dictgen::InsensitiveStr::Ascii("isticize"),
        dictgen::InsensitiveStr::Ascii("isticizes"),
        dictgen::InsensitiveStr::Ascii("izabilities"),
        dictgen::InsensitiveStr::Ascii("izability"),
        dictgen::InsensitiveStr::Ascii("izable"),
        dictgen::InsensitiveStr::Ascii("izableness"),
        dictgen::InsensitiveStr::Ascii("izabler"),
        dictgen::InsensitiveStr::Ascii("izables"),
        dictgen::InsensitiveStr::Ascii("izablest"),
        dictgen::InsensitiveStr::Ascii("izablies"),
        dictgen::InsensitiveStr::Ascii("izably"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izer"),
        dictgen::InsensitiveStr::Ascii("izers"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
        dictgen::InsensitiveStr::Ascii("izingly"),
        dictgen::InsensitiveStr::Ascii("izings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REALIZABILITIES_13223271680114933460)],
        &[(0b10010, &ENTRY_REALIZABILITY_13322425294944377574)],
        &[(0b10010, &ENTRY_REALIZABLE_10812601608535921771)],
        &[(0b10010, &ENTRY_REALIZABLENESS_6515553396419609224)],
        &[(0b10010, &ENTRY_REALIZABLER_14683688646248955937)],
        &[(0b10010, &ENTRY_REALIZABLES_7049723572386299791)],
        &[(0b10010, &ENTRY_REALIZABLEST_2622856111033460976)],
        &[(0b10010, &ENTRY_REALIZABLIES_14651669305923865755)],
        &[(0b10010, &ENTRY_REALIZABLY_14326441766508324971)],
        &[(0b10010, &ENTRY_REALIZATION_17538125674282335558)],
        &[(0b10010, &ENTRY_REALIZATIONS_12363509003743664991)],
        &[(0b10010, &ENTRY_REALIZE_16854214244264054056)],
        &[(0b10010, &ENTRY_REALIZED_16745895995959846860)],
        &[(0b10010, &ENTRY_REALIZER_1946233796964896252)],
        &[(0b10010, &ENTRY_REALIZERS_8487572591462819622)],
        &[(0b10010, &ENTRY_REALIZES_2138970691925381265)],
        &[(0b10010, &ENTRY_REALIZING_510217803664458507)],
        &[(0b10010, &ENTRY_REALIZINGLY_12242157990012557248)],
        &[(0b10010, &ENTRY_REALIZINGS_5530634631066484428)],
        &[(0b10010, &ENTRY_REALISTICIZE_13401215139227567955)],
        &[(0b10010, &ENTRY_REALISTICIZES_8988192173192469177)],
        &[(0b01001, &ENTRY_REALISTICIZE_13401215139227567955)],
        &[(0b01001, &ENTRY_REALISTICIZES_8988192173192469177)],
        &[(0b01001, &ENTRY_REALIZABILITIES_13223271680114933460)],
        &[(0b01001, &ENTRY_REALIZABILITY_13322425294944377574)],
        &[(0b01001, &ENTRY_REALIZABLE_10812601608535921771)],
        &[(0b01001, &ENTRY_REALIZABLENESS_6515553396419609224)],
        &[(0b01001, &ENTRY_REALIZABLER_14683688646248955937)],
        &[(0b01001, &ENTRY_REALIZABLES_7049723572386299791)],
        &[(0b01001, &ENTRY_REALIZABLEST_2622856111033460976)],
        &[(0b01001, &ENTRY_REALIZABLIES_14651669305923865755)],
        &[(0b01001, &ENTRY_REALIZABLY_14326441766508324971)],
        &[(0b01001, &ENTRY_REALIZATION_17538125674282335558)],
        &[(0b01001, &ENTRY_REALIZATIONS_12363509003743664991)],
        &[(0b01001, &ENTRY_REALIZE_16854214244264054056)],
        &[(0b01001, &ENTRY_REALIZED_16745895995959846860)],
        &[(0b01001, &ENTRY_REALIZER_1946233796964896252)],
        &[(0b01001, &ENTRY_REALIZERS_8487572591462819622)],
        &[(0b01001, &ENTRY_REALIZES_2138970691925381265)],
        &[(0b01001, &ENTRY_REALIZING_510217803664458507)],
        &[(0b01001, &ENTRY_REALIZINGLY_12242157990012557248)],
        &[(0b01001, &ENTRY_REALIZINGS_5530634631066484428)],
    ],
    range: 3..=11,
};

static VARS_REAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REAE_CHILDREN),
    value: None,
};

pub static VARS_REAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dified"),
        dictgen::InsensitiveStr::Ascii("difies"),
        dictgen::InsensitiveStr::Ascii("dify"),
        dictgen::InsensitiveStr::Ascii("difying"),
        dictgen::InsensitiveStr::Ascii("ntrance"),
        dictgen::InsensitiveStr::Ascii("xportation"),
        dictgen::InsensitiveStr::Ascii("xporter"),
    ],
    values: &[
        &[(0b11010, &ENTRY_REEDIFIED_16744059649461415199)],
        &[(0b11010, &ENTRY_REEDIFIES_1966686662934617271)],
        &[(0b11010, &ENTRY_REEDIFY_5917708217519330521)],
        &[(0b11010, &ENTRY_REEDIFYING_5914929745473328575)],
        &[(0b11010, &ENTRY_REENTRANCE_9955645890849905473)],
        &[(0b11010, &ENTRY_REEXPORTATION_15204503066819424789)],
        &[(0b11010, &ENTRY_REEXPORTER_3504356768607899599)],
    ],
    range: 4..=10,
};

static VARS_READ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_READ_CHILDREN),
    value: None,
};

pub static VARS_READ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("vertise"),
        dictgen::InsensitiveStr::Ascii("vertised"),
        dictgen::InsensitiveStr::Ascii("vertising"),
        dictgen::InsensitiveStr::Ascii("vertize"),
        dictgen::InsensitiveStr::Ascii("vertized"),
        dictgen::InsensitiveStr::Ascii("vertizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_READVERTIZE_13794491662836301519)],
        &[(0b10010, &ENTRY_READVERTIZED_17657507769021889566)],
        &[(0b10010, &ENTRY_READVERTIZING_8057785064827564408)],
        &[(0b01001, &ENTRY_READVERTIZE_13794491662836301519)],
        &[(0b01001, &ENTRY_READVERTIZED_17657507769021889566)],
        &[(0b01001, &ENTRY_READVERTIZING_8057785064827564408)],
    ],
    range: 7..=9,
};

static VARS_REAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REAC_CHILDREN),
    value: None,
};

pub static VARS_REAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("climatisation"),
        dictgen::InsensitiveStr::Ascii("climatisations"),
        dictgen::InsensitiveStr::Ascii("climatise"),
        dictgen::InsensitiveStr::Ascii("climatised"),
        dictgen::InsensitiveStr::Ascii("climatises"),
        dictgen::InsensitiveStr::Ascii("climatising"),
        dictgen::InsensitiveStr::Ascii("climatization"),
        dictgen::InsensitiveStr::Ascii("climatizations"),
        dictgen::InsensitiveStr::Ascii("climatize"),
        dictgen::InsensitiveStr::Ascii("climatized"),
        dictgen::InsensitiveStr::Ascii("climatizes"),
        dictgen::InsensitiveStr::Ascii("climatizing"),
        dictgen::InsensitiveStr::Ascii("tualise"),
        dictgen::InsensitiveStr::Ascii("tualises"),
        dictgen::InsensitiveStr::Ascii("tualize"),
        dictgen::InsensitiveStr::Ascii("tualizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REACCLIMATIZATION_2957354685459389977)],
        &[(0b10010, &ENTRY_REACCLIMATIZATIONS_1759410062674249822)],
        &[(0b10010, &ENTRY_REACCLIMATIZE_8214017527074354751)],
        &[(0b10010, &ENTRY_REACCLIMATIZED_13074003933896937486)],
        &[(0b10010, &ENTRY_REACCLIMATIZES_2132848089448488857)],
        &[(0b10010, &ENTRY_REACCLIMATIZING_9326049221438472202)],
        &[(0b01001, &ENTRY_REACCLIMATIZATION_2957354685459389977)],
        &[(0b01001, &ENTRY_REACCLIMATIZATIONS_1759410062674249822)],
        &[(0b01001, &ENTRY_REACCLIMATIZE_8214017527074354751)],
        &[(0b01001, &ENTRY_REACCLIMATIZED_13074003933896937486)],
        &[(0b01001, &ENTRY_REACCLIMATIZES_2132848089448488857)],
        &[(0b01001, &ENTRY_REACCLIMATIZING_9326049221438472202)],
        &[(0b10010, &ENTRY_REACTUALIZE_3203135312213485752)],
        &[(0b10010, &ENTRY_REACTUALIZES_17893616365972474414)],
        &[(0b01001, &ENTRY_REACTUALIZE_3203135312213485752)],
        &[(0b01001, &ENTRY_REACTUALIZES_17893616365972474414)],
    ],
    range: 7..=14,
};

static VARS_RA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RA_CHILDREN),
    value: None,
};

static VARS_RA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_RAC_NODE),
    Some(&VARS_RAD_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RAM_NODE),
    Some(&VARS_RAN_NODE),
    None,
    Some(&VARS_RAP_NODE),
    None,
    None,
    Some(&VARS_RAS_NODE),
    Some(&VARS_RAT_NODE),
    None,
    Some(&VARS_RAV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_RAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAV_CHILDREN),
    value: None,
};

pub static VARS_RAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_RAVELED_9671236154632535117)],
        &[(0b00001, &ENTRY_RAVELER_1875202002762708867)],
        &[(0b00001, &ENTRY_RAVELERS_15963715376836433914)],
        &[
            (0b00001, &ENTRY_RAVELING_11765690468894667622),
            (0b01001, &ENTRY_RAVELING_17031636493348292626),
        ],
        &[(0b01001, &ENTRY_RAVELINGS_15784329780600976151)],
        &[(0b11010, &ENTRY_RAVELED_9671236154632535117)],
        &[(0b11010, &ENTRY_RAVELER_1875202002762708867)],
        &[(0b11010, &ENTRY_RAVELERS_15963715376836433914)],
        &[
            (0b11010, &ENTRY_RAVELING_11765690468894667622),
            (0b11010, &ENTRY_RAVELING_17031636493348292626),
        ],
        &[(0b11010, &ENTRY_RAVELINGS_15784329780600976151)],
    ],
    range: 4..=7,
};

static VARS_RAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAT_CHILDREN),
    value: None,
};

pub static VARS_RAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ionalisable"),
        dictgen::InsensitiveStr::Ascii("ionalisables"),
        dictgen::InsensitiveStr::Ascii("ionalisation"),
        dictgen::InsensitiveStr::Ascii("ionalisations"),
        dictgen::InsensitiveStr::Ascii("ionalise"),
        dictgen::InsensitiveStr::Ascii("ionalised"),
        dictgen::InsensitiveStr::Ascii("ionaliser"),
        dictgen::InsensitiveStr::Ascii("ionalisers"),
        dictgen::InsensitiveStr::Ascii("ionalises"),
        dictgen::InsensitiveStr::Ascii("ionalising"),
        dictgen::InsensitiveStr::Ascii("ionalizable"),
        dictgen::InsensitiveStr::Ascii("ionalizables"),
        dictgen::InsensitiveStr::Ascii("ionalization"),
        dictgen::InsensitiveStr::Ascii("ionalizations"),
        dictgen::InsensitiveStr::Ascii("ionalize"),
        dictgen::InsensitiveStr::Ascii("ionalized"),
        dictgen::InsensitiveStr::Ascii("ionalizer"),
        dictgen::InsensitiveStr::Ascii("ionalizers"),
        dictgen::InsensitiveStr::Ascii("ionalizes"),
        dictgen::InsensitiveStr::Ascii("ionalizing"),
        dictgen::InsensitiveStr::Ascii("itae"),
        dictgen::InsensitiveStr::Ascii("ite"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RATIONALIZABLE_13968007634740037455)],
        &[(0b10010, &ENTRY_RATIONALIZABLES_13479284365708575735)],
        &[(0b10010, &ENTRY_RATIONALIZATION_15122379068974818074)],
        &[(0b10010, &ENTRY_RATIONALIZATIONS_9800744027548504414)],
        &[(0b10010, &ENTRY_RATIONALIZE_6652701615501848408)],
        &[(0b10010, &ENTRY_RATIONALIZED_1971558827219194409)],
        &[(0b10010, &ENTRY_RATIONALIZER_11150960083745833433)],
        &[(0b10010, &ENTRY_RATIONALIZERS_14291639036077192937)],
        &[(0b10010, &ENTRY_RATIONALIZES_4247086699247832305)],
        &[(0b10010, &ENTRY_RATIONALIZING_8795870211255807930)],
        &[(0b01001, &ENTRY_RATIONALIZABLE_13968007634740037455)],
        &[(0b01001, &ENTRY_RATIONALIZABLES_13479284365708575735)],
        &[(0b01001, &ENTRY_RATIONALIZATION_15122379068974818074)],
        &[(0b01001, &ENTRY_RATIONALIZATIONS_9800744027548504414)],
        &[(0b01001, &ENTRY_RATIONALIZE_6652701615501848408)],
        &[(0b01001, &ENTRY_RATIONALIZED_1971558827219194409)],
        &[(0b01001, &ENTRY_RATIONALIZER_11150960083745833433)],
        &[(0b01001, &ENTRY_RATIONALIZERS_14291639036077192937)],
        &[(0b01001, &ENTRY_RATIONALIZES_4247086699247832305)],
        &[(0b01001, &ENTRY_RATIONALIZING_8795870211255807930)],
        &[(0b11010, &ENTRY_RATITE_12860753036335482821)],
        &[(0b00001, &ENTRY_RATITE_12860753036335482821)],
    ],
    range: 3..=13,
};

static VARS_RAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAS_CHILDREN),
    value: None,
};

pub static VARS_RAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("calise"),
        dictgen::InsensitiveStr::Ascii("calises"),
        dictgen::InsensitiveStr::Ascii("calize"),
        dictgen::InsensitiveStr::Ascii("calizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RASCALIZE_11088984531047771127)],
        &[(0b10010, &ENTRY_RASCALIZES_3431692090706905594)],
        &[(0b01001, &ENTRY_RASCALIZE_11088984531047771127)],
        &[(0b01001, &ENTRY_RASCALIZES_3431692090706905594)],
    ],
    range: 6..=7,
};

static VARS_RAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAP_CHILDREN),
    value: None,
};

pub static VARS_RAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hae"),
        dictgen::InsensitiveStr::Ascii("he"),
        dictgen::InsensitiveStr::Ascii("hidae"),
        dictgen::InsensitiveStr::Ascii("hide"),
        dictgen::InsensitiveStr::Ascii("turise"),
        dictgen::InsensitiveStr::Ascii("turised"),
        dictgen::InsensitiveStr::Ascii("turises"),
        dictgen::InsensitiveStr::Ascii("turising"),
        dictgen::InsensitiveStr::Ascii("turize"),
        dictgen::InsensitiveStr::Ascii("turized"),
        dictgen::InsensitiveStr::Ascii("turizes"),
        dictgen::InsensitiveStr::Ascii("turizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_RAPHE_17614585471421284474)],
        &[(0b00001, &ENTRY_RAPHE_17614585471421284474)],
        &[(0b11010, &ENTRY_RAPHIDE_11826784517180909569)],
        &[(0b00001, &ENTRY_RAPHIDE_11826784517180909569)],
        &[(0b10010, &ENTRY_RAPTURIZE_3642337496632244291)],
        &[(0b10010, &ENTRY_RAPTURIZED_2957768997607937781)],
        &[(0b10010, &ENTRY_RAPTURIZES_10958799811768096836)],
        &[(0b10010, &ENTRY_RAPTURIZING_11292594828989392597)],
        &[(0b01001, &ENTRY_RAPTURIZE_3642337496632244291)],
        &[(0b01001, &ENTRY_RAPTURIZED_2957768997607937781)],
        &[(0b01001, &ENTRY_RAPTURIZES_10958799811768096836)],
        &[(0b01001, &ENTRY_RAPTURIZING_11292594828989392597)],
    ],
    range: 2..=8,
};

static VARS_RAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAN_CHILDREN),
    value: None,
};

pub static VARS_RAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cor"),
        dictgen::InsensitiveStr::Ascii("cors"),
        dictgen::InsensitiveStr::Ascii("cour"),
        dictgen::InsensitiveStr::Ascii("cours"),
        dictgen::InsensitiveStr::Ascii("domisation"),
        dictgen::InsensitiveStr::Ascii("domisations"),
        dictgen::InsensitiveStr::Ascii("domise"),
        dictgen::InsensitiveStr::Ascii("domised"),
        dictgen::InsensitiveStr::Ascii("domiser"),
        dictgen::InsensitiveStr::Ascii("domisers"),
        dictgen::InsensitiveStr::Ascii("domises"),
        dictgen::InsensitiveStr::Ascii("domising"),
        dictgen::InsensitiveStr::Ascii("domization"),
        dictgen::InsensitiveStr::Ascii("domizations"),
        dictgen::InsensitiveStr::Ascii("domize"),
        dictgen::InsensitiveStr::Ascii("domized"),
        dictgen::InsensitiveStr::Ascii("domizer"),
        dictgen::InsensitiveStr::Ascii("domizers"),
        dictgen::InsensitiveStr::Ascii("domizes"),
        dictgen::InsensitiveStr::Ascii("domizing"),
    ],
    values: &[
        &[(0b11001, &ENTRY_RANCOR_9356695782734834392)],
        &[(0b11001, &ENTRY_RANCORS_270940283740230206)],
        &[(0b11010, &ENTRY_RANCOR_9356695782734834392)],
        &[(0b11010, &ENTRY_RANCORS_270940283740230206)],
        &[(0b10010, &ENTRY_RANDOMIZATION_3681577253421449588)],
        &[(0b10010, &ENTRY_RANDOMIZATIONS_17321397777946946784)],
        &[(0b10010, &ENTRY_RANDOMIZE_6072760763688384932)],
        &[(0b10010, &ENTRY_RANDOMIZED_14277029247963491589)],
        &[(0b10010, &ENTRY_RANDOMIZER_1280923813569790342)],
        &[(0b10010, &ENTRY_RANDOMIZERS_4291017330476860233)],
        &[(0b10010, &ENTRY_RANDOMIZES_13911797236422860580)],
        &[(0b10010, &ENTRY_RANDOMIZING_2799378200434038162)],
        &[(0b01001, &ENTRY_RANDOMIZATION_3681577253421449588)],
        &[(0b01001, &ENTRY_RANDOMIZATIONS_17321397777946946784)],
        &[(0b01001, &ENTRY_RANDOMIZE_6072760763688384932)],
        &[(0b01001, &ENTRY_RANDOMIZED_14277029247963491589)],
        &[(0b01001, &ENTRY_RANDOMIZER_1280923813569790342)],
        &[(0b01001, &ENTRY_RANDOMIZERS_4291017330476860233)],
        &[(0b01001, &ENTRY_RANDOMIZES_13911797236422860580)],
        &[(0b01001, &ENTRY_RANDOMIZING_2799378200434038162)],
    ],
    range: 3..=11,
};

static VARS_RAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAM_CHILDREN),
    value: None,
};

pub static VARS_RAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("pier"),
        dictgen::InsensitiveStr::Ascii("pire"),
    ],
    values: &[
        &[(0b11010, &ENTRY_RAME_10158219518261805370)],
        &[(0b00001, &ENTRY_RAME_10158219518261805370)],
        &[(0b00001, &ENTRY_RAMPIER_3346640046708441849)],
        &[(0b11010, &ENTRY_RAMPIER_3346640046708441849)],
    ],
    range: 1..=4,
};

static VARS_RAD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAD_CHILDREN),
    value: None,
};

pub static VARS_RAD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("borne"),
        dictgen::InsensitiveStr::Ascii("bourne"),
        dictgen::InsensitiveStr::Ascii("ialisation"),
        dictgen::InsensitiveStr::Ascii("ialisations"),
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialised"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialising"),
        dictgen::InsensitiveStr::Ascii("ialization"),
        dictgen::InsensitiveStr::Ascii("ializations"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ialized"),
        dictgen::InsensitiveStr::Ascii("ializes"),
        dictgen::InsensitiveStr::Ascii("ializing"),
        dictgen::InsensitiveStr::Ascii("icalisation"),
        dictgen::InsensitiveStr::Ascii("icalisations"),
        dictgen::InsensitiveStr::Ascii("icalise"),
        dictgen::InsensitiveStr::Ascii("icalised"),
        dictgen::InsensitiveStr::Ascii("icalises"),
        dictgen::InsensitiveStr::Ascii("icalising"),
        dictgen::InsensitiveStr::Ascii("icalization"),
        dictgen::InsensitiveStr::Ascii("icalizations"),
        dictgen::InsensitiveStr::Ascii("icalize"),
        dictgen::InsensitiveStr::Ascii("icalized"),
        dictgen::InsensitiveStr::Ascii("icalizes"),
        dictgen::InsensitiveStr::Ascii("icalizing"),
        dictgen::InsensitiveStr::Ascii("iopasteurisation"),
        dictgen::InsensitiveStr::Ascii("iopasteurization"),
        dictgen::InsensitiveStr::Ascii("iosensitise"),
        dictgen::InsensitiveStr::Ascii("iosensitised"),
        dictgen::InsensitiveStr::Ascii("iosensitises"),
        dictgen::InsensitiveStr::Ascii("iosensitising"),
        dictgen::InsensitiveStr::Ascii("iosensitize"),
        dictgen::InsensitiveStr::Ascii("iosensitized"),
        dictgen::InsensitiveStr::Ascii("iosensitizes"),
        dictgen::InsensitiveStr::Ascii("iosensitizing"),
        dictgen::InsensitiveStr::Ascii("iosterilisation"),
        dictgen::InsensitiveStr::Ascii("iosterilise"),
        dictgen::InsensitiveStr::Ascii("iosterilised"),
        dictgen::InsensitiveStr::Ascii("iosterilises"),
        dictgen::InsensitiveStr::Ascii("iosterilising"),
        dictgen::InsensitiveStr::Ascii("iosterilization"),
        dictgen::InsensitiveStr::Ascii("iosterilize"),
        dictgen::InsensitiveStr::Ascii("iosterilized"),
        dictgen::InsensitiveStr::Ascii("iosterilizes"),
        dictgen::InsensitiveStr::Ascii("iosterilizing"),
        dictgen::InsensitiveStr::Ascii("iumisation"),
        dictgen::InsensitiveStr::Ascii("iumisations"),
        dictgen::InsensitiveStr::Ascii("iumise"),
        dictgen::InsensitiveStr::Ascii("iumises"),
        dictgen::InsensitiveStr::Ascii("iumization"),
        dictgen::InsensitiveStr::Ascii("iumizations"),
        dictgen::InsensitiveStr::Ascii("iumize"),
        dictgen::InsensitiveStr::Ascii("iumizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_RADBORNE_3041954533932383584)],
        &[(0b11010, &ENTRY_RADBORNE_3041954533932383584)],
        &[(0b10010, &ENTRY_RADIALIZATION_18383971186210393104)],
        &[(0b10010, &ENTRY_RADIALIZATIONS_10502594546253256068)],
        &[(0b10010, &ENTRY_RADIALIZE_8311173565044984666)],
        &[(0b10010, &ENTRY_RADIALIZED_4237438878600149477)],
        &[(0b10010, &ENTRY_RADIALIZES_12634635863472551020)],
        &[(0b10010, &ENTRY_RADIALIZING_16490137149663325926)],
        &[(0b01001, &ENTRY_RADIALIZATION_18383971186210393104)],
        &[(0b01001, &ENTRY_RADIALIZATIONS_10502594546253256068)],
        &[(0b01001, &ENTRY_RADIALIZE_8311173565044984666)],
        &[(0b01001, &ENTRY_RADIALIZED_4237438878600149477)],
        &[(0b01001, &ENTRY_RADIALIZES_12634635863472551020)],
        &[(0b01001, &ENTRY_RADIALIZING_16490137149663325926)],
        &[(0b10010, &ENTRY_RADICALIZATION_13110894594007945745)],
        &[(0b10010, &ENTRY_RADICALIZATIONS_11340536761047241964)],
        &[(0b10010, &ENTRY_RADICALIZE_10054640819610183612)],
        &[(0b10010, &ENTRY_RADICALIZED_16178051502331122105)],
        &[(0b10010, &ENTRY_RADICALIZES_7656516679067813609)],
        &[(0b10010, &ENTRY_RADICALIZING_9302352701494268209)],
        &[(0b01001, &ENTRY_RADICALIZATION_13110894594007945745)],
        &[(0b01001, &ENTRY_RADICALIZATIONS_11340536761047241964)],
        &[(0b01001, &ENTRY_RADICALIZE_10054640819610183612)],
        &[(0b01001, &ENTRY_RADICALIZED_16178051502331122105)],
        &[(0b01001, &ENTRY_RADICALIZES_7656516679067813609)],
        &[(0b01001, &ENTRY_RADICALIZING_9302352701494268209)],
        &[(0b10010, &ENTRY_RADIOPASTEURIZATION_15447663133364104406)],
        &[(0b01001, &ENTRY_RADIOPASTEURIZATION_15447663133364104406)],
        &[(0b10010, &ENTRY_RADIOSENSITIZE_10576583280478170080)],
        &[(0b10010, &ENTRY_RADIOSENSITIZED_3133459093835999280)],
        &[(0b10010, &ENTRY_RADIOSENSITIZES_5205828049305600755)],
        &[(0b10010, &ENTRY_RADIOSENSITIZING_5621538877060197152)],
        &[(0b01001, &ENTRY_RADIOSENSITIZE_10576583280478170080)],
        &[(0b01001, &ENTRY_RADIOSENSITIZED_3133459093835999280)],
        &[(0b01001, &ENTRY_RADIOSENSITIZES_5205828049305600755)],
        &[(0b01001, &ENTRY_RADIOSENSITIZING_5621538877060197152)],
        &[(0b10010, &ENTRY_RADIOSTERILIZATION_5746202029644240544)],
        &[(0b10010, &ENTRY_RADIOSTERILIZE_12689946306814556239)],
        &[(0b10010, &ENTRY_RADIOSTERILIZED_18243964894695163623)],
        &[(0b10010, &ENTRY_RADIOSTERILIZES_1628059493209100984)],
        &[(0b10010, &ENTRY_RADIOSTERILIZING_15523793208987281845)],
        &[(0b01001, &ENTRY_RADIOSTERILIZATION_5746202029644240544)],
        &[(0b01001, &ENTRY_RADIOSTERILIZE_12689946306814556239)],
        &[(0b01001, &ENTRY_RADIOSTERILIZED_18243964894695163623)],
        &[(0b01001, &ENTRY_RADIOSTERILIZES_1628059493209100984)],
        &[(0b01001, &ENTRY_RADIOSTERILIZING_15523793208987281845)],
        &[(0b10010, &ENTRY_RADIUMIZATION_602043437160535636)],
        &[(0b10010, &ENTRY_RADIUMIZATIONS_7650953693255078336)],
        &[(0b10010, &ENTRY_RADIUMIZE_11607458329799776620)],
        &[(0b10010, &ENTRY_RADIUMIZES_5319143397967858483)],
        &[(0b01001, &ENTRY_RADIUMIZATION_602043437160535636)],
        &[(0b01001, &ENTRY_RADIUMIZATIONS_7650953693255078336)],
        &[(0b01001, &ENTRY_RADIUMIZE_11607458329799776620)],
        &[(0b01001, &ENTRY_RADIUMIZES_5319143397967858483)],
    ],
    range: 5..=16,
};

static VARS_RAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAC_CHILDREN),
    value: None,
};

pub static VARS_RAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emisation"),
        dictgen::InsensitiveStr::Ascii("emisations"),
        dictgen::InsensitiveStr::Ascii("emise"),
        dictgen::InsensitiveStr::Ascii("emised"),
        dictgen::InsensitiveStr::Ascii("emises"),
        dictgen::InsensitiveStr::Ascii("emising"),
        dictgen::InsensitiveStr::Ascii("emization"),
        dictgen::InsensitiveStr::Ascii("emizations"),
        dictgen::InsensitiveStr::Ascii("emize"),
        dictgen::InsensitiveStr::Ascii("emized"),
        dictgen::InsensitiveStr::Ascii("emizes"),
        dictgen::InsensitiveStr::Ascii("emizing"),
        dictgen::InsensitiveStr::Ascii("ialisation"),
        dictgen::InsensitiveStr::Ascii("ialisations"),
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialization"),
        dictgen::InsensitiveStr::Ascii("ializations"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RACEMIZATION_9371693322902504373)],
        &[(0b10010, &ENTRY_RACEMIZATIONS_12310534806043247350)],
        &[(0b10010, &ENTRY_RACEMIZE_3054918782672213541)],
        &[(0b10010, &ENTRY_RACEMIZED_9677793823006904997)],
        &[(0b10010, &ENTRY_RACEMIZES_10597386031959072058)],
        &[(0b10010, &ENTRY_RACEMIZING_5309342562156096170)],
        &[(0b01001, &ENTRY_RACEMIZATION_9371693322902504373)],
        &[(0b01001, &ENTRY_RACEMIZATIONS_12310534806043247350)],
        &[(0b01001, &ENTRY_RACEMIZE_3054918782672213541)],
        &[(0b01001, &ENTRY_RACEMIZED_9677793823006904997)],
        &[(0b01001, &ENTRY_RACEMIZES_10597386031959072058)],
        &[(0b01001, &ENTRY_RACEMIZING_5309342562156096170)],
        &[(0b10010, &ENTRY_RACIALIZATION_12563934097397087336)],
        &[(0b10010, &ENTRY_RACIALIZATIONS_9543941027629116033)],
        &[(0b10010, &ENTRY_RACIALIZE_3649756850548033240)],
        &[(0b10010, &ENTRY_RACIALIZES_2119895632298352154)],
        &[(0b01001, &ENTRY_RACIALIZATION_12563934097397087336)],
        &[(0b01001, &ENTRY_RACIALIZATIONS_9543941027629116033)],
        &[(0b01001, &ENTRY_RACIALIZE_3649756850548033240)],
        &[(0b01001, &ENTRY_RACIALIZES_2119895632298352154)],
    ],
    range: 5..=11,
};

static VARS_Q_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_Q_CHILDREN),
    value: None,
};

static VARS_Q_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_QU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_QU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_QU_CHILDREN),
    value: None,
};

static VARS_QU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_QUA_NODE),
    None,
    None,
    None,
    Some(&VARS_QUE_NODE),
    None,
    None,
    None,
    Some(&VARS_QUI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_QUI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_QUI_CHILDREN),
    value: None,
};

pub static VARS_QUI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ninise"),
        dictgen::InsensitiveStr::Ascii("ninises"),
        dictgen::InsensitiveStr::Ascii("ninize"),
        dictgen::InsensitiveStr::Ascii("ninizes"),
        dictgen::InsensitiveStr::Ascii("ntessentialise"),
        dictgen::InsensitiveStr::Ascii("ntessentialised"),
        dictgen::InsensitiveStr::Ascii("ntessentialises"),
        dictgen::InsensitiveStr::Ascii("ntessentialising"),
        dictgen::InsensitiveStr::Ascii("ntessentialize"),
        dictgen::InsensitiveStr::Ascii("ntessentialized"),
        dictgen::InsensitiveStr::Ascii("ntessentializes"),
        dictgen::InsensitiveStr::Ascii("ntessentializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_QUININIZE_17096362566529931559)],
        &[(0b10010, &ENTRY_QUININIZES_12729565422121835336)],
        &[(0b01001, &ENTRY_QUININIZE_17096362566529931559)],
        &[(0b01001, &ENTRY_QUININIZES_12729565422121835336)],
        &[(0b10010, &ENTRY_QUINTESSENTIALIZE_16551571696077174150)],
        &[(0b10010, &ENTRY_QUINTESSENTIALIZED_13415832374097191642)],
        &[(0b10010, &ENTRY_QUINTESSENTIALIZES_9197519715821715432)],
        &[(0b10010, &ENTRY_QUINTESSENTIALIZING_17194024065213552996)],
        &[(0b01001, &ENTRY_QUINTESSENTIALIZE_16551571696077174150)],
        &[(0b01001, &ENTRY_QUINTESSENTIALIZED_13415832374097191642)],
        &[(0b01001, &ENTRY_QUINTESSENTIALIZES_9197519715821715432)],
        &[(0b01001, &ENTRY_QUINTESSENTIALIZING_17194024065213552996)],
    ],
    range: 6..=16,
};

static VARS_QUE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_QUE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_QUE_13140225885135664317)]),
};

pub static VARS_QUE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("relae"),
        dictgen::InsensitiveStr::Ascii("rele"),
        dictgen::InsensitiveStr::Ascii("stionaries"),
        dictgen::InsensitiveStr::Ascii("stionary"),
        dictgen::InsensitiveStr::Ascii("stor"),
        dictgen::InsensitiveStr::Ascii("storial"),
        dictgen::InsensitiveStr::Ascii("stors"),
        dictgen::InsensitiveStr::Ascii("storship"),
        dictgen::InsensitiveStr::Ascii("ueing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_QUERELE_9438416090405216166)],
        &[(0b00001, &ENTRY_QUERELE_9438416090405216166)],
        &[(0b00001, &ENTRY_QUESTIONARIES_14112072398132498455)],
        &[(0b00001, &ENTRY_QUESTIONARY_3937811141146454597)],
        &[(0b00001, &ENTRY_QUAESTOR_2102274138115411812)],
        &[(0b00001, &ENTRY_QUESTORIAL_17326734910194857691)],
        &[(0b00001, &ENTRY_QUAESTORS_10032398541103637992)],
        &[(0b00001, &ENTRY_QUESTORSHIP_15494085821790686854)],
        &[(0b11010, &ENTRY_QUEUING_8138344236437954477)],
    ],
    range: 4..=10,
};

static VARS_QUA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_QUA_CHILDREN),
    value: None,
};

pub static VARS_QUA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("estionaries"),
        dictgen::InsensitiveStr::Ascii("estionary"),
        dictgen::InsensitiveStr::Ascii("estorial"),
        dictgen::InsensitiveStr::Ascii("estorship"),
        dictgen::InsensitiveStr::Ascii("kerisation"),
        dictgen::InsensitiveStr::Ascii("kerisations"),
        dictgen::InsensitiveStr::Ascii("kerise"),
        dictgen::InsensitiveStr::Ascii("kerises"),
        dictgen::InsensitiveStr::Ascii("kerization"),
        dictgen::InsensitiveStr::Ascii("kerizations"),
        dictgen::InsensitiveStr::Ascii("kerize"),
        dictgen::InsensitiveStr::Ascii("kerizes"),
        dictgen::InsensitiveStr::Ascii("ntisation"),
        dictgen::InsensitiveStr::Ascii("ntisations"),
        dictgen::InsensitiveStr::Ascii("ntise"),
        dictgen::InsensitiveStr::Ascii("ntised"),
        dictgen::InsensitiveStr::Ascii("ntiser"),
        dictgen::InsensitiveStr::Ascii("ntisers"),
        dictgen::InsensitiveStr::Ascii("ntises"),
        dictgen::InsensitiveStr::Ascii("ntising"),
        dictgen::InsensitiveStr::Ascii("ntization"),
        dictgen::InsensitiveStr::Ascii("ntizations"),
        dictgen::InsensitiveStr::Ascii("ntize"),
        dictgen::InsensitiveStr::Ascii("ntized"),
        dictgen::InsensitiveStr::Ascii("ntizer"),
        dictgen::InsensitiveStr::Ascii("ntizers"),
        dictgen::InsensitiveStr::Ascii("ntizes"),
        dictgen::InsensitiveStr::Ascii("ntizing"),
        dictgen::InsensitiveStr::Ascii("rreled"),
        dictgen::InsensitiveStr::Ascii("rreler"),
        dictgen::InsensitiveStr::Ascii("rrelers"),
        dictgen::InsensitiveStr::Ascii("rreling"),
        dictgen::InsensitiveStr::Ascii("rrelled"),
        dictgen::InsensitiveStr::Ascii("rreller"),
        dictgen::InsensitiveStr::Ascii("rrellers"),
        dictgen::InsensitiveStr::Ascii("rrelling"),
        dictgen::InsensitiveStr::Ascii("rrellous"),
        dictgen::InsensitiveStr::Ascii("rrelous"),
        dictgen::InsensitiveStr::Ascii("rterisation"),
        dictgen::InsensitiveStr::Ascii("rterisations"),
        dictgen::InsensitiveStr::Ascii("rterization"),
        dictgen::InsensitiveStr::Ascii("rterizations"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_QUE_13140225885135664317)],
        &[(0b11010, &ENTRY_QUESTIONARIES_14112072398132498455)],
        &[(0b11010, &ENTRY_QUESTIONARY_3937811141146454597)],
        &[(0b11010, &ENTRY_QUESTORIAL_17326734910194857691)],
        &[(0b11010, &ENTRY_QUESTORSHIP_15494085821790686854)],
        &[(0b10010, &ENTRY_QUAKERIZATION_17206737357396103152)],
        &[(0b10010, &ENTRY_QUAKERIZATIONS_3245384999167216727)],
        &[(0b10010, &ENTRY_QUAKERIZE_5397219040311238658)],
        &[(0b10010, &ENTRY_QUAKERIZES_10193743747756102765)],
        &[(0b01001, &ENTRY_QUAKERIZATION_17206737357396103152)],
        &[(0b01001, &ENTRY_QUAKERIZATIONS_3245384999167216727)],
        &[(0b01001, &ENTRY_QUAKERIZE_5397219040311238658)],
        &[(0b01001, &ENTRY_QUAKERIZES_10193743747756102765)],
        &[(0b10010, &ENTRY_QUANTIZATION_16189268688890136964)],
        &[(0b10010, &ENTRY_QUANTIZATIONS_15578988125770234593)],
        &[(0b10010, &ENTRY_QUANTIZE_17116602340307321764)],
        &[(0b10010, &ENTRY_QUANTIZED_191687807901136208)],
        &[(0b10010, &ENTRY_QUANTIZER_10076665771116527647)],
        &[(0b10010, &ENTRY_QUANTIZERS_12112876514118865032)],
        &[(0b10010, &ENTRY_QUANTIZES_7731963658205656129)],
        &[(0b10010, &ENTRY_QUANTIZING_10481986099348319524)],
        &[(0b01001, &ENTRY_QUANTIZATION_16189268688890136964)],
        &[(0b01001, &ENTRY_QUANTIZATIONS_15578988125770234593)],
        &[(0b01001, &ENTRY_QUANTIZE_17116602340307321764)],
        &[(0b01001, &ENTRY_QUANTIZED_191687807901136208)],
        &[(0b01001, &ENTRY_QUANTIZER_10076665771116527647)],
        &[(0b01001, &ENTRY_QUANTIZERS_12112876514118865032)],
        &[(0b01001, &ENTRY_QUANTIZES_7731963658205656129)],
        &[(0b01001, &ENTRY_QUANTIZING_10481986099348319524)],
        &[(0b00001, &ENTRY_QUARRELED_15985766844967944821)],
        &[(0b00001, &ENTRY_QUARRELER_14446710496260840710)],
        &[(0b00001, &ENTRY_QUARRELERS_11216624719057293145)],
        &[(0b00001, &ENTRY_QUARRELING_14209000824927192944)],
        &[(0b11010, &ENTRY_QUARRELED_15985766844967944821)],
        &[(0b11010, &ENTRY_QUARRELER_14446710496260840710)],
        &[(0b11010, &ENTRY_QUARRELERS_11216624719057293145)],
        &[(0b11010, &ENTRY_QUARRELING_14209000824927192944)],
        &[(0b11010, &ENTRY_QUARRELOUS_4829001542031065451)],
        &[(0b00001, &ENTRY_QUARRELOUS_4829001542031065451)],
        &[(0b10010, &ENTRY_QUARTERIZATION_8280402932685165689)],
        &[(0b10010, &ENTRY_QUARTERIZATIONS_11825260088632494839)],
        &[(0b01001, &ENTRY_QUARTERIZATION_8280402932685165689)],
        &[(0b01001, &ENTRY_QUARTERIZATIONS_11825260088632494839)],
        &[(0b00001, &ENTRY_QUATERS_2526447849750605551)],
        &[(0b11010, &ENTRY_QUATERS_2526447849750605551)],
    ],
    range: 1..=12,
};

static VARS_P_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_P_CHILDREN),
    value: None,
};

static VARS_P_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PA_NODE),
    None,
    None,
    None,
    Some(&VARS_PE_NODE),
    None,
    None,
    Some(&VARS_PH_NODE),
    Some(&VARS_PI_NODE),
    None,
    None,
    Some(&VARS_PL_NODE),
    None,
    None,
    Some(&VARS_PO_NODE),
    None,
    None,
    Some(&VARS_PR_NODE),
    Some(&VARS_PS_NODE),
    Some(&VARS_PT_NODE),
    Some(&VARS_PU_NODE),
    None,
    None,
    None,
    Some(&VARS_PY_NODE),
    None,
];

static VARS_PY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PY_CHILDREN),
    value: None,
};

static VARS_PY_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PYA_NODE),
    None,
    None,
    None,
    Some(&VARS_PYE_NODE),
    None,
    Some(&VARS_PYG_NODE),
    None,
    None,
    Some(&VARS_PYJ_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_PYO_NODE),
    None,
    None,
    Some(&VARS_PYR_NODE),
    None,
    Some(&VARS_PYT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PYT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYT_CHILDREN),
    value: None,
};

pub static VARS_PYT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hagoreanise"),
        dictgen::InsensitiveStr::Ascii("hagoreanises"),
        dictgen::InsensitiveStr::Ascii("hagoreanize"),
        dictgen::InsensitiveStr::Ascii("hagoreanizes"),
        dictgen::InsensitiveStr::Ascii("honinae"),
        dictgen::InsensitiveStr::Ascii("honine"),
        dictgen::InsensitiveStr::Ascii("honise"),
        dictgen::InsensitiveStr::Ascii("honises"),
        dictgen::InsensitiveStr::Ascii("honize"),
        dictgen::InsensitiveStr::Ascii("honizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PYTHAGOREANIZE_4718603082876001070)],
        &[(0b10010, &ENTRY_PYTHAGOREANIZES_4101293918117765599)],
        &[(0b01001, &ENTRY_PYTHAGOREANIZE_4718603082876001070)],
        &[(0b01001, &ENTRY_PYTHAGOREANIZES_4101293918117765599)],
        &[(0b11010, &ENTRY_PYTHONINE_17988724234836146578)],
        &[(0b00001, &ENTRY_PYTHONINE_17988724234836146578)],
        &[(0b10010, &ENTRY_PYTHONIZE_11169836088771020218)],
        &[(0b10010, &ENTRY_PYTHONIZES_12966276028590092936)],
        &[(0b01001, &ENTRY_PYTHONIZE_11169836088771020218)],
        &[(0b01001, &ENTRY_PYTHONIZES_12966276028590092936)],
    ],
    range: 6..=12,
};

static VARS_PYR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYR_CHILDREN),
    value: None,
};

pub static VARS_PYR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("amidise"),
        dictgen::InsensitiveStr::Ascii("amidises"),
        dictgen::InsensitiveStr::Ascii("amidize"),
        dictgen::InsensitiveStr::Ascii("amidizes"),
        dictgen::InsensitiveStr::Ascii("enaean"),
        dictgen::InsensitiveStr::Ascii("enaeus"),
        dictgen::InsensitiveStr::Ascii("enean"),
        dictgen::InsensitiveStr::Ascii("eneus"),
        dictgen::InsensitiveStr::Ascii("idinise"),
        dictgen::InsensitiveStr::Ascii("idinises"),
        dictgen::InsensitiveStr::Ascii("idinize"),
        dictgen::InsensitiveStr::Ascii("idinizes"),
        dictgen::InsensitiveStr::Ascii("itisation"),
        dictgen::InsensitiveStr::Ascii("itisations"),
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itization"),
        dictgen::InsensitiveStr::Ascii("itizations"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
        dictgen::InsensitiveStr::Ascii("olysable"),
        dictgen::InsensitiveStr::Ascii("olysate"),
        dictgen::InsensitiveStr::Ascii("olysates"),
        dictgen::InsensitiveStr::Ascii("olyse"),
        dictgen::InsensitiveStr::Ascii("olysed"),
        dictgen::InsensitiveStr::Ascii("olyser"),
        dictgen::InsensitiveStr::Ascii("olyses"),
        dictgen::InsensitiveStr::Ascii("olysing"),
        dictgen::InsensitiveStr::Ascii("olyzable"),
        dictgen::InsensitiveStr::Ascii("olyzate"),
        dictgen::InsensitiveStr::Ascii("olyzates"),
        dictgen::InsensitiveStr::Ascii("olyze"),
        dictgen::InsensitiveStr::Ascii("olyzed"),
        dictgen::InsensitiveStr::Ascii("olyzer"),
        dictgen::InsensitiveStr::Ascii("olyzes"),
        dictgen::InsensitiveStr::Ascii("olyzing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PYRAMIDIZE_6518185724012578568)],
        &[(0b10010, &ENTRY_PYRAMIDIZES_10735124649198481951)],
        &[(0b01001, &ENTRY_PYRAMIDIZE_6518185724012578568)],
        &[(0b01001, &ENTRY_PYRAMIDIZES_10735124649198481951)],
        &[(0b11010, &ENTRY_PYRENEAN_15204083665180883806)],
        &[(0b11010, &ENTRY_PYRENEUS_9499865956932679317)],
        &[(0b00001, &ENTRY_PYRENEAN_15204083665180883806)],
        &[(0b00001, &ENTRY_PYRENEUS_9499865956932679317)],
        &[(0b10010, &ENTRY_PYRIDINIZE_12080394653590795845)],
        &[(0b10010, &ENTRY_PYRIDINIZES_17373239390566251661)],
        &[(0b01001, &ENTRY_PYRIDINIZE_12080394653590795845)],
        &[(0b01001, &ENTRY_PYRIDINIZES_17373239390566251661)],
        &[(0b10010, &ENTRY_PYRITIZATION_3981025262217302180)],
        &[(0b10010, &ENTRY_PYRITIZATIONS_15645658849345555870)],
        &[(0b10010, &ENTRY_PYRITIZE_4098278292163241581)],
        &[(0b10010, &ENTRY_PYRITIZED_2729055497658727569)],
        &[(0b10010, &ENTRY_PYRITIZES_1825397531229652480)],
        &[(0b10010, &ENTRY_PYRITIZING_9304613293971430176)],
        &[(0b01001, &ENTRY_PYRITIZATION_3981025262217302180)],
        &[(0b01001, &ENTRY_PYRITIZATIONS_15645658849345555870)],
        &[(0b01001, &ENTRY_PYRITIZE_4098278292163241581)],
        &[(0b01001, &ENTRY_PYRITIZED_2729055497658727569)],
        &[(0b01001, &ENTRY_PYRITIZES_1825397531229652480)],
        &[(0b01001, &ENTRY_PYRITIZING_9304613293971430176)],
        &[(0b11010, &ENTRY_PYROLYZABLE_11388782876912970763)],
        &[(0b11010, &ENTRY_PYROLYZATE_6347070741811549467)],
        &[(0b11010, &ENTRY_PYROLYZATES_5304514469678411687)],
        &[(0b11010, &ENTRY_PYROLYZE_1370306423959504329)],
        &[(0b11010, &ENTRY_PYROLYZED_13833971036459417043)],
        &[(0b11010, &ENTRY_PYROLYZER_14520847897378277316)],
        &[(0b11010, &ENTRY_PYROLYZES_4360458297920745869)],
        &[(0b11010, &ENTRY_PYROLYZING_3017668529784184986)],
        &[(0b00001, &ENTRY_PYROLYZABLE_11388782876912970763)],
        &[(0b00001, &ENTRY_PYROLYZATE_6347070741811549467)],
        &[(0b00001, &ENTRY_PYROLYZATES_5304514469678411687)],
        &[(0b01001, &ENTRY_PYROLYZE_1370306423959504329)],
        &[(0b01001, &ENTRY_PYROLYZED_13833971036459417043)],
        &[(0b00001, &ENTRY_PYROLYZER_14520847897378277316)],
        &[(0b01001, &ENTRY_PYROLYZES_4360458297920745869)],
        &[(0b01001, &ENTRY_PYROLYZING_3017668529784184986)],
    ],
    range: 5..=10,
};

static VARS_PYO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYO_CHILDREN),
    value: None,
};

pub static VARS_PYO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rrhea"),
        dictgen::InsensitiveStr::Ascii("rrheal"),
        dictgen::InsensitiveStr::Ascii("rrhealer"),
        dictgen::InsensitiveStr::Ascii("rrhealest"),
        dictgen::InsensitiveStr::Ascii("rrheas"),
        dictgen::InsensitiveStr::Ascii("rrheic"),
        dictgen::InsensitiveStr::Ascii("rrhoea"),
        dictgen::InsensitiveStr::Ascii("rrhoeal"),
        dictgen::InsensitiveStr::Ascii("rrhoealer"),
        dictgen::InsensitiveStr::Ascii("rrhoealest"),
        dictgen::InsensitiveStr::Ascii("rrhoeas"),
        dictgen::InsensitiveStr::Ascii("rrhoeic"),
    ],
    values: &[
        &[(0b01001, &ENTRY_PYORRHEA_3796710759481808618)],
        &[(0b00001, &ENTRY_PYORRHEAL_8724408354208820698)],
        &[(0b00001, &ENTRY_PYORRHEALER_979614094516325433)],
        &[(0b00001, &ENTRY_PYORRHEALEST_2608051559882275769)],
        &[(0b01001, &ENTRY_PYORRHEAS_10646277786557890077)],
        &[(0b00001, &ENTRY_PYORRHEIC_11175810966012719800)],
        &[(0b10010, &ENTRY_PYORRHEA_3796710759481808618)],
        &[(0b11010, &ENTRY_PYORRHEAL_8724408354208820698)],
        &[(0b11010, &ENTRY_PYORRHEALER_979614094516325433)],
        &[(0b11010, &ENTRY_PYORRHEALEST_2608051559882275769)],
        &[(0b10010, &ENTRY_PYORRHEAS_10646277786557890077)],
        &[(0b11010, &ENTRY_PYORRHEIC_11175810966012719800)],
    ],
    range: 5..=10,
};

static VARS_PYJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYJ_CHILDREN),
    value: None,
};

pub static VARS_PYJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ama"),
        dictgen::InsensitiveStr::Ascii("amas"),
        dictgen::InsensitiveStr::Ascii("amased"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PAJAMA_3939742153808099869)],
        &[(0b11010, &ENTRY_PAJAMAS_18438866384752213563)],
        &[(0b11010, &ENTRY_PAJAMAED_6840620032200463652)],
    ],
    range: 3..=6,
};

static VARS_PYG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYG_CHILDREN),
    value: None,
};

pub static VARS_PYG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("maean"),
        dictgen::InsensitiveStr::Ascii("mean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PYGMEAN_17790184024575865702)],
        &[(0b00001, &ENTRY_PYGMEAN_17790184024575865702)],
    ],
    range: 4..=5,
};

static VARS_PYE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYE_CHILDREN),
    value: None,
};

pub static VARS_PYE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mia"),
        dictgen::InsensitiveStr::Ascii("mias"),
        dictgen::InsensitiveStr::Ascii("mic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PYEMIA_6014368326116867825)],
        &[(0b00001, &ENTRY_PYEMIAS_15972708527455152251)],
        &[(0b00001, &ENTRY_PYEMIC_299205947973053064)],
    ],
    range: 3..=4,
};

static VARS_PYA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYA_CHILDREN),
    value: None,
};

pub static VARS_PYA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emias"),
        dictgen::InsensitiveStr::Ascii("emic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PYEMIA_6014368326116867825)],
        &[(0b11010, &ENTRY_PYEMIAS_15972708527455152251)],
        &[(0b11010, &ENTRY_PYEMIC_299205947973053064)],
    ],
    range: 4..=5,
};

static VARS_PU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PU_CHILDREN),
    value: None,
};

static VARS_PU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_PUB_NODE),
    None,
    None,
    Some(&VARS_PUE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PUL_NODE),
    Some(&VARS_PUM_NODE),
    None,
    None,
    Some(&VARS_PUP_NODE),
    None,
    Some(&VARS_PUR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PUR_CHILDREN),
    value: None,
};

pub static VARS_PUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("itanise"),
        dictgen::InsensitiveStr::Ascii("itanised"),
        dictgen::InsensitiveStr::Ascii("itaniser"),
        dictgen::InsensitiveStr::Ascii("itanisers"),
        dictgen::InsensitiveStr::Ascii("itanises"),
        dictgen::InsensitiveStr::Ascii("itanising"),
        dictgen::InsensitiveStr::Ascii("itanize"),
        dictgen::InsensitiveStr::Ascii("itanized"),
        dictgen::InsensitiveStr::Ascii("itanizer"),
        dictgen::InsensitiveStr::Ascii("itanizers"),
        dictgen::InsensitiveStr::Ascii("itanizes"),
        dictgen::InsensitiveStr::Ascii("itanizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PUERS_15212243335679873039)],
        &[(0b10010, &ENTRY_PURITANIZE_14818586420411105390)],
        &[(0b10010, &ENTRY_PURITANIZED_7990904455585990927)],
        &[(0b10010, &ENTRY_PURITANIZER_5248542814648310307)],
        &[(0b10010, &ENTRY_PURITANIZERS_2427860611923301122)],
        &[(0b10010, &ENTRY_PURITANIZES_412554844347730493)],
        &[(0b10010, &ENTRY_PURITANIZING_2930261870874651377)],
        &[(0b01001, &ENTRY_PURITANIZE_14818586420411105390)],
        &[(0b01001, &ENTRY_PURITANIZED_7990904455585990927)],
        &[(0b01001, &ENTRY_PURITANIZER_5248542814648310307)],
        &[(0b01001, &ENTRY_PURITANIZERS_2427860611923301122)],
        &[(0b01001, &ENTRY_PURITANIZES_412554844347730493)],
        &[(0b01001, &ENTRY_PURITANIZING_2930261870874651377)],
    ],
    range: 2..=9,
};

static VARS_PUP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PUP_CHILDREN),
    value: None,
};

pub static VARS_PUP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("petise"),
        dictgen::InsensitiveStr::Ascii("petises"),
        dictgen::InsensitiveStr::Ascii("petize"),
        dictgen::InsensitiveStr::Ascii("petizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PUPILIZE_4813815664186208258)],
        &[(0b10010, &ENTRY_PUPILIZES_3451767798624549889)],
        &[(0b01001, &ENTRY_PUPILIZE_4813815664186208258)],
        &[(0b01001, &ENTRY_PUPILIZES_3451767798624549889)],
        &[(0b10010, &ENTRY_PUPPETIZE_17610253588173061678)],
        &[(0b10010, &ENTRY_PUPPETIZES_6991413059968099138)],
        &[(0b01001, &ENTRY_PUPPETIZE_17610253588173061678)],
        &[(0b01001, &ENTRY_PUPPETIZES_6991413059968099138)],
    ],
    range: 5..=7,
};

static VARS_PUM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PUM_CHILDREN),
    value: None,
};

pub static VARS_PUM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("meled"),
        dictgen::InsensitiveStr::Ascii("meler"),
        dictgen::InsensitiveStr::Ascii("meling"),
        dictgen::InsensitiveStr::Ascii("melled"),
        dictgen::InsensitiveStr::Ascii("meller"),
        dictgen::InsensitiveStr::Ascii("melling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PUMMELED_14220543769322316417)],
        &[(0b00001, &ENTRY_PUMMELER_10140090635614975322)],
        &[(0b00001, &ENTRY_PUMMELING_86144285377904737)],
        &[(0b11010, &ENTRY_PUMMELED_14220543769322316417)],
        &[(0b11010, &ENTRY_PUMMELER_10140090635614975322)],
        &[(0b11010, &ENTRY_PUMMELING_86144285377904737)],
    ],
    range: 5..=7,
};

static VARS_PUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PUL_CHILDREN),
    value: None,
};

pub static VARS_PUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icidae"),
        dictgen::InsensitiveStr::Ascii("icide"),
        dictgen::InsensitiveStr::Ascii("lmanise"),
        dictgen::InsensitiveStr::Ascii("lmanises"),
        dictgen::InsensitiveStr::Ascii("lmanize"),
        dictgen::InsensitiveStr::Ascii("lmanizes"),
        dictgen::InsensitiveStr::Ascii("pitise"),
        dictgen::InsensitiveStr::Ascii("pitises"),
        dictgen::InsensitiveStr::Ascii("pitize"),
        dictgen::InsensitiveStr::Ascii("pitizes"),
        dictgen::InsensitiveStr::Ascii("verisable"),
        dictgen::InsensitiveStr::Ascii("verisabler"),
        dictgen::InsensitiveStr::Ascii("verisables"),
        dictgen::InsensitiveStr::Ascii("verisablest"),
        dictgen::InsensitiveStr::Ascii("verisation"),
        dictgen::InsensitiveStr::Ascii("verisations"),
        dictgen::InsensitiveStr::Ascii("verise"),
        dictgen::InsensitiveStr::Ascii("verised"),
        dictgen::InsensitiveStr::Ascii("veriser"),
        dictgen::InsensitiveStr::Ascii("verisers"),
        dictgen::InsensitiveStr::Ascii("verises"),
        dictgen::InsensitiveStr::Ascii("verising"),
        dictgen::InsensitiveStr::Ascii("verizable"),
        dictgen::InsensitiveStr::Ascii("verizabler"),
        dictgen::InsensitiveStr::Ascii("verizables"),
        dictgen::InsensitiveStr::Ascii("verizablest"),
        dictgen::InsensitiveStr::Ascii("verization"),
        dictgen::InsensitiveStr::Ascii("verizations"),
        dictgen::InsensitiveStr::Ascii("verize"),
        dictgen::InsensitiveStr::Ascii("verized"),
        dictgen::InsensitiveStr::Ascii("verizer"),
        dictgen::InsensitiveStr::Ascii("verizers"),
        dictgen::InsensitiveStr::Ascii("verizes"),
        dictgen::InsensitiveStr::Ascii("verizing"),
        dictgen::InsensitiveStr::Ascii("vilised"),
        dictgen::InsensitiveStr::Ascii("vilized"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PULICIDE_15247724617600167568)],
        &[(0b00001, &ENTRY_PULICIDE_15247724617600167568)],
        &[(0b10010, &ENTRY_PULLMANIZE_14503256122372519048)],
        &[(0b10010, &ENTRY_PULLMANIZES_17269054163787556918)],
        &[(0b01001, &ENTRY_PULLMANIZE_14503256122372519048)],
        &[(0b01001, &ENTRY_PULLMANIZES_17269054163787556918)],
        &[(0b10010, &ENTRY_PULPITIZE_10489028357901570216)],
        &[(0b10010, &ENTRY_PULPITIZES_12676842864281663017)],
        &[(0b01001, &ENTRY_PULPITIZE_10489028357901570216)],
        &[(0b01001, &ENTRY_PULPITIZES_12676842864281663017)],
        &[(0b10010, &ENTRY_PULVERIZABLE_7604627270800430124)],
        &[(0b10010, &ENTRY_PULVERIZABLER_5218535595905845450)],
        &[(0b10010, &ENTRY_PULVERIZABLES_5549786631554922273)],
        &[(0b10010, &ENTRY_PULVERIZABLEST_6079579218302677233)],
        &[(0b10010, &ENTRY_PULVERIZATION_17401567700247612056)],
        &[(0b10010, &ENTRY_PULVERIZATIONS_2088646255652876100)],
        &[(0b10010, &ENTRY_PULVERIZE_7762340513545873128)],
        &[(0b10010, &ENTRY_PULVERIZED_8994580757484344110)],
        &[(0b10010, &ENTRY_PULVERIZER_10176365177336582670)],
        &[(0b10010, &ENTRY_PULVERIZERS_9774439820094487955)],
        &[(0b10010, &ENTRY_PULVERIZES_10527798401373635350)],
        &[(0b10010, &ENTRY_PULVERIZING_2591037067348532366)],
        &[(0b01001, &ENTRY_PULVERIZABLE_7604627270800430124)],
        &[(0b01001, &ENTRY_PULVERIZABLER_5218535595905845450)],
        &[(0b01001, &ENTRY_PULVERIZABLES_5549786631554922273)],
        &[(0b01001, &ENTRY_PULVERIZABLEST_6079579218302677233)],
        &[(0b01001, &ENTRY_PULVERIZATION_17401567700247612056)],
        &[(0b01001, &ENTRY_PULVERIZATIONS_2088646255652876100)],
        &[(0b01001, &ENTRY_PULVERIZE_7762340513545873128)],
        &[(0b01001, &ENTRY_PULVERIZED_8994580757484344110)],
        &[(0b01001, &ENTRY_PULVERIZER_10176365177336582670)],
        &[(0b01001, &ENTRY_PULVERIZERS_9774439820094487955)],
        &[(0b01001, &ENTRY_PULVERIZES_10527798401373635350)],
        &[(0b01001, &ENTRY_PULVERIZING_2591037067348532366)],
        &[(0b10010, &ENTRY_PULVILIZED_8081698958947874094)],
        &[(0b01001, &ENTRY_PULVILIZED_8081698958947874094)],
    ],
    range: 5..=11,
};

static VARS_PUE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PUE_CHILDREN),
    value: None,
};

pub static VARS_PUE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bloisation"),
        dictgen::InsensitiveStr::Ascii("bloisations"),
        dictgen::InsensitiveStr::Ascii("bloise"),
        dictgen::InsensitiveStr::Ascii("bloises"),
        dictgen::InsensitiveStr::Ascii("bloization"),
        dictgen::InsensitiveStr::Ascii("bloizations"),
        dictgen::InsensitiveStr::Ascii("bloize"),
        dictgen::InsensitiveStr::Ascii("bloizes"),
        dictgen::InsensitiveStr::Ascii("rs"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PUEBLOIZATION_11619662074461690533)],
        &[(0b10010, &ENTRY_PUEBLOIZATIONS_1207431189485470945)],
        &[(0b10010, &ENTRY_PUEBLOIZE_10879706836776671039)],
        &[(0b10010, &ENTRY_PUEBLOIZES_5950295222868591250)],
        &[(0b01001, &ENTRY_PUEBLOIZATION_11619662074461690533)],
        &[(0b01001, &ENTRY_PUEBLOIZATIONS_1207431189485470945)],
        &[(0b01001, &ENTRY_PUEBLOIZE_10879706836776671039)],
        &[(0b01001, &ENTRY_PUEBLOIZES_5950295222868591250)],
        &[(0b00001, &ENTRY_PUERS_15212243335679873039)],
    ],
    range: 2..=11,
};

static VARS_PUB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PUB_CHILDREN),
    value: None,
};

pub static VARS_PUB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("licae"),
        dictgen::InsensitiveStr::Ascii("lice"),
        dictgen::InsensitiveStr::Ascii("licise"),
        dictgen::InsensitiveStr::Ascii("licised"),
        dictgen::InsensitiveStr::Ascii("licises"),
        dictgen::InsensitiveStr::Ascii("licising"),
        dictgen::InsensitiveStr::Ascii("licize"),
        dictgen::InsensitiveStr::Ascii("licized"),
        dictgen::InsensitiveStr::Ascii("licizes"),
        dictgen::InsensitiveStr::Ascii("licizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PUBLICE_3806609421992105409)],
        &[(0b00001, &ENTRY_PUBLICE_3806609421992105409)],
        &[(0b10010, &ENTRY_PUBLICIZE_5424063269919566067)],
        &[(0b10010, &ENTRY_PUBLICIZED_16571421876501016970)],
        &[(0b10010, &ENTRY_PUBLICIZES_9435453312305988637)],
        &[(0b10010, &ENTRY_PUBLICIZING_9494963417088857325)],
        &[(0b01001, &ENTRY_PUBLICIZE_5424063269919566067)],
        &[(0b01001, &ENTRY_PUBLICIZED_16571421876501016970)],
        &[(0b01001, &ENTRY_PUBLICIZES_9435453312305988637)],
        &[(0b01001, &ENTRY_PUBLICIZING_9494963417088857325)],
    ],
    range: 4..=8,
};

static VARS_PT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PT_CHILDREN),
    value: None,
};

pub static VARS_PT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olemaean"),
        dictgen::InsensitiveStr::Ascii("olemean"),
        dictgen::InsensitiveStr::Ascii("yalise"),
        dictgen::InsensitiveStr::Ascii("yalised"),
        dictgen::InsensitiveStr::Ascii("yalises"),
        dictgen::InsensitiveStr::Ascii("yalising"),
        dictgen::InsensitiveStr::Ascii("yalize"),
        dictgen::InsensitiveStr::Ascii("yalized"),
        dictgen::InsensitiveStr::Ascii("yalizes"),
        dictgen::InsensitiveStr::Ascii("yalizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PTOLEMEAN_2551741330039753225)],
        &[(0b00001, &ENTRY_PTOLEMEAN_2551741330039753225)],
        &[(0b10010, &ENTRY_PTYALIZE_10403248045054698478)],
        &[(0b10010, &ENTRY_PTYALIZED_2480073821976771187)],
        &[(0b10010, &ENTRY_PTYALIZES_66260576722278161)],
        &[(0b10010, &ENTRY_PTYALIZING_12909110709768995708)],
        &[(0b01001, &ENTRY_PTYALIZE_10403248045054698478)],
        &[(0b01001, &ENTRY_PTYALIZED_2480073821976771187)],
        &[(0b01001, &ENTRY_PTYALIZES_66260576722278161)],
        &[(0b01001, &ENTRY_PTYALIZING_12909110709768995708)],
    ],
    range: 6..=8,
};

static VARS_PS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PS_CHILDREN),
    value: None,
};

pub static VARS_PS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("almodise"),
        dictgen::InsensitiveStr::Ascii("almodised"),
        dictgen::InsensitiveStr::Ascii("almodises"),
        dictgen::InsensitiveStr::Ascii("almodising"),
        dictgen::InsensitiveStr::Ascii("almodize"),
        dictgen::InsensitiveStr::Ascii("almodized"),
        dictgen::InsensitiveStr::Ascii("almodizes"),
        dictgen::InsensitiveStr::Ascii("almodizing"),
        dictgen::InsensitiveStr::Ascii("eudaesthesia"),
        dictgen::InsensitiveStr::Ascii("eudelephant"),
        dictgen::InsensitiveStr::Ascii("eudembryo"),
        dictgen::InsensitiveStr::Ascii("eudembryonic"),
        dictgen::InsensitiveStr::Ascii("eudesthesia"),
        dictgen::InsensitiveStr::Ascii("eudhaemal"),
        dictgen::InsensitiveStr::Ascii("eudhemal"),
        dictgen::InsensitiveStr::Ascii("eudoanaemia"),
        dictgen::InsensitiveStr::Ascii("eudoanaemias"),
        dictgen::InsensitiveStr::Ascii("eudoanaemic"),
        dictgen::InsensitiveStr::Ascii("eudoanaemics"),
        dictgen::InsensitiveStr::Ascii("eudoanemia"),
        dictgen::InsensitiveStr::Ascii("eudoanemias"),
        dictgen::InsensitiveStr::Ascii("eudoanemic"),
        dictgen::InsensitiveStr::Ascii("eudoanemics"),
        dictgen::InsensitiveStr::Ascii("eudocele"),
        dictgen::InsensitiveStr::Ascii("eudocelom"),
        dictgen::InsensitiveStr::Ascii("eudocoele"),
        dictgen::InsensitiveStr::Ascii("eudocoelom"),
        dictgen::InsensitiveStr::Ascii("eudoedema"),
        dictgen::InsensitiveStr::Ascii("eudoedemas"),
        dictgen::InsensitiveStr::Ascii("eudoelephant"),
        dictgen::InsensitiveStr::Ascii("eudoembryo"),
        dictgen::InsensitiveStr::Ascii("eudoembryonic"),
        dictgen::InsensitiveStr::Ascii("eudographise"),
        dictgen::InsensitiveStr::Ascii("eudographises"),
        dictgen::InsensitiveStr::Ascii("eudographize"),
        dictgen::InsensitiveStr::Ascii("eudographizes"),
        dictgen::InsensitiveStr::Ascii("eudolunulae"),
        dictgen::InsensitiveStr::Ascii("eudolunule"),
        dictgen::InsensitiveStr::Ascii("eudooedema"),
        dictgen::InsensitiveStr::Ascii("eudooedemas"),
        dictgen::InsensitiveStr::Ascii("ychoanalyse"),
        dictgen::InsensitiveStr::Ascii("ychoanalysed"),
        dictgen::InsensitiveStr::Ascii("ychoanalyser"),
        dictgen::InsensitiveStr::Ascii("ychoanalysers"),
        dictgen::InsensitiveStr::Ascii("ychoanalysing"),
        dictgen::InsensitiveStr::Ascii("ychoanalyze"),
        dictgen::InsensitiveStr::Ascii("ychoanalyzed"),
        dictgen::InsensitiveStr::Ascii("ychoanalyzer"),
        dictgen::InsensitiveStr::Ascii("ychoanalyzers"),
        dictgen::InsensitiveStr::Ascii("ychoanalyzes"),
        dictgen::InsensitiveStr::Ascii("ychoanalyzing"),
        dictgen::InsensitiveStr::Ascii("ychologisation"),
        dictgen::InsensitiveStr::Ascii("ychologise"),
        dictgen::InsensitiveStr::Ascii("ychologised"),
        dictgen::InsensitiveStr::Ascii("ychologises"),
        dictgen::InsensitiveStr::Ascii("ychologising"),
        dictgen::InsensitiveStr::Ascii("ychologization"),
        dictgen::InsensitiveStr::Ascii("ychologize"),
        dictgen::InsensitiveStr::Ascii("ychologized"),
        dictgen::InsensitiveStr::Ascii("ychologizes"),
        dictgen::InsensitiveStr::Ascii("ychologizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PSALMODIZE_15004094711325009957)],
        &[(0b10010, &ENTRY_PSALMODIZED_7514155639553618886)],
        &[(0b10010, &ENTRY_PSALMODIZES_2076290176085375139)],
        &[(0b10010, &ENTRY_PSALMODIZING_751749509657132335)],
        &[(0b01001, &ENTRY_PSALMODIZE_15004094711325009957)],
        &[(0b01001, &ENTRY_PSALMODIZED_7514155639553618886)],
        &[(0b01001, &ENTRY_PSALMODIZES_2076290176085375139)],
        &[(0b01001, &ENTRY_PSALMODIZING_751749509657132335)],
        &[(0b11010, &ENTRY_PSEUDESTHESIA_1275162758906081869)],
        &[(0b00001, &ENTRY_PSEUDELEPHANT_2030914162737246911)],
        &[(0b00001, &ENTRY_PSEUDEMBRYO_14203020715857032391)],
        &[(0b00001, &ENTRY_PSEUDEMBRYONIC_11216696215007963967)],
        &[(0b00001, &ENTRY_PSEUDESTHESIA_1275162758906081869)],
        &[(0b11010, &ENTRY_PSEUDHEMAL_15598474376323098687)],
        &[(0b00001, &ENTRY_PSEUDHEMAL_15598474376323098687)],
        &[(0b11010, &ENTRY_PSEUDOANEMIA_13668020166240077472)],
        &[(0b11010, &ENTRY_PSEUDOANEMIAS_12376590166743463304)],
        &[(0b11010, &ENTRY_PSEUDOANEMIC_12741381100990975341)],
        &[(0b11010, &ENTRY_PSEUDOANEMICS_11106944421043495730)],
        &[(0b00001, &ENTRY_PSEUDOANEMIA_13668020166240077472)],
        &[(0b00001, &ENTRY_PSEUDOANEMIAS_12376590166743463304)],
        &[(0b00001, &ENTRY_PSEUDOANEMIC_12741381100990975341)],
        &[(0b00001, &ENTRY_PSEUDOANEMICS_11106944421043495730)],
        &[(0b00001, &ENTRY_PSEUDOCELE_8053951785853751294)],
        &[(0b00001, &ENTRY_PSEUDOCELOM_13969014156705538002)],
        &[(0b11010, &ENTRY_PSEUDOCELE_8053951785853751294)],
        &[(0b11010, &ENTRY_PSEUDOCELOM_13969014156705538002)],
        &[(0b00001, &ENTRY_PSEUDOEDEMA_15365216887149708823)],
        &[(0b00001, &ENTRY_PSEUDOEDEMAS_12395792322606353606)],
        &[(0b11010, &ENTRY_PSEUDELEPHANT_2030914162737246911)],
        &[(0b11010, &ENTRY_PSEUDEMBRYO_14203020715857032391)],
        &[(0b11010, &ENTRY_PSEUDEMBRYONIC_11216696215007963967)],
        &[(0b10010, &ENTRY_PSEUDOGRAPHIZE_885997092067089742)],
        &[(0b10010, &ENTRY_PSEUDOGRAPHIZES_9996987914403453497)],
        &[(0b01001, &ENTRY_PSEUDOGRAPHIZE_885997092067089742)],
        &[(0b01001, &ENTRY_PSEUDOGRAPHIZES_9996987914403453497)],
        &[(0b11010, &ENTRY_PSEUDOLUNULE_14036316726076847351)],
        &[(0b00001, &ENTRY_PSEUDOLUNULE_14036316726076847351)],
        &[(0b11010, &ENTRY_PSEUDOEDEMA_15365216887149708823)],
        &[(0b11010, &ENTRY_PSEUDOEDEMAS_12395792322606353606)],
        &[(0b10010, &ENTRY_PSYCHOANALYZE_13352325501420392703)],
        &[(0b10010, &ENTRY_PSYCHOANALYZED_2361240273552649217)],
        &[(0b10010, &ENTRY_PSYCHOANALYZER_1467300969528733943)],
        &[(0b10010, &ENTRY_PSYCHOANALYZERS_6122603980161912665)],
        &[(0b10010, &ENTRY_PSYCHOANALYZING_17396903265279304718)],
        &[(0b01001, &ENTRY_PSYCHOANALYZE_13352325501420392703)],
        &[(0b01001, &ENTRY_PSYCHOANALYZED_2361240273552649217)],
        &[(0b01001, &ENTRY_PSYCHOANALYZER_1467300969528733943)],
        &[(0b01001, &ENTRY_PSYCHOANALYZERS_6122603980161912665)],
        &[(0b01001, &ENTRY_PSYCHOANALYZES_17393570726957476631)],
        &[(0b01001, &ENTRY_PSYCHOANALYZING_17396903265279304718)],
        &[(0b10010, &ENTRY_PSYCHOLOGIZATION_6576901085662588432)],
        &[(0b10010, &ENTRY_PSYCHOLOGIZE_5793948135745501907)],
        &[(0b10010, &ENTRY_PSYCHOLOGIZED_6245845065865139826)],
        &[(0b10010, &ENTRY_PSYCHOLOGIZES_5058513302027995583)],
        &[(0b10010, &ENTRY_PSYCHOLOGIZING_3642591565222639415)],
        &[(0b01001, &ENTRY_PSYCHOLOGIZATION_6576901085662588432)],
        &[(0b01001, &ENTRY_PSYCHOLOGIZE_5793948135745501907)],
        &[(0b01001, &ENTRY_PSYCHOLOGIZED_6245845065865139826)],
        &[(0b01001, &ENTRY_PSYCHOLOGIZES_5058513302027995583)],
        &[(0b01001, &ENTRY_PSYCHOLOGIZING_3642591565222639415)],
    ],
    range: 8..=14,
};

static VARS_PR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PR_CHILDREN),
    value: None,
};

static VARS_PR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PRA_NODE),
    None,
    None,
    None,
    Some(&VARS_PRE_NODE),
    None,
    None,
    None,
    Some(&VARS_PRI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PRO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PRU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_PRU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRU_CHILDREN),
    value: None,
};

pub static VARS_PRU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ssianisation"),
        dictgen::InsensitiveStr::Ascii("ssianisations"),
        dictgen::InsensitiveStr::Ascii("ssianise"),
        dictgen::InsensitiveStr::Ascii("ssianised"),
        dictgen::InsensitiveStr::Ascii("ssianiser"),
        dictgen::InsensitiveStr::Ascii("ssianisers"),
        dictgen::InsensitiveStr::Ascii("ssianises"),
        dictgen::InsensitiveStr::Ascii("ssianising"),
        dictgen::InsensitiveStr::Ascii("ssianization"),
        dictgen::InsensitiveStr::Ascii("ssianizations"),
        dictgen::InsensitiveStr::Ascii("ssianize"),
        dictgen::InsensitiveStr::Ascii("ssianized"),
        dictgen::InsensitiveStr::Ascii("ssianizer"),
        dictgen::InsensitiveStr::Ascii("ssianizers"),
        dictgen::InsensitiveStr::Ascii("ssianizes"),
        dictgen::InsensitiveStr::Ascii("ssianizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PRUSSIANIZATION_4426098874560395046)],
        &[(0b10010, &ENTRY_PRUSSIANIZATIONS_3200828078370769033)],
        &[(0b10010, &ENTRY_PRUSSIANIZE_12459016936159488594)],
        &[(0b10010, &ENTRY_PRUSSIANIZED_10124812572238942023)],
        &[(0b10010, &ENTRY_PRUSSIANIZER_18286762685167593766)],
        &[(0b10010, &ENTRY_PRUSSIANIZERS_14800421025773551283)],
        &[(0b10010, &ENTRY_PRUSSIANIZES_13923514287346300166)],
        &[(0b10010, &ENTRY_PRUSSIANIZING_12424701237527019665)],
        &[(0b01001, &ENTRY_PRUSSIANIZATION_4426098874560395046)],
        &[(0b01001, &ENTRY_PRUSSIANIZATIONS_3200828078370769033)],
        &[(0b01001, &ENTRY_PRUSSIANIZE_12459016936159488594)],
        &[(0b01001, &ENTRY_PRUSSIANIZED_10124812572238942023)],
        &[(0b01001, &ENTRY_PRUSSIANIZER_18286762685167593766)],
        &[(0b01001, &ENTRY_PRUSSIANIZERS_14800421025773551283)],
        &[(0b01001, &ENTRY_PRUSSIANIZES_13923514287346300166)],
        &[(0b01001, &ENTRY_PRUSSIANIZING_12424701237527019665)],
    ],
    range: 8..=13,
};

static VARS_PRO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PRO_CHILDREN),
    value: None,
};

static VARS_PRO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PROA_NODE),
    Some(&VARS_PROB_NODE),
    Some(&VARS_PROC_NODE),
    Some(&VARS_PROD_NODE),
    Some(&VARS_PROE_NODE),
    Some(&VARS_PROF_NODE),
    Some(&VARS_PROG_NODE),
    None,
    Some(&VARS_PROI_NODE),
    Some(&VARS_PROJ_NODE),
    None,
    Some(&VARS_PROL_NODE),
    None,
    Some(&VARS_PRON_NODE),
    Some(&VARS_PROO_NODE),
    Some(&VARS_PROP_NODE),
    None,
    None,
    Some(&VARS_PROS_NODE),
    Some(&VARS_PROT_NODE),
    None,
    Some(&VARS_PROV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_PROV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROV_CHILDREN),
    value: None,
};

pub static VARS_PROV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erbialise"),
        dictgen::InsensitiveStr::Ascii("erbialised"),
        dictgen::InsensitiveStr::Ascii("erbialises"),
        dictgen::InsensitiveStr::Ascii("erbialising"),
        dictgen::InsensitiveStr::Ascii("erbialize"),
        dictgen::InsensitiveStr::Ascii("erbialized"),
        dictgen::InsensitiveStr::Ascii("erbializes"),
        dictgen::InsensitiveStr::Ascii("erbializing"),
        dictgen::InsensitiveStr::Ascii("erbise"),
        dictgen::InsensitiveStr::Ascii("erbises"),
        dictgen::InsensitiveStr::Ascii("erbize"),
        dictgen::InsensitiveStr::Ascii("erbizes"),
        dictgen::InsensitiveStr::Ascii("incialisation"),
        dictgen::InsensitiveStr::Ascii("incialisations"),
        dictgen::InsensitiveStr::Ascii("incialise"),
        dictgen::InsensitiveStr::Ascii("incialised"),
        dictgen::InsensitiveStr::Ascii("incialises"),
        dictgen::InsensitiveStr::Ascii("incialising"),
        dictgen::InsensitiveStr::Ascii("incialization"),
        dictgen::InsensitiveStr::Ascii("incializations"),
        dictgen::InsensitiveStr::Ascii("incialize"),
        dictgen::InsensitiveStr::Ascii("incialized"),
        dictgen::InsensitiveStr::Ascii("incializes"),
        dictgen::InsensitiveStr::Ascii("incializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROVERBIALIZE_13334383391371333892)],
        &[(0b10010, &ENTRY_PROVERBIALIZED_8987504788438996422)],
        &[(0b10010, &ENTRY_PROVERBIALIZES_8317029653044381349)],
        &[(0b10010, &ENTRY_PROVERBIALIZING_18074267399445313428)],
        &[(0b01001, &ENTRY_PROVERBIALIZE_13334383391371333892)],
        &[(0b01001, &ENTRY_PROVERBIALIZED_8987504788438996422)],
        &[(0b01001, &ENTRY_PROVERBIALIZES_8317029653044381349)],
        &[(0b01001, &ENTRY_PROVERBIALIZING_18074267399445313428)],
        &[(0b10010, &ENTRY_PROVERBIZE_10993755369638498420)],
        &[(0b10010, &ENTRY_PROVERBIZES_18160973412105788998)],
        &[(0b01001, &ENTRY_PROVERBIZE_10993755369638498420)],
        &[(0b01001, &ENTRY_PROVERBIZES_18160973412105788998)],
        &[(0b10010, &ENTRY_PROVINCIALIZATION_11197353514593321649)],
        &[(0b10010, &ENTRY_PROVINCIALIZATIONS_1272068076611645435)],
        &[(0b10010, &ENTRY_PROVINCIALIZE_9892471258204714701)],
        &[(0b10010, &ENTRY_PROVINCIALIZED_14091881793591709636)],
        &[(0b10010, &ENTRY_PROVINCIALIZES_7740199822590027111)],
        &[(0b10010, &ENTRY_PROVINCIALIZING_12497264018634460310)],
        &[(0b01001, &ENTRY_PROVINCIALIZATION_11197353514593321649)],
        &[(0b01001, &ENTRY_PROVINCIALIZATIONS_1272068076611645435)],
        &[(0b01001, &ENTRY_PROVINCIALIZE_9892471258204714701)],
        &[(0b01001, &ENTRY_PROVINCIALIZED_14091881793591709636)],
        &[(0b01001, &ENTRY_PROVINCIALIZES_7740199822590027111)],
        &[(0b01001, &ENTRY_PROVINCIALIZING_12497264018634460310)],
    ],
    range: 6..=14,
};

static VARS_PROT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROT_CHILDREN),
    value: None,
};

pub static VARS_PROT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectionise"),
        dictgen::InsensitiveStr::Ascii("ectionises"),
        dictgen::InsensitiveStr::Ascii("ectionize"),
        dictgen::InsensitiveStr::Ascii("ectionizes"),
        dictgen::InsensitiveStr::Ascii("eidae"),
        dictgen::InsensitiveStr::Ascii("eide"),
        dictgen::InsensitiveStr::Ascii("estantise"),
        dictgen::InsensitiveStr::Ascii("estantised"),
        dictgen::InsensitiveStr::Ascii("estantises"),
        dictgen::InsensitiveStr::Ascii("estantising"),
        dictgen::InsensitiveStr::Ascii("estantize"),
        dictgen::InsensitiveStr::Ascii("estantized"),
        dictgen::InsensitiveStr::Ascii("estantizes"),
        dictgen::InsensitiveStr::Ascii("estantizing"),
        dictgen::InsensitiveStr::Ascii("hoaenor"),
        dictgen::InsensitiveStr::Ascii("hoenor"),
        dictgen::InsensitiveStr::Ascii("oarchaeology"),
        dictgen::InsensitiveStr::Ascii("oarcheology"),
        dictgen::InsensitiveStr::Ascii("ocoled"),
        dictgen::InsensitiveStr::Ascii("ocoling"),
        dictgen::InsensitiveStr::Ascii("ocolisation"),
        dictgen::InsensitiveStr::Ascii("ocolisations"),
        dictgen::InsensitiveStr::Ascii("ocolise"),
        dictgen::InsensitiveStr::Ascii("ocolised"),
        dictgen::InsensitiveStr::Ascii("ocolises"),
        dictgen::InsensitiveStr::Ascii("ocolising"),
        dictgen::InsensitiveStr::Ascii("ocolization"),
        dictgen::InsensitiveStr::Ascii("ocolizations"),
        dictgen::InsensitiveStr::Ascii("ocolize"),
        dictgen::InsensitiveStr::Ascii("ocolized"),
        dictgen::InsensitiveStr::Ascii("ocolizes"),
        dictgen::InsensitiveStr::Ascii("ocolizing"),
        dictgen::InsensitiveStr::Ascii("ocolled"),
        dictgen::InsensitiveStr::Ascii("ocolling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROTECTIONIZE_5626694334800959888)],
        &[(0b10010, &ENTRY_PROTECTIONIZES_185151310463565901)],
        &[(0b01001, &ENTRY_PROTECTIONIZE_5626694334800959888)],
        &[(0b01001, &ENTRY_PROTECTIONIZES_185151310463565901)],
        &[(0b11010, &ENTRY_PROTEIDE_8541786308809678707)],
        &[(0b00001, &ENTRY_PROTEIDE_8541786308809678707)],
        &[(0b10010, &ENTRY_PROTESTANTIZE_930408179750739241)],
        &[(0b10010, &ENTRY_PROTESTANTIZED_9706500663127294434)],
        &[(0b10010, &ENTRY_PROTESTANTIZES_14980175348825437179)],
        &[(0b10010, &ENTRY_PROTESTANTIZING_17553830627472979038)],
        &[(0b01001, &ENTRY_PROTESTANTIZE_930408179750739241)],
        &[(0b01001, &ENTRY_PROTESTANTIZED_9706500663127294434)],
        &[(0b01001, &ENTRY_PROTESTANTIZES_14980175348825437179)],
        &[(0b01001, &ENTRY_PROTESTANTIZING_17553830627472979038)],
        &[(0b11010, &ENTRY_PROTHOENOR_12241019511979868123)],
        &[(0b00001, &ENTRY_PROTHOENOR_12241019511979868123)],
        &[(0b11010, &ENTRY_PROTOARCHEOLOGY_12948760782790762751)],
        &[(0b00001, &ENTRY_PROTOARCHEOLOGY_12948760782790762751)],
        &[(0b00001, &ENTRY_PROTOCOLED_9512660668033614324)],
        &[(0b00001, &ENTRY_PROTOCOLING_4325129038987463009)],
        &[(0b10010, &ENTRY_PROTOCOLIZATION_7253399674306380843)],
        &[(0b10010, &ENTRY_PROTOCOLIZATIONS_1652690302390074801)],
        &[(0b10010, &ENTRY_PROTOCOLIZE_14027135970880253930)],
        &[(0b10010, &ENTRY_PROTOCOLIZED_8014687509536437744)],
        &[(0b10010, &ENTRY_PROTOCOLIZES_12890931742186597048)],
        &[(0b10010, &ENTRY_PROTOCOLIZING_3470922517137243613)],
        &[(0b01001, &ENTRY_PROTOCOLIZATION_7253399674306380843)],
        &[(0b01001, &ENTRY_PROTOCOLIZATIONS_1652690302390074801)],
        &[(0b01001, &ENTRY_PROTOCOLIZE_14027135970880253930)],
        &[(0b01001, &ENTRY_PROTOCOLIZED_8014687509536437744)],
        &[(0b01001, &ENTRY_PROTOCOLIZES_12890931742186597048)],
        &[(0b01001, &ENTRY_PROTOCOLIZING_3470922517137243613)],
        &[(0b11010, &ENTRY_PROTOCOLED_9512660668033614324)],
        &[(0b11010, &ENTRY_PROTOCOLING_4325129038987463009)],
    ],
    range: 4..=12,
};

static VARS_PROS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROS_CHILDREN),
    value: None,
};

pub static VARS_PROS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elytisation"),
        dictgen::InsensitiveStr::Ascii("elytisations"),
        dictgen::InsensitiveStr::Ascii("elytise"),
        dictgen::InsensitiveStr::Ascii("elytised"),
        dictgen::InsensitiveStr::Ascii("elytiser"),
        dictgen::InsensitiveStr::Ascii("elytisers"),
        dictgen::InsensitiveStr::Ascii("elytises"),
        dictgen::InsensitiveStr::Ascii("elytising"),
        dictgen::InsensitiveStr::Ascii("elytization"),
        dictgen::InsensitiveStr::Ascii("elytizations"),
        dictgen::InsensitiveStr::Ascii("elytize"),
        dictgen::InsensitiveStr::Ascii("elytized"),
        dictgen::InsensitiveStr::Ascii("elytizer"),
        dictgen::InsensitiveStr::Ascii("elytizers"),
        dictgen::InsensitiveStr::Ascii("elytizes"),
        dictgen::InsensitiveStr::Ascii("elytizing"),
        dictgen::InsensitiveStr::Ascii("euchae"),
        dictgen::InsensitiveStr::Ascii("euche"),
        dictgen::InsensitiveStr::Ascii("ocele"),
        dictgen::InsensitiveStr::Ascii("ocoele"),
        dictgen::InsensitiveStr::Ascii("opopeia"),
        dictgen::InsensitiveStr::Ascii("opopeial"),
        dictgen::InsensitiveStr::Ascii("opopeias"),
        dictgen::InsensitiveStr::Ascii("opopoeial"),
        dictgen::InsensitiveStr::Ascii("tatorrhea"),
        dictgen::InsensitiveStr::Ascii("tatorrhoea"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROSELYTIZATION_17135856883988053610)],
        &[(0b10010, &ENTRY_PROSELYTIZATIONS_15779681958788343945)],
        &[(0b10010, &ENTRY_PROSELYTIZE_14508434076807964437)],
        &[(0b10010, &ENTRY_PROSELYTIZED_13393641785992171327)],
        &[(0b10010, &ENTRY_PROSELYTIZER_10730288809990334441)],
        &[(0b10010, &ENTRY_PROSELYTIZERS_7582504000576690857)],
        &[(0b10010, &ENTRY_PROSELYTIZES_6759164791000097610)],
        &[(0b10010, &ENTRY_PROSELYTIZING_3222893683296080940)],
        &[(0b01001, &ENTRY_PROSELYTIZATION_17135856883988053610)],
        &[(0b01001, &ENTRY_PROSELYTIZATIONS_15779681958788343945)],
        &[(0b01001, &ENTRY_PROSELYTIZE_14508434076807964437)],
        &[(0b01001, &ENTRY_PROSELYTIZED_13393641785992171327)],
        &[(0b01001, &ENTRY_PROSELYTIZER_10730288809990334441)],
        &[(0b01001, &ENTRY_PROSELYTIZERS_7582504000576690857)],
        &[(0b01001, &ENTRY_PROSELYTIZES_6759164791000097610)],
        &[(0b01001, &ENTRY_PROSELYTIZING_3222893683296080940)],
        &[(0b11010, &ENTRY_PROSEUCHE_10388889221593101497)],
        &[(0b00001, &ENTRY_PROSEUCHE_10388889221593101497)],
        &[(0b00001, &ENTRY_PROSOCELE_8387894783348711239)],
        &[(0b11010, &ENTRY_PROSOCELE_8387894783348711239)],
        &[(0b01001, &ENTRY_PROSOPOPOEIA_3116153132173899307)],
        &[(0b00001, &ENTRY_PROSOPOPEIAL_12885233098577128627)],
        &[(0b01001, &ENTRY_PROSOPOPOEIAS_10634619028210897533)],
        &[(0b11010, &ENTRY_PROSOPOPEIAL_12885233098577128627)],
        &[(0b00001, &ENTRY_PROSTATORRHEA_17007958745656658064)],
        &[(0b11010, &ENTRY_PROSTATORRHEA_17007958745656658064)],
    ],
    range: 5..=12,
};

static VARS_PROP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROP_CHILDREN),
    value: None,
};

pub static VARS_PROP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agandise"),
        dictgen::InsensitiveStr::Ascii("agandised"),
        dictgen::InsensitiveStr::Ascii("agandises"),
        dictgen::InsensitiveStr::Ascii("agandising"),
        dictgen::InsensitiveStr::Ascii("agandize"),
        dictgen::InsensitiveStr::Ascii("agandized"),
        dictgen::InsensitiveStr::Ascii("agandizes"),
        dictgen::InsensitiveStr::Ascii("agandizing"),
        dictgen::InsensitiveStr::Ascii("hetise"),
        dictgen::InsensitiveStr::Ascii("hetises"),
        dictgen::InsensitiveStr::Ascii("hetize"),
        dictgen::InsensitiveStr::Ascii("hetizes"),
        dictgen::InsensitiveStr::Ascii("ositionise"),
        dictgen::InsensitiveStr::Ascii("ositionises"),
        dictgen::InsensitiveStr::Ascii("ositionize"),
        dictgen::InsensitiveStr::Ascii("ositionizes"),
        dictgen::InsensitiveStr::Ascii("raetor"),
        dictgen::InsensitiveStr::Ascii("raetorial"),
        dictgen::InsensitiveStr::Ascii("raetorian"),
        dictgen::InsensitiveStr::Ascii("raetors"),
        dictgen::InsensitiveStr::Ascii("retor"),
        dictgen::InsensitiveStr::Ascii("retorial"),
        dictgen::InsensitiveStr::Ascii("retorian"),
        dictgen::InsensitiveStr::Ascii("retors"),
        dictgen::InsensitiveStr::Ascii("ylitisation"),
        dictgen::InsensitiveStr::Ascii("ylitisations"),
        dictgen::InsensitiveStr::Ascii("ylitise"),
        dictgen::InsensitiveStr::Ascii("ylitised"),
        dictgen::InsensitiveStr::Ascii("ylitises"),
        dictgen::InsensitiveStr::Ascii("ylitising"),
        dictgen::InsensitiveStr::Ascii("ylitization"),
        dictgen::InsensitiveStr::Ascii("ylitizations"),
        dictgen::InsensitiveStr::Ascii("ylitize"),
        dictgen::InsensitiveStr::Ascii("ylitized"),
        dictgen::InsensitiveStr::Ascii("ylitizes"),
        dictgen::InsensitiveStr::Ascii("ylitizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROPAGANDIZE_8177553084887485510)],
        &[(0b10010, &ENTRY_PROPAGANDIZED_16934930634247263476)],
        &[(0b10010, &ENTRY_PROPAGANDIZES_9571312284054421445)],
        &[(0b10010, &ENTRY_PROPAGANDIZING_8734852002578869522)],
        &[(0b01001, &ENTRY_PROPAGANDIZE_8177553084887485510)],
        &[(0b01001, &ENTRY_PROPAGANDIZED_16934930634247263476)],
        &[(0b01001, &ENTRY_PROPAGANDIZES_9571312284054421445)],
        &[(0b01001, &ENTRY_PROPAGANDIZING_8734852002578869522)],
        &[(0b10010, &ENTRY_PROPHETIZE_452344212153495963)],
        &[(0b10010, &ENTRY_PROPHETIZES_4261334625906585144)],
        &[(0b01001, &ENTRY_PROPHETIZE_452344212153495963)],
        &[(0b01001, &ENTRY_PROPHETIZES_4261334625906585144)],
        &[(0b10010, &ENTRY_PROPOSITIONIZE_15255429142774392236)],
        &[(0b10010, &ENTRY_PROPOSITIONIZES_998017883950780980)],
        &[(0b01001, &ENTRY_PROPOSITIONIZE_15255429142774392236)],
        &[(0b01001, &ENTRY_PROPOSITIONIZES_998017883950780980)],
        &[(0b11010, &ENTRY_PROPRETOR_17239413312041471631)],
        &[(0b11010, &ENTRY_PROPRETORIAL_2347772660746698838)],
        &[(0b11010, &ENTRY_PROPRETORIAN_758510350938796380)],
        &[(0b11010, &ENTRY_PROPRETORS_3015280642699082218)],
        &[(0b00001, &ENTRY_PROPRETOR_17239413312041471631)],
        &[(0b00001, &ENTRY_PROPRETORIAL_2347772660746698838)],
        &[(0b00001, &ENTRY_PROPRETORIAN_758510350938796380)],
        &[(0b00001, &ENTRY_PROPRETORS_3015280642699082218)],
        &[(0b10010, &ENTRY_PROPYLITIZATION_16422443521775391870)],
        &[(0b10010, &ENTRY_PROPYLITIZATIONS_6860959394412061312)],
        &[(0b10010, &ENTRY_PROPYLITIZE_221263951211359073)],
        &[(0b10010, &ENTRY_PROPYLITIZED_4181293442870295139)],
        &[(0b10010, &ENTRY_PROPYLITIZES_1024314893105495596)],
        &[(0b10010, &ENTRY_PROPYLITIZING_8928406423210230276)],
        &[(0b01001, &ENTRY_PROPYLITIZATION_16422443521775391870)],
        &[(0b01001, &ENTRY_PROPYLITIZATIONS_6860959394412061312)],
        &[(0b01001, &ENTRY_PROPYLITIZE_221263951211359073)],
        &[(0b01001, &ENTRY_PROPYLITIZED_4181293442870295139)],
        &[(0b01001, &ENTRY_PROPYLITIZES_1024314893105495596)],
        &[(0b01001, &ENTRY_PROPYLITIZING_8928406423210230276)],
    ],
    range: 5..=12,
};

static VARS_PROO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROO_CHILDREN),
    value: None,
};

pub static VARS_PROO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("emium")],
    values: &[&[(0b11010, &ENTRY_PROEMIUM_14234532915733161254)]],
    range: 5..=5,
};

static VARS_PRON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRON_CHILDREN),
    value: None,
};

pub static VARS_PRON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ominalisation"),
        dictgen::InsensitiveStr::Ascii("ominalise"),
        dictgen::InsensitiveStr::Ascii("ominalization"),
        dictgen::InsensitiveStr::Ascii("ominalize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PRONOMINALIZATION_2160092279956307185)],
        &[(0b10010, &ENTRY_PRONOMINALIZE_16300143735228333916)],
        &[(0b01001, &ENTRY_PRONOMINALIZATION_2160092279956307185)],
        &[(0b01001, &ENTRY_PRONOMINALIZE_16300143735228333916)],
    ],
    range: 9..=13,
};

static VARS_PROL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROL_CHILDREN),
    value: None,
};

pub static VARS_PROL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etarianisation"),
        dictgen::InsensitiveStr::Ascii("etarianisations"),
        dictgen::InsensitiveStr::Ascii("etarianise"),
        dictgen::InsensitiveStr::Ascii("etarianised"),
        dictgen::InsensitiveStr::Ascii("etarianises"),
        dictgen::InsensitiveStr::Ascii("etarianising"),
        dictgen::InsensitiveStr::Ascii("etarianization"),
        dictgen::InsensitiveStr::Ascii("etarianizations"),
        dictgen::InsensitiveStr::Ascii("etarianize"),
        dictgen::InsensitiveStr::Ascii("etarianized"),
        dictgen::InsensitiveStr::Ascii("etarianizes"),
        dictgen::InsensitiveStr::Ascii("etarianizing"),
        dictgen::InsensitiveStr::Ascii("etarise"),
        dictgen::InsensitiveStr::Ascii("etarised"),
        dictgen::InsensitiveStr::Ascii("etarising"),
        dictgen::InsensitiveStr::Ascii("etarize"),
        dictgen::InsensitiveStr::Ascii("etarized"),
        dictgen::InsensitiveStr::Ascii("etarizing"),
        dictgen::InsensitiveStr::Ascii("og"),
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
        dictgen::InsensitiveStr::Ascii("ogs"),
        dictgen::InsensitiveStr::Ascii("oguise"),
        dictgen::InsensitiveStr::Ascii("oguised"),
        dictgen::InsensitiveStr::Ascii("oguiser"),
        dictgen::InsensitiveStr::Ascii("oguisers"),
        dictgen::InsensitiveStr::Ascii("oguises"),
        dictgen::InsensitiveStr::Ascii("oguising"),
        dictgen::InsensitiveStr::Ascii("oguize"),
        dictgen::InsensitiveStr::Ascii("oguized"),
        dictgen::InsensitiveStr::Ascii("oguizer"),
        dictgen::InsensitiveStr::Ascii("oguizers"),
        dictgen::InsensitiveStr::Ascii("oguizes"),
        dictgen::InsensitiveStr::Ascii("oguizing"),
        dictgen::InsensitiveStr::Ascii("usionise"),
        dictgen::InsensitiveStr::Ascii("usionises"),
        dictgen::InsensitiveStr::Ascii("usionize"),
        dictgen::InsensitiveStr::Ascii("usionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROLETARIANIZATION_15790660889449578730)],
        &[(0b10010, &ENTRY_PROLETARIANIZATIONS_1328735160914809433)],
        &[(0b10010, &ENTRY_PROLETARIANIZE_12339926232015096187)],
        &[(0b10010, &ENTRY_PROLETARIANIZED_2183449213380270293)],
        &[(0b10010, &ENTRY_PROLETARIANIZES_6188493854575184994)],
        &[(0b10010, &ENTRY_PROLETARIANIZING_15272438542602632385)],
        &[(0b01001, &ENTRY_PROLETARIANIZATION_15790660889449578730)],
        &[(0b01001, &ENTRY_PROLETARIANIZATIONS_1328735160914809433)],
        &[(0b01001, &ENTRY_PROLETARIANIZE_12339926232015096187)],
        &[(0b01001, &ENTRY_PROLETARIANIZED_2183449213380270293)],
        &[(0b01001, &ENTRY_PROLETARIANIZES_6188493854575184994)],
        &[(0b01001, &ENTRY_PROLETARIANIZING_15272438542602632385)],
        &[(0b10010, &ENTRY_PROLETARIZE_9501153541273515734)],
        &[(0b10010, &ENTRY_PROLETARIZED_14247407550828649128)],
        &[(0b10010, &ENTRY_PROLETARIZING_16999278085483859607)],
        &[(0b01001, &ENTRY_PROLETARIZE_9501153541273515734)],
        &[(0b01001, &ENTRY_PROLETARIZED_14247407550828649128)],
        &[(0b01001, &ENTRY_PROLETARIZING_16999278085483859607)],
        &[(0b00001, &ENTRY_PROLOGUE_11728138965466131419)],
        &[(0b10010, &ENTRY_PROLOGIZE_16244188212641112947)],
        &[(0b10010, &ENTRY_PROLOGIZED_6273077668308831309)],
        &[(0b10010, &ENTRY_PROLOGIZES_13741317884710515836)],
        &[(0b10010, &ENTRY_PROLOGIZING_16747002832029621473)],
        &[(0b01001, &ENTRY_PROLOGIZE_16244188212641112947)],
        &[(0b01001, &ENTRY_PROLOGIZED_6273077668308831309)],
        &[(0b01001, &ENTRY_PROLOGIZES_13741317884710515836)],
        &[(0b01001, &ENTRY_PROLOGIZING_16747002832029621473)],
        &[(0b00001, &ENTRY_PROLOGUES_2022541342111438442)],
        &[(0b10010, &ENTRY_PROLOGUIZE_13986490182533024537)],
        &[(0b10010, &ENTRY_PROLOGUIZED_1059404595951898705)],
        &[(0b10010, &ENTRY_PROLOGUIZER_12529304749250729020)],
        &[(0b10010, &ENTRY_PROLOGUIZERS_4337951202538976392)],
        &[(0b10010, &ENTRY_PROLOGUIZES_9492816923512770566)],
        &[(0b10010, &ENTRY_PROLOGUIZING_8390679435340498064)],
        &[(0b01001, &ENTRY_PROLOGUIZE_13986490182533024537)],
        &[(0b01001, &ENTRY_PROLOGUIZED_1059404595951898705)],
        &[(0b01001, &ENTRY_PROLOGUIZER_12529304749250729020)],
        &[(0b01001, &ENTRY_PROLOGUIZERS_4337951202538976392)],
        &[(0b01001, &ENTRY_PROLOGUIZES_9492816923512770566)],
        &[(0b01001, &ENTRY_PROLOGUIZING_8390679435340498064)],
        &[(0b10010, &ENTRY_PROLUSIONIZE_14743949812729365990)],
        &[(0b10010, &ENTRY_PROLUSIONIZES_9375527204411045313)],
        &[(0b01001, &ENTRY_PROLUSIONIZE_14743949812729365990)],
        &[(0b01001, &ENTRY_PROLUSIONIZES_9375527204411045313)],
    ],
    range: 2..=15,
};

static VARS_PROJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROJ_CHILDREN),
    value: None,
};

pub static VARS_PROJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectisation"),
        dictgen::InsensitiveStr::Ascii("ectisations"),
        dictgen::InsensitiveStr::Ascii("ectization"),
        dictgen::InsensitiveStr::Ascii("ectizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROJECTIZATION_1538272338112971382)],
        &[(0b10010, &ENTRY_PROJECTIZATIONS_17947038612206928913)],
        &[(0b01001, &ENTRY_PROJECTIZATION_1538272338112971382)],
        &[(0b01001, &ENTRY_PROJECTIZATIONS_17947038612206928913)],
    ],
    range: 10..=11,
};

static VARS_PROI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROI_CHILDREN),
    value: None,
};

pub static VARS_PROI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ndustrialisation"),
        dictgen::InsensitiveStr::Ascii("ndustrialization"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROINDUSTRIALIZATION_7705497117665030256)],
        &[(0b01001, &ENTRY_PROINDUSTRIALIZATION_7705497117665030256)],
    ],
    range: 16..=16,
};

static VARS_PROG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROG_CHILDREN),
    value: None,
};

pub static VARS_PROG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ramed"),
        dictgen::InsensitiveStr::Ascii("ramer"),
        dictgen::InsensitiveStr::Ascii("ramers"),
        dictgen::InsensitiveStr::Ascii("raming"),
    ],
    values: &[
        &[
            (0b00001, &ENTRY_PROGRAMMED_11095179087329270774),
            (0b00001, &ENTRY_PROGRAMMED_14686782791235843952),
        ],
        &[(0b00001, &ENTRY_PROGRAMMER_14647609425245098552)],
        &[(0b00001, &ENTRY_PROGRAMMERS_7198725162117062597)],
        &[
            (0b00001, &ENTRY_PROGRAMMING_3117523448840634735),
            (0b00001, &ENTRY_PROGRAMMING_9189526122229014819),
        ],
    ],
    range: 5..=6,
};

static VARS_PROF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROF_CHILDREN),
    value: None,
};

pub static VARS_PROF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("essionalisation"),
        dictgen::InsensitiveStr::Ascii("essionalisations"),
        dictgen::InsensitiveStr::Ascii("essionalise"),
        dictgen::InsensitiveStr::Ascii("essionalised"),
        dictgen::InsensitiveStr::Ascii("essionalises"),
        dictgen::InsensitiveStr::Ascii("essionalising"),
        dictgen::InsensitiveStr::Ascii("essionalization"),
        dictgen::InsensitiveStr::Ascii("essionalizations"),
        dictgen::InsensitiveStr::Ascii("essionalize"),
        dictgen::InsensitiveStr::Ascii("essionalized"),
        dictgen::InsensitiveStr::Ascii("essionalizes"),
        dictgen::InsensitiveStr::Ascii("essionalizing"),
        dictgen::InsensitiveStr::Ascii("essionise"),
        dictgen::InsensitiveStr::Ascii("essionises"),
        dictgen::InsensitiveStr::Ascii("essionize"),
        dictgen::InsensitiveStr::Ascii("essionizes"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROFANIZE_16692055975755795401)],
        &[(0b10010, &ENTRY_PROFANIZES_15009721751572169566)],
        &[(0b01001, &ENTRY_PROFANIZE_16692055975755795401)],
        &[(0b01001, &ENTRY_PROFANIZES_15009721751572169566)],
        &[(0b00001, &ENTRY_PROFER_15410953148965704808)],
        &[(0b10010, &ENTRY_PROFESSIONALIZATION_18024061751549463881)],
        &[(0b10010, &ENTRY_PROFESSIONALIZATIONS_15242793239637656612)],
        &[(0b10010, &ENTRY_PROFESSIONALIZE_8390330200790326962)],
        &[(0b10010, &ENTRY_PROFESSIONALIZED_2063985099756041218)],
        &[(0b10010, &ENTRY_PROFESSIONALIZES_13162965236440047136)],
        &[(0b10010, &ENTRY_PROFESSIONALIZING_11815435443308938942)],
        &[(0b01001, &ENTRY_PROFESSIONALIZATION_18024061751549463881)],
        &[(0b01001, &ENTRY_PROFESSIONALIZATIONS_15242793239637656612)],
        &[(0b01001, &ENTRY_PROFESSIONALIZE_8390330200790326962)],
        &[(0b01001, &ENTRY_PROFESSIONALIZED_2063985099756041218)],
        &[(0b01001, &ENTRY_PROFESSIONALIZES_13162965236440047136)],
        &[(0b01001, &ENTRY_PROFESSIONALIZING_11815435443308938942)],
        &[(0b10010, &ENTRY_PROFESSIONIZE_14437669104523413326)],
        &[(0b10010, &ENTRY_PROFESSIONIZES_14576667596106193495)],
        &[(0b01001, &ENTRY_PROFESSIONIZE_14437669104523413326)],
        &[(0b01001, &ENTRY_PROFESSIONIZES_14576667596106193495)],
        &[(0b11010, &ENTRY_PROFER_15410953148965704808)],
    ],
    range: 2..=16,
};

static VARS_PROE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROE_CHILDREN),
    value: None,
};

pub static VARS_PROE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mial"),
        dictgen::InsensitiveStr::Ascii("mium"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PREMIAL_7239338890868461187)],
        &[(0b00001, &ENTRY_PROEMIUM_14234532915733161254)],
    ],
    range: 4..=4,
};

static VARS_PROD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROD_CHILDREN),
    value: None,
};

pub static VARS_PROD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("igalise"),
        dictgen::InsensitiveStr::Ascii("igalised"),
        dictgen::InsensitiveStr::Ascii("igalises"),
        dictgen::InsensitiveStr::Ascii("igalising"),
        dictgen::InsensitiveStr::Ascii("igalize"),
        dictgen::InsensitiveStr::Ascii("igalized"),
        dictgen::InsensitiveStr::Ascii("igalizes"),
        dictgen::InsensitiveStr::Ascii("igalizing"),
        dictgen::InsensitiveStr::Ascii("uctise"),
        dictgen::InsensitiveStr::Ascii("uctised"),
        dictgen::InsensitiveStr::Ascii("uctiser"),
        dictgen::InsensitiveStr::Ascii("uctisers"),
        dictgen::InsensitiveStr::Ascii("uctises"),
        dictgen::InsensitiveStr::Ascii("uctising"),
        dictgen::InsensitiveStr::Ascii("uctize"),
        dictgen::InsensitiveStr::Ascii("uctized"),
        dictgen::InsensitiveStr::Ascii("uctizer"),
        dictgen::InsensitiveStr::Ascii("uctizers"),
        dictgen::InsensitiveStr::Ascii("uctizes"),
        dictgen::InsensitiveStr::Ascii("uctizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PRODIGALIZE_6556148767910967929)],
        &[(0b10010, &ENTRY_PRODIGALIZED_5183373559053607699)],
        &[(0b10010, &ENTRY_PRODIGALIZES_13614987973661874173)],
        &[(0b10010, &ENTRY_PRODIGALIZING_17327500545166930662)],
        &[(0b01001, &ENTRY_PRODIGALIZE_6556148767910967929)],
        &[(0b01001, &ENTRY_PRODIGALIZED_5183373559053607699)],
        &[(0b01001, &ENTRY_PRODIGALIZES_13614987973661874173)],
        &[(0b01001, &ENTRY_PRODIGALIZING_17327500545166930662)],
        &[(0b10010, &ENTRY_PRODUCTIZE_5881144802979662642)],
        &[(0b10010, &ENTRY_PRODUCTIZED_10875872271101596314)],
        &[(0b10010, &ENTRY_PRODUCTIZER_15368907505651290238)],
        &[(0b10010, &ENTRY_PRODUCTIZERS_3610620963148254180)],
        &[(0b10010, &ENTRY_PRODUCTIZES_2489445768881598197)],
        &[(0b10010, &ENTRY_PRODUCTIZING_913073828657978689)],
        &[(0b01001, &ENTRY_PRODUCTIZE_5881144802979662642)],
        &[(0b01001, &ENTRY_PRODUCTIZED_10875872271101596314)],
        &[(0b01001, &ENTRY_PRODUCTIZER_15368907505651290238)],
        &[(0b01001, &ENTRY_PRODUCTIZERS_3610620963148254180)],
        &[(0b01001, &ENTRY_PRODUCTIZES_2489445768881598197)],
        &[(0b01001, &ENTRY_PRODUCTIZING_913073828657978689)],
    ],
    range: 6..=9,
};

static VARS_PROC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROC_CHILDREN),
    value: None,
};

pub static VARS_PROC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("essionise"),
        dictgen::InsensitiveStr::Ascii("essionises"),
        dictgen::InsensitiveStr::Ascii("essionize"),
        dictgen::InsensitiveStr::Ascii("essionizes"),
        dictgen::InsensitiveStr::Ascii("rusteanise"),
        dictgen::InsensitiveStr::Ascii("rusteanises"),
        dictgen::InsensitiveStr::Ascii("rusteanize"),
        dictgen::InsensitiveStr::Ascii("rusteanizes"),
        dictgen::InsensitiveStr::Ascii("todaea"),
        dictgen::InsensitiveStr::Ascii("todaeal"),
        dictgen::InsensitiveStr::Ascii("todaeum"),
        dictgen::InsensitiveStr::Ascii("todaeums"),
        dictgen::InsensitiveStr::Ascii("todea"),
        dictgen::InsensitiveStr::Ascii("todeal"),
        dictgen::InsensitiveStr::Ascii("todeum"),
        dictgen::InsensitiveStr::Ascii("todeums"),
        dictgen::InsensitiveStr::Ascii("torisation"),
        dictgen::InsensitiveStr::Ascii("torisations"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torised"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torising"),
        dictgen::InsensitiveStr::Ascii("torization"),
        dictgen::InsensitiveStr::Ascii("torizations"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torized"),
        dictgen::InsensitiveStr::Ascii("torizes"),
        dictgen::InsensitiveStr::Ascii("torizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROCESSIONIZE_363359302673816281)],
        &[(0b10010, &ENTRY_PROCESSIONIZES_3404719682305726652)],
        &[(0b01001, &ENTRY_PROCESSIONIZE_363359302673816281)],
        &[(0b01001, &ENTRY_PROCESSIONIZES_3404719682305726652)],
        &[(0b10010, &ENTRY_PROCRUSTEANIZE_17397014473088592045)],
        &[(0b10010, &ENTRY_PROCRUSTEANIZES_10425675503914668807)],
        &[(0b01001, &ENTRY_PROCRUSTEANIZE_17397014473088592045)],
        &[(0b01001, &ENTRY_PROCRUSTEANIZES_10425675503914668807)],
        &[(0b11010, &ENTRY_PROCTODEA_9264272751486692747)],
        &[(0b11010, &ENTRY_PROCTODEAL_5673226521410272400)],
        &[(0b11010, &ENTRY_PROCTODEUM_4237934730961962313)],
        &[(0b11010, &ENTRY_PROCTODEUMS_2978610134813867751)],
        &[(0b00001, &ENTRY_PROCTODEA_9264272751486692747)],
        &[(0b00001, &ENTRY_PROCTODEAL_5673226521410272400)],
        &[(0b00001, &ENTRY_PROCTODEUM_4237934730961962313)],
        &[(0b00001, &ENTRY_PROCTODEUMS_2978610134813867751)],
        &[(0b10010, &ENTRY_PROCTORIZATION_9417674116945748895)],
        &[(0b10010, &ENTRY_PROCTORIZATIONS_12249312162294372727)],
        &[(0b10010, &ENTRY_PROCTORIZE_3777189878290336613)],
        &[(0b10010, &ENTRY_PROCTORIZED_6091712676193842819)],
        &[(0b10010, &ENTRY_PROCTORIZES_221418959204501654)],
        &[(0b10010, &ENTRY_PROCTORIZING_6126835312244696695)],
        &[(0b01001, &ENTRY_PROCTORIZATION_9417674116945748895)],
        &[(0b01001, &ENTRY_PROCTORIZATIONS_12249312162294372727)],
        &[(0b01001, &ENTRY_PROCTORIZE_3777189878290336613)],
        &[(0b01001, &ENTRY_PROCTORIZED_6091712676193842819)],
        &[(0b01001, &ENTRY_PROCTORIZES_221418959204501654)],
        &[(0b01001, &ENTRY_PROCTORIZING_6126835312244696695)],
    ],
    range: 5..=11,
};

static VARS_PROB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROB_CHILDREN),
    value: None,
};

pub static VARS_PROB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lemise"),
        dictgen::InsensitiveStr::Ascii("lemises"),
        dictgen::InsensitiveStr::Ascii("lemize"),
        dictgen::InsensitiveStr::Ascii("lemizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROBLEMIZE_11504359583073410309)],
        &[(0b10010, &ENTRY_PROBLEMIZES_10106644264183859282)],
        &[(0b01001, &ENTRY_PROBLEMIZE_11504359583073410309)],
        &[(0b01001, &ENTRY_PROBLEMIZES_10106644264183859282)],
    ],
    range: 6..=7,
};

static VARS_PROA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROA_CHILDREN),
    value: None,
};

pub static VARS_PROA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dvertising"),
        dictgen::InsensitiveStr::Ascii("dvertizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROADVERTIZING_10146408801765586763)],
        &[(0b01001, &ENTRY_PROADVERTIZING_10146408801765586763)],
    ],
    range: 10..=10,
};

static VARS_PRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRI_CHILDREN),
    value: None,
};

pub static VARS_PRI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("maeval"),
        dictgen::InsensitiveStr::Ascii("maevally"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("oritisation"),
        dictgen::InsensitiveStr::Ascii("oritisations"),
        dictgen::InsensitiveStr::Ascii("oritise"),
        dictgen::InsensitiveStr::Ascii("oritised"),
        dictgen::InsensitiveStr::Ascii("oritiser"),
        dictgen::InsensitiveStr::Ascii("oritisers"),
        dictgen::InsensitiveStr::Ascii("oritises"),
        dictgen::InsensitiveStr::Ascii("oritising"),
        dictgen::InsensitiveStr::Ascii("oritisings"),
        dictgen::InsensitiveStr::Ascii("oritization"),
        dictgen::InsensitiveStr::Ascii("oritizations"),
        dictgen::InsensitiveStr::Ascii("oritize"),
        dictgen::InsensitiveStr::Ascii("oritized"),
        dictgen::InsensitiveStr::Ascii("oritizer"),
        dictgen::InsensitiveStr::Ascii("oritizers"),
        dictgen::InsensitiveStr::Ascii("oritizes"),
        dictgen::InsensitiveStr::Ascii("oritizing"),
        dictgen::InsensitiveStr::Ascii("oritizings"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
        dictgen::InsensitiveStr::Ascii("sable"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("sed"),
        dictgen::InsensitiveStr::Ascii("ser"),
        dictgen::InsensitiveStr::Ascii("sers"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("sing"),
        dictgen::InsensitiveStr::Ascii("vatisation"),
        dictgen::InsensitiveStr::Ascii("vatisations"),
        dictgen::InsensitiveStr::Ascii("vatise"),
        dictgen::InsensitiveStr::Ascii("vatised"),
        dictgen::InsensitiveStr::Ascii("vatiser"),
        dictgen::InsensitiveStr::Ascii("vatisers"),
        dictgen::InsensitiveStr::Ascii("vatises"),
        dictgen::InsensitiveStr::Ascii("vatising"),
        dictgen::InsensitiveStr::Ascii("vatization"),
        dictgen::InsensitiveStr::Ascii("vatizations"),
        dictgen::InsensitiveStr::Ascii("vatize"),
        dictgen::InsensitiveStr::Ascii("vatized"),
        dictgen::InsensitiveStr::Ascii("vatizer"),
        dictgen::InsensitiveStr::Ascii("vatizers"),
        dictgen::InsensitiveStr::Ascii("vatizes"),
        dictgen::InsensitiveStr::Ascii("vatizing"),
        dictgen::InsensitiveStr::Ascii("zable"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PRIMEVAL_1417379882500902562)],
        &[(0b11010, &ENTRY_PRIMEVALLY_5695214551446778886)],
        &[(0b10010, &ENTRY_PRIORIZATION_6881117100427905620)],
        &[(0b10010, &ENTRY_PRIORIZATIONS_8298289640162436181)],
        &[(0b10010, &ENTRY_PRIORIZE_144293817568297285)],
        &[(0b10010, &ENTRY_PRIORIZED_7964231373333312688)],
        &[(0b10010, &ENTRY_PRIORIZES_9720813797683913872)],
        &[(0b10010, &ENTRY_PRIORIZING_11437754851911989314)],
        &[(0b10010, &ENTRY_PRIORITIZATION_17373812427352173208)],
        &[(0b10010, &ENTRY_PRIORITIZATIONS_4547440538414190662)],
        &[(0b10010, &ENTRY_PRIORITIZE_7432754868592786562)],
        &[(0b10010, &ENTRY_PRIORITIZED_4527962682420219040)],
        &[(0b10010, &ENTRY_PRIORITIZER_13382006918758416159)],
        &[(0b10010, &ENTRY_PRIORITIZERS_6825770252020420898)],
        &[(0b10010, &ENTRY_PRIORITIZES_9554518663110998287)],
        &[(0b10010, &ENTRY_PRIORITIZING_10063035288697055724)],
        &[(0b10010, &ENTRY_PRIORITIZINGS_16876590680015495867)],
        &[(0b01001, &ENTRY_PRIORITIZATION_17373812427352173208)],
        &[(0b01001, &ENTRY_PRIORITIZATIONS_4547440538414190662)],
        &[(0b01001, &ENTRY_PRIORITIZE_7432754868592786562)],
        &[(0b01001, &ENTRY_PRIORITIZED_4527962682420219040)],
        &[(0b01001, &ENTRY_PRIORITIZER_13382006918758416159)],
        &[(0b01001, &ENTRY_PRIORITIZERS_6825770252020420898)],
        &[(0b01001, &ENTRY_PRIORITIZES_9554518663110998287)],
        &[(0b01001, &ENTRY_PRIORITIZING_10063035288697055724)],
        &[(0b01001, &ENTRY_PRIORITIZINGS_16876590680015495867)],
        &[(0b01001, &ENTRY_PRIORIZATION_6881117100427905620)],
        &[(0b01001, &ENTRY_PRIORIZATIONS_8298289640162436181)],
        &[(0b01001, &ENTRY_PRIORIZE_144293817568297285)],
        &[(0b01001, &ENTRY_PRIORIZED_7964231373333312688)],
        &[(0b01001, &ENTRY_PRIORIZES_9720813797683913872)],
        &[(0b01001, &ENTRY_PRIORIZING_11437754851911989314)],
        &[(0b10010, &ENTRY_PRIZABLE_3624070517581805612)],
        &[(0b10010, &ENTRY_PRIZE_1961043608814215148)],
        &[(0b10010, &ENTRY_PRIZED_13278503117736836068)],
        &[(0b10010, &ENTRY_PRIZER_3172722922601400896)],
        &[(0b10010, &ENTRY_PRIZERS_15789594842148438822)],
        &[(0b10010, &ENTRY_PRIZES_7638257834418170687)],
        &[(0b10010, &ENTRY_PRIZING_5311484152980850571)],
        &[(0b10010, &ENTRY_PRIVATIZATION_3684133102365221258)],
        &[(0b10010, &ENTRY_PRIVATIZATIONS_17033667469063461810)],
        &[(0b10010, &ENTRY_PRIVATIZE_9023800133991613189)],
        &[(0b10010, &ENTRY_PRIVATIZED_17871845478636985919)],
        &[(0b10010, &ENTRY_PRIVATIZER_3347166286516553417)],
        &[(0b10010, &ENTRY_PRIVATIZERS_4157500876246357166)],
        &[(0b10010, &ENTRY_PRIVATIZES_15354432852660291680)],
        &[(0b10010, &ENTRY_PRIVATIZING_15665137231742087652)],
        &[(0b01001, &ENTRY_PRIVATIZATION_3684133102365221258)],
        &[(0b01001, &ENTRY_PRIVATIZATIONS_17033667469063461810)],
        &[(0b01001, &ENTRY_PRIVATIZE_9023800133991613189)],
        &[(0b01001, &ENTRY_PRIVATIZED_17871845478636985919)],
        &[(0b01001, &ENTRY_PRIVATIZER_3347166286516553417)],
        &[(0b01001, &ENTRY_PRIVATIZERS_4157500876246357166)],
        &[(0b01001, &ENTRY_PRIVATIZES_15354432852660291680)],
        &[(0b01001, &ENTRY_PRIVATIZING_15665137231742087652)],
        &[(0b01001, &ENTRY_PRIZABLE_3624070517581805612)],
    ],
    range: 2..=12,
};

static VARS_PRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PRE_CHILDREN),
    value: None,
};

static VARS_PRE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PREA_NODE),
    Some(&VARS_PREB_NODE),
    Some(&VARS_PREC_NODE),
    Some(&VARS_PRED_NODE),
    Some(&VARS_PREE_NODE),
    Some(&VARS_PREF_NODE),
    Some(&VARS_PREG_NODE),
    Some(&VARS_PREH_NODE),
    Some(&VARS_PREI_NODE),
    Some(&VARS_PREJ_NODE),
    None,
    Some(&VARS_PREL_NODE),
    Some(&VARS_PREM_NODE),
    Some(&VARS_PREN_NODE),
    Some(&VARS_PREO_NODE),
    Some(&VARS_PREP_NODE),
    None,
    Some(&VARS_PRER_NODE),
    Some(&VARS_PRES_NODE),
    Some(&VARS_PRET_NODE),
    Some(&VARS_PREU_NODE),
    Some(&VARS_PREV_NODE),
    None,
    None,
    None,
    Some(&VARS_PREZ_NODE),
];

static VARS_PREZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREZ_CHILDREN),
    value: None,
};

pub static VARS_PREZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ygapophysis")],
    values: &[&[(0b00001, &ENTRY_PREZYGAPOPHYSIS_12276661304999283736)]],
    range: 11..=11,
};

static VARS_PREV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREV_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_PERV_12538763894300491770)]),
};

pub static VARS_PREV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("iable"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("iousness"),
        dictgen::InsensitiveStr::Ascii("iousnesses"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ue"),
        dictgen::InsensitiveStr::Ascii("ues"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PERVE_15605705734121788203)],
        &[(0b11010, &ENTRY_PERVED_5641773030984045701)],
        &[(0b11010, &ENTRY_PERVES_15457354577274877085)],
        &[(0b11010, &ENTRY_PERVIABLE_7017934559789149180)],
        &[(0b11010, &ENTRY_PERVING_861961187036741303)],
        &[(0b11010, &ENTRY_PERVIOUSNESS_12070729285035585339)],
        &[(0b11010, &ENTRY_PERVIOUSNESSES_16881754789905331743)],
        &[(0b10010, &ENTRY_PREVIZE_11758683809300984520)],
        &[(0b01001, &ENTRY_PREVIZE_11758683809300984520)],
        &[(0b00001, &ENTRY_PREVIEW_17480641034975402216)],
        &[(0b00001, &ENTRY_PREVIEWS_15754902130358490470)],
    ],
    range: 1..=10,
};

static VARS_PREU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREU_CHILDREN),
    value: None,
};

pub static VARS_PREU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tilisable"),
        dictgen::InsensitiveStr::Ascii("tilisables"),
        dictgen::InsensitiveStr::Ascii("tilisation"),
        dictgen::InsensitiveStr::Ascii("tilisations"),
        dictgen::InsensitiveStr::Ascii("tilise"),
        dictgen::InsensitiveStr::Ascii("tilises"),
        dictgen::InsensitiveStr::Ascii("tilizable"),
        dictgen::InsensitiveStr::Ascii("tilizables"),
        dictgen::InsensitiveStr::Ascii("tilization"),
        dictgen::InsensitiveStr::Ascii("tilizations"),
        dictgen::InsensitiveStr::Ascii("tilize"),
        dictgen::InsensitiveStr::Ascii("tilizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PREUTILIZABLE_10502977666588008006)],
        &[(0b10010, &ENTRY_PREUTILIZABLES_12568308354937276763)],
        &[(0b10010, &ENTRY_PREUTILIZATION_5168298681347218530)],
        &[(0b10010, &ENTRY_PREUTILIZATIONS_13261898768735461584)],
        &[(0b10010, &ENTRY_PREUTILIZE_13437269687735714618)],
        &[(0b10010, &ENTRY_PREUTILIZES_11485486872811225597)],
        &[(0b01001, &ENTRY_PREUTILIZABLE_10502977666588008006)],
        &[(0b01001, &ENTRY_PREUTILIZABLES_12568308354937276763)],
        &[(0b01001, &ENTRY_PREUTILIZATION_5168298681347218530)],
        &[(0b01001, &ENTRY_PREUTILIZATIONS_13261898768735461584)],
        &[(0b01001, &ENTRY_PREUTILIZE_13437269687735714618)],
        &[(0b01001, &ENTRY_PREUTILIZES_11485486872811225597)],
    ],
    range: 6..=11,
};

static VARS_PRET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRET_CHILDREN),
    value: None,
};

pub static VARS_PRET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("axation"),
        dictgen::InsensitiveStr::Ascii("ence"),
        dictgen::InsensitiveStr::Ascii("ences"),
        dictgen::InsensitiveStr::Ascii("encive"),
        dictgen::InsensitiveStr::Ascii("ense"),
        dictgen::InsensitiveStr::Ascii("enses"),
        dictgen::InsensitiveStr::Ascii("ensive"),
        dictgen::InsensitiveStr::Ascii("erit"),
        dictgen::InsensitiveStr::Ascii("erits"),
        dictgen::InsensitiveStr::Ascii("exta"),
        dictgen::InsensitiveStr::Ascii("extae"),
        dictgen::InsensitiveStr::Ascii("orial"),
        dictgen::InsensitiveStr::Ascii("orians"),
        dictgen::InsensitiveStr::Ascii("orium"),
        dictgen::InsensitiveStr::Ascii("orius"),
        dictgen::InsensitiveStr::Ascii("orship"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRETAXATION_8079989165281713211)],
        &[(0b11010, &ENTRY_PRETENSE_11134246296321318334)],
        &[(0b11010, &ENTRY_PRETENSES_7458659267060171206)],
        &[(0b11010, &ENTRY_PRETENSIVE_9146039768574026128)],
        &[(0b01001, &ENTRY_PRETENSE_11134246296321318334)],
        &[(0b01001, &ENTRY_PRETENSES_7458659267060171206)],
        &[(0b00001, &ENTRY_PRETENSIVE_9146039768574026128)],
        &[(0b01001, &ENTRY_PRETERIT_7498968913037091407)],
        &[(0b01001, &ENTRY_PRETERITS_12755061437397802511)],
        &[(0b00001, &ENTRY_PRETEXTA_13846622072471023683)],
        &[(0b00001, &ENTRY_PRETEXTAE_10204336454667170862)],
        &[(0b00001, &ENTRY_PRETORIAL_15378699772955129270)],
        &[(0b00001, &ENTRY_PRETORIANS_6215048104690331583)],
        &[(0b00001, &ENTRY_PRETORIUM_14398242596704932612)],
        &[(0b00001, &ENTRY_PRETORIUS_5267977306289147499)],
        &[(0b00001, &ENTRY_PRETORSHIP_6874769297580857439)],
    ],
    range: 4..=7,
};

static VARS_PRES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRES_CHILDREN),
    value: None,
};

pub static VARS_PRES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("byterianise"),
        dictgen::InsensitiveStr::Ascii("byterianised"),
        dictgen::InsensitiveStr::Ascii("byterianises"),
        dictgen::InsensitiveStr::Ascii("byterianising"),
        dictgen::InsensitiveStr::Ascii("byterianize"),
        dictgen::InsensitiveStr::Ascii("byterianized"),
        dictgen::InsensitiveStr::Ascii("byterianizes"),
        dictgen::InsensitiveStr::Ascii("byterianizing"),
        dictgen::InsensitiveStr::Ascii("cutum"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("idia"),
        dictgen::InsensitiveStr::Ascii("olve"),
        dictgen::InsensitiveStr::Ascii("pecialise"),
        dictgen::InsensitiveStr::Ascii("pecialises"),
        dictgen::InsensitiveStr::Ascii("pecialize"),
        dictgen::InsensitiveStr::Ascii("pecializes"),
        dictgen::InsensitiveStr::Ascii("phenoid"),
        dictgen::InsensitiveStr::Ascii("plendor"),
        dictgen::InsensitiveStr::Ascii("plendors"),
        dictgen::InsensitiveStr::Ascii("plendour"),
        dictgen::InsensitiveStr::Ascii("plendours"),
        dictgen::InsensitiveStr::Ascii("surisation"),
        dictgen::InsensitiveStr::Ascii("surisations"),
        dictgen::InsensitiveStr::Ascii("surise"),
        dictgen::InsensitiveStr::Ascii("surised"),
        dictgen::InsensitiveStr::Ascii("suriser"),
        dictgen::InsensitiveStr::Ascii("surisers"),
        dictgen::InsensitiveStr::Ascii("surises"),
        dictgen::InsensitiveStr::Ascii("surising"),
        dictgen::InsensitiveStr::Ascii("surization"),
        dictgen::InsensitiveStr::Ascii("surizations"),
        dictgen::InsensitiveStr::Ascii("surize"),
        dictgen::InsensitiveStr::Ascii("surized"),
        dictgen::InsensitiveStr::Ascii("surizer"),
        dictgen::InsensitiveStr::Ascii("surizers"),
        dictgen::InsensitiveStr::Ascii("surizes"),
        dictgen::InsensitiveStr::Ascii("surizing"),
        dictgen::InsensitiveStr::Ascii("t"),
        dictgen::InsensitiveStr::Ascii("tandardisation"),
        dictgen::InsensitiveStr::Ascii("tandardisations"),
        dictgen::InsensitiveStr::Ascii("tandardise"),
        dictgen::InsensitiveStr::Ascii("tandardises"),
        dictgen::InsensitiveStr::Ascii("tandardization"),
        dictgen::InsensitiveStr::Ascii("tandardizations"),
        dictgen::InsensitiveStr::Ascii("tandardize"),
        dictgen::InsensitiveStr::Ascii("tandardizes"),
        dictgen::InsensitiveStr::Ascii("ternal"),
        dictgen::InsensitiveStr::Ascii("ternum"),
        dictgen::InsensitiveStr::Ascii("tomium"),
        dictgen::InsensitiveStr::Ascii("ympathise"),
        dictgen::InsensitiveStr::Ascii("ympathises"),
        dictgen::InsensitiveStr::Ascii("ympathize"),
        dictgen::InsensitiveStr::Ascii("ympathizes"),
        dictgen::InsensitiveStr::Ascii("ystolic"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PRESBYTERIANIZE_4999287070580173639)],
        &[(0b10010, &ENTRY_PRESBYTERIANIZED_17583472478168085387)],
        &[(0b10010, &ENTRY_PRESBYTERIANIZES_4964908232020982000)],
        &[(0b10010, &ENTRY_PRESBYTERIANIZING_14044541616214486352)],
        &[(0b01001, &ENTRY_PRESBYTERIANIZE_4999287070580173639)],
        &[(0b01001, &ENTRY_PRESBYTERIANIZED_17583472478168085387)],
        &[(0b01001, &ENTRY_PRESBYTERIANIZES_4964908232020982000)],
        &[(0b01001, &ENTRY_PRESBYTERIANIZING_14044541616214486352)],
        &[(0b00001, &ENTRY_PRESCUTUM_4847968595911667425)],
        &[(0b11010, &ENTRY_PERSE_11387837727041811534)],
        &[(0b00001, &ENTRY_PRESIDIUMS_1425790211349943895)],
        &[(0b11010, &ENTRY_PERSOLVE_6208805617619929798)],
        &[(0b10010, &ENTRY_PRESPECIALIZE_967052105156335842)],
        &[(0b10010, &ENTRY_PRESPECIALIZES_11006115119286112345)],
        &[(0b01001, &ENTRY_PRESPECIALIZE_967052105156335842)],
        &[(0b01001, &ENTRY_PRESPECIALIZES_11006115119286112345)],
        &[(0b00001, &ENTRY_PRESPHENOID_4021931112345182287)],
        &[(0b00001, &ENTRY_PRESPLENDOR_12905475499591730121)],
        &[(0b00001, &ENTRY_PRESPLENDORS_5824632808972650605)],
        &[(0b11010, &ENTRY_PRESPLENDOR_12905475499591730121)],
        &[(0b11010, &ENTRY_PRESPLENDORS_5824632808972650605)],
        &[(0b10010, &ENTRY_PRESSURIZATION_13356670902399248842)],
        &[(0b10010, &ENTRY_PRESSURIZATIONS_118195243034235909)],
        &[(0b10010, &ENTRY_PRESSURIZE_2472285357926099657)],
        &[(0b10010, &ENTRY_PRESSURIZED_13396852261615154911)],
        &[(0b10010, &ENTRY_PRESSURIZER_4292185580180276393)],
        &[(0b10010, &ENTRY_PRESSURIZERS_3559116169299219184)],
        &[(0b10010, &ENTRY_PRESSURIZES_12650153372563760390)],
        &[(0b10010, &ENTRY_PRESSURIZING_5224479349902662356)],
        &[(0b01001, &ENTRY_PRESSURIZATION_13356670902399248842)],
        &[(0b01001, &ENTRY_PRESSURIZATIONS_118195243034235909)],
        &[(0b01001, &ENTRY_PRESSURIZE_2472285357926099657)],
        &[(0b01001, &ENTRY_PRESSURIZED_13396852261615154911)],
        &[(0b01001, &ENTRY_PRESSURIZER_4292185580180276393)],
        &[(0b01001, &ENTRY_PRESSURIZERS_3559116169299219184)],
        &[(0b01001, &ENTRY_PRESSURIZES_12650153372563760390)],
        &[(0b01001, &ENTRY_PRESSURIZING_5224479349902662356)],
        &[(0b11010, &ENTRY_PERST_13560994870115707725)],
        &[(0b10010, &ENTRY_PRESTANDARDIZATION_2363065887839704808)],
        &[(0b10010, &ENTRY_PRESTANDARDIZATIONS_18319526321595787840)],
        &[(0b10010, &ENTRY_PRESTANDARDIZE_15894564553262715859)],
        &[(0b10010, &ENTRY_PRESTANDARDIZES_937266387346880025)],
        &[(0b01001, &ENTRY_PRESTANDARDIZATION_2363065887839704808)],
        &[(0b01001, &ENTRY_PRESTANDARDIZATIONS_18319526321595787840)],
        &[(0b01001, &ENTRY_PRESTANDARDIZE_15894564553262715859)],
        &[(0b01001, &ENTRY_PRESTANDARDIZES_937266387346880025)],
        &[(0b00001, &ENTRY_PRESTERNAL_15812473893616823077)],
        &[(0b00001, &ENTRY_PRESTERNUM_1763363816928245465)],
        &[(0b00001, &ENTRY_PRESTOMIUM_16214618765076520281)],
        &[(0b10010, &ENTRY_PRESYMPATHIZE_8629925375514514985)],
        &[(0b10010, &ENTRY_PRESYMPATHIZES_14009852068318536738)],
        &[(0b01001, &ENTRY_PRESYMPATHIZE_8629925375514514985)],
        &[(0b01001, &ENTRY_PRESYMPATHIZES_14009852068318536738)],
        &[(0b00001, &ENTRY_PRESYSTOLIC_9748851267145215677)],
    ],
    range: 1..=15,
};

static VARS_PRER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRER_CHILDREN),
    value: None,
};

pub static VARS_PRER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ealisation"),
        dictgen::InsensitiveStr::Ascii("ealisations"),
        dictgen::InsensitiveStr::Ascii("ealise"),
        dictgen::InsensitiveStr::Ascii("ealises"),
        dictgen::InsensitiveStr::Ascii("ealization"),
        dictgen::InsensitiveStr::Ascii("ealizations"),
        dictgen::InsensitiveStr::Ascii("ealize"),
        dictgen::InsensitiveStr::Ascii("ealizes"),
        dictgen::InsensitiveStr::Ascii("ecognise"),
        dictgen::InsensitiveStr::Ascii("ecognises"),
        dictgen::InsensitiveStr::Ascii("ecognize"),
        dictgen::InsensitiveStr::Ascii("ecognizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PREREALIZATION_16751668738223798926)],
        &[(0b10010, &ENTRY_PREREALIZATIONS_2143545589004280472)],
        &[(0b10010, &ENTRY_PREREALIZE_11988199343123512512)],
        &[(0b10010, &ENTRY_PREREALIZES_2916100817699778962)],
        &[(0b01001, &ENTRY_PREREALIZATION_16751668738223798926)],
        &[(0b01001, &ENTRY_PREREALIZATIONS_2143545589004280472)],
        &[(0b01001, &ENTRY_PREREALIZE_11988199343123512512)],
        &[(0b01001, &ENTRY_PREREALIZES_2916100817699778962)],
        &[(0b10010, &ENTRY_PRERECOGNIZE_12618463696266445555)],
        &[(0b10010, &ENTRY_PRERECOGNIZES_5929115671355232434)],
        &[(0b01001, &ENTRY_PRERECOGNIZE_12618463696266445555)],
        &[(0b01001, &ENTRY_PRERECOGNIZES_5929115671355232434)],
    ],
    range: 6..=11,
};

static VARS_PREP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREP_CHILDREN),
    value: None,
};

pub static VARS_PREP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alaeolithic"),
        dictgen::InsensitiveStr::Ascii("aleolithic"),
        dictgen::InsensitiveStr::Ascii("erfect"),
        dictgen::InsensitiveStr::Ascii("ositor"),
        dictgen::InsensitiveStr::Ascii("ositure"),
        dictgen::InsensitiveStr::Ascii("oster"),
        dictgen::InsensitiveStr::Ascii("ostor"),
        dictgen::InsensitiveStr::Ascii("ostors"),
        dictgen::InsensitiveStr::Ascii("rogram"),
        dictgen::InsensitiveStr::Ascii("rogramme"),
        dictgen::InsensitiveStr::Ascii("ubis"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PREPALEOLITHIC_183867950926594500)],
        &[(0b00001, &ENTRY_PREPALEOLITHIC_183867950926594500)],
        &[(0b11010, &ENTRY_PERPERFECT_18179313282884798168)],
        &[(0b00001, &ENTRY_PREPOSITOR_10063403644988472815)],
        &[(0b00001, &ENTRY_PREPOSITURE_4560239659829395865)],
        &[(0b00001, &ENTRY_PREPOSTER_5492394426366092278)],
        &[(0b00001, &ENTRY_PREPOSTOR_11151951142384506524)],
        &[(0b00001, &ENTRY_PREPOSTORS_7492263855684321754)],
        &[(0b01001, &ENTRY_PREPROGRAM_748095052838191885)],
        &[(0b10010, &ENTRY_PREPROGRAM_748095052838191885)],
        &[(0b00001, &ENTRY_PREPUBIS_1427267276575788983)],
    ],
    range: 4..=11,
};

static VARS_PREO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREO_CHILDREN),
    value: None,
};

pub static VARS_PREO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("esophageal"),
        dictgen::InsensitiveStr::Ascii("ffence"),
        dictgen::InsensitiveStr::Ascii("ffences"),
        dictgen::InsensitiveStr::Ascii("ffense"),
        dictgen::InsensitiveStr::Ascii("ffenses"),
        dictgen::InsensitiveStr::Ascii("perculum"),
        dictgen::InsensitiveStr::Ascii("ral"),
        dictgen::InsensitiveStr::Ascii("rally"),
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganise"),
        dictgen::InsensitiveStr::Ascii("rganises"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("rganize"),
        dictgen::InsensitiveStr::Ascii("rganizes"),
        dictgen::InsensitiveStr::Ascii("tic"),
        dictgen::InsensitiveStr::Ascii("xidise"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidises"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidize"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizes"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PREESOPHAGEAL_7351484208782474235)],
        &[(0b11010, &ENTRY_PREOFFENSE_579716648102296925)],
        &[(0b11010, &ENTRY_PREOFFENSES_7896176460933351275)],
        &[(0b00001, &ENTRY_PREOFFENSE_579716648102296925)],
        &[(0b00001, &ENTRY_PREOFFENSES_7896176460933351275)],
        &[(0b00001, &ENTRY_PREOPERCULUM_14063888562450517256)],
        &[(0b11010, &ENTRY_PERORAL_7733507504372641537)],
        &[(0b11010, &ENTRY_PERORALLY_13736466146014362811)],
        &[(0b10010, &ENTRY_PREORGANIZATION_2330721165999405697)],
        &[(0b10010, &ENTRY_PREORGANIZATIONS_9703149629890011334)],
        &[(0b10010, &ENTRY_PREORGANIZE_11661260841615530241)],
        &[(0b10010, &ENTRY_PREORGANIZES_12964164181090276763)],
        &[(0b01001, &ENTRY_PREORGANIZATION_2330721165999405697)],
        &[(0b01001, &ENTRY_PREORGANIZATIONS_9703149629890011334)],
        &[(0b01001, &ENTRY_PREORGANIZE_11661260841615530241)],
        &[(0b01001, &ENTRY_PREORGANIZES_12964164181090276763)],
        &[(0b11010, &ENTRY_PEROTIC_5938557738822235093)],
        &[(0b10010, &ENTRY_PREOXIDIZE_16282140963246736780)],
        &[(0b10010, &ENTRY_PREOXIDIZED_7318658950505462890)],
        &[(0b10010, &ENTRY_PREOXIDIZES_12387705073002168500)],
        &[(0b10010, &ENTRY_PREOXIDIZING_9934682611281956009)],
        &[(0b01001, &ENTRY_PREOXIDIZE_16282140963246736780)],
        &[(0b01001, &ENTRY_PREOXIDIZED_7318658950505462890)],
        &[(0b01001, &ENTRY_PREOXIDIZES_12387705073002168500)],
        &[(0b01001, &ENTRY_PREOXIDIZING_9934682611281956009)],
    ],
    range: 3..=12,
};

static VARS_PREN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREN_CHILDREN),
    value: None,
};

pub static VARS_PREN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arial"),
        dictgen::InsensitiveStr::Ascii("asal"),
        dictgen::InsensitiveStr::Ascii("eural"),
        dictgen::InsensitiveStr::Ascii("omen"),
        dictgen::InsensitiveStr::Ascii("omens"),
        dictgen::InsensitiveStr::Ascii("omina"),
        dictgen::InsensitiveStr::Ascii("ominal"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRENARIAL_260763454177661493)],
        &[(0b11010, &ENTRY_PERNASAL_9314997630181268940)],
        &[(0b00001, &ENTRY_PRENEURAL_2408211185451005975)],
        &[(0b00001, &ENTRY_PRAENOMEN_12851101647627907857)],
        &[(0b00001, &ENTRY_PRAENOMENS_251912711638326782)],
        &[(0b00001, &ENTRY_PRENOMINA_10767320086992242477)],
        &[(0b00001, &ENTRY_PRENOMINAL_13090458952010105722)],
    ],
    range: 4..=6,
};

static VARS_PREM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREM_CHILDREN),
    value: None,
};

pub static VARS_PREM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("axilla"),
        dictgen::InsensitiveStr::Ascii("ial"),
        dictgen::InsensitiveStr::Ascii("illennialise"),
        dictgen::InsensitiveStr::Ascii("illennialised"),
        dictgen::InsensitiveStr::Ascii("illennialising"),
        dictgen::InsensitiveStr::Ascii("illennialize"),
        dictgen::InsensitiveStr::Ascii("illennialized"),
        dictgen::InsensitiveStr::Ascii("illennializing"),
        dictgen::InsensitiveStr::Ascii("issable"),
        dictgen::InsensitiveStr::Ascii("ixture"),
        dictgen::InsensitiveStr::Ascii("onopolise"),
        dictgen::InsensitiveStr::Ascii("onopolises"),
        dictgen::InsensitiveStr::Ascii("onopolize"),
        dictgen::InsensitiveStr::Ascii("onopolizes"),
        dictgen::InsensitiveStr::Ascii("unire"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PREMAXILLA_1949932614025975842)],
        &[(0b00001, &ENTRY_PREMIAL_7239338890868461187)],
        &[(0b10010, &ENTRY_PREMILLENNIALIZE_492481850943039694)],
        &[(0b10010, &ENTRY_PREMILLENNIALIZED_1833932061640377180)],
        &[(0b10010, &ENTRY_PREMILLENNIALIZING_11897307349466382218)],
        &[(0b01001, &ENTRY_PREMILLENNIALIZE_492481850943039694)],
        &[(0b01001, &ENTRY_PREMILLENNIALIZED_1833932061640377180)],
        &[(0b01001, &ENTRY_PREMILLENNIALIZING_11897307349466382218)],
        &[(0b11010, &ENTRY_PERMISSABLE_15564403146668071230)],
        &[(0b11010, &ENTRY_PERMIXTURE_14648968165378084827)],
        &[(0b10010, &ENTRY_PREMONOPOLIZE_977575207751993670)],
        &[(0b10010, &ENTRY_PREMONOPOLIZES_16617698551422036185)],
        &[(0b01001, &ENTRY_PREMONOPOLIZE_977575207751993670)],
        &[(0b01001, &ENTRY_PREMONOPOLIZES_16617698551422036185)],
        &[(0b00001, &ENTRY_PREMUNIRE_6858216713782981118)],
    ],
    range: 3..=14,
};

static VARS_PREL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREL_CHILDREN),
    value: None,
};

pub static VARS_PREL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abor"),
        dictgen::InsensitiveStr::Ascii("abors"),
        dictgen::InsensitiveStr::Ascii("abour"),
        dictgen::InsensitiveStr::Ascii("abours"),
        dictgen::InsensitiveStr::Ascii("abrum"),
        dictgen::InsensitiveStr::Ascii("atise"),
        dictgen::InsensitiveStr::Ascii("atised"),
        dictgen::InsensitiveStr::Ascii("atises"),
        dictgen::InsensitiveStr::Ascii("atising"),
        dictgen::InsensitiveStr::Ascii("atize"),
        dictgen::InsensitiveStr::Ascii("atized"),
        dictgen::InsensitiveStr::Ascii("atizes"),
        dictgen::InsensitiveStr::Ascii("atizing"),
        dictgen::InsensitiveStr::Ascii("ect"),
        dictgen::InsensitiveStr::Ascii("ected"),
        dictgen::InsensitiveStr::Ascii("ecting"),
        dictgen::InsensitiveStr::Ascii("ection"),
        dictgen::InsensitiveStr::Ascii("ector"),
        dictgen::InsensitiveStr::Ascii("ectorship"),
        dictgen::InsensitiveStr::Ascii("ectress"),
        dictgen::InsensitiveStr::Ascii("ects"),
        dictgen::InsensitiveStr::Ascii("ingual"),
        dictgen::InsensitiveStr::Ascii("ingually"),
        dictgen::InsensitiveStr::Ascii("ocalisation"),
        dictgen::InsensitiveStr::Ascii("ocalisations"),
        dictgen::InsensitiveStr::Ascii("ocalization"),
        dictgen::InsensitiveStr::Ascii("ocalizations"),
        dictgen::InsensitiveStr::Ascii("udise"),
        dictgen::InsensitiveStr::Ascii("udises"),
        dictgen::InsensitiveStr::Ascii("udium"),
        dictgen::InsensitiveStr::Ascii("udize"),
        dictgen::InsensitiveStr::Ascii("udizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRELABOR_780423797883210133)],
        &[(0b00001, &ENTRY_PRELABORS_1691176672047019402)],
        &[(0b11010, &ENTRY_PRELABOR_780423797883210133)],
        &[(0b11010, &ENTRY_PRELABORS_1691176672047019402)],
        &[(0b00001, &ENTRY_PRELABRUM_4394969735839137776)],
        &[(0b10010, &ENTRY_PRELATIZE_10149280095441660432)],
        &[(0b10010, &ENTRY_PRELATIZED_5978559888639182049)],
        &[(0b10010, &ENTRY_PRELATIZES_1897637326171289560)],
        &[(0b10010, &ENTRY_PRELATIZING_4028012513229840028)],
        &[(0b01001, &ENTRY_PRELATIZE_10149280095441660432)],
        &[(0b01001, &ENTRY_PRELATIZED_5978559888639182049)],
        &[(0b01001, &ENTRY_PRELATIZES_1897637326171289560)],
        &[(0b01001, &ENTRY_PRELATIZING_4028012513229840028)],
        &[(0b00001, &ENTRY_PRELECT_12537605063468335740)],
        &[(0b00001, &ENTRY_PRELECTED_17531016903900240455)],
        &[(0b00001, &ENTRY_PRELECTING_17733481734284410679)],
        &[
            (0b11010, &ENTRY_PERLECTION_10848653127438263550),
            (0b00001, &ENTRY_PRELECTION_14375165505479018006),
        ],
        &[(0b00001, &ENTRY_PRELECTOR_16845719004040241611)],
        &[(0b00001, &ENTRY_PRELECTORSHIP_13792769749923826474)],
        &[(0b00001, &ENTRY_PRELECTRESS_5401088119304407518)],
        &[(0b00001, &ENTRY_PRELECTS_11650422889665953253)],
        &[(0b11010, &ENTRY_PERLINGUAL_9348282944919159241)],
        &[(0b11010, &ENTRY_PERLINGUALLY_9782531538000987848)],
        &[(0b10010, &ENTRY_PRELOCALIZATION_3522544466185913321)],
        &[(0b10010, &ENTRY_PRELOCALIZATIONS_12419652001524346907)],
        &[(0b01001, &ENTRY_PRELOCALIZATION_3522544466185913321)],
        &[(0b01001, &ENTRY_PRELOCALIZATIONS_12419652001524346907)],
        &[(0b10010, &ENTRY_PRELUDIZE_15399918472889656379)],
        &[(0b10010, &ENTRY_PRELUDIZES_785047441714468739)],
        &[(0b10001, &ENTRY_PRELUDIUM_10948679295576237674)],
        &[(0b01001, &ENTRY_PRELUDIZE_15399918472889656379)],
        &[(0b01001, &ENTRY_PRELUDIZES_785047441714468739)],
    ],
    range: 3..=12,
};

static VARS_PREJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREJ_CHILDREN),
    value: None,
};

pub static VARS_PREJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ink"),
        dictgen::InsensitiveStr::Ascii("udgement"),
        dictgen::InsensitiveStr::Ascii("udgements"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PERJINK_8081638468925211155)],
        &[(0b10010, &ENTRY_PREJUDGMENT_16703900164850541684)],
        &[(0b10010, &ENTRY_PREJUDGMENTS_14741815798482492241)],
    ],
    range: 3..=9,
};

static VARS_PREI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREI_CHILDREN),
    value: None,
};

pub static VARS_PREI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nitialise"),
        dictgen::InsensitiveStr::Ascii("nitialised"),
        dictgen::InsensitiveStr::Ascii("nitialises"),
        dictgen::InsensitiveStr::Ascii("nitialising"),
        dictgen::InsensitiveStr::Ascii("nitialize"),
        dictgen::InsensitiveStr::Ascii("nitialized"),
        dictgen::InsensitiveStr::Ascii("nitializes"),
        dictgen::InsensitiveStr::Ascii("nitializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PREINITIALIZE_1468717660753702862)],
        &[(0b10010, &ENTRY_PREINITIALIZED_9596394147383220664)],
        &[(0b10010, &ENTRY_PREINITIALIZES_16023204644649323111)],
        &[(0b10010, &ENTRY_PREINITIALIZING_18005348415129385802)],
        &[(0b01001, &ENTRY_PREINITIALIZE_1468717660753702862)],
        &[(0b01001, &ENTRY_PREINITIALIZED_9596394147383220664)],
        &[(0b01001, &ENTRY_PREINITIALIZES_16023204644649323111)],
        &[(0b01001, &ENTRY_PREINITIALIZING_18005348415129385802)],
    ],
    range: 9..=11,
};

static VARS_PREH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREH_CHILDREN),
    value: None,
};

pub static VARS_PREH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("allux"),
        dictgen::InsensitiveStr::Ascii("azard"),
        dictgen::InsensitiveStr::Ascii("umor"),
        dictgen::InsensitiveStr::Ascii("umors"),
        dictgen::InsensitiveStr::Ascii("umour"),
        dictgen::InsensitiveStr::Ascii("umours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PREHALLUX_4969284544099274299)],
        &[(0b11010, &ENTRY_PERHAZARD_3309804805860844776)],
        &[(0b00001, &ENTRY_PREHUMOR_1371086280255419223)],
        &[(0b00001, &ENTRY_PREHUMORS_13859524652523742789)],
        &[(0b11010, &ENTRY_PREHUMOR_1371086280255419223)],
        &[(0b11010, &ENTRY_PREHUMORS_13859524652523742789)],
    ],
    range: 4..=6,
};

static VARS_PREG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREG_CHILDREN),
    value: None,
};

pub static VARS_PREG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alvanise"),
        dictgen::InsensitiveStr::Ascii("alvanises"),
        dictgen::InsensitiveStr::Ascii("alvanize"),
        dictgen::InsensitiveStr::Ascii("alvanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PREGALVANIZE_16984111387364425037)],
        &[(0b10010, &ENTRY_PREGALVANIZES_18085190507843305402)],
        &[(0b01001, &ENTRY_PREGALVANIZE_16984111387364425037)],
        &[(0b01001, &ENTRY_PREGALVANIZES_18085190507843305402)],
    ],
    range: 8..=9,
};

static VARS_PREF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREF_CHILDREN),
    value: None,
};

pub static VARS_PREF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avor"),
        dictgen::InsensitiveStr::Ascii("avorable"),
        dictgen::InsensitiveStr::Ascii("avorables"),
        dictgen::InsensitiveStr::Ascii("avorablies"),
        dictgen::InsensitiveStr::Ascii("avorably"),
        dictgen::InsensitiveStr::Ascii("avorite"),
        dictgen::InsensitiveStr::Ascii("avorites"),
        dictgen::InsensitiveStr::Ascii("avors"),
        dictgen::InsensitiveStr::Ascii("avour"),
        dictgen::InsensitiveStr::Ascii("avourable"),
        dictgen::InsensitiveStr::Ascii("avourables"),
        dictgen::InsensitiveStr::Ascii("avourablies"),
        dictgen::InsensitiveStr::Ascii("avourably"),
        dictgen::InsensitiveStr::Ascii("avourite"),
        dictgen::InsensitiveStr::Ascii("avourites"),
        dictgen::InsensitiveStr::Ascii("avours"),
        dictgen::InsensitiveStr::Ascii("ectorial"),
        dictgen::InsensitiveStr::Ascii("ertilisation"),
        dictgen::InsensitiveStr::Ascii("ertilisations"),
        dictgen::InsensitiveStr::Ascii("ertilise"),
        dictgen::InsensitiveStr::Ascii("ertilises"),
        dictgen::InsensitiveStr::Ascii("ertilization"),
        dictgen::InsensitiveStr::Ascii("ertilizations"),
        dictgen::InsensitiveStr::Ascii("ertilize"),
        dictgen::InsensitiveStr::Ascii("ertilizes"),
        dictgen::InsensitiveStr::Ascii("et"),
        dictgen::InsensitiveStr::Ascii("lavor"),
        dictgen::InsensitiveStr::Ascii("lavoring"),
        dictgen::InsensitiveStr::Ascii("lavorings"),
        dictgen::InsensitiveStr::Ascii("lavors"),
        dictgen::InsensitiveStr::Ascii("lavour"),
        dictgen::InsensitiveStr::Ascii("lavouring"),
        dictgen::InsensitiveStr::Ascii("lavourings"),
        dictgen::InsensitiveStr::Ascii("lavours"),
        dictgen::InsensitiveStr::Ascii("loration"),
        dictgen::InsensitiveStr::Ascii("oliation"),
        dictgen::InsensitiveStr::Ascii("oliations"),
        dictgen::InsensitiveStr::Ascii("ormant"),
        dictgen::InsensitiveStr::Ascii("ormative"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PREFAVOR_1052743038836547643)],
        &[(0b00001, &ENTRY_PREFAVORABLE_11226316521498660594)],
        &[(0b00001, &ENTRY_PREFAVORABLES_14007584726075938864)],
        &[(0b00001, &ENTRY_PREFAVORABLIES_16468315820782161395)],
        &[(0b00001, &ENTRY_PREFAVORABLY_8511265901221040677)],
        &[(0b00001, &ENTRY_PREFAVORITE_17782297686433439541)],
        &[(0b00001, &ENTRY_PREFAVORITES_6381395897759886730)],
        &[(0b00001, &ENTRY_PREFAVORS_2743070173975491288)],
        &[(0b11010, &ENTRY_PREFAVOR_1052743038836547643)],
        &[(0b11010, &ENTRY_PREFAVORABLE_11226316521498660594)],
        &[(0b11010, &ENTRY_PREFAVORABLES_14007584726075938864)],
        &[(0b11010, &ENTRY_PREFAVORABLIES_16468315820782161395)],
        &[(0b11010, &ENTRY_PREFAVORABLY_8511265901221040677)],
        &[(0b11010, &ENTRY_PREFAVORITE_17782297686433439541)],
        &[(0b11010, &ENTRY_PREFAVORITES_6381395897759886730)],
        &[(0b11010, &ENTRY_PREFAVORS_2743070173975491288)],
        &[(0b00001, &ENTRY_PREFECTORIAL_12394552410147263896)],
        &[(0b10010, &ENTRY_PREFERTILIZATION_4841765994936591802)],
        &[(0b10010, &ENTRY_PREFERTILIZATIONS_11003132162782639220)],
        &[(0b10010, &ENTRY_PREFERTILIZE_12979945903814095432)],
        &[(0b10010, &ENTRY_PREFERTILIZES_15925140722483029210)],
        &[(0b01001, &ENTRY_PREFERTILIZATION_4841765994936591802)],
        &[(0b01001, &ENTRY_PREFERTILIZATIONS_11003132162782639220)],
        &[(0b01001, &ENTRY_PREFERTILIZE_12979945903814095432)],
        &[(0b01001, &ENTRY_PREFERTILIZES_15925140722483029210)],
        &[(0b11010, &ENTRY_PERFET_13896758539689213591)],
        &[(0b00001, &ENTRY_PREFLAVOR_18251384983795695782)],
        &[(0b00001, &ENTRY_PREFLAVORING_7487499086450337069)],
        &[(0b00001, &ENTRY_PREFLAVORINGS_8688443428859654444)],
        &[(0b00001, &ENTRY_PREFLAVORS_8068519514702666048)],
        &[(0b11010, &ENTRY_PREFLAVOR_18251384983795695782)],
        &[(0b11010, &ENTRY_PREFLAVORING_7487499086450337069)],
        &[(0b11010, &ENTRY_PREFLAVORINGS_8688443428859654444)],
        &[(0b11010, &ENTRY_PREFLAVORS_8068519514702666048)],
        &[(0b00001, &ENTRY_PREFLORATION_11469641643312189954)],
        &[
            (0b11010, &ENTRY_PERFOLIATION_5188268018612471981),
            (0b00001, &ENTRY_PREFOLIATION_17171347073332349592),
        ],
        &[(0b11010, &ENTRY_PERFOLIATIONS_17365195892397282393)],
        &[(0b11010, &ENTRY_PERFORMANT_15759765683817996390)],
        &[(0b11010, &ENTRY_PERFORMATIVE_2390820457715027525)],
    ],
    range: 2..=13,
};

static VARS_PREE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREE_CHILDREN),
    value: None,
};

pub static VARS_PREE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mptor"),
        dictgen::InsensitiveStr::Ascii("sophageal"),
        dictgen::InsensitiveStr::Ascii("stival"),
        dictgen::InsensitiveStr::Ascii("xistent"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PREEMPTOR_15768806273074897294)],
        &[
            (0b00001, &ENTRY_PREESOPHAGEAL_7351484208782474235),
            (0b00001, &ENTRY_PREESOPHAGEAL_7806252650760260205),
        ],
        &[(0b00001, &ENTRY_PREESTIVAL_17457419379815350363)],
        &[(0b00001, &ENTRY_PREEXISTENT_5553896724671901278)],
    ],
    range: 5..=9,
};

static VARS_PRED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRED_CHILDREN),
    value: None,
};

pub static VARS_PRED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ial"),
        dictgen::InsensitiveStr::Ascii("ialist"),
        dictgen::InsensitiveStr::Ascii("iality"),
        dictgen::InsensitiveStr::Ascii("ials"),
        dictgen::InsensitiveStr::Ascii("iligent"),
        dictgen::InsensitiveStr::Ascii("y"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PREDIAL_13314408220157784404)],
        &[(0b00001, &ENTRY_PREDIALIST_15938835210648844562)],
        &[(0b00001, &ENTRY_PREDIALITY_5941457168149043947)],
        &[(0b00001, &ENTRY_PREDIALS_13874920445884966698)],
        &[(0b11010, &ENTRY_PERDILIGENT_6178720230946595348)],
        &[(0b11010, &ENTRY_PERDY_17015242260554099593)],
    ],
    range: 1..=7,
};

static VARS_PREC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PREC_CHILDREN),
    value: None,
};

static VARS_PREC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PRECA_NODE),
    None,
    None,
    None,
    Some(&VARS_PRECE_NODE),
    None,
    None,
    Some(&VARS_PRECH_NODE),
    Some(&VARS_PRECI_NODE),
    None,
    None,
    Some(&VARS_PRECL_NODE),
    None,
    None,
    Some(&VARS_PRECO_NODE),
    None,
    None,
    Some(&VARS_PRECR_NODE),
    None,
    None,
    Some(&VARS_PRECU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_PRECU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECU_CHILDREN),
    value: None,
};

pub static VARS_PRECU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("neus"),
        dictgen::InsensitiveStr::Ascii("rrent"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRECUNEUS_2232807234398123688)],
        &[(0b11010, &ENTRY_PERCURRENT_7729534483371927658)],
    ],
    range: 4..=5,
};

static VARS_PRECR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECR_CHILDREN),
    value: None,
};

pub static VARS_PRECR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iticise"),
        dictgen::InsensitiveStr::Ascii("iticises"),
        dictgen::InsensitiveStr::Ascii("iticize"),
        dictgen::InsensitiveStr::Ascii("iticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PRECRITICIZE_9318452050596986184)],
        &[(0b10010, &ENTRY_PRECRITICIZES_5247080334248511116)],
        &[(0b01001, &ENTRY_PRECRITICIZE_9318452050596986184)],
        &[(0b01001, &ENTRY_PRECRITICIZES_5247080334248511116)],
    ],
    range: 7..=8,
};

static VARS_PRECO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECO_CHILDREN),
    value: None,
};

pub static VARS_PRECO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cial"),
        dictgen::InsensitiveStr::Ascii("lor"),
        dictgen::InsensitiveStr::Ascii("lorable"),
        dictgen::InsensitiveStr::Ascii("lorabler"),
        dictgen::InsensitiveStr::Ascii("lorables"),
        dictgen::InsensitiveStr::Ascii("lorablest"),
        dictgen::InsensitiveStr::Ascii("loration"),
        dictgen::InsensitiveStr::Ascii("lorations"),
        dictgen::InsensitiveStr::Ascii("lored"),
        dictgen::InsensitiveStr::Ascii("loring"),
        dictgen::InsensitiveStr::Ascii("lorings"),
        dictgen::InsensitiveStr::Ascii("lors"),
        dictgen::InsensitiveStr::Ascii("lour"),
        dictgen::InsensitiveStr::Ascii("lourable"),
        dictgen::InsensitiveStr::Ascii("lourabler"),
        dictgen::InsensitiveStr::Ascii("lourables"),
        dictgen::InsensitiveStr::Ascii("lourablest"),
        dictgen::InsensitiveStr::Ascii("louration"),
        dictgen::InsensitiveStr::Ascii("lourations"),
        dictgen::InsensitiveStr::Ascii("loured"),
        dictgen::InsensitiveStr::Ascii("louring"),
        dictgen::InsensitiveStr::Ascii("lourings"),
        dictgen::InsensitiveStr::Ascii("lours"),
        dictgen::InsensitiveStr::Ascii("mpound"),
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
        dictgen::InsensitiveStr::Ascii("racoid"),
        dictgen::InsensitiveStr::Ascii("rdia"),
        dictgen::InsensitiveStr::Ascii("rdial"),
        dictgen::InsensitiveStr::Ascii("rdium"),
        dictgen::InsensitiveStr::Ascii("rnu"),
        dictgen::InsensitiveStr::Ascii("x"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRECOCIAL_1632763347532933222)],
        &[(0b10001, &ENTRY_PRECOLOR_421440567663720130)],
        &[(0b10001, &ENTRY_PRECOLORABLE_8927422689593708380)],
        &[(0b10001, &ENTRY_PRECOLORABLER_12809399652471625977)],
        &[(0b10001, &ENTRY_PRECOLORABLES_5228912827468002969)],
        &[(0b10001, &ENTRY_PRECOLORABLEST_16508120149722086116)],
        &[(0b00001, &ENTRY_PRECOLORATION_14701765064218173385)],
        &[(0b00001, &ENTRY_PRECOLORATIONS_10964118530390224803)],
        &[(0b10001, &ENTRY_PRECOLORED_8558043425935508627)],
        &[(0b10001, &ENTRY_PRECOLORING_15907201636458074973)],
        &[(0b10001, &ENTRY_PRECOLORINGS_1385084320150173125)],
        &[(0b10001, &ENTRY_PRECOLORS_4819161434090345366)],
        &[(0b11010, &ENTRY_PRECOLOR_421440567663720130)],
        &[(0b11010, &ENTRY_PRECOLORABLE_8927422689593708380)],
        &[(0b11010, &ENTRY_PRECOLORABLER_12809399652471625977)],
        &[(0b11010, &ENTRY_PRECOLORABLES_5228912827468002969)],
        &[(0b11010, &ENTRY_PRECOLORABLEST_16508120149722086116)],
        &[(0b11010, &ENTRY_PRECOLORATION_14701765064218173385)],
        &[(0b11010, &ENTRY_PRECOLORATIONS_10964118530390224803)],
        &[(0b11010, &ENTRY_PRECOLORED_8558043425935508627)],
        &[(0b11010, &ENTRY_PRECOLORING_15907201636458074973)],
        &[(0b11010, &ENTRY_PRECOLORINGS_1385084320150173125)],
        &[(0b11010, &ENTRY_PRECOLORS_4819161434090345366)],
        &[(0b11010, &ENTRY_PERCOMPOUND_4631387873257903195)],
        &[(0b10010, &ENTRY_PRECONIZATION_5128332384662999880)],
        &[(0b10010, &ENTRY_PRECONIZATIONS_15559954424980964068)],
        &[(0b10010, &ENTRY_PRECONIZE_13784477669434917149)],
        &[(0b10010, &ENTRY_PRECONIZED_11673314501314681040)],
        &[(0b10010, &ENTRY_PRECONIZER_183199819264544815)],
        &[(0b10010, &ENTRY_PRECONIZERS_2855306765570884664)],
        &[(0b10010, &ENTRY_PRECONIZES_16046662733582737370)],
        &[(0b10010, &ENTRY_PRECONIZING_856066415909262347)],
        &[(0b01001, &ENTRY_PRECONIZATION_5128332384662999880)],
        &[(0b01001, &ENTRY_PRECONIZATIONS_15559954424980964068)],
        &[(0b01001, &ENTRY_PRECONIZE_13784477669434917149)],
        &[(0b01001, &ENTRY_PRECONIZED_11673314501314681040)],
        &[(0b01001, &ENTRY_PRECONIZER_183199819264544815)],
        &[(0b01001, &ENTRY_PRECONIZERS_2855306765570884664)],
        &[(0b01001, &ENTRY_PRECONIZES_16046662733582737370)],
        &[(0b01001, &ENTRY_PRECONIZING_856066415909262347)],
        &[(0b00001, &ENTRY_PRECORACOID_14112650972840331881)],
        &[(0b00001, &ENTRY_PRECORDIA_1917126594708911487)],
        &[(0b00001, &ENTRY_PRECORDIAL_11499053547875463822)],
        &[(0b00001, &ENTRY_PRECORDIUM_8035690684402584466)],
        &[(0b00001, &ENTRY_PRECORNU_3251658118511369979)],
        &[(0b00001, &ENTRY_PRECOX_16157515385095809645)],
    ],
    range: 1..=10,
};

static VARS_PRECL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECL_CHILDREN),
    value: None,
};

pub static VARS_PRECL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ose")],
    values: &[&[(0b11010, &ENTRY_PERCLOSE_8855509826381556500)]],
    range: 3..=3,
};

static VARS_PRECI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECI_CHILDREN),
    value: None,
};

pub static VARS_PRECI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("pe"),
        dictgen::InsensitiveStr::Ascii("pes"),
        dictgen::InsensitiveStr::Ascii("sionise"),
        dictgen::InsensitiveStr::Ascii("sionises"),
        dictgen::InsensitiveStr::Ascii("sionize"),
        dictgen::InsensitiveStr::Ascii("sionizes"),
        dictgen::InsensitiveStr::Ascii("vilisation"),
        dictgen::InsensitiveStr::Ascii("vilisations"),
        dictgen::InsensitiveStr::Ascii("vilization"),
        dictgen::InsensitiveStr::Ascii("vilizations"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRECIPE_16439872753817235281)],
        &[(0b00001, &ENTRY_PRECIPES_11793138580696398194)],
        &[(0b10010, &ENTRY_PRECISIONIZE_7123140285802599910)],
        &[(0b10010, &ENTRY_PRECISIONIZES_8864457404063891143)],
        &[(0b01001, &ENTRY_PRECISIONIZE_7123140285802599910)],
        &[(0b01001, &ENTRY_PRECISIONIZES_8864457404063891143)],
        &[(0b10010, &ENTRY_PRECIVILIZATION_8889763047458993422)],
        &[(0b10010, &ENTRY_PRECIVILIZATIONS_14883120958183038655)],
        &[(0b01001, &ENTRY_PRECIVILIZATION_8889763047458993422)],
        &[(0b01001, &ENTRY_PRECIVILIZATIONS_14883120958183038655)],
    ],
    range: 2..=11,
};

static VARS_PRECH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECH_CHILDREN),
    value: None,
};

pub static VARS_PRECH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("loric")],
    values: &[&[(0b11010, &ENTRY_PERCHLORIC_15873681416223690811)]],
    range: 5..=5,
};

static VARS_PRECE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECE_CHILDREN),
    value: None,
};

pub static VARS_PRECE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("s")],
    values: &[&[(0b11010, &ENTRY_PERCES_18231213262419993595)]],
    range: 1..=1,
};

static VARS_PRECA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECA_CHILDREN),
    value: None,
};

pub static VARS_PRECA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ncelation"),
        dictgen::InsensitiveStr::Ascii("va"),
        dictgen::InsensitiveStr::Ascii("vae"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRECANCELATION_9783160411222572763)],
        &[(0b00001, &ENTRY_PRECAVA_17244718726567157566)],
        &[(0b00001, &ENTRY_PRECAVAE_4088664315652932471)],
    ],
    range: 2..=9,
};

static VARS_PREB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREB_CHILDREN),
    value: None,
};

pub static VARS_PREB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aptise"),
        dictgen::InsensitiveStr::Ascii("aptises"),
        dictgen::InsensitiveStr::Ascii("aptize"),
        dictgen::InsensitiveStr::Ascii("aptizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PREBAPTIZE_5674634642550900380)],
        &[(0b10010, &ENTRY_PREBAPTIZES_6136234876096081294)],
        &[(0b01001, &ENTRY_PREBAPTIZE_5674634642550900380)],
        &[(0b01001, &ENTRY_PREBAPTIZES_6136234876096081294)],
    ],
    range: 6..=7,
};

static VARS_PREA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREA_CHILDREN),
    value: None,
};

pub static VARS_PREA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bdomen"),
        dictgen::InsensitiveStr::Ascii("cetabular"),
        dictgen::InsensitiveStr::Ascii("cherise"),
        dictgen::InsensitiveStr::Ascii("cherises"),
        dictgen::InsensitiveStr::Ascii("cherize"),
        dictgen::InsensitiveStr::Ascii("cherizes"),
        dictgen::InsensitiveStr::Ascii("cid"),
        dictgen::InsensitiveStr::Ascii("cidity"),
        dictgen::InsensitiveStr::Ascii("cknowledgement"),
        dictgen::InsensitiveStr::Ascii("cknowledgements"),
        dictgen::InsensitiveStr::Ascii("cknowledgment"),
        dictgen::InsensitiveStr::Ascii("cknowledgments"),
        dictgen::InsensitiveStr::Ascii("ct"),
        dictgen::InsensitiveStr::Ascii("cute"),
        dictgen::InsensitiveStr::Ascii("emptor"),
        dictgen::InsensitiveStr::Ascii("estival"),
        dictgen::InsensitiveStr::Ascii("existent"),
        dictgen::InsensitiveStr::Ascii("mbulatory"),
        dictgen::InsensitiveStr::Ascii("naesthetic"),
        dictgen::InsensitiveStr::Ascii("naesthetics"),
        dictgen::InsensitiveStr::Ascii("nal"),
        dictgen::InsensitiveStr::Ascii("nesthetic"),
        dictgen::InsensitiveStr::Ascii("nesthetics"),
        dictgen::InsensitiveStr::Ascii("pprise"),
        dictgen::InsensitiveStr::Ascii("pprised"),
        dictgen::InsensitiveStr::Ascii("pprising"),
        dictgen::InsensitiveStr::Ascii("pprize"),
        dictgen::InsensitiveStr::Ascii("pprized"),
        dictgen::InsensitiveStr::Ascii("pprizing"),
        dictgen::InsensitiveStr::Ascii("uthorise"),
        dictgen::InsensitiveStr::Ascii("uthorize"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PREABDOMEN_17654103674218328344)],
        &[(0b00001, &ENTRY_PREACETABULAR_8636154966920332770)],
        &[(0b10010, &ENTRY_PREACHERIZE_15577462823086971421)],
        &[(0b10010, &ENTRY_PREACHERIZES_5353773739256681754)],
        &[(0b01001, &ENTRY_PREACHERIZE_15577462823086971421)],
        &[(0b01001, &ENTRY_PREACHERIZES_5353773739256681754)],
        &[(0b11010, &ENTRY_PERACID_18248699393309889840)],
        &[(0b11010, &ENTRY_PERACIDITY_4694554317646599680)],
        &[(0b11010, &ENTRY_PREACKNOWLEDGMENT_13370080387519237911)],
        &[(0b11010, &ENTRY_PREACKNOWLEDGMENTS_6210578949702226482)],
        &[(0b00001, &ENTRY_PREACKNOWLEDGMENT_13370080387519237911)],
        &[(0b00001, &ENTRY_PREACKNOWLEDGMENTS_6210578949702226482)],
        &[(0b11010, &ENTRY_PERACT_13646631763087455494)],
        &[(0b11010, &ENTRY_PERACUTE_18080047841868048531)],
        &[(0b11010, &ENTRY_PREEMPTOR_15768806273074897294)],
        &[(0b11010, &ENTRY_PREESTIVAL_17457419379815350363)],
        &[(0b11010, &ENTRY_PREEXISTENT_5553896724671901278)],
        &[(0b11010, &ENTRY_PERAMBULATORY_3157892809066109163)],
        &[(0b11010, &ENTRY_PREANESTHETIC_9312256255292612148)],
        &[(0b11010, &ENTRY_PREANESTHETICS_11926760638683781880)],
        &[(0b00001, &ENTRY_PREANAL_4045685164935232098)],
        &[(0b00001, &ENTRY_PREANESTHETIC_9312256255292612148)],
        &[(0b00001, &ENTRY_PREANESTHETICS_11926760638683781880)],
        &[(0b10010, &ENTRY_PREAPPRIZE_10965476670389309101)],
        &[(0b10010, &ENTRY_PREAPPRIZED_16626885948208304315)],
        &[(0b10010, &ENTRY_PREAPPRIZING_9245621224584706350)],
        &[(0b01001, &ENTRY_PREAPPRIZE_10965476670389309101)],
        &[(0b01001, &ENTRY_PREAPPRIZED_16626885948208304315)],
        &[(0b01001, &ENTRY_PREAPPRIZING_9245621224584706350)],
        &[(0b10010, &ENTRY_PREAUTHORIZE_17711895655398888607)],
        &[(0b01001, &ENTRY_PREAUTHORIZE_17711895655398888607)],
    ],
    range: 2..=15,
};

static VARS_PRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PRA_CHILDREN),
    value: None,
};

static VARS_PRA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_PRAC_NODE),
    None,
    Some(&VARS_PRAE_NODE),
    None,
    Some(&VARS_PRAG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PRAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRAG_CHILDREN),
    value: None,
};

pub static VARS_PRAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matisation"),
        dictgen::InsensitiveStr::Ascii("matisations"),
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matiser"),
        dictgen::InsensitiveStr::Ascii("matisers"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matization"),
        dictgen::InsensitiveStr::Ascii("matizations"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizer"),
        dictgen::InsensitiveStr::Ascii("matizers"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PRAGMATIZATION_7994386570071309962)],
        &[(0b10010, &ENTRY_PRAGMATIZATIONS_8662418597962158707)],
        &[(0b10010, &ENTRY_PRAGMATIZE_343422185629469665)],
        &[(0b10010, &ENTRY_PRAGMATIZED_1036888459501168703)],
        &[(0b10010, &ENTRY_PRAGMATIZER_7483637005948000334)],
        &[(0b10010, &ENTRY_PRAGMATIZERS_9799234638847516273)],
        &[(0b10010, &ENTRY_PRAGMATIZES_13474663761584307145)],
        &[(0b10010, &ENTRY_PRAGMATIZING_7905336194280525793)],
        &[(0b01001, &ENTRY_PRAGMATIZATION_7994386570071309962)],
        &[(0b01001, &ENTRY_PRAGMATIZATIONS_8662418597962158707)],
        &[(0b01001, &ENTRY_PRAGMATIZE_343422185629469665)],
        &[(0b01001, &ENTRY_PRAGMATIZED_1036888459501168703)],
        &[(0b01001, &ENTRY_PRAGMATIZER_7483637005948000334)],
        &[(0b01001, &ENTRY_PRAGMATIZERS_9799234638847516273)],
        &[(0b01001, &ENTRY_PRAGMATIZES_13474663761584307145)],
        &[(0b01001, &ENTRY_PRAGMATIZING_7905336194280525793)],
    ],
    range: 6..=11,
};

static VARS_PRAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRAE_CHILDREN),
    value: None,
};

pub static VARS_PRAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abdomen"),
        dictgen::InsensitiveStr::Ascii("acetabular"),
        dictgen::InsensitiveStr::Ascii("anal"),
        dictgen::InsensitiveStr::Ascii("cava"),
        dictgen::InsensitiveStr::Ascii("cavae"),
        dictgen::InsensitiveStr::Ascii("cipe"),
        dictgen::InsensitiveStr::Ascii("cipes"),
        dictgen::InsensitiveStr::Ascii("cocial"),
        dictgen::InsensitiveStr::Ascii("coracoid"),
        dictgen::InsensitiveStr::Ascii("cordia"),
        dictgen::InsensitiveStr::Ascii("cordial"),
        dictgen::InsensitiveStr::Ascii("cordium"),
        dictgen::InsensitiveStr::Ascii("cornu"),
        dictgen::InsensitiveStr::Ascii("cox"),
        dictgen::InsensitiveStr::Ascii("cuneus"),
        dictgen::InsensitiveStr::Ascii("dial"),
        dictgen::InsensitiveStr::Ascii("dialist"),
        dictgen::InsensitiveStr::Ascii("diality"),
        dictgen::InsensitiveStr::Ascii("dials"),
        dictgen::InsensitiveStr::Ascii("esophageal"),
        dictgen::InsensitiveStr::Ascii("fectorial"),
        dictgen::InsensitiveStr::Ascii("floration"),
        dictgen::InsensitiveStr::Ascii("foliation"),
        dictgen::InsensitiveStr::Ascii("hallux"),
        dictgen::InsensitiveStr::Ascii("labrum"),
        dictgen::InsensitiveStr::Ascii("lect"),
        dictgen::InsensitiveStr::Ascii("lected"),
        dictgen::InsensitiveStr::Ascii("lecting"),
        dictgen::InsensitiveStr::Ascii("lection"),
        dictgen::InsensitiveStr::Ascii("lector"),
        dictgen::InsensitiveStr::Ascii("lectorship"),
        dictgen::InsensitiveStr::Ascii("lectress"),
        dictgen::InsensitiveStr::Ascii("lects"),
        dictgen::InsensitiveStr::Ascii("ludium"),
        dictgen::InsensitiveStr::Ascii("maxilla"),
        dictgen::InsensitiveStr::Ascii("munire"),
        dictgen::InsensitiveStr::Ascii("narial"),
        dictgen::InsensitiveStr::Ascii("neural"),
        dictgen::InsensitiveStr::Ascii("nomina"),
        dictgen::InsensitiveStr::Ascii("nominal"),
        dictgen::InsensitiveStr::Ascii("operculum"),
        dictgen::InsensitiveStr::Ascii("positor"),
        dictgen::InsensitiveStr::Ascii("positure"),
        dictgen::InsensitiveStr::Ascii("poster"),
        dictgen::InsensitiveStr::Ascii("postor"),
        dictgen::InsensitiveStr::Ascii("postors"),
        dictgen::InsensitiveStr::Ascii("pubis"),
        dictgen::InsensitiveStr::Ascii("scutum"),
        dictgen::InsensitiveStr::Ascii("sphenoid"),
        dictgen::InsensitiveStr::Ascii("sternal"),
        dictgen::InsensitiveStr::Ascii("sternum"),
        dictgen::InsensitiveStr::Ascii("stomium"),
        dictgen::InsensitiveStr::Ascii("systolic"),
        dictgen::InsensitiveStr::Ascii("taxation"),
        dictgen::InsensitiveStr::Ascii("texta"),
        dictgen::InsensitiveStr::Ascii("textae"),
        dictgen::InsensitiveStr::Ascii("torial"),
        dictgen::InsensitiveStr::Ascii("torians"),
        dictgen::InsensitiveStr::Ascii("torium"),
        dictgen::InsensitiveStr::Ascii("torius"),
        dictgen::InsensitiveStr::Ascii("torship"),
        dictgen::InsensitiveStr::Ascii("zygapophysis"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PREABDOMEN_17654103674218328344)],
        &[(0b11010, &ENTRY_PREACETABULAR_8636154966920332770)],
        &[(0b11010, &ENTRY_PREANAL_4045685164935232098)],
        &[(0b11010, &ENTRY_PRECAVA_17244718726567157566)],
        &[(0b11010, &ENTRY_PRECAVAE_4088664315652932471)],
        &[(0b11010, &ENTRY_PRECIPE_16439872753817235281)],
        &[(0b11010, &ENTRY_PRECIPES_11793138580696398194)],
        &[(0b11010, &ENTRY_PRECOCIAL_1632763347532933222)],
        &[(0b11010, &ENTRY_PRECORACOID_14112650972840331881)],
        &[(0b11010, &ENTRY_PRECORDIA_1917126594708911487)],
        &[(0b11010, &ENTRY_PRECORDIAL_11499053547875463822)],
        &[(0b11010, &ENTRY_PRECORDIUM_8035690684402584466)],
        &[(0b11010, &ENTRY_PRECORNU_3251658118511369979)],
        &[(0b11010, &ENTRY_PRECOX_16157515385095809645)],
        &[(0b11010, &ENTRY_PRECUNEUS_2232807234398123688)],
        &[(0b11010, &ENTRY_PREDIAL_13314408220157784404)],
        &[(0b11010, &ENTRY_PREDIALIST_15938835210648844562)],
        &[(0b11010, &ENTRY_PREDIALITY_5941457168149043947)],
        &[(0b11010, &ENTRY_PREDIALS_13874920445884966698)],
        &[(0b11010, &ENTRY_PREESOPHAGEAL_7806252650760260205)],
        &[(0b11010, &ENTRY_PREFECTORIAL_12394552410147263896)],
        &[(0b11010, &ENTRY_PREFLORATION_11469641643312189954)],
        &[(0b11010, &ENTRY_PREFOLIATION_17171347073332349592)],
        &[(0b11010, &ENTRY_PREHALLUX_4969284544099274299)],
        &[(0b11010, &ENTRY_PRELABRUM_4394969735839137776)],
        &[(0b11010, &ENTRY_PRELECT_12537605063468335740)],
        &[(0b11010, &ENTRY_PRELECTED_17531016903900240455)],
        &[(0b11010, &ENTRY_PRELECTING_17733481734284410679)],
        &[(0b11010, &ENTRY_PRELECTION_14375165505479018006)],
        &[(0b11010, &ENTRY_PRELECTOR_16845719004040241611)],
        &[(0b11010, &ENTRY_PRELECTORSHIP_13792769749923826474)],
        &[(0b11010, &ENTRY_PRELECTRESS_5401088119304407518)],
        &[(0b11010, &ENTRY_PRELECTS_11650422889665953253)],
        &[(0b11010, &ENTRY_PRELUDIUM_10948679295576237674)],
        &[(0b11010, &ENTRY_PREMAXILLA_1949932614025975842)],
        &[(0b11010, &ENTRY_PREMUNIRE_6858216713782981118)],
        &[(0b11010, &ENTRY_PRENARIAL_260763454177661493)],
        &[(0b11010, &ENTRY_PRENEURAL_2408211185451005975)],
        &[(0b11010, &ENTRY_PRENOMINA_10767320086992242477)],
        &[(0b11010, &ENTRY_PRENOMINAL_13090458952010105722)],
        &[(0b11010, &ENTRY_PREOPERCULUM_14063888562450517256)],
        &[(0b11010, &ENTRY_PREPOSITOR_10063403644988472815)],
        &[(0b11010, &ENTRY_PREPOSITURE_4560239659829395865)],
        &[(0b11010, &ENTRY_PREPOSTER_5492394426366092278)],
        &[(0b11010, &ENTRY_PREPOSTOR_11151951142384506524)],
        &[(0b11010, &ENTRY_PREPOSTORS_7492263855684321754)],
        &[(0b11010, &ENTRY_PREPUBIS_1427267276575788983)],
        &[(0b11010, &ENTRY_PRESCUTUM_4847968595911667425)],
        &[(0b11010, &ENTRY_PRESPHENOID_4021931112345182287)],
        &[(0b11010, &ENTRY_PRESTERNAL_15812473893616823077)],
        &[(0b11010, &ENTRY_PRESTERNUM_1763363816928245465)],
        &[(0b11010, &ENTRY_PRESTOMIUM_16214618765076520281)],
        &[(0b11010, &ENTRY_PRESYSTOLIC_9748851267145215677)],
        &[(0b11010, &ENTRY_PRETAXATION_8079989165281713211)],
        &[(0b11010, &ENTRY_PRETEXTA_13846622072471023683)],
        &[(0b11010, &ENTRY_PRETEXTAE_10204336454667170862)],
        &[(0b11010, &ENTRY_PRETORIAL_15378699772955129270)],
        &[(0b11010, &ENTRY_PRETORIANS_6215048104690331583)],
        &[(0b11010, &ENTRY_PRETORIUM_14398242596704932612)],
        &[(0b11010, &ENTRY_PRETORIUS_5267977306289147499)],
        &[(0b11010, &ENTRY_PRETORSHIP_6874769297580857439)],
        &[(0b11010, &ENTRY_PREZYGAPOPHYSIS_12276661304999283736)],
    ],
    range: 3..=12,
};

static VARS_PRAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRAC_CHILDREN),
    value: None,
};

pub static VARS_PRAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ticed"),
        dictgen::InsensitiveStr::Ascii("ticer"),
        dictgen::InsensitiveStr::Ascii("ticers"),
        dictgen::InsensitiveStr::Ascii("ticing"),
        dictgen::InsensitiveStr::Ascii("tiser"),
        dictgen::InsensitiveStr::Ascii("tisers"),
    ],
    values: &[
        &[(0b01001, &ENTRY_PRACTICED_14764358740174771780)],
        &[(0b00001, &ENTRY_PRACTICER_1604829236283350937)],
        &[(0b00001, &ENTRY_PRACTICERS_11781048523398293872)],
        &[(0b01001, &ENTRY_PRACTICING_14301958615475402676)],
        &[(0b11010, &ENTRY_PRACTICER_1604829236283350937)],
        &[(0b11010, &ENTRY_PRACTICERS_11781048523398293872)],
    ],
    range: 5..=6,
};

static VARS_PO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PO_CHILDREN),
    value: None,
};

static VARS_PO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_POE_NODE),
    None,
    Some(&VARS_POG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_POL_NODE),
    Some(&VARS_POM_NODE),
    None,
    None,
    Some(&VARS_POP_NODE),
    None,
    Some(&VARS_POR_NODE),
    Some(&VARS_POS_NODE),
    Some(&VARS_POT_NODE),
    Some(&VARS_POU_NODE),
    None,
    Some(&VARS_POW_NODE),
    None,
    None,
    None,
];

static VARS_POW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POW_CHILDREN),
    value: None,
};

pub static VARS_POW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("derisation"),
        dictgen::InsensitiveStr::Ascii("derisations"),
        dictgen::InsensitiveStr::Ascii("derise"),
        dictgen::InsensitiveStr::Ascii("deriser"),
        dictgen::InsensitiveStr::Ascii("derisers"),
        dictgen::InsensitiveStr::Ascii("derises"),
        dictgen::InsensitiveStr::Ascii("derization"),
        dictgen::InsensitiveStr::Ascii("derizations"),
        dictgen::InsensitiveStr::Ascii("derize"),
        dictgen::InsensitiveStr::Ascii("derizer"),
        dictgen::InsensitiveStr::Ascii("derizers"),
        dictgen::InsensitiveStr::Ascii("derizes"),
        dictgen::InsensitiveStr::Ascii("ellise"),
        dictgen::InsensitiveStr::Ascii("ellised"),
        dictgen::InsensitiveStr::Ascii("ellises"),
        dictgen::InsensitiveStr::Ascii("ellising"),
        dictgen::InsensitiveStr::Ascii("ellize"),
        dictgen::InsensitiveStr::Ascii("ellized"),
        dictgen::InsensitiveStr::Ascii("ellizes"),
        dictgen::InsensitiveStr::Ascii("ellizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POWDERIZATION_10139052710323629052)],
        &[(0b10010, &ENTRY_POWDERIZATIONS_3928705133701495130)],
        &[(0b10010, &ENTRY_POWDERIZE_8922790541318187108)],
        &[(0b10010, &ENTRY_POWDERIZER_15656006136737054867)],
        &[(0b10010, &ENTRY_POWDERIZERS_16351372668298434346)],
        &[(0b10010, &ENTRY_POWDERIZES_13417898852536093227)],
        &[(0b01001, &ENTRY_POWDERIZATION_10139052710323629052)],
        &[(0b01001, &ENTRY_POWDERIZATIONS_3928705133701495130)],
        &[(0b01001, &ENTRY_POWDERIZE_8922790541318187108)],
        &[(0b01001, &ENTRY_POWDERIZER_15656006136737054867)],
        &[(0b01001, &ENTRY_POWDERIZERS_16351372668298434346)],
        &[(0b01001, &ENTRY_POWDERIZES_13417898852536093227)],
        &[(0b10010, &ENTRY_POWELLIZE_6906774516859375716)],
        &[(0b10010, &ENTRY_POWELLIZED_6166230388698204716)],
        &[(0b10010, &ENTRY_POWELLIZES_512498962386922850)],
        &[(0b10010, &ENTRY_POWELLIZING_538575818245718275)],
        &[(0b01001, &ENTRY_POWELLIZE_6906774516859375716)],
        &[(0b01001, &ENTRY_POWELLIZED_6166230388698204716)],
        &[(0b01001, &ENTRY_POWELLIZES_512498962386922850)],
        &[(0b01001, &ENTRY_POWELLIZING_538575818245718275)],
    ],
    range: 6..=11,
};

static VARS_POU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POU_CHILDREN),
    value: None,
};

pub static VARS_POU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("der"),
        dictgen::InsensitiveStr::Ascii("ders"),
        dictgen::InsensitiveStr::Ascii("dre"),
        dictgen::InsensitiveStr::Ascii("dres"),
        dictgen::InsensitiveStr::Ascii("lder"),
        dictgen::InsensitiveStr::Ascii("lders"),
        dictgen::InsensitiveStr::Ascii("ldre"),
        dictgen::InsensitiveStr::Ascii("ldres"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("ringly"),
    ],
    values: &[
        &[(0b00001, &ENTRY_POUDER_14484726764560419907)],
        &[(0b00001, &ENTRY_POUDERS_12605831179529023475)],
        &[(0b11010, &ENTRY_POUDER_14484726764560419907)],
        &[(0b11010, &ENTRY_POUDERS_12605831179529023475)],
        &[(0b00001, &ENTRY_POULDER_5243886849214829605)],
        &[(0b00001, &ENTRY_POULDERS_17859768566291438567)],
        &[(0b11010, &ENTRY_POULDER_5243886849214829605)],
        &[(0b11010, &ENTRY_POULDERS_17859768566291438567)],
        &[(0b11010, &ENTRY_PORER_2873682223884239996)],
        &[(0b11010, &ENTRY_PORERS_4082508852567391444)],
        &[(0b11010, &ENTRY_PORINGLY_5338555285588891229)],
    ],
    range: 3..=6,
};

static VARS_POT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POT_CHILDREN),
    value: None,
};

pub static VARS_POT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entialisation"),
        dictgen::InsensitiveStr::Ascii("entialisations"),
        dictgen::InsensitiveStr::Ascii("entialise"),
        dictgen::InsensitiveStr::Ascii("entialises"),
        dictgen::InsensitiveStr::Ascii("entialization"),
        dictgen::InsensitiveStr::Ascii("entializations"),
        dictgen::InsensitiveStr::Ascii("entialize"),
        dictgen::InsensitiveStr::Ascii("entializes"),
        dictgen::InsensitiveStr::Ascii("entise"),
        dictgen::InsensitiveStr::Ascii("entised"),
        dictgen::InsensitiveStr::Ascii("entises"),
        dictgen::InsensitiveStr::Ascii("entising"),
        dictgen::InsensitiveStr::Ascii("entize"),
        dictgen::InsensitiveStr::Ascii("entized"),
        dictgen::InsensitiveStr::Ascii("entizes"),
        dictgen::InsensitiveStr::Ascii("entizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POTENTIALIZATION_14393801122557379251)],
        &[(0b10010, &ENTRY_POTENTIALIZATIONS_7148347553977205280)],
        &[(0b10010, &ENTRY_POTENTIALIZE_18360475252961479174)],
        &[(0b10010, &ENTRY_POTENTIALIZES_636727104111977105)],
        &[(0b01001, &ENTRY_POTENTIALIZATION_14393801122557379251)],
        &[(0b01001, &ENTRY_POTENTIALIZATIONS_7148347553977205280)],
        &[(0b01001, &ENTRY_POTENTIALIZE_18360475252961479174)],
        &[(0b01001, &ENTRY_POTENTIALIZES_636727104111977105)],
        &[(0b10010, &ENTRY_POTENTIZE_13964196851888528627)],
        &[(0b10010, &ENTRY_POTENTIZED_1612875680521039571)],
        &[(0b10010, &ENTRY_POTENTIZES_2878093835262550941)],
        &[(0b10010, &ENTRY_POTENTIZING_2786016681800986152)],
        &[(0b01001, &ENTRY_POTENTIZE_13964196851888528627)],
        &[(0b01001, &ENTRY_POTENTIZED_1612875680521039571)],
        &[(0b01001, &ENTRY_POTENTIZES_2878093835262550941)],
        &[(0b01001, &ENTRY_POTENTIZING_2786016681800986152)],
    ],
    range: 6..=14,
};

static VARS_POS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POS_CHILDREN),
    value: None,
};

pub static VARS_POS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itivise"),
        dictgen::InsensitiveStr::Ascii("itivises"),
        dictgen::InsensitiveStr::Ascii("itivize"),
        dictgen::InsensitiveStr::Ascii("itivizes"),
        dictgen::InsensitiveStr::Ascii("tcaecal"),
        dictgen::InsensitiveStr::Ascii("tcecal"),
        dictgen::InsensitiveStr::Ascii("tcenal"),
        dictgen::InsensitiveStr::Ascii("tcoenal"),
        dictgen::InsensitiveStr::Ascii("terise"),
        dictgen::InsensitiveStr::Ascii("terises"),
        dictgen::InsensitiveStr::Ascii("terize"),
        dictgen::InsensitiveStr::Ascii("terizes"),
        dictgen::InsensitiveStr::Ascii("tfetal"),
        dictgen::InsensitiveStr::Ascii("tfoetal"),
        dictgen::InsensitiveStr::Ascii("tmediaeval"),
        dictgen::InsensitiveStr::Ascii("tmedieval"),
        dictgen::InsensitiveStr::Ascii("tsynchronisation"),
        dictgen::InsensitiveStr::Ascii("tsynchronization"),
        dictgen::InsensitiveStr::Ascii("turise"),
        dictgen::InsensitiveStr::Ascii("turised"),
        dictgen::InsensitiveStr::Ascii("turises"),
        dictgen::InsensitiveStr::Ascii("turising"),
        dictgen::InsensitiveStr::Ascii("turize"),
        dictgen::InsensitiveStr::Ascii("turized"),
        dictgen::InsensitiveStr::Ascii("turizes"),
        dictgen::InsensitiveStr::Ascii("turizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POSITIVIZE_2787313673514904195)],
        &[(0b10010, &ENTRY_POSITIVIZES_14296934196287559541)],
        &[(0b01001, &ENTRY_POSITIVIZE_2787313673514904195)],
        &[(0b01001, &ENTRY_POSITIVIZES_14296934196287559541)],
        &[(0b11010, &ENTRY_POSTCECAL_5697546375355169434)],
        &[(0b00001, &ENTRY_POSTCECAL_5697546375355169434)],
        &[(0b00001, &ENTRY_POSTCENAL_18321668788413423675)],
        &[(0b11010, &ENTRY_POSTCENAL_18321668788413423675)],
        &[(0b10010, &ENTRY_POSTERIZE_10675222155169741892)],
        &[(0b10010, &ENTRY_POSTERIZES_2395982070613751126)],
        &[(0b01001, &ENTRY_POSTERIZE_10675222155169741892)],
        &[(0b01001, &ENTRY_POSTERIZES_2395982070613751126)],
        &[(0b00001, &ENTRY_POSTFETAL_447021447482960445)],
        &[(0b11010, &ENTRY_POSTFETAL_447021447482960445)],
        &[(0b11010, &ENTRY_POSTMEDIEVAL_8669201851324592094)],
        &[(0b00001, &ENTRY_POSTMEDIEVAL_8669201851324592094)],
        &[(0b10010, &ENTRY_POSTSYNCHRONIZATION_8787900960494278765)],
        &[(0b01001, &ENTRY_POSTSYNCHRONIZATION_8787900960494278765)],
        &[(0b10010, &ENTRY_POSTURIZE_2373561399793969964)],
        &[(0b10010, &ENTRY_POSTURIZED_1855269915432760164)],
        &[(0b10010, &ENTRY_POSTURIZES_22978895906010729)],
        &[(0b10010, &ENTRY_POSTURIZING_7099554861688894034)],
        &[(0b01001, &ENTRY_POSTURIZE_2373561399793969964)],
        &[(0b01001, &ENTRY_POSTURIZED_1855269915432760164)],
        &[(0b01001, &ENTRY_POSTURIZES_22978895906010729)],
        &[(0b01001, &ENTRY_POSTURIZING_7099554861688894034)],
    ],
    range: 6..=16,
};

static VARS_POR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POR_CHILDREN),
    value: None,
};

pub static VARS_POR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("celainisation"),
        dictgen::InsensitiveStr::Ascii("celainisations"),
        dictgen::InsensitiveStr::Ascii("celainise"),
        dictgen::InsensitiveStr::Ascii("celainised"),
        dictgen::InsensitiveStr::Ascii("celainises"),
        dictgen::InsensitiveStr::Ascii("celainising"),
        dictgen::InsensitiveStr::Ascii("celainization"),
        dictgen::InsensitiveStr::Ascii("celainizations"),
        dictgen::InsensitiveStr::Ascii("celainize"),
        dictgen::InsensitiveStr::Ascii("celainized"),
        dictgen::InsensitiveStr::Ascii("celainizes"),
        dictgen::InsensitiveStr::Ascii("celainizing"),
        dictgen::InsensitiveStr::Ascii("cellanise"),
        dictgen::InsensitiveStr::Ascii("cellanised"),
        dictgen::InsensitiveStr::Ascii("cellanises"),
        dictgen::InsensitiveStr::Ascii("cellanising"),
        dictgen::InsensitiveStr::Ascii("cellanize"),
        dictgen::InsensitiveStr::Ascii("cellanized"),
        dictgen::InsensitiveStr::Ascii("cellanizes"),
        dictgen::InsensitiveStr::Ascii("cellanizing"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("ingly"),
        dictgen::InsensitiveStr::Ascii("phyrisation"),
        dictgen::InsensitiveStr::Ascii("phyrization"),
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("tionise"),
        dictgen::InsensitiveStr::Ascii("tionises"),
        dictgen::InsensitiveStr::Ascii("tionize"),
        dictgen::InsensitiveStr::Ascii("tionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PORCELAINIZATION_7970284653006774312)],
        &[(0b10010, &ENTRY_PORCELAINIZATIONS_14043183736562241078)],
        &[(0b10010, &ENTRY_PORCELAINIZE_15224248540476215268)],
        &[(0b10010, &ENTRY_PORCELAINIZED_17721995023351100286)],
        &[(0b10010, &ENTRY_PORCELAINIZES_15383829878492153993)],
        &[(0b10010, &ENTRY_PORCELAINIZING_6068406593577816117)],
        &[(0b01001, &ENTRY_PORCELAINIZATION_7970284653006774312)],
        &[(0b01001, &ENTRY_PORCELAINIZATIONS_14043183736562241078)],
        &[(0b01001, &ENTRY_PORCELAINIZE_15224248540476215268)],
        &[(0b01001, &ENTRY_PORCELAINIZED_17721995023351100286)],
        &[(0b01001, &ENTRY_PORCELAINIZES_15383829878492153993)],
        &[(0b01001, &ENTRY_PORCELAINIZING_6068406593577816117)],
        &[(0b10010, &ENTRY_PORCELLANIZE_9889734704487954397)],
        &[(0b10010, &ENTRY_PORCELLANIZED_1602184418072826370)],
        &[(0b10010, &ENTRY_PORCELLANIZES_11959737780523109755)],
        &[(0b10010, &ENTRY_PORCELLANIZING_72705707685647408)],
        &[(0b01001, &ENTRY_PORCELLANIZE_9889734704487954397)],
        &[(0b01001, &ENTRY_PORCELLANIZED_1602184418072826370)],
        &[(0b01001, &ENTRY_PORCELLANIZES_11959737780523109755)],
        &[(0b01001, &ENTRY_PORCELLANIZING_72705707685647408)],
        &[(0b00001, &ENTRY_PORER_2873682223884239996)],
        &[(0b00001, &ENTRY_PORERS_4082508852567391444)],
        &[(0b00001, &ENTRY_PORINGLY_5338555285588891229)],
        &[(0b10010, &ENTRY_PORPHYRIZATION_1148382602187520647)],
        &[(0b01001, &ENTRY_PORPHYRIZATION_1148382602187520647)],
        &[(0b11010, &ENTRY_PORTE_7184144057547184883)],
        &[(0b00001, &ENTRY_PORTE_7184144057547184883)],
        &[(0b10010, &ENTRY_PORTIONIZE_7745054283647390462)],
        &[(0b10010, &ENTRY_PORTIONIZES_14892365590304527286)],
        &[(0b01001, &ENTRY_PORTIONIZE_7745054283647390462)],
        &[(0b01001, &ENTRY_PORTIONIZES_14892365590304527286)],
    ],
    range: 2..=14,
};

static VARS_POP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POP_CHILDREN),
    value: None,
};

pub static VARS_POP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("litaeal"),
        dictgen::InsensitiveStr::Ascii("liteal"),
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularisations"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularised"),
        dictgen::InsensitiveStr::Ascii("ulariser"),
        dictgen::InsensitiveStr::Ascii("ularisers"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularising"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularizations"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularized"),
        dictgen::InsensitiveStr::Ascii("ularizer"),
        dictgen::InsensitiveStr::Ascii("ularizers"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("ularizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_POPLITEAL_9036243440649577224)],
        &[(0b00001, &ENTRY_POPLITEAL_9036243440649577224)],
        &[(0b10010, &ENTRY_POPULARIZATION_4319386853038418661)],
        &[(0b10010, &ENTRY_POPULARIZATIONS_9101849244962729450)],
        &[(0b10010, &ENTRY_POPULARIZE_11338007415870421983)],
        &[(0b10010, &ENTRY_POPULARIZED_10236116886713392471)],
        &[(0b10010, &ENTRY_POPULARIZER_3100157993575081442)],
        &[(0b10010, &ENTRY_POPULARIZERS_7507780986550043141)],
        &[(0b10010, &ENTRY_POPULARIZES_14323192839718770214)],
        &[(0b10010, &ENTRY_POPULARIZING_12963060727527671938)],
        &[(0b01001, &ENTRY_POPULARIZATION_4319386853038418661)],
        &[(0b01001, &ENTRY_POPULARIZATIONS_9101849244962729450)],
        &[(0b01001, &ENTRY_POPULARIZE_11338007415870421983)],
        &[(0b01001, &ENTRY_POPULARIZED_10236116886713392471)],
        &[(0b01001, &ENTRY_POPULARIZER_3100157993575081442)],
        &[(0b01001, &ENTRY_POPULARIZERS_7507780986550043141)],
        &[(0b01001, &ENTRY_POPULARIZES_14323192839718770214)],
        &[(0b01001, &ENTRY_POPULARIZING_12963060727527671938)],
    ],
    range: 6..=12,
};

static VARS_POM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POM_CHILDREN),
    value: None,
};

pub static VARS_POM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erium"),
        dictgen::InsensitiveStr::Ascii("mae"),
        dictgen::InsensitiveStr::Ascii("me"),
        dictgen::InsensitiveStr::Ascii("meled"),
        dictgen::InsensitiveStr::Ascii("meling"),
        dictgen::InsensitiveStr::Ascii("melled"),
        dictgen::InsensitiveStr::Ascii("melling"),
        dictgen::InsensitiveStr::Ascii("oerium"),
    ],
    values: &[
        &[(0b00001, &ENTRY_POMERIUM_16734132116216610483)],
        &[(0b11010, &ENTRY_POMME_1392041379995082220)],
        &[(0b00001, &ENTRY_POMME_1392041379995082220)],
        &[(0b00001, &ENTRY_POMMELED_12392540602238287482)],
        &[(0b00001, &ENTRY_POMMELING_9892304044489697369)],
        &[(0b11010, &ENTRY_POMMELED_12392540602238287482)],
        &[(0b11010, &ENTRY_POMMELING_9892304044489697369)],
        &[(0b11010, &ENTRY_POMERIUM_16734132116216610483)],
    ],
    range: 2..=7,
};

static VARS_POL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_POL_CHILDREN),
    value: None,
};

static VARS_POL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_POLA_NODE),
    None,
    None,
    None,
    Some(&VARS_POLE_NODE),
    None,
    None,
    None,
    Some(&VARS_POLI_NODE),
    None,
    None,
    Some(&VARS_POLL_NODE),
    None,
    None,
    Some(&VARS_POLO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_POLY_NODE),
    None,
];

static VARS_POLY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POLY_CHILDREN),
    value: None,
};

pub static VARS_POLY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("chaetous"),
        dictgen::InsensitiveStr::Ascii("chetous"),
        dictgen::InsensitiveStr::Ascii("chromatise"),
        dictgen::InsensitiveStr::Ascii("chromatises"),
        dictgen::InsensitiveStr::Ascii("chromatize"),
        dictgen::InsensitiveStr::Ascii("chromatizes"),
        dictgen::InsensitiveStr::Ascii("chromise"),
        dictgen::InsensitiveStr::Ascii("chromises"),
        dictgen::InsensitiveStr::Ascii("chromize"),
        dictgen::InsensitiveStr::Ascii("chromizes"),
        dictgen::InsensitiveStr::Ascii("cythaemia"),
        dictgen::InsensitiveStr::Ascii("cythaemias"),
        dictgen::InsensitiveStr::Ascii("cythaemic"),
        dictgen::InsensitiveStr::Ascii("cythemia"),
        dictgen::InsensitiveStr::Ascii("cythemias"),
        dictgen::InsensitiveStr::Ascii("cythemic"),
        dictgen::InsensitiveStr::Ascii("daemonism"),
        dictgen::InsensitiveStr::Ascii("daemonisms"),
        dictgen::InsensitiveStr::Ascii("daemonist"),
        dictgen::InsensitiveStr::Ascii("demonism"),
        dictgen::InsensitiveStr::Ascii("demonisms"),
        dictgen::InsensitiveStr::Ascii("demonist"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("estrous"),
        dictgen::InsensitiveStr::Ascii("gamise"),
        dictgen::InsensitiveStr::Ascii("gamises"),
        dictgen::InsensitiveStr::Ascii("gamize"),
        dictgen::InsensitiveStr::Ascii("gamizes"),
        dictgen::InsensitiveStr::Ascii("haemia"),
        dictgen::InsensitiveStr::Ascii("haemic"),
        dictgen::InsensitiveStr::Ascii("hemia"),
        dictgen::InsensitiveStr::Ascii("hemic"),
        dictgen::InsensitiveStr::Ascii("merisation"),
        dictgen::InsensitiveStr::Ascii("merisations"),
        dictgen::InsensitiveStr::Ascii("merise"),
        dictgen::InsensitiveStr::Ascii("merised"),
        dictgen::InsensitiveStr::Ascii("merises"),
        dictgen::InsensitiveStr::Ascii("merising"),
        dictgen::InsensitiveStr::Ascii("merization"),
        dictgen::InsensitiveStr::Ascii("merizations"),
        dictgen::InsensitiveStr::Ascii("merize"),
        dictgen::InsensitiveStr::Ascii("merized"),
        dictgen::InsensitiveStr::Ascii("merizes"),
        dictgen::InsensitiveStr::Ascii("merizing"),
        dictgen::InsensitiveStr::Ascii("oestrous"),
        dictgen::InsensitiveStr::Ascii("pnea"),
        dictgen::InsensitiveStr::Ascii("pneic"),
        dictgen::InsensitiveStr::Ascii("pnoea"),
        dictgen::InsensitiveStr::Ascii("pnoeic"),
        dictgen::InsensitiveStr::Ascii("sulphurisation"),
        dictgen::InsensitiveStr::Ascii("sulphurisations"),
        dictgen::InsensitiveStr::Ascii("sulphurization"),
        dictgen::InsensitiveStr::Ascii("sulphurizations"),
        dictgen::InsensitiveStr::Ascii("tetrafluorethylene"),
        dictgen::InsensitiveStr::Ascii("tetrafluorethylenes"),
        dictgen::InsensitiveStr::Ascii("tetrafluoroethylene"),
        dictgen::InsensitiveStr::Ascii("tetrafluoroethylenes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_POLYEMIA_17027501052390389926)],
        &[(0b11010, &ENTRY_POLYEMIC_16404653103485719307)],
        &[(0b11010, &ENTRY_POLYCHETOUS_11825929076734596407)],
        &[(0b00001, &ENTRY_POLYCHETOUS_11825929076734596407)],
        &[(0b10010, &ENTRY_POLYCHROMATIZE_10052020194151377560)],
        &[(0b10010, &ENTRY_POLYCHROMATIZES_14641652646809838991)],
        &[(0b01001, &ENTRY_POLYCHROMATIZE_10052020194151377560)],
        &[(0b01001, &ENTRY_POLYCHROMATIZES_14641652646809838991)],
        &[(0b10010, &ENTRY_POLYCHROMIZE_5715117656342861961)],
        &[(0b10010, &ENTRY_POLYCHROMIZES_14814470113356117191)],
        &[(0b01001, &ENTRY_POLYCHROMIZE_5715117656342861961)],
        &[(0b01001, &ENTRY_POLYCHROMIZES_14814470113356117191)],
        &[(0b11010, &ENTRY_POLYCYTHEMIA_7260966493605108921)],
        &[(0b11010, &ENTRY_POLYCYTHEMIAS_157883751608332886)],
        &[(0b11010, &ENTRY_POLYCYTHEMIC_12712383842754585769)],
        &[(0b10001, &ENTRY_POLYCYTHEMIA_7260966493605108921)],
        &[(0b10001, &ENTRY_POLYCYTHEMIAS_157883751608332886)],
        &[(0b10001, &ENTRY_POLYCYTHEMIC_12712383842754585769)],
        &[(0b11010, &ENTRY_POLYDEMONISM_7317742690433096316)],
        &[(0b11010, &ENTRY_POLYDEMONISMS_1302003455364237571)],
        &[(0b11010, &ENTRY_POLYDEMONIST_3735364090533159436)],
        &[(0b00001, &ENTRY_POLYDEMONISM_7317742690433096316)],
        &[(0b00001, &ENTRY_POLYDEMONISMS_1302003455364237571)],
        &[(0b00001, &ENTRY_POLYDEMONIST_3735364090533159436)],
        &[(0b00001, &ENTRY_POLYEMIA_17027501052390389926)],
        &[(0b00001, &ENTRY_POLYEMIC_16404653103485719307)],
        &[(0b00001, &ENTRY_POLYESTROUS_17172156309762664707)],
        &[(0b10010, &ENTRY_POLYGAMIZE_12078625945995610836)],
        &[(0b10010, &ENTRY_POLYGAMIZES_13516060080821320556)],
        &[(0b01001, &ENTRY_POLYGAMIZE_12078625945995610836)],
        &[(0b01001, &ENTRY_POLYGAMIZES_13516060080821320556)],
        &[(0b11010, &ENTRY_POLYHEMIA_974497438142146493)],
        &[(0b11010, &ENTRY_POLYHEMIC_12649506891350992052)],
        &[(0b00001, &ENTRY_POLYHEMIA_974497438142146493)],
        &[(0b00001, &ENTRY_POLYHEMIC_12649506891350992052)],
        &[(0b10010, &ENTRY_POLYMERIZATION_1464478082413309887)],
        &[(0b10010, &ENTRY_POLYMERIZATIONS_6860899723431207692)],
        &[(0b10010, &ENTRY_POLYMERIZE_6708036056371064979)],
        &[(0b10010, &ENTRY_POLYMERIZED_13422662021131191207)],
        &[(0b10010, &ENTRY_POLYMERIZES_2934787247449201471)],
        &[(0b10010, &ENTRY_POLYMERIZING_4276224557971404133)],
        &[(0b01001, &ENTRY_POLYMERIZATION_1464478082413309887)],
        &[(0b01001, &ENTRY_POLYMERIZATIONS_6860899723431207692)],
        &[(0b01001, &ENTRY_POLYMERIZE_6708036056371064979)],
        &[(0b01001, &ENTRY_POLYMERIZED_13422662021131191207)],
        &[(0b01001, &ENTRY_POLYMERIZES_2934787247449201471)],
        &[(0b01001, &ENTRY_POLYMERIZING_4276224557971404133)],
        &[(0b11010, &ENTRY_POLYESTROUS_17172156309762664707)],
        &[(0b00001, &ENTRY_POLYPNEA_6328008602290527604)],
        &[(0b00001, &ENTRY_POLYPNEIC_16775313163795534836)],
        &[(0b11010, &ENTRY_POLYPNEA_6328008602290527604)],
        &[(0b11010, &ENTRY_POLYPNEIC_16775313163795534836)],
        &[(0b10010, &ENTRY_POLYSULPHURIZATION_11461377658804684698)],
        &[(0b10010, &ENTRY_POLYSULPHURIZATIONS_7327023976815066572)],
        &[(0b01001, &ENTRY_POLYSULPHURIZATION_11461377658804684698)],
        &[(0b01001, &ENTRY_POLYSULPHURIZATIONS_7327023976815066572)],
        &[(0b00001, &ENTRY_POLYTETRAFLUORETHYLENE_2112133591938710091)],
        &[(0b00001, &ENTRY_POLYTETRAFLUORETHYLENES_6710798717502830509)],
        &[(0b11010, &ENTRY_POLYTETRAFLUORETHYLENE_2112133591938710091)],
        &[(0b11010, &ENTRY_POLYTETRAFLUORETHYLENES_6710798717502830509)],
    ],
    range: 4..=20,
};

static VARS_POLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POLO_CHILDREN),
    value: None,
};

pub static VARS_POLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POLONIZATION_8949080039895919308)],
        &[(0b10010, &ENTRY_POLONIZE_5875145906362854820)],
        &[(0b10010, &ENTRY_POLONIZED_600542361713627836)],
        &[(0b10010, &ENTRY_POLONIZES_7283464149215527797)],
        &[(0b10010, &ENTRY_POLONIZING_5285708850960514239)],
        &[(0b01001, &ENTRY_POLONIZATION_8949080039895919308)],
        &[(0b01001, &ENTRY_POLONIZE_5875145906362854820)],
        &[(0b01001, &ENTRY_POLONIZED_600542361713627836)],
        &[(0b01001, &ENTRY_POLONIZES_7283464149215527797)],
        &[(0b01001, &ENTRY_POLONIZING_5285708850960514239)],
    ],
    range: 4..=8,
};

static VARS_POLL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POLL_CHILDREN),
    value: None,
};

pub static VARS_POLL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eniser"),
        dictgen::InsensitiveStr::Ascii("enizer"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inised"),
        dictgen::InsensitiveStr::Ascii("iniser"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inising"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inized"),
        dictgen::InsensitiveStr::Ascii("inizer"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POLLENIZER_6903386018614258437)],
        &[(0b01001, &ENTRY_POLLENIZER_6903386018614258437)],
        &[(0b10010, &ENTRY_POLLINIZE_2202943414429288102)],
        &[(0b10010, &ENTRY_POLLINIZED_9141671454408181534)],
        &[(0b10010, &ENTRY_POLLINIZER_17051026365097333805)],
        &[(0b10010, &ENTRY_POLLINIZES_12439282934086792068)],
        &[(0b10010, &ENTRY_POLLINIZING_17154378888329023435)],
        &[(0b01001, &ENTRY_POLLINIZE_2202943414429288102)],
        &[(0b01001, &ENTRY_POLLINIZED_9141671454408181534)],
        &[(0b01001, &ENTRY_POLLINIZER_17051026365097333805)],
        &[(0b01001, &ENTRY_POLLINIZES_12439282934086792068)],
        &[(0b01001, &ENTRY_POLLINIZING_17154378888329023435)],
    ],
    range: 5..=7,
};

static VARS_POLI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POLI_CHILDREN),
    value: None,
};

pub static VARS_POLI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cise"),
        dictgen::InsensitiveStr::Ascii("ciser"),
        dictgen::InsensitiveStr::Ascii("cisers"),
        dictgen::InsensitiveStr::Ascii("cises"),
        dictgen::InsensitiveStr::Ascii("cize"),
        dictgen::InsensitiveStr::Ascii("cizer"),
        dictgen::InsensitiveStr::Ascii("cizers"),
        dictgen::InsensitiveStr::Ascii("cizes"),
        dictgen::InsensitiveStr::Ascii("encephalitis"),
        dictgen::InsensitiveStr::Ascii("encephalomyelitis"),
        dictgen::InsensitiveStr::Ascii("oencephalitis"),
        dictgen::InsensitiveStr::Ascii("oencephalomyelitis"),
        dictgen::InsensitiveStr::Ascii("ticalise"),
        dictgen::InsensitiveStr::Ascii("ticalises"),
        dictgen::InsensitiveStr::Ascii("ticalize"),
        dictgen::InsensitiveStr::Ascii("ticalizes"),
        dictgen::InsensitiveStr::Ascii("ticisation"),
        dictgen::InsensitiveStr::Ascii("ticisations"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticised"),
        dictgen::InsensitiveStr::Ascii("ticiser"),
        dictgen::InsensitiveStr::Ascii("ticisers"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticising"),
        dictgen::InsensitiveStr::Ascii("ticization"),
        dictgen::InsensitiveStr::Ascii("ticizations"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticized"),
        dictgen::InsensitiveStr::Ascii("ticizer"),
        dictgen::InsensitiveStr::Ascii("ticizers"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
        dictgen::InsensitiveStr::Ascii("ticizing"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POLICIZE_6261956984982088948)],
        &[(0b10010, &ENTRY_POLICIZER_11504979841575522568)],
        &[(0b10010, &ENTRY_POLICIZERS_10984675264862024887)],
        &[(0b10010, &ENTRY_POLICIZES_3231780840519708788)],
        &[(0b01001, &ENTRY_POLICIZE_6261956984982088948)],
        &[(0b01001, &ENTRY_POLICIZER_11504979841575522568)],
        &[(0b01001, &ENTRY_POLICIZERS_10984675264862024887)],
        &[(0b01001, &ENTRY_POLICIZES_3231780840519708788)],
        &[(0b00001, &ENTRY_POLIENCEPHALITIS_10355986804039942235)],
        &[(0b00001, &ENTRY_POLIENCEPHALOMYELITIS_18175298687506614222)],
        &[(0b11010, &ENTRY_POLIENCEPHALITIS_10355986804039942235)],
        &[(0b11010, &ENTRY_POLIENCEPHALOMYELITIS_18175298687506614222)],
        &[(0b10010, &ENTRY_POLITICALIZE_13546525614092282549)],
        &[(0b10010, &ENTRY_POLITICALIZES_9952299193970370172)],
        &[(0b01001, &ENTRY_POLITICALIZE_13546525614092282549)],
        &[(0b01001, &ENTRY_POLITICALIZES_9952299193970370172)],
        &[(0b10010, &ENTRY_POLITICIZATION_14296189920998092712)],
        &[(0b10010, &ENTRY_POLITICIZATIONS_1624829829441968277)],
        &[(0b10010, &ENTRY_POLITICIZE_14733719891264090605)],
        &[(0b10010, &ENTRY_POLITICIZED_2600843113498243890)],
        &[(0b10010, &ENTRY_POLITICIZER_16483262168673095615)],
        &[(0b10010, &ENTRY_POLITICIZERS_536327452029040996)],
        &[(0b10010, &ENTRY_POLITICIZES_15842748929836601577)],
        &[(0b10010, &ENTRY_POLITICIZING_2582222145866644700)],
        &[(0b01001, &ENTRY_POLITICIZATION_14296189920998092712)],
        &[(0b01001, &ENTRY_POLITICIZATIONS_1624829829441968277)],
        &[(0b01001, &ENTRY_POLITICIZE_14733719891264090605)],
        &[(0b01001, &ENTRY_POLITICIZED_2600843113498243890)],
        &[(0b01001, &ENTRY_POLITICIZER_16483262168673095615)],
        &[(0b01001, &ENTRY_POLITICIZERS_536327452029040996)],
        &[(0b01001, &ENTRY_POLITICIZES_15842748929836601577)],
        &[(0b01001, &ENTRY_POLITICIZING_2582222145866644700)],
        &[(0b10010, &ENTRY_POLITIZE_15643725307730123435)],
        &[(0b10010, &ENTRY_POLITIZES_11960619261098930872)],
        &[(0b01001, &ENTRY_POLITIZE_15643725307730123435)],
        &[(0b01001, &ENTRY_POLITIZES_11960619261098930872)],
    ],
    range: 4..=18,
};

static VARS_POLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POLE_CHILDREN),
    value: None,
};

pub static VARS_POLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("micise"),
        dictgen::InsensitiveStr::Ascii("micised"),
        dictgen::InsensitiveStr::Ascii("micises"),
        dictgen::InsensitiveStr::Ascii("micising"),
        dictgen::InsensitiveStr::Ascii("micize"),
        dictgen::InsensitiveStr::Ascii("micized"),
        dictgen::InsensitiveStr::Ascii("micizes"),
        dictgen::InsensitiveStr::Ascii("micizing"),
        dictgen::InsensitiveStr::Ascii("mise"),
        dictgen::InsensitiveStr::Ascii("mised"),
        dictgen::InsensitiveStr::Ascii("mises"),
        dictgen::InsensitiveStr::Ascii("mising"),
        dictgen::InsensitiveStr::Ascii("mize"),
        dictgen::InsensitiveStr::Ascii("mized"),
        dictgen::InsensitiveStr::Ascii("mizes"),
        dictgen::InsensitiveStr::Ascii("mizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POLEMICIZE_15120423673289782910)],
        &[(0b10010, &ENTRY_POLEMICIZED_5043816132806935047)],
        &[(0b10010, &ENTRY_POLEMICIZES_11323884554859340249)],
        &[(0b10010, &ENTRY_POLEMICIZING_17142821477503800842)],
        &[(0b01001, &ENTRY_POLEMICIZE_15120423673289782910)],
        &[(0b01001, &ENTRY_POLEMICIZED_5043816132806935047)],
        &[(0b01001, &ENTRY_POLEMICIZES_11323884554859340249)],
        &[(0b01001, &ENTRY_POLEMICIZING_17142821477503800842)],
        &[(0b10010, &ENTRY_POLEMIZE_4645054350538789425)],
        &[(0b10010, &ENTRY_POLEMIZED_18177371753176965844)],
        &[(0b10010, &ENTRY_POLEMIZES_4956607855217033028)],
        &[(0b10010, &ENTRY_POLEMIZING_12643115025013767594)],
        &[(0b01001, &ENTRY_POLEMIZE_4645054350538789425)],
        &[(0b01001, &ENTRY_POLEMIZED_18177371753176965844)],
        &[(0b01001, &ENTRY_POLEMIZES_4956607855217033028)],
        &[(0b01001, &ENTRY_POLEMIZING_12643115025013767594)],
    ],
    range: 4..=8,
};

static VARS_POLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POLA_CHILDREN),
    value: None,
};

pub static VARS_POLA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("risabilities"),
        dictgen::InsensitiveStr::Ascii("risability"),
        dictgen::InsensitiveStr::Ascii("risable"),
        dictgen::InsensitiveStr::Ascii("risables"),
        dictgen::InsensitiveStr::Ascii("risation"),
        dictgen::InsensitiveStr::Ascii("risations"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("riser"),
        dictgen::InsensitiveStr::Ascii("risers"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rizabilities"),
        dictgen::InsensitiveStr::Ascii("rizability"),
        dictgen::InsensitiveStr::Ascii("rizable"),
        dictgen::InsensitiveStr::Ascii("rizables"),
        dictgen::InsensitiveStr::Ascii("rization"),
        dictgen::InsensitiveStr::Ascii("rizations"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizer"),
        dictgen::InsensitiveStr::Ascii("rizers"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POLARIZABILITIES_10442898120414601326)],
        &[(0b10010, &ENTRY_POLARIZABILITY_2038012121804259011)],
        &[(0b10010, &ENTRY_POLARIZABLE_18223083191028705666)],
        &[(0b10010, &ENTRY_POLARIZABLES_6205801333281852987)],
        &[(0b10010, &ENTRY_POLARIZATION_6614126062136329693)],
        &[(0b10010, &ENTRY_POLARIZATIONS_5016707483625496334)],
        &[(0b10010, &ENTRY_POLARIZE_6991502646544699233)],
        &[(0b10010, &ENTRY_POLARIZED_4384502108509113795)],
        &[(0b10010, &ENTRY_POLARIZER_216484594834440123)],
        &[(0b10010, &ENTRY_POLARIZERS_17435224860043461879)],
        &[(0b10010, &ENTRY_POLARIZES_8543434351223099952)],
        &[(0b10010, &ENTRY_POLARIZING_5791777031620829770)],
        &[(0b01001, &ENTRY_POLARIZABILITIES_10442898120414601326)],
        &[(0b01001, &ENTRY_POLARIZABILITY_2038012121804259011)],
        &[(0b01001, &ENTRY_POLARIZABLE_18223083191028705666)],
        &[(0b01001, &ENTRY_POLARIZABLES_6205801333281852987)],
        &[(0b01001, &ENTRY_POLARIZATION_6614126062136329693)],
        &[(0b01001, &ENTRY_POLARIZATIONS_5016707483625496334)],
        &[(0b01001, &ENTRY_POLARIZE_6991502646544699233)],
        &[(0b01001, &ENTRY_POLARIZED_4384502108509113795)],
        &[(0b01001, &ENTRY_POLARIZER_216484594834440123)],
        &[(0b01001, &ENTRY_POLARIZERS_17435224860043461879)],
        &[(0b01001, &ENTRY_POLARIZES_8543434351223099952)],
        &[(0b01001, &ENTRY_POLARIZING_5791777031620829770)],
    ],
    range: 4..=12,
};

static VARS_POG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POG_CHILDREN),
    value: None,
};

pub static VARS_POG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("romise"),
        dictgen::InsensitiveStr::Ascii("romises"),
        dictgen::InsensitiveStr::Ascii("romize"),
        dictgen::InsensitiveStr::Ascii("romizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POGROMIZE_15682226993080301613)],
        &[(0b10010, &ENTRY_POGROMIZES_1020547626860892723)],
        &[(0b01001, &ENTRY_POGROMIZE_15682226993080301613)],
        &[(0b01001, &ENTRY_POGROMIZES_1020547626860892723)],
    ],
    range: 6..=7,
};

static VARS_POE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_PE_17043181136692725962)]),
};

pub static VARS_POE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ticisation"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticised"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticising"),
        dictgen::InsensitiveStr::Ascii("ticization"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticized"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
        dictgen::InsensitiveStr::Ascii("ticizing"),
        dictgen::InsensitiveStr::Ascii("tisation"),
        dictgen::InsensitiveStr::Ascii("tisations"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tiser"),
        dictgen::InsensitiveStr::Ascii("tisers"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tization"),
        dictgen::InsensitiveStr::Ascii("tizations"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizer"),
        dictgen::InsensitiveStr::Ascii("tizers"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
        dictgen::InsensitiveStr::Ascii("tling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POETICIZATION_4360595178449589100)],
        &[(0b10010, &ENTRY_POETICIZE_3171830565693860719)],
        &[(0b10010, &ENTRY_POETICIZED_11505730651571650970)],
        &[(0b10010, &ENTRY_POETICIZES_932344514096954986)],
        &[(0b10010, &ENTRY_POETICIZING_2145412927507553207)],
        &[(0b01001, &ENTRY_POETICIZATION_4360595178449589100)],
        &[(0b01001, &ENTRY_POETICIZE_3171830565693860719)],
        &[(0b01001, &ENTRY_POETICIZED_11505730651571650970)],
        &[(0b01001, &ENTRY_POETICIZES_932344514096954986)],
        &[(0b01001, &ENTRY_POETICIZING_2145412927507553207)],
        &[(0b10010, &ENTRY_POETIZATION_15662003063836424254)],
        &[(0b10010, &ENTRY_POETIZATIONS_9001788595381046094)],
        &[(0b10010, &ENTRY_POETIZE_4485886018698886455)],
        &[(0b10010, &ENTRY_POETIZED_10784111762264956661)],
        &[(0b10010, &ENTRY_POETIZER_7035494850642872918)],
        &[(0b10010, &ENTRY_POETIZERS_9898979383342189761)],
        &[(0b10010, &ENTRY_POETIZES_10934814919977679962)],
        &[(0b10010, &ENTRY_POETIZING_14064411681153855919)],
        &[(0b01001, &ENTRY_POETIZATION_15662003063836424254)],
        &[(0b01001, &ENTRY_POETIZATIONS_9001788595381046094)],
        &[(0b01001, &ENTRY_POETIZE_4485886018698886455)],
        &[(0b01001, &ENTRY_POETIZED_10784111762264956661)],
        &[(0b01001, &ENTRY_POETIZER_7035494850642872918)],
        &[(0b01001, &ENTRY_POETIZERS_9898979383342189761)],
        &[(0b01001, &ENTRY_POETIZES_10934814919977679962)],
        &[(0b01001, &ENTRY_POETIZING_14064411681153855919)],
        &[(0b11010, &ENTRY_PETLING_10839442998921882121)],
    ],
    range: 4..=10,
};

static VARS_PL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PL_CHILDREN),
    value: None,
};

static VARS_PL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PLA_NODE),
    None,
    None,
    None,
    Some(&VARS_PLE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PLO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PLU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_PLU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLU_CHILDREN),
    value: None,
};

pub static VARS_PLU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mulae"),
        dictgen::InsensitiveStr::Ascii("mule"),
        dictgen::InsensitiveStr::Ascii("ralisation"),
        dictgen::InsensitiveStr::Ascii("ralisations"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralised"),
        dictgen::InsensitiveStr::Ascii("raliser"),
        dictgen::InsensitiveStr::Ascii("ralisers"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralising"),
        dictgen::InsensitiveStr::Ascii("ralization"),
        dictgen::InsensitiveStr::Ascii("ralizations"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralized"),
        dictgen::InsensitiveStr::Ascii("ralizer"),
        dictgen::InsensitiveStr::Ascii("ralizers"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLUMULE_4648783015281606707)],
        &[(0b00001, &ENTRY_PLUMULE_4648783015281606707)],
        &[(0b10010, &ENTRY_PLURALIZATION_5670946523880574178)],
        &[(0b10010, &ENTRY_PLURALIZATIONS_18269674181224004202)],
        &[(0b10010, &ENTRY_PLURALIZE_11864296364586636944)],
        &[(0b10010, &ENTRY_PLURALIZED_6800060174654023706)],
        &[(0b10010, &ENTRY_PLURALIZER_1150676904940417175)],
        &[(0b10010, &ENTRY_PLURALIZERS_15471907995822956968)],
        &[(0b10010, &ENTRY_PLURALIZES_11096808149614325328)],
        &[(0b10010, &ENTRY_PLURALIZING_11611672548631403517)],
        &[(0b01001, &ENTRY_PLURALIZATION_5670946523880574178)],
        &[(0b01001, &ENTRY_PLURALIZATIONS_18269674181224004202)],
        &[(0b01001, &ENTRY_PLURALIZE_11864296364586636944)],
        &[(0b01001, &ENTRY_PLURALIZED_6800060174654023706)],
        &[(0b01001, &ENTRY_PLURALIZER_1150676904940417175)],
        &[(0b01001, &ENTRY_PLURALIZERS_15471907995822956968)],
        &[(0b01001, &ENTRY_PLURALIZES_11096808149614325328)],
        &[(0b01001, &ENTRY_PLURALIZING_11611672548631403517)],
    ],
    range: 4..=11,
};

static VARS_PLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLO_CHILDREN),
    value: None,
};

pub static VARS_PLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ugh"),
        dictgen::InsensitiveStr::Ascii("ughable"),
        dictgen::InsensitiveStr::Ascii("ughboy"),
        dictgen::InsensitiveStr::Ascii("ughboys"),
        dictgen::InsensitiveStr::Ascii("ughed"),
        dictgen::InsensitiveStr::Ascii("ugher"),
        dictgen::InsensitiveStr::Ascii("ughers"),
        dictgen::InsensitiveStr::Ascii("ughhead"),
        dictgen::InsensitiveStr::Ascii("ughing"),
        dictgen::InsensitiveStr::Ascii("ughman"),
        dictgen::InsensitiveStr::Ascii("ughmen"),
        dictgen::InsensitiveStr::Ascii("ughs"),
        dictgen::InsensitiveStr::Ascii("ughshare"),
        dictgen::InsensitiveStr::Ascii("ughshares"),
        dictgen::InsensitiveStr::Ascii("w"),
        dictgen::InsensitiveStr::Ascii("wable"),
        dictgen::InsensitiveStr::Ascii("wboy"),
        dictgen::InsensitiveStr::Ascii("wboys"),
        dictgen::InsensitiveStr::Ascii("wed"),
        dictgen::InsensitiveStr::Ascii("wer"),
        dictgen::InsensitiveStr::Ascii("wers"),
        dictgen::InsensitiveStr::Ascii("whead"),
        dictgen::InsensitiveStr::Ascii("wing"),
        dictgen::InsensitiveStr::Ascii("wman"),
        dictgen::InsensitiveStr::Ascii("wmen"),
        dictgen::InsensitiveStr::Ascii("ws"),
        dictgen::InsensitiveStr::Ascii("wshare"),
        dictgen::InsensitiveStr::Ascii("wshares"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLOW_5294773589996205415)],
        &[(0b10010, &ENTRY_PLOWABLE_17280767722391212022)],
        &[(0b11010, &ENTRY_PLOWBOY_3950688802796165974)],
        &[(0b11010, &ENTRY_PLOWBOYS_13918215017723803049)],
        &[(0b11010, &ENTRY_PLOWED_9574602430050227983)],
        &[(0b10010, &ENTRY_PLOWER_8745478383312458084)],
        &[(0b10010, &ENTRY_PLOWERS_12302245220185487703)],
        &[(0b11010, &ENTRY_PLOWHEAD_4904472169551678601)],
        &[(0b11010, &ENTRY_PLOWING_17492249086035756049)],
        &[(0b11010, &ENTRY_PLOWMAN_17563255430094623913)],
        &[(0b11010, &ENTRY_PLOWMEN_2445871749264248581)],
        &[(0b11010, &ENTRY_PLOWS_11203227963409601706)],
        &[(0b11010, &ENTRY_PLOWSHARE_951608328770233313)],
        &[(0b11010, &ENTRY_PLOWSHARES_13417439424755185353)],
        &[(0b01001, &ENTRY_PLOW_5294773589996205415)],
        &[(0b01001, &ENTRY_PLOWABLE_17280767722391212022)],
        &[(0b00001, &ENTRY_PLOWBOY_3950688802796165974)],
        &[(0b00001, &ENTRY_PLOWBOYS_13918215017723803049)],
        &[(0b01001, &ENTRY_PLOWED_9574602430050227983)],
        &[(0b01001, &ENTRY_PLOWER_8745478383312458084)],
        &[(0b01001, &ENTRY_PLOWERS_12302245220185487703)],
        &[(0b00001, &ENTRY_PLOWHEAD_4904472169551678601)],
        &[(0b01001, &ENTRY_PLOWING_17492249086035756049)],
        &[(0b01001, &ENTRY_PLOWMAN_17563255430094623913)],
        &[(0b01001, &ENTRY_PLOWMEN_2445871749264248581)],
        &[(0b01001, &ENTRY_PLOWS_11203227963409601706)],
        &[(0b01001, &ENTRY_PLOWSHARE_951608328770233313)],
        &[(0b01001, &ENTRY_PLOWSHARES_13417439424755185353)],
    ],
    range: 1..=9,
};

static VARS_PLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLE_CHILDREN),
    value: None,
};

pub static VARS_PLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("beianisation"),
        dictgen::InsensitiveStr::Ascii("beianise"),
        dictgen::InsensitiveStr::Ascii("beianised"),
        dictgen::InsensitiveStr::Ascii("beianises"),
        dictgen::InsensitiveStr::Ascii("beianising"),
        dictgen::InsensitiveStr::Ascii("beianization"),
        dictgen::InsensitiveStr::Ascii("beianize"),
        dictgen::InsensitiveStr::Ascii("beianized"),
        dictgen::InsensitiveStr::Ascii("beianizes"),
        dictgen::InsensitiveStr::Ascii("beianizing"),
        dictgen::InsensitiveStr::Ascii("uroperitonaeal"),
        dictgen::InsensitiveStr::Ascii("uroperitoneal"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PLEBEIANIZATION_12091869174390175684)],
        &[(0b10010, &ENTRY_PLEBEIANIZE_11877968367262483887)],
        &[(0b10010, &ENTRY_PLEBEIANIZED_3279512410016852495)],
        &[(0b10010, &ENTRY_PLEBEIANIZES_13488763327989099599)],
        &[(0b10010, &ENTRY_PLEBEIANIZING_3295946886737938243)],
        &[(0b01001, &ENTRY_PLEBEIANIZATION_12091869174390175684)],
        &[(0b01001, &ENTRY_PLEBEIANIZE_11877968367262483887)],
        &[(0b01001, &ENTRY_PLEBEIANIZED_3279512410016852495)],
        &[(0b01001, &ENTRY_PLEBEIANIZES_13488763327989099599)],
        &[(0b01001, &ENTRY_PLEBEIANIZING_3295946886737938243)],
        &[(0b11010, &ENTRY_PLEUROPERITONEAL_4698454746375539129)],
        &[(0b00001, &ENTRY_PLEUROPERITONEAL_4698454746375539129)],
    ],
    range: 8..=14,
};

static VARS_PLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PLA_CHILDREN),
    value: None,
};

static VARS_PLA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_PLAC_NODE),
    None,
    None,
    None,
    Some(&VARS_PLAG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PLAN_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_PLAS_NODE),
    Some(&VARS_PLAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PLAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLAT_CHILDREN),
    value: None,
};

pub static VARS_PLAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aea"),
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("inisation"),
        dictgen::InsensitiveStr::Ascii("inisations"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inised"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inising"),
        dictgen::InsensitiveStr::Ascii("inization"),
        dictgen::InsensitiveStr::Ascii("inizations"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inized"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inizing"),
        dictgen::InsensitiveStr::Ascii("itudinisation"),
        dictgen::InsensitiveStr::Ascii("itudinisations"),
        dictgen::InsensitiveStr::Ascii("itudinise"),
        dictgen::InsensitiveStr::Ascii("itudinised"),
        dictgen::InsensitiveStr::Ascii("itudiniser"),
        dictgen::InsensitiveStr::Ascii("itudinises"),
        dictgen::InsensitiveStr::Ascii("itudinising"),
        dictgen::InsensitiveStr::Ascii("itudinization"),
        dictgen::InsensitiveStr::Ascii("itudinizations"),
        dictgen::InsensitiveStr::Ascii("itudinize"),
        dictgen::InsensitiveStr::Ascii("itudinized"),
        dictgen::InsensitiveStr::Ascii("itudinizer"),
        dictgen::InsensitiveStr::Ascii("itudinizes"),
        dictgen::InsensitiveStr::Ascii("itudinizing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniser"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizer"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("ycelian"),
        dictgen::InsensitiveStr::Ascii("ycelous"),
        dictgen::InsensitiveStr::Ascii("ycoelian"),
        dictgen::InsensitiveStr::Ascii("ycoelous"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLATEA_11834704696568479057)],
        &[(0b00001, &ENTRY_PLATEA_11834704696568479057)],
        &[(0b10010, &ENTRY_PLATINIZATION_1083038364602615335)],
        &[(0b10010, &ENTRY_PLATINIZATIONS_1156288939962168369)],
        &[(0b10010, &ENTRY_PLATINIZE_6742218053291606205)],
        &[(0b10010, &ENTRY_PLATINIZED_14868058494774606882)],
        &[(0b10010, &ENTRY_PLATINIZES_2691556545522250539)],
        &[(0b10010, &ENTRY_PLATINIZING_8264599125346829618)],
        &[(0b01001, &ENTRY_PLATINIZATION_1083038364602615335)],
        &[(0b01001, &ENTRY_PLATINIZATIONS_1156288939962168369)],
        &[(0b01001, &ENTRY_PLATINIZE_6742218053291606205)],
        &[(0b01001, &ENTRY_PLATINIZED_14868058494774606882)],
        &[(0b01001, &ENTRY_PLATINIZES_2691556545522250539)],
        &[(0b01001, &ENTRY_PLATINIZING_8264599125346829618)],
        &[(0b10010, &ENTRY_PLATITUDINIZATION_11548882127482737211)],
        &[(0b10010, &ENTRY_PLATITUDINIZATIONS_8947623953157828775)],
        &[(0b10010, &ENTRY_PLATITUDINIZE_5511778463063483337)],
        &[(0b10010, &ENTRY_PLATITUDINIZED_12324616080202347816)],
        &[(0b10010, &ENTRY_PLATITUDINIZER_7798668408381897855)],
        &[(0b10010, &ENTRY_PLATITUDINIZES_13848363114958142428)],
        &[(0b10010, &ENTRY_PLATITUDINIZING_11960508778562463338)],
        &[(0b01001, &ENTRY_PLATITUDINIZATION_11548882127482737211)],
        &[(0b01001, &ENTRY_PLATITUDINIZATIONS_8947623953157828775)],
        &[(0b01001, &ENTRY_PLATITUDINIZE_5511778463063483337)],
        &[(0b01001, &ENTRY_PLATITUDINIZED_12324616080202347816)],
        &[(0b01001, &ENTRY_PLATITUDINIZER_7798668408381897855)],
        &[(0b01001, &ENTRY_PLATITUDINIZES_13848363114958142428)],
        &[(0b01001, &ENTRY_PLATITUDINIZING_11960508778562463338)],
        &[(0b10010, &ENTRY_PLATONIZATION_1431972253304975157)],
        &[(0b10010, &ENTRY_PLATONIZE_4955313131784059286)],
        &[(0b10010, &ENTRY_PLATONIZED_9850939091619434183)],
        &[(0b10010, &ENTRY_PLATONIZER_18217924882843355421)],
        &[(0b10010, &ENTRY_PLATONIZES_11528499264638923457)],
        &[(0b10010, &ENTRY_PLATONIZING_3062623929119448423)],
        &[(0b01001, &ENTRY_PLATONIZATION_1431972253304975157)],
        &[(0b01001, &ENTRY_PLATONIZE_4955313131784059286)],
        &[(0b01001, &ENTRY_PLATONIZED_9850939091619434183)],
        &[(0b01001, &ENTRY_PLATONIZER_18217924882843355421)],
        &[(0b01001, &ENTRY_PLATONIZES_11528499264638923457)],
        &[(0b01001, &ENTRY_PLATONIZING_3062623929119448423)],
        &[(0b00001, &ENTRY_PLATYCELIAN_7398526835897071803)],
        &[(0b00001, &ENTRY_PLATYCELOUS_13326142746308283636)],
        &[(0b11010, &ENTRY_PLATYCELIAN_7398526835897071803)],
        &[(0b11010, &ENTRY_PLATYCELOUS_13326142746308283636)],
    ],
    range: 2..=14,
};

static VARS_PLAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLAS_CHILDREN),
    value: None,
};

pub static VARS_PLAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("maphaeresis"),
        dictgen::InsensitiveStr::Ascii("mapheresis"),
        dictgen::InsensitiveStr::Ascii("molyse"),
        dictgen::InsensitiveStr::Ascii("molysed"),
        dictgen::InsensitiveStr::Ascii("molyses"),
        dictgen::InsensitiveStr::Ascii("molysing"),
        dictgen::InsensitiveStr::Ascii("molyze"),
        dictgen::InsensitiveStr::Ascii("molyzed"),
        dictgen::InsensitiveStr::Ascii("molyzes"),
        dictgen::InsensitiveStr::Ascii("molyzing"),
        dictgen::InsensitiveStr::Ascii("ticisation"),
        dictgen::InsensitiveStr::Ascii("ticisations"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticised"),
        dictgen::InsensitiveStr::Ascii("ticiser"),
        dictgen::InsensitiveStr::Ascii("ticisers"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticising"),
        dictgen::InsensitiveStr::Ascii("ticization"),
        dictgen::InsensitiveStr::Ascii("ticizations"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticized"),
        dictgen::InsensitiveStr::Ascii("ticizer"),
        dictgen::InsensitiveStr::Ascii("ticizers"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
        dictgen::InsensitiveStr::Ascii("ticizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLASMAPHERESIS_1101729942583566589)],
        &[(0b00001, &ENTRY_PLASMAPHERESIS_1101729942583566589)],
        &[(0b11010, &ENTRY_PLASMOLYZE_1739506176647936790)],
        &[(0b11010, &ENTRY_PLASMOLYZED_5978703891064918750)],
        &[(0b11010, &ENTRY_PLASMOLYZES_5557512980309334270)],
        &[(0b11010, &ENTRY_PLASMOLYZING_4681078529426985256)],
        &[(0b00001, &ENTRY_PLASMOLYZE_1739506176647936790)],
        &[(0b00001, &ENTRY_PLASMOLYZED_5978703891064918750)],
        &[(0b00001, &ENTRY_PLASMOLYZES_5557512980309334270)],
        &[(0b00001, &ENTRY_PLASMOLYZING_4681078529426985256)],
        &[(0b10010, &ENTRY_PLASTICIZATION_5223268547130847422)],
        &[(0b10010, &ENTRY_PLASTICIZATIONS_17193500125688789685)],
        &[(0b10010, &ENTRY_PLASTICIZE_12797038501706387171)],
        &[(0b10010, &ENTRY_PLASTICIZED_7781252037154490596)],
        &[(0b10010, &ENTRY_PLASTICIZER_8318606071228781590)],
        &[(0b10010, &ENTRY_PLASTICIZERS_6018942164442812723)],
        &[(0b10010, &ENTRY_PLASTICIZES_9170692950470288401)],
        &[(0b10010, &ENTRY_PLASTICIZING_9614229074072341821)],
        &[(0b01001, &ENTRY_PLASTICIZATION_5223268547130847422)],
        &[(0b01001, &ENTRY_PLASTICIZATIONS_17193500125688789685)],
        &[(0b01001, &ENTRY_PLASTICIZE_12797038501706387171)],
        &[(0b01001, &ENTRY_PLASTICIZED_7781252037154490596)],
        &[(0b01001, &ENTRY_PLASTICIZER_8318606071228781590)],
        &[(0b01001, &ENTRY_PLASTICIZERS_6018942164442812723)],
        &[(0b01001, &ENTRY_PLASTICIZES_9170692950470288401)],
        &[(0b01001, &ENTRY_PLASTICIZING_9614229074072341821)],
    ],
    range: 6..=11,
};

static VARS_PLAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLAN_CHILDREN),
    value: None,
};

pub static VARS_PLAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("tulae"),
        dictgen::InsensitiveStr::Ascii("tule"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLANTE_10913440927257642720)],
        &[(0b00001, &ENTRY_PLANTE_10913440927257642720)],
        &[(0b11010, &ENTRY_PLANTULE_7843694394733769427)],
        &[(0b00001, &ENTRY_PLANTULE_7843694394733769427)],
    ],
    range: 2..=5,
};

static VARS_PLAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLAG_CHILDREN),
    value: None,
};

pub static VARS_PLAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("iarisation"),
        dictgen::InsensitiveStr::Ascii("iarisations"),
        dictgen::InsensitiveStr::Ascii("iarise"),
        dictgen::InsensitiveStr::Ascii("iarised"),
        dictgen::InsensitiveStr::Ascii("iariser"),
        dictgen::InsensitiveStr::Ascii("iarisers"),
        dictgen::InsensitiveStr::Ascii("iarises"),
        dictgen::InsensitiveStr::Ascii("iarising"),
        dictgen::InsensitiveStr::Ascii("iarization"),
        dictgen::InsensitiveStr::Ascii("iarizations"),
        dictgen::InsensitiveStr::Ascii("iarize"),
        dictgen::InsensitiveStr::Ascii("iarized"),
        dictgen::InsensitiveStr::Ascii("iarizer"),
        dictgen::InsensitiveStr::Ascii("iarizers"),
        dictgen::InsensitiveStr::Ascii("iarizes"),
        dictgen::InsensitiveStr::Ascii("iarizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLAGE_9296345710514961167)],
        &[(0b00001, &ENTRY_PLAGE_9296345710514961167)],
        &[(0b10010, &ENTRY_PLAGIARIZATION_7961094991777232104)],
        &[(0b10010, &ENTRY_PLAGIARIZATIONS_198428492151552423)],
        &[(0b10010, &ENTRY_PLAGIARIZE_10194759391693640324)],
        &[(0b10010, &ENTRY_PLAGIARIZED_9613017187196721707)],
        &[(0b10010, &ENTRY_PLAGIARIZER_837829193172431711)],
        &[(0b10010, &ENTRY_PLAGIARIZERS_9616347174653166907)],
        &[(0b10010, &ENTRY_PLAGIARIZES_5807100586921225426)],
        &[(0b10010, &ENTRY_PLAGIARIZING_14588615914934086132)],
        &[(0b01001, &ENTRY_PLAGIARIZATION_7961094991777232104)],
        &[(0b01001, &ENTRY_PLAGIARIZATIONS_198428492151552423)],
        &[(0b01001, &ENTRY_PLAGIARIZE_10194759391693640324)],
        &[(0b01001, &ENTRY_PLAGIARIZED_9613017187196721707)],
        &[(0b01001, &ENTRY_PLAGIARIZER_837829193172431711)],
        &[(0b01001, &ENTRY_PLAGIARIZERS_9616347174653166907)],
        &[(0b01001, &ENTRY_PLAGIARIZES_5807100586921225426)],
        &[(0b01001, &ENTRY_PLAGIARIZING_14588615914934086132)],
    ],
    range: 1..=11,
};

static VARS_PLAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLAC_CHILDREN),
    value: None,
};

pub static VARS_PLAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aean"),
        dictgen::InsensitiveStr::Ascii("ean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLACEAN_13827495213601838014)],
        &[(0b00001, &ENTRY_PLACEAN_13827495213601838014)],
    ],
    range: 3..=4,
};

static VARS_PI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PI_CHILDREN),
    value: None,
};

static VARS_PI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PIA_NODE),
    None,
    Some(&VARS_PIC_NODE),
    Some(&VARS_PID_NODE),
    None,
    None,
    Some(&VARS_PIG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_PIL_NODE),
    None,
    Some(&VARS_PIN_NODE),
    None,
    None,
    None,
    Some(&VARS_PIR_NODE),
    Some(&VARS_PIS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PIZ_NODE),
];

static VARS_PIZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIZ_CHILDREN),
    value: None,
};

pub static VARS_PIZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("es")],
    values: &[&[(0b01001, &ENTRY_PIZES_5560835984418995409)]],
    range: 2..=2,
};

static VARS_PIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIS_CHILDREN),
    value: None,
};

pub static VARS_PIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cinae"),
        dictgen::InsensitiveStr::Ascii("cine"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("toled"),
        dictgen::InsensitiveStr::Ascii("toling"),
        dictgen::InsensitiveStr::Ascii("tolled"),
        dictgen::InsensitiveStr::Ascii("tolling"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PISCINE_3032140466849687519)],
        &[(0b00001, &ENTRY_PISCINE_3032140466849687519)],
        &[(0b10010, &ENTRY_PIZES_5560835984418995409)],
        &[(0b00001, &ENTRY_PISTOLED_12241561110057693947)],
        &[(0b00001, &ENTRY_PISTOLING_2607035646140319770)],
        &[(0b11010, &ENTRY_PISTOLED_12241561110057693947)],
        &[(0b11010, &ENTRY_PISTOLING_2607035646140319770)],
    ],
    range: 2..=7,
};

static VARS_PIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIR_CHILDREN),
    value: None,
};

pub static VARS_PIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atise"),
        dictgen::InsensitiveStr::Ascii("atises"),
        dictgen::InsensitiveStr::Ascii("atize"),
        dictgen::InsensitiveStr::Ascii("atizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PIRATIZE_7498584575055060768)],
        &[(0b10010, &ENTRY_PIRATIZES_6363280016400180691)],
        &[(0b01001, &ENTRY_PIRATIZE_7498584575055060768)],
        &[(0b01001, &ENTRY_PIRATIZES_6363280016400180691)],
    ],
    range: 5..=6,
};

static VARS_PIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIN_CHILDREN),
    value: None,
};

pub static VARS_PIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("darise"),
        dictgen::InsensitiveStr::Ascii("darised"),
        dictgen::InsensitiveStr::Ascii("darises"),
        dictgen::InsensitiveStr::Ascii("darising"),
        dictgen::InsensitiveStr::Ascii("darize"),
        dictgen::InsensitiveStr::Ascii("darized"),
        dictgen::InsensitiveStr::Ascii("darizes"),
        dictgen::InsensitiveStr::Ascii("darizing"),
        dictgen::InsensitiveStr::Ascii("nulae"),
        dictgen::InsensitiveStr::Ascii("nule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PINDARIZE_5665870824881318813)],
        &[(0b10010, &ENTRY_PINDARIZED_7413959525709250668)],
        &[(0b10010, &ENTRY_PINDARIZES_17165896999619788388)],
        &[(0b10010, &ENTRY_PINDARIZING_5252449072306360079)],
        &[(0b01001, &ENTRY_PINDARIZE_5665870824881318813)],
        &[(0b01001, &ENTRY_PINDARIZED_7413959525709250668)],
        &[(0b01001, &ENTRY_PINDARIZES_17165896999619788388)],
        &[(0b01001, &ENTRY_PINDARIZING_5252449072306360079)],
        &[(0b11010, &ENTRY_PINNULE_1047095209482962902)],
        &[(0b00001, &ENTRY_PINNULE_1047095209482962902)],
    ],
    range: 4..=8,
};

static VARS_PIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIL_CHILDREN),
    value: None,
};

pub static VARS_PIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("grimise"),
        dictgen::InsensitiveStr::Ascii("grimised"),
        dictgen::InsensitiveStr::Ascii("grimises"),
        dictgen::InsensitiveStr::Ascii("grimising"),
        dictgen::InsensitiveStr::Ascii("grimize"),
        dictgen::InsensitiveStr::Ascii("grimized"),
        dictgen::InsensitiveStr::Ascii("grimizes"),
        dictgen::InsensitiveStr::Ascii("grimizing"),
        dictgen::InsensitiveStr::Ascii("larise"),
        dictgen::InsensitiveStr::Ascii("larises"),
        dictgen::InsensitiveStr::Ascii("larize"),
        dictgen::InsensitiveStr::Ascii("larizes"),
        dictgen::InsensitiveStr::Ascii("lorise"),
        dictgen::InsensitiveStr::Ascii("lorised"),
        dictgen::InsensitiveStr::Ascii("lorises"),
        dictgen::InsensitiveStr::Ascii("lorising"),
        dictgen::InsensitiveStr::Ascii("lorize"),
        dictgen::InsensitiveStr::Ascii("lorized"),
        dictgen::InsensitiveStr::Ascii("lorizes"),
        dictgen::InsensitiveStr::Ascii("lorizing"),
        dictgen::InsensitiveStr::Ascii("lowbeer"),
        dictgen::InsensitiveStr::Ascii("lowbere"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PILGRIMIZE_17154519410230272465)],
        &[(0b10010, &ENTRY_PILGRIMIZED_7383980687925714066)],
        &[(0b10010, &ENTRY_PILGRIMIZES_712155321674693248)],
        &[(0b10010, &ENTRY_PILGRIMIZING_12398626332914324239)],
        &[(0b01001, &ENTRY_PILGRIMIZE_17154519410230272465)],
        &[(0b01001, &ENTRY_PILGRIMIZED_7383980687925714066)],
        &[(0b01001, &ENTRY_PILGRIMIZES_712155321674693248)],
        &[(0b01001, &ENTRY_PILGRIMIZING_12398626332914324239)],
        &[(0b10010, &ENTRY_PILLARIZE_17893293885273404475)],
        &[(0b10010, &ENTRY_PILLARIZES_14004328546306417688)],
        &[(0b01001, &ENTRY_PILLARIZE_17893293885273404475)],
        &[(0b01001, &ENTRY_PILLARIZES_14004328546306417688)],
        &[(0b10010, &ENTRY_PILLORIZE_8959002670003616471)],
        &[(0b10010, &ENTRY_PILLORIZED_8385306358890514198)],
        &[(0b10010, &ENTRY_PILLORIZES_8938264984517358007)],
        &[(0b10010, &ENTRY_PILLORIZING_12916238741504692400)],
        &[(0b01001, &ENTRY_PILLORIZE_8959002670003616471)],
        &[(0b01001, &ENTRY_PILLORIZED_8385306358890514198)],
        &[(0b01001, &ENTRY_PILLORIZES_8938264984517358007)],
        &[(0b01001, &ENTRY_PILLORIZING_12916238741504692400)],
        &[(0b00001, &ENTRY_PILLOWBEER_7107283998185116408)],
        &[(0b11010, &ENTRY_PILLOWBEER_7107283998185116408)],
    ],
    range: 6..=9,
};

static VARS_PIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIG_CHILDREN),
    value: None,
};

pub static VARS_PIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("maean"),
        dictgen::InsensitiveStr::Ascii("mean"),
        dictgen::InsensitiveStr::Ascii("mentise"),
        dictgen::InsensitiveStr::Ascii("mentises"),
        dictgen::InsensitiveStr::Ascii("mentize"),
        dictgen::InsensitiveStr::Ascii("mentizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PIGMEAN_16264762923594143012)],
        &[(0b00001, &ENTRY_PIGMEAN_16264762923594143012)],
        &[(0b10010, &ENTRY_PIGMENTIZE_5554925876815794210)],
        &[(0b10010, &ENTRY_PIGMENTIZES_5693731952847051859)],
        &[(0b01001, &ENTRY_PIGMENTIZE_5554925876815794210)],
        &[(0b01001, &ENTRY_PIGMENTIZES_5693731952847051859)],
    ],
    range: 4..=8,
};

static VARS_PID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PID_CHILDREN),
    value: None,
};

pub static VARS_PID_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ginisation"),
        dictgen::InsensitiveStr::Ascii("ginisations"),
        dictgen::InsensitiveStr::Ascii("ginise"),
        dictgen::InsensitiveStr::Ascii("ginised"),
        dictgen::InsensitiveStr::Ascii("ginises"),
        dictgen::InsensitiveStr::Ascii("ginising"),
        dictgen::InsensitiveStr::Ascii("ginization"),
        dictgen::InsensitiveStr::Ascii("ginizations"),
        dictgen::InsensitiveStr::Ascii("ginize"),
        dictgen::InsensitiveStr::Ascii("ginized"),
        dictgen::InsensitiveStr::Ascii("ginizes"),
        dictgen::InsensitiveStr::Ascii("ginizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PIDGINIZATION_14898298171211785128)],
        &[(0b10010, &ENTRY_PIDGINIZATIONS_9043568517184811829)],
        &[(0b10010, &ENTRY_PIDGINIZE_14642311815580598344)],
        &[(0b10010, &ENTRY_PIDGINIZED_13513455210066371222)],
        &[(0b10010, &ENTRY_PIDGINIZES_5675570422788375057)],
        &[(0b10010, &ENTRY_PIDGINIZING_5775992654421420841)],
        &[(0b01001, &ENTRY_PIDGINIZATION_14898298171211785128)],
        &[(0b01001, &ENTRY_PIDGINIZATIONS_9043568517184811829)],
        &[(0b01001, &ENTRY_PIDGINIZE_14642311815580598344)],
        &[(0b01001, &ENTRY_PIDGINIZED_13513455210066371222)],
        &[(0b01001, &ENTRY_PIDGINIZES_5675570422788375057)],
        &[(0b01001, &ENTRY_PIDGINIZING_5775992654421420841)],
    ],
    range: 6..=11,
};

static VARS_PIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIC_CHILDREN),
    value: None,
};

pub static VARS_PIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ogramme"),
        dictgen::InsensitiveStr::Ascii("ogrammes"),
        dictgen::InsensitiveStr::Ascii("ometer"),
        dictgen::InsensitiveStr::Ascii("ometers"),
        dictgen::InsensitiveStr::Ascii("ometre"),
        dictgen::InsensitiveStr::Ascii("ometres"),
        dictgen::InsensitiveStr::Ascii("torialisation"),
        dictgen::InsensitiveStr::Ascii("torialisations"),
        dictgen::InsensitiveStr::Ascii("torialise"),
        dictgen::InsensitiveStr::Ascii("torialised"),
        dictgen::InsensitiveStr::Ascii("torialises"),
        dictgen::InsensitiveStr::Ascii("torialising"),
        dictgen::InsensitiveStr::Ascii("torialization"),
        dictgen::InsensitiveStr::Ascii("torializations"),
        dictgen::InsensitiveStr::Ascii("torialize"),
        dictgen::InsensitiveStr::Ascii("torialized"),
        dictgen::InsensitiveStr::Ascii("torializes"),
        dictgen::InsensitiveStr::Ascii("torializing"),
        dictgen::InsensitiveStr::Ascii("turisation"),
        dictgen::InsensitiveStr::Ascii("turisations"),
        dictgen::InsensitiveStr::Ascii("turise"),
        dictgen::InsensitiveStr::Ascii("turised"),
        dictgen::InsensitiveStr::Ascii("turises"),
        dictgen::InsensitiveStr::Ascii("turising"),
        dictgen::InsensitiveStr::Ascii("turization"),
        dictgen::InsensitiveStr::Ascii("turizations"),
        dictgen::InsensitiveStr::Ascii("turize"),
        dictgen::InsensitiveStr::Ascii("turized"),
        dictgen::InsensitiveStr::Ascii("turizes"),
        dictgen::InsensitiveStr::Ascii("turizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PICOGRAM_897071979947632084)],
        &[(0b10010, &ENTRY_PICOGRAMS_6301335701016571140)],
        &[(0b01001, &ENTRY_PICOMETER_18154171812281634044)],
        &[(0b01001, &ENTRY_PICOMETERS_8849208120065637750)],
        &[(0b11010, &ENTRY_PICOMETER_18154171812281634044)],
        &[(0b11010, &ENTRY_PICOMETERS_8849208120065637750)],
        &[(0b10010, &ENTRY_PICTORIALIZATION_7712094291310927501)],
        &[(0b10010, &ENTRY_PICTORIALIZATIONS_8617172813285892415)],
        &[(0b10010, &ENTRY_PICTORIALIZE_1587515587218069513)],
        &[(0b10010, &ENTRY_PICTORIALIZED_6310600748747560949)],
        &[(0b10010, &ENTRY_PICTORIALIZES_1596343688530759401)],
        &[(0b10010, &ENTRY_PICTORIALIZING_1280923510844471637)],
        &[(0b01001, &ENTRY_PICTORIALIZATION_7712094291310927501)],
        &[(0b01001, &ENTRY_PICTORIALIZATIONS_8617172813285892415)],
        &[(0b01001, &ENTRY_PICTORIALIZE_1587515587218069513)],
        &[(0b01001, &ENTRY_PICTORIALIZED_6310600748747560949)],
        &[(0b01001, &ENTRY_PICTORIALIZES_1596343688530759401)],
        &[(0b01001, &ENTRY_PICTORIALIZING_1280923510844471637)],
        &[(0b10010, &ENTRY_PICTURIZATION_17028325824167615829)],
        &[(0b10010, &ENTRY_PICTURIZATIONS_8434741872826810359)],
        &[(0b10010, &ENTRY_PICTURIZE_4350733612421535987)],
        &[(0b10010, &ENTRY_PICTURIZED_15492681815366106114)],
        &[(0b10010, &ENTRY_PICTURIZES_3225547602517349068)],
        &[(0b10010, &ENTRY_PICTURIZING_9871609769029307573)],
        &[(0b01001, &ENTRY_PICTURIZATION_17028325824167615829)],
        &[(0b01001, &ENTRY_PICTURIZATIONS_8434741872826810359)],
        &[(0b01001, &ENTRY_PICTURIZE_4350733612421535987)],
        &[(0b01001, &ENTRY_PICTURIZED_15492681815366106114)],
        &[(0b01001, &ENTRY_PICTURIZES_3225547602517349068)],
        &[(0b01001, &ENTRY_PICTURIZING_9871609769029307573)],
    ],
    range: 6..=14,
};

static VARS_PIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIA_CHILDREN),
    value: None,
};

pub static VARS_PIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rhaemic"),
        dictgen::InsensitiveStr::Ascii("rhemic"),
        dictgen::InsensitiveStr::Ascii("ster"),
        dictgen::InsensitiveStr::Ascii("sters"),
        dictgen::InsensitiveStr::Ascii("stre"),
        dictgen::InsensitiveStr::Ascii("stres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PIARHEMIC_7252173850563280414)],
        &[(0b00001, &ENTRY_PIARHEMIC_7252173850563280414)],
        &[(0b00001, &ENTRY_PIASTER_11202645044054150783)],
        &[(0b00001, &ENTRY_PIASTERS_7280037555234194522)],
        &[(0b11010, &ENTRY_PIASTER_11202645044054150783)],
        &[(0b11010, &ENTRY_PIASTERS_7280037555234194522)],
    ],
    range: 4..=7,
};

static VARS_PH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PH_CHILDREN),
    value: None,
};

static VARS_PH_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PHA_NODE),
    None,
    None,
    None,
    Some(&VARS_PHE_NODE),
    None,
    None,
    None,
    Some(&VARS_PHI_NODE),
    None,
    None,
    Some(&VARS_PHL_NODE),
    None,
    None,
    Some(&VARS_PHO_NODE),
    None,
    None,
    Some(&VARS_PHR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PHY_NODE),
    None,
];

static VARS_PHY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHY_CHILDREN),
    value: None,
};

pub static VARS_PHY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lactolaema"),
        dictgen::InsensitiveStr::Ascii("lactolaemata"),
        dictgen::InsensitiveStr::Ascii("lactolema"),
        dictgen::InsensitiveStr::Ascii("lactolemata"),
        dictgen::InsensitiveStr::Ascii("toecology"),
        dictgen::InsensitiveStr::Ascii("tohaemagglutinin"),
        dictgen::InsensitiveStr::Ascii("tohemagglutinin"),
        dictgen::InsensitiveStr::Ascii("tooecology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PHYLACTOLEMA_9504620286399322607)],
        &[(0b11010, &ENTRY_PHYLACTOLEMATA_4727881121175758737)],
        &[(0b00001, &ENTRY_PHYLACTOLEMA_9504620286399322607)],
        &[(0b00001, &ENTRY_PHYLACTOLEMATA_4727881121175758737)],
        &[(0b00001, &ENTRY_PHYTOECOLOGY_14832754206983871485)],
        &[(0b11010, &ENTRY_PHYTOHEMAGGLUTININ_6639532879219917503)],
        &[(0b00001, &ENTRY_PHYTOHEMAGGLUTININ_6639532879219917503)],
        &[(0b11010, &ENTRY_PHYTOECOLOGY_14832754206983871485)],
    ],
    range: 9..=16,
};

static VARS_PHR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHR_CHILDREN),
    value: None,
};

pub static VARS_PHR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enologise"),
        dictgen::InsensitiveStr::Ascii("enologised"),
        dictgen::InsensitiveStr::Ascii("enologises"),
        dictgen::InsensitiveStr::Ascii("enologising"),
        dictgen::InsensitiveStr::Ascii("enologize"),
        dictgen::InsensitiveStr::Ascii("enologized"),
        dictgen::InsensitiveStr::Ascii("enologizes"),
        dictgen::InsensitiveStr::Ascii("enologizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PHRENOLOGIZE_8826874213224657962)],
        &[(0b10010, &ENTRY_PHRENOLOGIZED_3753596870390610768)],
        &[(0b10010, &ENTRY_PHRENOLOGIZES_9322358579091550629)],
        &[(0b10010, &ENTRY_PHRENOLOGIZING_8180250475409589410)],
        &[(0b01001, &ENTRY_PHRENOLOGIZE_8826874213224657962)],
        &[(0b01001, &ENTRY_PHRENOLOGIZED_3753596870390610768)],
        &[(0b01001, &ENTRY_PHRENOLOGIZES_9322358579091550629)],
        &[(0b01001, &ENTRY_PHRENOLOGIZING_8180250475409589410)],
    ],
    range: 9..=11,
};

static VARS_PHO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PHO_CHILDREN),
    value: None,
};

static VARS_PHO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_PHOC_NODE),
    None,
    Some(&VARS_PHOE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PHON_NODE),
    None,
    None,
    None,
    Some(&VARS_PHOR_NODE),
    Some(&VARS_PHOS_NODE),
    Some(&VARS_PHOT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PHOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PHOT_CHILDREN),
    value: None,
};

static VARS_PHOT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PHOTA_NODE),
    None,
    None,
    None,
    Some(&VARS_PHOTE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PHOTO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PHOTO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOTO_CHILDREN),
    value: None,
};

pub static VARS_PHOTO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthetic"),
        dictgen::InsensitiveStr::Ascii("catalyser"),
        dictgen::InsensitiveStr::Ascii("catalysers"),
        dictgen::InsensitiveStr::Ascii("catalyzer"),
        dictgen::InsensitiveStr::Ascii("catalyzers"),
        dictgen::InsensitiveStr::Ascii("esthesis"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
        dictgen::InsensitiveStr::Ascii("graphise"),
        dictgen::InsensitiveStr::Ascii("graphises"),
        dictgen::InsensitiveStr::Ascii("graphize"),
        dictgen::InsensitiveStr::Ascii("graphizes"),
        dictgen::InsensitiveStr::Ascii("ionisation"),
        dictgen::InsensitiveStr::Ascii("ionisations"),
        dictgen::InsensitiveStr::Ascii("ionization"),
        dictgen::InsensitiveStr::Ascii("ionizations"),
        dictgen::InsensitiveStr::Ascii("isomerisation"),
        dictgen::InsensitiveStr::Ascii("isomerisations"),
        dictgen::InsensitiveStr::Ascii("isomerization"),
        dictgen::InsensitiveStr::Ascii("isomerizations"),
        dictgen::InsensitiveStr::Ascii("labeled"),
        dictgen::InsensitiveStr::Ascii("labeler"),
        dictgen::InsensitiveStr::Ascii("labeling"),
        dictgen::InsensitiveStr::Ascii("labelled"),
        dictgen::InsensitiveStr::Ascii("labeller"),
        dictgen::InsensitiveStr::Ascii("labelling"),
        dictgen::InsensitiveStr::Ascii("lysable"),
        dictgen::InsensitiveStr::Ascii("lyse"),
        dictgen::InsensitiveStr::Ascii("lysed"),
        dictgen::InsensitiveStr::Ascii("lyses"),
        dictgen::InsensitiveStr::Ascii("lysing"),
        dictgen::InsensitiveStr::Ascii("lyzable"),
        dictgen::InsensitiveStr::Ascii("lyze"),
        dictgen::InsensitiveStr::Ascii("lyzed"),
        dictgen::InsensitiveStr::Ascii("lyzes"),
        dictgen::InsensitiveStr::Ascii("lyzing"),
        dictgen::InsensitiveStr::Ascii("polymerisation"),
        dictgen::InsensitiveStr::Ascii("polymerisations"),
        dictgen::InsensitiveStr::Ascii("polymerization"),
        dictgen::InsensitiveStr::Ascii("polymerizations"),
        dictgen::InsensitiveStr::Ascii("sensitisation"),
        dictgen::InsensitiveStr::Ascii("sensitisations"),
        dictgen::InsensitiveStr::Ascii("sensitise"),
        dictgen::InsensitiveStr::Ascii("sensitised"),
        dictgen::InsensitiveStr::Ascii("sensitiser"),
        dictgen::InsensitiveStr::Ascii("sensitisers"),
        dictgen::InsensitiveStr::Ascii("sensitises"),
        dictgen::InsensitiveStr::Ascii("sensitising"),
        dictgen::InsensitiveStr::Ascii("sensitization"),
        dictgen::InsensitiveStr::Ascii("sensitizations"),
        dictgen::InsensitiveStr::Ascii("sensitize"),
        dictgen::InsensitiveStr::Ascii("sensitized"),
        dictgen::InsensitiveStr::Ascii("sensitizer"),
        dictgen::InsensitiveStr::Ascii("sensitizers"),
        dictgen::InsensitiveStr::Ascii("sensitizes"),
        dictgen::InsensitiveStr::Ascii("sensitizing"),
        dictgen::InsensitiveStr::Ascii("synthesise"),
        dictgen::InsensitiveStr::Ascii("synthesised"),
        dictgen::InsensitiveStr::Ascii("synthesises"),
        dictgen::InsensitiveStr::Ascii("synthesising"),
        dictgen::InsensitiveStr::Ascii("synthesize"),
        dictgen::InsensitiveStr::Ascii("synthesized"),
        dictgen::InsensitiveStr::Ascii("synthesizes"),
        dictgen::InsensitiveStr::Ascii("synthesizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PHOTOESTHETIC_4162550279086204135)],
        &[(0b11010, &ENTRY_PHOTOCATALYZER_16625334355925095744)],
        &[(0b11010, &ENTRY_PHOTOCATALYZERS_8164419550583756409)],
        &[(0b00001, &ENTRY_PHOTOCATALYZER_16625334355925095744)],
        &[(0b00001, &ENTRY_PHOTOCATALYZERS_8164419550583756409)],
        &[(0b11010, &ENTRY_PHOTESTHESIS_10504089027857371233)],
        &[(0b00001, &ENTRY_PHOTOESTHETIC_4162550279086204135)],
        &[(0b10010, &ENTRY_PHOTOGRAPHIZE_13009051709358189470)],
        &[(0b10010, &ENTRY_PHOTOGRAPHIZES_17052291772239819803)],
        &[(0b01001, &ENTRY_PHOTOGRAPHIZE_13009051709358189470)],
        &[(0b01001, &ENTRY_PHOTOGRAPHIZES_17052291772239819803)],
        &[(0b10010, &ENTRY_PHOTOIONIZATION_2353665288545299552)],
        &[(0b10010, &ENTRY_PHOTOIONIZATIONS_12632972190380552273)],
        &[(0b01001, &ENTRY_PHOTOIONIZATION_2353665288545299552)],
        &[(0b01001, &ENTRY_PHOTOIONIZATIONS_12632972190380552273)],
        &[(0b10010, &ENTRY_PHOTOISOMERIZATION_14033181143754093132)],
        &[(0b10010, &ENTRY_PHOTOISOMERIZATIONS_3131890740686826947)],
        &[(0b01001, &ENTRY_PHOTOISOMERIZATION_14033181143754093132)],
        &[(0b01001, &ENTRY_PHOTOISOMERIZATIONS_3131890740686826947)],
        &[(0b00001, &ENTRY_PHOTOLABELED_7558538457232731327)],
        &[(0b00001, &ENTRY_PHOTOLABELER_9834790744528440316)],
        &[(0b00001, &ENTRY_PHOTOLABELING_12583957988292145757)],
        &[(0b11010, &ENTRY_PHOTOLABELED_7558538457232731327)],
        &[(0b11010, &ENTRY_PHOTOLABELER_9834790744528440316)],
        &[(0b11010, &ENTRY_PHOTOLABELING_12583957988292145757)],
        &[(0b11010, &ENTRY_PHOTOLYZABLE_3013653466379758491)],
        &[(0b10010, &ENTRY_PHOTOLYZE_15369041603064723973)],
        &[(0b10010, &ENTRY_PHOTOLYZED_4044401391833424884)],
        &[(0b10010, &ENTRY_PHOTOLYZES_11442533529208998520)],
        &[(0b10010, &ENTRY_PHOTOLYZING_10304193905450130961)],
        &[(0b00001, &ENTRY_PHOTOLYZABLE_3013653466379758491)],
        &[(0b01001, &ENTRY_PHOTOLYZE_15369041603064723973)],
        &[(0b01001, &ENTRY_PHOTOLYZED_4044401391833424884)],
        &[(0b01001, &ENTRY_PHOTOLYZES_11442533529208998520)],
        &[(0b01001, &ENTRY_PHOTOLYZING_10304193905450130961)],
        &[(0b10010, &ENTRY_PHOTOPOLYMERIZATION_8332984251030365028)],
        &[(0b10010, &ENTRY_PHOTOPOLYMERIZATIONS_9963570724543744714)],
        &[(0b01001, &ENTRY_PHOTOPOLYMERIZATION_8332984251030365028)],
        &[(0b01001, &ENTRY_PHOTOPOLYMERIZATIONS_9963570724543744714)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZATION_3455225719453288209)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZATIONS_5900393581512994740)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZE_12371098856611489759)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZED_6142679385850023798)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZER_10017955015526437502)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZERS_11297622188466828139)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZES_5875867603426985013)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZING_3966854427188119206)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZATION_3455225719453288209)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZATIONS_5900393581512994740)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZE_12371098856611489759)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZED_6142679385850023798)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZER_10017955015526437502)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZERS_11297622188466828139)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZES_5875867603426985013)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZING_3966854427188119206)],
        &[(0b10010, &ENTRY_PHOTOSYNTHESIZE_9353202202077615821)],
        &[(0b10010, &ENTRY_PHOTOSYNTHESIZED_8205058313674230591)],
        &[(0b10010, &ENTRY_PHOTOSYNTHESIZES_2447766527906919866)],
        &[(0b10010, &ENTRY_PHOTOSYNTHESIZING_9195844832593591204)],
        &[(0b01001, &ENTRY_PHOTOSYNTHESIZE_9353202202077615821)],
        &[(0b01001, &ENTRY_PHOTOSYNTHESIZED_8205058313674230591)],
        &[(0b01001, &ENTRY_PHOTOSYNTHESIZES_2447766527906919866)],
        &[(0b01001, &ENTRY_PHOTOSYNTHESIZING_9195844832593591204)],
    ],
    range: 4..=15,
};

static VARS_PHOTE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOTE_CHILDREN),
    value: None,
};

pub static VARS_PHOTE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("sthesis")],
    values: &[&[
        (0b00001, &ENTRY_PHOTESTHESIS_10504089027857371233),
        (0b00001, &ENTRY_PHOTESTHESIS_18028002935597043463),
    ]],
    range: 7..=7,
};

static VARS_PHOTA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOTA_CHILDREN),
    value: None,
};

pub static VARS_PHOTA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("esthesis")],
    values: &[&[(0b11010, &ENTRY_PHOTESTHESIS_18028002935597043463)]],
    range: 8..=8,
};

static VARS_PHOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOS_CHILDREN),
    value: None,
};

pub static VARS_PHOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("phatisation"),
        dictgen::InsensitiveStr::Ascii("phatisations"),
        dictgen::InsensitiveStr::Ascii("phatise"),
        dictgen::InsensitiveStr::Ascii("phatised"),
        dictgen::InsensitiveStr::Ascii("phatises"),
        dictgen::InsensitiveStr::Ascii("phatising"),
        dictgen::InsensitiveStr::Ascii("phatization"),
        dictgen::InsensitiveStr::Ascii("phatizations"),
        dictgen::InsensitiveStr::Ascii("phatize"),
        dictgen::InsensitiveStr::Ascii("phatized"),
        dictgen::InsensitiveStr::Ascii("phatizes"),
        dictgen::InsensitiveStr::Ascii("phatizing"),
        dictgen::InsensitiveStr::Ascii("phorise"),
        dictgen::InsensitiveStr::Ascii("phorised"),
        dictgen::InsensitiveStr::Ascii("phorises"),
        dictgen::InsensitiveStr::Ascii("phorising"),
        dictgen::InsensitiveStr::Ascii("phorize"),
        dictgen::InsensitiveStr::Ascii("phorized"),
        dictgen::InsensitiveStr::Ascii("phorizes"),
        dictgen::InsensitiveStr::Ascii("phorizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PHOSPHATIZATION_616667263394769289)],
        &[(0b10010, &ENTRY_PHOSPHATIZATIONS_1121958433579509731)],
        &[(0b10010, &ENTRY_PHOSPHATIZE_1667299755293922263)],
        &[(0b10010, &ENTRY_PHOSPHATIZED_13126970640675535946)],
        &[(0b10010, &ENTRY_PHOSPHATIZES_8990776804655352551)],
        &[(0b10010, &ENTRY_PHOSPHATIZING_17500888516700323389)],
        &[(0b01001, &ENTRY_PHOSPHATIZATION_616667263394769289)],
        &[(0b01001, &ENTRY_PHOSPHATIZATIONS_1121958433579509731)],
        &[(0b01001, &ENTRY_PHOSPHATIZE_1667299755293922263)],
        &[(0b01001, &ENTRY_PHOSPHATIZED_13126970640675535946)],
        &[(0b01001, &ENTRY_PHOSPHATIZES_8990776804655352551)],
        &[(0b01001, &ENTRY_PHOSPHATIZING_17500888516700323389)],
        &[(0b10010, &ENTRY_PHOSPHORIZE_16358423542391123484)],
        &[(0b10010, &ENTRY_PHOSPHORIZED_16384672095284129419)],
        &[(0b10010, &ENTRY_PHOSPHORIZES_14092986315021869609)],
        &[(0b10010, &ENTRY_PHOSPHORIZING_17105539577918917030)],
        &[(0b01001, &ENTRY_PHOSPHORIZE_16358423542391123484)],
        &[(0b01001, &ENTRY_PHOSPHORIZED_16384672095284129419)],
        &[(0b01001, &ENTRY_PHOSPHORIZES_14092986315021869609)],
        &[(0b01001, &ENTRY_PHOSPHORIZING_17105539577918917030)],
    ],
    range: 7..=12,
};

static VARS_PHOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOR_CHILDREN),
    value: None,
};

pub static VARS_PHOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rhea"),
        dictgen::InsensitiveStr::Ascii("rhoea"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PHORRHEA_17608253370867057471)],
        &[(0b11010, &ENTRY_PHORRHEA_17608253370867057471)],
    ],
    range: 4..=5,
};

static VARS_PHON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHON_CHILDREN),
    value: None,
};

pub static VARS_PHON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emicisation"),
        dictgen::InsensitiveStr::Ascii("emicisations"),
        dictgen::InsensitiveStr::Ascii("emicise"),
        dictgen::InsensitiveStr::Ascii("emicised"),
        dictgen::InsensitiveStr::Ascii("emicises"),
        dictgen::InsensitiveStr::Ascii("emicising"),
        dictgen::InsensitiveStr::Ascii("emicization"),
        dictgen::InsensitiveStr::Ascii("emicizations"),
        dictgen::InsensitiveStr::Ascii("emicize"),
        dictgen::InsensitiveStr::Ascii("emicized"),
        dictgen::InsensitiveStr::Ascii("emicizes"),
        dictgen::InsensitiveStr::Ascii("emicizing"),
        dictgen::InsensitiveStr::Ascii("eticisation"),
        dictgen::InsensitiveStr::Ascii("eticisations"),
        dictgen::InsensitiveStr::Ascii("eticise"),
        dictgen::InsensitiveStr::Ascii("eticised"),
        dictgen::InsensitiveStr::Ascii("eticises"),
        dictgen::InsensitiveStr::Ascii("eticising"),
        dictgen::InsensitiveStr::Ascii("eticization"),
        dictgen::InsensitiveStr::Ascii("eticizations"),
        dictgen::InsensitiveStr::Ascii("eticize"),
        dictgen::InsensitiveStr::Ascii("eticized"),
        dictgen::InsensitiveStr::Ascii("eticizes"),
        dictgen::InsensitiveStr::Ascii("eticizing"),
        dictgen::InsensitiveStr::Ascii("etisation"),
        dictgen::InsensitiveStr::Ascii("etisations"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etising"),
        dictgen::InsensitiveStr::Ascii("etization"),
        dictgen::InsensitiveStr::Ascii("etizations"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("etizing"),
        dictgen::InsensitiveStr::Ascii("eyed"),
        dictgen::InsensitiveStr::Ascii("eying"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PHONEMICIZATION_6323160181205469127)],
        &[(0b10010, &ENTRY_PHONEMICIZATIONS_16553605663286995185)],
        &[(0b10010, &ENTRY_PHONEMICIZE_927469605150151893)],
        &[(0b10010, &ENTRY_PHONEMICIZED_4997860750971504400)],
        &[(0b10010, &ENTRY_PHONEMICIZES_6569001176089796159)],
        &[(0b10010, &ENTRY_PHONEMICIZING_10695322427443994471)],
        &[(0b01001, &ENTRY_PHONEMICIZATION_6323160181205469127)],
        &[(0b01001, &ENTRY_PHONEMICIZATIONS_16553605663286995185)],
        &[(0b01001, &ENTRY_PHONEMICIZE_927469605150151893)],
        &[(0b01001, &ENTRY_PHONEMICIZED_4997860750971504400)],
        &[(0b01001, &ENTRY_PHONEMICIZES_6569001176089796159)],
        &[(0b01001, &ENTRY_PHONEMICIZING_10695322427443994471)],
        &[(0b10010, &ENTRY_PHONETICIZATION_737615114921263050)],
        &[(0b10010, &ENTRY_PHONETICIZATIONS_6895495606775013512)],
        &[(0b10010, &ENTRY_PHONETICIZE_17444104769984047253)],
        &[(0b10010, &ENTRY_PHONETICIZED_12784331896589493557)],
        &[(0b10010, &ENTRY_PHONETICIZES_8399555500802410311)],
        &[(0b10010, &ENTRY_PHONETICIZING_1852361785918936440)],
        &[(0b01001, &ENTRY_PHONETICIZATION_737615114921263050)],
        &[(0b01001, &ENTRY_PHONETICIZATIONS_6895495606775013512)],
        &[(0b01001, &ENTRY_PHONETICIZE_17444104769984047253)],
        &[(0b01001, &ENTRY_PHONETICIZED_12784331896589493557)],
        &[(0b01001, &ENTRY_PHONETICIZES_8399555500802410311)],
        &[(0b01001, &ENTRY_PHONETICIZING_1852361785918936440)],
        &[(0b10010, &ENTRY_PHONETIZATION_18215901972235617344)],
        &[(0b10010, &ENTRY_PHONETIZATIONS_1248934340338779916)],
        &[(0b10010, &ENTRY_PHONETIZE_8262409265563929787)],
        &[(0b10010, &ENTRY_PHONETIZED_5591888960341485474)],
        &[(0b10010, &ENTRY_PHONETIZES_17948181531880979803)],
        &[(0b10010, &ENTRY_PHONETIZING_4349191718988073503)],
        &[(0b01001, &ENTRY_PHONETIZATION_18215901972235617344)],
        &[(0b01001, &ENTRY_PHONETIZATIONS_1248934340338779916)],
        &[(0b01001, &ENTRY_PHONETIZE_8262409265563929787)],
        &[(0b01001, &ENTRY_PHONETIZED_5591888960341485474)],
        &[(0b01001, &ENTRY_PHONETIZES_17948181531880979803)],
        &[(0b01001, &ENTRY_PHONETIZING_4349191718988073503)],
        &[(0b00001, &ENTRY_PHONIED_2250260042946147168)],
        &[(0b00001, &ENTRY_PHONYING_13054141319835686864)],
    ],
    range: 4..=12,
};

static VARS_PHOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOE_CHILDREN),
    value: None,
};

pub static VARS_PHOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nicia"),
        dictgen::InsensitiveStr::Ascii("nicopter"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PHENICIA_15630851869480130195)],
        &[(0b11010, &ENTRY_PHENICOPTER_2824141521828380168)],
    ],
    range: 5..=8,
};

static VARS_PHOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOC_CHILDREN),
    value: None,
};

pub static VARS_PHOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aean"),
        dictgen::InsensitiveStr::Ascii("ean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PHOCEAN_8276831186971524579)],
        &[(0b00001, &ENTRY_PHOCEAN_8276831186971524579)],
    ],
    range: 3..=4,
};

static VARS_PHL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHL_CHILDREN),
    value: None,
};

pub static VARS_PHL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ebotomisation"),
        dictgen::InsensitiveStr::Ascii("ebotomisations"),
        dictgen::InsensitiveStr::Ascii("ebotomise"),
        dictgen::InsensitiveStr::Ascii("ebotomised"),
        dictgen::InsensitiveStr::Ascii("ebotomises"),
        dictgen::InsensitiveStr::Ascii("ebotomising"),
        dictgen::InsensitiveStr::Ascii("ebotomization"),
        dictgen::InsensitiveStr::Ascii("ebotomizations"),
        dictgen::InsensitiveStr::Ascii("ebotomize"),
        dictgen::InsensitiveStr::Ascii("ebotomized"),
        dictgen::InsensitiveStr::Ascii("ebotomizes"),
        dictgen::InsensitiveStr::Ascii("ebotomizing"),
        dictgen::InsensitiveStr::Ascii("eum"),
        dictgen::InsensitiveStr::Ascii("oeum"),
        dictgen::InsensitiveStr::Ascii("yctaena"),
        dictgen::InsensitiveStr::Ascii("yctaenae"),
        dictgen::InsensitiveStr::Ascii("yctaenula"),
        dictgen::InsensitiveStr::Ascii("yctena"),
        dictgen::InsensitiveStr::Ascii("yctenae"),
        dictgen::InsensitiveStr::Ascii("yctenula"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PHLEBOTOMIZATION_14789748646153111751)],
        &[(0b10010, &ENTRY_PHLEBOTOMIZATIONS_13570026240025562120)],
        &[(0b10010, &ENTRY_PHLEBOTOMIZE_5424959391532030755)],
        &[(0b10010, &ENTRY_PHLEBOTOMIZED_5100102168126674735)],
        &[(0b10010, &ENTRY_PHLEBOTOMIZES_4093384839909362396)],
        &[(0b10010, &ENTRY_PHLEBOTOMIZING_12242317892759935073)],
        &[(0b01001, &ENTRY_PHLEBOTOMIZATION_14789748646153111751)],
        &[(0b01001, &ENTRY_PHLEBOTOMIZATIONS_13570026240025562120)],
        &[(0b01001, &ENTRY_PHLEBOTOMIZE_5424959391532030755)],
        &[(0b01001, &ENTRY_PHLEBOTOMIZED_5100102168126674735)],
        &[(0b01001, &ENTRY_PHLEBOTOMIZES_4093384839909362396)],
        &[(0b01001, &ENTRY_PHLEBOTOMIZING_12242317892759935073)],
        &[(0b00001, &ENTRY_PHLEUM_2009705278880979838)],
        &[(0b11010, &ENTRY_PHLEUM_2009705278880979838)],
        &[(0b11010, &ENTRY_PHLYCTENA_5882861521043497675)],
        &[(0b11010, &ENTRY_PHLYCTENAE_2049602725476666121)],
        &[(0b11010, &ENTRY_PHLYCTENULA_514120502377170929)],
        &[(0b00001, &ENTRY_PHLYCTENA_5882861521043497675)],
        &[(0b00001, &ENTRY_PHLYCTENAE_2049602725476666121)],
        &[(0b00001, &ENTRY_PHLYCTENULA_514120502377170929)],
    ],
    range: 3..=14,
};

static VARS_PHI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHI_CHILDREN),
    value: None,
};

pub static VARS_PHI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alae"),
        dictgen::InsensitiveStr::Ascii("ale"),
        dictgen::InsensitiveStr::Ascii("lanthropise"),
        dictgen::InsensitiveStr::Ascii("lanthropised"),
        dictgen::InsensitiveStr::Ascii("lanthropises"),
        dictgen::InsensitiveStr::Ascii("lanthropising"),
        dictgen::InsensitiveStr::Ascii("lanthropize"),
        dictgen::InsensitiveStr::Ascii("lanthropized"),
        dictgen::InsensitiveStr::Ascii("lanthropizes"),
        dictgen::InsensitiveStr::Ascii("lanthropizing"),
        dictgen::InsensitiveStr::Ascii("lippise"),
        dictgen::InsensitiveStr::Ascii("lippised"),
        dictgen::InsensitiveStr::Ascii("lippises"),
        dictgen::InsensitiveStr::Ascii("lippising"),
        dictgen::InsensitiveStr::Ascii("lippize"),
        dictgen::InsensitiveStr::Ascii("lippized"),
        dictgen::InsensitiveStr::Ascii("lippizes"),
        dictgen::InsensitiveStr::Ascii("lippizing"),
        dictgen::InsensitiveStr::Ascii("listinise"),
        dictgen::InsensitiveStr::Ascii("listinised"),
        dictgen::InsensitiveStr::Ascii("listinises"),
        dictgen::InsensitiveStr::Ascii("listinising"),
        dictgen::InsensitiveStr::Ascii("listinize"),
        dictgen::InsensitiveStr::Ascii("listinized"),
        dictgen::InsensitiveStr::Ascii("listinizes"),
        dictgen::InsensitiveStr::Ascii("listinizing"),
        dictgen::InsensitiveStr::Ascii("lopena"),
        dictgen::InsensitiveStr::Ascii("lopenas"),
        dictgen::InsensitiveStr::Ascii("lopoena"),
        dictgen::InsensitiveStr::Ascii("lopoenas"),
        dictgen::InsensitiveStr::Ascii("losophisation"),
        dictgen::InsensitiveStr::Ascii("losophisations"),
        dictgen::InsensitiveStr::Ascii("losophise"),
        dictgen::InsensitiveStr::Ascii("losophised"),
        dictgen::InsensitiveStr::Ascii("losophiser"),
        dictgen::InsensitiveStr::Ascii("losophisers"),
        dictgen::InsensitiveStr::Ascii("losophises"),
        dictgen::InsensitiveStr::Ascii("losophising"),
        dictgen::InsensitiveStr::Ascii("losophization"),
        dictgen::InsensitiveStr::Ascii("losophizations"),
        dictgen::InsensitiveStr::Ascii("losophize"),
        dictgen::InsensitiveStr::Ascii("losophized"),
        dictgen::InsensitiveStr::Ascii("losophizer"),
        dictgen::InsensitiveStr::Ascii("losophizers"),
        dictgen::InsensitiveStr::Ascii("losophizes"),
        dictgen::InsensitiveStr::Ascii("losophizing"),
        dictgen::InsensitiveStr::Ascii("lter"),
        dictgen::InsensitiveStr::Ascii("lters"),
        dictgen::InsensitiveStr::Ascii("ltre"),
        dictgen::InsensitiveStr::Ascii("ltres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PHIALE_16648988129627894747)],
        &[(0b00001, &ENTRY_PHIALE_16648988129627894747)],
        &[(0b10010, &ENTRY_PHILANTHROPIZE_11035127392376583449)],
        &[(0b10010, &ENTRY_PHILANTHROPIZED_8816715198631162734)],
        &[(0b10010, &ENTRY_PHILANTHROPIZES_15996753996390534851)],
        &[(0b10010, &ENTRY_PHILANTHROPIZING_927855906725859822)],
        &[(0b01001, &ENTRY_PHILANTHROPIZE_11035127392376583449)],
        &[(0b01001, &ENTRY_PHILANTHROPIZED_8816715198631162734)],
        &[(0b01001, &ENTRY_PHILANTHROPIZES_15996753996390534851)],
        &[(0b01001, &ENTRY_PHILANTHROPIZING_927855906725859822)],
        &[(0b10010, &ENTRY_PHILIPPIZE_13053145819398147538)],
        &[(0b10010, &ENTRY_PHILIPPIZED_10195366950258611952)],
        &[(0b10010, &ENTRY_PHILIPPIZES_3858718280017954826)],
        &[(0b10010, &ENTRY_PHILIPPIZING_12304909522561212858)],
        &[(0b01001, &ENTRY_PHILIPPIZE_13053145819398147538)],
        &[(0b01001, &ENTRY_PHILIPPIZED_10195366950258611952)],
        &[(0b01001, &ENTRY_PHILIPPIZES_3858718280017954826)],
        &[(0b01001, &ENTRY_PHILIPPIZING_12304909522561212858)],
        &[(0b10010, &ENTRY_PHILISTINIZE_13261459833175390275)],
        &[(0b10010, &ENTRY_PHILISTINIZED_15824917951523189934)],
        &[(0b10010, &ENTRY_PHILISTINIZES_121754806134507167)],
        &[(0b10010, &ENTRY_PHILISTINIZING_9474558502061243392)],
        &[(0b01001, &ENTRY_PHILISTINIZE_13261459833175390275)],
        &[(0b01001, &ENTRY_PHILISTINIZED_15824917951523189934)],
        &[(0b01001, &ENTRY_PHILISTINIZES_121754806134507167)],
        &[(0b01001, &ENTRY_PHILISTINIZING_9474558502061243392)],
        &[(0b00001, &ENTRY_PHILOPENA_1662688293565385739)],
        &[(0b00001, &ENTRY_PHILOPENAS_10705048107924510090)],
        &[(0b11010, &ENTRY_PHILOPENA_1662688293565385739)],
        &[(0b11010, &ENTRY_PHILOPENAS_10705048107924510090)],
        &[(0b10010, &ENTRY_PHILOSOPHIZATION_4092799111515698897)],
        &[(0b10010, &ENTRY_PHILOSOPHIZATIONS_8563926038056739714)],
        &[(0b10010, &ENTRY_PHILOSOPHIZE_6289672951361880530)],
        &[(0b10010, &ENTRY_PHILOSOPHIZED_2316681608168076190)],
        &[(0b10010, &ENTRY_PHILOSOPHIZER_13078210838054950081)],
        &[(0b10010, &ENTRY_PHILOSOPHIZERS_9751548833379500220)],
        &[(0b10010, &ENTRY_PHILOSOPHIZES_4374489325746751173)],
        &[(0b10010, &ENTRY_PHILOSOPHIZING_7293438746871613968)],
        &[(0b01001, &ENTRY_PHILOSOPHIZATION_4092799111515698897)],
        &[(0b01001, &ENTRY_PHILOSOPHIZATIONS_8563926038056739714)],
        &[(0b01001, &ENTRY_PHILOSOPHIZE_6289672951361880530)],
        &[(0b01001, &ENTRY_PHILOSOPHIZED_2316681608168076190)],
        &[(0b01001, &ENTRY_PHILOSOPHIZER_13078210838054950081)],
        &[(0b01001, &ENTRY_PHILOSOPHIZERS_9751548833379500220)],
        &[(0b01001, &ENTRY_PHILOSOPHIZES_4374489325746751173)],
        &[(0b01001, &ENTRY_PHILOSOPHIZING_7293438746871613968)],
        &[(0b00001, &ENTRY_PHILTER_10084940057302890116)],
        &[(0b00001, &ENTRY_PHILTERS_15728406259693213137)],
        &[(0b11010, &ENTRY_PHILTER_10084940057302890116)],
        &[(0b11010, &ENTRY_PHILTERS_15728406259693213137)],
    ],
    range: 3..=14,
};

static VARS_PHE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHE_CHILDREN),
    value: None,
};

pub static VARS_PHE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lonion"),
        dictgen::InsensitiveStr::Ascii("lonions"),
        dictgen::InsensitiveStr::Ascii("nicia"),
        dictgen::InsensitiveStr::Ascii("nicopter"),
        dictgen::InsensitiveStr::Ascii("nogam"),
        dictgen::InsensitiveStr::Ascii("nogams"),
        dictgen::InsensitiveStr::Ascii("nogenesis"),
        dictgen::InsensitiveStr::Ascii("nogenetic"),
        dictgen::InsensitiveStr::Ascii("nolisation"),
        dictgen::InsensitiveStr::Ascii("nolisations"),
        dictgen::InsensitiveStr::Ascii("nolise"),
        dictgen::InsensitiveStr::Ascii("nolises"),
        dictgen::InsensitiveStr::Ascii("nolization"),
        dictgen::InsensitiveStr::Ascii("nolizations"),
        dictgen::InsensitiveStr::Ascii("nolize"),
        dictgen::InsensitiveStr::Ascii("nolizes"),
        dictgen::InsensitiveStr::Ascii("nological"),
        dictgen::InsensitiveStr::Ascii("nologies"),
        dictgen::InsensitiveStr::Ascii("nology"),
        dictgen::InsensitiveStr::Ascii("nomenalisation"),
        dictgen::InsensitiveStr::Ascii("nomenalisations"),
        dictgen::InsensitiveStr::Ascii("nomenalise"),
        dictgen::InsensitiveStr::Ascii("nomenalised"),
        dictgen::InsensitiveStr::Ascii("nomenalises"),
        dictgen::InsensitiveStr::Ascii("nomenalising"),
        dictgen::InsensitiveStr::Ascii("nomenalization"),
        dictgen::InsensitiveStr::Ascii("nomenalizations"),
        dictgen::InsensitiveStr::Ascii("nomenalize"),
        dictgen::InsensitiveStr::Ascii("nomenalized"),
        dictgen::InsensitiveStr::Ascii("nomenalizes"),
        dictgen::InsensitiveStr::Ascii("nomenalizing"),
        dictgen::InsensitiveStr::Ascii("nomenise"),
        dictgen::InsensitiveStr::Ascii("nomenised"),
        dictgen::InsensitiveStr::Ascii("nomenises"),
        dictgen::InsensitiveStr::Ascii("nomenising"),
        dictgen::InsensitiveStr::Ascii("nomenism"),
        dictgen::InsensitiveStr::Ascii("nomenize"),
        dictgen::InsensitiveStr::Ascii("nomenized"),
        dictgen::InsensitiveStr::Ascii("nomenizes"),
        dictgen::InsensitiveStr::Ascii("nomenizing"),
        dictgen::InsensitiveStr::Ascii("nozygous"),
        dictgen::InsensitiveStr::Ascii("ophyl"),
        dictgen::InsensitiveStr::Ascii("ophyll"),
        dictgen::InsensitiveStr::Ascii("ophytin"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PHELONION_16911775146755324729)],
        &[(0b00001, &ENTRY_PHELONIONS_15367895008171210427)],
        &[(0b00001, &ENTRY_PHENICIA_15630851869480130195)],
        &[(0b00001, &ENTRY_PHENICOPTER_2824141521828380168)],
        &[(0b00001, &ENTRY_PHENOGAM_4209907075654374375)],
        &[(0b00001, &ENTRY_PHENOGAMS_1730886532743225108)],
        &[(0b00001, &ENTRY_PHENOGENESIS_5657114645659088205)],
        &[(0b00001, &ENTRY_PHENOGENETIC_4532917918539313819)],
        &[(0b10010, &ENTRY_PHENOLIZATION_6178643424301535160)],
        &[(0b10010, &ENTRY_PHENOLIZATIONS_14816642927391194800)],
        &[(0b10010, &ENTRY_PHENOLIZE_1901105808826241610)],
        &[(0b10010, &ENTRY_PHENOLIZES_12025904088177779404)],
        &[(0b01001, &ENTRY_PHENOLIZATION_6178643424301535160)],
        &[(0b01001, &ENTRY_PHENOLIZATIONS_14816642927391194800)],
        &[(0b01001, &ENTRY_PHENOLIZE_1901105808826241610)],
        &[(0b01001, &ENTRY_PHENOLIZES_12025904088177779404)],
        &[(0b00001, &ENTRY_PHENOLOGICAL_10955652503353448632)],
        &[(0b00001, &ENTRY_PHENOLOGIES_16299581387606345895)],
        &[(0b00001, &ENTRY_PHENOLOGY_2533225012965146295)],
        &[(0b10010, &ENTRY_PHENOMENALIZATION_14528853097910122994)],
        &[(0b10010, &ENTRY_PHENOMENALIZATIONS_12206092907848664074)],
        &[(0b10010, &ENTRY_PHENOMENALIZE_5560443916737905726)],
        &[(0b10010, &ENTRY_PHENOMENALIZED_11643906778812926830)],
        &[(0b10010, &ENTRY_PHENOMENALIZES_17401908608894538474)],
        &[(0b10010, &ENTRY_PHENOMENALIZING_153151426474266164)],
        &[(0b01001, &ENTRY_PHENOMENALIZATION_14528853097910122994)],
        &[(0b01001, &ENTRY_PHENOMENALIZATIONS_12206092907848664074)],
        &[(0b01001, &ENTRY_PHENOMENALIZE_5560443916737905726)],
        &[(0b01001, &ENTRY_PHENOMENALIZED_11643906778812926830)],
        &[(0b01001, &ENTRY_PHENOMENALIZES_17401908608894538474)],
        &[(0b01001, &ENTRY_PHENOMENALIZING_153151426474266164)],
        &[(0b10010, &ENTRY_PHENOMENIZE_3388568256287381277)],
        &[(0b10010, &ENTRY_PHENOMENIZED_13186647982537861618)],
        &[(0b10010, &ENTRY_PHENOMENIZES_8149035924823974047)],
        &[(0b10010, &ENTRY_PHENOMENIZING_3379221850892214321)],
        &[(0b00001, &ENTRY_PHENOMENISM_960132059160089939)],
        &[(0b01001, &ENTRY_PHENOMENIZE_3388568256287381277)],
        &[(0b01001, &ENTRY_PHENOMENIZED_13186647982537861618)],
        &[(0b01001, &ENTRY_PHENOMENIZES_8149035924823974047)],
        &[(0b01001, &ENTRY_PHENOMENIZING_3379221850892214321)],
        &[(0b00001, &ENTRY_PHENOZYGOUS_5083828519660760393)],
        &[(0b00001, &ENTRY_PHEOPHYL_6124525277655392353)],
        &[(0b00001, &ENTRY_PHEOPHYLL_2945109598564039144)],
        &[(0b00001, &ENTRY_PHEOPHYTIN_6768938655441713384)],
    ],
    range: 5..=15,
};

static VARS_PHA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHA_CHILDREN),
    value: None,
};

pub static VARS_PHA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aenna"),
        dictgen::InsensitiveStr::Ascii("cochere"),
        dictgen::InsensitiveStr::Ascii("cocherine"),
        dictgen::InsensitiveStr::Ascii("cochoere"),
        dictgen::InsensitiveStr::Ascii("cochoerine"),
        dictgen::InsensitiveStr::Ascii("elonion"),
        dictgen::InsensitiveStr::Ascii("elonions"),
        dictgen::InsensitiveStr::Ascii("enna"),
        dictgen::InsensitiveStr::Ascii("enogam"),
        dictgen::InsensitiveStr::Ascii("enogams"),
        dictgen::InsensitiveStr::Ascii("enogenesis"),
        dictgen::InsensitiveStr::Ascii("enogenetic"),
        dictgen::InsensitiveStr::Ascii("enological"),
        dictgen::InsensitiveStr::Ascii("enologies"),
        dictgen::InsensitiveStr::Ascii("enology"),
        dictgen::InsensitiveStr::Ascii("enomenism"),
        dictgen::InsensitiveStr::Ascii("enozygous"),
        dictgen::InsensitiveStr::Ascii("eophyl"),
        dictgen::InsensitiveStr::Ascii("eophyll"),
        dictgen::InsensitiveStr::Ascii("eophytin"),
        dictgen::InsensitiveStr::Ascii("gedaena"),
        dictgen::InsensitiveStr::Ascii("gedaenas"),
        dictgen::InsensitiveStr::Ascii("gedaenic"),
        dictgen::InsensitiveStr::Ascii("gedaenical"),
        dictgen::InsensitiveStr::Ascii("gedaenous"),
        dictgen::InsensitiveStr::Ascii("gedena"),
        dictgen::InsensitiveStr::Ascii("gedenas"),
        dictgen::InsensitiveStr::Ascii("gedenic"),
        dictgen::InsensitiveStr::Ascii("gedenical"),
        dictgen::InsensitiveStr::Ascii("gedenous"),
        dictgen::InsensitiveStr::Ascii("gocytise"),
        dictgen::InsensitiveStr::Ascii("gocytises"),
        dictgen::InsensitiveStr::Ascii("gocytize"),
        dictgen::InsensitiveStr::Ascii("gocytizes"),
        dictgen::InsensitiveStr::Ascii("ntomise"),
        dictgen::InsensitiveStr::Ascii("ntomiser"),
        dictgen::InsensitiveStr::Ascii("ntomisers"),
        dictgen::InsensitiveStr::Ascii("ntomises"),
        dictgen::InsensitiveStr::Ascii("ntomize"),
        dictgen::InsensitiveStr::Ascii("ntomizer"),
        dictgen::InsensitiveStr::Ascii("ntomizers"),
        dictgen::InsensitiveStr::Ascii("ntomizes"),
        dictgen::InsensitiveStr::Ascii("risaean"),
        dictgen::InsensitiveStr::Ascii("risean"),
        dictgen::InsensitiveStr::Ascii("rmacopeial"),
        dictgen::InsensitiveStr::Ascii("rmacopeian"),
        dictgen::InsensitiveStr::Ascii("rmacopoeian"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PHAENNA_14814304862853568718)],
        &[(0b00001, &ENTRY_PHACOCHERE_13405482370905993670)],
        &[(0b00001, &ENTRY_PHACOCHERINE_10554606661894707387)],
        &[(0b11010, &ENTRY_PHACOCHERE_13405482370905993670)],
        &[(0b11010, &ENTRY_PHACOCHERINE_10554606661894707387)],
        &[(0b11010, &ENTRY_PHELONION_16911775146755324729)],
        &[(0b11010, &ENTRY_PHELONIONS_15367895008171210427)],
        &[(0b00001, &ENTRY_PHAENNA_14814304862853568718)],
        &[(0b11010, &ENTRY_PHENOGAM_4209907075654374375)],
        &[(0b11010, &ENTRY_PHENOGAMS_1730886532743225108)],
        &[(0b11010, &ENTRY_PHENOGENESIS_5657114645659088205)],
        &[(0b11010, &ENTRY_PHENOGENETIC_4532917918539313819)],
        &[(0b11010, &ENTRY_PHENOLOGICAL_10955652503353448632)],
        &[(0b11010, &ENTRY_PHENOLOGIES_16299581387606345895)],
        &[(0b11010, &ENTRY_PHENOLOGY_2533225012965146295)],
        &[(0b11010, &ENTRY_PHENOMENISM_960132059160089939)],
        &[(0b11010, &ENTRY_PHENOZYGOUS_5083828519660760393)],
        &[(0b11010, &ENTRY_PHEOPHYL_6124525277655392353)],
        &[(0b11010, &ENTRY_PHEOPHYLL_2945109598564039144)],
        &[(0b11010, &ENTRY_PHEOPHYTIN_6768938655441713384)],
        &[(0b11010, &ENTRY_PHAGEDENA_6704742627403782762)],
        &[(0b11010, &ENTRY_PHAGEDENAS_5494425801711070409)],
        &[(0b11010, &ENTRY_PHAGEDENIC_18396375847593319909)],
        &[(0b11010, &ENTRY_PHAGEDENICAL_3768231547699838610)],
        &[(0b11010, &ENTRY_PHAGEDENOUS_1711073083864725072)],
        &[(0b00001, &ENTRY_PHAGEDENA_6704742627403782762)],
        &[(0b00001, &ENTRY_PHAGEDENAS_5494425801711070409)],
        &[(0b00001, &ENTRY_PHAGEDENIC_18396375847593319909)],
        &[(0b00001, &ENTRY_PHAGEDENICAL_3768231547699838610)],
        &[(0b00001, &ENTRY_PHAGEDENOUS_1711073083864725072)],
        &[(0b10010, &ENTRY_PHAGOCYTIZE_16597394072222984740)],
        &[(0b10010, &ENTRY_PHAGOCYTIZES_9458568216408453182)],
        &[(0b01001, &ENTRY_PHAGOCYTIZE_16597394072222984740)],
        &[(0b01001, &ENTRY_PHAGOCYTIZES_9458568216408453182)],
        &[(0b10010, &ENTRY_PHANTOMIZE_11390339407875429440)],
        &[(0b10010, &ENTRY_PHANTOMIZER_17193520697780091154)],
        &[(0b10010, &ENTRY_PHANTOMIZERS_9577813910680390311)],
        &[(0b10010, &ENTRY_PHANTOMIZES_7467789553969706258)],
        &[(0b01001, &ENTRY_PHANTOMIZE_11390339407875429440)],
        &[(0b01001, &ENTRY_PHANTOMIZER_17193520697780091154)],
        &[(0b01001, &ENTRY_PHANTOMIZERS_9577813910680390311)],
        &[(0b01001, &ENTRY_PHANTOMIZES_7467789553969706258)],
        &[(0b11010, &ENTRY_PHARISEAN_7036875068880504869)],
        &[(0b00001, &ENTRY_PHARISEAN_7036875068880504869)],
        &[(0b00001, &ENTRY_PHARMACOPOEIAL_5233925692521382480)],
        &[(0b00001, &ENTRY_PHARMACOPEIAN_4180747604463943610)],
        &[(0b11010, &ENTRY_PHARMACOPEIAN_4180747604463943610)],
    ],
    range: 4..=11,
};

static VARS_PE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_PE_17043181136692725962)]),
};

static VARS_PE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PEA_NODE),
    None,
    Some(&VARS_PEC_NODE),
    Some(&VARS_PED_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_PEI_NODE),
    None,
    None,
    Some(&VARS_PEL_NODE),
    Some(&VARS_PEM_NODE),
    Some(&VARS_PEN_NODE),
    None,
    Some(&VARS_PEP_NODE),
    None,
    Some(&VARS_PER_NODE),
    None,
    Some(&VARS_PET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PET_CHILDREN),
    value: None,
};

pub static VARS_PET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aled"),
        dictgen::InsensitiveStr::Ascii("alled"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("rarchise"),
        dictgen::InsensitiveStr::Ascii("rarchised"),
        dictgen::InsensitiveStr::Ascii("rarchises"),
        dictgen::InsensitiveStr::Ascii("rarchising"),
        dictgen::InsensitiveStr::Ascii("rarchize"),
        dictgen::InsensitiveStr::Ascii("rarchized"),
        dictgen::InsensitiveStr::Ascii("rarchizes"),
        dictgen::InsensitiveStr::Ascii("rarchizing"),
        dictgen::InsensitiveStr::Ascii("rolisation"),
        dictgen::InsensitiveStr::Ascii("rolisations"),
        dictgen::InsensitiveStr::Ascii("rolise"),
        dictgen::InsensitiveStr::Ascii("rolises"),
        dictgen::InsensitiveStr::Ascii("rolization"),
        dictgen::InsensitiveStr::Ascii("rolizations"),
        dictgen::InsensitiveStr::Ascii("rolize"),
        dictgen::InsensitiveStr::Ascii("rolizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PETALED_7430352286411012981)],
        &[(0b11010, &ENTRY_PETALED_7430352286411012981)],
        &[(0b00001, &ENTRY_PETLING_10839442998921882121)],
        &[(0b10010, &ENTRY_PETRARCHIZE_9904851722785626871)],
        &[(0b10010, &ENTRY_PETRARCHIZED_7348574978602994537)],
        &[(0b10010, &ENTRY_PETRARCHIZES_5058218394133373743)],
        &[(0b10010, &ENTRY_PETRARCHIZING_12190562219826886176)],
        &[(0b01001, &ENTRY_PETRARCHIZE_9904851722785626871)],
        &[(0b01001, &ENTRY_PETRARCHIZED_7348574978602994537)],
        &[(0b01001, &ENTRY_PETRARCHIZES_5058218394133373743)],
        &[(0b01001, &ENTRY_PETRARCHIZING_12190562219826886176)],
        &[(0b10010, &ENTRY_PETROLIZATION_13498255753961375094)],
        &[(0b10010, &ENTRY_PETROLIZATIONS_3981394461797224358)],
        &[(0b10010, &ENTRY_PETROLIZE_11225628320479097869)],
        &[(0b10010, &ENTRY_PETROLIZES_7786452671132997357)],
        &[(0b01001, &ENTRY_PETROLIZATION_13498255753961375094)],
        &[(0b01001, &ENTRY_PETROLIZATIONS_3981394461797224358)],
        &[(0b01001, &ENTRY_PETROLIZE_11225628320479097869)],
        &[(0b01001, &ENTRY_PETROLIZES_7786452671132997357)],
    ],
    range: 4..=11,
};

static VARS_PER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PER_CHILDREN),
    value: None,
};

static VARS_PER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PERA_NODE),
    None,
    Some(&VARS_PERC_NODE),
    Some(&VARS_PERD_NODE),
    Some(&VARS_PERE_NODE),
    Some(&VARS_PERF_NODE),
    None,
    Some(&VARS_PERH_NODE),
    Some(&VARS_PERI_NODE),
    Some(&VARS_PERJ_NODE),
    None,
    Some(&VARS_PERL_NODE),
    Some(&VARS_PERM_NODE),
    Some(&VARS_PERN_NODE),
    Some(&VARS_PERO_NODE),
    Some(&VARS_PERP_NODE),
    None,
    None,
    Some(&VARS_PERS_NODE),
    None,
    Some(&VARS_PERU_NODE),
    Some(&VARS_PERV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_PERV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERV_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_PERV_12538763894300491770)]),
};

pub static VARS_PERV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("iable"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("iousness"),
        dictgen::InsensitiveStr::Ascii("iousnesses"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERVE_15605705734121788203)],
        &[(0b00001, &ENTRY_PERVED_5641773030984045701)],
        &[(0b00001, &ENTRY_PERVES_15457354577274877085)],
        &[(0b00001, &ENTRY_PERVIABLE_7017934559789149180)],
        &[(0b00001, &ENTRY_PERVING_861961187036741303)],
        &[(0b00001, &ENTRY_PERVIOUSNESS_12070729285035585339)],
        &[(0b00001, &ENTRY_PERVIOUSNESSES_16881754789905331743)],
    ],
    range: 1..=10,
};

static VARS_PERU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERU_CHILDREN),
    value: None,
};

pub static VARS_PERU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("vianise"),
        dictgen::InsensitiveStr::Ascii("vianises"),
        dictgen::InsensitiveStr::Ascii("vianize"),
        dictgen::InsensitiveStr::Ascii("vianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PERUVIANIZE_11424645593077204472)],
        &[(0b10010, &ENTRY_PERUVIANIZES_5512079830671646)],
        &[(0b01001, &ENTRY_PERUVIANIZE_11424645593077204472)],
        &[(0b01001, &ENTRY_PERUVIANIZES_5512079830671646)],
    ],
    range: 7..=8,
};

static VARS_PERS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERS_CHILDREN),
    value: None,
};

pub static VARS_PERS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ianisation"),
        dictgen::InsensitiveStr::Ascii("ianisations"),
        dictgen::InsensitiveStr::Ascii("ianise"),
        dictgen::InsensitiveStr::Ascii("ianised"),
        dictgen::InsensitiveStr::Ascii("ianises"),
        dictgen::InsensitiveStr::Ascii("ianising"),
        dictgen::InsensitiveStr::Ascii("ianization"),
        dictgen::InsensitiveStr::Ascii("ianizations"),
        dictgen::InsensitiveStr::Ascii("ianize"),
        dictgen::InsensitiveStr::Ascii("ianized"),
        dictgen::InsensitiveStr::Ascii("ianizes"),
        dictgen::InsensitiveStr::Ascii("ianizing"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icizing"),
        dictgen::InsensitiveStr::Ascii("olve"),
        dictgen::InsensitiveStr::Ascii("onalisation"),
        dictgen::InsensitiveStr::Ascii("onalisations"),
        dictgen::InsensitiveStr::Ascii("onalise"),
        dictgen::InsensitiveStr::Ascii("onalised"),
        dictgen::InsensitiveStr::Ascii("onalises"),
        dictgen::InsensitiveStr::Ascii("onalising"),
        dictgen::InsensitiveStr::Ascii("onalization"),
        dictgen::InsensitiveStr::Ascii("onalizations"),
        dictgen::InsensitiveStr::Ascii("onalize"),
        dictgen::InsensitiveStr::Ascii("onalized"),
        dictgen::InsensitiveStr::Ascii("onalizes"),
        dictgen::InsensitiveStr::Ascii("onalizing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("t"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PERSE_16607558930587897129)],
        &[
            (0b00001, &ENTRY_PERSE_11387837727041811534),
            (0b00001, &ENTRY_PERSE_16607558930587897129),
        ],
        &[(0b10010, &ENTRY_PERSIANIZATION_18022273901354166264)],
        &[(0b10010, &ENTRY_PERSIANIZATIONS_313451334445471865)],
        &[(0b10010, &ENTRY_PERSIANIZE_9671949628640572602)],
        &[(0b10010, &ENTRY_PERSIANIZED_14851869006792985600)],
        &[(0b10010, &ENTRY_PERSIANIZES_3568176301631230831)],
        &[(0b10010, &ENTRY_PERSIANIZING_14450069458480800675)],
        &[(0b01001, &ENTRY_PERSIANIZATION_18022273901354166264)],
        &[(0b01001, &ENTRY_PERSIANIZATIONS_313451334445471865)],
        &[(0b01001, &ENTRY_PERSIANIZE_9671949628640572602)],
        &[(0b01001, &ENTRY_PERSIANIZED_14851869006792985600)],
        &[(0b01001, &ENTRY_PERSIANIZES_3568176301631230831)],
        &[(0b01001, &ENTRY_PERSIANIZING_14450069458480800675)],
        &[(0b10010, &ENTRY_PERSICIZE_7446428141072412578)],
        &[(0b10010, &ENTRY_PERSICIZED_5078414010687668628)],
        &[(0b10010, &ENTRY_PERSICIZES_14697873868504090786)],
        &[(0b10010, &ENTRY_PERSICIZING_912433421347336038)],
        &[(0b01001, &ENTRY_PERSICIZE_7446428141072412578)],
        &[(0b01001, &ENTRY_PERSICIZED_5078414010687668628)],
        &[(0b01001, &ENTRY_PERSICIZES_14697873868504090786)],
        &[(0b01001, &ENTRY_PERSICIZING_912433421347336038)],
        &[(0b00001, &ENTRY_PERSOLVE_6208805617619929798)],
        &[(0b10010, &ENTRY_PERSONALIZATION_2807413073355132478)],
        &[(0b10010, &ENTRY_PERSONALIZATIONS_8445180728009943143)],
        &[(0b10010, &ENTRY_PERSONALIZE_16406670836185668125)],
        &[(0b10010, &ENTRY_PERSONALIZED_7678165486146161596)],
        &[(0b10010, &ENTRY_PERSONALIZES_498227984615996131)],
        &[(0b10010, &ENTRY_PERSONALIZING_5672131506914446806)],
        &[(0b01001, &ENTRY_PERSONALIZATION_2807413073355132478)],
        &[(0b01001, &ENTRY_PERSONALIZATIONS_8445180728009943143)],
        &[(0b01001, &ENTRY_PERSONALIZE_16406670836185668125)],
        &[(0b01001, &ENTRY_PERSONALIZED_7678165486146161596)],
        &[(0b01001, &ENTRY_PERSONALIZES_498227984615996131)],
        &[(0b01001, &ENTRY_PERSONALIZING_5672131506914446806)],
        &[(0b10010, &ENTRY_PERSONIZATION_1020700707438862869)],
        &[(0b10010, &ENTRY_PERSONIZATIONS_11988733076780280712)],
        &[(0b10010, &ENTRY_PERSONIZE_8848776385579513558)],
        &[(0b10010, &ENTRY_PERSONIZED_7128716389683509405)],
        &[(0b10010, &ENTRY_PERSONIZES_3422163177015925790)],
        &[(0b10010, &ENTRY_PERSONIZING_3522234374911377812)],
        &[(0b01001, &ENTRY_PERSONIZATION_1020700707438862869)],
        &[(0b01001, &ENTRY_PERSONIZATIONS_11988733076780280712)],
        &[(0b01001, &ENTRY_PERSONIZE_8848776385579513558)],
        &[(0b01001, &ENTRY_PERSONIZED_7128716389683509405)],
        &[(0b01001, &ENTRY_PERSONIZES_3422163177015925790)],
        &[(0b01001, &ENTRY_PERSONIZING_3522234374911377812)],
        &[(0b00001, &ENTRY_PERST_13560994870115707725)],
    ],
    range: 1..=12,
};

static VARS_PERP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERP_CHILDREN),
    value: None,
};

pub static VARS_PERP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("erfect")],
    values: &[&[(0b00001, &ENTRY_PERPERFECT_18179313282884798168)]],
    range: 6..=6,
};

static VARS_PERO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERO_CHILDREN),
    value: None,
};

pub static VARS_PERO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ral"),
        dictgen::InsensitiveStr::Ascii("rally"),
        dictgen::InsensitiveStr::Ascii("tic"),
        dictgen::InsensitiveStr::Ascii("xidise"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidisement"),
        dictgen::InsensitiveStr::Ascii("xidisements"),
        dictgen::InsensitiveStr::Ascii("xidises"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidize"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizement"),
        dictgen::InsensitiveStr::Ascii("xidizements"),
        dictgen::InsensitiveStr::Ascii("xidizes"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERORAL_7733507504372641537)],
        &[(0b00001, &ENTRY_PERORALLY_13736466146014362811)],
        &[(0b00001, &ENTRY_PEROTIC_5938557738822235093)],
        &[(0b10010, &ENTRY_PEROXIDIZE_10190672229167948456)],
        &[(0b10010, &ENTRY_PEROXIDIZED_1496757986507118262)],
        &[(0b10010, &ENTRY_PEROXIDIZEMENT_2992204370621740514)],
        &[(0b10010, &ENTRY_PEROXIDIZEMENTS_13015140457438659181)],
        &[(0b10010, &ENTRY_PEROXIDIZES_17724693640385328099)],
        &[(0b10010, &ENTRY_PEROXIDIZING_402392174204032068)],
        &[(0b01001, &ENTRY_PEROXIDIZE_10190672229167948456)],
        &[(0b01001, &ENTRY_PEROXIDIZED_1496757986507118262)],
        &[(0b01001, &ENTRY_PEROXIDIZEMENT_2992204370621740514)],
        &[(0b01001, &ENTRY_PEROXIDIZEMENTS_13015140457438659181)],
        &[(0b01001, &ENTRY_PEROXIDIZES_17724693640385328099)],
        &[(0b01001, &ENTRY_PEROXIDIZING_402392174204032068)],
    ],
    range: 3..=11,
};

static VARS_PERN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERN_CHILDREN),
    value: None,
};

pub static VARS_PERN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("asal")],
    values: &[&[(0b00001, &ENTRY_PERNASAL_9314997630181268940)]],
    range: 4..=4,
};

static VARS_PERM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERM_CHILDREN),
    value: None,
};

pub static VARS_PERM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("issable"),
        dictgen::InsensitiveStr::Ascii("ixture"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERMISSABLE_15564403146668071230)],
        &[(0b00001, &ENTRY_PERMIXTURE_14648968165378084827)],
    ],
    range: 6..=7,
};

static VARS_PERL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERL_CHILDREN),
    value: None,
};

pub static VARS_PERL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ection"),
        dictgen::InsensitiveStr::Ascii("ingual"),
        dictgen::InsensitiveStr::Ascii("ingually"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERLECTION_10848653127438263550)],
        &[(0b00001, &ENTRY_PERLINGUAL_9348282944919159241)],
        &[(0b00001, &ENTRY_PERLINGUALLY_9782531538000987848)],
    ],
    range: 6..=8,
};

static VARS_PERJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERJ_CHILDREN),
    value: None,
};

pub static VARS_PERJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ink")],
    values: &[&[(0b00001, &ENTRY_PERJINK_8081638468925211155)]],
    range: 3..=3,
};

static VARS_PERI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERI_CHILDREN),
    value: None,
};

pub static VARS_PERI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("caecal"),
        dictgen::InsensitiveStr::Ascii("caecitis"),
        dictgen::InsensitiveStr::Ascii("cecal"),
        dictgen::InsensitiveStr::Ascii("cecitis"),
        dictgen::InsensitiveStr::Ascii("center"),
        dictgen::InsensitiveStr::Ascii("centre"),
        dictgen::InsensitiveStr::Ascii("chaete"),
        dictgen::InsensitiveStr::Ascii("chete"),
        dictgen::InsensitiveStr::Ascii("copae"),
        dictgen::InsensitiveStr::Ascii("cope"),
        dictgen::InsensitiveStr::Ascii("esophageal"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("odicalise"),
        dictgen::InsensitiveStr::Ascii("odicalises"),
        dictgen::InsensitiveStr::Ascii("odicalize"),
        dictgen::InsensitiveStr::Ascii("odicalizes"),
        dictgen::InsensitiveStr::Ascii("odisation"),
        dictgen::InsensitiveStr::Ascii("odisations"),
        dictgen::InsensitiveStr::Ascii("odise"),
        dictgen::InsensitiveStr::Ascii("odised"),
        dictgen::InsensitiveStr::Ascii("odises"),
        dictgen::InsensitiveStr::Ascii("odising"),
        dictgen::InsensitiveStr::Ascii("odization"),
        dictgen::InsensitiveStr::Ascii("odizations"),
        dictgen::InsensitiveStr::Ascii("odize"),
        dictgen::InsensitiveStr::Ascii("odized"),
        dictgen::InsensitiveStr::Ascii("odizes"),
        dictgen::InsensitiveStr::Ascii("odizing"),
        dictgen::InsensitiveStr::Ascii("oesophageal"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PERICECAL_11561552565749838840)],
        &[(0b11010, &ENTRY_PERICECITIS_17229068204731568936)],
        &[(0b00001, &ENTRY_PERICECAL_11561552565749838840)],
        &[(0b00001, &ENTRY_PERICECITIS_17229068204731568936)],
        &[(0b00001, &ENTRY_PERICENTER_10614733866576424320)],
        &[(0b11010, &ENTRY_PERICENTER_10614733866576424320)],
        &[(0b11010, &ENTRY_PERICHETE_18105271752996227267)],
        &[(0b00001, &ENTRY_PERICHETE_18105271752996227267)],
        &[(0b11010, &ENTRY_PERICOPE_14246960621803601482)],
        &[(0b00001, &ENTRY_PERICOPE_14246960621803601482)],
        &[(0b00001, &ENTRY_PERIESOPHAGEAL_1263127563857060969)],
        &[(0b00001, &ENTRY_PERILED_15060178372319479950)],
        &[(0b00001, &ENTRY_PERILING_16221031141616213209)],
        &[(0b11010, &ENTRY_PERILED_15060178372319479950)],
        &[(0b11010, &ENTRY_PERILING_16221031141616213209)],
        &[(0b10010, &ENTRY_PERIODICALIZE_2528030134467014135)],
        &[(0b10010, &ENTRY_PERIODICALIZES_17372107047478590982)],
        &[(0b01001, &ENTRY_PERIODICALIZE_2528030134467014135)],
        &[(0b01001, &ENTRY_PERIODICALIZES_17372107047478590982)],
        &[(0b10010, &ENTRY_PERIODIZATION_10629388178555953074)],
        &[(0b10010, &ENTRY_PERIODIZATIONS_17618036349132017353)],
        &[(0b10010, &ENTRY_PERIODIZE_9672274415726820349)],
        &[(0b10010, &ENTRY_PERIODIZED_17003691710060511111)],
        &[(0b10010, &ENTRY_PERIODIZES_18153679890341959171)],
        &[(0b10010, &ENTRY_PERIODIZING_11263976325652979359)],
        &[(0b01001, &ENTRY_PERIODIZATION_10629388178555953074)],
        &[(0b01001, &ENTRY_PERIODIZATIONS_17618036349132017353)],
        &[(0b01001, &ENTRY_PERIODIZE_9672274415726820349)],
        &[(0b01001, &ENTRY_PERIODIZED_17003691710060511111)],
        &[(0b01001, &ENTRY_PERIODIZES_18153679890341959171)],
        &[(0b01001, &ENTRY_PERIODIZING_11263976325652979359)],
        &[(0b11010, &ENTRY_PERIESOPHAGEAL_1263127563857060969)],
    ],
    range: 3..=11,
};

static VARS_PERH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERH_CHILDREN),
    value: None,
};

pub static VARS_PERH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("azard")],
    values: &[&[(0b00001, &ENTRY_PERHAZARD_3309804805860844776)]],
    range: 5..=5,
};

static VARS_PERF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERF_CHILDREN),
    value: None,
};

pub static VARS_PERF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectivise"),
        dictgen::InsensitiveStr::Ascii("ectivises"),
        dictgen::InsensitiveStr::Ascii("ectivize"),
        dictgen::InsensitiveStr::Ascii("ectivizes"),
        dictgen::InsensitiveStr::Ascii("ervor"),
        dictgen::InsensitiveStr::Ascii("ervors"),
        dictgen::InsensitiveStr::Ascii("ervour"),
        dictgen::InsensitiveStr::Ascii("ervours"),
        dictgen::InsensitiveStr::Ascii("et"),
        dictgen::InsensitiveStr::Ascii("oliation"),
        dictgen::InsensitiveStr::Ascii("oliations"),
        dictgen::InsensitiveStr::Ascii("ormant"),
        dictgen::InsensitiveStr::Ascii("ormative"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PERFECTIVIZE_4991190653079170578)],
        &[(0b10010, &ENTRY_PERFECTIVIZES_3556092795978966359)],
        &[(0b01001, &ENTRY_PERFECTIVIZE_4991190653079170578)],
        &[(0b01001, &ENTRY_PERFECTIVIZES_3556092795978966359)],
        &[(0b00001, &ENTRY_PERFERVOR_5094411619878396347)],
        &[(0b00001, &ENTRY_PERFERVORS_408834739628621753)],
        &[(0b11010, &ENTRY_PERFERVOR_5094411619878396347)],
        &[(0b11010, &ENTRY_PERFERVORS_408834739628621753)],
        &[(0b00001, &ENTRY_PERFET_13896758539689213591)],
        &[(0b00001, &ENTRY_PERFOLIATION_5188268018612471981)],
        &[(0b00001, &ENTRY_PERFOLIATIONS_17365195892397282393)],
        &[(0b00001, &ENTRY_PERFORMANT_15759765683817996390)],
        &[(0b00001, &ENTRY_PERFORMATIVE_2390820457715027525)],
    ],
    range: 2..=9,
};

static VARS_PERE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERE_CHILDREN),
    value: None,
};

pub static VARS_PERE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("nnialise"),
        dictgen::InsensitiveStr::Ascii("nnialises"),
        dictgen::InsensitiveStr::Ascii("nnialize"),
        dictgen::InsensitiveStr::Ascii("nnializes"),
        dictgen::InsensitiveStr::Ascii("on"),
        dictgen::InsensitiveStr::Ascii("opod"),
        dictgen::InsensitiveStr::Ascii("opods"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PEREA_9815109123113005524)],
        &[(0b10010, &ENTRY_PERENNIALIZE_17073460830652016286)],
        &[(0b10010, &ENTRY_PERENNIALIZES_7776437049346762142)],
        &[(0b01001, &ENTRY_PERENNIALIZE_17073460830652016286)],
        &[(0b01001, &ENTRY_PERENNIALIZES_7776437049346762142)],
        &[(0b00001, &ENTRY_PEREON_10052830467199040722)],
        &[(0b00001, &ENTRY_PEREOPOD_4376907164155484639)],
        &[(0b00001, &ENTRY_PEREOPODS_5967506407992460438)],
    ],
    range: 1..=9,
};

static VARS_PERD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERD_CHILDREN),
    value: None,
};

pub static VARS_PERD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icinae"),
        dictgen::InsensitiveStr::Ascii("icine"),
        dictgen::InsensitiveStr::Ascii("iligent"),
        dictgen::InsensitiveStr::Ascii("y"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PERDICINE_12163131408787238481)],
        &[(0b00001, &ENTRY_PERDICINE_12163131408787238481)],
        &[(0b00001, &ENTRY_PERDILIGENT_6178720230946595348)],
        &[(0b00001, &ENTRY_PERDY_17015242260554099593)],
    ],
    range: 1..=7,
};

static VARS_PERC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERC_CHILDREN),
    value: None,
};

pub static VARS_PERC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("hlorethane"),
        dictgen::InsensitiveStr::Ascii("hlorethylene"),
        dictgen::InsensitiveStr::Ascii("hloric"),
        dictgen::InsensitiveStr::Ascii("hloroethane"),
        dictgen::InsensitiveStr::Ascii("hloroethylene"),
        dictgen::InsensitiveStr::Ascii("lose"),
        dictgen::InsensitiveStr::Ascii("ompound"),
        dictgen::InsensitiveStr::Ascii("urrent"),
        dictgen::InsensitiveStr::Ascii("ussionise"),
        dictgen::InsensitiveStr::Ascii("ussionises"),
        dictgen::InsensitiveStr::Ascii("ussionize"),
        dictgen::InsensitiveStr::Ascii("ussionizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERCES_18231213262419993595)],
        &[(0b00001, &ENTRY_PERCHLORETHANE_1893865275398341525)],
        &[(0b00001, &ENTRY_PERCHLORETHYLENE_525647590945342214)],
        &[(0b00001, &ENTRY_PERCHLORIC_15873681416223690811)],
        &[(0b11010, &ENTRY_PERCHLORETHANE_1893865275398341525)],
        &[(0b11010, &ENTRY_PERCHLORETHYLENE_525647590945342214)],
        &[(0b00001, &ENTRY_PERCLOSE_8855509826381556500)],
        &[(0b00001, &ENTRY_PERCOMPOUND_4631387873257903195)],
        &[(0b00001, &ENTRY_PERCURRENT_7729534483371927658)],
        &[(0b10010, &ENTRY_PERCUSSIONIZE_6452251918750798380)],
        &[(0b10010, &ENTRY_PERCUSSIONIZES_13062136969515927546)],
        &[(0b01001, &ENTRY_PERCUSSIONIZE_6452251918750798380)],
        &[(0b01001, &ENTRY_PERCUSSIONIZES_13062136969515927546)],
    ],
    range: 2..=13,
};

static VARS_PERA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERA_CHILDREN),
    value: None,
};

pub static VARS_PERA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cid"),
        dictgen::InsensitiveStr::Ascii("cidity"),
        dictgen::InsensitiveStr::Ascii("ct"),
        dictgen::InsensitiveStr::Ascii("cute"),
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("eon"),
        dictgen::InsensitiveStr::Ascii("eopod"),
        dictgen::InsensitiveStr::Ascii("eopods"),
        dictgen::InsensitiveStr::Ascii("mbulatory"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERACID_18248699393309889840)],
        &[(0b00001, &ENTRY_PERACIDITY_4694554317646599680)],
        &[(0b00001, &ENTRY_PERACT_13646631763087455494)],
        &[(0b00001, &ENTRY_PERACUTE_18080047841868048531)],
        &[(0b11010, &ENTRY_PEREA_9815109123113005524)],
        &[(0b11010, &ENTRY_PEREON_10052830467199040722)],
        &[(0b11010, &ENTRY_PEREOPOD_4376907164155484639)],
        &[(0b11010, &ENTRY_PEREOPODS_5967506407992460438)],
        &[(0b00001, &ENTRY_PERAMBULATORY_3157892809066109163)],
    ],
    range: 2..=9,
};

static VARS_PEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEP_CHILDREN),
    value: None,
};

pub static VARS_PEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tisable"),
        dictgen::InsensitiveStr::Ascii("tisables"),
        dictgen::InsensitiveStr::Ascii("tisation"),
        dictgen::InsensitiveStr::Ascii("tisations"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tiser"),
        dictgen::InsensitiveStr::Ascii("tisers"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tizable"),
        dictgen::InsensitiveStr::Ascii("tizables"),
        dictgen::InsensitiveStr::Ascii("tization"),
        dictgen::InsensitiveStr::Ascii("tizations"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizer"),
        dictgen::InsensitiveStr::Ascii("tizers"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
        dictgen::InsensitiveStr::Ascii("tonaemia"),
        dictgen::InsensitiveStr::Ascii("tonemia"),
        dictgen::InsensitiveStr::Ascii("tonisation"),
        dictgen::InsensitiveStr::Ascii("tonisations"),
        dictgen::InsensitiveStr::Ascii("tonise"),
        dictgen::InsensitiveStr::Ascii("tonised"),
        dictgen::InsensitiveStr::Ascii("toniser"),
        dictgen::InsensitiveStr::Ascii("tonises"),
        dictgen::InsensitiveStr::Ascii("tonising"),
        dictgen::InsensitiveStr::Ascii("tonization"),
        dictgen::InsensitiveStr::Ascii("tonizations"),
        dictgen::InsensitiveStr::Ascii("tonize"),
        dictgen::InsensitiveStr::Ascii("tonized"),
        dictgen::InsensitiveStr::Ascii("tonizer"),
        dictgen::InsensitiveStr::Ascii("tonizes"),
        dictgen::InsensitiveStr::Ascii("tonizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PEPTIZABLE_10009160293830058217)],
        &[(0b10010, &ENTRY_PEPTIZABLES_11059733857451389630)],
        &[(0b10010, &ENTRY_PEPTIZATION_2277498319096983409)],
        &[(0b10010, &ENTRY_PEPTIZATIONS_4461223542992646400)],
        &[(0b10010, &ENTRY_PEPTIZE_1985280393670536602)],
        &[(0b10010, &ENTRY_PEPTIZED_9732700991499029534)],
        &[(0b10010, &ENTRY_PEPTIZER_8332572606012159911)],
        &[(0b10010, &ENTRY_PEPTIZERS_15152990595163734193)],
        &[(0b10010, &ENTRY_PEPTIZES_14243270822862510623)],
        &[(0b10010, &ENTRY_PEPTIZING_1479862026322855639)],
        &[(0b01001, &ENTRY_PEPTIZABLE_10009160293830058217)],
        &[(0b01001, &ENTRY_PEPTIZABLES_11059733857451389630)],
        &[(0b01001, &ENTRY_PEPTIZATION_2277498319096983409)],
        &[(0b01001, &ENTRY_PEPTIZATIONS_4461223542992646400)],
        &[(0b01001, &ENTRY_PEPTIZE_1985280393670536602)],
        &[(0b01001, &ENTRY_PEPTIZED_9732700991499029534)],
        &[(0b01001, &ENTRY_PEPTIZER_8332572606012159911)],
        &[(0b01001, &ENTRY_PEPTIZERS_15152990595163734193)],
        &[(0b01001, &ENTRY_PEPTIZES_14243270822862510623)],
        &[(0b01001, &ENTRY_PEPTIZING_1479862026322855639)],
        &[(0b11010, &ENTRY_PEPTONEMIA_17907025745393161380)],
        &[(0b00001, &ENTRY_PEPTONEMIA_17907025745393161380)],
        &[(0b10010, &ENTRY_PEPTONIZATION_5464229779513025707)],
        &[(0b10010, &ENTRY_PEPTONIZATIONS_129619205916628004)],
        &[(0b10010, &ENTRY_PEPTONIZE_11347438316995918427)],
        &[(0b10010, &ENTRY_PEPTONIZED_13686078805549079398)],
        &[(0b10010, &ENTRY_PEPTONIZER_13244378595341792018)],
        &[(0b10010, &ENTRY_PEPTONIZES_6176239638278066971)],
        &[(0b10010, &ENTRY_PEPTONIZING_641849953879089250)],
        &[(0b01001, &ENTRY_PEPTONIZATION_5464229779513025707)],
        &[(0b01001, &ENTRY_PEPTONIZATIONS_129619205916628004)],
        &[(0b01001, &ENTRY_PEPTONIZE_11347438316995918427)],
        &[(0b01001, &ENTRY_PEPTONIZED_13686078805549079398)],
        &[(0b01001, &ENTRY_PEPTONIZER_13244378595341792018)],
        &[(0b01001, &ENTRY_PEPTONIZES_6176239638278066971)],
        &[(0b01001, &ENTRY_PEPTONIZING_641849953879089250)],
    ],
    range: 4..=11,
};

static VARS_PEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEN_CHILDREN),
    value: None,
};

pub static VARS_PEN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisable"),
        dictgen::InsensitiveStr::Ascii("alisabler"),
        dictgen::InsensitiveStr::Ascii("alisables"),
        dictgen::InsensitiveStr::Ascii("alisablest"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alizable"),
        dictgen::InsensitiveStr::Ascii("alizabler"),
        dictgen::InsensitiveStr::Ascii("alizables"),
        dictgen::InsensitiveStr::Ascii("alizablest"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("ciled"),
        dictgen::InsensitiveStr::Ascii("ciler"),
        dictgen::InsensitiveStr::Ascii("cilers"),
        dictgen::InsensitiveStr::Ascii("ciling"),
        dictgen::InsensitiveStr::Ascii("cilings"),
        dictgen::InsensitiveStr::Ascii("cilled"),
        dictgen::InsensitiveStr::Ascii("ciller"),
        dictgen::InsensitiveStr::Ascii("cillers"),
        dictgen::InsensitiveStr::Ascii("cilling"),
        dictgen::InsensitiveStr::Ascii("cillings"),
        dictgen::InsensitiveStr::Ascii("elopise"),
        dictgen::InsensitiveStr::Ascii("elopised"),
        dictgen::InsensitiveStr::Ascii("elopises"),
        dictgen::InsensitiveStr::Ascii("elopising"),
        dictgen::InsensitiveStr::Ascii("elopize"),
        dictgen::InsensitiveStr::Ascii("elopized"),
        dictgen::InsensitiveStr::Ascii("elopizes"),
        dictgen::InsensitiveStr::Ascii("elopizing"),
        dictgen::InsensitiveStr::Ascii("nae"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("sae"),
        dictgen::InsensitiveStr::Ascii("se"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PENALIZABLE_17690740352185429467)],
        &[(0b10010, &ENTRY_PENALIZABLER_13315936384310138731)],
        &[(0b10010, &ENTRY_PENALIZABLES_4001001474166504822)],
        &[(0b10010, &ENTRY_PENALIZABLEST_16408899980166923386)],
        &[(0b10010, &ENTRY_PENALIZATION_11949589953931542079)],
        &[(0b10010, &ENTRY_PENALIZATIONS_6599684304676350857)],
        &[(0b10010, &ENTRY_PENALIZE_2530505701143168189)],
        &[(0b10010, &ENTRY_PENALIZED_11761122234321379751)],
        &[(0b10010, &ENTRY_PENALIZES_3731488236002265727)],
        &[(0b10010, &ENTRY_PENALIZING_15558361744095191436)],
        &[(0b01001, &ENTRY_PENALIZABLE_17690740352185429467)],
        &[(0b01001, &ENTRY_PENALIZABLER_13315936384310138731)],
        &[(0b01001, &ENTRY_PENALIZABLES_4001001474166504822)],
        &[(0b01001, &ENTRY_PENALIZABLEST_16408899980166923386)],
        &[(0b01001, &ENTRY_PENALIZATION_11949589953931542079)],
        &[(0b01001, &ENTRY_PENALIZATIONS_6599684304676350857)],
        &[(0b01001, &ENTRY_PENALIZE_2530505701143168189)],
        &[(0b01001, &ENTRY_PENALIZED_11761122234321379751)],
        &[(0b01001, &ENTRY_PENALIZES_3731488236002265727)],
        &[(0b01001, &ENTRY_PENALIZING_15558361744095191436)],
        &[(0b00001, &ENTRY_PENCILED_12950313690598237437)],
        &[(0b00001, &ENTRY_PENCILER_648131672630788391)],
        &[(0b00001, &ENTRY_PENCILERS_16761262302512468378)],
        &[(0b00001, &ENTRY_PENCILING_16152937612714350821)],
        &[(0b00001, &ENTRY_PENCILINGS_15763703545745446520)],
        &[(0b11010, &ENTRY_PENCILED_12950313690598237437)],
        &[(0b11010, &ENTRY_PENCILER_648131672630788391)],
        &[(0b11010, &ENTRY_PENCILERS_16761262302512468378)],
        &[(0b11010, &ENTRY_PENCILING_16152937612714350821)],
        &[(0b11010, &ENTRY_PENCILINGS_15763703545745446520)],
        &[(0b10010, &ENTRY_PENELOPIZE_15326668379859195264)],
        &[(0b10010, &ENTRY_PENELOPIZED_9633788614812989197)],
        &[(0b10010, &ENTRY_PENELOPIZES_689767339108882697)],
        &[(0b10010, &ENTRY_PENELOPIZING_7014423288398423825)],
        &[(0b01001, &ENTRY_PENELOPIZE_15326668379859195264)],
        &[(0b01001, &ENTRY_PENELOPIZED_9633788614812989197)],
        &[(0b01001, &ENTRY_PENELOPIZES_689767339108882697)],
        &[(0b01001, &ENTRY_PENELOPIZING_7014423288398423825)],
        &[(0b11010, &ENTRY_PENNE_15841661894922746764)],
        &[(0b00001, &ENTRY_PENNE_15841661894922746764)],
        &[(0b11010, &ENTRY_PENSE_8108242775850229925)],
        &[(0b00001, &ENTRY_PENSE_8108242775850229925)],
    ],
    range: 2..=10,
};

static VARS_PEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEM_CHILDREN),
    value: None,
};

pub static VARS_PEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("micanisation"),
        dictgen::InsensitiveStr::Ascii("micanisations"),
        dictgen::InsensitiveStr::Ascii("micanise"),
        dictgen::InsensitiveStr::Ascii("micanises"),
        dictgen::InsensitiveStr::Ascii("micanization"),
        dictgen::InsensitiveStr::Ascii("micanizations"),
        dictgen::InsensitiveStr::Ascii("micanize"),
        dictgen::InsensitiveStr::Ascii("micanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PEMMICANIZATION_6834983618739941341)],
        &[(0b10010, &ENTRY_PEMMICANIZATIONS_3371249122296666006)],
        &[(0b10010, &ENTRY_PEMMICANIZE_4530348954719077520)],
        &[(0b10010, &ENTRY_PEMMICANIZES_15457349973362759137)],
        &[(0b01001, &ENTRY_PEMMICANIZATION_6834983618739941341)],
        &[(0b01001, &ENTRY_PEMMICANIZATIONS_3371249122296666006)],
        &[(0b01001, &ENTRY_PEMMICANIZE_4530348954719077520)],
        &[(0b01001, &ENTRY_PEMMICANIZES_15457349973362759137)],
    ],
    range: 8..=13,
};

static VARS_PEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEL_CHILDREN),
    value: None,
};

pub static VARS_PEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("letisation"),
        dictgen::InsensitiveStr::Ascii("letisations"),
        dictgen::InsensitiveStr::Ascii("letise"),
        dictgen::InsensitiveStr::Ascii("letised"),
        dictgen::InsensitiveStr::Ascii("letiser"),
        dictgen::InsensitiveStr::Ascii("letises"),
        dictgen::InsensitiveStr::Ascii("letising"),
        dictgen::InsensitiveStr::Ascii("letization"),
        dictgen::InsensitiveStr::Ascii("letizations"),
        dictgen::InsensitiveStr::Ascii("letize"),
        dictgen::InsensitiveStr::Ascii("letized"),
        dictgen::InsensitiveStr::Ascii("letizer"),
        dictgen::InsensitiveStr::Ascii("letizes"),
        dictgen::InsensitiveStr::Ascii("letizing"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PELLETIZATION_1256758943430120850)],
        &[(0b10010, &ENTRY_PELLETIZATIONS_1578808908659139702)],
        &[(0b10010, &ENTRY_PELLETIZE_895054063093563526)],
        &[(0b10010, &ENTRY_PELLETIZED_17773084033857349036)],
        &[(0b10010, &ENTRY_PELLETIZER_16282407634028657238)],
        &[(0b10010, &ENTRY_PELLETIZES_10483149214534795271)],
        &[(0b10010, &ENTRY_PELLETIZING_4612268880939417810)],
        &[(0b01001, &ENTRY_PELLETIZATION_1256758943430120850)],
        &[(0b01001, &ENTRY_PELLETIZATIONS_1578808908659139702)],
        &[(0b01001, &ENTRY_PELLETIZE_895054063093563526)],
        &[(0b01001, &ENTRY_PELLETIZED_17773084033857349036)],
        &[(0b01001, &ENTRY_PELLETIZER_16282407634028657238)],
        &[(0b01001, &ENTRY_PELLETIZES_10483149214534795271)],
        &[(0b01001, &ENTRY_PELLETIZING_4612268880939417810)],
        &[(0b10010, &ENTRY_PELORIZED_3025534207228128571)],
        &[(0b01001, &ENTRY_PELORIZED_3025534207228128571)],
    ],
    range: 6..=11,
};

static VARS_PEI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEI_CHILDREN),
    value: None,
};

pub static VARS_PEI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("sed"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("sing"),
        dictgen::InsensitiveStr::Ascii("ze"),
        dictgen::InsensitiveStr::Ascii("zed"),
        dictgen::InsensitiveStr::Ascii("zes"),
        dictgen::InsensitiveStr::Ascii("zing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PEIZE_2588318101141868014)],
        &[(0b10010, &ENTRY_PEIZED_375446066448131987)],
        &[(0b10010, &ENTRY_PEIZES_4039009294122552266)],
        &[(0b10010, &ENTRY_PEIZING_1448966680631053962)],
        &[(0b01001, &ENTRY_PEIZE_2588318101141868014)],
        &[(0b01001, &ENTRY_PEIZED_375446066448131987)],
        &[(0b01001, &ENTRY_PEIZES_4039009294122552266)],
        &[(0b01001, &ENTRY_PEIZING_1448966680631053962)],
    ],
    range: 2..=4,
};

static VARS_PED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PED_CHILDREN),
    value: None,
};

static VARS_PED_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PEDA_NODE),
    None,
    None,
    Some(&VARS_PEDD_NODE),
    Some(&VARS_PEDE_NODE),
    None,
    None,
    None,
    Some(&VARS_PEDI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PEDO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PEDO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEDO_CHILDREN),
    value: None,
};

pub static VARS_PEDO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("baptism"),
        dictgen::InsensitiveStr::Ascii("baptist"),
        dictgen::InsensitiveStr::Ascii("dontic"),
        dictgen::InsensitiveStr::Ascii("dontics"),
        dictgen::InsensitiveStr::Ascii("geneses"),
        dictgen::InsensitiveStr::Ascii("genesis"),
        dictgen::InsensitiveStr::Ascii("genetic"),
        dictgen::InsensitiveStr::Ascii("genic"),
        dictgen::InsensitiveStr::Ascii("logical"),
        dictgen::InsensitiveStr::Ascii("logist"),
        dictgen::InsensitiveStr::Ascii("logists"),
        dictgen::InsensitiveStr::Ascii("metrical"),
        dictgen::InsensitiveStr::Ascii("morphic"),
        dictgen::InsensitiveStr::Ascii("morphism"),
        dictgen::InsensitiveStr::Ascii("morphisms"),
        dictgen::InsensitiveStr::Ascii("morphoses"),
        dictgen::InsensitiveStr::Ascii("morphosis"),
        dictgen::InsensitiveStr::Ascii("phile"),
        dictgen::InsensitiveStr::Ascii("philes"),
        dictgen::InsensitiveStr::Ascii("philia"),
        dictgen::InsensitiveStr::Ascii("philiac"),
        dictgen::InsensitiveStr::Ascii("philiacs"),
        dictgen::InsensitiveStr::Ascii("philias"),
        dictgen::InsensitiveStr::Ascii("philic"),
        dictgen::InsensitiveStr::Ascii("tribe"),
        dictgen::InsensitiveStr::Ascii("trophic"),
        dictgen::InsensitiveStr::Ascii("trophist"),
        dictgen::InsensitiveStr::Ascii("trophy"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PEDOBAPTISM_6120739017189134576)],
        &[(0b00001, &ENTRY_PEDOBAPTIST_13392021271448005376)],
        &[(0b00001, &ENTRY_PEDODONTIC_7097035619717257706)],
        &[(0b00001, &ENTRY_PEDODONTICS_8145223833546781144)],
        &[(0b00001, &ENTRY_PEDOGENESES_11751885517659328439)],
        &[(0b00001, &ENTRY_PEDOGENESIS_16553520519907492848)],
        &[(0b00001, &ENTRY_PEDOGENETIC_14694065223630380055)],
        &[(0b00001, &ENTRY_PEDOGENIC_1833539086674286725)],
        &[(0b00001, &ENTRY_PEDOLOGICAL_2385823981182048058)],
        &[(0b00001, &ENTRY_PEDOLOGIST_354177147374191220)],
        &[(0b00001, &ENTRY_PEDOLOGISTS_1566477727057184854)],
        &[(0b00001, &ENTRY_PEDOMETRICAL_17829124265715907889)],
        &[(0b00001, &ENTRY_PEDOMORPHIC_146159920442818415)],
        &[(0b00001, &ENTRY_PEDOMORPHISM_11023075726064362802)],
        &[(0b00001, &ENTRY_PEDOMORPHISMS_7963376961948666057)],
        &[(0b00001, &ENTRY_PEDOMORPHOSES_13196177470788332356)],
        &[(0b00001, &ENTRY_PEDOMORPHOSIS_10919909675152569331)],
        &[(0b11001, &ENTRY_PEDOPHILE_17284081556096473917)],
        &[(0b11001, &ENTRY_PEDOPHILES_18122867727560912141)],
        &[(0b10001, &ENTRY_PEDOPHILIA_6687546858614581858)],
        &[(0b10001, &ENTRY_PEDOPHILIAC_9617447498442302443)],
        &[(0b10001, &ENTRY_PEDOPHILIACS_13603976488274466890)],
        &[(0b10001, &ENTRY_PEDOPHILIAS_7493061271312788807)],
        &[(0b10001, &ENTRY_PEDOPHILIC_17657453635897677867)],
        &[(0b00001, &ENTRY_PEDOTRIBE_8433883032428611364)],
        &[(0b00001, &ENTRY_PEDOTROPHIC_13712350295339661103)],
        &[(0b00001, &ENTRY_PEDOTROPHIST_8546583891936764947)],
        &[(0b00001, &ENTRY_PEDOTROPHY_12360033708377322745)],
    ],
    range: 5..=9,
};

static VARS_PEDI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEDI_CHILDREN),
    value: None,
};

pub static VARS_PEDI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atric"),
        dictgen::InsensitiveStr::Ascii("atrician"),
        dictgen::InsensitiveStr::Ascii("atricians"),
        dictgen::InsensitiveStr::Ascii("atrics"),
        dictgen::InsensitiveStr::Ascii("atrist"),
        dictgen::InsensitiveStr::Ascii("atrists"),
        dictgen::InsensitiveStr::Ascii("atry"),
    ],
    values: &[
        &[(0b11001, &ENTRY_PEDIATRIC_14057388448801273518)],
        &[(0b11001, &ENTRY_PEDIATRICIAN_10944796143655723735)],
        &[(0b11001, &ENTRY_PEDIATRICIANS_11770782104393001942)],
        &[(0b11001, &ENTRY_PEDIATRICS_11689829247825832837)],
        &[(0b00001, &ENTRY_PEDIATRICIAN_10944796143655723735)],
        &[(0b00001, &ENTRY_PEDIATRICIANS_11770782104393001942)],
        &[(0b00001, &ENTRY_PEDIATRY_12652041456225827046)],
    ],
    range: 4..=9,
};

static VARS_PEDE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEDE_CHILDREN),
    value: None,
};

pub static VARS_PEDE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rastic"),
        dictgen::InsensitiveStr::Ascii("rastically"),
        dictgen::InsensitiveStr::Ascii("staled"),
        dictgen::InsensitiveStr::Ascii("staling"),
        dictgen::InsensitiveStr::Ascii("stalled"),
        dictgen::InsensitiveStr::Ascii("stalling"),
        dictgen::InsensitiveStr::Ascii("strianisation"),
        dictgen::InsensitiveStr::Ascii("strianisations"),
        dictgen::InsensitiveStr::Ascii("strianise"),
        dictgen::InsensitiveStr::Ascii("strianised"),
        dictgen::InsensitiveStr::Ascii("strianises"),
        dictgen::InsensitiveStr::Ascii("strianising"),
        dictgen::InsensitiveStr::Ascii("strianization"),
        dictgen::InsensitiveStr::Ascii("strianizations"),
        dictgen::InsensitiveStr::Ascii("strianize"),
        dictgen::InsensitiveStr::Ascii("strianized"),
        dictgen::InsensitiveStr::Ascii("strianizes"),
        dictgen::InsensitiveStr::Ascii("strianizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PEDERASTIC_5749923948076776972)],
        &[(0b00001, &ENTRY_PEDERASTICALLY_851286493260604551)],
        &[(0b00001, &ENTRY_PEDESTALED_15135809349372761183)],
        &[(0b00001, &ENTRY_PEDESTALING_5711575848882675830)],
        &[(0b11010, &ENTRY_PEDESTALED_15135809349372761183)],
        &[(0b11010, &ENTRY_PEDESTALING_5711575848882675830)],
        &[(0b10010, &ENTRY_PEDESTRIANIZATION_10522132408255479732)],
        &[(0b10010, &ENTRY_PEDESTRIANIZATIONS_15701187568960243875)],
        &[(0b10010, &ENTRY_PEDESTRIANIZE_14520784452518295924)],
        &[(0b10010, &ENTRY_PEDESTRIANIZED_13675127004868727770)],
        &[(0b10010, &ENTRY_PEDESTRIANIZES_3493882547527020632)],
        &[(0b10010, &ENTRY_PEDESTRIANIZING_6617534362263439264)],
        &[(0b01001, &ENTRY_PEDESTRIANIZATION_10522132408255479732)],
        &[(0b01001, &ENTRY_PEDESTRIANIZATIONS_15701187568960243875)],
        &[(0b01001, &ENTRY_PEDESTRIANIZE_14520784452518295924)],
        &[(0b01001, &ENTRY_PEDESTRIANIZED_13675127004868727770)],
        &[(0b01001, &ENTRY_PEDESTRIANIZES_3493882547527020632)],
        &[(0b01001, &ENTRY_PEDESTRIANIZING_6617534362263439264)],
    ],
    range: 6..=14,
};

static VARS_PEDD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEDD_CHILDREN),
    value: None,
};

pub static VARS_PEDD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
    ],
    values: &[
        &[(0b01001, &ENTRY_PEDDLER_7340625236288148080)],
        &[(0b01001, &ENTRY_PEDDLERS_13297303646234860431)],
    ],
    range: 3..=4,
};

static VARS_PEDA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEDA_CHILDREN),
    value: None,
};

pub static VARS_PEDA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gog"),
        dictgen::InsensitiveStr::Ascii("gogism"),
        dictgen::InsensitiveStr::Ascii("gogs"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("ller"),
        dictgen::InsensitiveStr::Ascii("llers"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("nticise"),
        dictgen::InsensitiveStr::Ascii("nticised"),
        dictgen::InsensitiveStr::Ascii("nticises"),
        dictgen::InsensitiveStr::Ascii("nticising"),
        dictgen::InsensitiveStr::Ascii("nticize"),
        dictgen::InsensitiveStr::Ascii("nticized"),
        dictgen::InsensitiveStr::Ascii("nticizes"),
        dictgen::InsensitiveStr::Ascii("nticizing"),
        dictgen::InsensitiveStr::Ascii("ntise"),
        dictgen::InsensitiveStr::Ascii("ntised"),
        dictgen::InsensitiveStr::Ascii("ntises"),
        dictgen::InsensitiveStr::Ascii("ntising"),
        dictgen::InsensitiveStr::Ascii("ntize"),
        dictgen::InsensitiveStr::Ascii("ntized"),
        dictgen::InsensitiveStr::Ascii("ntizes"),
        dictgen::InsensitiveStr::Ascii("ntizing"),
        dictgen::InsensitiveStr::Ascii("trophia"),
        dictgen::InsensitiveStr::Ascii("trophy"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PEDAGOGUE_17463305726294731487)],
        &[(0b00001, &ENTRY_PEDAGOGISM_12986063057005247378)],
        &[(0b00001, &ENTRY_PEDAGOGUES_7902989780410302300)],
        &[(0b01001, &ENTRY_PEDALED_11301735024430265900)],
        &[(0b01001, &ENTRY_PEDALER_6897157105660727886)],
        &[(0b01001, &ENTRY_PEDALERS_15975067802508211844)],
        &[(0b01001, &ENTRY_PEDALING_5358000154746792705)],
        &[(0b11010, &ENTRY_PEDALED_11301735024430265900)],
        &[(0b11010, &ENTRY_PEDALER_6897157105660727886)],
        &[(0b11010, &ENTRY_PEDALERS_15975067802508211844)],
        &[(0b11010, &ENTRY_PEDALING_5358000154746792705)],
        &[(0b10010, &ENTRY_PEDANTICIZE_4397269955051838054)],
        &[(0b10010, &ENTRY_PEDANTICIZED_5325771179377667563)],
        &[(0b10010, &ENTRY_PEDANTICIZES_2473214515859949893)],
        &[(0b10010, &ENTRY_PEDANTICIZING_16769706095455553889)],
        &[(0b01001, &ENTRY_PEDANTICIZE_4397269955051838054)],
        &[(0b01001, &ENTRY_PEDANTICIZED_5325771179377667563)],
        &[(0b01001, &ENTRY_PEDANTICIZES_2473214515859949893)],
        &[(0b01001, &ENTRY_PEDANTICIZING_16769706095455553889)],
        &[(0b10010, &ENTRY_PEDANTIZE_16316367695842370347)],
        &[(0b10010, &ENTRY_PEDANTIZED_16507756779947105562)],
        &[(0b10010, &ENTRY_PEDANTIZES_12798801729250307983)],
        &[(0b10010, &ENTRY_PEDANTIZING_4575465028095390897)],
        &[(0b01001, &ENTRY_PEDANTIZE_16316367695842370347)],
        &[(0b01001, &ENTRY_PEDANTIZED_16507756779947105562)],
        &[(0b01001, &ENTRY_PEDANTIZES_12798801729250307983)],
        &[(0b01001, &ENTRY_PEDANTIZING_4575465028095390897)],
        &[(0b00001, &ENTRY_PEDATROPHIA_14603400894477278904)],
        &[(0b00001, &ENTRY_PEDATROPHY_987856254519026242)],
    ],
    range: 3..=9,
};

static VARS_PEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEC_CHILDREN),
    value: None,
};

pub static VARS_PEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tisation"),
        dictgen::InsensitiveStr::Ascii("tisations"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tization"),
        dictgen::InsensitiveStr::Ascii("tizations"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
        dictgen::InsensitiveStr::Ascii("uliarise"),
        dictgen::InsensitiveStr::Ascii("uliarised"),
        dictgen::InsensitiveStr::Ascii("uliarises"),
        dictgen::InsensitiveStr::Ascii("uliarising"),
        dictgen::InsensitiveStr::Ascii("uliarize"),
        dictgen::InsensitiveStr::Ascii("uliarized"),
        dictgen::InsensitiveStr::Ascii("uliarizes"),
        dictgen::InsensitiveStr::Ascii("uliarizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PECTIZATION_10823502370164603724)],
        &[(0b10010, &ENTRY_PECTIZATIONS_6560766904324138817)],
        &[(0b10010, &ENTRY_PECTIZE_5427052689928146895)],
        &[(0b10010, &ENTRY_PECTIZED_4855680733574523884)],
        &[(0b10010, &ENTRY_PECTIZES_9322778985278923283)],
        &[(0b10010, &ENTRY_PECTIZING_14368223699615574041)],
        &[(0b01001, &ENTRY_PECTIZATION_10823502370164603724)],
        &[(0b01001, &ENTRY_PECTIZATIONS_6560766904324138817)],
        &[(0b01001, &ENTRY_PECTIZE_5427052689928146895)],
        &[(0b01001, &ENTRY_PECTIZED_4855680733574523884)],
        &[(0b01001, &ENTRY_PECTIZES_9322778985278923283)],
        &[(0b01001, &ENTRY_PECTIZING_14368223699615574041)],
        &[(0b10010, &ENTRY_PECULIARIZE_5557459505404245071)],
        &[(0b10010, &ENTRY_PECULIARIZED_1480104559580961178)],
        &[(0b10010, &ENTRY_PECULIARIZES_5117499293497869568)],
        &[(0b10010, &ENTRY_PECULIARIZING_16350485573039538930)],
        &[(0b01001, &ENTRY_PECULIARIZE_5557459505404245071)],
        &[(0b01001, &ENTRY_PECULIARIZED_1480104559580961178)],
        &[(0b01001, &ENTRY_PECULIARIZES_5117499293497869568)],
        &[(0b01001, &ENTRY_PECULIARIZING_16350485573039538930)],
    ],
    range: 4..=10,
};

static VARS_PEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEA_CHILDREN),
    value: None,
};

pub static VARS_PEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rlisation"),
        dictgen::InsensitiveStr::Ascii("rlise"),
        dictgen::InsensitiveStr::Ascii("rlised"),
        dictgen::InsensitiveStr::Ascii("rlises"),
        dictgen::InsensitiveStr::Ascii("rlising"),
        dictgen::InsensitiveStr::Ascii("rlization"),
        dictgen::InsensitiveStr::Ascii("rlize"),
        dictgen::InsensitiveStr::Ascii("rlized"),
        dictgen::InsensitiveStr::Ascii("rlizes"),
        dictgen::InsensitiveStr::Ascii("rlizing"),
        dictgen::InsensitiveStr::Ascii("santise"),
        dictgen::InsensitiveStr::Ascii("santises"),
        dictgen::InsensitiveStr::Ascii("santize"),
        dictgen::InsensitiveStr::Ascii("santizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PEARLIZATION_1551638197806205636)],
        &[(0b10010, &ENTRY_PEARLIZE_11311542095439566464)],
        &[(0b10010, &ENTRY_PEARLIZED_14450889956724609032)],
        &[(0b10010, &ENTRY_PEARLIZES_5892211774151827893)],
        &[(0b10010, &ENTRY_PEARLIZING_2645796683659888681)],
        &[(0b01001, &ENTRY_PEARLIZATION_1551638197806205636)],
        &[(0b01001, &ENTRY_PEARLIZE_11311542095439566464)],
        &[(0b01001, &ENTRY_PEARLIZED_14450889956724609032)],
        &[(0b01001, &ENTRY_PEARLIZES_5892211774151827893)],
        &[(0b01001, &ENTRY_PEARLIZING_2645796683659888681)],
        &[(0b10010, &ENTRY_PEASANTIZE_13558495439484194442)],
        &[(0b10010, &ENTRY_PEASANTIZES_6479750851568010639)],
        &[(0b01001, &ENTRY_PEASANTIZE_13558495439484194442)],
        &[(0b01001, &ENTRY_PEASANTIZES_6479750851568010639)],
    ],
    range: 5..=9,
};

static VARS_PA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PA_CHILDREN),
    value: None,
};

static VARS_PA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_PAC_NODE),
    None,
    Some(&VARS_PAE_NODE),
    None,
    Some(&VARS_PAG_NODE),
    None,
    None,
    Some(&VARS_PAJ_NODE),
    None,
    Some(&VARS_PAL_NODE),
    Some(&VARS_PAM_NODE),
    Some(&VARS_PAN_NODE),
    None,
    Some(&VARS_PAP_NODE),
    None,
    Some(&VARS_PAR_NODE),
    Some(&VARS_PAS_NODE),
    Some(&VARS_PAT_NODE),
    Some(&VARS_PAU_NODE),
    Some(&VARS_PAV_NODE),
    None,
    None,
    Some(&VARS_PAY_NODE),
    None,
];

static VARS_PAY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAY_CHILDREN),
    value: None,
};

pub static VARS_PAY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAYNIZE_5649388039598420083)],
        &[(0b10010, &ENTRY_PAYNIZES_13618850850869066244)],
        &[(0b01001, &ENTRY_PAYNIZE_5649388039598420083)],
        &[(0b01001, &ENTRY_PAYNIZES_13618850850869066244)],
    ],
    range: 4..=5,
};

static VARS_PAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAV_CHILDREN),
    value: None,
};

pub static VARS_PAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ior"),
        dictgen::InsensitiveStr::Ascii("iors"),
        dictgen::InsensitiveStr::Ascii("iour"),
        dictgen::InsensitiveStr::Ascii("iours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PAVIOR_15746156113380683198)],
        &[(0b00001, &ENTRY_PAVIORS_6064325610314922380)],
        &[(0b11010, &ENTRY_PAVIOR_15746156113380683198)],
        &[(0b11010, &ENTRY_PAVIORS_6064325610314922380)],
    ],
    range: 3..=5,
};

static VARS_PAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAU_CHILDREN),
    value: None,
};

pub static VARS_PAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("linise"),
        dictgen::InsensitiveStr::Ascii("linises"),
        dictgen::InsensitiveStr::Ascii("linize"),
        dictgen::InsensitiveStr::Ascii("linizes"),
        dictgen::InsensitiveStr::Ascii("perisation"),
        dictgen::InsensitiveStr::Ascii("perisations"),
        dictgen::InsensitiveStr::Ascii("perise"),
        dictgen::InsensitiveStr::Ascii("perised"),
        dictgen::InsensitiveStr::Ascii("periser"),
        dictgen::InsensitiveStr::Ascii("perisers"),
        dictgen::InsensitiveStr::Ascii("perises"),
        dictgen::InsensitiveStr::Ascii("perising"),
        dictgen::InsensitiveStr::Ascii("perization"),
        dictgen::InsensitiveStr::Ascii("perizations"),
        dictgen::InsensitiveStr::Ascii("perize"),
        dictgen::InsensitiveStr::Ascii("perized"),
        dictgen::InsensitiveStr::Ascii("perizer"),
        dictgen::InsensitiveStr::Ascii("perizers"),
        dictgen::InsensitiveStr::Ascii("perizes"),
        dictgen::InsensitiveStr::Ascii("perizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAULINIZE_2460573239735736716)],
        &[(0b10010, &ENTRY_PAULINIZES_16873641534240765118)],
        &[(0b01001, &ENTRY_PAULINIZE_2460573239735736716)],
        &[(0b01001, &ENTRY_PAULINIZES_16873641534240765118)],
        &[(0b10010, &ENTRY_PAUPERIZATION_2161984306553805604)],
        &[(0b10010, &ENTRY_PAUPERIZATIONS_10251769409806507728)],
        &[(0b10010, &ENTRY_PAUPERIZE_18158151809070795878)],
        &[(0b10010, &ENTRY_PAUPERIZED_6686296815894484392)],
        &[(0b10010, &ENTRY_PAUPERIZER_15676497663002877808)],
        &[(0b10010, &ENTRY_PAUPERIZERS_18420726162837139825)],
        &[(0b10010, &ENTRY_PAUPERIZES_13654913193374307039)],
        &[(0b10010, &ENTRY_PAUPERIZING_9202769342367666141)],
        &[(0b01001, &ENTRY_PAUPERIZATION_2161984306553805604)],
        &[(0b01001, &ENTRY_PAUPERIZATIONS_10251769409806507728)],
        &[(0b01001, &ENTRY_PAUPERIZE_18158151809070795878)],
        &[(0b01001, &ENTRY_PAUPERIZED_6686296815894484392)],
        &[(0b01001, &ENTRY_PAUPERIZER_15676497663002877808)],
        &[(0b01001, &ENTRY_PAUPERIZERS_18420726162837139825)],
        &[(0b01001, &ENTRY_PAUPERIZES_13654913193374307039)],
        &[(0b01001, &ENTRY_PAUPERIZING_9202769342367666141)],
    ],
    range: 6..=11,
};

static VARS_PAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAT_CHILDREN),
    value: None,
};

pub static VARS_PAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ernalise"),
        dictgen::InsensitiveStr::Ascii("ernalises"),
        dictgen::InsensitiveStr::Ascii("ernalize"),
        dictgen::InsensitiveStr::Ascii("ernalizes"),
        dictgen::InsensitiveStr::Ascii("inae"),
        dictgen::InsensitiveStr::Ascii("inaed"),
        dictgen::InsensitiveStr::Ascii("ine"),
        dictgen::InsensitiveStr::Ascii("ined"),
        dictgen::InsensitiveStr::Ascii("rialisation"),
        dictgen::InsensitiveStr::Ascii("rialisations"),
        dictgen::InsensitiveStr::Ascii("rialise"),
        dictgen::InsensitiveStr::Ascii("rialised"),
        dictgen::InsensitiveStr::Ascii("rialises"),
        dictgen::InsensitiveStr::Ascii("rialising"),
        dictgen::InsensitiveStr::Ascii("rialization"),
        dictgen::InsensitiveStr::Ascii("rializations"),
        dictgen::InsensitiveStr::Ascii("rialize"),
        dictgen::InsensitiveStr::Ascii("rialized"),
        dictgen::InsensitiveStr::Ascii("rializes"),
        dictgen::InsensitiveStr::Ascii("rializing"),
        dictgen::InsensitiveStr::Ascii("rices"),
        dictgen::InsensitiveStr::Ascii("ricoes"),
        dictgen::InsensitiveStr::Ascii("ronisable"),
        dictgen::InsensitiveStr::Ascii("ronisabler"),
        dictgen::InsensitiveStr::Ascii("ronisables"),
        dictgen::InsensitiveStr::Ascii("ronisablest"),
        dictgen::InsensitiveStr::Ascii("ronisation"),
        dictgen::InsensitiveStr::Ascii("ronisations"),
        dictgen::InsensitiveStr::Ascii("ronise"),
        dictgen::InsensitiveStr::Ascii("ronised"),
        dictgen::InsensitiveStr::Ascii("roniser"),
        dictgen::InsensitiveStr::Ascii("ronisers"),
        dictgen::InsensitiveStr::Ascii("ronises"),
        dictgen::InsensitiveStr::Ascii("ronising"),
        dictgen::InsensitiveStr::Ascii("ronisinglier"),
        dictgen::InsensitiveStr::Ascii("ronisingliest"),
        dictgen::InsensitiveStr::Ascii("ronisingly"),
        dictgen::InsensitiveStr::Ascii("ronisings"),
        dictgen::InsensitiveStr::Ascii("ronizable"),
        dictgen::InsensitiveStr::Ascii("ronizabler"),
        dictgen::InsensitiveStr::Ascii("ronizables"),
        dictgen::InsensitiveStr::Ascii("ronizablest"),
        dictgen::InsensitiveStr::Ascii("ronization"),
        dictgen::InsensitiveStr::Ascii("ronizations"),
        dictgen::InsensitiveStr::Ascii("ronize"),
        dictgen::InsensitiveStr::Ascii("ronized"),
        dictgen::InsensitiveStr::Ascii("ronizer"),
        dictgen::InsensitiveStr::Ascii("ronizers"),
        dictgen::InsensitiveStr::Ascii("ronizes"),
        dictgen::InsensitiveStr::Ascii("ronizing"),
        dictgen::InsensitiveStr::Ascii("ronizinglier"),
        dictgen::InsensitiveStr::Ascii("ronizingliest"),
        dictgen::InsensitiveStr::Ascii("ronizingly"),
        dictgen::InsensitiveStr::Ascii("ronizings"),
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("ternise"),
        dictgen::InsensitiveStr::Ascii("ternises"),
        dictgen::InsensitiveStr::Ascii("ternize"),
        dictgen::InsensitiveStr::Ascii("ternizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PATERNALIZE_17612845585576962910)],
        &[(0b10010, &ENTRY_PATERNALIZES_6090370098103830575)],
        &[(0b01001, &ENTRY_PATERNALIZE_17612845585576962910)],
        &[(0b01001, &ENTRY_PATERNALIZES_6090370098103830575)],
        &[(0b11010, &ENTRY_PATINE_2383187798704264861)],
        &[(0b11010, &ENTRY_PATINED_17741036475179872327)],
        &[(0b00001, &ENTRY_PATINE_2383187798704264861)],
        &[(0b00001, &ENTRY_PATINED_17741036475179872327)],
        &[(0b10010, &ENTRY_PATRIALIZATION_9949115296750967273)],
        &[(0b10010, &ENTRY_PATRIALIZATIONS_8913404008720113294)],
        &[(0b10010, &ENTRY_PATRIALIZE_2025590991584754634)],
        &[(0b10010, &ENTRY_PATRIALIZED_438648802317738966)],
        &[(0b10010, &ENTRY_PATRIALIZES_14381499556205684969)],
        &[(0b10010, &ENTRY_PATRIALIZING_12870398855810619317)],
        &[(0b01001, &ENTRY_PATRIALIZATION_9949115296750967273)],
        &[(0b01001, &ENTRY_PATRIALIZATIONS_8913404008720113294)],
        &[(0b01001, &ENTRY_PATRIALIZE_2025590991584754634)],
        &[(0b01001, &ENTRY_PATRIALIZED_438648802317738966)],
        &[(0b01001, &ENTRY_PATRIALIZES_14381499556205684969)],
        &[(0b01001, &ENTRY_PATRIALIZING_12870398855810619317)],
        &[(0b00001, &ENTRY_PATRICES_7408034855473052638)],
        &[(0b11010, &ENTRY_PATRICES_7408034855473052638)],
        &[(0b10010, &ENTRY_PATRONIZABLE_18388697617212249244)],
        &[(0b10010, &ENTRY_PATRONIZABLER_8283184479282006483)],
        &[(0b10010, &ENTRY_PATRONIZABLES_7300624032056980557)],
        &[(0b10010, &ENTRY_PATRONIZABLEST_307591711490088244)],
        &[(0b10010, &ENTRY_PATRONIZATION_10398895486217879996)],
        &[(0b10010, &ENTRY_PATRONIZATIONS_18089723998023320020)],
        &[(0b10010, &ENTRY_PATRONIZE_2120552335415939536)],
        &[(0b10010, &ENTRY_PATRONIZED_11064398139600850345)],
        &[(0b10010, &ENTRY_PATRONIZER_10813433458376234707)],
        &[(0b10010, &ENTRY_PATRONIZERS_11272030543646937310)],
        &[(0b10010, &ENTRY_PATRONIZES_11395708073720458865)],
        &[(0b10010, &ENTRY_PATRONIZING_12434118065877059973)],
        &[(0b10010, &ENTRY_PATRONIZINGLIER_302802414773543310)],
        &[(0b10010, &ENTRY_PATRONIZINGLIEST_16305371931388137130)],
        &[(0b10010, &ENTRY_PATRONIZINGLY_6847062421337873239)],
        &[(0b10010, &ENTRY_PATRONIZINGS_13629575403778748423)],
        &[(0b01001, &ENTRY_PATRONIZABLE_18388697617212249244)],
        &[(0b01001, &ENTRY_PATRONIZABLER_8283184479282006483)],
        &[(0b01001, &ENTRY_PATRONIZABLES_7300624032056980557)],
        &[(0b01001, &ENTRY_PATRONIZABLEST_307591711490088244)],
        &[(0b01001, &ENTRY_PATRONIZATION_10398895486217879996)],
        &[(0b01001, &ENTRY_PATRONIZATIONS_18089723998023320020)],
        &[(0b01001, &ENTRY_PATRONIZE_2120552335415939536)],
        &[(0b01001, &ENTRY_PATRONIZED_11064398139600850345)],
        &[(0b01001, &ENTRY_PATRONIZER_10813433458376234707)],
        &[(0b01001, &ENTRY_PATRONIZERS_11272030543646937310)],
        &[(0b01001, &ENTRY_PATRONIZES_11395708073720458865)],
        &[(0b01001, &ENTRY_PATRONIZING_12434118065877059973)],
        &[(0b01001, &ENTRY_PATRONIZINGLIER_302802414773543310)],
        &[(0b01001, &ENTRY_PATRONIZINGLIEST_16305371931388137130)],
        &[(0b01001, &ENTRY_PATRONIZINGLY_6847062421337873239)],
        &[(0b01001, &ENTRY_PATRONIZINGS_13629575403778748423)],
        &[(0b11010, &ENTRY_PATTE_8336102578296137635)],
        &[(0b00001, &ENTRY_PATTE_8336102578296137635)],
        &[(0b10010, &ENTRY_PATTERNIZE_5417694889107920916)],
        &[(0b10010, &ENTRY_PATTERNIZES_5545508925274719419)],
        &[(0b01001, &ENTRY_PATTERNIZE_5417694889107920916)],
        &[(0b01001, &ENTRY_PATTERNIZES_5545508925274719419)],
    ],
    range: 2..=13,
};

static VARS_PAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAS_CHILDREN),
    value: None,
};

pub static VARS_PAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iphaae"),
        dictgen::InsensitiveStr::Ascii("iphae"),
        dictgen::InsensitiveStr::Ascii("sades"),
        dictgen::InsensitiveStr::Ascii("sadoes"),
        dictgen::InsensitiveStr::Ascii("sivisation"),
        dictgen::InsensitiveStr::Ascii("sivization"),
        dictgen::InsensitiveStr::Ascii("teurisation"),
        dictgen::InsensitiveStr::Ascii("teurisations"),
        dictgen::InsensitiveStr::Ascii("teurise"),
        dictgen::InsensitiveStr::Ascii("teurised"),
        dictgen::InsensitiveStr::Ascii("teuriser"),
        dictgen::InsensitiveStr::Ascii("teurisers"),
        dictgen::InsensitiveStr::Ascii("teurises"),
        dictgen::InsensitiveStr::Ascii("teurising"),
        dictgen::InsensitiveStr::Ascii("teurization"),
        dictgen::InsensitiveStr::Ascii("teurizations"),
        dictgen::InsensitiveStr::Ascii("teurize"),
        dictgen::InsensitiveStr::Ascii("teurized"),
        dictgen::InsensitiveStr::Ascii("teurizer"),
        dictgen::InsensitiveStr::Ascii("teurizers"),
        dictgen::InsensitiveStr::Ascii("teurizes"),
        dictgen::InsensitiveStr::Ascii("teurizing"),
        dictgen::InsensitiveStr::Ascii("toralise"),
        dictgen::InsensitiveStr::Ascii("toralises"),
        dictgen::InsensitiveStr::Ascii("toralize"),
        dictgen::InsensitiveStr::Ascii("toralizes"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PASIPHAE_14757892558890999139)],
        &[(0b00001, &ENTRY_PASIPHAE_14757892558890999139)],
        &[(0b00001, &ENTRY_PASSADES_14898665474288463392)],
        &[(0b11010, &ENTRY_PASSADES_14898665474288463392)],
        &[(0b10010, &ENTRY_PASSIVIZATION_14555794353650852047)],
        &[(0b01001, &ENTRY_PASSIVIZATION_14555794353650852047)],
        &[(0b10010, &ENTRY_PASTEURIZATION_15699653175330456323)],
        &[(0b10010, &ENTRY_PASTEURIZATIONS_2915811841905287610)],
        &[(0b10010, &ENTRY_PASTEURIZE_163174462491369649)],
        &[(0b10010, &ENTRY_PASTEURIZED_13548937625186713170)],
        &[(0b10010, &ENTRY_PASTEURIZER_2458848217830417439)],
        &[(0b10010, &ENTRY_PASTEURIZERS_15085534957712496351)],
        &[(0b10010, &ENTRY_PASTEURIZES_5846494049033549631)],
        &[(0b10010, &ENTRY_PASTEURIZING_15425456478399382152)],
        &[(0b01001, &ENTRY_PASTEURIZATION_15699653175330456323)],
        &[(0b01001, &ENTRY_PASTEURIZATIONS_2915811841905287610)],
        &[(0b01001, &ENTRY_PASTEURIZE_163174462491369649)],
        &[(0b01001, &ENTRY_PASTEURIZED_13548937625186713170)],
        &[(0b01001, &ENTRY_PASTEURIZER_2458848217830417439)],
        &[(0b01001, &ENTRY_PASTEURIZERS_15085534957712496351)],
        &[(0b01001, &ENTRY_PASTEURIZES_5846494049033549631)],
        &[(0b01001, &ENTRY_PASTEURIZING_15425456478399382152)],
        &[(0b10010, &ENTRY_PASTORALIZE_14882784365438844418)],
        &[(0b10010, &ENTRY_PASTORALIZES_6186051459304798026)],
        &[(0b01001, &ENTRY_PASTORALIZE_14882784365438844418)],
        &[(0b01001, &ENTRY_PASTORALIZES_6186051459304798026)],
        &[(0b10010, &ENTRY_PASTORIZE_17256510429688032591)],
        &[(0b10010, &ENTRY_PASTORIZES_18160198317277729221)],
        &[(0b01001, &ENTRY_PASTORIZE_17256510429688032591)],
        &[(0b01001, &ENTRY_PASTORIZES_18160198317277729221)],
    ],
    range: 5..=12,
};

static VARS_PAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PAR_CHILDREN),
    value: None,
};

static VARS_PAR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PARA_NODE),
    None,
    Some(&VARS_PARC_NODE),
    None,
    Some(&VARS_PARE_NODE),
    Some(&VARS_PARF_NODE),
    None,
    None,
    Some(&VARS_PARI_NODE),
    None,
    None,
    Some(&VARS_PARL_NODE),
    None,
    None,
    Some(&VARS_PARO_NODE),
    None,
    None,
    Some(&VARS_PARR_NODE),
    Some(&VARS_PARS_NODE),
    Some(&VARS_PART_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PART_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PART_CHILDREN),
    value: None,
};

pub static VARS_PART_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialised"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialising"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ialized"),
        dictgen::InsensitiveStr::Ascii("ializes"),
        dictgen::InsensitiveStr::Ascii("ializing"),
        dictgen::InsensitiveStr::Ascii("icolored"),
        dictgen::InsensitiveStr::Ascii("icoloredder"),
        dictgen::InsensitiveStr::Ascii("icoloreddest"),
        dictgen::InsensitiveStr::Ascii("icoloured"),
        dictgen::InsensitiveStr::Ascii("icolouredder"),
        dictgen::InsensitiveStr::Ascii("icoloureddest"),
        dictgen::InsensitiveStr::Ascii("icularisation"),
        dictgen::InsensitiveStr::Ascii("icularisations"),
        dictgen::InsensitiveStr::Ascii("icularise"),
        dictgen::InsensitiveStr::Ascii("icularised"),
        dictgen::InsensitiveStr::Ascii("iculariser"),
        dictgen::InsensitiveStr::Ascii("icularises"),
        dictgen::InsensitiveStr::Ascii("icularising"),
        dictgen::InsensitiveStr::Ascii("icularization"),
        dictgen::InsensitiveStr::Ascii("icularizations"),
        dictgen::InsensitiveStr::Ascii("icularize"),
        dictgen::InsensitiveStr::Ascii("icularized"),
        dictgen::InsensitiveStr::Ascii("icularizer"),
        dictgen::InsensitiveStr::Ascii("icularizes"),
        dictgen::InsensitiveStr::Ascii("icularizing"),
        dictgen::InsensitiveStr::Ascii("isanise"),
        dictgen::InsensitiveStr::Ascii("isanises"),
        dictgen::InsensitiveStr::Ascii("isanize"),
        dictgen::InsensitiveStr::Ascii("isanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARTIALIZE_1962663665740826203)],
        &[(0b10010, &ENTRY_PARTIALIZED_4252087159550355238)],
        &[(0b10010, &ENTRY_PARTIALIZES_6032034501365058234)],
        &[(0b10010, &ENTRY_PARTIALIZING_12669034655608424199)],
        &[(0b01001, &ENTRY_PARTIALIZE_1962663665740826203)],
        &[(0b01001, &ENTRY_PARTIALIZED_4252087159550355238)],
        &[(0b01001, &ENTRY_PARTIALIZES_6032034501365058234)],
        &[(0b01001, &ENTRY_PARTIALIZING_12669034655608424199)],
        &[(0b10001, &ENTRY_PARTICOLORED_13675013999250147429)],
        &[(0b10001, &ENTRY_PARTICOLOREDDER_9511263899731979802)],
        &[(0b10001, &ENTRY_PARTICOLOREDDEST_1358436328033457410)],
        &[(0b11010, &ENTRY_PARTICOLORED_13675013999250147429)],
        &[(0b11010, &ENTRY_PARTICOLOREDDER_9511263899731979802)],
        &[(0b11010, &ENTRY_PARTICOLOREDDEST_1358436328033457410)],
        &[(0b10010, &ENTRY_PARTICULARIZATION_15085297445135933435)],
        &[(0b10010, &ENTRY_PARTICULARIZATIONS_7496757883724885887)],
        &[(0b10010, &ENTRY_PARTICULARIZE_15520939813264385830)],
        &[(0b10010, &ENTRY_PARTICULARIZED_11569157644638431290)],
        &[(0b10010, &ENTRY_PARTICULARIZER_14936600870613435660)],
        &[(0b10010, &ENTRY_PARTICULARIZES_8370763796403583228)],
        &[(0b10010, &ENTRY_PARTICULARIZING_5658452593803942085)],
        &[(0b01001, &ENTRY_PARTICULARIZATION_15085297445135933435)],
        &[(0b01001, &ENTRY_PARTICULARIZATIONS_7496757883724885887)],
        &[(0b01001, &ENTRY_PARTICULARIZE_15520939813264385830)],
        &[(0b01001, &ENTRY_PARTICULARIZED_11569157644638431290)],
        &[(0b01001, &ENTRY_PARTICULARIZER_14936600870613435660)],
        &[(0b01001, &ENTRY_PARTICULARIZES_8370763796403583228)],
        &[(0b01001, &ENTRY_PARTICULARIZING_5658452593803942085)],
        &[(0b10010, &ENTRY_PARTISANIZE_2022426188255513510)],
        &[(0b10010, &ENTRY_PARTISANIZES_1728318026660141228)],
        &[(0b01001, &ENTRY_PARTISANIZE_2022426188255513510)],
        &[(0b01001, &ENTRY_PARTISANIZES_1728318026660141228)],
    ],
    range: 6..=14,
};

static VARS_PARS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARS_CHILDREN),
    value: None,
};

pub static VARS_PARS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARSONIZE_6711982105966566323)],
        &[(0b10010, &ENTRY_PARSONIZES_8755384066719912504)],
        &[(0b01001, &ENTRY_PARSONIZE_6711982105966566323)],
        &[(0b01001, &ENTRY_PARSONIZES_8755384066719912504)],
    ],
    range: 5..=6,
};

static VARS_PARR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARR_CHILDREN),
    value: None,
};

pub static VARS_PARR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARROTIZE_6855799754055791992)],
        &[(0b10010, &ENTRY_PARROTIZES_11339528989147708955)],
        &[(0b01001, &ENTRY_PARROTIZE_6855799754055791992)],
        &[(0b01001, &ENTRY_PARROTIZES_11339528989147708955)],
    ],
    range: 5..=6,
};

static VARS_PARO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARO_CHILDREN),
    value: None,
};

pub static VARS_PARO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chialisation"),
        dictgen::InsensitiveStr::Ascii("chialisations"),
        dictgen::InsensitiveStr::Ascii("chialise"),
        dictgen::InsensitiveStr::Ascii("chialised"),
        dictgen::InsensitiveStr::Ascii("chialises"),
        dictgen::InsensitiveStr::Ascii("chialising"),
        dictgen::InsensitiveStr::Ascii("chialization"),
        dictgen::InsensitiveStr::Ascii("chializations"),
        dictgen::InsensitiveStr::Ascii("chialize"),
        dictgen::InsensitiveStr::Ascii("chialized"),
        dictgen::InsensitiveStr::Ascii("chializes"),
        dictgen::InsensitiveStr::Ascii("chializing"),
        dictgen::InsensitiveStr::Ascii("ecious"),
        dictgen::InsensitiveStr::Ascii("eciously"),
        dictgen::InsensitiveStr::Ascii("eciousness"),
        dictgen::InsensitiveStr::Ascii("ecism"),
        dictgen::InsensitiveStr::Ascii("ecy"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAROCHIALIZATION_14100344379237107874)],
        &[(0b10010, &ENTRY_PAROCHIALIZATIONS_16574969241210280652)],
        &[(0b10010, &ENTRY_PAROCHIALIZE_1801958382160346709)],
        &[(0b10010, &ENTRY_PAROCHIALIZED_7303132907572634206)],
        &[(0b10010, &ENTRY_PAROCHIALIZES_6747512001914510504)],
        &[(0b10010, &ENTRY_PAROCHIALIZING_675693589145640380)],
        &[(0b01001, &ENTRY_PAROCHIALIZATION_14100344379237107874)],
        &[(0b01001, &ENTRY_PAROCHIALIZATIONS_16574969241210280652)],
        &[(0b01001, &ENTRY_PAROCHIALIZE_1801958382160346709)],
        &[(0b01001, &ENTRY_PAROCHIALIZED_7303132907572634206)],
        &[(0b01001, &ENTRY_PAROCHIALIZES_6747512001914510504)],
        &[(0b01001, &ENTRY_PAROCHIALIZING_675693589145640380)],
        &[(0b11010, &ENTRY_PARECIOUS_14569683298578543735)],
        &[(0b11010, &ENTRY_PARECIOUSLY_1136225838796007635)],
        &[(0b11010, &ENTRY_PARECIOUSNESS_14170146750788160014)],
        &[(0b11010, &ENTRY_PARECISM_16138695721790138925)],
        &[(0b11010, &ENTRY_PARECY_16642153001069896304)],
    ],
    range: 3..=13,
};

static VARS_PARL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARL_CHILDREN),
    value: None,
};

pub static VARS_PARL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("orish"),
        dictgen::InsensitiveStr::Ascii("ormaid"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ourish"),
        dictgen::InsensitiveStr::Ascii("ourmaid"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_PARLOR_5988253503224208460)],
        &[(0b00001, &ENTRY_PARLORISH_13017991595146743483)],
        &[(0b10001, &ENTRY_PARLORMAID_4150851883941162027)],
        &[(0b11001, &ENTRY_PARLORS_13263653608415272696)],
        &[(0b11010, &ENTRY_PARLOR_5988253503224208460)],
        &[(0b11010, &ENTRY_PARLORISH_13017991595146743483)],
        &[(0b11010, &ENTRY_PARLORMAID_4150851883941162027)],
        &[(0b11010, &ENTRY_PARLORS_13263653608415272696)],
    ],
    range: 2..=7,
};

static VARS_PARI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARI_CHILDREN),
    value: None,
};

pub static VARS_PARI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sianisation"),
        dictgen::InsensitiveStr::Ascii("sianisations"),
        dictgen::InsensitiveStr::Ascii("sianise"),
        dictgen::InsensitiveStr::Ascii("sianises"),
        dictgen::InsensitiveStr::Ascii("sianization"),
        dictgen::InsensitiveStr::Ascii("sianizations"),
        dictgen::InsensitiveStr::Ascii("sianize"),
        dictgen::InsensitiveStr::Ascii("sianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARISIANIZATION_8796044822297406094)],
        &[(0b10010, &ENTRY_PARISIANIZATIONS_4850617849122164225)],
        &[(0b10010, &ENTRY_PARISIANIZE_18132108741295808736)],
        &[(0b10010, &ENTRY_PARISIANIZES_15357022119572583625)],
        &[(0b01001, &ENTRY_PARISIANIZATION_8796044822297406094)],
        &[(0b01001, &ENTRY_PARISIANIZATIONS_4850617849122164225)],
        &[(0b01001, &ENTRY_PARISIANIZE_18132108741295808736)],
        &[(0b01001, &ENTRY_PARISIANIZES_15357022119572583625)],
    ],
    range: 7..=12,
};

static VARS_PARF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARF_CHILDREN),
    value: None,
};

pub static VARS_PARF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ocalisation"),
        dictgen::InsensitiveStr::Ascii("ocalise"),
        dictgen::InsensitiveStr::Ascii("ocalization"),
        dictgen::InsensitiveStr::Ascii("ocalize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARFOCALIZATION_2105460359882027002)],
        &[(0b10010, &ENTRY_PARFOCALIZE_17464433649035265735)],
        &[(0b01001, &ENTRY_PARFOCALIZATION_2105460359882027002)],
        &[(0b01001, &ENTRY_PARFOCALIZE_17464433649035265735)],
    ],
    range: 7..=11,
};

static VARS_PARE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARE_CHILDREN),
    value: None,
};

pub static VARS_PARE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cious"),
        dictgen::InsensitiveStr::Ascii("ciously"),
        dictgen::InsensitiveStr::Ascii("ciousness"),
        dictgen::InsensitiveStr::Ascii("cism"),
        dictgen::InsensitiveStr::Ascii("cy"),
        dictgen::InsensitiveStr::Ascii("neses"),
        dictgen::InsensitiveStr::Ascii("nesis"),
        dictgen::InsensitiveStr::Ascii("netic"),
        dictgen::InsensitiveStr::Ascii("netical"),
        dictgen::InsensitiveStr::Ascii("nthesisation"),
        dictgen::InsensitiveStr::Ascii("nthesise"),
        dictgen::InsensitiveStr::Ascii("nthesised"),
        dictgen::InsensitiveStr::Ascii("nthesises"),
        dictgen::InsensitiveStr::Ascii("nthesising"),
        dictgen::InsensitiveStr::Ascii("nthesization"),
        dictgen::InsensitiveStr::Ascii("nthesize"),
        dictgen::InsensitiveStr::Ascii("nthesized"),
        dictgen::InsensitiveStr::Ascii("nthesizes"),
        dictgen::InsensitiveStr::Ascii("nthesizing"),
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PARECIOUS_14569683298578543735)],
        &[(0b10001, &ENTRY_PARECIOUSLY_1136225838796007635)],
        &[(0b10001, &ENTRY_PARECIOUSNESS_14170146750788160014)],
        &[(0b10001, &ENTRY_PARECISM_16138695721790138925)],
        &[(0b10001, &ENTRY_PARECY_16642153001069896304)],
        &[(0b10001, &ENTRY_PARENESES_15075590434109366156)],
        &[(0b10001, &ENTRY_PARENESIS_10831614342484659031)],
        &[(0b10001, &ENTRY_PARENETIC_14670463709273075800)],
        &[(0b10001, &ENTRY_PARENETICAL_7355921821382251766)],
        &[(0b10010, &ENTRY_PARENTHESIZATION_13202063789668639765)],
        &[(0b10010, &ENTRY_PARENTHESIZE_16232933755981914094)],
        &[(0b10010, &ENTRY_PARENTHESIZED_3648906989752316418)],
        &[(0b10010, &ENTRY_PARENTHESIZES_9065065510113606774)],
        &[(0b10010, &ENTRY_PARENTHESIZING_632457343746225122)],
        &[(0b01001, &ENTRY_PARENTHESIZATION_13202063789668639765)],
        &[(0b01001, &ENTRY_PARENTHESIZE_16232933755981914094)],
        &[(0b01001, &ENTRY_PARENTHESIZED_3648906989752316418)],
        &[(0b01001, &ENTRY_PARENTHESIZES_9065065510113606774)],
        &[(0b01001, &ENTRY_PARENTHESIZING_632457343746225122)],
        &[(0b10001, &ENTRY_PARESTHESIA_6053545970539213078)],
        &[(0b10001, &ENTRY_PARESTHESIAS_12326929322577395759)],
        &[(0b10001, &ENTRY_PARESTHETIC_7625031320540803873)],
    ],
    range: 2..=12,
};

static VARS_PARC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARC_CHILDREN),
    value: None,
};

pub static VARS_PARC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("hmentise"),
        dictgen::InsensitiveStr::Ascii("hmentised"),
        dictgen::InsensitiveStr::Ascii("hmentises"),
        dictgen::InsensitiveStr::Ascii("hmentising"),
        dictgen::InsensitiveStr::Ascii("hmentize"),
        dictgen::InsensitiveStr::Ascii("hmentized"),
        dictgen::InsensitiveStr::Ascii("hmentizes"),
        dictgen::InsensitiveStr::Ascii("hmentizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PARCELED_6170016542434984869)],
        &[(0b00001, &ENTRY_PARCELER_17576388958982772521)],
        &[(0b00001, &ENTRY_PARCELING_851710970245334651)],
        &[(0b11010, &ENTRY_PARCELED_6170016542434984869)],
        &[(0b11010, &ENTRY_PARCELER_17576388958982772521)],
        &[(0b11010, &ENTRY_PARCELING_851710970245334651)],
        &[(0b10010, &ENTRY_PARCHMENTIZE_1939046984216613974)],
        &[(0b10010, &ENTRY_PARCHMENTIZED_16479603540981235266)],
        &[(0b10010, &ENTRY_PARCHMENTIZES_844658164566902891)],
        &[(0b10010, &ENTRY_PARCHMENTIZING_15031589244698001883)],
        &[(0b01001, &ENTRY_PARCHMENTIZE_1939046984216613974)],
        &[(0b01001, &ENTRY_PARCHMENTIZED_16479603540981235266)],
        &[(0b01001, &ENTRY_PARCHMENTIZES_844658164566902891)],
        &[(0b01001, &ENTRY_PARCHMENTIZING_15031589244698001883)],
    ],
    range: 4..=10,
};

static VARS_PARA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PARA_CHILDREN),
    value: None,
};

static VARS_PARA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_PARAB_NODE),
    None,
    None,
    Some(&VARS_PARAE_NODE),
    Some(&VARS_PARAF_NODE),
    Some(&VARS_PARAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_PARAL_NODE),
    Some(&VARS_PARAM_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PARAS_NODE),
    Some(&VARS_PARAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PARAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAT_CHILDREN),
    value: None,
};

pub static VARS_PARAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hyroidectomise"),
        dictgen::InsensitiveStr::Ascii("hyroidectomised"),
        dictgen::InsensitiveStr::Ascii("hyroidectomises"),
        dictgen::InsensitiveStr::Ascii("hyroidectomising"),
        dictgen::InsensitiveStr::Ascii("hyroidectomize"),
        dictgen::InsensitiveStr::Ascii("hyroidectomized"),
        dictgen::InsensitiveStr::Ascii("hyroidectomizes"),
        dictgen::InsensitiveStr::Ascii("hyroidectomizing"),
        dictgen::InsensitiveStr::Ascii("ragedia"),
        dictgen::InsensitiveStr::Ascii("ragoedia"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARATHYROIDECTOMIZE_14484344006380038665)],
        &[(0b10010, &ENTRY_PARATHYROIDECTOMIZED_5474592337131298831)],
        &[(0b10010, &ENTRY_PARATHYROIDECTOMIZES_2007746234745477770)],
        &[(0b10010, &ENTRY_PARATHYROIDECTOMIZING_123904040877460171)],
        &[(0b01001, &ENTRY_PARATHYROIDECTOMIZE_14484344006380038665)],
        &[(0b01001, &ENTRY_PARATHYROIDECTOMIZED_5474592337131298831)],
        &[(0b01001, &ENTRY_PARATHYROIDECTOMIZES_2007746234745477770)],
        &[(0b01001, &ENTRY_PARATHYROIDECTOMIZING_123904040877460171)],
        &[(0b00001, &ENTRY_PARATRAGEDIA_16004760938575301167)],
        &[(0b11010, &ENTRY_PARATRAGEDIA_16004760938575301167)],
    ],
    range: 7..=16,
};

static VARS_PARAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAS_CHILDREN),
    value: None,
};

pub static VARS_PARAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elenae"),
        dictgen::InsensitiveStr::Ascii("elene"),
        dictgen::InsensitiveStr::Ascii("itaemia"),
        dictgen::InsensitiveStr::Ascii("itemia"),
        dictgen::InsensitiveStr::Ascii("itisation"),
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itization"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PARASELENE_6912874048936205670)],
        &[(0b00001, &ENTRY_PARASELENE_6912874048936205670)],
        &[(0b11010, &ENTRY_PARASITEMIA_6177658356922218519)],
        &[(0b10001, &ENTRY_PARASITEMIA_6177658356922218519)],
        &[(0b10010, &ENTRY_PARASITIZATION_10764422602155636226)],
        &[(0b10010, &ENTRY_PARASITIZE_10442537268642059851)],
        &[(0b10010, &ENTRY_PARASITIZED_17454588215531391347)],
        &[(0b10010, &ENTRY_PARASITIZES_15093324507866591370)],
        &[(0b10010, &ENTRY_PARASITIZING_13253219762304399299)],
        &[(0b01001, &ENTRY_PARASITIZATION_10764422602155636226)],
        &[(0b01001, &ENTRY_PARASITIZE_10442537268642059851)],
        &[(0b01001, &ENTRY_PARASITIZED_17454588215531391347)],
        &[(0b01001, &ENTRY_PARASITIZES_15093324507866591370)],
        &[(0b01001, &ENTRY_PARASITIZING_13253219762304399299)],
    ],
    range: 5..=9,
};

static VARS_PARAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAM_CHILDREN),
    value: None,
};

pub static VARS_PARAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecium"),
        dictgen::InsensitiveStr::Ascii("eterisable"),
        dictgen::InsensitiveStr::Ascii("eterisation"),
        dictgen::InsensitiveStr::Ascii("eterisations"),
        dictgen::InsensitiveStr::Ascii("eterise"),
        dictgen::InsensitiveStr::Ascii("eterised"),
        dictgen::InsensitiveStr::Ascii("eterises"),
        dictgen::InsensitiveStr::Ascii("eterising"),
        dictgen::InsensitiveStr::Ascii("eterizable"),
        dictgen::InsensitiveStr::Ascii("eterization"),
        dictgen::InsensitiveStr::Ascii("eterizations"),
        dictgen::InsensitiveStr::Ascii("eterize"),
        dictgen::InsensitiveStr::Ascii("eterized"),
        dictgen::InsensitiveStr::Ascii("eterizes"),
        dictgen::InsensitiveStr::Ascii("eterizing"),
        dictgen::InsensitiveStr::Ascii("etrisable"),
        dictgen::InsensitiveStr::Ascii("etrisation"),
        dictgen::InsensitiveStr::Ascii("etrisations"),
        dictgen::InsensitiveStr::Ascii("etrise"),
        dictgen::InsensitiveStr::Ascii("etrised"),
        dictgen::InsensitiveStr::Ascii("etrises"),
        dictgen::InsensitiveStr::Ascii("etrising"),
        dictgen::InsensitiveStr::Ascii("etrizable"),
        dictgen::InsensitiveStr::Ascii("etrization"),
        dictgen::InsensitiveStr::Ascii("etrizations"),
        dictgen::InsensitiveStr::Ascii("etrize"),
        dictgen::InsensitiveStr::Ascii("etrized"),
        dictgen::InsensitiveStr::Ascii("etrizes"),
        dictgen::InsensitiveStr::Ascii("etrizing"),
        dictgen::InsensitiveStr::Ascii("oecium"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PARAMECIUM_3779667447675673813)],
        &[(0b10010, &ENTRY_PARAMETERIZABLE_8797908909194558616)],
        &[(0b10010, &ENTRY_PARAMETERIZATION_11837209911752300457)],
        &[(0b10010, &ENTRY_PARAMETERIZATIONS_7162471395165876296)],
        &[(0b10010, &ENTRY_PARAMETERIZE_15902800810917069503)],
        &[(0b10010, &ENTRY_PARAMETERIZED_10523524909406136092)],
        &[(0b10010, &ENTRY_PARAMETERIZES_16321927350979537220)],
        &[(0b10010, &ENTRY_PARAMETERIZING_17336476515168482632)],
        &[(0b01001, &ENTRY_PARAMETERIZABLE_8797908909194558616)],
        &[(0b01001, &ENTRY_PARAMETERIZATION_11837209911752300457)],
        &[(0b01001, &ENTRY_PARAMETERIZATIONS_7162471395165876296)],
        &[(0b01001, &ENTRY_PARAMETERIZE_15902800810917069503)],
        &[(0b01001, &ENTRY_PARAMETERIZED_10523524909406136092)],
        &[(0b01001, &ENTRY_PARAMETERIZES_16321927350979537220)],
        &[(0b01001, &ENTRY_PARAMETERIZING_17336476515168482632)],
        &[(0b10010, &ENTRY_PARAMETRIZABLE_7927413513463824291)],
        &[(0b10010, &ENTRY_PARAMETRIZATION_8706840929864673961)],
        &[(0b10010, &ENTRY_PARAMETRIZATIONS_7360315396492509494)],
        &[(0b10010, &ENTRY_PARAMETRIZE_7024833004706310910)],
        &[(0b10010, &ENTRY_PARAMETRIZED_9399874769518811207)],
        &[(0b10010, &ENTRY_PARAMETRIZES_5906260080588211958)],
        &[(0b10010, &ENTRY_PARAMETRIZING_2499223549119532396)],
        &[(0b01001, &ENTRY_PARAMETRIZABLE_7927413513463824291)],
        &[(0b01001, &ENTRY_PARAMETRIZATION_8706840929864673961)],
        &[(0b01001, &ENTRY_PARAMETRIZATIONS_7360315396492509494)],
        &[(0b01001, &ENTRY_PARAMETRIZE_7024833004706310910)],
        &[(0b01001, &ENTRY_PARAMETRIZED_9399874769518811207)],
        &[(0b01001, &ENTRY_PARAMETRIZES_5906260080588211958)],
        &[(0b01001, &ENTRY_PARAMETRIZING_2499223549119532396)],
        &[(0b11010, &ENTRY_PARAMECIUM_3779667447675673813)],
    ],
    range: 5..=12,
};

static VARS_PARAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAL_CHILDREN),
    value: None,
};

pub static VARS_PARAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lelisation"),
        dictgen::InsensitiveStr::Ascii("lelisations"),
        dictgen::InsensitiveStr::Ascii("lelise"),
        dictgen::InsensitiveStr::Ascii("lelised"),
        dictgen::InsensitiveStr::Ascii("leliser"),
        dictgen::InsensitiveStr::Ascii("lelisers"),
        dictgen::InsensitiveStr::Ascii("lelises"),
        dictgen::InsensitiveStr::Ascii("lelising"),
        dictgen::InsensitiveStr::Ascii("lelization"),
        dictgen::InsensitiveStr::Ascii("lelizations"),
        dictgen::InsensitiveStr::Ascii("lelize"),
        dictgen::InsensitiveStr::Ascii("lelized"),
        dictgen::InsensitiveStr::Ascii("lelizer"),
        dictgen::InsensitiveStr::Ascii("lelizers"),
        dictgen::InsensitiveStr::Ascii("lelizes"),
        dictgen::InsensitiveStr::Ascii("lelizing"),
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
        dictgen::InsensitiveStr::Ascii("ysation"),
        dictgen::InsensitiveStr::Ascii("ysations"),
        dictgen::InsensitiveStr::Ascii("yse"),
        dictgen::InsensitiveStr::Ascii("ysed"),
        dictgen::InsensitiveStr::Ascii("ysedlies"),
        dictgen::InsensitiveStr::Ascii("ysedly"),
        dictgen::InsensitiveStr::Ascii("yser"),
        dictgen::InsensitiveStr::Ascii("ysers"),
        dictgen::InsensitiveStr::Ascii("ysing"),
        dictgen::InsensitiveStr::Ascii("ysinglies"),
        dictgen::InsensitiveStr::Ascii("ysingly"),
        dictgen::InsensitiveStr::Ascii("yzation"),
        dictgen::InsensitiveStr::Ascii("yzations"),
        dictgen::InsensitiveStr::Ascii("yze"),
        dictgen::InsensitiveStr::Ascii("yzed"),
        dictgen::InsensitiveStr::Ascii("yzedlies"),
        dictgen::InsensitiveStr::Ascii("yzedly"),
        dictgen::InsensitiveStr::Ascii("yzer"),
        dictgen::InsensitiveStr::Ascii("yzers"),
        dictgen::InsensitiveStr::Ascii("yzes"),
        dictgen::InsensitiveStr::Ascii("yzing"),
        dictgen::InsensitiveStr::Ascii("yzinglies"),
        dictgen::InsensitiveStr::Ascii("yzingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARALLELIZATION_7245934204447125604)],
        &[(0b10010, &ENTRY_PARALLELIZATIONS_133672918746936059)],
        &[(0b10010, &ENTRY_PARALLELIZE_1958083969952429229)],
        &[(0b10010, &ENTRY_PARALLELIZED_4111465640711886667)],
        &[(0b10010, &ENTRY_PARALLELIZER_12768796695953090002)],
        &[(0b10010, &ENTRY_PARALLELIZERS_8909000637472788633)],
        &[(0b10010, &ENTRY_PARALLELIZES_4727085859295719609)],
        &[(0b10010, &ENTRY_PARALLELIZING_17049440584088440335)],
        &[(0b01001, &ENTRY_PARALLELIZATION_7245934204447125604)],
        &[(0b01001, &ENTRY_PARALLELIZATIONS_133672918746936059)],
        &[(0b01001, &ENTRY_PARALLELIZE_1958083969952429229)],
        &[(0b01001, &ENTRY_PARALLELIZED_4111465640711886667)],
        &[(0b01001, &ENTRY_PARALLELIZER_12768796695953090002)],
        &[(0b01001, &ENTRY_PARALLELIZERS_8909000637472788633)],
        &[(0b01001, &ENTRY_PARALLELIZES_4727085859295719609)],
        &[(0b01001, &ENTRY_PARALLELIZING_17049440584088440335)],
        &[(0b10010, &ENTRY_PARALOGIZE_12214907662748039398)],
        &[(0b10010, &ENTRY_PARALOGIZED_14744665030205649557)],
        &[(0b10010, &ENTRY_PARALOGIZES_9488115918771452379)],
        &[(0b10010, &ENTRY_PARALOGIZING_11295656204568323189)],
        &[(0b01001, &ENTRY_PARALOGIZE_12214907662748039398)],
        &[(0b01001, &ENTRY_PARALOGIZED_14744665030205649557)],
        &[(0b01001, &ENTRY_PARALOGIZES_9488115918771452379)],
        &[(0b01001, &ENTRY_PARALOGIZING_11295656204568323189)],
        &[(0b11010, &ENTRY_PARALYZATION_9848908666776705153)],
        &[(0b11010, &ENTRY_PARALYZATIONS_7680809956520835808)],
        &[(0b11010, &ENTRY_PARALYZE_5616245633076129426)],
        &[(0b11010, &ENTRY_PARALYZED_16839880512939084025)],
        &[(0b11010, &ENTRY_PARALYZEDLIES_6503851599747415664)],
        &[(0b11010, &ENTRY_PARALYZEDLY_15858220542027209484)],
        &[(0b11010, &ENTRY_PARALYZER_4178714175758599714)],
        &[(0b11010, &ENTRY_PARALYZERS_13745656060590463226)],
        &[(0b11010, &ENTRY_PARALYZING_3887960173123159019)],
        &[(0b11010, &ENTRY_PARALYZINGLIES_11000762994581262667)],
        &[(0b11010, &ENTRY_PARALYZINGLY_2254446540316450510)],
        &[(0b00001, &ENTRY_PARALYZATION_9848908666776705153)],
        &[(0b00001, &ENTRY_PARALYZATIONS_7680809956520835808)],
        &[(0b01001, &ENTRY_PARALYZE_5616245633076129426)],
        &[(0b01001, &ENTRY_PARALYZED_16839880512939084025)],
        &[(0b00001, &ENTRY_PARALYZEDLIES_6503851599747415664)],
        &[(0b00001, &ENTRY_PARALYZEDLY_15858220542027209484)],
        &[(0b00001, &ENTRY_PARALYZER_4178714175758599714)],
        &[(0b00001, &ENTRY_PARALYZERS_13745656060590463226)],
        &[(0b01001, &ENTRY_PARALYZES_2906384954321317007)],
        &[(0b01001, &ENTRY_PARALYZING_3887960173123159019)],
        &[(0b00001, &ENTRY_PARALYZINGLIES_11000762994581262667)],
        &[(0b00001, &ENTRY_PARALYZINGLY_2254446540316450510)],
    ],
    range: 3..=11,
};

static VARS_PARAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAG_CHILDREN),
    value: None,
};

pub static VARS_PARAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("raphise"),
        dictgen::InsensitiveStr::Ascii("raphises"),
        dictgen::InsensitiveStr::Ascii("raphize"),
        dictgen::InsensitiveStr::Ascii("raphizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARAGRAPHIZE_6569788940642685820)],
        &[(0b10010, &ENTRY_PARAGRAPHIZES_17320641323920182037)],
        &[(0b01001, &ENTRY_PARAGRAPHIZE_6569788940642685820)],
        &[(0b01001, &ENTRY_PARAGRAPHIZES_17320641323920182037)],
    ],
    range: 7..=8,
};

static VARS_PARAF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAF_CHILDREN),
    value: None,
};

pub static VARS_PARAF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("finise"),
        dictgen::InsensitiveStr::Ascii("finises"),
        dictgen::InsensitiveStr::Ascii("finize"),
        dictgen::InsensitiveStr::Ascii("finizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARAFFINIZE_4902479195187558819)],
        &[(0b10010, &ENTRY_PARAFFINIZES_1377166017348875375)],
        &[(0b01001, &ENTRY_PARAFFINIZE_4902479195187558819)],
        &[(0b01001, &ENTRY_PARAFFINIZES_1377166017348875375)],
    ],
    range: 6..=7,
};

static VARS_PARAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAE_CHILDREN),
    value: None,
};

pub static VARS_PARAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("neses"),
        dictgen::InsensitiveStr::Ascii("nesis"),
        dictgen::InsensitiveStr::Ascii("netic"),
        dictgen::InsensitiveStr::Ascii("netical"),
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PARENESES_15075590434109366156)],
        &[(0b11010, &ENTRY_PARENESIS_10831614342484659031)],
        &[(0b11010, &ENTRY_PARENETIC_14670463709273075800)],
        &[(0b11010, &ENTRY_PARENETICAL_7355921821382251766)],
        &[(0b11010, &ENTRY_PARESTHESIA_6053545970539213078)],
        &[(0b11010, &ENTRY_PARESTHESIAS_12326929322577395759)],
        &[(0b11010, &ENTRY_PARESTHETIC_7625031320540803873)],
    ],
    range: 5..=8,
};

static VARS_PARAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAB_CHILDREN),
    value: None,
};

pub static VARS_PARAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olisation"),
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olization"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARABOLIZATION_9979029011128629425)],
        &[(0b10010, &ENTRY_PARABOLIZE_3633976210888421037)],
        &[(0b10010, &ENTRY_PARABOLIZED_18319308228981949562)],
        &[(0b10010, &ENTRY_PARABOLIZES_15064031586705803527)],
        &[(0b10010, &ENTRY_PARABOLIZING_4559864831118431645)],
        &[(0b01001, &ENTRY_PARABOLIZATION_9979029011128629425)],
        &[(0b01001, &ENTRY_PARABOLIZE_3633976210888421037)],
        &[(0b01001, &ENTRY_PARABOLIZED_18319308228981949562)],
        &[(0b01001, &ENTRY_PARABOLIZES_15064031586705803527)],
        &[(0b01001, &ENTRY_PARABOLIZING_4559864831118431645)],
    ],
    range: 5..=9,
};

static VARS_PAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAP_CHILDREN),
    value: None,
};

pub static VARS_PAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("illedema"),
        dictgen::InsensitiveStr::Ascii("illoedema"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAPALIZATION_10305112316051179611)],
        &[(0b10010, &ENTRY_PAPALIZATIONS_14103151976039127637)],
        &[(0b10010, &ENTRY_PAPALIZE_17095323209535476080)],
        &[(0b10010, &ENTRY_PAPALIZED_7105409138327586534)],
        &[(0b10010, &ENTRY_PAPALIZER_18353219266660388688)],
        &[(0b10010, &ENTRY_PAPALIZERS_15756683407514873742)],
        &[(0b10010, &ENTRY_PAPALIZES_3090977471549773473)],
        &[(0b10010, &ENTRY_PAPALIZING_15022851819713987399)],
        &[(0b01001, &ENTRY_PAPALIZATION_10305112316051179611)],
        &[(0b01001, &ENTRY_PAPALIZATIONS_14103151976039127637)],
        &[(0b01001, &ENTRY_PAPALIZE_17095323209535476080)],
        &[(0b01001, &ENTRY_PAPALIZED_7105409138327586534)],
        &[(0b01001, &ENTRY_PAPALIZER_18353219266660388688)],
        &[(0b01001, &ENTRY_PAPALIZERS_15756683407514873742)],
        &[(0b01001, &ENTRY_PAPALIZES_3090977471549773473)],
        &[(0b01001, &ENTRY_PAPALIZING_15022851819713987399)],
        &[(0b10001, &ENTRY_PAPILLEDEMA_17898703555064318930)],
        &[(0b11010, &ENTRY_PAPILLEDEMA_17898703555064318930)],
        &[(0b11010, &ENTRY_PAPULE_14971280913138248927)],
        &[(0b00001, &ENTRY_PAPULE_14971280913138248927)],
    ],
    range: 3..=10,
};

static VARS_PAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAN_CHILDREN),
    value: None,
};

pub static VARS_PAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("aesthesias"),
        dictgen::InsensitiveStr::Ascii("aesthetic"),
        dictgen::InsensitiveStr::Ascii("derise"),
        dictgen::InsensitiveStr::Ascii("derises"),
        dictgen::InsensitiveStr::Ascii("derize"),
        dictgen::InsensitiveStr::Ascii("derizes"),
        dictgen::InsensitiveStr::Ascii("dora"),
        dictgen::InsensitiveStr::Ascii("doura"),
        dictgen::InsensitiveStr::Ascii("egyrise"),
        dictgen::InsensitiveStr::Ascii("egyrised"),
        dictgen::InsensitiveStr::Ascii("egyrises"),
        dictgen::InsensitiveStr::Ascii("egyrising"),
        dictgen::InsensitiveStr::Ascii("egyrize"),
        dictgen::InsensitiveStr::Ascii("egyrized"),
        dictgen::InsensitiveStr::Ascii("egyrizes"),
        dictgen::InsensitiveStr::Ascii("egyrizing"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("elist"),
        dictgen::InsensitiveStr::Ascii("elists"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
        dictgen::InsensitiveStr::Ascii("ellisation"),
        dictgen::InsensitiveStr::Ascii("ellist"),
        dictgen::InsensitiveStr::Ascii("ellists"),
        dictgen::InsensitiveStr::Ascii("ellization"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthesias"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
        dictgen::InsensitiveStr::Ascii("gaea"),
        dictgen::InsensitiveStr::Ascii("gea"),
        dictgen::InsensitiveStr::Ascii("omphaean"),
        dictgen::InsensitiveStr::Ascii("omphean"),
        dictgen::InsensitiveStr::Ascii("theonisation"),
        dictgen::InsensitiveStr::Ascii("theonisations"),
        dictgen::InsensitiveStr::Ascii("theonise"),
        dictgen::InsensitiveStr::Ascii("theonises"),
        dictgen::InsensitiveStr::Ascii("theonization"),
        dictgen::InsensitiveStr::Ascii("theonizations"),
        dictgen::InsensitiveStr::Ascii("theonize"),
        dictgen::InsensitiveStr::Ascii("theonizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PANESTHESIA_5954150154376905982)],
        &[(0b11010, &ENTRY_PANESTHESIAS_2205607449667143893)],
        &[(0b11010, &ENTRY_PANESTHETIC_15762002620434117648)],
        &[(0b10010, &ENTRY_PANDERIZE_9746369180172729455)],
        &[(0b10010, &ENTRY_PANDERIZES_5781283006745603488)],
        &[(0b01001, &ENTRY_PANDERIZE_9746369180172729455)],
        &[(0b01001, &ENTRY_PANDERIZES_5781283006745603488)],
        &[(0b00001, &ENTRY_PANDORA_6847060433331710267)],
        &[(0b11010, &ENTRY_PANDORA_6847060433331710267)],
        &[(0b10010, &ENTRY_PANEGYRIZE_464787387720568012)],
        &[(0b10010, &ENTRY_PANEGYRIZED_1510999540705297287)],
        &[(0b10010, &ENTRY_PANEGYRIZES_614276823774184510)],
        &[(0b10010, &ENTRY_PANEGYRIZING_7503940443087587961)],
        &[(0b01001, &ENTRY_PANEGYRIZE_464787387720568012)],
        &[(0b01001, &ENTRY_PANEGYRIZED_1510999540705297287)],
        &[(0b01001, &ENTRY_PANEGYRIZES_614276823774184510)],
        &[(0b01001, &ENTRY_PANEGYRIZING_7503940443087587961)],
        &[(0b00001, &ENTRY_PANELED_12586780164955993512)],
        &[(0b00001, &ENTRY_PANELING_8089572046105071609)],
        &[(0b00001, &ENTRY_PANELINGS_11260550015389622953)],
        &[(0b10010, &ENTRY_PANELIZED_10063143549086734887)],
        &[(0b00001, &ENTRY_PANELIST_3043263775088249330)],
        &[(0b00001, &ENTRY_PANELISTS_16863143863031647099)],
        &[(0b00001, &ENTRY_PANELIZATION_1723586301806345893)],
        &[(0b01001, &ENTRY_PANELIZED_10063143549086734887)],
        &[(0b11010, &ENTRY_PANELED_12586780164955993512)],
        &[(0b11010, &ENTRY_PANELING_8089572046105071609)],
        &[(0b11010, &ENTRY_PANELINGS_11260550015389622953)],
        &[(0b10010, &ENTRY_PANELIZATION_1723586301806345893)],
        &[(0b11010, &ENTRY_PANELIST_3043263775088249330)],
        &[(0b11010, &ENTRY_PANELISTS_16863143863031647099)],
        &[(0b01000, &ENTRY_PANELIZATION_1723586301806345893)],
        &[(0b10001, &ENTRY_PANESTHESIA_5954150154376905982)],
        &[(0b10001, &ENTRY_PANESTHESIAS_2205607449667143893)],
        &[(0b10001, &ENTRY_PANESTHETIC_15762002620434117648)],
        &[(0b11010, &ENTRY_PANGEA_15349461870177052673)],
        &[(0b00001, &ENTRY_PANGEA_15349461870177052673)],
        &[(0b11010, &ENTRY_PANOMPHEAN_11042013803124847042)],
        &[(0b00001, &ENTRY_PANOMPHEAN_11042013803124847042)],
        &[(0b10010, &ENTRY_PANTHEONIZATION_3031761940679684536)],
        &[(0b10010, &ENTRY_PANTHEONIZATIONS_12369984766927055092)],
        &[(0b10010, &ENTRY_PANTHEONIZE_4830761873149783365)],
        &[(0b10010, &ENTRY_PANTHEONIZES_6927021183986839165)],
        &[(0b01001, &ENTRY_PANTHEONIZATION_3031761940679684536)],
        &[(0b01001, &ENTRY_PANTHEONIZATIONS_12369984766927055092)],
        &[(0b01001, &ENTRY_PANTHEONIZE_4830761873149783365)],
        &[(0b01001, &ENTRY_PANTHEONIZES_6927021183986839165)],
    ],
    range: 3..=13,
};

static VARS_PAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAM_CHILDREN),
    value: None,
};

pub static VARS_PAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("perise"),
        dictgen::InsensitiveStr::Ascii("perises"),
        dictgen::InsensitiveStr::Ascii("perize"),
        dictgen::InsensitiveStr::Ascii("perizes"),
        dictgen::InsensitiveStr::Ascii("phletise"),
        dictgen::InsensitiveStr::Ascii("phletises"),
        dictgen::InsensitiveStr::Ascii("phletize"),
        dictgen::InsensitiveStr::Ascii("phletizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAMPERIZE_15290111866003819228)],
        &[(0b10010, &ENTRY_PAMPERIZES_17242646056475121067)],
        &[(0b01001, &ENTRY_PAMPERIZE_15290111866003819228)],
        &[(0b01001, &ENTRY_PAMPERIZES_17242646056475121067)],
        &[(0b10010, &ENTRY_PAMPHLETIZE_3783375103913911282)],
        &[(0b10010, &ENTRY_PAMPHLETIZES_7614193080459247598)],
        &[(0b01001, &ENTRY_PAMPHLETIZE_3783375103913911282)],
        &[(0b01001, &ENTRY_PAMPHLETIZES_7614193080459247598)],
    ],
    range: 6..=9,
};

static VARS_PAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PAL_CHILDREN),
    value: None,
};

static VARS_PAL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PALA_NODE),
    None,
    None,
    None,
    Some(&VARS_PALE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PALL_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PALL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALL_CHILDREN),
    value: None,
};

pub static VARS_PALL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("adiumise"),
        dictgen::InsensitiveStr::Ascii("adiumises"),
        dictgen::InsensitiveStr::Ascii("adiumize"),
        dictgen::InsensitiveStr::Ascii("adiumizes"),
        dictgen::InsensitiveStr::Ascii("etisation"),
        dictgen::InsensitiveStr::Ascii("etisations"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etiser"),
        dictgen::InsensitiveStr::Ascii("etisers"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etising"),
        dictgen::InsensitiveStr::Ascii("etization"),
        dictgen::InsensitiveStr::Ascii("etizations"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizer"),
        dictgen::InsensitiveStr::Ascii("etizers"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("etizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PALLADIUMIZE_4224398356428570618)],
        &[(0b10010, &ENTRY_PALLADIUMIZES_1909221670496633613)],
        &[(0b01001, &ENTRY_PALLADIUMIZE_4224398356428570618)],
        &[(0b01001, &ENTRY_PALLADIUMIZES_1909221670496633613)],
        &[(0b10010, &ENTRY_PALLETIZATION_8304716403450886029)],
        &[(0b10010, &ENTRY_PALLETIZATIONS_18403803161909956898)],
        &[(0b10010, &ENTRY_PALLETIZE_7471981148190319796)],
        &[(0b10010, &ENTRY_PALLETIZED_7486422692101120739)],
        &[(0b10010, &ENTRY_PALLETIZER_2834663411422436703)],
        &[(0b10010, &ENTRY_PALLETIZERS_11136958979392472544)],
        &[(0b10010, &ENTRY_PALLETIZES_16047276413399886354)],
        &[(0b10010, &ENTRY_PALLETIZING_11317686306337242707)],
        &[(0b01001, &ENTRY_PALLETIZATION_8304716403450886029)],
        &[(0b01001, &ENTRY_PALLETIZATIONS_18403803161909956898)],
        &[(0b01001, &ENTRY_PALLETIZE_7471981148190319796)],
        &[(0b01001, &ENTRY_PALLETIZED_7486422692101120739)],
        &[(0b01001, &ENTRY_PALLETIZER_2834663411422436703)],
        &[(0b01001, &ENTRY_PALLETIZERS_11136958979392472544)],
        &[(0b01001, &ENTRY_PALLETIZES_16047276413399886354)],
        &[(0b01001, &ENTRY_PALLETIZING_11317686306337242707)],
    ],
    range: 5..=10,
};

static VARS_PALE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PALE_CHILDREN),
    value: None,
};

static VARS_PALE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PALEA_NODE),
    None,
    None,
    None,
    Some(&VARS_PALEE_NODE),
    None,
    None,
    None,
    Some(&VARS_PALEI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PALEO_NODE),
    None,
    None,
    None,
    Some(&VARS_PALES_NODE),
    Some(&VARS_PALET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PALET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALET_CHILDREN),
    value: None,
};

pub static VARS_PALET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("iology")],
    values: &[&[(0b10001, &ENTRY_PALETIOLOGY_4388412756789031487)]],
    range: 6..=6,
};

static VARS_PALES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALES_CHILDREN),
    value: None,
};

pub static VARS_PALES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tra"),
        dictgen::InsensitiveStr::Ascii("trae"),
        dictgen::InsensitiveStr::Ascii("tral"),
        dictgen::InsensitiveStr::Ascii("tras"),
        dictgen::InsensitiveStr::Ascii("trian"),
        dictgen::InsensitiveStr::Ascii("tric"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALESTRA_15858313904716663869)],
        &[(0b10001, &ENTRY_PALESTRAE_14184714476900356877)],
        &[(0b10001, &ENTRY_PALESTRAL_17875036424127182820)],
        &[(0b10001, &ENTRY_PALESTRAS_18241821718554443326)],
        &[(0b10001, &ENTRY_PALESTRIAN_16430867387330520444)],
        &[(0b10001, &ENTRY_PALESTRIC_10702847815072409215)],
    ],
    range: 3..=5,
};

static VARS_PALEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PALEO_CHILDREN),
    value: None,
};

static VARS_PALEO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PALEOA_NODE),
    Some(&VARS_PALEOB_NODE),
    Some(&VARS_PALEOC_NODE),
    Some(&VARS_PALEOD_NODE),
    Some(&VARS_PALEOE_NODE),
    Some(&VARS_PALEOF_NODE),
    Some(&VARS_PALEOG_NODE),
    Some(&VARS_PALEOH_NODE),
    Some(&VARS_PALEOI_NODE),
    None,
    None,
    Some(&VARS_PALEOL_NODE),
    Some(&VARS_PALEOM_NODE),
    Some(&VARS_PALEON_NODE),
    None,
    Some(&VARS_PALEOP_NODE),
    None,
    Some(&VARS_PALEOR_NODE),
    Some(&VARS_PALEOS_NODE),
    Some(&VARS_PALEOT_NODE),
    None,
    Some(&VARS_PALEOV_NODE),
    None,
    None,
    None,
    Some(&VARS_PALEOZ_NODE),
];

static VARS_PALEOZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOZ_CHILDREN),
    value: None,
};

pub static VARS_PALEOZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oic"),
        dictgen::InsensitiveStr::Ascii("oologic"),
        dictgen::InsensitiveStr::Ascii("oological"),
        dictgen::InsensitiveStr::Ascii("oologies"),
        dictgen::InsensitiveStr::Ascii("oologist"),
        dictgen::InsensitiveStr::Ascii("oologists"),
        dictgen::InsensitiveStr::Ascii("oology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOZOIC_2171352618595825046)],
        &[(0b10001, &ENTRY_PALEOZOOLOGIC_12472183251804979806)],
        &[(0b10001, &ENTRY_PALEOZOOLOGICAL_7651649713235051506)],
        &[(0b10001, &ENTRY_PALEOZOOLOGIES_17902367901707184491)],
        &[(0b10001, &ENTRY_PALEOZOOLOGIST_4602703364020254946)],
        &[(0b10001, &ENTRY_PALEOZOOLOGISTS_6609845946465372037)],
        &[(0b10001, &ENTRY_PALEOZOOLOGY_5066201776927454990)],
    ],
    range: 3..=9,
};

static VARS_PALEOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOV_CHILDREN),
    value: None,
};

pub static VARS_PALEOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("olcanic")],
    values: &[&[(0b10001, &ENTRY_PALEOVOLCANIC_1100245805130475160)]],
    range: 7..=7,
};

static VARS_PALEOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOT_CHILDREN),
    value: None,
};

pub static VARS_PALEOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("echnic"),
        dictgen::InsensitiveStr::Ascii("halamus"),
        dictgen::InsensitiveStr::Ascii("ropical"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOTECHNIC_9551091213770179886)],
        &[(0b10001, &ENTRY_PALEOTHALAMUS_10925563677009720429)],
        &[(0b10001, &ENTRY_PALEOTROPICAL_18065203176296129763)],
    ],
    range: 6..=7,
};

static VARS_PALEOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOS_CHILDREN),
    value: None,
};

pub static VARS_PALEOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("triatal"),
        dictgen::InsensitiveStr::Ascii("triatum"),
        dictgen::InsensitiveStr::Ascii("tylic"),
        dictgen::InsensitiveStr::Ascii("tyly"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOSTRIATAL_17033529618847936065)],
        &[(0b10001, &ENTRY_PALEOSTRIATUM_8135708815680998194)],
        &[(0b10001, &ENTRY_PALEOSTYLIC_13586027329666518772)],
        &[(0b10001, &ENTRY_PALEOSTYLY_329937646655027738)],
    ],
    range: 4..=7,
};

static VARS_PALEOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOR_CHILDREN),
    value: None,
};

pub static VARS_PALEOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nithological"),
        dictgen::InsensitiveStr::Ascii("nithology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEORNITHOLOGICAL_6805615354003961394)],
        &[(0b10001, &ENTRY_PALEORNITHOLOGY_4480620476474604419)],
    ],
    range: 9..=12,
};

static VARS_PALEOP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOP_CHILDREN),
    value: None,
};

pub static VARS_PALEOP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("athologic"),
        dictgen::InsensitiveStr::Ascii("athological"),
        dictgen::InsensitiveStr::Ascii("athologies"),
        dictgen::InsensitiveStr::Ascii("athologist"),
        dictgen::InsensitiveStr::Ascii("athologists"),
        dictgen::InsensitiveStr::Ascii("athology"),
        dictgen::InsensitiveStr::Ascii("edology"),
        dictgen::InsensitiveStr::Ascii("hysiography"),
        dictgen::InsensitiveStr::Ascii("hysiology"),
        dictgen::InsensitiveStr::Ascii("hytic"),
        dictgen::InsensitiveStr::Ascii("hytological"),
        dictgen::InsensitiveStr::Ascii("hytologist"),
        dictgen::InsensitiveStr::Ascii("hytology"),
        dictgen::InsensitiveStr::Ascii("lain"),
        dictgen::InsensitiveStr::Ascii("otamology"),
        dictgen::InsensitiveStr::Ascii("sychic"),
        dictgen::InsensitiveStr::Ascii("sychological"),
        dictgen::InsensitiveStr::Ascii("sychology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOPATHOLOGIC_8048979982047381626)],
        &[(0b10001, &ENTRY_PALEOPATHOLOGICAL_6355077786853784135)],
        &[(0b10001, &ENTRY_PALEOPATHOLOGIES_3907569211124295484)],
        &[(0b10001, &ENTRY_PALEOPATHOLOGIST_11591525888140398394)],
        &[(0b10001, &ENTRY_PALEOPATHOLOGISTS_16699786230783410448)],
        &[(0b10001, &ENTRY_PALEOPATHOLOGY_3434376491146064878)],
        &[(0b10001, &ENTRY_PALEOPEDOLOGY_3869256322046937665)],
        &[(0b10001, &ENTRY_PALEOPHYSIOGRAPHY_11544580360735995612)],
        &[(0b10001, &ENTRY_PALEOPHYSIOLOGY_15071752915664349110)],
        &[(0b10001, &ENTRY_PALEOPHYTIC_6789302132283036079)],
        &[(0b10001, &ENTRY_PALEOPHYTOLOGICAL_5744086473592891476)],
        &[(0b10001, &ENTRY_PALEOPHYTOLOGIST_10785914590748470485)],
        &[(0b10001, &ENTRY_PALEOPHYTOLOGY_3952145533872729647)],
        &[(0b10001, &ENTRY_PALEOPLAIN_4445180941860383489)],
        &[(0b10001, &ENTRY_PALEOPOTAMOLOGY_9728822371435540856)],
        &[(0b10001, &ENTRY_PALEOPSYCHIC_1286029760595353697)],
        &[(0b10001, &ENTRY_PALEOPSYCHOLOGICAL_8115976081179191215)],
        &[(0b10001, &ENTRY_PALEOPSYCHOLOGY_14002375044163854176)],
    ],
    range: 4..=12,
};

static VARS_PALEON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEON_CHILDREN),
    value: None,
};

pub static VARS_PALEON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tographic"),
        dictgen::InsensitiveStr::Ascii("tographical"),
        dictgen::InsensitiveStr::Ascii("tographies"),
        dictgen::InsensitiveStr::Ascii("tography"),
        dictgen::InsensitiveStr::Ascii("tol"),
        dictgen::InsensitiveStr::Ascii("tologic"),
        dictgen::InsensitiveStr::Ascii("tological"),
        dictgen::InsensitiveStr::Ascii("tologically"),
        dictgen::InsensitiveStr::Ascii("tologist"),
        dictgen::InsensitiveStr::Ascii("tologists"),
        dictgen::InsensitiveStr::Ascii("tology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEONTOGRAPHIC_8614487224686150719)],
        &[(0b10001, &ENTRY_PALEONTOGRAPHICAL_8390709172465677724)],
        &[(0b10001, &ENTRY_PALEONTOGRAPHIES_6412037643243713928)],
        &[(0b10001, &ENTRY_PALEONTOGRAPHY_15155568729047027987)],
        &[(0b10001, &ENTRY_PALEONTOL_16908832703236553374)],
        &[(0b10001, &ENTRY_PALEONTOLOGIC_9726526633122558228)],
        &[(0b11001, &ENTRY_PALEONTOLOGICAL_11378757918485663576)],
        &[(0b10001, &ENTRY_PALEONTOLOGICALLY_7795552250402863412)],
        &[(0b11001, &ENTRY_PALEONTOLOGIST_14409308310083449867)],
        &[(0b11001, &ENTRY_PALEONTOLOGISTS_1615341850049645435)],
        &[(0b11001, &ENTRY_PALEONTOLOGY_8727472879076855658)],
    ],
    range: 3..=11,
};

static VARS_PALEOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOM_CHILDREN),
    value: None,
};

pub static VARS_PALEOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agnetism"),
        dictgen::InsensitiveStr::Ascii("agnetisms"),
        dictgen::InsensitiveStr::Ascii("etallic"),
        dictgen::InsensitiveStr::Ascii("eteorological"),
        dictgen::InsensitiveStr::Ascii("eteorology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOMAGNETISM_10382230568315308075)],
        &[(0b10001, &ENTRY_PALEOMAGNETISMS_11618371615606652138)],
        &[(0b10001, &ENTRY_PALEOMETALLIC_1327931506117283329)],
        &[(0b10001, &ENTRY_PALEOMETEOROLOGICAL_13764122166986418655)],
        &[(0b10001, &ENTRY_PALEOMETEOROLOGY_5577530218919631079)],
    ],
    range: 7..=13,
};

static VARS_PALEOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOL_CHILDREN),
    value: None,
};

pub static VARS_PALEOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atry"),
        dictgen::InsensitiveStr::Ascii("imnology"),
        dictgen::InsensitiveStr::Ascii("ith"),
        dictgen::InsensitiveStr::Ascii("ithic"),
        dictgen::InsensitiveStr::Ascii("ithical"),
        dictgen::InsensitiveStr::Ascii("ithist"),
        dictgen::InsensitiveStr::Ascii("ithoid"),
        dictgen::InsensitiveStr::Ascii("iths"),
        dictgen::InsensitiveStr::Ascii("ithy"),
        dictgen::InsensitiveStr::Ascii("ogical"),
        dictgen::InsensitiveStr::Ascii("ogist"),
        dictgen::InsensitiveStr::Ascii("ogy"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOLATRY_14450699210706774620)],
        &[(0b10001, &ENTRY_PALEOLIMNOLOGY_1236880097590741596)],
        &[(0b10001, &ENTRY_PALEOLITH_12363554094675316318)],
        &[(0b11001, &ENTRY_PALEOLITHIC_10579173722626414001)],
        &[(0b10001, &ENTRY_PALEOLITHICAL_1935974690293577369)],
        &[(0b10001, &ENTRY_PALEOLITHIST_9458879760716165734)],
        &[(0b10001, &ENTRY_PALEOLITHOID_6543358911316320294)],
        &[(0b10001, &ENTRY_PALEOLITHS_7568765529239450192)],
        &[(0b10001, &ENTRY_PALEOLITHY_7860170771676717319)],
        &[(0b10001, &ENTRY_PALEOLOGICAL_1841349892746131160)],
        &[(0b10001, &ENTRY_PALEOLOGIST_1275103816971686493)],
        &[(0b10001, &ENTRY_PALEOLOGY_9039082638538518660)],
    ],
    range: 3..=8,
};

static VARS_PALEOI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOI_CHILDREN),
    value: None,
};

pub static VARS_PALEOI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("chthyology")],
    values: &[&[(0b10001, &ENTRY_PALEOICHTHYOLOGY_16030251089000297685)]],
    range: 10..=10,
};

static VARS_PALEOH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOH_CHILDREN),
    value: None,
};

pub static VARS_PALEOH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erpetologist"),
        dictgen::InsensitiveStr::Ascii("erpetology"),
        dictgen::InsensitiveStr::Ascii("istology"),
        dictgen::InsensitiveStr::Ascii("ydrography"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOHERPETOLOGIST_3262925931087486684)],
        &[(0b10001, &ENTRY_PALEOHERPETOLOGY_10885033853235926434)],
        &[(0b10001, &ENTRY_PALEOHISTOLOGY_8638825422062573518)],
        &[(0b10001, &ENTRY_PALEOHYDROGRAPHY_2971028169559708924)],
    ],
    range: 8..=12,
};

static VARS_PALEOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOG_CHILDREN),
    value: None,
};

pub static VARS_PALEOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enesis"),
        dictgen::InsensitiveStr::Ascii("enetic"),
        dictgen::InsensitiveStr::Ascii("eographer"),
        dictgen::InsensitiveStr::Ascii("eographers"),
        dictgen::InsensitiveStr::Ascii("eographic"),
        dictgen::InsensitiveStr::Ascii("eographical"),
        dictgen::InsensitiveStr::Ascii("eographically"),
        dictgen::InsensitiveStr::Ascii("eographies"),
        dictgen::InsensitiveStr::Ascii("eography"),
        dictgen::InsensitiveStr::Ascii("eology"),
        dictgen::InsensitiveStr::Ascii("laciology"),
        dictgen::InsensitiveStr::Ascii("lyph"),
        dictgen::InsensitiveStr::Ascii("raph"),
        dictgen::InsensitiveStr::Ascii("raphic"),
        dictgen::InsensitiveStr::Ascii("raphical"),
        dictgen::InsensitiveStr::Ascii("raphically"),
        dictgen::InsensitiveStr::Ascii("raphist"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOGENESIS_17234588466739986743)],
        &[(0b10001, &ENTRY_PALEOGENETIC_3671327870094791359)],
        &[(0b10001, &ENTRY_PALEOGEOGRAPHER_7865313036683833980)],
        &[(0b10001, &ENTRY_PALEOGEOGRAPHERS_17925499304699862812)],
        &[(0b10001, &ENTRY_PALEOGEOGRAPHIC_12366567756392166026)],
        &[(0b10001, &ENTRY_PALEOGEOGRAPHICAL_16657456835077012317)],
        &[(0b10001, &ENTRY_PALEOGEOGRAPHICALLY_15437320738294900083)],
        &[(0b11001, &ENTRY_PALEOGEOGRAPHIES_12038367756274519862)],
        &[(0b11001, &ENTRY_PALEOGEOGRAPHY_14735924833615110050)],
        &[(0b10001, &ENTRY_PALEOGEOLOGY_10091590621653936254)],
        &[(0b10001, &ENTRY_PALEOGLACIOLOGY_16037720465585450625)],
        &[(0b10001, &ENTRY_PALEOGLYPH_15930058668062136413)],
        &[(0b10001, &ENTRY_PALEOGRAPH_13677256025266645311)],
        &[(0b10001, &ENTRY_PALEOGRAPHIC_8091858415531998756)],
        &[(0b10001, &ENTRY_PALEOGRAPHICAL_4607017356275969347)],
        &[(0b10001, &ENTRY_PALEOGRAPHICALLY_10052249768233307285)],
        &[(0b10001, &ENTRY_PALEOGRAPHIST_16452384260584578278)],
    ],
    range: 4..=13,
};

static VARS_PALEOF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOF_CHILDREN),
    value: None,
};

pub static VARS_PALEOF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("auna")],
    values: &[&[(0b10001, &ENTRY_PALEOFAUNA_14514918396801724693)]],
    range: 4..=4,
};

static VARS_PALEOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOE_CHILDREN),
    value: None,
};

pub static VARS_PALEOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cologic"),
        dictgen::InsensitiveStr::Ascii("cological"),
        dictgen::InsensitiveStr::Ascii("cologies"),
        dictgen::InsensitiveStr::Ascii("cologist"),
        dictgen::InsensitiveStr::Ascii("cologists"),
        dictgen::InsensitiveStr::Ascii("cology"),
        dictgen::InsensitiveStr::Ascii("ncephalon"),
        dictgen::InsensitiveStr::Ascii("ntomologic"),
        dictgen::InsensitiveStr::Ascii("ntomological"),
        dictgen::InsensitiveStr::Ascii("ntomologist"),
        dictgen::InsensitiveStr::Ascii("remology"),
        dictgen::InsensitiveStr::Ascii("thnic"),
        dictgen::InsensitiveStr::Ascii("thnography"),
        dictgen::InsensitiveStr::Ascii("thnologic"),
        dictgen::InsensitiveStr::Ascii("thnological"),
        dictgen::InsensitiveStr::Ascii("thnologist"),
        dictgen::InsensitiveStr::Ascii("thnology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOECOLOGIC_4669354935242540330)],
        &[(0b10001, &ENTRY_PALEOECOLOGICAL_12243112048304818096)],
        &[(0b11001, &ENTRY_PALEOECOLOGIES_18110959250046855627)],
        &[(0b10001, &ENTRY_PALEOECOLOGIST_8254000552693957088)],
        &[(0b10001, &ENTRY_PALEOECOLOGISTS_3308516876293590602)],
        &[(0b11001, &ENTRY_PALEOECOLOGY_4482816158539091906)],
        &[(0b10001, &ENTRY_PALEOENCEPHALON_9569832069668177801)],
        &[(0b10001, &ENTRY_PALEOENTOMOLOGIC_4007524847624498176)],
        &[(0b10001, &ENTRY_PALEOENTOMOLOGICAL_16493536171383050969)],
        &[(0b10001, &ENTRY_PALEOENTOMOLOGIST_5004696292111737108)],
        &[(0b10001, &ENTRY_PALEOEREMOLOGY_179203799725486477)],
        &[(0b10001, &ENTRY_PALEOETHNIC_18256982848006324404)],
        &[(0b10001, &ENTRY_PALEOETHNOGRAPHY_4293329065986396408)],
        &[(0b10001, &ENTRY_PALEOETHNOLOGIC_3941018589215004237)],
        &[(0b10001, &ENTRY_PALEOETHNOLOGICAL_2716015278756182228)],
        &[(0b10001, &ENTRY_PALEOETHNOLOGIST_5288127538766606384)],
        &[(0b10001, &ENTRY_PALEOETHNOLOGY_4385814784718071920)],
    ],
    range: 5..=12,
};

static VARS_PALEOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOD_CHILDREN),
    value: None,
};

pub static VARS_PALEOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("endrologic"),
        dictgen::InsensitiveStr::Ascii("endrological"),
        dictgen::InsensitiveStr::Ascii("endrologically"),
        dictgen::InsensitiveStr::Ascii("endrologist"),
        dictgen::InsensitiveStr::Ascii("endrology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEODENDROLOGIC_6856992872417007321)],
        &[(0b10001, &ENTRY_PALEODENDROLOGICAL_16026323992623885288)],
        &[(0b10001, &ENTRY_PALEODENDROLOGICALLY_10449298583529356832)],
        &[(0b10001, &ENTRY_PALEODENDROLOGIST_3579987086039471029)],
        &[(0b10001, &ENTRY_PALEODENDROLOGY_644708576508951069)],
    ],
    range: 9..=14,
};

static VARS_PALEOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOC_CHILDREN),
    value: None,
};

pub static VARS_PALEOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eanography"),
        dictgen::InsensitiveStr::Ascii("horology"),
        dictgen::InsensitiveStr::Ascii("limatic"),
        dictgen::InsensitiveStr::Ascii("limatologic"),
        dictgen::InsensitiveStr::Ascii("limatological"),
        dictgen::InsensitiveStr::Ascii("limatologies"),
        dictgen::InsensitiveStr::Ascii("limatologist"),
        dictgen::InsensitiveStr::Ascii("limatologists"),
        dictgen::InsensitiveStr::Ascii("limatology"),
        dictgen::InsensitiveStr::Ascii("oncha"),
        dictgen::InsensitiveStr::Ascii("osmic"),
        dictgen::InsensitiveStr::Ascii("osmology"),
        dictgen::InsensitiveStr::Ascii("rystal"),
        dictgen::InsensitiveStr::Ascii("rystallic"),
        dictgen::InsensitiveStr::Ascii("rystalline"),
        dictgen::InsensitiveStr::Ascii("rystic"),
        dictgen::InsensitiveStr::Ascii("yclic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOCEANOGRAPHY_14962055579685652535)],
        &[(0b10001, &ENTRY_PALEOCHOROLOGY_850601678065927399)],
        &[(0b10001, &ENTRY_PALEOCLIMATIC_6296078474332592218)],
        &[(0b10001, &ENTRY_PALEOCLIMATOLOGIC_16629931497670783741)],
        &[(0b10001, &ENTRY_PALEOCLIMATOLOGICAL_10778161163245213013)],
        &[(0b11001, &ENTRY_PALEOCLIMATOLOGIES_11917584077388492841)],
        &[(0b10001, &ENTRY_PALEOCLIMATOLOGIST_11724353766703176409)],
        &[(0b10001, &ENTRY_PALEOCLIMATOLOGISTS_1702175029968282301)],
        &[(0b11001, &ENTRY_PALEOCLIMATOLOGY_1888923764675563721)],
        &[(0b10001, &ENTRY_PALEOCONCHA_12575460314070906956)],
        &[(0b10001, &ENTRY_PALEOCOSMIC_8220601833060404387)],
        &[(0b10001, &ENTRY_PALEOCOSMOLOGY_3054270398344471213)],
        &[(0b10001, &ENTRY_PALEOCRYSTAL_6061679730436734129)],
        &[(0b10001, &ENTRY_PALEOCRYSTALLIC_7687563109158345160)],
        &[(0b10001, &ENTRY_PALEOCRYSTALLINE_16791923438113684889)],
        &[(0b10001, &ENTRY_PALEOCRYSTIC_6917970529581792050)],
        &[(0b10001, &ENTRY_PALEOCYCLIC_2933965135068085885)],
    ],
    range: 5..=13,
};

static VARS_PALEOB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOB_CHILDREN),
    value: None,
};

pub static VARS_PALEOB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iogeography"),
        dictgen::InsensitiveStr::Ascii("iologic"),
        dictgen::InsensitiveStr::Ascii("iological"),
        dictgen::InsensitiveStr::Ascii("iologies"),
        dictgen::InsensitiveStr::Ascii("iologist"),
        dictgen::InsensitiveStr::Ascii("iologists"),
        dictgen::InsensitiveStr::Ascii("iology"),
        dictgen::InsensitiveStr::Ascii("otanic"),
        dictgen::InsensitiveStr::Ascii("otanical"),
        dictgen::InsensitiveStr::Ascii("otanically"),
        dictgen::InsensitiveStr::Ascii("otanies"),
        dictgen::InsensitiveStr::Ascii("otanist"),
        dictgen::InsensitiveStr::Ascii("otanists"),
        dictgen::InsensitiveStr::Ascii("otany"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOBIOGEOGRAPHY_325937363029607315)],
        &[(0b10001, &ENTRY_PALEOBIOLOGIC_4482534007872730058)],
        &[(0b10001, &ENTRY_PALEOBIOLOGICAL_11068936077299560080)],
        &[(0b10001, &ENTRY_PALEOBIOLOGIES_16079649969733714006)],
        &[(0b10001, &ENTRY_PALEOBIOLOGIST_11463263721083732972)],
        &[(0b10001, &ENTRY_PALEOBIOLOGISTS_5556956387839510467)],
        &[(0b10001, &ENTRY_PALEOBIOLOGY_516075182383032405)],
        &[(0b10001, &ENTRY_PALEOBOTANIC_15818878290850712580)],
        &[(0b10001, &ENTRY_PALEOBOTANICAL_6725030604787116294)],
        &[(0b10001, &ENTRY_PALEOBOTANICALLY_8114378639258087733)],
        &[(0b10001, &ENTRY_PALEOBOTANIES_3595430527233437089)],
        &[(0b10001, &ENTRY_PALEOBOTANIST_12652116508136864156)],
        &[(0b10001, &ENTRY_PALEOBOTANISTS_12893724949436199492)],
        &[(0b10001, &ENTRY_PALEOBOTANY_15311510435996174332)],
    ],
    range: 5..=11,
};

static VARS_PALEOA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOA_CHILDREN),
    value: None,
};

pub static VARS_PALEOA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lchemical"),
        dictgen::InsensitiveStr::Ascii("nthropic"),
        dictgen::InsensitiveStr::Ascii("nthropography"),
        dictgen::InsensitiveStr::Ascii("nthropological"),
        dictgen::InsensitiveStr::Ascii("nthropologies"),
        dictgen::InsensitiveStr::Ascii("nthropologist"),
        dictgen::InsensitiveStr::Ascii("nthropologists"),
        dictgen::InsensitiveStr::Ascii("nthropology"),
        dictgen::InsensitiveStr::Ascii("nthropus"),
        dictgen::InsensitiveStr::Ascii("tavism"),
        dictgen::InsensitiveStr::Ascii("tavistic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOALCHEMICAL_2017386339869599932)],
        &[(0b10001, &ENTRY_PALEOANTHROPIC_5536563183205702870)],
        &[(0b10001, &ENTRY_PALEOANTHROPOGRAPHY_12272975649262449090)],
        &[(0b10001, &ENTRY_PALEOANTHROPOLOGICAL_8354621329613991958)],
        &[(0b10001, &ENTRY_PALEOANTHROPOLOGIES_574959913847154144)],
        &[(0b10001, &ENTRY_PALEOANTHROPOLOGIST_7159496852876445664)],
        &[(0b10001, &ENTRY_PALEOANTHROPOLOGISTS_5480906880376936367)],
        &[(0b10001, &ENTRY_PALEOANTHROPOLOGY_9395441508658928847)],
        &[(0b10001, &ENTRY_PALEOANTHROPUS_4669275914071277181)],
        &[(0b10001, &ENTRY_PALEOATAVISM_10031993578414975154)],
        &[(0b10001, &ENTRY_PALEOATAVISTIC_4298342201893698464)],
    ],
    range: 6..=14,
};

static VARS_PALEI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEI_CHILDREN),
    value: None,
};

pub static VARS_PALEI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chthyologist"),
        dictgen::InsensitiveStr::Ascii("chthyology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEICHTHYOLOGIST_10083578482342894714)],
        &[(0b10001, &ENTRY_PALEICHTHYOLOGY_16090612391743494942)],
    ],
    range: 10..=12,
};

static VARS_PALEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEE_CHILDREN),
    value: None,
};

pub static VARS_PALEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ncephalon"),
        dictgen::InsensitiveStr::Ascii("ntomology"),
        dictgen::InsensitiveStr::Ascii("thnologic"),
        dictgen::InsensitiveStr::Ascii("thnological"),
        dictgen::InsensitiveStr::Ascii("thnologist"),
        dictgen::InsensitiveStr::Ascii("thnology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEENCEPHALON_11148932634549019619)],
        &[(0b00001, &ENTRY_PALEENTOMOLOGY_15712434980354703142)],
        &[(0b10001, &ENTRY_PALEETHNOLOGIC_8892871688742593100)],
        &[(0b10001, &ENTRY_PALEETHNOLOGICAL_4481749690646676213)],
        &[(0b10001, &ENTRY_PALEETHNOLOGIST_6906911702331517133)],
        &[(0b10001, &ENTRY_PALEETHNOLOGY_3869668393036843087)],
    ],
    range: 8..=11,
};

static VARS_PALEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEA_CHILDREN),
    value: None,
};

pub static VARS_PALEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nthropic"),
        dictgen::InsensitiveStr::Ascii("rctic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEANTHROPIC_16127484915247367741)],
        &[(0b11001, &ENTRY_PALEARCTIC_269034461231115236)],
    ],
    range: 5..=8,
};

static VARS_PALA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PALA_CHILDREN),
    value: None,
};

static VARS_PALA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_PALAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PALAM_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PALAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PALAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAT_CHILDREN),
    value: None,
};

pub static VARS_PALAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("izes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PALATALIZATION_5484250888619777534)],
        &[(0b10010, &ENTRY_PALATALIZATIONS_4807700789809767940)],
        &[(0b10010, &ENTRY_PALATALIZE_11951391819712678616)],
        &[(0b10010, &ENTRY_PALATALIZED_9802151654299491783)],
        &[(0b10010, &ENTRY_PALATALIZES_9060739880362868418)],
        &[(0b10010, &ENTRY_PALATALIZING_8149766451780072792)],
        &[(0b01001, &ENTRY_PALATALIZATION_5484250888619777534)],
        &[(0b01001, &ENTRY_PALATALIZATIONS_4807700789809767940)],
        &[(0b01001, &ENTRY_PALATALIZE_11951391819712678616)],
        &[(0b01001, &ENTRY_PALATALIZED_9802151654299491783)],
        &[(0b01001, &ENTRY_PALATALIZES_9060739880362868418)],
        &[(0b01001, &ENTRY_PALATALIZING_8149766451780072792)],
        &[(0b10010, &ENTRY_PALATIZATION_13119970299223991169)],
        &[(0b10010, &ENTRY_PALATIZATIONS_1427522090300090503)],
        &[(0b10010, &ENTRY_PALATIZE_5247212428943117433)],
        &[(0b10010, &ENTRY_PALATIZES_7409196583984830669)],
        &[(0b01001, &ENTRY_PALATIZATION_13119970299223991169)],
        &[(0b01001, &ENTRY_PALATIZATIONS_1427522090300090503)],
        &[(0b01001, &ENTRY_PALATIZE_5247212428943117433)],
        &[(0b01001, &ENTRY_PALATIZES_7409196583984830669)],
    ],
    range: 3..=10,
};

static VARS_PALAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAM_CHILDREN),
    value: None,
};

pub static VARS_PALAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALAME_4183236324927672378)],
        &[(0b00001, &ENTRY_PALAME_4183236324927672378)],
    ],
    range: 1..=2,
};

static VARS_PALAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PALAE_CHILDREN),
    value: None,
};

static VARS_PALAE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PALAEA_NODE),
    None,
    None,
    None,
    Some(&VARS_PALAEE_NODE),
    None,
    None,
    None,
    Some(&VARS_PALAEI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PALAEO_NODE),
    None,
    None,
    None,
    Some(&VARS_PALAES_NODE),
    Some(&VARS_PALAET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PALAET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAET_CHILDREN),
    value: None,
};

pub static VARS_PALAET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("iology")],
    values: &[&[(0b11010, &ENTRY_PALETIOLOGY_4388412756789031487)]],
    range: 6..=6,
};

static VARS_PALAES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAES_CHILDREN),
    value: None,
};

pub static VARS_PALAES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tra"),
        dictgen::InsensitiveStr::Ascii("trae"),
        dictgen::InsensitiveStr::Ascii("tral"),
        dictgen::InsensitiveStr::Ascii("tras"),
        dictgen::InsensitiveStr::Ascii("trian"),
        dictgen::InsensitiveStr::Ascii("tric"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALESTRA_15858313904716663869)],
        &[(0b11010, &ENTRY_PALESTRAE_14184714476900356877)],
        &[(0b11010, &ENTRY_PALESTRAL_17875036424127182820)],
        &[(0b11010, &ENTRY_PALESTRAS_18241821718554443326)],
        &[(0b11010, &ENTRY_PALESTRIAN_16430867387330520444)],
        &[(0b11010, &ENTRY_PALESTRIC_10702847815072409215)],
    ],
    range: 3..=5,
};

static VARS_PALAEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PALAEO_CHILDREN),
    value: None,
};

static VARS_PALAEO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PALAEOA_NODE),
    Some(&VARS_PALAEOB_NODE),
    Some(&VARS_PALAEOC_NODE),
    Some(&VARS_PALAEOD_NODE),
    Some(&VARS_PALAEOE_NODE),
    Some(&VARS_PALAEOF_NODE),
    Some(&VARS_PALAEOG_NODE),
    Some(&VARS_PALAEOH_NODE),
    Some(&VARS_PALAEOI_NODE),
    None,
    None,
    Some(&VARS_PALAEOL_NODE),
    Some(&VARS_PALAEOM_NODE),
    Some(&VARS_PALAEON_NODE),
    None,
    Some(&VARS_PALAEOP_NODE),
    None,
    Some(&VARS_PALAEOR_NODE),
    Some(&VARS_PALAEOS_NODE),
    Some(&VARS_PALAEOT_NODE),
    None,
    Some(&VARS_PALAEOV_NODE),
    None,
    None,
    None,
    Some(&VARS_PALAEOZ_NODE),
];

static VARS_PALAEOZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOZ_CHILDREN),
    value: None,
};

pub static VARS_PALAEOZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oic"),
        dictgen::InsensitiveStr::Ascii("oologic"),
        dictgen::InsensitiveStr::Ascii("oological"),
        dictgen::InsensitiveStr::Ascii("oologies"),
        dictgen::InsensitiveStr::Ascii("oologist"),
        dictgen::InsensitiveStr::Ascii("oologists"),
        dictgen::InsensitiveStr::Ascii("oology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOZOIC_2171352618595825046)],
        &[(0b11010, &ENTRY_PALEOZOOLOGIC_12472183251804979806)],
        &[(0b11010, &ENTRY_PALEOZOOLOGICAL_7651649713235051506)],
        &[(0b11010, &ENTRY_PALEOZOOLOGIES_17902367901707184491)],
        &[(0b11010, &ENTRY_PALEOZOOLOGIST_4602703364020254946)],
        &[(0b11010, &ENTRY_PALEOZOOLOGISTS_6609845946465372037)],
        &[(0b11010, &ENTRY_PALEOZOOLOGY_5066201776927454990)],
    ],
    range: 3..=9,
};

static VARS_PALAEOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOV_CHILDREN),
    value: None,
};

pub static VARS_PALAEOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("olcanic")],
    values: &[&[(0b11010, &ENTRY_PALEOVOLCANIC_1100245805130475160)]],
    range: 7..=7,
};

static VARS_PALAEOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOT_CHILDREN),
    value: None,
};

pub static VARS_PALAEOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("echnic"),
        dictgen::InsensitiveStr::Ascii("halamus"),
        dictgen::InsensitiveStr::Ascii("ropical"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOTECHNIC_9551091213770179886)],
        &[(0b11010, &ENTRY_PALEOTHALAMUS_10925563677009720429)],
        &[(0b11010, &ENTRY_PALEOTROPICAL_18065203176296129763)],
    ],
    range: 6..=7,
};

static VARS_PALAEOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOS_CHILDREN),
    value: None,
};

pub static VARS_PALAEOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("triatal"),
        dictgen::InsensitiveStr::Ascii("triatum"),
        dictgen::InsensitiveStr::Ascii("tylic"),
        dictgen::InsensitiveStr::Ascii("tyly"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOSTRIATAL_17033529618847936065)],
        &[(0b11010, &ENTRY_PALEOSTRIATUM_8135708815680998194)],
        &[(0b11010, &ENTRY_PALEOSTYLIC_13586027329666518772)],
        &[(0b11010, &ENTRY_PALEOSTYLY_329937646655027738)],
    ],
    range: 4..=7,
};

static VARS_PALAEOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOR_CHILDREN),
    value: None,
};

pub static VARS_PALAEOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nithological"),
        dictgen::InsensitiveStr::Ascii("nithology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEORNITHOLOGICAL_6805615354003961394)],
        &[(0b11010, &ENTRY_PALEORNITHOLOGY_4480620476474604419)],
    ],
    range: 9..=12,
};

static VARS_PALAEOP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOP_CHILDREN),
    value: None,
};

pub static VARS_PALAEOP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("athologic"),
        dictgen::InsensitiveStr::Ascii("athological"),
        dictgen::InsensitiveStr::Ascii("athologies"),
        dictgen::InsensitiveStr::Ascii("athologist"),
        dictgen::InsensitiveStr::Ascii("athologists"),
        dictgen::InsensitiveStr::Ascii("athology"),
        dictgen::InsensitiveStr::Ascii("edology"),
        dictgen::InsensitiveStr::Ascii("hysiography"),
        dictgen::InsensitiveStr::Ascii("hysiology"),
        dictgen::InsensitiveStr::Ascii("hytic"),
        dictgen::InsensitiveStr::Ascii("hytological"),
        dictgen::InsensitiveStr::Ascii("hytologist"),
        dictgen::InsensitiveStr::Ascii("hytology"),
        dictgen::InsensitiveStr::Ascii("lain"),
        dictgen::InsensitiveStr::Ascii("otamology"),
        dictgen::InsensitiveStr::Ascii("sychic"),
        dictgen::InsensitiveStr::Ascii("sychological"),
        dictgen::InsensitiveStr::Ascii("sychology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOPATHOLOGIC_8048979982047381626)],
        &[(0b11010, &ENTRY_PALEOPATHOLOGICAL_6355077786853784135)],
        &[(0b11010, &ENTRY_PALEOPATHOLOGIES_3907569211124295484)],
        &[(0b11010, &ENTRY_PALEOPATHOLOGIST_11591525888140398394)],
        &[(0b11010, &ENTRY_PALEOPATHOLOGISTS_16699786230783410448)],
        &[(0b11010, &ENTRY_PALEOPATHOLOGY_3434376491146064878)],
        &[(0b11010, &ENTRY_PALEOPEDOLOGY_3869256322046937665)],
        &[(0b11010, &ENTRY_PALEOPHYSIOGRAPHY_11544580360735995612)],
        &[(0b11010, &ENTRY_PALEOPHYSIOLOGY_15071752915664349110)],
        &[(0b11010, &ENTRY_PALEOPHYTIC_6789302132283036079)],
        &[(0b11010, &ENTRY_PALEOPHYTOLOGICAL_5744086473592891476)],
        &[(0b11010, &ENTRY_PALEOPHYTOLOGIST_10785914590748470485)],
        &[(0b11010, &ENTRY_PALEOPHYTOLOGY_3952145533872729647)],
        &[(0b11010, &ENTRY_PALEOPLAIN_4445180941860383489)],
        &[(0b11010, &ENTRY_PALEOPOTAMOLOGY_9728822371435540856)],
        &[(0b11010, &ENTRY_PALEOPSYCHIC_1286029760595353697)],
        &[(0b11010, &ENTRY_PALEOPSYCHOLOGICAL_8115976081179191215)],
        &[(0b11010, &ENTRY_PALEOPSYCHOLOGY_14002375044163854176)],
    ],
    range: 4..=12,
};

static VARS_PALAEON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEON_CHILDREN),
    value: None,
};

pub static VARS_PALAEON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tographic"),
        dictgen::InsensitiveStr::Ascii("tographical"),
        dictgen::InsensitiveStr::Ascii("tographies"),
        dictgen::InsensitiveStr::Ascii("tography"),
        dictgen::InsensitiveStr::Ascii("tol"),
        dictgen::InsensitiveStr::Ascii("tologic"),
        dictgen::InsensitiveStr::Ascii("tological"),
        dictgen::InsensitiveStr::Ascii("tologically"),
        dictgen::InsensitiveStr::Ascii("tologist"),
        dictgen::InsensitiveStr::Ascii("tologists"),
        dictgen::InsensitiveStr::Ascii("tology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEONTOGRAPHIC_8614487224686150719)],
        &[(0b11010, &ENTRY_PALEONTOGRAPHICAL_8390709172465677724)],
        &[(0b11010, &ENTRY_PALEONTOGRAPHIES_6412037643243713928)],
        &[(0b11010, &ENTRY_PALEONTOGRAPHY_15155568729047027987)],
        &[(0b11010, &ENTRY_PALEONTOL_16908832703236553374)],
        &[(0b11010, &ENTRY_PALEONTOLOGIC_9726526633122558228)],
        &[(0b10010, &ENTRY_PALEONTOLOGICAL_11378757918485663576)],
        &[(0b11010, &ENTRY_PALEONTOLOGICALLY_7795552250402863412)],
        &[(0b10010, &ENTRY_PALEONTOLOGIST_14409308310083449867)],
        &[(0b10010, &ENTRY_PALEONTOLOGISTS_1615341850049645435)],
        &[(0b10010, &ENTRY_PALEONTOLOGY_8727472879076855658)],
    ],
    range: 3..=11,
};

static VARS_PALAEOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOM_CHILDREN),
    value: None,
};

pub static VARS_PALAEOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agnetism"),
        dictgen::InsensitiveStr::Ascii("agnetisms"),
        dictgen::InsensitiveStr::Ascii("etallic"),
        dictgen::InsensitiveStr::Ascii("eteorological"),
        dictgen::InsensitiveStr::Ascii("eteorology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOMAGNETISM_10382230568315308075)],
        &[(0b11010, &ENTRY_PALEOMAGNETISMS_11618371615606652138)],
        &[(0b11010, &ENTRY_PALEOMETALLIC_1327931506117283329)],
        &[(0b11010, &ENTRY_PALEOMETEOROLOGICAL_13764122166986418655)],
        &[(0b11010, &ENTRY_PALEOMETEOROLOGY_5577530218919631079)],
    ],
    range: 7..=13,
};

static VARS_PALAEOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOL_CHILDREN),
    value: None,
};

pub static VARS_PALAEOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atry"),
        dictgen::InsensitiveStr::Ascii("imnology"),
        dictgen::InsensitiveStr::Ascii("ith"),
        dictgen::InsensitiveStr::Ascii("ithic"),
        dictgen::InsensitiveStr::Ascii("ithical"),
        dictgen::InsensitiveStr::Ascii("ithist"),
        dictgen::InsensitiveStr::Ascii("ithoid"),
        dictgen::InsensitiveStr::Ascii("iths"),
        dictgen::InsensitiveStr::Ascii("ithy"),
        dictgen::InsensitiveStr::Ascii("ogical"),
        dictgen::InsensitiveStr::Ascii("ogist"),
        dictgen::InsensitiveStr::Ascii("ogy"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOLATRY_14450699210706774620)],
        &[(0b11010, &ENTRY_PALEOLIMNOLOGY_1236880097590741596)],
        &[(0b11010, &ENTRY_PALEOLITH_12363554094675316318)],
        &[(0b10010, &ENTRY_PALEOLITHIC_10579173722626414001)],
        &[(0b11010, &ENTRY_PALEOLITHICAL_1935974690293577369)],
        &[(0b11010, &ENTRY_PALEOLITHIST_9458879760716165734)],
        &[(0b11010, &ENTRY_PALEOLITHOID_6543358911316320294)],
        &[(0b11010, &ENTRY_PALEOLITHS_7568765529239450192)],
        &[(0b11010, &ENTRY_PALEOLITHY_7860170771676717319)],
        &[(0b11010, &ENTRY_PALEOLOGICAL_1841349892746131160)],
        &[(0b11010, &ENTRY_PALEOLOGIST_1275103816971686493)],
        &[(0b11010, &ENTRY_PALEOLOGY_9039082638538518660)],
    ],
    range: 3..=8,
};

static VARS_PALAEOI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOI_CHILDREN),
    value: None,
};

pub static VARS_PALAEOI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("chthyology")],
    values: &[&[(0b11010, &ENTRY_PALEOICHTHYOLOGY_16030251089000297685)]],
    range: 10..=10,
};

static VARS_PALAEOH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOH_CHILDREN),
    value: None,
};

pub static VARS_PALAEOH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erpetologist"),
        dictgen::InsensitiveStr::Ascii("erpetology"),
        dictgen::InsensitiveStr::Ascii("istology"),
        dictgen::InsensitiveStr::Ascii("ydrography"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOHERPETOLOGIST_3262925931087486684)],
        &[(0b11010, &ENTRY_PALEOHERPETOLOGY_10885033853235926434)],
        &[(0b11010, &ENTRY_PALEOHISTOLOGY_8638825422062573518)],
        &[(0b11010, &ENTRY_PALEOHYDROGRAPHY_2971028169559708924)],
    ],
    range: 8..=12,
};

static VARS_PALAEOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOG_CHILDREN),
    value: None,
};

pub static VARS_PALAEOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enesis"),
        dictgen::InsensitiveStr::Ascii("enetic"),
        dictgen::InsensitiveStr::Ascii("eographer"),
        dictgen::InsensitiveStr::Ascii("eographers"),
        dictgen::InsensitiveStr::Ascii("eographic"),
        dictgen::InsensitiveStr::Ascii("eographical"),
        dictgen::InsensitiveStr::Ascii("eographically"),
        dictgen::InsensitiveStr::Ascii("eographies"),
        dictgen::InsensitiveStr::Ascii("eography"),
        dictgen::InsensitiveStr::Ascii("eology"),
        dictgen::InsensitiveStr::Ascii("laciology"),
        dictgen::InsensitiveStr::Ascii("lyph"),
        dictgen::InsensitiveStr::Ascii("raph"),
        dictgen::InsensitiveStr::Ascii("raphic"),
        dictgen::InsensitiveStr::Ascii("raphical"),
        dictgen::InsensitiveStr::Ascii("raphically"),
        dictgen::InsensitiveStr::Ascii("raphist"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOGENESIS_17234588466739986743)],
        &[(0b11010, &ENTRY_PALEOGENETIC_3671327870094791359)],
        &[(0b11010, &ENTRY_PALEOGEOGRAPHER_7865313036683833980)],
        &[(0b11010, &ENTRY_PALEOGEOGRAPHERS_17925499304699862812)],
        &[(0b11010, &ENTRY_PALEOGEOGRAPHIC_12366567756392166026)],
        &[(0b11010, &ENTRY_PALEOGEOGRAPHICAL_16657456835077012317)],
        &[(0b11010, &ENTRY_PALEOGEOGRAPHICALLY_15437320738294900083)],
        &[(0b10010, &ENTRY_PALEOGEOGRAPHIES_12038367756274519862)],
        &[(0b10010, &ENTRY_PALEOGEOGRAPHY_14735924833615110050)],
        &[(0b11010, &ENTRY_PALEOGEOLOGY_10091590621653936254)],
        &[(0b11010, &ENTRY_PALEOGLACIOLOGY_16037720465585450625)],
        &[(0b11010, &ENTRY_PALEOGLYPH_15930058668062136413)],
        &[(0b11010, &ENTRY_PALEOGRAPH_13677256025266645311)],
        &[(0b11010, &ENTRY_PALEOGRAPHIC_8091858415531998756)],
        &[(0b11010, &ENTRY_PALEOGRAPHICAL_4607017356275969347)],
        &[(0b11010, &ENTRY_PALEOGRAPHICALLY_10052249768233307285)],
        &[(0b11010, &ENTRY_PALEOGRAPHIST_16452384260584578278)],
    ],
    range: 4..=13,
};

static VARS_PALAEOF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOF_CHILDREN),
    value: None,
};

pub static VARS_PALAEOF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("auna")],
    values: &[&[(0b11010, &ENTRY_PALEOFAUNA_14514918396801724693)]],
    range: 4..=4,
};

static VARS_PALAEOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOE_CHILDREN),
    value: None,
};

pub static VARS_PALAEOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cologic"),
        dictgen::InsensitiveStr::Ascii("cological"),
        dictgen::InsensitiveStr::Ascii("cologies"),
        dictgen::InsensitiveStr::Ascii("cologist"),
        dictgen::InsensitiveStr::Ascii("cologists"),
        dictgen::InsensitiveStr::Ascii("cology"),
        dictgen::InsensitiveStr::Ascii("ncephalon"),
        dictgen::InsensitiveStr::Ascii("ntomologic"),
        dictgen::InsensitiveStr::Ascii("ntomological"),
        dictgen::InsensitiveStr::Ascii("ntomologist"),
        dictgen::InsensitiveStr::Ascii("remology"),
        dictgen::InsensitiveStr::Ascii("thnic"),
        dictgen::InsensitiveStr::Ascii("thnography"),
        dictgen::InsensitiveStr::Ascii("thnologic"),
        dictgen::InsensitiveStr::Ascii("thnological"),
        dictgen::InsensitiveStr::Ascii("thnologist"),
        dictgen::InsensitiveStr::Ascii("thnology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOECOLOGIC_4669354935242540330)],
        &[(0b11010, &ENTRY_PALEOECOLOGICAL_12243112048304818096)],
        &[(0b10010, &ENTRY_PALEOECOLOGIES_18110959250046855627)],
        &[(0b11010, &ENTRY_PALEOECOLOGIST_8254000552693957088)],
        &[(0b11010, &ENTRY_PALEOECOLOGISTS_3308516876293590602)],
        &[(0b10010, &ENTRY_PALEOECOLOGY_4482816158539091906)],
        &[(0b11010, &ENTRY_PALEOENCEPHALON_9569832069668177801)],
        &[(0b11010, &ENTRY_PALEOENTOMOLOGIC_4007524847624498176)],
        &[(0b11010, &ENTRY_PALEOENTOMOLOGICAL_16493536171383050969)],
        &[(0b11010, &ENTRY_PALEOENTOMOLOGIST_5004696292111737108)],
        &[(0b11010, &ENTRY_PALEOEREMOLOGY_179203799725486477)],
        &[(0b11010, &ENTRY_PALEOETHNIC_18256982848006324404)],
        &[(0b11010, &ENTRY_PALEOETHNOGRAPHY_4293329065986396408)],
        &[(0b11010, &ENTRY_PALEOETHNOLOGIC_3941018589215004237)],
        &[(0b11010, &ENTRY_PALEOETHNOLOGICAL_2716015278756182228)],
        &[(0b11010, &ENTRY_PALEOETHNOLOGIST_5288127538766606384)],
        &[(0b11010, &ENTRY_PALEOETHNOLOGY_4385814784718071920)],
    ],
    range: 5..=12,
};

static VARS_PALAEOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOD_CHILDREN),
    value: None,
};

pub static VARS_PALAEOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("endrologic"),
        dictgen::InsensitiveStr::Ascii("endrological"),
        dictgen::InsensitiveStr::Ascii("endrologically"),
        dictgen::InsensitiveStr::Ascii("endrologist"),
        dictgen::InsensitiveStr::Ascii("endrology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEODENDROLOGIC_6856992872417007321)],
        &[(0b11010, &ENTRY_PALEODENDROLOGICAL_16026323992623885288)],
        &[(0b11010, &ENTRY_PALEODENDROLOGICALLY_10449298583529356832)],
        &[(0b11010, &ENTRY_PALEODENDROLOGIST_3579987086039471029)],
        &[(0b11010, &ENTRY_PALEODENDROLOGY_644708576508951069)],
    ],
    range: 9..=14,
};

static VARS_PALAEOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOC_CHILDREN),
    value: None,
};

pub static VARS_PALAEOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eanography"),
        dictgen::InsensitiveStr::Ascii("horology"),
        dictgen::InsensitiveStr::Ascii("limatic"),
        dictgen::InsensitiveStr::Ascii("limatologic"),
        dictgen::InsensitiveStr::Ascii("limatological"),
        dictgen::InsensitiveStr::Ascii("limatologies"),
        dictgen::InsensitiveStr::Ascii("limatologist"),
        dictgen::InsensitiveStr::Ascii("limatologists"),
        dictgen::InsensitiveStr::Ascii("limatology"),
        dictgen::InsensitiveStr::Ascii("oncha"),
        dictgen::InsensitiveStr::Ascii("osmic"),
        dictgen::InsensitiveStr::Ascii("osmology"),
        dictgen::InsensitiveStr::Ascii("rystal"),
        dictgen::InsensitiveStr::Ascii("rystallic"),
        dictgen::InsensitiveStr::Ascii("rystalline"),
        dictgen::InsensitiveStr::Ascii("rystic"),
        dictgen::InsensitiveStr::Ascii("yclic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOCEANOGRAPHY_14962055579685652535)],
        &[(0b11010, &ENTRY_PALEOCHOROLOGY_850601678065927399)],
        &[(0b11010, &ENTRY_PALEOCLIMATIC_6296078474332592218)],
        &[(0b11010, &ENTRY_PALEOCLIMATOLOGIC_16629931497670783741)],
        &[(0b11010, &ENTRY_PALEOCLIMATOLOGICAL_10778161163245213013)],
        &[(0b10010, &ENTRY_PALEOCLIMATOLOGIES_11917584077388492841)],
        &[(0b11010, &ENTRY_PALEOCLIMATOLOGIST_11724353766703176409)],
        &[(0b11010, &ENTRY_PALEOCLIMATOLOGISTS_1702175029968282301)],
        &[(0b10010, &ENTRY_PALEOCLIMATOLOGY_1888923764675563721)],
        &[(0b11010, &ENTRY_PALEOCONCHA_12575460314070906956)],
        &[(0b11010, &ENTRY_PALEOCOSMIC_8220601833060404387)],
        &[(0b11010, &ENTRY_PALEOCOSMOLOGY_3054270398344471213)],
        &[(0b11010, &ENTRY_PALEOCRYSTAL_6061679730436734129)],
        &[(0b11010, &ENTRY_PALEOCRYSTALLIC_7687563109158345160)],
        &[(0b11010, &ENTRY_PALEOCRYSTALLINE_16791923438113684889)],
        &[(0b11010, &ENTRY_PALEOCRYSTIC_6917970529581792050)],
        &[(0b11010, &ENTRY_PALEOCYCLIC_2933965135068085885)],
    ],
    range: 5..=13,
};

static VARS_PALAEOB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOB_CHILDREN),
    value: None,
};

pub static VARS_PALAEOB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iogeography"),
        dictgen::InsensitiveStr::Ascii("iologic"),
        dictgen::InsensitiveStr::Ascii("iological"),
        dictgen::InsensitiveStr::Ascii("iologies"),
        dictgen::InsensitiveStr::Ascii("iologist"),
        dictgen::InsensitiveStr::Ascii("iologists"),
        dictgen::InsensitiveStr::Ascii("iology"),
        dictgen::InsensitiveStr::Ascii("otanic"),
        dictgen::InsensitiveStr::Ascii("otanical"),
        dictgen::InsensitiveStr::Ascii("otanically"),
        dictgen::InsensitiveStr::Ascii("otanies"),
        dictgen::InsensitiveStr::Ascii("otanist"),
        dictgen::InsensitiveStr::Ascii("otanists"),
        dictgen::InsensitiveStr::Ascii("otany"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOBIOGEOGRAPHY_325937363029607315)],
        &[(0b11010, &ENTRY_PALEOBIOLOGIC_4482534007872730058)],
        &[(0b11010, &ENTRY_PALEOBIOLOGICAL_11068936077299560080)],
        &[(0b11010, &ENTRY_PALEOBIOLOGIES_16079649969733714006)],
        &[(0b11010, &ENTRY_PALEOBIOLOGIST_11463263721083732972)],
        &[(0b11010, &ENTRY_PALEOBIOLOGISTS_5556956387839510467)],
        &[(0b11010, &ENTRY_PALEOBIOLOGY_516075182383032405)],
        &[(0b11010, &ENTRY_PALEOBOTANIC_15818878290850712580)],
        &[(0b11010, &ENTRY_PALEOBOTANICAL_6725030604787116294)],
        &[(0b11010, &ENTRY_PALEOBOTANICALLY_8114378639258087733)],
        &[(0b11010, &ENTRY_PALEOBOTANIES_3595430527233437089)],
        &[(0b11010, &ENTRY_PALEOBOTANIST_12652116508136864156)],
        &[(0b11010, &ENTRY_PALEOBOTANISTS_12893724949436199492)],
        &[(0b11010, &ENTRY_PALEOBOTANY_15311510435996174332)],
    ],
    range: 5..=11,
};

static VARS_PALAEOA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOA_CHILDREN),
    value: None,
};

pub static VARS_PALAEOA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lchemical"),
        dictgen::InsensitiveStr::Ascii("nthropic"),
        dictgen::InsensitiveStr::Ascii("nthropography"),
        dictgen::InsensitiveStr::Ascii("nthropological"),
        dictgen::InsensitiveStr::Ascii("nthropologies"),
        dictgen::InsensitiveStr::Ascii("nthropologist"),
        dictgen::InsensitiveStr::Ascii("nthropologists"),
        dictgen::InsensitiveStr::Ascii("nthropology"),
        dictgen::InsensitiveStr::Ascii("nthropus"),
        dictgen::InsensitiveStr::Ascii("tavism"),
        dictgen::InsensitiveStr::Ascii("tavistic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOALCHEMICAL_2017386339869599932)],
        &[(0b11010, &ENTRY_PALEOANTHROPIC_5536563183205702870)],
        &[(0b11010, &ENTRY_PALEOANTHROPOGRAPHY_12272975649262449090)],
        &[(0b11010, &ENTRY_PALEOANTHROPOLOGICAL_8354621329613991958)],
        &[(0b11010, &ENTRY_PALEOANTHROPOLOGIES_574959913847154144)],
        &[(0b11010, &ENTRY_PALEOANTHROPOLOGIST_7159496852876445664)],
        &[(0b11010, &ENTRY_PALEOANTHROPOLOGISTS_5480906880376936367)],
        &[(0b11010, &ENTRY_PALEOANTHROPOLOGY_9395441508658928847)],
        &[(0b11010, &ENTRY_PALEOANTHROPUS_4669275914071277181)],
        &[(0b11010, &ENTRY_PALEOATAVISM_10031993578414975154)],
        &[(0b11010, &ENTRY_PALEOATAVISTIC_4298342201893698464)],
    ],
    range: 6..=14,
};

static VARS_PALAEI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEI_CHILDREN),
    value: None,
};

pub static VARS_PALAEI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chthyologist"),
        dictgen::InsensitiveStr::Ascii("chthyology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEICHTHYOLOGIST_10083578482342894714)],
        &[(0b11010, &ENTRY_PALEICHTHYOLOGY_16090612391743494942)],
    ],
    range: 10..=12,
};

static VARS_PALAEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEE_CHILDREN),
    value: None,
};

pub static VARS_PALAEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ncephalon"),
        dictgen::InsensitiveStr::Ascii("ntomology"),
        dictgen::InsensitiveStr::Ascii("thnologic"),
        dictgen::InsensitiveStr::Ascii("thnological"),
        dictgen::InsensitiveStr::Ascii("thnologist"),
        dictgen::InsensitiveStr::Ascii("thnology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEENCEPHALON_11148932634549019619)],
        &[(0b11010, &ENTRY_PALEENTOMOLOGY_15712434980354703142)],
        &[(0b11010, &ENTRY_PALEETHNOLOGIC_8892871688742593100)],
        &[(0b11010, &ENTRY_PALEETHNOLOGICAL_4481749690646676213)],
        &[(0b11010, &ENTRY_PALEETHNOLOGIST_6906911702331517133)],
        &[(0b11010, &ENTRY_PALEETHNOLOGY_3869668393036843087)],
    ],
    range: 8..=11,
};

static VARS_PALAEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEA_CHILDREN),
    value: None,
};

pub static VARS_PALAEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nthropic"),
        dictgen::InsensitiveStr::Ascii("rctic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEANTHROPIC_16127484915247367741)],
        &[(0b10010, &ENTRY_PALEARCTIC_269034461231115236)],
    ],
    range: 5..=8,
};

static VARS_PAJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAJ_CHILDREN),
    value: None,
};

pub static VARS_PAJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ama"),
        dictgen::InsensitiveStr::Ascii("amaed"),
        dictgen::InsensitiveStr::Ascii("amas"),
    ],
    values: &[
        &[(0b01001, &ENTRY_PAJAMA_3939742153808099869)],
        &[(0b00001, &ENTRY_PAJAMAED_6840620032200463652)],
        &[(0b01001, &ENTRY_PAJAMAS_18438866384752213563)],
    ],
    range: 3..=5,
};

static VARS_PAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAG_CHILDREN),
    value: None,
};

pub static VARS_PAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anisations"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("aniser"),
        dictgen::InsensitiveStr::Ascii("anisers"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anizations"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizer"),
        dictgen::InsensitiveStr::Ascii("anizers"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("inae"),
        dictgen::InsensitiveStr::Ascii("ine"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAGANIZATION_2943576925427198072)],
        &[(0b10010, &ENTRY_PAGANIZATIONS_12724171596950745904)],
        &[(0b10010, &ENTRY_PAGANIZE_15046389715179883624)],
        &[(0b10010, &ENTRY_PAGANIZED_10870075564649051258)],
        &[(0b10010, &ENTRY_PAGANIZER_1865530174558486992)],
        &[(0b10010, &ENTRY_PAGANIZERS_9387808109651520352)],
        &[(0b10010, &ENTRY_PAGANIZES_1804382210312745290)],
        &[(0b10010, &ENTRY_PAGANIZING_16496197304705619669)],
        &[(0b01001, &ENTRY_PAGANIZATION_2943576925427198072)],
        &[(0b01001, &ENTRY_PAGANIZATIONS_12724171596950745904)],
        &[(0b01001, &ENTRY_PAGANIZE_15046389715179883624)],
        &[(0b01001, &ENTRY_PAGANIZED_10870075564649051258)],
        &[(0b01001, &ENTRY_PAGANIZER_1865530174558486992)],
        &[(0b01001, &ENTRY_PAGANIZERS_9387808109651520352)],
        &[(0b01001, &ENTRY_PAGANIZES_1804382210312745290)],
        &[(0b01001, &ENTRY_PAGANIZING_16496197304705619669)],
        &[(0b11010, &ENTRY_PAGINE_14521861128818045118)],
        &[(0b00001, &ENTRY_PAGINE_14521861128818045118)],
    ],
    range: 3..=10,
};

static VARS_PAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAE_CHILDREN),
    value: None,
};

pub static VARS_PAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("dagogism"),
        dictgen::InsensitiveStr::Ascii("datrophia"),
        dictgen::InsensitiveStr::Ascii("datrophy"),
        dictgen::InsensitiveStr::Ascii("derast"),
        dictgen::InsensitiveStr::Ascii("derastic"),
        dictgen::InsensitiveStr::Ascii("derastically"),
        dictgen::InsensitiveStr::Ascii("derasts"),
        dictgen::InsensitiveStr::Ascii("diatric"),
        dictgen::InsensitiveStr::Ascii("diatrician"),
        dictgen::InsensitiveStr::Ascii("diatricians"),
        dictgen::InsensitiveStr::Ascii("diatrics"),
        dictgen::InsensitiveStr::Ascii("diatry"),
        dictgen::InsensitiveStr::Ascii("dobaptism"),
        dictgen::InsensitiveStr::Ascii("dobaptist"),
        dictgen::InsensitiveStr::Ascii("dodontic"),
        dictgen::InsensitiveStr::Ascii("dodontics"),
        dictgen::InsensitiveStr::Ascii("dogeneses"),
        dictgen::InsensitiveStr::Ascii("dogenesis"),
        dictgen::InsensitiveStr::Ascii("dogenetic"),
        dictgen::InsensitiveStr::Ascii("dogenic"),
        dictgen::InsensitiveStr::Ascii("dological"),
        dictgen::InsensitiveStr::Ascii("dologies"),
        dictgen::InsensitiveStr::Ascii("dologist"),
        dictgen::InsensitiveStr::Ascii("dologists"),
        dictgen::InsensitiveStr::Ascii("dology"),
        dictgen::InsensitiveStr::Ascii("dometrical"),
        dictgen::InsensitiveStr::Ascii("domorphic"),
        dictgen::InsensitiveStr::Ascii("domorphism"),
        dictgen::InsensitiveStr::Ascii("domorphisms"),
        dictgen::InsensitiveStr::Ascii("domorphoses"),
        dictgen::InsensitiveStr::Ascii("domorphosis"),
        dictgen::InsensitiveStr::Ascii("dophile"),
        dictgen::InsensitiveStr::Ascii("dophiles"),
        dictgen::InsensitiveStr::Ascii("dophilia"),
        dictgen::InsensitiveStr::Ascii("dophiliac"),
        dictgen::InsensitiveStr::Ascii("dophiliacs"),
        dictgen::InsensitiveStr::Ascii("dophilias"),
        dictgen::InsensitiveStr::Ascii("dophilic"),
        dictgen::InsensitiveStr::Ascii("dotribe"),
        dictgen::InsensitiveStr::Ascii("dotrophic"),
        dictgen::InsensitiveStr::Ascii("dotrophist"),
        dictgen::InsensitiveStr::Ascii("dotrophy"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAEANIZE_15507572022142186294)],
        &[(0b10010, &ENTRY_PAEANIZES_11463331795160910581)],
        &[(0b01001, &ENTRY_PAEANIZE_15507572022142186294)],
        &[(0b01001, &ENTRY_PAEANIZES_11463331795160910581)],
        &[(0b11010, &ENTRY_PEDAGOGISM_12986063057005247378)],
        &[(0b11010, &ENTRY_PEDATROPHIA_14603400894477278904)],
        &[(0b11010, &ENTRY_PEDATROPHY_987856254519026242)],
        &[(0b11010, &ENTRY_PEDERAST_6508738365729508616)],
        &[(0b11010, &ENTRY_PEDERASTIC_5749923948076776972)],
        &[(0b11010, &ENTRY_PEDERASTICALLY_851286493260604551)],
        &[(0b11010, &ENTRY_PEDERASTS_5835872448427039713)],
        &[(0b10010, &ENTRY_PEDIATRIC_14057388448801273518)],
        &[(0b10010, &ENTRY_PEDIATRICIAN_10944796143655723735)],
        &[(0b10010, &ENTRY_PEDIATRICIANS_11770782104393001942)],
        &[(0b10010, &ENTRY_PEDIATRICS_11689829247825832837)],
        &[(0b11010, &ENTRY_PEDIATRY_12652041456225827046)],
        &[(0b11010, &ENTRY_PEDOBAPTISM_6120739017189134576)],
        &[(0b11010, &ENTRY_PEDOBAPTIST_13392021271448005376)],
        &[(0b11010, &ENTRY_PEDODONTIC_7097035619717257706)],
        &[(0b11010, &ENTRY_PEDODONTICS_8145223833546781144)],
        &[(0b11010, &ENTRY_PEDOGENESES_11751885517659328439)],
        &[(0b11010, &ENTRY_PEDOGENESIS_16553520519907492848)],
        &[(0b11010, &ENTRY_PEDOGENETIC_14694065223630380055)],
        &[(0b11010, &ENTRY_PEDOGENIC_1833539086674286725)],
        &[(0b11010, &ENTRY_PEDOLOGICAL_2385823981182048058)],
        &[(0b11010, &ENTRY_PEDOLOGIES_1726305538167071973)],
        &[(0b11010, &ENTRY_PEDOLOGIST_354177147374191220)],
        &[(0b11010, &ENTRY_PEDOLOGISTS_1566477727057184854)],
        &[(0b11010, &ENTRY_PEDOLOGY_4566379431183985277)],
        &[(0b11010, &ENTRY_PEDOMETRICAL_17829124265715907889)],
        &[(0b11010, &ENTRY_PEDOMORPHIC_146159920442818415)],
        &[(0b11010, &ENTRY_PEDOMORPHISM_11023075726064362802)],
        &[(0b11010, &ENTRY_PEDOMORPHISMS_7963376961948666057)],
        &[(0b11010, &ENTRY_PEDOMORPHOSES_13196177470788332356)],
        &[(0b11010, &ENTRY_PEDOMORPHOSIS_10919909675152569331)],
        &[(0b10010, &ENTRY_PEDOPHILE_17284081556096473917)],
        &[(0b10010, &ENTRY_PEDOPHILES_18122867727560912141)],
        &[(0b11010, &ENTRY_PEDOPHILIA_6687546858614581858)],
        &[(0b11010, &ENTRY_PEDOPHILIAC_9617447498442302443)],
        &[(0b11010, &ENTRY_PEDOPHILIACS_13603976488274466890)],
        &[(0b11010, &ENTRY_PEDOPHILIAS_7493061271312788807)],
        &[(0b11010, &ENTRY_PEDOPHILIC_17657453635897677867)],
        &[(0b11010, &ENTRY_PEDOTRIBE_8433883032428611364)],
        &[(0b11010, &ENTRY_PEDOTROPHIC_13712350295339661103)],
        &[(0b11010, &ENTRY_PEDOTROPHIST_8546583891936764947)],
        &[(0b11010, &ENTRY_PEDOTROPHY_12360033708377322745)],
    ],
    range: 5..=12,
};

static VARS_PAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAC_CHILDREN),
    value: None,
};

pub static VARS_PAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hyaemia"),
        dictgen::InsensitiveStr::Ascii("hyemia"),
        dictgen::InsensitiveStr::Ascii("hyhaemia"),
        dictgen::InsensitiveStr::Ascii("hyhemia"),
        dictgen::InsensitiveStr::Ascii("ketisation"),
        dictgen::InsensitiveStr::Ascii("ketise"),
        dictgen::InsensitiveStr::Ascii("ketised"),
        dictgen::InsensitiveStr::Ascii("ketiser"),
        dictgen::InsensitiveStr::Ascii("ketisers"),
        dictgen::InsensitiveStr::Ascii("ketises"),
        dictgen::InsensitiveStr::Ascii("ketising"),
        dictgen::InsensitiveStr::Ascii("ketization"),
        dictgen::InsensitiveStr::Ascii("ketize"),
        dictgen::InsensitiveStr::Ascii("ketized"),
        dictgen::InsensitiveStr::Ascii("ketizer"),
        dictgen::InsensitiveStr::Ascii("ketizers"),
        dictgen::InsensitiveStr::Ascii("ketizes"),
        dictgen::InsensitiveStr::Ascii("ketizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PACHYEMIA_9489620928857821879)],
        &[(0b10001, &ENTRY_PACHYEMIA_9489620928857821879)],
        &[(0b11010, &ENTRY_PACHYHEMIA_8832332591288336993)],
        &[(0b10001, &ENTRY_PACHYHEMIA_8832332591288336993)],
        &[(0b10010, &ENTRY_PACKETIZATION_10464592564290475261)],
        &[(0b10010, &ENTRY_PACKETIZE_5763572427852346907)],
        &[(0b10010, &ENTRY_PACKETIZED_8036428449595588231)],
        &[(0b10010, &ENTRY_PACKETIZER_15919936461315780788)],
        &[(0b10010, &ENTRY_PACKETIZERS_3352597016758962447)],
        &[(0b10010, &ENTRY_PACKETIZES_11082673242873858301)],
        &[(0b10010, &ENTRY_PACKETIZING_2464553966414791741)],
        &[(0b01001, &ENTRY_PACKETIZATION_10464592564290475261)],
        &[(0b01001, &ENTRY_PACKETIZE_5763572427852346907)],
        &[(0b01001, &ENTRY_PACKETIZED_8036428449595588231)],
        &[(0b01001, &ENTRY_PACKETIZER_15919936461315780788)],
        &[(0b01001, &ENTRY_PACKETIZERS_3352597016758962447)],
        &[(0b01001, &ENTRY_PACKETIZES_11082673242873858301)],
        &[(0b01001, &ENTRY_PACKETIZING_2464553966414791741)],
    ],
    range: 6..=10,
};

static VARS_O_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_O_CHILDREN),
    value: None,
};

static VARS_O_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_OB_NODE),
    Some(&VARS_OC_NODE),
    Some(&VARS_OD_NODE),
    Some(&VARS_OE_NODE),
    Some(&VARS_OF_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_OL_NODE),
    Some(&VARS_OM_NODE),
    Some(&VARS_ON_NODE),
    Some(&VARS_OO_NODE),
    Some(&VARS_OP_NODE),
    None,
    Some(&VARS_OR_NODE),
    Some(&VARS_OS_NODE),
    Some(&VARS_OT_NODE),
    Some(&VARS_OU_NODE),
    Some(&VARS_OV_NODE),
    Some(&VARS_OW_NODE),
    Some(&VARS_OX_NODE),
    None,
    Some(&VARS_OZ_NODE),
];

static VARS_OZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OZ_CHILDREN),
    value: None,
};

pub static VARS_OZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aena"),
        dictgen::InsensitiveStr::Ascii("ena"),
        dictgen::InsensitiveStr::Ascii("oena"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniser"),
        dictgen::InsensitiveStr::Ascii("onisers"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizer"),
        dictgen::InsensitiveStr::Ascii("onizers"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OZENA_7757597485130320426)],
        &[
            (0b00001, &ENTRY_OZENA_5442312756553924434),
            (0b00001, &ENTRY_OZENA_7757597485130320426),
        ],
        &[(0b11010, &ENTRY_OZENA_5442312756553924434)],
        &[(0b10010, &ENTRY_OZONIZATION_12273080851661121450)],
        &[(0b10010, &ENTRY_OZONIZATIONS_15122382781840799944)],
        &[(0b10010, &ENTRY_OZONIZE_346284534762547575)],
        &[(0b10010, &ENTRY_OZONIZED_9207502852384727699)],
        &[(0b10010, &ENTRY_OZONIZER_15162830907127483395)],
        &[(0b10010, &ENTRY_OZONIZERS_10604136522486103167)],
        &[(0b10010, &ENTRY_OZONIZES_3688167369925893609)],
        &[(0b10010, &ENTRY_OZONIZING_8937744434536354872)],
        &[(0b01001, &ENTRY_OZONIZATION_12273080851661121450)],
        &[(0b01001, &ENTRY_OZONIZATIONS_15122382781840799944)],
        &[(0b01001, &ENTRY_OZONIZE_346284534762547575)],
        &[(0b01001, &ENTRY_OZONIZED_9207502852384727699)],
        &[(0b01001, &ENTRY_OZONIZER_15162830907127483395)],
        &[(0b01001, &ENTRY_OZONIZERS_10604136522486103167)],
        &[(0b01001, &ENTRY_OZONIZES_3688167369925893609)],
        &[(0b01001, &ENTRY_OZONIZING_8937744434536354872)],
    ],
    range: 3..=10,
};

static VARS_OX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OX_CHILDREN),
    value: None,
};

pub static VARS_OX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alaemia"),
        dictgen::InsensitiveStr::Ascii("alemia"),
        dictgen::InsensitiveStr::Ascii("idisabilities"),
        dictgen::InsensitiveStr::Ascii("idisability"),
        dictgen::InsensitiveStr::Ascii("idisable"),
        dictgen::InsensitiveStr::Ascii("idisables"),
        dictgen::InsensitiveStr::Ascii("idisation"),
        dictgen::InsensitiveStr::Ascii("idisations"),
        dictgen::InsensitiveStr::Ascii("idise"),
        dictgen::InsensitiveStr::Ascii("idised"),
        dictgen::InsensitiveStr::Ascii("idisement"),
        dictgen::InsensitiveStr::Ascii("idisements"),
        dictgen::InsensitiveStr::Ascii("idiser"),
        dictgen::InsensitiveStr::Ascii("idisers"),
        dictgen::InsensitiveStr::Ascii("idises"),
        dictgen::InsensitiveStr::Ascii("idising"),
        dictgen::InsensitiveStr::Ascii("idisings"),
        dictgen::InsensitiveStr::Ascii("idizabilities"),
        dictgen::InsensitiveStr::Ascii("idizability"),
        dictgen::InsensitiveStr::Ascii("idizable"),
        dictgen::InsensitiveStr::Ascii("idizables"),
        dictgen::InsensitiveStr::Ascii("idization"),
        dictgen::InsensitiveStr::Ascii("idizations"),
        dictgen::InsensitiveStr::Ascii("idize"),
        dictgen::InsensitiveStr::Ascii("idized"),
        dictgen::InsensitiveStr::Ascii("idizement"),
        dictgen::InsensitiveStr::Ascii("idizements"),
        dictgen::InsensitiveStr::Ascii("idizer"),
        dictgen::InsensitiveStr::Ascii("idizers"),
        dictgen::InsensitiveStr::Ascii("idizes"),
        dictgen::InsensitiveStr::Ascii("idizing"),
        dictgen::InsensitiveStr::Ascii("idizings"),
        dictgen::InsensitiveStr::Ascii("ygenisable"),
        dictgen::InsensitiveStr::Ascii("ygenisables"),
        dictgen::InsensitiveStr::Ascii("ygenise"),
        dictgen::InsensitiveStr::Ascii("ygenised"),
        dictgen::InsensitiveStr::Ascii("ygenisement"),
        dictgen::InsensitiveStr::Ascii("ygenisements"),
        dictgen::InsensitiveStr::Ascii("ygeniser"),
        dictgen::InsensitiveStr::Ascii("ygenisers"),
        dictgen::InsensitiveStr::Ascii("ygenises"),
        dictgen::InsensitiveStr::Ascii("ygenising"),
        dictgen::InsensitiveStr::Ascii("ygenizable"),
        dictgen::InsensitiveStr::Ascii("ygenizables"),
        dictgen::InsensitiveStr::Ascii("ygenize"),
        dictgen::InsensitiveStr::Ascii("ygenized"),
        dictgen::InsensitiveStr::Ascii("ygenizement"),
        dictgen::InsensitiveStr::Ascii("ygenizements"),
        dictgen::InsensitiveStr::Ascii("ygenizer"),
        dictgen::InsensitiveStr::Ascii("ygenizers"),
        dictgen::InsensitiveStr::Ascii("ygenizes"),
        dictgen::InsensitiveStr::Ascii("ygenizing"),
        dictgen::InsensitiveStr::Ascii("yhaematin"),
        dictgen::InsensitiveStr::Ascii("yhaemoglobin"),
        dictgen::InsensitiveStr::Ascii("yhaemoglobins"),
        dictgen::InsensitiveStr::Ascii("yhematin"),
        dictgen::InsensitiveStr::Ascii("yhemoglobin"),
        dictgen::InsensitiveStr::Ascii("yhemoglobins"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OXALEMIA_11109410730791647209)],
        &[(0b10001, &ENTRY_OXALEMIA_11109410730791647209)],
        &[(0b10010, &ENTRY_OXIDIZABILITIES_6073197852100555717)],
        &[(0b10010, &ENTRY_OXIDIZABILITY_989208003122354980)],
        &[(0b10010, &ENTRY_OXIDIZABLE_5289655147636602365)],
        &[(0b10010, &ENTRY_OXIDIZABLES_10964178463482153600)],
        &[(0b10010, &ENTRY_OXIDIZATION_13166504173020505769)],
        &[(0b10010, &ENTRY_OXIDIZATIONS_10794857157062767651)],
        &[(0b10010, &ENTRY_OXIDIZE_16273392528175590013)],
        &[(0b10010, &ENTRY_OXIDIZED_11075904073295172473)],
        &[(0b10010, &ENTRY_OXIDIZEMENT_4972583911879846564)],
        &[(0b10010, &ENTRY_OXIDIZEMENTS_97180816186053602)],
        &[(0b10010, &ENTRY_OXIDIZER_10115554319871451478)],
        &[(0b10010, &ENTRY_OXIDIZERS_15313203568879188818)],
        &[(0b10010, &ENTRY_OXIDIZES_9639252663902404191)],
        &[(0b10010, &ENTRY_OXIDIZING_16338645204512386709)],
        &[(0b10010, &ENTRY_OXIDIZINGS_10090589532009393809)],
        &[(0b01001, &ENTRY_OXIDIZABILITIES_6073197852100555717)],
        &[(0b01001, &ENTRY_OXIDIZABILITY_989208003122354980)],
        &[(0b01001, &ENTRY_OXIDIZABLE_5289655147636602365)],
        &[(0b01001, &ENTRY_OXIDIZABLES_10964178463482153600)],
        &[(0b01001, &ENTRY_OXIDIZATION_13166504173020505769)],
        &[(0b01001, &ENTRY_OXIDIZATIONS_10794857157062767651)],
        &[(0b01001, &ENTRY_OXIDIZE_16273392528175590013)],
        &[(0b01001, &ENTRY_OXIDIZED_11075904073295172473)],
        &[(0b01001, &ENTRY_OXIDIZEMENT_4972583911879846564)],
        &[(0b01001, &ENTRY_OXIDIZEMENTS_97180816186053602)],
        &[(0b01001, &ENTRY_OXIDIZER_10115554319871451478)],
        &[(0b01001, &ENTRY_OXIDIZERS_15313203568879188818)],
        &[(0b01001, &ENTRY_OXIDIZES_9639252663902404191)],
        &[(0b01001, &ENTRY_OXIDIZING_16338645204512386709)],
        &[(0b01001, &ENTRY_OXIDIZINGS_10090589532009393809)],
        &[(0b10010, &ENTRY_OXYGENIZABLE_9202370148099325185)],
        &[(0b10010, &ENTRY_OXYGENIZABLES_12197126132345293113)],
        &[(0b10010, &ENTRY_OXYGENIZE_13897612552534735492)],
        &[(0b10010, &ENTRY_OXYGENIZED_9126851973435245083)],
        &[(0b10010, &ENTRY_OXYGENIZEMENT_18236184986628200327)],
        &[(0b10010, &ENTRY_OXYGENIZEMENTS_16517849615537520423)],
        &[(0b10010, &ENTRY_OXYGENIZER_11932344404155632770)],
        &[(0b10010, &ENTRY_OXYGENIZERS_150704751084290053)],
        &[(0b10010, &ENTRY_OXYGENIZES_12009319071464897303)],
        &[(0b10010, &ENTRY_OXYGENIZING_10986136118043010748)],
        &[(0b01001, &ENTRY_OXYGENIZABLE_9202370148099325185)],
        &[(0b01001, &ENTRY_OXYGENIZABLES_12197126132345293113)],
        &[(0b01001, &ENTRY_OXYGENIZE_13897612552534735492)],
        &[(0b01001, &ENTRY_OXYGENIZED_9126851973435245083)],
        &[(0b01001, &ENTRY_OXYGENIZEMENT_18236184986628200327)],
        &[(0b01001, &ENTRY_OXYGENIZEMENTS_16517849615537520423)],
        &[(0b01001, &ENTRY_OXYGENIZER_11932344404155632770)],
        &[(0b01001, &ENTRY_OXYGENIZERS_150704751084290053)],
        &[(0b01001, &ENTRY_OXYGENIZES_12009319071464897303)],
        &[(0b01001, &ENTRY_OXYGENIZING_10986136118043010748)],
        &[(0b11010, &ENTRY_OXYHEMATIN_13193737801953766702)],
        &[(0b11010, &ENTRY_OXYHEMOGLOBIN_1846482423983796024)],
        &[(0b11010, &ENTRY_OXYHEMOGLOBINS_8110549662482466088)],
        &[(0b10001, &ENTRY_OXYHEMATIN_13193737801953766702)],
        &[(0b10001, &ENTRY_OXYHEMOGLOBIN_1846482423983796024)],
        &[(0b10001, &ENTRY_OXYHEMOGLOBINS_8110549662482466088)],
    ],
    range: 5..=13,
};

static VARS_OW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OW_CHILDREN),
    value: None,
};

pub static VARS_OW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ercome"),
        dictgen::InsensitiveStr::Ascii("erword"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("recome"),
        dictgen::InsensitiveStr::Ascii("reword"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OWER_714367973734079294)],
        &[(0b00001, &ENTRY_OWERCOME_4480209725664164037)],
        &[(0b00001, &ENTRY_OWERWORD_17641737365333065987)],
        &[(0b11010, &ENTRY_OWER_714367973734079294)],
        &[(0b11010, &ENTRY_OWERCOME_4480209725664164037)],
        &[(0b11010, &ENTRY_OWERWORD_17641737365333065987)],
    ],
    range: 2..=6,
};

static VARS_OV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_OV_CHILDREN),
    value: None,
};

static VARS_OV_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_OVA_NODE),
    None,
    None,
    None,
    Some(&VARS_OVE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_OVE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_OVE_CHILDREN),
    value: None,
};

static VARS_OVE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_OVER_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_OVER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_OVER_CHILDREN),
    value: None,
};

static VARS_OVER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_OVERA_NODE),
    Some(&VARS_OVERB_NODE),
    Some(&VARS_OVERC_NODE),
    Some(&VARS_OVERD_NODE),
    Some(&VARS_OVERE_NODE),
    Some(&VARS_OVERF_NODE),
    Some(&VARS_OVERG_NODE),
    Some(&VARS_OVERH_NODE),
    Some(&VARS_OVERI_NODE),
    Some(&VARS_OVERJ_NODE),
    None,
    Some(&VARS_OVERL_NODE),
    None,
    Some(&VARS_OVERN_NODE),
    None,
    None,
    None,
    Some(&VARS_OVERR_NODE),
    Some(&VARS_OVERS_NODE),
    None,
    Some(&VARS_OVERU_NODE),
    None,
    Some(&VARS_OVERW_NODE),
    None,
    None,
    None,
];

static VARS_OVERW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERW_CHILDREN),
    value: None,
};

pub static VARS_OVERW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("omanise"),
        dictgen::InsensitiveStr::Ascii("omanises"),
        dictgen::InsensitiveStr::Ascii("omanize"),
        dictgen::InsensitiveStr::Ascii("omanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERWOMANIZE_11490817551978529822)],
        &[(0b10010, &ENTRY_OVERWOMANIZES_2414716567143102514)],
        &[(0b01001, &ENTRY_OVERWOMANIZE_11490817551978529822)],
        &[(0b01001, &ENTRY_OVERWOMANIZES_2414716567143102514)],
    ],
    range: 7..=8,
};

static VARS_OVERU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERU_CHILDREN),
    value: None,
};

pub static VARS_OVERU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nionised"),
        dictgen::InsensitiveStr::Ascii("nioniseds"),
        dictgen::InsensitiveStr::Ascii("nionized"),
        dictgen::InsensitiveStr::Ascii("nionizeds"),
        dictgen::InsensitiveStr::Ascii("rbanisation"),
        dictgen::InsensitiveStr::Ascii("rbanisations"),
        dictgen::InsensitiveStr::Ascii("rbanization"),
        dictgen::InsensitiveStr::Ascii("rbanizations"),
        dictgen::InsensitiveStr::Ascii("tilisation"),
        dictgen::InsensitiveStr::Ascii("tilization"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERUNIONIZED_6174875703556667280)],
        &[(0b10010, &ENTRY_OVERUNIONIZEDS_1211100019455129140)],
        &[(0b01001, &ENTRY_OVERUNIONIZED_6174875703556667280)],
        &[(0b01001, &ENTRY_OVERUNIONIZEDS_1211100019455129140)],
        &[(0b10010, &ENTRY_OVERURBANIZATION_18316259619018505400)],
        &[(0b10010, &ENTRY_OVERURBANIZATIONS_4989453349116630693)],
        &[(0b01001, &ENTRY_OVERURBANIZATION_18316259619018505400)],
        &[(0b01001, &ENTRY_OVERURBANIZATIONS_4989453349116630693)],
        &[(0b10010, &ENTRY_OVERUTILIZATION_17588927385548718079)],
        &[(0b01001, &ENTRY_OVERUTILIZATION_17588927385548718079)],
    ],
    range: 8..=12,
};

static VARS_OVERS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERS_CHILDREN),
    value: None,
};

pub static VARS_OVERS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entimentalise"),
        dictgen::InsensitiveStr::Ascii("entimentalises"),
        dictgen::InsensitiveStr::Ascii("entimentalize"),
        dictgen::InsensitiveStr::Ascii("entimentalizes"),
        dictgen::InsensitiveStr::Ascii("pecialisation"),
        dictgen::InsensitiveStr::Ascii("pecialisations"),
        dictgen::InsensitiveStr::Ascii("pecialise"),
        dictgen::InsensitiveStr::Ascii("pecialised"),
        dictgen::InsensitiveStr::Ascii("pecialises"),
        dictgen::InsensitiveStr::Ascii("pecialising"),
        dictgen::InsensitiveStr::Ascii("pecialization"),
        dictgen::InsensitiveStr::Ascii("pecializations"),
        dictgen::InsensitiveStr::Ascii("pecialize"),
        dictgen::InsensitiveStr::Ascii("pecialized"),
        dictgen::InsensitiveStr::Ascii("pecializes"),
        dictgen::InsensitiveStr::Ascii("pecializing"),
        dictgen::InsensitiveStr::Ascii("ystematise"),
        dictgen::InsensitiveStr::Ascii("ystematises"),
        dictgen::InsensitiveStr::Ascii("ystematize"),
        dictgen::InsensitiveStr::Ascii("ystematizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERSENTIMENTALIZE_9811793490104951879)],
        &[(0b10010, &ENTRY_OVERSENTIMENTALIZES_16872043038895867715)],
        &[(0b01001, &ENTRY_OVERSENTIMENTALIZE_9811793490104951879)],
        &[(0b01001, &ENTRY_OVERSENTIMENTALIZES_16872043038895867715)],
        &[(0b10010, &ENTRY_OVERSPECIALIZATION_1633031571639798019)],
        &[(0b10010, &ENTRY_OVERSPECIALIZATIONS_18126012734047267284)],
        &[(0b10010, &ENTRY_OVERSPECIALIZE_7229749289149801509)],
        &[(0b10010, &ENTRY_OVERSPECIALIZED_1547172552972623375)],
        &[(0b10010, &ENTRY_OVERSPECIALIZES_10793320734082567309)],
        &[(0b10010, &ENTRY_OVERSPECIALIZING_3587227959598734164)],
        &[(0b01001, &ENTRY_OVERSPECIALIZATION_1633031571639798019)],
        &[(0b01001, &ENTRY_OVERSPECIALIZATIONS_18126012734047267284)],
        &[(0b01001, &ENTRY_OVERSPECIALIZE_7229749289149801509)],
        &[(0b01001, &ENTRY_OVERSPECIALIZED_1547172552972623375)],
        &[(0b01001, &ENTRY_OVERSPECIALIZES_10793320734082567309)],
        &[(0b01001, &ENTRY_OVERSPECIALIZING_3587227959598734164)],
        &[(0b10010, &ENTRY_OVERSYSTEMATIZE_15992334018865759556)],
        &[(0b10010, &ENTRY_OVERSYSTEMATIZES_15181329179373696484)],
        &[(0b01001, &ENTRY_OVERSYSTEMATIZE_15992334018865759556)],
        &[(0b01001, &ENTRY_OVERSYSTEMATIZES_15181329179373696484)],
    ],
    range: 9..=14,
};

static VARS_OVERR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERR_CHILDREN),
    value: None,
};

pub static VARS_OVERR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("apturise"),
        dictgen::InsensitiveStr::Ascii("apturises"),
        dictgen::InsensitiveStr::Ascii("apturize"),
        dictgen::InsensitiveStr::Ascii("apturizes"),
        dictgen::InsensitiveStr::Ascii("ationalise"),
        dictgen::InsensitiveStr::Ascii("ationalises"),
        dictgen::InsensitiveStr::Ascii("ationalize"),
        dictgen::InsensitiveStr::Ascii("ationalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERRAPTURIZE_4942964855869337557)],
        &[(0b10010, &ENTRY_OVERRAPTURIZES_13279076080761686590)],
        &[(0b01001, &ENTRY_OVERRAPTURIZE_4942964855869337557)],
        &[(0b01001, &ENTRY_OVERRAPTURIZES_13279076080761686590)],
        &[(0b10010, &ENTRY_OVERRATIONALIZE_6906270410629017501)],
        &[(0b10010, &ENTRY_OVERRATIONALIZES_11313615435929619)],
        &[(0b01001, &ENTRY_OVERRATIONALIZE_6906270410629017501)],
        &[(0b01001, &ENTRY_OVERRATIONALIZES_11313615435929619)],
    ],
    range: 8..=11,
};

static VARS_OVERN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERN_CHILDREN),
    value: None,
};

pub static VARS_OVERN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ationalisation"),
        dictgen::InsensitiveStr::Ascii("ationalisations"),
        dictgen::InsensitiveStr::Ascii("ationalization"),
        dictgen::InsensitiveStr::Ascii("ationalizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERNATIONALIZATION_14750126295058482804)],
        &[(0b10010, &ENTRY_OVERNATIONALIZATIONS_15292388911190908837)],
        &[(0b01001, &ENTRY_OVERNATIONALIZATION_14750126295058482804)],
        &[(0b01001, &ENTRY_OVERNATIONALIZATIONS_15292388911190908837)],
    ],
    range: 14..=15,
};

static VARS_OVERL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERL_CHILDREN),
    value: None,
};

pub static VARS_OVERL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abor"),
        dictgen::InsensitiveStr::Ascii("abored"),
        dictgen::InsensitiveStr::Ascii("aboring"),
        dictgen::InsensitiveStr::Ascii("abors"),
        dictgen::InsensitiveStr::Ascii("abour"),
        dictgen::InsensitiveStr::Ascii("aboured"),
        dictgen::InsensitiveStr::Ascii("abouring"),
        dictgen::InsensitiveStr::Ascii("abours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OVERLABOR_17688410265271100123)],
        &[(0b00001, &ENTRY_OVERLABORED_12205791932532611074)],
        &[(0b00001, &ENTRY_OVERLABORING_7695604562828463501)],
        &[(0b00001, &ENTRY_OVERLABORS_7659441557822287857)],
        &[(0b11010, &ENTRY_OVERLABOR_17688410265271100123)],
        &[(0b11010, &ENTRY_OVERLABORED_12205791932532611074)],
        &[(0b11010, &ENTRY_OVERLABORING_7695604562828463501)],
        &[(0b11010, &ENTRY_OVERLABORS_7659441557822287857)],
    ],
    range: 4..=8,
};

static VARS_OVERJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERJ_CHILDREN),
    value: None,
};

pub static VARS_OVERJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("udgement"),
        dictgen::InsensitiveStr::Ascii("udgements"),
        dictgen::InsensitiveStr::Ascii("udgment"),
        dictgen::InsensitiveStr::Ascii("udgments"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OVERJUDGMENT_14410272038538410201)],
        &[(0b11010, &ENTRY_OVERJUDGMENTS_1683734198657934729)],
        &[(0b00001, &ENTRY_OVERJUDGMENT_14410272038538410201)],
        &[(0b00001, &ENTRY_OVERJUDGMENTS_1683734198657934729)],
    ],
    range: 7..=9,
};

static VARS_OVERI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERI_CHILDREN),
    value: None,
};

pub static VARS_OVERI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ndustrialisation"),
        dictgen::InsensitiveStr::Ascii("ndustrialisations"),
        dictgen::InsensitiveStr::Ascii("ndustrialise"),
        dictgen::InsensitiveStr::Ascii("ndustrialises"),
        dictgen::InsensitiveStr::Ascii("ndustrialization"),
        dictgen::InsensitiveStr::Ascii("ndustrializations"),
        dictgen::InsensitiveStr::Ascii("ndustrialize"),
        dictgen::InsensitiveStr::Ascii("ndustrializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERINDUSTRIALIZATION_1518640640867699568)],
        &[(0b10010, &ENTRY_OVERINDUSTRIALIZATIONS_880181449046892729)],
        &[(0b10010, &ENTRY_OVERINDUSTRIALIZE_1935760429076726086)],
        &[(0b10010, &ENTRY_OVERINDUSTRIALIZES_15665873696822393914)],
        &[(0b01001, &ENTRY_OVERINDUSTRIALIZATION_1518640640867699568)],
        &[(0b01001, &ENTRY_OVERINDUSTRIALIZATIONS_880181449046892729)],
        &[(0b01001, &ENTRY_OVERINDUSTRIALIZE_1935760429076726086)],
        &[(0b01001, &ENTRY_OVERINDUSTRIALIZES_15665873696822393914)],
    ],
    range: 12..=17,
};

static VARS_OVERH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERH_CHILDREN),
    value: None,
};

pub static VARS_OVERH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onor"),
        dictgen::InsensitiveStr::Ascii("onors"),
        dictgen::InsensitiveStr::Ascii("onour"),
        dictgen::InsensitiveStr::Ascii("onours"),
        dictgen::InsensitiveStr::Ascii("umanise"),
        dictgen::InsensitiveStr::Ascii("umanises"),
        dictgen::InsensitiveStr::Ascii("umanize"),
        dictgen::InsensitiveStr::Ascii("umanizes"),
    ],
    values: &[
        &[(0b10001, &ENTRY_OVERHONOR_7061058962043742785)],
        &[(0b10001, &ENTRY_OVERHONORS_12559365250164975436)],
        &[(0b11010, &ENTRY_OVERHONOR_7061058962043742785)],
        &[(0b11010, &ENTRY_OVERHONORS_12559365250164975436)],
        &[(0b10010, &ENTRY_OVERHUMANIZE_17831519361456561071)],
        &[(0b10010, &ENTRY_OVERHUMANIZES_2059890155268395387)],
        &[(0b01001, &ENTRY_OVERHUMANIZE_17831519361456561071)],
        &[(0b01001, &ENTRY_OVERHUMANIZES_2059890155268395387)],
    ],
    range: 4..=8,
};

static VARS_OVERG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERG_CHILDREN),
    value: None,
};

pub static VARS_OVERG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eneralise"),
        dictgen::InsensitiveStr::Ascii("eneralised"),
        dictgen::InsensitiveStr::Ascii("eneralises"),
        dictgen::InsensitiveStr::Ascii("eneralising"),
        dictgen::InsensitiveStr::Ascii("eneralize"),
        dictgen::InsensitiveStr::Ascii("eneralized"),
        dictgen::InsensitiveStr::Ascii("eneralizes"),
        dictgen::InsensitiveStr::Ascii("eneralizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERGENERALIZE_7625722739665195923)],
        &[(0b10010, &ENTRY_OVERGENERALIZED_2362525225382909269)],
        &[(0b10010, &ENTRY_OVERGENERALIZES_1194543416222013859)],
        &[(0b10010, &ENTRY_OVERGENERALIZING_3046182641254114632)],
        &[(0b01001, &ENTRY_OVERGENERALIZE_7625722739665195923)],
        &[(0b01001, &ENTRY_OVERGENERALIZED_2362525225382909269)],
        &[(0b01001, &ENTRY_OVERGENERALIZES_1194543416222013859)],
        &[(0b01001, &ENTRY_OVERGENERALIZING_3046182641254114632)],
    ],
    range: 9..=11,
};

static VARS_OVERF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERF_CHILDREN),
    value: None,
};

pub static VARS_OVERF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avor"),
        dictgen::InsensitiveStr::Ascii("avorable"),
        dictgen::InsensitiveStr::Ascii("avorables"),
        dictgen::InsensitiveStr::Ascii("avorablies"),
        dictgen::InsensitiveStr::Ascii("avorably"),
        dictgen::InsensitiveStr::Ascii("avors"),
        dictgen::InsensitiveStr::Ascii("avour"),
        dictgen::InsensitiveStr::Ascii("avourable"),
        dictgen::InsensitiveStr::Ascii("avourables"),
        dictgen::InsensitiveStr::Ascii("avourablies"),
        dictgen::InsensitiveStr::Ascii("avourably"),
        dictgen::InsensitiveStr::Ascii("avours"),
        dictgen::InsensitiveStr::Ascii("ertilisation"),
        dictgen::InsensitiveStr::Ascii("ertilization"),
    ],
    values: &[
        &[(0b10001, &ENTRY_OVERFAVOR_17309564975320504308)],
        &[(0b10001, &ENTRY_OVERFAVORABLE_10044615958182307903)],
        &[(0b10001, &ENTRY_OVERFAVORABLES_3683339017470690215)],
        &[(0b10001, &ENTRY_OVERFAVORABLIES_16549422454865344977)],
        &[(0b10001, &ENTRY_OVERFAVORABLY_17663512402196493148)],
        &[(0b10001, &ENTRY_OVERFAVORS_2292027566669700103)],
        &[(0b11010, &ENTRY_OVERFAVOR_17309564975320504308)],
        &[(0b11010, &ENTRY_OVERFAVORABLE_10044615958182307903)],
        &[(0b11010, &ENTRY_OVERFAVORABLES_3683339017470690215)],
        &[(0b11010, &ENTRY_OVERFAVORABLIES_16549422454865344977)],
        &[(0b11010, &ENTRY_OVERFAVORABLY_17663512402196493148)],
        &[(0b11010, &ENTRY_OVERFAVORS_2292027566669700103)],
        &[(0b10010, &ENTRY_OVERFERTILIZATION_15723879745564166382)],
        &[(0b01001, &ENTRY_OVERFERTILIZATION_15723879745564166382)],
    ],
    range: 4..=12,
};

static VARS_OVERE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERE_CHILDREN),
    value: None,
};

pub static VARS_OVERE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("motionalise"),
        dictgen::InsensitiveStr::Ascii("motionalises"),
        dictgen::InsensitiveStr::Ascii("motionalize"),
        dictgen::InsensitiveStr::Ascii("motionalizes"),
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasised"),
        dictgen::InsensitiveStr::Ascii("mphasiser"),
        dictgen::InsensitiveStr::Ascii("mphasisers"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasising"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasized"),
        dictgen::InsensitiveStr::Ascii("mphasizer"),
        dictgen::InsensitiveStr::Ascii("mphasizers"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
        dictgen::InsensitiveStr::Ascii("mphasizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVEREMOTIONALIZE_3492219056437347076)],
        &[(0b10010, &ENTRY_OVEREMOTIONALIZES_15929713333601260258)],
        &[(0b01001, &ENTRY_OVEREMOTIONALIZE_3492219056437347076)],
        &[(0b01001, &ENTRY_OVEREMOTIONALIZES_15929713333601260258)],
        &[(0b10010, &ENTRY_OVEREMPHASIZE_10188078811171146690)],
        &[(0b10010, &ENTRY_OVEREMPHASIZED_14422660185907423404)],
        &[(0b10010, &ENTRY_OVEREMPHASIZER_13084428145414100736)],
        &[(0b10010, &ENTRY_OVEREMPHASIZERS_12835127742532574597)],
        &[(0b10010, &ENTRY_OVEREMPHASIZES_9211947340714823778)],
        &[(0b10010, &ENTRY_OVEREMPHASIZING_656930053748535278)],
        &[(0b01001, &ENTRY_OVEREMPHASIZE_10188078811171146690)],
        &[(0b01001, &ENTRY_OVEREMPHASIZED_14422660185907423404)],
        &[(0b01001, &ENTRY_OVEREMPHASIZER_13084428145414100736)],
        &[(0b01001, &ENTRY_OVEREMPHASIZERS_12835127742532574597)],
        &[(0b01001, &ENTRY_OVEREMPHASIZES_9211947340714823778)],
        &[(0b01001, &ENTRY_OVEREMPHASIZING_656930053748535278)],
    ],
    range: 8..=12,
};

static VARS_OVERD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERD_CHILDREN),
    value: None,
};

pub static VARS_OVERD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("octrinise"),
        dictgen::InsensitiveStr::Ascii("octrinises"),
        dictgen::InsensitiveStr::Ascii("octrinize"),
        dictgen::InsensitiveStr::Ascii("octrinizes"),
        dictgen::InsensitiveStr::Ascii("ramatise"),
        dictgen::InsensitiveStr::Ascii("ramatised"),
        dictgen::InsensitiveStr::Ascii("ramatises"),
        dictgen::InsensitiveStr::Ascii("ramatising"),
        dictgen::InsensitiveStr::Ascii("ramatize"),
        dictgen::InsensitiveStr::Ascii("ramatized"),
        dictgen::InsensitiveStr::Ascii("ramatizes"),
        dictgen::InsensitiveStr::Ascii("ramatizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERDOCTRINIZE_9952294591350746328)],
        &[(0b10010, &ENTRY_OVERDOCTRINIZES_16618778111872081207)],
        &[(0b01001, &ENTRY_OVERDOCTRINIZE_9952294591350746328)],
        &[(0b01001, &ENTRY_OVERDOCTRINIZES_16618778111872081207)],
        &[(0b10010, &ENTRY_OVERDRAMATIZE_9956046184240652478)],
        &[(0b10010, &ENTRY_OVERDRAMATIZED_568182443613701103)],
        &[(0b10010, &ENTRY_OVERDRAMATIZES_677559530199440792)],
        &[(0b10010, &ENTRY_OVERDRAMATIZING_8041727993818066162)],
        &[(0b01001, &ENTRY_OVERDRAMATIZE_9956046184240652478)],
        &[(0b01001, &ENTRY_OVERDRAMATIZED_568182443613701103)],
        &[(0b01001, &ENTRY_OVERDRAMATIZES_677559530199440792)],
        &[(0b01001, &ENTRY_OVERDRAMATIZING_8041727993818066162)],
    ],
    range: 8..=10,
};

static VARS_OVERC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERC_CHILDREN),
    value: None,
};

pub static VARS_OVERC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("apitalisation"),
        dictgen::InsensitiveStr::Ascii("apitalisations"),
        dictgen::InsensitiveStr::Ascii("apitalise"),
        dictgen::InsensitiveStr::Ascii("apitalised"),
        dictgen::InsensitiveStr::Ascii("apitalises"),
        dictgen::InsensitiveStr::Ascii("apitalising"),
        dictgen::InsensitiveStr::Ascii("apitalization"),
        dictgen::InsensitiveStr::Ascii("apitalizations"),
        dictgen::InsensitiveStr::Ascii("apitalize"),
        dictgen::InsensitiveStr::Ascii("apitalized"),
        dictgen::InsensitiveStr::Ascii("apitalizes"),
        dictgen::InsensitiveStr::Ascii("apitalizing"),
        dictgen::InsensitiveStr::Ascii("entralisation"),
        dictgen::InsensitiveStr::Ascii("entralisations"),
        dictgen::InsensitiveStr::Ascii("entralise"),
        dictgen::InsensitiveStr::Ascii("entralises"),
        dictgen::InsensitiveStr::Ascii("entralization"),
        dictgen::InsensitiveStr::Ascii("entralizations"),
        dictgen::InsensitiveStr::Ascii("entralize"),
        dictgen::InsensitiveStr::Ascii("entralizes"),
        dictgen::InsensitiveStr::Ascii("ivilisation"),
        dictgen::InsensitiveStr::Ascii("ivilisations"),
        dictgen::InsensitiveStr::Ascii("ivilise"),
        dictgen::InsensitiveStr::Ascii("ivilises"),
        dictgen::InsensitiveStr::Ascii("ivilization"),
        dictgen::InsensitiveStr::Ascii("ivilizations"),
        dictgen::InsensitiveStr::Ascii("ivilize"),
        dictgen::InsensitiveStr::Ascii("ivilizes"),
        dictgen::InsensitiveStr::Ascii("lamor"),
        dictgen::InsensitiveStr::Ascii("lamors"),
        dictgen::InsensitiveStr::Ascii("lamour"),
        dictgen::InsensitiveStr::Ascii("lamours"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("oloration"),
        dictgen::InsensitiveStr::Ascii("oloring"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("olouration"),
        dictgen::InsensitiveStr::Ascii("olouring"),
        dictgen::InsensitiveStr::Ascii("olours"),
        dictgen::InsensitiveStr::Ascii("riticise"),
        dictgen::InsensitiveStr::Ascii("riticises"),
        dictgen::InsensitiveStr::Ascii("riticize"),
        dictgen::InsensitiveStr::Ascii("riticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERCAPITALIZATION_16491991909868759291)],
        &[(0b10010, &ENTRY_OVERCAPITALIZATIONS_8515268345747345778)],
        &[(0b10010, &ENTRY_OVERCAPITALIZE_5137404458805033721)],
        &[(0b10010, &ENTRY_OVERCAPITALIZED_16391070453870509941)],
        &[(0b10010, &ENTRY_OVERCAPITALIZES_6277345493449192746)],
        &[(0b10010, &ENTRY_OVERCAPITALIZING_1761143477577642450)],
        &[(0b01001, &ENTRY_OVERCAPITALIZATION_16491991909868759291)],
        &[(0b01001, &ENTRY_OVERCAPITALIZATIONS_8515268345747345778)],
        &[(0b01001, &ENTRY_OVERCAPITALIZE_5137404458805033721)],
        &[(0b01001, &ENTRY_OVERCAPITALIZED_16391070453870509941)],
        &[(0b01001, &ENTRY_OVERCAPITALIZES_6277345493449192746)],
        &[(0b01001, &ENTRY_OVERCAPITALIZING_1761143477577642450)],
        &[(0b10010, &ENTRY_OVERCENTRALIZATION_4206431460039066433)],
        &[(0b10010, &ENTRY_OVERCENTRALIZATIONS_8087116287428750116)],
        &[(0b10010, &ENTRY_OVERCENTRALIZE_12851132365246138388)],
        &[(0b10010, &ENTRY_OVERCENTRALIZES_5222524178127209553)],
        &[(0b01001, &ENTRY_OVERCENTRALIZATION_4206431460039066433)],
        &[(0b01001, &ENTRY_OVERCENTRALIZATIONS_8087116287428750116)],
        &[(0b01001, &ENTRY_OVERCENTRALIZE_12851132365246138388)],
        &[(0b01001, &ENTRY_OVERCENTRALIZES_5222524178127209553)],
        &[(0b10010, &ENTRY_OVERCIVILIZATION_14330185198631343224)],
        &[(0b10010, &ENTRY_OVERCIVILIZATIONS_1687537129456067045)],
        &[(0b10010, &ENTRY_OVERCIVILIZE_7361104998251555913)],
        &[(0b10010, &ENTRY_OVERCIVILIZES_7600225434837167383)],
        &[(0b01001, &ENTRY_OVERCIVILIZATION_14330185198631343224)],
        &[(0b01001, &ENTRY_OVERCIVILIZATIONS_1687537129456067045)],
        &[(0b01001, &ENTRY_OVERCIVILIZE_7361104998251555913)],
        &[(0b01001, &ENTRY_OVERCIVILIZES_7600225434837167383)],
        &[(0b10001, &ENTRY_OVERCLAMOR_7626038013386332277)],
        &[(0b10001, &ENTRY_OVERCLAMORS_13060839905474300243)],
        &[(0b11010, &ENTRY_OVERCLAMOR_7626038013386332277)],
        &[(0b11010, &ENTRY_OVERCLAMORS_13060839905474300243)],
        &[(0b10001, &ENTRY_OVERCOLOR_9560847732348280457)],
        &[(0b00001, &ENTRY_OVERCOLORATION_9954247583751155389)],
        &[(0b10001, &ENTRY_OVERCOLORING_12857603657681315527)],
        &[(0b10001, &ENTRY_OVERCOLORS_12585352933997313554)],
        &[(0b11010, &ENTRY_OVERCOLOR_9560847732348280457)],
        &[(0b11010, &ENTRY_OVERCOLORATION_9954247583751155389)],
        &[(0b11010, &ENTRY_OVERCOLORING_12857603657681315527)],
        &[(0b11010, &ENTRY_OVERCOLORS_12585352933997313554)],
        &[(0b10010, &ENTRY_OVERCRITICIZE_8553366067384322807)],
        &[(0b10010, &ENTRY_OVERCRITICIZES_410272753519343801)],
        &[(0b01001, &ENTRY_OVERCRITICIZE_8553366067384322807)],
        &[(0b01001, &ENTRY_OVERCRITICIZES_410272753519343801)],
    ],
    range: 4..=14,
};

static VARS_OVERB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERB_CHILDREN),
    value: None,
};

pub static VARS_OVERB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rutalise"),
        dictgen::InsensitiveStr::Ascii("rutalises"),
        dictgen::InsensitiveStr::Ascii("rutalize"),
        dictgen::InsensitiveStr::Ascii("rutalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERBRUTALIZE_12508120024832721923)],
        &[(0b10010, &ENTRY_OVERBRUTALIZES_5838247981424780614)],
        &[(0b01001, &ENTRY_OVERBRUTALIZE_12508120024832721923)],
        &[(0b01001, &ENTRY_OVERBRUTALIZES_5838247981424780614)],
    ],
    range: 8..=9,
};

static VARS_OVERA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERA_CHILDREN),
    value: None,
};

pub static VARS_OVERA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gonise"),
        dictgen::InsensitiveStr::Ascii("gonises"),
        dictgen::InsensitiveStr::Ascii("gonize"),
        dictgen::InsensitiveStr::Ascii("gonizes"),
        dictgen::InsensitiveStr::Ascii("nalyse"),
        dictgen::InsensitiveStr::Ascii("nalyses"),
        dictgen::InsensitiveStr::Ascii("nalyze"),
        dictgen::InsensitiveStr::Ascii("nalyzes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERAGONIZE_12839802073298082121)],
        &[(0b10010, &ENTRY_OVERAGONIZES_18072904232465525038)],
        &[(0b01001, &ENTRY_OVERAGONIZE_12839802073298082121)],
        &[(0b01001, &ENTRY_OVERAGONIZES_18072904232465525038)],
        &[(0b10010, &ENTRY_OVERANALYZE_9915211901630072465)],
        &[(0b10010, &ENTRY_OVERANALYZES_1261439988617962985)],
        &[(0b01001, &ENTRY_OVERANALYZE_9915211901630072465)],
        &[(0b01001, &ENTRY_OVERANALYZES_1261439988617962985)],
    ],
    range: 6..=7,
};

static VARS_OVA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVA_CHILDREN),
    value: None,
};

pub static VARS_OVA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("riectomised"),
        dictgen::InsensitiveStr::Ascii("riectomized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVALIZATION_1291479772354921953)],
        &[(0b10010, &ENTRY_OVALIZATIONS_18116960851150407547)],
        &[(0b10010, &ENTRY_OVALIZE_10690880851091583963)],
        &[(0b10010, &ENTRY_OVALIZES_14265834545135198955)],
        &[(0b01001, &ENTRY_OVALIZATION_1291479772354921953)],
        &[(0b01001, &ENTRY_OVALIZATIONS_18116960851150407547)],
        &[(0b01001, &ENTRY_OVALIZE_10690880851091583963)],
        &[(0b01001, &ENTRY_OVALIZES_14265834545135198955)],
        &[(0b10010, &ENTRY_OVARIECTOMIZED_10591671171299862773)],
        &[(0b01001, &ENTRY_OVARIECTOMIZED_10591671171299862773)],
    ],
    range: 4..=11,
};

static VARS_OU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OU_CHILDREN),
    value: None,
};

pub static VARS_OU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rang"),
        dictgen::InsensitiveStr::Ascii("rangs"),
        dictgen::InsensitiveStr::Ascii("rologies"),
        dictgen::InsensitiveStr::Ascii("rology"),
        dictgen::InsensitiveStr::Ascii("rsel"),
        dictgen::InsensitiveStr::Ascii("tcaviled"),
        dictgen::InsensitiveStr::Ascii("tcaviling"),
        dictgen::InsensitiveStr::Ascii("tcavilled"),
        dictgen::InsensitiveStr::Ascii("tcavilling"),
        dictgen::InsensitiveStr::Ascii("tclamor"),
        dictgen::InsensitiveStr::Ascii("tclamors"),
        dictgen::InsensitiveStr::Ascii("tclamour"),
        dictgen::InsensitiveStr::Ascii("tclamours"),
        dictgen::InsensitiveStr::Ascii("terness"),
        dictgen::InsensitiveStr::Ascii("thumor"),
        dictgen::InsensitiveStr::Ascii("thumored"),
        dictgen::InsensitiveStr::Ascii("thumoring"),
        dictgen::InsensitiveStr::Ascii("thumors"),
        dictgen::InsensitiveStr::Ascii("thumour"),
        dictgen::InsensitiveStr::Ascii("thumoured"),
        dictgen::InsensitiveStr::Ascii("thumouring"),
        dictgen::InsensitiveStr::Ascii("thumours"),
        dictgen::InsensitiveStr::Ascii("thyperbolise"),
        dictgen::InsensitiveStr::Ascii("thyperbolises"),
        dictgen::InsensitiveStr::Ascii("thyperbolize"),
        dictgen::InsensitiveStr::Ascii("thyperbolizes"),
        dictgen::InsensitiveStr::Ascii("tlabor"),
        dictgen::InsensitiveStr::Ascii("tlabors"),
        dictgen::InsensitiveStr::Ascii("tlabour"),
        dictgen::InsensitiveStr::Ascii("tlabours"),
        dictgen::InsensitiveStr::Ascii("tluster"),
        dictgen::InsensitiveStr::Ascii("tlustre"),
        dictgen::InsensitiveStr::Ascii("tmaneuver"),
        dictgen::InsensitiveStr::Ascii("tmaneuvered"),
        dictgen::InsensitiveStr::Ascii("tmaneuvering"),
        dictgen::InsensitiveStr::Ascii("tmaneuvers"),
        dictgen::InsensitiveStr::Ascii("tmanoeuvre"),
        dictgen::InsensitiveStr::Ascii("tmanoeuvred"),
        dictgen::InsensitiveStr::Ascii("tmanoeuvres"),
        dictgen::InsensitiveStr::Ascii("tmanoeuvring"),
        dictgen::InsensitiveStr::Ascii("treness"),
        dictgen::InsensitiveStr::Ascii("trivaled"),
        dictgen::InsensitiveStr::Ascii("trivaling"),
        dictgen::InsensitiveStr::Ascii("trivalled"),
        dictgen::InsensitiveStr::Ascii("trivalling"),
        dictgen::InsensitiveStr::Ascii("tsavor"),
        dictgen::InsensitiveStr::Ascii("tsavoring"),
        dictgen::InsensitiveStr::Ascii("tsavors"),
        dictgen::InsensitiveStr::Ascii("tsavour"),
        dictgen::InsensitiveStr::Ascii("tsavouring"),
        dictgen::InsensitiveStr::Ascii("tsavours"),
        dictgen::InsensitiveStr::Ascii("tsplendor"),
        dictgen::InsensitiveStr::Ascii("tsplendors"),
        dictgen::InsensitiveStr::Ascii("tsplendour"),
        dictgen::InsensitiveStr::Ascii("tsplendours"),
        dictgen::InsensitiveStr::Ascii("ttyrannise"),
        dictgen::InsensitiveStr::Ascii("ttyrannises"),
        dictgen::InsensitiveStr::Ascii("ttyrannize"),
        dictgen::InsensitiveStr::Ascii("ttyrannizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ORANG_3026443150827231855)],
        &[(0b11010, &ENTRY_ORANGS_11893539110910417877)],
        &[(0b11010, &ENTRY_OROLOGIES_1741200697611441025)],
        &[(0b11010, &ENTRY_OROLOGY_10784240065242117238)],
        &[(0b11010, &ENTRY_ORSEL_3088141134430316343)],
        &[(0b00001, &ENTRY_OUTCAVILED_8067524519482771834)],
        &[(0b00001, &ENTRY_OUTCAVILING_7846684353859330358)],
        &[(0b11010, &ENTRY_OUTCAVILED_8067524519482771834)],
        &[(0b11010, &ENTRY_OUTCAVILING_7846684353859330358)],
        &[(0b10001, &ENTRY_OUTCLAMOR_2628099102923288161)],
        &[(0b10001, &ENTRY_OUTCLAMORS_1932016408951518776)],
        &[(0b11010, &ENTRY_OUTCLAMOR_2628099102923288161)],
        &[(0b11010, &ENTRY_OUTCLAMORS_1932016408951518776)],
        &[(0b00001, &ENTRY_OUTERNESS_5110209358797551194)],
        &[(0b10001, &ENTRY_OUTHUMOR_12739979941160567143)],
        &[(0b10001, &ENTRY_OUTHUMORED_17153608064346262904)],
        &[(0b10001, &ENTRY_OUTHUMORING_5294044524439877555)],
        &[(0b10001, &ENTRY_OUTHUMORS_6379878794964447015)],
        &[(0b11010, &ENTRY_OUTHUMOR_12739979941160567143)],
        &[(0b11010, &ENTRY_OUTHUMORED_17153608064346262904)],
        &[(0b11010, &ENTRY_OUTHUMORING_5294044524439877555)],
        &[(0b11010, &ENTRY_OUTHUMORS_6379878794964447015)],
        &[(0b10010, &ENTRY_OUTHYPERBOLIZE_17971419597167705024)],
        &[(0b10010, &ENTRY_OUTHYPERBOLIZES_3730443298592019408)],
        &[(0b01001, &ENTRY_OUTHYPERBOLIZE_17971419597167705024)],
        &[(0b01001, &ENTRY_OUTHYPERBOLIZES_3730443298592019408)],
        &[(0b10001, &ENTRY_OUTLABOR_4477843439986939547)],
        &[(0b10001, &ENTRY_OUTLABORS_8639955974059144964)],
        &[(0b11010, &ENTRY_OUTLABOR_4477843439986939547)],
        &[(0b11010, &ENTRY_OUTLABORS_8639955974059144964)],
        &[(0b00001, &ENTRY_OUTLUSTER_14753354047674654656)],
        &[(0b11010, &ENTRY_OUTLUSTER_14753354047674654656)],
        &[(0b01001, &ENTRY_OUTMANEUVER_8971376472472700486)],
        &[(0b01001, &ENTRY_OUTMANEUVERED_15207995604008599908)],
        &[(0b01001, &ENTRY_OUTMANEUVERING_18066101649103069658)],
        &[(0b01001, &ENTRY_OUTMANEUVERS_12354989641176250449)],
        &[(0b11010, &ENTRY_OUTMANEUVER_8971376472472700486)],
        &[(0b11010, &ENTRY_OUTMANEUVERED_15207995604008599908)],
        &[(0b11010, &ENTRY_OUTMANEUVERS_12354989641176250449)],
        &[(0b11010, &ENTRY_OUTMANEUVERING_18066101649103069658)],
        &[(0b11010, &ENTRY_OUTERNESS_5110209358797551194)],
        &[(0b00001, &ENTRY_OUTRIVALED_3341374795207180843)],
        &[(0b00001, &ENTRY_OUTRIVALING_2545493549405891999)],
        &[(0b11010, &ENTRY_OUTRIVALED_3341374795207180843)],
        &[(0b11010, &ENTRY_OUTRIVALING_2545493549405891999)],
        &[(0b10001, &ENTRY_OUTSAVOR_10580389165402595979)],
        &[(0b10001, &ENTRY_OUTSAVORING_12930164474104036309)],
        &[(0b10001, &ENTRY_OUTSAVORS_8162427042123223209)],
        &[(0b11010, &ENTRY_OUTSAVOR_10580389165402595979)],
        &[(0b11010, &ENTRY_OUTSAVORING_12930164474104036309)],
        &[(0b11010, &ENTRY_OUTSAVORS_8162427042123223209)],
        &[(0b10001, &ENTRY_OUTSPLENDOR_5260326500390827064)],
        &[(0b10001, &ENTRY_OUTSPLENDORS_11316257281529662399)],
        &[(0b11010, &ENTRY_OUTSPLENDOR_5260326500390827064)],
        &[(0b11010, &ENTRY_OUTSPLENDORS_11316257281529662399)],
        &[(0b10010, &ENTRY_OUTTYRANNIZE_15662237949831559495)],
        &[(0b10010, &ENTRY_OUTTYRANNIZES_14123969537438855678)],
        &[(0b01001, &ENTRY_OUTTYRANNIZE_15662237949831559495)],
        &[(0b01001, &ENTRY_OUTTYRANNIZES_14123969537438855678)],
    ],
    range: 4..=13,
};

static VARS_OT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OT_CHILDREN),
    value: None,
};

pub static VARS_OT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("haematoma"),
        dictgen::InsensitiveStr::Ascii("hematoma"),
        dictgen::InsensitiveStr::Ascii("orrhea"),
        dictgen::InsensitiveStr::Ascii("orrhoea"),
        dictgen::InsensitiveStr::Ascii("tomanisation"),
        dictgen::InsensitiveStr::Ascii("tomanisations"),
        dictgen::InsensitiveStr::Ascii("tomanise"),
        dictgen::InsensitiveStr::Ascii("tomanises"),
        dictgen::InsensitiveStr::Ascii("tomanization"),
        dictgen::InsensitiveStr::Ascii("tomanizations"),
        dictgen::InsensitiveStr::Ascii("tomanize"),
        dictgen::InsensitiveStr::Ascii("tomanizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OTHEMATOMA_5365268843459293252)],
        &[(0b10001, &ENTRY_OTHEMATOMA_5365268843459293252)],
        &[(0b10001, &ENTRY_OTORRHEA_117491974381310742)],
        &[(0b11010, &ENTRY_OTORRHEA_117491974381310742)],
        &[(0b10010, &ENTRY_OTTOMANIZATION_16626009540415399841)],
        &[(0b10010, &ENTRY_OTTOMANIZATIONS_18103044857042617134)],
        &[(0b10010, &ENTRY_OTTOMANIZE_13171359343489848435)],
        &[(0b10010, &ENTRY_OTTOMANIZES_8070802369257673752)],
        &[(0b01001, &ENTRY_OTTOMANIZATION_16626009540415399841)],
        &[(0b01001, &ENTRY_OTTOMANIZATIONS_18103044857042617134)],
        &[(0b01001, &ENTRY_OTTOMANIZE_13171359343489848435)],
        &[(0b01001, &ENTRY_OTTOMANIZES_8070802369257673752)],
    ],
    range: 6..=13,
};

static VARS_OS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OS_CHILDREN),
    value: None,
};

pub static VARS_OS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("teopaedion"),
        dictgen::InsensitiveStr::Ascii("teopedion"),
        dictgen::InsensitiveStr::Ascii("tracisable"),
        dictgen::InsensitiveStr::Ascii("tracisables"),
        dictgen::InsensitiveStr::Ascii("tracisation"),
        dictgen::InsensitiveStr::Ascii("tracisations"),
        dictgen::InsensitiveStr::Ascii("tracise"),
        dictgen::InsensitiveStr::Ascii("tracised"),
        dictgen::InsensitiveStr::Ascii("traciser"),
        dictgen::InsensitiveStr::Ascii("tracisers"),
        dictgen::InsensitiveStr::Ascii("tracises"),
        dictgen::InsensitiveStr::Ascii("tracising"),
        dictgen::InsensitiveStr::Ascii("tracizable"),
        dictgen::InsensitiveStr::Ascii("tracizables"),
        dictgen::InsensitiveStr::Ascii("tracization"),
        dictgen::InsensitiveStr::Ascii("tracizations"),
        dictgen::InsensitiveStr::Ascii("tracize"),
        dictgen::InsensitiveStr::Ascii("tracized"),
        dictgen::InsensitiveStr::Ascii("tracizer"),
        dictgen::InsensitiveStr::Ascii("tracizers"),
        dictgen::InsensitiveStr::Ascii("tracizes"),
        dictgen::InsensitiveStr::Ascii("tracizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OSTEOPEDION_4857509053557423347)],
        &[(0b00001, &ENTRY_OSTEOPEDION_4857509053557423347)],
        &[(0b10010, &ENTRY_OSTRACIZABLE_17001025771860320461)],
        &[(0b10010, &ENTRY_OSTRACIZABLES_14502674393095664398)],
        &[(0b10010, &ENTRY_OSTRACIZATION_4685169978124572954)],
        &[(0b10010, &ENTRY_OSTRACIZATIONS_2093227212501115759)],
        &[(0b10010, &ENTRY_OSTRACIZE_16556482869488657514)],
        &[(0b10010, &ENTRY_OSTRACIZED_17082390290234422430)],
        &[(0b10010, &ENTRY_OSTRACIZER_6163748049161701474)],
        &[(0b10010, &ENTRY_OSTRACIZERS_5292704159191951070)],
        &[(0b10010, &ENTRY_OSTRACIZES_12242933710212962262)],
        &[(0b10010, &ENTRY_OSTRACIZING_13078448502630833661)],
        &[(0b01001, &ENTRY_OSTRACIZABLE_17001025771860320461)],
        &[(0b01001, &ENTRY_OSTRACIZABLES_14502674393095664398)],
        &[(0b01001, &ENTRY_OSTRACIZATION_4685169978124572954)],
        &[(0b01001, &ENTRY_OSTRACIZATIONS_2093227212501115759)],
        &[(0b01001, &ENTRY_OSTRACIZE_16556482869488657514)],
        &[(0b01001, &ENTRY_OSTRACIZED_17082390290234422430)],
        &[(0b01001, &ENTRY_OSTRACIZER_6163748049161701474)],
        &[(0b01001, &ENTRY_OSTRACIZERS_5292704159191951070)],
        &[(0b01001, &ENTRY_OSTRACIZES_12242933710212962262)],
        &[(0b01001, &ENTRY_OSTRACIZING_13078448502630833661)],
    ],
    range: 7..=12,
};

static VARS_OR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_OR_CHILDREN),
    value: None,
};

static VARS_OR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ORA_NODE),
    None,
    Some(&VARS_ORC_NODE),
    None,
    None,
    None,
    Some(&VARS_ORG_NODE),
    None,
    Some(&VARS_ORI_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_ORN_NODE),
    Some(&VARS_ORO_NODE),
    Some(&VARS_ORP_NODE),
    None,
    None,
    Some(&VARS_ORS_NODE),
    Some(&VARS_ORT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ORT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORT_CHILDREN),
    value: None,
};

pub static VARS_ORT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hocenter"),
        dictgen::InsensitiveStr::Ascii("hocenters"),
        dictgen::InsensitiveStr::Ascii("hocentre"),
        dictgen::InsensitiveStr::Ascii("hocentres"),
        dictgen::InsensitiveStr::Ascii("hogonalisation"),
        dictgen::InsensitiveStr::Ascii("hogonalise"),
        dictgen::InsensitiveStr::Ascii("hogonalised"),
        dictgen::InsensitiveStr::Ascii("hogonalises"),
        dictgen::InsensitiveStr::Ascii("hogonalising"),
        dictgen::InsensitiveStr::Ascii("hogonalization"),
        dictgen::InsensitiveStr::Ascii("hogonalize"),
        dictgen::InsensitiveStr::Ascii("hogonalized"),
        dictgen::InsensitiveStr::Ascii("hogonalizes"),
        dictgen::InsensitiveStr::Ascii("hogonalizing"),
        dictgen::InsensitiveStr::Ascii("hographise"),
        dictgen::InsensitiveStr::Ascii("hographised"),
        dictgen::InsensitiveStr::Ascii("hographising"),
        dictgen::InsensitiveStr::Ascii("hographize"),
        dictgen::InsensitiveStr::Ascii("hographized"),
        dictgen::InsensitiveStr::Ascii("hographizing"),
        dictgen::InsensitiveStr::Ascii("hopaedia"),
        dictgen::InsensitiveStr::Ascii("hopaedic"),
        dictgen::InsensitiveStr::Ascii("hopaedical"),
        dictgen::InsensitiveStr::Ascii("hopaedicallier"),
        dictgen::InsensitiveStr::Ascii("hopaedicalliest"),
        dictgen::InsensitiveStr::Ascii("hopaedically"),
        dictgen::InsensitiveStr::Ascii("hopaedicer"),
        dictgen::InsensitiveStr::Ascii("hopaedicest"),
        dictgen::InsensitiveStr::Ascii("hopaedics"),
        dictgen::InsensitiveStr::Ascii("hopaedies"),
        dictgen::InsensitiveStr::Ascii("hopaedist"),
        dictgen::InsensitiveStr::Ascii("hopaedists"),
        dictgen::InsensitiveStr::Ascii("hopaedy"),
        dictgen::InsensitiveStr::Ascii("hopedia"),
        dictgen::InsensitiveStr::Ascii("hopedic"),
        dictgen::InsensitiveStr::Ascii("hopedical"),
        dictgen::InsensitiveStr::Ascii("hopedicallier"),
        dictgen::InsensitiveStr::Ascii("hopedicalliest"),
        dictgen::InsensitiveStr::Ascii("hopedically"),
        dictgen::InsensitiveStr::Ascii("hopedicer"),
        dictgen::InsensitiveStr::Ascii("hopedicest"),
        dictgen::InsensitiveStr::Ascii("hopedics"),
        dictgen::InsensitiveStr::Ascii("hopedies"),
        dictgen::InsensitiveStr::Ascii("hopedist"),
        dictgen::InsensitiveStr::Ascii("hopedists"),
        dictgen::InsensitiveStr::Ascii("hopedy"),
        dictgen::InsensitiveStr::Ascii("hopnea"),
        dictgen::InsensitiveStr::Ascii("hopneic"),
        dictgen::InsensitiveStr::Ascii("hopnoea"),
        dictgen::InsensitiveStr::Ascii("hopnoeic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ORTHOCENTER_13207654446878205458)],
        &[(0b00001, &ENTRY_ORTHOCENTERS_13755283236164913906)],
        &[(0b11010, &ENTRY_ORTHOCENTER_13207654446878205458)],
        &[(0b11010, &ENTRY_ORTHOCENTERS_13755283236164913906)],
        &[(0b10010, &ENTRY_ORTHOGONALIZATION_8307926330180047305)],
        &[(0b10010, &ENTRY_ORTHOGONALIZE_6060658647304766221)],
        &[(0b10010, &ENTRY_ORTHOGONALIZED_16305306345092783979)],
        &[(0b10010, &ENTRY_ORTHOGONALIZES_12099471702779010348)],
        &[(0b10010, &ENTRY_ORTHOGONALIZING_1408036844114979301)],
        &[(0b01001, &ENTRY_ORTHOGONALIZATION_8307926330180047305)],
        &[(0b01001, &ENTRY_ORTHOGONALIZE_6060658647304766221)],
        &[(0b01001, &ENTRY_ORTHOGONALIZED_16305306345092783979)],
        &[(0b01001, &ENTRY_ORTHOGONALIZES_12099471702779010348)],
        &[(0b01001, &ENTRY_ORTHOGONALIZING_1408036844114979301)],
        &[(0b10010, &ENTRY_ORTHOGRAPHIZE_3476357704806405396)],
        &[(0b10010, &ENTRY_ORTHOGRAPHIZED_13781857966805232511)],
        &[(0b10010, &ENTRY_ORTHOGRAPHIZING_4089809753480171437)],
        &[(0b01001, &ENTRY_ORTHOGRAPHIZE_3476357704806405396)],
        &[(0b01001, &ENTRY_ORTHOGRAPHIZED_13781857966805232511)],
        &[(0b01001, &ENTRY_ORTHOGRAPHIZING_4089809753480171437)],
        &[(0b11010, &ENTRY_ORTHOPEDIA_16461309721642844449)],
        &[(0b11010, &ENTRY_ORTHOPEDIC_11181628856417796299)],
        &[(0b11010, &ENTRY_ORTHOPEDICAL_6610437949463263530)],
        &[(0b11010, &ENTRY_ORTHOPEDICALLIER_3224037467165156060)],
        &[(0b11010, &ENTRY_ORTHOPEDICALLIEST_8960378657095551218)],
        &[(0b11010, &ENTRY_ORTHOPEDICALLY_2298336873051715813)],
        &[(0b11010, &ENTRY_ORTHOPEDICER_3585810925484129429)],
        &[(0b11010, &ENTRY_ORTHOPEDICEST_12750955173838086616)],
        &[(0b11010, &ENTRY_ORTHOPEDICS_12977459761715868784)],
        &[(0b11010, &ENTRY_ORTHOPEDIES_5292169995821299852)],
        &[(0b11010, &ENTRY_ORTHOPEDIST_6644326132964977786)],
        &[(0b11010, &ENTRY_ORTHOPEDISTS_13748363777846849291)],
        &[(0b11010, &ENTRY_ORTHOPEDY_9278741910215259372)],
        &[(0b10001, &ENTRY_ORTHOPEDIA_16461309721642844449)],
        &[(0b11001, &ENTRY_ORTHOPEDIC_11181628856417796299)],
        &[(0b10001, &ENTRY_ORTHOPEDICAL_6610437949463263530)],
        &[(0b10001, &ENTRY_ORTHOPEDICALLIER_3224037467165156060)],
        &[(0b10001, &ENTRY_ORTHOPEDICALLIEST_8960378657095551218)],
        &[(0b10001, &ENTRY_ORTHOPEDICALLY_2298336873051715813)],
        &[(0b11001, &ENTRY_ORTHOPEDICER_3585810925484129429)],
        &[(0b11001, &ENTRY_ORTHOPEDICEST_12750955173838086616)],
        &[(0b11001, &ENTRY_ORTHOPEDICS_12977459761715868784)],
        &[(0b10001, &ENTRY_ORTHOPEDIES_5292169995821299852)],
        &[(0b10001, &ENTRY_ORTHOPEDIST_6644326132964977786)],
        &[(0b10001, &ENTRY_ORTHOPEDISTS_13748363777846849291)],
        &[(0b10001, &ENTRY_ORTHOPEDY_9278741910215259372)],
        &[(0b00001, &ENTRY_ORTHOPNEA_1668703272398397545)],
        &[(0b00001, &ENTRY_ORTHOPNEIC_11214547916528097306)],
        &[(0b11010, &ENTRY_ORTHOPNEA_1668703272398397545)],
        &[(0b11010, &ENTRY_ORTHOPNEIC_11214547916528097306)],
    ],
    range: 6..=15,
};

static VARS_ORS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORS_CHILDREN),
    value: None,
};

pub static VARS_ORS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("el")],
    values: &[&[(0b00001, &ENTRY_ORSEL_3088141134430316343)]],
    range: 2..=2,
};

static VARS_ORP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORP_CHILDREN),
    value: None,
};

pub static VARS_ORP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hanise"),
        dictgen::InsensitiveStr::Ascii("hanises"),
        dictgen::InsensitiveStr::Ascii("hanize"),
        dictgen::InsensitiveStr::Ascii("hanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ORPHANIZE_12252103065591212309)],
        &[(0b10010, &ENTRY_ORPHANIZES_9131568606393406839)],
        &[(0b01001, &ENTRY_ORPHANIZE_12252103065591212309)],
        &[(0b01001, &ENTRY_ORPHANIZES_9131568606393406839)],
    ],
    range: 6..=7,
};

static VARS_ORO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORO_CHILDREN),
    value: None,
};

pub static VARS_ORO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("logies"),
        dictgen::InsensitiveStr::Ascii("logy"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OROLOGIES_1741200697611441025)],
        &[(0b00001, &ENTRY_OROLOGY_10784240065242117238)],
    ],
    range: 4..=6,
};

static VARS_ORN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORN_CHILDREN),
    value: None,
};

pub static VARS_ORN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("amentalise"),
        dictgen::InsensitiveStr::Ascii("amentalises"),
        dictgen::InsensitiveStr::Ascii("amentalize"),
        dictgen::InsensitiveStr::Ascii("amentalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ORNAMENTALIZE_7265064091795605703)],
        &[(0b10010, &ENTRY_ORNAMENTALIZES_910695680953477344)],
        &[(0b01001, &ENTRY_ORNAMENTALIZE_7265064091795605703)],
        &[(0b01001, &ENTRY_ORNAMENTALIZES_910695680953477344)],
    ],
    range: 10..=11,
};

static VARS_ORI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORI_CHILDREN),
    value: None,
};

pub static VARS_ORI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entalisation"),
        dictgen::InsensitiveStr::Ascii("entalisations"),
        dictgen::InsensitiveStr::Ascii("entalise"),
        dictgen::InsensitiveStr::Ascii("entalised"),
        dictgen::InsensitiveStr::Ascii("entalises"),
        dictgen::InsensitiveStr::Ascii("entalising"),
        dictgen::InsensitiveStr::Ascii("entalization"),
        dictgen::InsensitiveStr::Ascii("entalizations"),
        dictgen::InsensitiveStr::Ascii("entalize"),
        dictgen::InsensitiveStr::Ascii("entalized"),
        dictgen::InsensitiveStr::Ascii("entalizes"),
        dictgen::InsensitiveStr::Ascii("entalizing"),
        dictgen::InsensitiveStr::Ascii("entisation"),
        dictgen::InsensitiveStr::Ascii("entisations"),
        dictgen::InsensitiveStr::Ascii("entise"),
        dictgen::InsensitiveStr::Ascii("entises"),
        dictgen::InsensitiveStr::Ascii("entization"),
        dictgen::InsensitiveStr::Ascii("entizations"),
        dictgen::InsensitiveStr::Ascii("entize"),
        dictgen::InsensitiveStr::Ascii("entizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ORIENTALIZATION_1232208388762237133)],
        &[(0b10010, &ENTRY_ORIENTALIZATIONS_3726476841271105524)],
        &[(0b10010, &ENTRY_ORIENTALIZE_3925980212984131506)],
        &[(0b10010, &ENTRY_ORIENTALIZED_17195678597420672824)],
        &[(0b10010, &ENTRY_ORIENTALIZES_15493764345171362933)],
        &[(0b10010, &ENTRY_ORIENTALIZING_16469770502347036371)],
        &[(0b01001, &ENTRY_ORIENTALIZATION_1232208388762237133)],
        &[(0b01001, &ENTRY_ORIENTALIZATIONS_3726476841271105524)],
        &[(0b01001, &ENTRY_ORIENTALIZE_3925980212984131506)],
        &[(0b01001, &ENTRY_ORIENTALIZED_17195678597420672824)],
        &[(0b01001, &ENTRY_ORIENTALIZES_15493764345171362933)],
        &[(0b01001, &ENTRY_ORIENTALIZING_16469770502347036371)],
        &[(0b10010, &ENTRY_ORIENTIZATION_2913174614870744272)],
        &[(0b10010, &ENTRY_ORIENTIZATIONS_16760664737151206075)],
        &[(0b10010, &ENTRY_ORIENTIZE_16169620859440661915)],
        &[(0b10010, &ENTRY_ORIENTIZES_4137063984653504864)],
        &[(0b01001, &ENTRY_ORIENTIZATION_2913174614870744272)],
        &[(0b01001, &ENTRY_ORIENTIZATIONS_16760664737151206075)],
        &[(0b01001, &ENTRY_ORIENTIZE_16169620859440661915)],
        &[(0b01001, &ENTRY_ORIENTIZES_4137063984653504864)],
    ],
    range: 6..=13,
};

static VARS_ORG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORG_CHILDREN),
    value: None,
};

pub static VARS_ORG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("andie"),
        dictgen::InsensitiveStr::Ascii("andy"),
        dictgen::InsensitiveStr::Ascii("anisabilities"),
        dictgen::InsensitiveStr::Ascii("anisability"),
        dictgen::InsensitiveStr::Ascii("anisable"),
        dictgen::InsensitiveStr::Ascii("anisabler"),
        dictgen::InsensitiveStr::Ascii("anisables"),
        dictgen::InsensitiveStr::Ascii("anisablest"),
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anisational"),
        dictgen::InsensitiveStr::Ascii("anisationaler"),
        dictgen::InsensitiveStr::Ascii("anisationalest"),
        dictgen::InsensitiveStr::Ascii("anisationallier"),
        dictgen::InsensitiveStr::Ascii("anisationalliest"),
        dictgen::InsensitiveStr::Ascii("anisationally"),
        dictgen::InsensitiveStr::Ascii("anisationals"),
        dictgen::InsensitiveStr::Ascii("anisationist"),
        dictgen::InsensitiveStr::Ascii("anisationists"),
        dictgen::InsensitiveStr::Ascii("anisations"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("aniser"),
        dictgen::InsensitiveStr::Ascii("anisers"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anizabilities"),
        dictgen::InsensitiveStr::Ascii("anizability"),
        dictgen::InsensitiveStr::Ascii("anizable"),
        dictgen::InsensitiveStr::Ascii("anizabler"),
        dictgen::InsensitiveStr::Ascii("anizables"),
        dictgen::InsensitiveStr::Ascii("anizablest"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anizational"),
        dictgen::InsensitiveStr::Ascii("anizationaler"),
        dictgen::InsensitiveStr::Ascii("anizationalest"),
        dictgen::InsensitiveStr::Ascii("anizationallier"),
        dictgen::InsensitiveStr::Ascii("anizationalliest"),
        dictgen::InsensitiveStr::Ascii("anizationally"),
        dictgen::InsensitiveStr::Ascii("anizationals"),
        dictgen::InsensitiveStr::Ascii("anizationist"),
        dictgen::InsensitiveStr::Ascii("anizationists"),
        dictgen::InsensitiveStr::Ascii("anizations"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizer"),
        dictgen::InsensitiveStr::Ascii("anizers"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
    ],
    values: &[
        &[(0b10011, &ENTRY_ORGANDY_16885011380899378447)],
        &[(0b01001, &ENTRY_ORGANDY_16885011380899378447)],
        &[(0b10010, &ENTRY_ORGANIZABILITIES_9394931609149039377)],
        &[(0b10010, &ENTRY_ORGANIZABILITY_5246488745229410216)],
        &[(0b10010, &ENTRY_ORGANIZABLE_6357914431188658371)],
        &[(0b10010, &ENTRY_ORGANIZABLER_1969669150958775103)],
        &[(0b10010, &ENTRY_ORGANIZABLES_18100950647422214168)],
        &[(0b10010, &ENTRY_ORGANIZABLEST_8166375843038220493)],
        &[(0b10010, &ENTRY_ORGANIZATION_17289795818827632314)],
        &[(0b10010, &ENTRY_ORGANIZATIONAL_2693930595138979162)],
        &[(0b10010, &ENTRY_ORGANIZATIONALER_3873019173853092798)],
        &[(0b10010, &ENTRY_ORGANIZATIONALEST_1078872185464956795)],
        &[(0b10010, &ENTRY_ORGANIZATIONALLIER_4232299366340167031)],
        &[(0b10010, &ENTRY_ORGANIZATIONALLIEST_5781070786689457967)],
        &[(0b10010, &ENTRY_ORGANIZATIONALLY_14545398087106745696)],
        &[(0b10010, &ENTRY_ORGANIZATIONALS_14375928891357084131)],
        &[(0b10010, &ENTRY_ORGANIZATIONIST_4240138124771372347)],
        &[(0b10010, &ENTRY_ORGANIZATIONISTS_16677324722617299171)],
        &[(0b10010, &ENTRY_ORGANIZATIONS_4577579545569833942)],
        &[(0b10010, &ENTRY_ORGANIZE_5877473548332466223)],
        &[(0b10010, &ENTRY_ORGANIZED_14662641348959642965)],
        &[(0b10010, &ENTRY_ORGANIZER_11892981286551035399)],
        &[(0b10010, &ENTRY_ORGANIZERS_3593448493398179170)],
        &[(0b10010, &ENTRY_ORGANIZES_10823078939317146880)],
        &[(0b10010, &ENTRY_ORGANIZING_8682329261432472945)],
        &[(0b01001, &ENTRY_ORGANIZABILITIES_9394931609149039377)],
        &[(0b01001, &ENTRY_ORGANIZABILITY_5246488745229410216)],
        &[(0b01001, &ENTRY_ORGANIZABLE_6357914431188658371)],
        &[(0b01001, &ENTRY_ORGANIZABLER_1969669150958775103)],
        &[(0b01001, &ENTRY_ORGANIZABLES_18100950647422214168)],
        &[(0b01001, &ENTRY_ORGANIZABLEST_8166375843038220493)],
        &[(0b01001, &ENTRY_ORGANIZATION_17289795818827632314)],
        &[(0b01001, &ENTRY_ORGANIZATIONAL_2693930595138979162)],
        &[(0b01001, &ENTRY_ORGANIZATIONALER_3873019173853092798)],
        &[(0b01001, &ENTRY_ORGANIZATIONALEST_1078872185464956795)],
        &[(0b01001, &ENTRY_ORGANIZATIONALLIER_4232299366340167031)],
        &[(0b01001, &ENTRY_ORGANIZATIONALLIEST_5781070786689457967)],
        &[(0b01001, &ENTRY_ORGANIZATIONALLY_14545398087106745696)],
        &[(0b01001, &ENTRY_ORGANIZATIONALS_14375928891357084131)],
        &[(0b01001, &ENTRY_ORGANIZATIONIST_4240138124771372347)],
        &[(0b01001, &ENTRY_ORGANIZATIONISTS_16677324722617299171)],
        &[(0b01001, &ENTRY_ORGANIZATIONS_4577579545569833942)],
        &[(0b01001, &ENTRY_ORGANIZE_5877473548332466223)],
        &[(0b01001, &ENTRY_ORGANIZED_14662641348959642965)],
        &[(0b01001, &ENTRY_ORGANIZER_11892981286551035399)],
        &[(0b01001, &ENTRY_ORGANIZERS_3593448493398179170)],
        &[(0b01001, &ENTRY_ORGANIZES_10823078939317146880)],
        &[(0b01001, &ENTRY_ORGANIZING_8682329261432472945)],
    ],
    range: 4..=16,
};

static VARS_ORC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORC_CHILDREN),
    value: None,
};

pub static VARS_ORC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hester"),
        dictgen::InsensitiveStr::Ascii("hestre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ORCHESTER_10087918988280176676)],
        &[(0b11010, &ENTRY_ORCHESTER_10087918988280176676)],
    ],
    range: 6..=6,
};

static VARS_ORA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORA_CHILDREN),
    value: None,
};

pub static VARS_ORA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("ngise"),
        dictgen::InsensitiveStr::Ascii("ngises"),
        dictgen::InsensitiveStr::Ascii("ngize"),
        dictgen::InsensitiveStr::Ascii("ngizes"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ORALIZATION_14102364602676138991)],
        &[(0b10010, &ENTRY_ORALIZATIONS_7948469631672727124)],
        &[(0b10010, &ENTRY_ORALIZE_13699344227459420149)],
        &[(0b10010, &ENTRY_ORALIZES_4086024195630455303)],
        &[(0b01001, &ENTRY_ORALIZATION_14102364602676138991)],
        &[(0b01001, &ENTRY_ORALIZATIONS_7948469631672727124)],
        &[(0b01001, &ENTRY_ORALIZE_13699344227459420149)],
        &[(0b01001, &ENTRY_ORALIZES_4086024195630455303)],
        &[(0b10010, &ENTRY_ORANGIZE_2611683647153302964)],
        &[(0b10010, &ENTRY_ORANGIZES_11725856239709635108)],
        &[(0b01001, &ENTRY_ORANGIZE_2611683647153302964)],
        &[(0b01001, &ENTRY_ORANGIZES_11725856239709635108)],
        &[(0b10010, &ENTRY_ORATORIZE_6597645605933742855)],
        &[(0b10010, &ENTRY_ORATORIZES_6306251252951589283)],
        &[(0b01001, &ENTRY_ORATORIZE_6597645605933742855)],
        &[(0b01001, &ENTRY_ORATORIZES_6306251252951589283)],
    ],
    range: 4..=9,
};

static VARS_OP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OP_CHILDREN),
    value: None,
};

pub static VARS_OP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aled"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alled"),
        dictgen::InsensitiveStr::Ascii("erationalisation"),
        dictgen::InsensitiveStr::Ascii("erationalisations"),
        dictgen::InsensitiveStr::Ascii("erationalise"),
        dictgen::InsensitiveStr::Ascii("erationalised"),
        dictgen::InsensitiveStr::Ascii("erationalization"),
        dictgen::InsensitiveStr::Ascii("erationalizations"),
        dictgen::InsensitiveStr::Ascii("erationalize"),
        dictgen::InsensitiveStr::Ascii("erationalized"),
        dictgen::InsensitiveStr::Ascii("eratise"),
        dictgen::InsensitiveStr::Ascii("eratised"),
        dictgen::InsensitiveStr::Ascii("eratises"),
        dictgen::InsensitiveStr::Ascii("eratising"),
        dictgen::InsensitiveStr::Ascii("eratize"),
        dictgen::InsensitiveStr::Ascii("eratized"),
        dictgen::InsensitiveStr::Ascii("eratizes"),
        dictgen::InsensitiveStr::Ascii("eratizing"),
        dictgen::InsensitiveStr::Ascii("iniaster"),
        dictgen::InsensitiveStr::Ascii("iniastre"),
        dictgen::InsensitiveStr::Ascii("iniater"),
        dictgen::InsensitiveStr::Ascii("iniatre"),
        dictgen::InsensitiveStr::Ascii("timalisation"),
        dictgen::InsensitiveStr::Ascii("timalisations"),
        dictgen::InsensitiveStr::Ascii("timalise"),
        dictgen::InsensitiveStr::Ascii("timalised"),
        dictgen::InsensitiveStr::Ascii("timalises"),
        dictgen::InsensitiveStr::Ascii("timalising"),
        dictgen::InsensitiveStr::Ascii("timalization"),
        dictgen::InsensitiveStr::Ascii("timalizations"),
        dictgen::InsensitiveStr::Ascii("timalize"),
        dictgen::InsensitiveStr::Ascii("timalized"),
        dictgen::InsensitiveStr::Ascii("timalizes"),
        dictgen::InsensitiveStr::Ascii("timalizing"),
        dictgen::InsensitiveStr::Ascii("timisation"),
        dictgen::InsensitiveStr::Ascii("timisations"),
        dictgen::InsensitiveStr::Ascii("timise"),
        dictgen::InsensitiveStr::Ascii("timised"),
        dictgen::InsensitiveStr::Ascii("timiser"),
        dictgen::InsensitiveStr::Ascii("timisers"),
        dictgen::InsensitiveStr::Ascii("timises"),
        dictgen::InsensitiveStr::Ascii("timising"),
        dictgen::InsensitiveStr::Ascii("timization"),
        dictgen::InsensitiveStr::Ascii("timizations"),
        dictgen::InsensitiveStr::Ascii("timize"),
        dictgen::InsensitiveStr::Ascii("timized"),
        dictgen::InsensitiveStr::Ascii("timizer"),
        dictgen::InsensitiveStr::Ascii("timizers"),
        dictgen::InsensitiveStr::Ascii("timizes"),
        dictgen::InsensitiveStr::Ascii("timizing"),
        dictgen::InsensitiveStr::Ascii("tionalise"),
        dictgen::InsensitiveStr::Ascii("tionalises"),
        dictgen::InsensitiveStr::Ascii("tionalize"),
        dictgen::InsensitiveStr::Ascii("tionalizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OPALED_4268978649764110434)],
        &[(0b10010, &ENTRY_OPALIZE_1437903205364528409)],
        &[(0b10010, &ENTRY_OPALIZED_4004234219806495147)],
        &[(0b10010, &ENTRY_OPALIZES_13091586316761723756)],
        &[(0b01001, &ENTRY_OPALIZE_1437903205364528409)],
        &[(0b01001, &ENTRY_OPALIZED_4004234219806495147)],
        &[(0b01001, &ENTRY_OPALIZES_13091586316761723756)],
        &[(0b11010, &ENTRY_OPALED_4268978649764110434)],
        &[(0b10010, &ENTRY_OPERATIONALIZATION_12829818197536963102)],
        &[(0b10010, &ENTRY_OPERATIONALIZATIONS_17065729379646598828)],
        &[(0b10010, &ENTRY_OPERATIONALIZE_15949572577613892246)],
        &[(0b10010, &ENTRY_OPERATIONALIZED_2127043114686016582)],
        &[(0b01001, &ENTRY_OPERATIONALIZATION_12829818197536963102)],
        &[(0b01001, &ENTRY_OPERATIONALIZATIONS_17065729379646598828)],
        &[(0b01001, &ENTRY_OPERATIONALIZE_15949572577613892246)],
        &[(0b01001, &ENTRY_OPERATIONALIZED_2127043114686016582)],
        &[(0b10010, &ENTRY_OPERATIZE_2365742892752822648)],
        &[(0b10010, &ENTRY_OPERATIZED_2802384364460316139)],
        &[(0b10010, &ENTRY_OPERATIZES_15123147664326939450)],
        &[(0b10010, &ENTRY_OPERATIZING_18314800119781305216)],
        &[(0b01001, &ENTRY_OPERATIZE_2365742892752822648)],
        &[(0b01001, &ENTRY_OPERATIZED_2802384364460316139)],
        &[(0b01001, &ENTRY_OPERATIZES_15123147664326939450)],
        &[(0b01001, &ENTRY_OPERATIZING_18314800119781305216)],
        &[(0b00001, &ENTRY_OPINIASTER_923208296007920958)],
        &[(0b11010, &ENTRY_OPINIASTER_923208296007920958)],
        &[(0b00001, &ENTRY_OPINIATER_17164500991773351887)],
        &[(0b11010, &ENTRY_OPINIATER_17164500991773351887)],
        &[(0b10010, &ENTRY_OPTIMALIZATION_5266921443954560262)],
        &[(0b10010, &ENTRY_OPTIMALIZATIONS_2899060633295590432)],
        &[(0b10010, &ENTRY_OPTIMALIZE_4657203074060229056)],
        &[(0b10010, &ENTRY_OPTIMALIZED_18163256389331832808)],
        &[(0b10010, &ENTRY_OPTIMALIZES_16961555613967169097)],
        &[(0b10010, &ENTRY_OPTIMALIZING_3678300131645142586)],
        &[(0b01001, &ENTRY_OPTIMALIZATION_5266921443954560262)],
        &[(0b01001, &ENTRY_OPTIMALIZATIONS_2899060633295590432)],
        &[(0b01001, &ENTRY_OPTIMALIZE_4657203074060229056)],
        &[(0b01001, &ENTRY_OPTIMALIZED_18163256389331832808)],
        &[(0b01001, &ENTRY_OPTIMALIZES_16961555613967169097)],
        &[(0b01001, &ENTRY_OPTIMALIZING_3678300131645142586)],
        &[(0b10010, &ENTRY_OPTIMIZATION_7999660279345208813)],
        &[(0b10010, &ENTRY_OPTIMIZATIONS_5853505921922952795)],
        &[(0b10010, &ENTRY_OPTIMIZE_2249839710181808282)],
        &[(0b10010, &ENTRY_OPTIMIZED_1595116357475103476)],
        &[(0b10010, &ENTRY_OPTIMIZER_17271297266309970872)],
        &[(0b10010, &ENTRY_OPTIMIZERS_9262293159377441067)],
        &[(0b10010, &ENTRY_OPTIMIZES_4735979948079339705)],
        &[(0b10010, &ENTRY_OPTIMIZING_13977015133672850235)],
        &[(0b01001, &ENTRY_OPTIMIZATION_7999660279345208813)],
        &[(0b01001, &ENTRY_OPTIMIZATIONS_5853505921922952795)],
        &[(0b01001, &ENTRY_OPTIMIZE_2249839710181808282)],
        &[(0b01001, &ENTRY_OPTIMIZED_1595116357475103476)],
        &[(0b01001, &ENTRY_OPTIMIZER_17271297266309970872)],
        &[(0b01001, &ENTRY_OPTIMIZERS_9262293159377441067)],
        &[(0b01001, &ENTRY_OPTIMIZES_4735979948079339705)],
        &[(0b01001, &ENTRY_OPTIMIZING_13977015133672850235)],
        &[(0b10010, &ENTRY_OPTIONALIZE_14534625353219798956)],
        &[(0b10010, &ENTRY_OPTIONALIZES_9215004327024243624)],
        &[(0b01001, &ENTRY_OPTIONALIZE_14534625353219798956)],
        &[(0b01001, &ENTRY_OPTIONALIZES_9215004327024243624)],
    ],
    range: 4..=17,
};

static VARS_OO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OO_CHILDREN),
    value: None,
};

pub static VARS_OO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("glea"),
        dictgen::InsensitiveStr::Ascii("gloea"),
        dictgen::InsensitiveStr::Ascii("phorectomise"),
        dictgen::InsensitiveStr::Ascii("phorectomised"),
        dictgen::InsensitiveStr::Ascii("phorectomises"),
        dictgen::InsensitiveStr::Ascii("phorectomising"),
        dictgen::InsensitiveStr::Ascii("phorectomize"),
        dictgen::InsensitiveStr::Ascii("phorectomized"),
        dictgen::InsensitiveStr::Ascii("phorectomizes"),
        dictgen::InsensitiveStr::Ascii("phorectomizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OOGLEA_9695545370949817893)],
        &[(0b11010, &ENTRY_OOGLEA_9695545370949817893)],
        &[(0b10010, &ENTRY_OOPHORECTOMIZE_1811121544488658856)],
        &[(0b10010, &ENTRY_OOPHORECTOMIZED_14268303583521763064)],
        &[(0b10010, &ENTRY_OOPHORECTOMIZES_11659877128377332157)],
        &[(0b10010, &ENTRY_OOPHORECTOMIZING_18341066518044446483)],
        &[(0b01001, &ENTRY_OOPHORECTOMIZE_1811121544488658856)],
        &[(0b01001, &ENTRY_OOPHORECTOMIZED_14268303583521763064)],
        &[(0b01001, &ENTRY_OOPHORECTOMIZES_11659877128377332157)],
        &[(0b01001, &ENTRY_OOPHORECTOMIZING_18341066518044446483)],
    ],
    range: 4..=14,
};

static VARS_ON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ON_CHILDREN),
    value: None,
};

pub static VARS_ON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eyer"),
        dictgen::InsensitiveStr::Ascii("eyers"),
        dictgen::InsensitiveStr::Ascii("eyre"),
        dictgen::InsensitiveStr::Ascii("eyres"),
        dictgen::InsensitiveStr::Ascii("ionised"),
        dictgen::InsensitiveStr::Ascii("ioniseds"),
        dictgen::InsensitiveStr::Ascii("ionized"),
        dictgen::InsensitiveStr::Ascii("ionizeds"),
        dictgen::InsensitiveStr::Ascii("tologise"),
        dictgen::InsensitiveStr::Ascii("tologize"),
        dictgen::InsensitiveStr::Ascii("wards"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ONEYER_1302914143351093181)],
        &[(0b00001, &ENTRY_ONEYERS_17135938246039464961)],
        &[(0b11010, &ENTRY_ONEYER_1302914143351093181)],
        &[(0b11010, &ENTRY_ONEYERS_17135938246039464961)],
        &[(0b10010, &ENTRY_ONIONIZED_12389658815685910930)],
        &[(0b10010, &ENTRY_ONIONIZEDS_7393920731584280289)],
        &[(0b01001, &ENTRY_ONIONIZED_12389658815685910930)],
        &[(0b01001, &ENTRY_ONIONIZEDS_7393920731584280289)],
        &[(0b10010, &ENTRY_ONTOLOGIZE_16817464287858369211)],
        &[(0b01001, &ENTRY_ONTOLOGIZE_16817464287858369211)],
        &[(0b10011, &ENTRY_ONWARD_5633188724180907694)],
    ],
    range: 4..=8,
};

static VARS_OM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OM_CHILDREN),
    value: None,
};

pub static VARS_OM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ber"),
        dictgen::InsensitiveStr::Ascii("bers"),
        dictgen::InsensitiveStr::Ascii("bre"),
        dictgen::InsensitiveStr::Ascii("bres"),
        dictgen::InsensitiveStr::Ascii("elet"),
        dictgen::InsensitiveStr::Ascii("elets"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OMBER_14663073390907191243)],
        &[(0b00001, &ENTRY_OMBERS_8620615949302259409)],
        &[(0b11010, &ENTRY_OMBER_14663073390907191243)],
        &[(0b11010, &ENTRY_OMBERS_8620615949302259409)],
        &[(0b01001, &ENTRY_OMELET_764513264155611675)],
        &[(0b01001, &ENTRY_OMELETS_3609558159591624407)],
    ],
    range: 3..=5,
};

static VARS_OL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OL_CHILDREN),
    value: None,
};

pub static VARS_OL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("igaemia"),
        dictgen::InsensitiveStr::Ascii("igemia"),
        dictgen::InsensitiveStr::Ascii("igocythaemia"),
        dictgen::InsensitiveStr::Ascii("igocythemia"),
        dictgen::InsensitiveStr::Ascii("pae"),
        dictgen::InsensitiveStr::Ascii("pe"),
        dictgen::InsensitiveStr::Ascii("ympianise"),
        dictgen::InsensitiveStr::Ascii("ympianises"),
        dictgen::InsensitiveStr::Ascii("ympianize"),
        dictgen::InsensitiveStr::Ascii("ympianizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OLIGEMIA_2437312993307346729)],
        &[(0b10001, &ENTRY_OLIGEMIA_2437312993307346729)],
        &[(0b11010, &ENTRY_OLIGOCYTHEMIA_11016311239765932815)],
        &[(0b10001, &ENTRY_OLIGOCYTHEMIA_11016311239765932815)],
        &[(0b11010, &ENTRY_OLPE_8094297296134265506)],
        &[(0b00001, &ENTRY_OLPE_8094297296134265506)],
        &[(0b10010, &ENTRY_OLYMPIANIZE_2609363663438954403)],
        &[(0b10010, &ENTRY_OLYMPIANIZES_11684603460342800519)],
        &[(0b01001, &ENTRY_OLYMPIANIZE_2609363663438954403)],
        &[(0b01001, &ENTRY_OLYMPIANIZES_11684603460342800519)],
    ],
    range: 2..=12,
};

static VARS_OF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OF_CHILDREN),
    value: None,
};

pub static VARS_OF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fence"),
        dictgen::InsensitiveStr::Ascii("fenceless"),
        dictgen::InsensitiveStr::Ascii("fencelesser"),
        dictgen::InsensitiveStr::Ascii("fencelesses"),
        dictgen::InsensitiveStr::Ascii("fencelessest"),
        dictgen::InsensitiveStr::Ascii("fencelessly"),
        dictgen::InsensitiveStr::Ascii("fences"),
        dictgen::InsensitiveStr::Ascii("fense"),
        dictgen::InsensitiveStr::Ascii("fenseless"),
        dictgen::InsensitiveStr::Ascii("fenselesser"),
        dictgen::InsensitiveStr::Ascii("fenselesses"),
        dictgen::InsensitiveStr::Ascii("fenselessest"),
        dictgen::InsensitiveStr::Ascii("fenselessly"),
        dictgen::InsensitiveStr::Ascii("fenses"),
        dictgen::InsensitiveStr::Ascii("ficialisation"),
        dictgen::InsensitiveStr::Ascii("ficialisations"),
        dictgen::InsensitiveStr::Ascii("ficialise"),
        dictgen::InsensitiveStr::Ascii("ficialises"),
        dictgen::InsensitiveStr::Ascii("ficialization"),
        dictgen::InsensitiveStr::Ascii("ficializations"),
        dictgen::InsensitiveStr::Ascii("ficialize"),
        dictgen::InsensitiveStr::Ascii("ficializes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OFFENSE_3255912368052973030)],
        &[(0b11010, &ENTRY_OFFENSELESS_2398765789263825333)],
        &[(0b11010, &ENTRY_OFFENSELESSER_11777917350340758028)],
        &[(0b11010, &ENTRY_OFFENSELESSES_13236163449907150320)],
        &[(0b11010, &ENTRY_OFFENSELESSEST_9145066131421191055)],
        &[(0b11010, &ENTRY_OFFENSELESSLY_5078736202987113916)],
        &[(0b11010, &ENTRY_OFFENSES_14914149738486494625)],
        &[(0b01001, &ENTRY_OFFENSE_3255912368052973030)],
        &[(0b00001, &ENTRY_OFFENSELESS_2398765789263825333)],
        &[(0b00001, &ENTRY_OFFENSELESSER_11777917350340758028)],
        &[(0b00001, &ENTRY_OFFENSELESSES_13236163449907150320)],
        &[(0b00001, &ENTRY_OFFENSELESSEST_9145066131421191055)],
        &[(0b00001, &ENTRY_OFFENSELESSLY_5078736202987113916)],
        &[(0b01001, &ENTRY_OFFENSES_14914149738486494625)],
        &[(0b10010, &ENTRY_OFFICIALIZATION_7004816527823497683)],
        &[(0b10010, &ENTRY_OFFICIALIZATIONS_3020857948638018278)],
        &[(0b10010, &ENTRY_OFFICIALIZE_18360229525723516910)],
        &[(0b10010, &ENTRY_OFFICIALIZES_5576900539771678977)],
        &[(0b01001, &ENTRY_OFFICIALIZATION_7004816527823497683)],
        &[(0b01001, &ENTRY_OFFICIALIZATIONS_3020857948638018278)],
        &[(0b01001, &ENTRY_OFFICIALIZE_18360229525723516910)],
        &[(0b01001, &ENTRY_OFFICIALIZES_5576900539771678977)],
    ],
    range: 5..=14,
};

static VARS_OE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OE_CHILDREN),
    value: None,
};

pub static VARS_OE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("coid"),
        dictgen::InsensitiveStr::Ascii("cophobia"),
        dictgen::InsensitiveStr::Ascii("cumenic"),
        dictgen::InsensitiveStr::Ascii("cumenicalism"),
        dictgen::InsensitiveStr::Ascii("cumenicity"),
        dictgen::InsensitiveStr::Ascii("cumenism"),
        dictgen::InsensitiveStr::Ascii("cus"),
        dictgen::InsensitiveStr::Ascii("dema"),
        dictgen::InsensitiveStr::Ascii("demas"),
        dictgen::InsensitiveStr::Ascii("dematose"),
        dictgen::InsensitiveStr::Ascii("dematous"),
        dictgen::InsensitiveStr::Ascii("nocyte"),
        dictgen::InsensitiveStr::Ascii("nolic"),
        dictgen::InsensitiveStr::Ascii("nological"),
        dictgen::InsensitiveStr::Ascii("nologist"),
        dictgen::InsensitiveStr::Ascii("nologists"),
        dictgen::InsensitiveStr::Ascii("nomania"),
        dictgen::InsensitiveStr::Ascii("sophagal"),
        dictgen::InsensitiveStr::Ascii("sophagean"),
        dictgen::InsensitiveStr::Ascii("sophagi"),
        dictgen::InsensitiveStr::Ascii("sophagism"),
        dictgen::InsensitiveStr::Ascii("sophagismus"),
        dictgen::InsensitiveStr::Ascii("sophagitis"),
        dictgen::InsensitiveStr::Ascii("sophagus"),
        dictgen::InsensitiveStr::Ascii("sophaguses"),
        dictgen::InsensitiveStr::Ascii("stradiol"),
        dictgen::InsensitiveStr::Ascii("stradiols"),
        dictgen::InsensitiveStr::Ascii("stral"),
        dictgen::InsensitiveStr::Ascii("strin"),
        dictgen::InsensitiveStr::Ascii("strins"),
        dictgen::InsensitiveStr::Ascii("striol"),
        dictgen::InsensitiveStr::Ascii("striols"),
        dictgen::InsensitiveStr::Ascii("strogen"),
        dictgen::InsensitiveStr::Ascii("strogenic"),
        dictgen::InsensitiveStr::Ascii("strogens"),
        dictgen::InsensitiveStr::Ascii("strone"),
        dictgen::InsensitiveStr::Ascii("strones"),
        dictgen::InsensitiveStr::Ascii("strous"),
        dictgen::InsensitiveStr::Ascii("strual"),
        dictgen::InsensitiveStr::Ascii("struate"),
        dictgen::InsensitiveStr::Ascii("struation"),
        dictgen::InsensitiveStr::Ascii("strum"),
        dictgen::InsensitiveStr::Ascii("strums"),
        dictgen::InsensitiveStr::Ascii("strus"),
        dictgen::InsensitiveStr::Ascii("struses"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ECOID_15394441758678226221)],
        &[(0b11010, &ENTRY_ECOPHOBIA_5971973597118487121)],
        &[(0b11010, &ENTRY_ECUMENIC_8234812006342728847)],
        &[(0b11010, &ENTRY_ECUMENICALISM_16608780476444919974)],
        &[(0b11010, &ENTRY_ECUMENICITY_12037844523161670010)],
        &[(0b11010, &ENTRY_ECUMENISM_1878909652524904058)],
        &[(0b11010, &ENTRY_ECUS_6730015734116715954)],
        &[(0b10010, &ENTRY_EDEMA_6077775640730618555)],
        &[(0b10010, &ENTRY_EDEMAS_2647107175205211125)],
        &[(0b10010, &ENTRY_EDEMATOSE_8946823576029811633)],
        &[(0b10010, &ENTRY_EDEMATOUS_6296161129737314269)],
        &[(0b11010, &ENTRY_ENOCYTE_12666928362851607670)],
        &[(0b11010, &ENTRY_ENOLIC_7934123335578564140)],
        &[(0b11010, &ENTRY_ENOLOGICAL_11189078660498192658)],
        &[(0b11010, &ENTRY_ENOLOGIST_382673391921246993)],
        &[(0b11010, &ENTRY_ENOLOGISTS_1989647851737964355)],
        &[(0b11010, &ENTRY_ENOMANIA_9115311181322537124)],
        &[(0b11010, &ENTRY_ESOPHAGAL_11568993434283087514)],
        &[(0b11010, &ENTRY_ESOPHAGEAN_9494840858799849160)],
        &[(0b10010, &ENTRY_ESOPHAGI_11954876978132806506)],
        &[(0b11010, &ENTRY_ESOPHAGISM_13497979405696032460)],
        &[(0b11010, &ENTRY_ESOPHAGISMUS_12116284235422316328)],
        &[(0b11010, &ENTRY_ESOPHAGITIS_13843737924467364508)],
        &[(0b11010, &ENTRY_ESOPHAGUS_17094499599237101062)],
        &[(0b00010, &ENTRY_ESOPHAGI_11954876978132806506)],
        &[(0b11010, &ENTRY_ESTRADIOL_31151792297264606)],
        &[(0b11010, &ENTRY_ESTRADIOLS_6635571464074472879)],
        &[(0b11010, &ENTRY_ESTRAL_4263474669881304636)],
        &[(0b11010, &ENTRY_ESTRIN_17130710844251925900)],
        &[(0b11010, &ENTRY_ESTRINS_17829170952547459464)],
        &[(0b11010, &ENTRY_ESTRIOL_14358431962924162389)],
        &[(0b11010, &ENTRY_ESTRIOLS_1134091154686696143)],
        &[(0b10010, &ENTRY_ESTROGEN_10173348120996063533)],
        &[(0b10010, &ENTRY_ESTROGENIC_3724956938647222280)],
        &[(0b10010, &ENTRY_ESTROGENS_11487970579706669068)],
        &[(0b11010, &ENTRY_ESTRONE_9986540566043863893)],
        &[(0b11010, &ENTRY_ESTRONES_10736858198614463395)],
        &[(0b10010, &ENTRY_ESTROUS_7878210273842809015)],
        &[(0b11010, &ENTRY_ESTRUAL_8880059716302502408)],
        &[(0b11010, &ENTRY_ESTRUATE_16347180830721817630)],
        &[(0b11010, &ENTRY_ESTRUATION_16723443098265001574)],
        &[(0b11010, &ENTRY_ESTRUM_14101011195419605525)],
        &[(0b11010, &ENTRY_ESTRUMS_7268966665464885989)],
        &[(0b10010, &ENTRY_ESTRUS_391811675946213924)],
        &[(0b10010, &ENTRY_ESTRUSES_7947106804154830951)],
    ],
    range: 3..=12,
};

static VARS_OD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OD_CHILDREN),
    value: None,
};

pub static VARS_OD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("orful"),
        dictgen::InsensitiveStr::Ascii("orfuller"),
        dictgen::InsensitiveStr::Ascii("orfullest"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("oriser"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizer"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
        dictgen::InsensitiveStr::Ascii("orless"),
        dictgen::InsensitiveStr::Ascii("orlesser"),
        dictgen::InsensitiveStr::Ascii("orlesses"),
        dictgen::InsensitiveStr::Ascii("orlessest"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ourful"),
        dictgen::InsensitiveStr::Ascii("ourfuller"),
        dictgen::InsensitiveStr::Ascii("ourfullest"),
        dictgen::InsensitiveStr::Ascii("ourless"),
        dictgen::InsensitiveStr::Ascii("ourlesser"),
        dictgen::InsensitiveStr::Ascii("ourlesses"),
        dictgen::InsensitiveStr::Ascii("ourlessest"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_ODOR_2702216183818705106)],
        &[(0b11001, &ENTRY_ODORED_16591159416202204717)],
        &[(0b11001, &ENTRY_ODORFUL_10183651138141826760)],
        &[(0b11001, &ENTRY_ODORFULLER_13227327083024783843)],
        &[(0b11001, &ENTRY_ODORFULLEST_561913207316625895)],
        &[(0b10010, &ENTRY_ODORIZE_872977924177419056)],
        &[(0b10010, &ENTRY_ODORIZED_18414489297080773534)],
        &[(0b10010, &ENTRY_ODORIZER_5204041533476108502)],
        &[(0b10010, &ENTRY_ODORIZES_16793160564252381786)],
        &[(0b10010, &ENTRY_ODORIZING_1882846929730225949)],
        &[(0b01001, &ENTRY_ODORIZE_872977924177419056)],
        &[(0b01001, &ENTRY_ODORIZED_18414489297080773534)],
        &[(0b01001, &ENTRY_ODORIZER_5204041533476108502)],
        &[(0b01001, &ENTRY_ODORIZES_16793160564252381786)],
        &[(0b01001, &ENTRY_ODORIZING_1882846929730225949)],
        &[(0b11001, &ENTRY_ODORLESS_16700169054217746196)],
        &[(0b11001, &ENTRY_ODORLESSER_9186460254240088489)],
        &[(0b11001, &ENTRY_ODORLESSES_2783434654756197474)],
        &[(0b11001, &ENTRY_ODORLESSEST_9571347228428809475)],
        &[(0b11001, &ENTRY_ODORS_1722093147325611045)],
        &[(0b11010, &ENTRY_ODOR_2702216183818705106)],
        &[(0b11010, &ENTRY_ODORED_16591159416202204717)],
        &[(0b11010, &ENTRY_ODORFUL_10183651138141826760)],
        &[(0b11010, &ENTRY_ODORFULLER_13227327083024783843)],
        &[(0b11010, &ENTRY_ODORFULLEST_561913207316625895)],
        &[(0b11010, &ENTRY_ODORLESS_16700169054217746196)],
        &[(0b11010, &ENTRY_ODORLESSER_9186460254240088489)],
        &[(0b11010, &ENTRY_ODORLESSES_2783434654756197474)],
        &[(0b11010, &ENTRY_ODORLESSEST_9571347228428809475)],
        &[(0b11010, &ENTRY_ODORS_1722093147325611045)],
    ],
    range: 2..=10,
};

static VARS_OC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OC_CHILDREN),
    value: None,
};

pub static VARS_OC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cidentalisation"),
        dictgen::InsensitiveStr::Ascii("cidentalisations"),
        dictgen::InsensitiveStr::Ascii("cidentalise"),
        dictgen::InsensitiveStr::Ascii("cidentalised"),
        dictgen::InsensitiveStr::Ascii("cidentalises"),
        dictgen::InsensitiveStr::Ascii("cidentalising"),
        dictgen::InsensitiveStr::Ascii("cidentalization"),
        dictgen::InsensitiveStr::Ascii("cidentalizations"),
        dictgen::InsensitiveStr::Ascii("cidentalize"),
        dictgen::InsensitiveStr::Ascii("cidentalized"),
        dictgen::InsensitiveStr::Ascii("cidentalizes"),
        dictgen::InsensitiveStr::Ascii("cidentalizing"),
        dictgen::InsensitiveStr::Ascii("her"),
        dictgen::InsensitiveStr::Ascii("hered"),
        dictgen::InsensitiveStr::Ascii("hering"),
        dictgen::InsensitiveStr::Ascii("herish"),
        dictgen::InsensitiveStr::Ascii("herous"),
        dictgen::InsensitiveStr::Ascii("herouser"),
        dictgen::InsensitiveStr::Ascii("herousest"),
        dictgen::InsensitiveStr::Ascii("herrer"),
        dictgen::InsensitiveStr::Ascii("herrest"),
        dictgen::InsensitiveStr::Ascii("hers"),
        dictgen::InsensitiveStr::Ascii("hery"),
        dictgen::InsensitiveStr::Ascii("hre"),
        dictgen::InsensitiveStr::Ascii("hred"),
        dictgen::InsensitiveStr::Ascii("hreish"),
        dictgen::InsensitiveStr::Ascii("hrer"),
        dictgen::InsensitiveStr::Ascii("hres"),
        dictgen::InsensitiveStr::Ascii("hrest"),
        dictgen::InsensitiveStr::Ascii("hrey"),
        dictgen::InsensitiveStr::Ascii("hring"),
        dictgen::InsensitiveStr::Ascii("yrrhoae"),
        dictgen::InsensitiveStr::Ascii("yrrhoe"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OCCIDENTALIZATION_15524974948175552775)],
        &[(0b10010, &ENTRY_OCCIDENTALIZATIONS_17139435434038991612)],
        &[(0b10010, &ENTRY_OCCIDENTALIZE_10589550920412342970)],
        &[(0b10010, &ENTRY_OCCIDENTALIZED_13409124988057556187)],
        &[(0b10010, &ENTRY_OCCIDENTALIZES_15812493525050066801)],
        &[(0b10010, &ENTRY_OCCIDENTALIZING_6771021046622848919)],
        &[(0b01001, &ENTRY_OCCIDENTALIZATION_15524974948175552775)],
        &[(0b01001, &ENTRY_OCCIDENTALIZATIONS_17139435434038991612)],
        &[(0b01001, &ENTRY_OCCIDENTALIZE_10589550920412342970)],
        &[(0b01001, &ENTRY_OCCIDENTALIZED_13409124988057556187)],
        &[(0b01001, &ENTRY_OCCIDENTALIZES_15812493525050066801)],
        &[(0b01001, &ENTRY_OCCIDENTALIZING_6771021046622848919)],
        &[(0b00001, &ENTRY_OCHER_17256686823220191412)],
        &[(0b00001, &ENTRY_OCHERED_16675172852225671937)],
        &[(0b00001, &ENTRY_OCHERING_14121606727366800680)],
        &[(0b00001, &ENTRY_OCHERISH_15629897168603851362)],
        &[(0b00001, &ENTRY_OCHEROUS_7457653784346760110)],
        &[(0b00001, &ENTRY_OCHEROUSER_9548217901029813754)],
        &[(0b00001, &ENTRY_OCHEROUSEST_9550248650160884919)],
        &[(0b00001, &ENTRY_OCHERRER_16308994947056150512)],
        &[(0b00001, &ENTRY_OCHERREST_7388621669374657137)],
        &[(0b00001, &ENTRY_OCHERS_4760067737965399289)],
        &[(0b00001, &ENTRY_OCHERY_8176749558188989833)],
        &[(0b11010, &ENTRY_OCHER_17256686823220191412)],
        &[(0b11010, &ENTRY_OCHERED_16675172852225671937)],
        &[(0b11010, &ENTRY_OCHERISH_15629897168603851362)],
        &[(0b11010, &ENTRY_OCHERRER_16308994947056150512)],
        &[(0b11010, &ENTRY_OCHERS_4760067737965399289)],
        &[(0b11010, &ENTRY_OCHERREST_7388621669374657137)],
        &[(0b11010, &ENTRY_OCHERY_8176749558188989833)],
        &[(0b11010, &ENTRY_OCHERING_14121606727366800680)],
        &[(0b11010, &ENTRY_OCYRRHOE_6375534256118272896)],
        &[(0b00001, &ENTRY_OCYRRHOE_6375534256118272896)],
    ],
    range: 3..=16,
};

static VARS_OB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OB_CHILDREN),
    value: None,
};

pub static VARS_OB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elising"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("elizing"),
        dictgen::InsensitiveStr::Ascii("jectisation"),
        dictgen::InsensitiveStr::Ascii("jectisations"),
        dictgen::InsensitiveStr::Ascii("jectise"),
        dictgen::InsensitiveStr::Ascii("jectises"),
        dictgen::InsensitiveStr::Ascii("jectivise"),
        dictgen::InsensitiveStr::Ascii("jectivised"),
        dictgen::InsensitiveStr::Ascii("jectivises"),
        dictgen::InsensitiveStr::Ascii("jectivising"),
        dictgen::InsensitiveStr::Ascii("jectivize"),
        dictgen::InsensitiveStr::Ascii("jectivized"),
        dictgen::InsensitiveStr::Ascii("jectivizes"),
        dictgen::InsensitiveStr::Ascii("jectivizing"),
        dictgen::InsensitiveStr::Ascii("jectization"),
        dictgen::InsensitiveStr::Ascii("jectizations"),
        dictgen::InsensitiveStr::Ascii("jectize"),
        dictgen::InsensitiveStr::Ascii("jectizes"),
        dictgen::InsensitiveStr::Ascii("livionise"),
        dictgen::InsensitiveStr::Ascii("livionises"),
        dictgen::InsensitiveStr::Ascii("livionize"),
        dictgen::InsensitiveStr::Ascii("livionizes"),
        dictgen::InsensitiveStr::Ascii("oe"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OBE_1507663346832934200)],
        &[(0b10010, &ENTRY_OBELIZE_6489558286080618836)],
        &[(0b10010, &ENTRY_OBELIZED_5205778799169039990)],
        &[(0b10010, &ENTRY_OBELIZES_716031993831418076)],
        &[(0b10010, &ENTRY_OBELIZING_11436948508699926722)],
        &[(0b01001, &ENTRY_OBELIZE_6489558286080618836)],
        &[(0b01001, &ENTRY_OBELIZED_5205778799169039990)],
        &[(0b01001, &ENTRY_OBELIZES_716031993831418076)],
        &[(0b01001, &ENTRY_OBELIZING_11436948508699926722)],
        &[(0b10010, &ENTRY_OBJECTIZATION_7865667227742220120)],
        &[(0b10010, &ENTRY_OBJECTIZATIONS_5369909600107239746)],
        &[(0b10010, &ENTRY_OBJECTIZE_1941703412324553040)],
        &[(0b10010, &ENTRY_OBJECTIZES_8079723669956332188)],
        &[(0b10010, &ENTRY_OBJECTIVIZE_17947776649437604843)],
        &[(0b10010, &ENTRY_OBJECTIVIZED_15413360897315336968)],
        &[(0b10010, &ENTRY_OBJECTIVIZES_9105568866369059029)],
        &[(0b10010, &ENTRY_OBJECTIVIZING_12654258354920210911)],
        &[(0b01001, &ENTRY_OBJECTIVIZE_17947776649437604843)],
        &[(0b01001, &ENTRY_OBJECTIVIZED_15413360897315336968)],
        &[(0b01001, &ENTRY_OBJECTIVIZES_9105568866369059029)],
        &[(0b01001, &ENTRY_OBJECTIVIZING_12654258354920210911)],
        &[(0b01001, &ENTRY_OBJECTIZATION_7865667227742220120)],
        &[(0b01001, &ENTRY_OBJECTIZATIONS_5369909600107239746)],
        &[(0b01001, &ENTRY_OBJECTIZE_1941703412324553040)],
        &[(0b01001, &ENTRY_OBJECTIZES_8079723669956332188)],
        &[(0b10010, &ENTRY_OBLIVIONIZE_7661904693925296298)],
        &[(0b10010, &ENTRY_OBLIVIONIZES_16152353056435754063)],
        &[(0b01001, &ENTRY_OBLIVIONIZE_7661904693925296298)],
        &[(0b01001, &ENTRY_OBLIVIONIZES_16152353056435754063)],
        &[(0b11010, &ENTRY_OBE_1507663346832934200)],
    ],
    range: 1..=12,
};

static VARS_N_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_N_CHILDREN),
    value: None,
};

static VARS_N_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_NA_NODE),
    None,
    None,
    None,
    Some(&VARS_NE_NODE),
    None,
    None,
    None,
    Some(&VARS_NI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_NO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_NU_NODE),
    None,
    None,
    None,
    Some(&VARS_NY_NODE),
    None,
];

static VARS_NY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NY_CHILDREN),
    value: None,
};

pub static VARS_NY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mphaeum"),
        dictgen::InsensitiveStr::Ascii("mpheum"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NYMPHEUM_11562010131373678409)],
        &[(0b00001, &ENTRY_NYMPHEUM_11562010131373678409)],
    ],
    range: 6..=7,
};

static VARS_NU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NU_CHILDREN),
    value: None,
};

pub static VARS_NU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("clearisation"),
        dictgen::InsensitiveStr::Ascii("clearisations"),
        dictgen::InsensitiveStr::Ascii("clearise"),
        dictgen::InsensitiveStr::Ascii("clearised"),
        dictgen::InsensitiveStr::Ascii("clearises"),
        dictgen::InsensitiveStr::Ascii("clearising"),
        dictgen::InsensitiveStr::Ascii("clearization"),
        dictgen::InsensitiveStr::Ascii("clearizations"),
        dictgen::InsensitiveStr::Ascii("clearize"),
        dictgen::InsensitiveStr::Ascii("clearized"),
        dictgen::InsensitiveStr::Ascii("clearizes"),
        dictgen::InsensitiveStr::Ascii("clearizing"),
        dictgen::InsensitiveStr::Ascii("ptialise"),
        dictgen::InsensitiveStr::Ascii("ptialises"),
        dictgen::InsensitiveStr::Ascii("ptialize"),
        dictgen::InsensitiveStr::Ascii("ptializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NUCLEARIZATION_15701379174589299721)],
        &[(0b10010, &ENTRY_NUCLEARIZATIONS_14289779087630955640)],
        &[(0b10010, &ENTRY_NUCLEARIZE_16873979658884021829)],
        &[(0b10010, &ENTRY_NUCLEARIZED_6673795548622925030)],
        &[(0b10010, &ENTRY_NUCLEARIZES_5460600536427785035)],
        &[(0b10010, &ENTRY_NUCLEARIZING_15786741416474645245)],
        &[(0b01001, &ENTRY_NUCLEARIZATION_15701379174589299721)],
        &[(0b01001, &ENTRY_NUCLEARIZATIONS_14289779087630955640)],
        &[(0b01001, &ENTRY_NUCLEARIZE_16873979658884021829)],
        &[(0b01001, &ENTRY_NUCLEARIZED_6673795548622925030)],
        &[(0b01001, &ENTRY_NUCLEARIZES_5460600536427785035)],
        &[(0b01001, &ENTRY_NUCLEARIZING_15786741416474645245)],
        &[(0b10010, &ENTRY_NUPTIALIZE_1486337558182989700)],
        &[(0b10010, &ENTRY_NUPTIALIZES_10810848802613002169)],
        &[(0b01001, &ENTRY_NUPTIALIZE_1486337558182989700)],
        &[(0b01001, &ENTRY_NUPTIALIZES_10810848802613002169)],
    ],
    range: 8..=13,
};

static VARS_NO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_NO_CHILDREN),
    value: None,
};

static VARS_NO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_NOA_NODE),
    None,
    None,
    Some(&VARS_NOD_NODE),
    Some(&VARS_NOE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_NOM_NODE),
    Some(&VARS_NON_NODE),
    None,
    None,
    None,
    Some(&VARS_NOR_NODE),
    Some(&VARS_NOS_NODE),
    Some(&VARS_NOT_NODE),
    Some(&VARS_NOU_NODE),
    Some(&VARS_NOV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_NOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOV_CHILDREN),
    value: None,
};

pub static VARS_NOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elisation"),
        dictgen::InsensitiveStr::Ascii("elisations"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("eliser"),
        dictgen::InsensitiveStr::Ascii("elisers"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elising"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elizations"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elizer"),
        dictgen::InsensitiveStr::Ascii("elizers"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("elizing"),
        dictgen::InsensitiveStr::Ascii("enae"),
        dictgen::InsensitiveStr::Ascii("ene"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NOVELIZATION_21718915207717005)],
        &[(0b10010, &ENTRY_NOVELIZATIONS_3735074127764106015)],
        &[(0b10010, &ENTRY_NOVELIZE_9678275742447267508)],
        &[(0b10010, &ENTRY_NOVELIZED_15738528375210454895)],
        &[(0b10010, &ENTRY_NOVELIZER_15766315188431000536)],
        &[(0b10010, &ENTRY_NOVELIZERS_16950317005606382575)],
        &[(0b10010, &ENTRY_NOVELIZES_4390292103638708970)],
        &[(0b10010, &ENTRY_NOVELIZING_8236112411426222682)],
        &[(0b01001, &ENTRY_NOVELIZATION_21718915207717005)],
        &[(0b01001, &ENTRY_NOVELIZATIONS_3735074127764106015)],
        &[(0b01001, &ENTRY_NOVELIZE_9678275742447267508)],
        &[(0b01001, &ENTRY_NOVELIZED_15738528375210454895)],
        &[(0b01001, &ENTRY_NOVELIZER_15766315188431000536)],
        &[(0b01001, &ENTRY_NOVELIZERS_16950317005606382575)],
        &[(0b01001, &ENTRY_NOVELIZES_4390292103638708970)],
        &[(0b01001, &ENTRY_NOVELIZING_8236112411426222682)],
        &[(0b11010, &ENTRY_NOVENE_8369049316963603721)],
        &[(0b00001, &ENTRY_NOVENE_8369049316963603721)],
    ],
    range: 3..=10,
};

static VARS_NOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOU_CHILDREN),
    value: None,
};

pub static VARS_NOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("rice"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NOUNIZE_4724905253679159672)],
        &[(0b10010, &ENTRY_NOUNIZES_1623788942254245780)],
        &[(0b01001, &ENTRY_NOUNIZE_4724905253679159672)],
        &[(0b01001, &ENTRY_NOUNIZES_1623788942254245780)],
        &[(0b11010, &ENTRY_NORICE_11649257481922397534)],
    ],
    range: 4..=5,
};

static VARS_NOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOT_CHILDREN),
    value: None,
};

pub static VARS_NOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arisation"),
        dictgen::InsensitiveStr::Ascii("arisations"),
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arised"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arising"),
        dictgen::InsensitiveStr::Ascii("arization"),
        dictgen::InsensitiveStr::Ascii("arizations"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arized"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("arizing"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("hingise"),
        dictgen::InsensitiveStr::Ascii("hingises"),
        dictgen::InsensitiveStr::Ascii("hingize"),
        dictgen::InsensitiveStr::Ascii("hingizes"),
        dictgen::InsensitiveStr::Ascii("ogaea"),
        dictgen::InsensitiveStr::Ascii("ogea"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NOTARIZATION_8951353232118053302)],
        &[(0b10010, &ENTRY_NOTARIZATIONS_16318755198604086001)],
        &[(0b11010, &ENTRY_NOTARIZE_14995362902294634015)],
        &[(0b11010, &ENTRY_NOTARIZED_5329696136884282809)],
        &[(0b11010, &ENTRY_NOTARIZES_9436796973316272397)],
        &[(0b11010, &ENTRY_NOTARIZING_5636125110527307987)],
        &[(0b01001, &ENTRY_NOTARIZATION_8951353232118053302)],
        &[(0b01001, &ENTRY_NOTARIZATIONS_16318755198604086001)],
        &[(0b01001, &ENTRY_NOTARIZE_14995362902294634015)],
        &[(0b01001, &ENTRY_NOTARIZED_5329696136884282809)],
        &[(0b01001, &ENTRY_NOTARIZES_9436796973316272397)],
        &[(0b01001, &ENTRY_NOTARIZING_5636125110527307987)],
        &[(0b00001, &ENTRY_NOTER_7982355487050318652)],
        &[(0b10010, &ENTRY_NOTHINGIZE_2529018495677046007)],
        &[(0b10010, &ENTRY_NOTHINGIZES_8887372277211243227)],
        &[(0b01001, &ENTRY_NOTHINGIZE_2529018495677046007)],
        &[(0b01001, &ENTRY_NOTHINGIZES_8887372277211243227)],
        &[(0b11010, &ENTRY_NOTOGEA_12842356277236712449)],
        &[(0b00001, &ENTRY_NOTOGEA_12842356277236712449)],
        &[(0b11010, &ENTRY_NOTER_7982355487050318652)],
    ],
    range: 2..=10,
};

static VARS_NOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOS_CHILDREN),
    value: None,
};

pub static VARS_NOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ey"),
        dictgen::InsensitiveStr::Ascii("eys"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ohaemia"),
        dictgen::InsensitiveStr::Ascii("ohemia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NOSY_1009929718367174024)],
        &[(0b11010, &ENTRY_NOSIES_15482746754024260075)],
        &[(0b10010, &ENTRY_NOSIZE_14624422945441670096)],
        &[(0b01001, &ENTRY_NOSIZE_14624422945441670096)],
        &[(0b11010, &ENTRY_NOSOHEMIA_1514931224404468711)],
        &[(0b10001, &ENTRY_NOSOHEMIA_1514931224404468711)],
    ],
    range: 2..=7,
};

static VARS_NOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOR_CHILDREN),
    value: None,
};

pub static VARS_NOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ice"),
        dictgen::InsensitiveStr::Ascii("malisable"),
        dictgen::InsensitiveStr::Ascii("malisation"),
        dictgen::InsensitiveStr::Ascii("malisations"),
        dictgen::InsensitiveStr::Ascii("malise"),
        dictgen::InsensitiveStr::Ascii("malised"),
        dictgen::InsensitiveStr::Ascii("maliser"),
        dictgen::InsensitiveStr::Ascii("malisers"),
        dictgen::InsensitiveStr::Ascii("malises"),
        dictgen::InsensitiveStr::Ascii("malising"),
        dictgen::InsensitiveStr::Ascii("malizable"),
        dictgen::InsensitiveStr::Ascii("malization"),
        dictgen::InsensitiveStr::Ascii("malizations"),
        dictgen::InsensitiveStr::Ascii("malize"),
        dictgen::InsensitiveStr::Ascii("malized"),
        dictgen::InsensitiveStr::Ascii("malizer"),
        dictgen::InsensitiveStr::Ascii("malizers"),
        dictgen::InsensitiveStr::Ascii("malizes"),
        dictgen::InsensitiveStr::Ascii("malizing"),
        dictgen::InsensitiveStr::Ascii("manisation"),
        dictgen::InsensitiveStr::Ascii("manisations"),
        dictgen::InsensitiveStr::Ascii("manise"),
        dictgen::InsensitiveStr::Ascii("manised"),
        dictgen::InsensitiveStr::Ascii("maniser"),
        dictgen::InsensitiveStr::Ascii("manisers"),
        dictgen::InsensitiveStr::Ascii("manises"),
        dictgen::InsensitiveStr::Ascii("manising"),
        dictgen::InsensitiveStr::Ascii("manization"),
        dictgen::InsensitiveStr::Ascii("manizations"),
        dictgen::InsensitiveStr::Ascii("manize"),
        dictgen::InsensitiveStr::Ascii("manized"),
        dictgen::InsensitiveStr::Ascii("manizer"),
        dictgen::InsensitiveStr::Ascii("manizers"),
        dictgen::InsensitiveStr::Ascii("manizes"),
        dictgen::InsensitiveStr::Ascii("manizing"),
        dictgen::InsensitiveStr::Ascii("thernise"),
        dictgen::InsensitiveStr::Ascii("thernised"),
        dictgen::InsensitiveStr::Ascii("thernises"),
        dictgen::InsensitiveStr::Ascii("thernising"),
        dictgen::InsensitiveStr::Ascii("thernize"),
        dictgen::InsensitiveStr::Ascii("thernized"),
        dictgen::InsensitiveStr::Ascii("thernizes"),
        dictgen::InsensitiveStr::Ascii("thernizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NORICE_11649257481922397534)],
        &[(0b10010, &ENTRY_NORMALIZABLE_14256375385440464739)],
        &[(0b10010, &ENTRY_NORMALIZATION_1763771903231509736)],
        &[(0b10010, &ENTRY_NORMALIZATIONS_6086334685841165071)],
        &[(0b10010, &ENTRY_NORMALIZE_17937494001703948277)],
        &[(0b10010, &ENTRY_NORMALIZED_13905640716588216801)],
        &[(0b10010, &ENTRY_NORMALIZER_6185815349658447968)],
        &[(0b10010, &ENTRY_NORMALIZERS_9242854506371928930)],
        &[(0b10010, &ENTRY_NORMALIZES_11815977506135648870)],
        &[(0b10010, &ENTRY_NORMALIZING_8454204097903734518)],
        &[(0b01001, &ENTRY_NORMALIZABLE_14256375385440464739)],
        &[(0b01001, &ENTRY_NORMALIZATION_1763771903231509736)],
        &[(0b01001, &ENTRY_NORMALIZATIONS_6086334685841165071)],
        &[(0b01001, &ENTRY_NORMALIZE_17937494001703948277)],
        &[(0b01001, &ENTRY_NORMALIZED_13905640716588216801)],
        &[(0b01001, &ENTRY_NORMALIZER_6185815349658447968)],
        &[(0b01001, &ENTRY_NORMALIZERS_9242854506371928930)],
        &[(0b01001, &ENTRY_NORMALIZES_11815977506135648870)],
        &[(0b01001, &ENTRY_NORMALIZING_8454204097903734518)],
        &[(0b10010, &ENTRY_NORMANIZATION_6961828407816376561)],
        &[(0b10010, &ENTRY_NORMANIZATIONS_9277423991706179990)],
        &[(0b10010, &ENTRY_NORMANIZE_2965443577391748183)],
        &[(0b10010, &ENTRY_NORMANIZED_14551932295476748760)],
        &[(0b10010, &ENTRY_NORMANIZER_5080941412143667065)],
        &[(0b10010, &ENTRY_NORMANIZERS_12925142031749146670)],
        &[(0b10010, &ENTRY_NORMANIZES_16041441689197564016)],
        &[(0b10010, &ENTRY_NORMANIZING_10483194032455928026)],
        &[(0b01001, &ENTRY_NORMANIZATION_6961828407816376561)],
        &[(0b01001, &ENTRY_NORMANIZATIONS_9277423991706179990)],
        &[(0b01001, &ENTRY_NORMANIZE_2965443577391748183)],
        &[(0b01001, &ENTRY_NORMANIZED_14551932295476748760)],
        &[(0b01001, &ENTRY_NORMANIZER_5080941412143667065)],
        &[(0b01001, &ENTRY_NORMANIZERS_12925142031749146670)],
        &[(0b01001, &ENTRY_NORMANIZES_16041441689197564016)],
        &[(0b01001, &ENTRY_NORMANIZING_10483194032455928026)],
        &[(0b10010, &ENTRY_NORTHERNIZE_9212991273136137117)],
        &[(0b10010, &ENTRY_NORTHERNIZED_13771447161233484057)],
        &[(0b10010, &ENTRY_NORTHERNIZES_11095974865864372366)],
        &[(0b10010, &ENTRY_NORTHERNIZING_7618561667513786062)],
        &[(0b01001, &ENTRY_NORTHERNIZE_9212991273136137117)],
        &[(0b01001, &ENTRY_NORTHERNIZED_13771447161233484057)],
        &[(0b01001, &ENTRY_NORTHERNIZES_11095974865864372366)],
        &[(0b01001, &ENTRY_NORTHERNIZING_7618561667513786062)],
    ],
    range: 3..=11,
};

static VARS_NON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_NON_CHILDREN),
    value: None,
};

static VARS_NON_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_NONA_NODE),
    None,
    Some(&VARS_NONC_NODE),
    Some(&VARS_NOND_NODE),
    Some(&VARS_NONE_NODE),
    Some(&VARS_NONF_NODE),
    Some(&VARS_NONG_NODE),
    Some(&VARS_NONH_NODE),
    Some(&VARS_NONI_NODE),
    None,
    None,
    Some(&VARS_NONL_NODE),
    Some(&VARS_NONM_NODE),
    Some(&VARS_NONN_NODE),
    Some(&VARS_NONO_NODE),
    Some(&VARS_NONP_NODE),
    None,
    Some(&VARS_NONR_NODE),
    Some(&VARS_NONS_NODE),
    Some(&VARS_NONT_NODE),
    Some(&VARS_NONU_NODE),
    Some(&VARS_NONV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_NONV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONV_CHILDREN),
    value: None,
};

pub static VARS_NONV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isualised"),
        dictgen::InsensitiveStr::Ascii("isualiseds"),
        dictgen::InsensitiveStr::Ascii("isualized"),
        dictgen::InsensitiveStr::Ascii("isualizeds"),
        dictgen::InsensitiveStr::Ascii("olatilised"),
        dictgen::InsensitiveStr::Ascii("olatiliseds"),
        dictgen::InsensitiveStr::Ascii("olatilized"),
        dictgen::InsensitiveStr::Ascii("olatilizeds"),
        dictgen::InsensitiveStr::Ascii("ulcanisable"),
        dictgen::InsensitiveStr::Ascii("ulcanisables"),
        dictgen::InsensitiveStr::Ascii("ulcanizable"),
        dictgen::InsensitiveStr::Ascii("ulcanizables"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONVISUALIZED_4803694735487431704)],
        &[(0b10010, &ENTRY_NONVISUALIZEDS_321628249125916825)],
        &[(0b01001, &ENTRY_NONVISUALIZED_4803694735487431704)],
        &[(0b01001, &ENTRY_NONVISUALIZEDS_321628249125916825)],
        &[(0b10010, &ENTRY_NONVOLATILIZED_14122463800578325946)],
        &[(0b10010, &ENTRY_NONVOLATILIZEDS_9930790287842469013)],
        &[(0b01001, &ENTRY_NONVOLATILIZED_14122463800578325946)],
        &[(0b01001, &ENTRY_NONVOLATILIZEDS_9930790287842469013)],
        &[(0b10010, &ENTRY_NONVULCANIZABLE_5020601800715170726)],
        &[(0b10010, &ENTRY_NONVULCANIZABLES_1406568761218608134)],
        &[(0b01001, &ENTRY_NONVULCANIZABLE_5020601800715170726)],
        &[(0b01001, &ENTRY_NONVULCANIZABLES_1406568761218608134)],
    ],
    range: 9..=12,
};

static VARS_NONU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONU_CHILDREN),
    value: None,
};

pub static VARS_NONU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tilised"),
        dictgen::InsensitiveStr::Ascii("tiliseds"),
        dictgen::InsensitiveStr::Ascii("tilized"),
        dictgen::InsensitiveStr::Ascii("tilizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONUTILIZED_6977234052565107201)],
        &[(0b10010, &ENTRY_NONUTILIZEDS_16763392484212693985)],
        &[(0b01001, &ENTRY_NONUTILIZED_6977234052565107201)],
        &[(0b01001, &ENTRY_NONUTILIZEDS_16763392484212693985)],
    ],
    range: 7..=8,
};

static VARS_NONT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONT_CHILDREN),
    value: None,
};

pub static VARS_NONT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emporising"),
        dictgen::InsensitiveStr::Ascii("emporisings"),
        dictgen::InsensitiveStr::Ascii("emporizing"),
        dictgen::InsensitiveStr::Ascii("emporizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONTEMPORIZING_7482017649343591602)],
        &[(0b10010, &ENTRY_NONTEMPORIZINGS_11414232594298995489)],
        &[(0b01001, &ENTRY_NONTEMPORIZING_7482017649343591602)],
        &[(0b01001, &ENTRY_NONTEMPORIZINGS_11414232594298995489)],
    ],
    range: 10..=11,
};

static VARS_NONS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONS_CHILDREN),
    value: None,
};

pub static VARS_NONS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chematised"),
        dictgen::InsensitiveStr::Ascii("chematiseds"),
        dictgen::InsensitiveStr::Ascii("chematized"),
        dictgen::InsensitiveStr::Ascii("chematizeds"),
        dictgen::InsensitiveStr::Ascii("ensitised"),
        dictgen::InsensitiveStr::Ascii("ensitiseds"),
        dictgen::InsensitiveStr::Ascii("ensitized"),
        dictgen::InsensitiveStr::Ascii("ensitizeds"),
        dictgen::InsensitiveStr::Ascii("pecialised"),
        dictgen::InsensitiveStr::Ascii("pecialiseds"),
        dictgen::InsensitiveStr::Ascii("pecialized"),
        dictgen::InsensitiveStr::Ascii("pecializeds"),
        dictgen::InsensitiveStr::Ascii("tandardised"),
        dictgen::InsensitiveStr::Ascii("tandardiseds"),
        dictgen::InsensitiveStr::Ascii("tandardized"),
        dictgen::InsensitiveStr::Ascii("tandardizeds"),
        dictgen::InsensitiveStr::Ascii("tylised"),
        dictgen::InsensitiveStr::Ascii("tyliseds"),
        dictgen::InsensitiveStr::Ascii("tylized"),
        dictgen::InsensitiveStr::Ascii("tylizeds"),
        dictgen::InsensitiveStr::Ascii("uccor"),
        dictgen::InsensitiveStr::Ascii("uccour"),
        dictgen::InsensitiveStr::Ascii("ympathiser"),
        dictgen::InsensitiveStr::Ascii("ympathisers"),
        dictgen::InsensitiveStr::Ascii("ympathizer"),
        dictgen::InsensitiveStr::Ascii("ympathizers"),
        dictgen::InsensitiveStr::Ascii("ynthesised"),
        dictgen::InsensitiveStr::Ascii("ynthesiseds"),
        dictgen::InsensitiveStr::Ascii("ynthesized"),
        dictgen::InsensitiveStr::Ascii("ynthesizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONSCHEMATIZED_8632859639656826393)],
        &[(0b10010, &ENTRY_NONSCHEMATIZEDS_3534565221599326465)],
        &[(0b01001, &ENTRY_NONSCHEMATIZED_8632859639656826393)],
        &[(0b01001, &ENTRY_NONSCHEMATIZEDS_3534565221599326465)],
        &[(0b10010, &ENTRY_NONSENSITIZED_7636351124138354819)],
        &[(0b10010, &ENTRY_NONSENSITIZEDS_16265989731308339490)],
        &[(0b01001, &ENTRY_NONSENSITIZED_7636351124138354819)],
        &[(0b01001, &ENTRY_NONSENSITIZEDS_16265989731308339490)],
        &[(0b10010, &ENTRY_NONSPECIALIZED_16389043871429531385)],
        &[(0b10010, &ENTRY_NONSPECIALIZEDS_16267745606425806478)],
        &[(0b01001, &ENTRY_NONSPECIALIZED_16389043871429531385)],
        &[(0b01001, &ENTRY_NONSPECIALIZEDS_16267745606425806478)],
        &[(0b10010, &ENTRY_NONSTANDARDIZED_15278040731989517059)],
        &[(0b10010, &ENTRY_NONSTANDARDIZEDS_5050992934219440733)],
        &[(0b01001, &ENTRY_NONSTANDARDIZED_15278040731989517059)],
        &[(0b01001, &ENTRY_NONSTANDARDIZEDS_5050992934219440733)],
        &[(0b10010, &ENTRY_NONSTYLIZED_14411143336075924222)],
        &[(0b10010, &ENTRY_NONSTYLIZEDS_3245363354710554909)],
        &[(0b01001, &ENTRY_NONSTYLIZED_14411143336075924222)],
        &[(0b01001, &ENTRY_NONSTYLIZEDS_3245363354710554909)],
        &[(0b00001, &ENTRY_NONSUCCOR_6598579766592657596)],
        &[(0b11010, &ENTRY_NONSUCCOR_6598579766592657596)],
        &[(0b10010, &ENTRY_NONSYMPATHIZER_4965121140144675590)],
        &[(0b10010, &ENTRY_NONSYMPATHIZERS_10490688261674736888)],
        &[(0b01001, &ENTRY_NONSYMPATHIZER_4965121140144675590)],
        &[(0b01001, &ENTRY_NONSYMPATHIZERS_10490688261674736888)],
        &[(0b10010, &ENTRY_NONSYNTHESIZED_13512975394986317082)],
        &[(0b10010, &ENTRY_NONSYNTHESIZEDS_17024224519378347416)],
        &[(0b01001, &ENTRY_NONSYNTHESIZED_13512975394986317082)],
        &[(0b01001, &ENTRY_NONSYNTHESIZEDS_17024224519378347416)],
    ],
    range: 5..=12,
};

static VARS_NONR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONR_CHILDREN),
    value: None,
};

pub static VARS_NONR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ationalised"),
        dictgen::InsensitiveStr::Ascii("ationaliseds"),
        dictgen::InsensitiveStr::Ascii("ationalized"),
        dictgen::InsensitiveStr::Ascii("ationalizeds"),
        dictgen::InsensitiveStr::Ascii("ealisation"),
        dictgen::InsensitiveStr::Ascii("ealisations"),
        dictgen::InsensitiveStr::Ascii("ealization"),
        dictgen::InsensitiveStr::Ascii("ealizations"),
        dictgen::InsensitiveStr::Ascii("ecognised"),
        dictgen::InsensitiveStr::Ascii("ecogniseds"),
        dictgen::InsensitiveStr::Ascii("ecognized"),
        dictgen::InsensitiveStr::Ascii("ecognizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONRATIONALIZED_14252903993087392578)],
        &[(0b10010, &ENTRY_NONRATIONALIZEDS_12119683182893470771)],
        &[(0b01001, &ENTRY_NONRATIONALIZED_14252903993087392578)],
        &[(0b01001, &ENTRY_NONRATIONALIZEDS_12119683182893470771)],
        &[(0b10010, &ENTRY_NONREALIZATION_1085294749674131476)],
        &[(0b10010, &ENTRY_NONREALIZATIONS_9707907650171739948)],
        &[(0b01001, &ENTRY_NONREALIZATION_1085294749674131476)],
        &[(0b01001, &ENTRY_NONREALIZATIONS_9707907650171739948)],
        &[(0b10010, &ENTRY_NONRECOGNIZED_7144499538091654669)],
        &[(0b10010, &ENTRY_NONRECOGNIZEDS_7029223781209778460)],
        &[(0b01001, &ENTRY_NONRECOGNIZED_7144499538091654669)],
        &[(0b01001, &ENTRY_NONRECOGNIZEDS_7029223781209778460)],
    ],
    range: 9..=12,
};

static VARS_NONP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONP_CHILDREN),
    value: None,
};

pub static VARS_NONP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arlor"),
        dictgen::InsensitiveStr::Ascii("arlors"),
        dictgen::InsensitiveStr::Ascii("arlour"),
        dictgen::InsensitiveStr::Ascii("arlours"),
        dictgen::InsensitiveStr::Ascii("enalised"),
        dictgen::InsensitiveStr::Ascii("enaliseds"),
        dictgen::InsensitiveStr::Ascii("enalized"),
        dictgen::InsensitiveStr::Ascii("enalizeds"),
        dictgen::InsensitiveStr::Ascii("hosphorised"),
        dictgen::InsensitiveStr::Ascii("hosphoriseds"),
        dictgen::InsensitiveStr::Ascii("hosphorized"),
        dictgen::InsensitiveStr::Ascii("hosphorizeds"),
        dictgen::InsensitiveStr::Ascii("olarisable"),
        dictgen::InsensitiveStr::Ascii("olarisables"),
        dictgen::InsensitiveStr::Ascii("olarised"),
        dictgen::InsensitiveStr::Ascii("olarising"),
        dictgen::InsensitiveStr::Ascii("olarisings"),
        dictgen::InsensitiveStr::Ascii("olarizable"),
        dictgen::InsensitiveStr::Ascii("olarizables"),
        dictgen::InsensitiveStr::Ascii("olarized"),
        dictgen::InsensitiveStr::Ascii("olarizing"),
        dictgen::InsensitiveStr::Ascii("olarizings"),
    ],
    values: &[
        &[(0b10001, &ENTRY_NONPARLOR_2583560003148588775)],
        &[(0b10001, &ENTRY_NONPARLORS_1263265995512153061)],
        &[(0b11010, &ENTRY_NONPARLOR_2583560003148588775)],
        &[(0b11010, &ENTRY_NONPARLORS_1263265995512153061)],
        &[(0b10010, &ENTRY_NONPENALIZED_9938333688009159198)],
        &[(0b10010, &ENTRY_NONPENALIZEDS_14714048229201860516)],
        &[(0b01001, &ENTRY_NONPENALIZED_9938333688009159198)],
        &[(0b01001, &ENTRY_NONPENALIZEDS_14714048229201860516)],
        &[(0b10010, &ENTRY_NONPHOSPHORIZED_15226565697312913858)],
        &[(0b10010, &ENTRY_NONPHOSPHORIZEDS_10408290644367324425)],
        &[(0b01001, &ENTRY_NONPHOSPHORIZED_15226565697312913858)],
        &[(0b01001, &ENTRY_NONPHOSPHORIZEDS_10408290644367324425)],
        &[(0b10010, &ENTRY_NONPOLARIZABLE_6473533389464029696)],
        &[(0b10010, &ENTRY_NONPOLARIZABLES_14784416862913176760)],
        &[(0b10010, &ENTRY_NONPOLARIZED_9666868525356577877)],
        &[(0b10010, &ENTRY_NONPOLARIZING_10385047813105106287)],
        &[(0b10010, &ENTRY_NONPOLARIZINGS_10991174532515610089)],
        &[(0b01001, &ENTRY_NONPOLARIZABLE_6473533389464029696)],
        &[(0b01001, &ENTRY_NONPOLARIZABLES_14784416862913176760)],
        &[(0b01001, &ENTRY_NONPOLARIZED_9666868525356577877)],
        &[(0b01001, &ENTRY_NONPOLARIZING_10385047813105106287)],
        &[(0b01001, &ENTRY_NONPOLARIZINGS_10991174532515610089)],
    ],
    range: 5..=12,
};

static VARS_NONO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONO_CHILDREN),
    value: None,
};

pub static VARS_NONO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecumenic"),
        dictgen::InsensitiveStr::Ascii("ecumenical"),
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("xidisable"),
        dictgen::InsensitiveStr::Ascii("xidisables"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidisings"),
        dictgen::InsensitiveStr::Ascii("xidizable"),
        dictgen::InsensitiveStr::Ascii("xidizables"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
        dictgen::InsensitiveStr::Ascii("xidizings"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NONECUMENIC_15150105529473042099)],
        &[(0b11010, &ENTRY_NONECUMENICAL_810904659323722625)],
        &[(0b10010, &ENTRY_NONORGANIZATION_15261480439585844401)],
        &[(0b10010, &ENTRY_NONORGANIZATIONS_7584860267076573731)],
        &[(0b01001, &ENTRY_NONORGANIZATION_15261480439585844401)],
        &[(0b01001, &ENTRY_NONORGANIZATIONS_7584860267076573731)],
        &[(0b10010, &ENTRY_NONOXIDIZABLE_3176964828889782374)],
        &[(0b10010, &ENTRY_NONOXIDIZABLES_2491632333208328373)],
        &[(0b10010, &ENTRY_NONOXIDIZING_15441038092706737796)],
        &[(0b10010, &ENTRY_NONOXIDIZINGS_9315788901303966844)],
        &[(0b01001, &ENTRY_NONOXIDIZABLE_3176964828889782374)],
        &[(0b01001, &ENTRY_NONOXIDIZABLES_2491632333208328373)],
        &[(0b01001, &ENTRY_NONOXIDIZING_15441038092706737796)],
        &[(0b01001, &ENTRY_NONOXIDIZINGS_9315788901303966844)],
    ],
    range: 8..=12,
};

static VARS_NONN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONN_CHILDREN),
    value: None,
};

pub static VARS_NONN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itrogenised"),
        dictgen::InsensitiveStr::Ascii("itrogeniseds"),
        dictgen::InsensitiveStr::Ascii("itrogenized"),
        dictgen::InsensitiveStr::Ascii("itrogenizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONNITROGENIZED_6692106666255942926)],
        &[(0b10010, &ENTRY_NONNITROGENIZEDS_13860960024826722287)],
        &[(0b01001, &ENTRY_NONNITROGENIZED_6692106666255942926)],
        &[(0b01001, &ENTRY_NONNITROGENIZEDS_13860960024826722287)],
    ],
    range: 11..=12,
};

static VARS_NONM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONM_CHILDREN),
    value: None,
};

pub static VARS_NONM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agnetisable"),
        dictgen::InsensitiveStr::Ascii("agnetisables"),
        dictgen::InsensitiveStr::Ascii("agnetizable"),
        dictgen::InsensitiveStr::Ascii("agnetizables"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONMAGNETIZABLE_17141546560968815138)],
        &[(0b10010, &ENTRY_NONMAGNETIZABLES_7457992790204468436)],
        &[(0b01001, &ENTRY_NONMAGNETIZABLE_17141546560968815138)],
        &[(0b01001, &ENTRY_NONMAGNETIZABLES_7457992790204468436)],
    ],
    range: 11..=12,
};

static VARS_NONL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONL_CHILDREN),
    value: None,
};

pub static VARS_NONL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ocalised"),
        dictgen::InsensitiveStr::Ascii("ocaliseds"),
        dictgen::InsensitiveStr::Ascii("ocalized"),
        dictgen::InsensitiveStr::Ascii("ocalizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONLOCALIZED_8241380360957256875)],
        &[(0b10010, &ENTRY_NONLOCALIZEDS_2038148318593203679)],
        &[(0b01001, &ENTRY_NONLOCALIZED_8241380360957256875)],
        &[(0b01001, &ENTRY_NONLOCALIZEDS_2038148318593203679)],
    ],
    range: 8..=9,
};

static VARS_NONI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONI_CHILDREN),
    value: None,
};

pub static VARS_NONI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mmunised"),
        dictgen::InsensitiveStr::Ascii("mmuniseds"),
        dictgen::InsensitiveStr::Ascii("mmunized"),
        dictgen::InsensitiveStr::Ascii("mmunizeds"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniseds"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onisings"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizeds"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("onizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONIMMUNIZED_4590493450951603549)],
        &[(0b10010, &ENTRY_NONIMMUNIZEDS_2963611111727770694)],
        &[(0b01001, &ENTRY_NONIMMUNIZED_4590493450951603549)],
        &[(0b01001, &ENTRY_NONIMMUNIZEDS_2963611111727770694)],
        &[(0b10010, &ENTRY_NONIONIZED_17820724010194720017)],
        &[(0b10010, &ENTRY_NONIONIZEDS_5599188828242558716)],
        &[(0b10010, &ENTRY_NONIONIZING_12310413608399838371)],
        &[(0b10010, &ENTRY_NONIONIZINGS_5881375827446483087)],
        &[(0b01001, &ENTRY_NONIONIZED_17820724010194720017)],
        &[(0b01001, &ENTRY_NONIONIZEDS_5599188828242558716)],
        &[(0b01001, &ENTRY_NONIONIZING_12310413608399838371)],
        &[(0b01001, &ENTRY_NONIONIZINGS_5881375827446483087)],
    ],
    range: 6..=9,
};

static VARS_NONH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONH_CHILDREN),
    value: None,
};

pub static VARS_NONH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ydrolysable"),
        dictgen::InsensitiveStr::Ascii("ydrolysables"),
        dictgen::InsensitiveStr::Ascii("ydrolyzable"),
        dictgen::InsensitiveStr::Ascii("ydrolyzables"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NONHYDROLYZABLE_17320011376315732668)],
        &[(0b11010, &ENTRY_NONHYDROLYZABLES_1998067287234569229)],
        &[(0b00001, &ENTRY_NONHYDROLYZABLE_17320011376315732668)],
        &[(0b00001, &ENTRY_NONHYDROLYZABLES_1998067287234569229)],
    ],
    range: 11..=12,
};

static VARS_NONG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONG_CHILDREN),
    value: None,
};

pub static VARS_NONG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alvanised"),
        dictgen::InsensitiveStr::Ascii("alvaniseds"),
        dictgen::InsensitiveStr::Ascii("alvanized"),
        dictgen::InsensitiveStr::Ascii("alvanizeds"),
        dictgen::InsensitiveStr::Ascii("elatinising"),
        dictgen::InsensitiveStr::Ascii("elatinisings"),
        dictgen::InsensitiveStr::Ascii("elatinizing"),
        dictgen::InsensitiveStr::Ascii("elatinizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONGALVANIZED_11384392564239466868)],
        &[(0b10010, &ENTRY_NONGALVANIZEDS_8550940513824683889)],
        &[(0b01001, &ENTRY_NONGALVANIZED_11384392564239466868)],
        &[(0b01001, &ENTRY_NONGALVANIZEDS_8550940513824683889)],
        &[(0b10010, &ENTRY_NONGELATINIZING_5051984650375658405)],
        &[(0b10010, &ENTRY_NONGELATINIZINGS_4067743041157459041)],
        &[(0b01001, &ENTRY_NONGELATINIZING_5051984650375658405)],
        &[(0b01001, &ENTRY_NONGELATINIZINGS_4067743041157459041)],
    ],
    range: 9..=12,
};

static VARS_NONF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONF_CHILDREN),
    value: None,
};

pub static VARS_NONF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avorite"),
        dictgen::InsensitiveStr::Ascii("avorites"),
        dictgen::InsensitiveStr::Ascii("avourite"),
        dictgen::InsensitiveStr::Ascii("avourites"),
        dictgen::InsensitiveStr::Ascii("lavored"),
        dictgen::InsensitiveStr::Ascii("lavoured"),
        dictgen::InsensitiveStr::Ascii("ulfillment"),
        dictgen::InsensitiveStr::Ascii("ulfillments"),
        dictgen::InsensitiveStr::Ascii("ulfilment"),
        dictgen::InsensitiveStr::Ascii("ulfilments"),
    ],
    values: &[
        &[(0b10001, &ENTRY_NONFAVORITE_9212483996832040949)],
        &[(0b10001, &ENTRY_NONFAVORITES_16348199772317515957)],
        &[(0b11010, &ENTRY_NONFAVORITE_9212483996832040949)],
        &[(0b11010, &ENTRY_NONFAVORITES_16348199772317515957)],
        &[(0b10001, &ENTRY_NONFLAVORED_10494480100237219729)],
        &[(0b11010, &ENTRY_NONFLAVORED_10494480100237219729)],
        &[(0b00001, &ENTRY_NONFULFILLMENT_2709075420628011330)],
        &[(0b00001, &ENTRY_NONFULFILLMENTS_15135034110516785101)],
        &[(0b11010, &ENTRY_NONFULFILLMENT_2709075420628011330)],
        &[(0b11010, &ENTRY_NONFULFILLMENTS_15135034110516785101)],
    ],
    range: 7..=11,
};

static VARS_NONE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONE_CHILDREN),
    value: None,
};

pub static VARS_NONE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cumenic"),
        dictgen::InsensitiveStr::Ascii("cumenical"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
        dictgen::InsensitiveStr::Ascii("sthetical"),
        dictgen::InsensitiveStr::Ascii("sthetically"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NONECUMENIC_15150105529473042099)],
        &[(0b00001, &ENTRY_NONECUMENICAL_810904659323722625)],
        &[(0b00001, &ENTRY_NONESTHETIC_2666778020362669429)],
        &[(0b00001, &ENTRY_NONESTHETICAL_17133793059861648567)],
        &[(0b00001, &ENTRY_NONESTHETICALLY_9030761369515840292)],
    ],
    range: 7..=11,
};

static VARS_NOND_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOND_CHILDREN),
    value: None,
};

pub static VARS_NOND_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emobilisation"),
        dictgen::InsensitiveStr::Ascii("emobilisations"),
        dictgen::InsensitiveStr::Ascii("emobilization"),
        dictgen::InsensitiveStr::Ascii("emobilizations"),
        dictgen::InsensitiveStr::Ascii("ialysing"),
        dictgen::InsensitiveStr::Ascii("ialysings"),
        dictgen::InsensitiveStr::Ascii("ialyzing"),
        dictgen::InsensitiveStr::Ascii("ialyzings"),
        dictgen::InsensitiveStr::Ascii("imensionalise"),
        dictgen::InsensitiveStr::Ascii("imensionalised"),
        dictgen::InsensitiveStr::Ascii("imensionalize"),
        dictgen::InsensitiveStr::Ascii("imensionalized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONDEMOBILIZATION_11387355722360688339)],
        &[(0b10010, &ENTRY_NONDEMOBILIZATIONS_15826216627113214457)],
        &[(0b01001, &ENTRY_NONDEMOBILIZATION_11387355722360688339)],
        &[(0b01001, &ENTRY_NONDEMOBILIZATIONS_15826216627113214457)],
        &[(0b11010, &ENTRY_NONDIALYZING_8935478329511290197)],
        &[(0b11010, &ENTRY_NONDIALYZINGS_11543173817555613522)],
        &[(0b00001, &ENTRY_NONDIALYZING_8935478329511290197)],
        &[(0b00001, &ENTRY_NONDIALYZINGS_11543173817555613522)],
        &[(0b10010, &ENTRY_NONDIMENSIONALIZE_17818368850919719572)],
        &[(0b10010, &ENTRY_NONDIMENSIONALIZED_10355726740313798452)],
        &[(0b01001, &ENTRY_NONDIMENSIONALIZE_17818368850919719572)],
        &[(0b01001, &ENTRY_NONDIMENSIONALIZED_10355726740313798452)],
    ],
    range: 8..=14,
};

static VARS_NONC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONC_CHILDREN),
    value: None,
};

pub static VARS_NONC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anonisation"),
        dictgen::InsensitiveStr::Ascii("anonisations"),
        dictgen::InsensitiveStr::Ascii("anonization"),
        dictgen::InsensitiveStr::Ascii("anonizations"),
        dictgen::InsensitiveStr::Ascii("artelised"),
        dictgen::InsensitiveStr::Ascii("arteliseds"),
        dictgen::InsensitiveStr::Ascii("artelized"),
        dictgen::InsensitiveStr::Ascii("artelizeds"),
        dictgen::InsensitiveStr::Ascii("atechisable"),
        dictgen::InsensitiveStr::Ascii("atechisables"),
        dictgen::InsensitiveStr::Ascii("atechizable"),
        dictgen::InsensitiveStr::Ascii("atechizables"),
        dictgen::InsensitiveStr::Ascii("ivilised"),
        dictgen::InsensitiveStr::Ascii("iviliseds"),
        dictgen::InsensitiveStr::Ascii("ivilized"),
        dictgen::InsensitiveStr::Ascii("ivilizeds"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olorabilities"),
        dictgen::InsensitiveStr::Ascii("olorability"),
        dictgen::InsensitiveStr::Ascii("olorable"),
        dictgen::InsensitiveStr::Ascii("olorableness"),
        dictgen::InsensitiveStr::Ascii("olorables"),
        dictgen::InsensitiveStr::Ascii("olorablies"),
        dictgen::InsensitiveStr::Ascii("olorably"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("olorer"),
        dictgen::InsensitiveStr::Ascii("olorers"),
        dictgen::InsensitiveStr::Ascii("olorfast"),
        dictgen::InsensitiveStr::Ascii("oloring"),
        dictgen::InsensitiveStr::Ascii("olorings"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("olourabilities"),
        dictgen::InsensitiveStr::Ascii("olourability"),
        dictgen::InsensitiveStr::Ascii("olourable"),
        dictgen::InsensitiveStr::Ascii("olourableness"),
        dictgen::InsensitiveStr::Ascii("olourables"),
        dictgen::InsensitiveStr::Ascii("olourablies"),
        dictgen::InsensitiveStr::Ascii("olourably"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olourer"),
        dictgen::InsensitiveStr::Ascii("olourers"),
        dictgen::InsensitiveStr::Ascii("olourfast"),
        dictgen::InsensitiveStr::Ascii("olouring"),
        dictgen::InsensitiveStr::Ascii("olourings"),
        dictgen::InsensitiveStr::Ascii("olours"),
        dictgen::InsensitiveStr::Ascii("rystallisable"),
        dictgen::InsensitiveStr::Ascii("rystallisables"),
        dictgen::InsensitiveStr::Ascii("rystallised"),
        dictgen::InsensitiveStr::Ascii("rystalliseds"),
        dictgen::InsensitiveStr::Ascii("rystallising"),
        dictgen::InsensitiveStr::Ascii("rystallisings"),
        dictgen::InsensitiveStr::Ascii("rystallizable"),
        dictgen::InsensitiveStr::Ascii("rystallizables"),
        dictgen::InsensitiveStr::Ascii("rystallized"),
        dictgen::InsensitiveStr::Ascii("rystallizeds"),
        dictgen::InsensitiveStr::Ascii("rystallizing"),
        dictgen::InsensitiveStr::Ascii("rystallizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONCANONIZATION_445261145541333623)],
        &[(0b10010, &ENTRY_NONCANONIZATIONS_7638961939958144698)],
        &[(0b01001, &ENTRY_NONCANONIZATION_445261145541333623)],
        &[(0b01001, &ENTRY_NONCANONIZATIONS_7638961939958144698)],
        &[(0b10010, &ENTRY_NONCARTELIZED_6322002509020882794)],
        &[(0b10010, &ENTRY_NONCARTELIZEDS_17969407783152652717)],
        &[(0b01001, &ENTRY_NONCARTELIZED_6322002509020882794)],
        &[(0b01001, &ENTRY_NONCARTELIZEDS_17969407783152652717)],
        &[(0b10010, &ENTRY_NONCATECHIZABLE_10484851131855579792)],
        &[(0b10010, &ENTRY_NONCATECHIZABLES_1642435244323993126)],
        &[(0b01001, &ENTRY_NONCATECHIZABLE_10484851131855579792)],
        &[(0b01001, &ENTRY_NONCATECHIZABLES_1642435244323993126)],
        &[(0b10010, &ENTRY_NONCIVILIZED_6441644839637486277)],
        &[(0b10010, &ENTRY_NONCIVILIZEDS_1908754485486798836)],
        &[(0b01001, &ENTRY_NONCIVILIZED_6441644839637486277)],
        &[(0b01001, &ENTRY_NONCIVILIZEDS_1908754485486798836)],
        &[(0b10001, &ENTRY_NONCOLOR_3149179056960307443)],
        &[(0b10001, &ENTRY_NONCOLORABILITIES_4632001048163187739)],
        &[(0b10001, &ENTRY_NONCOLORABILITY_5533585286824786241)],
        &[(0b10001, &ENTRY_NONCOLORABLE_15709560648548694896)],
        &[(0b10001, &ENTRY_NONCOLORABLENESS_5261192976036412796)],
        &[(0b10001, &ENTRY_NONCOLORABLES_1727679389289748377)],
        &[(0b10001, &ENTRY_NONCOLORABLIES_5998817198041959004)],
        &[(0b10001, &ENTRY_NONCOLORABLY_3878269464585493782)],
        &[(0b10001, &ENTRY_NONCOLORED_2167088987541317140)],
        &[(0b10001, &ENTRY_NONCOLORER_17317229215012927154)],
        &[(0b10001, &ENTRY_NONCOLORERS_1139612663123614815)],
        &[(0b10001, &ENTRY_NONCOLORFAST_15726041912771117535)],
        &[(0b10001, &ENTRY_NONCOLORING_5917730754685432342)],
        &[(0b10001, &ENTRY_NONCOLORINGS_5298650017970611127)],
        &[(0b10001, &ENTRY_NONCOLORS_1933476685975670621)],
        &[(0b11010, &ENTRY_NONCOLOR_3149179056960307443)],
        &[(0b11010, &ENTRY_NONCOLORABILITIES_4632001048163187739)],
        &[(0b11010, &ENTRY_NONCOLORABILITY_5533585286824786241)],
        &[(0b11010, &ENTRY_NONCOLORABLE_15709560648548694896)],
        &[(0b11010, &ENTRY_NONCOLORABLENESS_5261192976036412796)],
        &[(0b11010, &ENTRY_NONCOLORABLES_1727679389289748377)],
        &[(0b11010, &ENTRY_NONCOLORABLIES_5998817198041959004)],
        &[(0b11010, &ENTRY_NONCOLORABLY_3878269464585493782)],
        &[(0b11010, &ENTRY_NONCOLORED_2167088987541317140)],
        &[(0b11010, &ENTRY_NONCOLORER_17317229215012927154)],
        &[(0b11010, &ENTRY_NONCOLORERS_1139612663123614815)],
        &[(0b11010, &ENTRY_NONCOLORFAST_15726041912771117535)],
        &[(0b11010, &ENTRY_NONCOLORING_5917730754685432342)],
        &[(0b11010, &ENTRY_NONCOLORINGS_5298650017970611127)],
        &[(0b11010, &ENTRY_NONCOLORS_1933476685975670621)],
        &[(0b10010, &ENTRY_NONCRYSTALLIZABLE_10372505411607325770)],
        &[(0b10010, &ENTRY_NONCRYSTALLIZABLES_18102046015913198078)],
        &[(0b10010, &ENTRY_NONCRYSTALLIZED_5605940453320328190)],
        &[(0b10010, &ENTRY_NONCRYSTALLIZEDS_1965011183723304686)],
        &[(0b10010, &ENTRY_NONCRYSTALLIZING_10201570469442349314)],
        &[(0b10010, &ENTRY_NONCRYSTALLIZINGS_17233992070596336023)],
        &[(0b01001, &ENTRY_NONCRYSTALLIZABLE_10372505411607325770)],
        &[(0b01001, &ENTRY_NONCRYSTALLIZABLES_18102046015913198078)],
        &[(0b01001, &ENTRY_NONCRYSTALLIZED_5605940453320328190)],
        &[(0b01001, &ENTRY_NONCRYSTALLIZEDS_1965011183723304686)],
        &[(0b01001, &ENTRY_NONCRYSTALLIZING_10201570469442349314)],
        &[(0b01001, &ENTRY_NONCRYSTALLIZINGS_17233992070596336023)],
    ],
    range: 4..=14,
};

static VARS_NONA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONA_CHILDREN),
    value: None,
};

pub static VARS_NONA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cknowledgement"),
        dictgen::InsensitiveStr::Ascii("cknowledgements"),
        dictgen::InsensitiveStr::Ascii("cknowledgment"),
        dictgen::InsensitiveStr::Ascii("cknowledgments"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
        dictgen::InsensitiveStr::Ascii("esthetical"),
        dictgen::InsensitiveStr::Ascii("esthetically"),
        dictgen::InsensitiveStr::Ascii("naemic"),
        dictgen::InsensitiveStr::Ascii("naesthetised"),
        dictgen::InsensitiveStr::Ascii("naesthetized"),
        dictgen::InsensitiveStr::Ascii("nemic"),
        dictgen::InsensitiveStr::Ascii("nesthetized"),
        dictgen::InsensitiveStr::Ascii("postatising"),
        dictgen::InsensitiveStr::Ascii("postatisings"),
        dictgen::InsensitiveStr::Ascii("postatizing"),
        dictgen::InsensitiveStr::Ascii("postatizings"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NONACKNOWLEDGMENT_10855774066809250441)],
        &[(0b11010, &ENTRY_NONACKNOWLEDGMENTS_12640036285499344454)],
        &[(0b00001, &ENTRY_NONACKNOWLEDGMENT_10855774066809250441)],
        &[(0b00001, &ENTRY_NONACKNOWLEDGMENTS_12640036285499344454)],
        &[(0b11010, &ENTRY_NONESTHETIC_2666778020362669429)],
        &[(0b11010, &ENTRY_NONESTHETICAL_17133793059861648567)],
        &[(0b11010, &ENTRY_NONESTHETICALLY_9030761369515840292)],
        &[(0b11010, &ENTRY_NONANEMIC_15444821350095455223)],
        &[(0b10010, &ENTRY_NONANESTHETIZED_9198347943161763514)],
        &[(0b01000, &ENTRY_NONANESTHETIZED_9198347943161763514)],
        &[(0b10001, &ENTRY_NONANEMIC_15444821350095455223)],
        &[(0b00001, &ENTRY_NONANESTHETIZED_9198347943161763514)],
        &[(0b10010, &ENTRY_NONAPOSTATIZING_17606338307706364018)],
        &[(0b10010, &ENTRY_NONAPOSTATIZINGS_16518298917775117568)],
        &[(0b01001, &ENTRY_NONAPOSTATIZING_17606338307706364018)],
        &[(0b01001, &ENTRY_NONAPOSTATIZINGS_16518298917775117568)],
    ],
    range: 5..=15,
};

static VARS_NOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOM_CHILDREN),
    value: None,
};

pub static VARS_NOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("adisation"),
        dictgen::InsensitiveStr::Ascii("adisations"),
        dictgen::InsensitiveStr::Ascii("adise"),
        dictgen::InsensitiveStr::Ascii("adised"),
        dictgen::InsensitiveStr::Ascii("adises"),
        dictgen::InsensitiveStr::Ascii("adising"),
        dictgen::InsensitiveStr::Ascii("adization"),
        dictgen::InsensitiveStr::Ascii("adizations"),
        dictgen::InsensitiveStr::Ascii("adize"),
        dictgen::InsensitiveStr::Ascii("adized"),
        dictgen::InsensitiveStr::Ascii("adizes"),
        dictgen::InsensitiveStr::Ascii("adizing"),
        dictgen::InsensitiveStr::Ascii("inalisation"),
        dictgen::InsensitiveStr::Ascii("inalisations"),
        dictgen::InsensitiveStr::Ascii("inalise"),
        dictgen::InsensitiveStr::Ascii("inalised"),
        dictgen::InsensitiveStr::Ascii("inalises"),
        dictgen::InsensitiveStr::Ascii("inalising"),
        dictgen::InsensitiveStr::Ascii("inalization"),
        dictgen::InsensitiveStr::Ascii("inalizations"),
        dictgen::InsensitiveStr::Ascii("inalize"),
        dictgen::InsensitiveStr::Ascii("inalized"),
        dictgen::InsensitiveStr::Ascii("inalizes"),
        dictgen::InsensitiveStr::Ascii("inalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NOMADIZATION_3726418886473657659)],
        &[(0b10010, &ENTRY_NOMADIZATIONS_14059871491871936323)],
        &[(0b10010, &ENTRY_NOMADIZE_7419521819158010147)],
        &[(0b10010, &ENTRY_NOMADIZED_17060101352980657463)],
        &[(0b10010, &ENTRY_NOMADIZES_7490658564095276952)],
        &[(0b10010, &ENTRY_NOMADIZING_2240078758612833075)],
        &[(0b01001, &ENTRY_NOMADIZATION_3726418886473657659)],
        &[(0b01001, &ENTRY_NOMADIZATIONS_14059871491871936323)],
        &[(0b01001, &ENTRY_NOMADIZE_7419521819158010147)],
        &[(0b01001, &ENTRY_NOMADIZED_17060101352980657463)],
        &[(0b01001, &ENTRY_NOMADIZES_7490658564095276952)],
        &[(0b01001, &ENTRY_NOMADIZING_2240078758612833075)],
        &[(0b10010, &ENTRY_NOMINALIZATION_15107108373532687182)],
        &[(0b10010, &ENTRY_NOMINALIZATIONS_17926119396970399435)],
        &[(0b10010, &ENTRY_NOMINALIZE_10111105335237024044)],
        &[(0b10010, &ENTRY_NOMINALIZED_9317987662267404083)],
        &[(0b10010, &ENTRY_NOMINALIZES_7590279431491000660)],
        &[(0b10010, &ENTRY_NOMINALIZING_17210085527679423974)],
        &[(0b01001, &ENTRY_NOMINALIZATION_15107108373532687182)],
        &[(0b01001, &ENTRY_NOMINALIZATIONS_17926119396970399435)],
        &[(0b01001, &ENTRY_NOMINALIZE_10111105335237024044)],
        &[(0b01001, &ENTRY_NOMINALIZED_9317987662267404083)],
        &[(0b01001, &ENTRY_NOMINALIZES_7590279431491000660)],
        &[(0b01001, &ENTRY_NOMINALIZING_17210085527679423974)],
    ],
    range: 5..=12,
};

static VARS_NOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOE_CHILDREN),
    value: None,
};

pub static VARS_NOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("mon")],
    values: &[&[(0b00001, &ENTRY_NOEMON_10873567031051101962)]],
    range: 3..=3,
};

static VARS_NOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOD_CHILDREN),
    value: None,
};

pub static VARS_NOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("ulise"),
        dictgen::InsensitiveStr::Ascii("ulises"),
        dictgen::InsensitiveStr::Ascii("ulize"),
        dictgen::InsensitiveStr::Ascii("ulizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NODALIZE_2482979525031615560)],
        &[(0b10010, &ENTRY_NODALIZED_16625400756956152734)],
        &[(0b10010, &ENTRY_NODALIZES_11438261223912295797)],
        &[(0b10010, &ENTRY_NODALIZING_3463035244214116724)],
        &[(0b01001, &ENTRY_NODALIZE_2482979525031615560)],
        &[(0b01001, &ENTRY_NODALIZED_16625400756956152734)],
        &[(0b01001, &ENTRY_NODALIZES_11438261223912295797)],
        &[(0b01001, &ENTRY_NODALIZING_3463035244214116724)],
        &[(0b10010, &ENTRY_NODULIZE_9262608488062865502)],
        &[(0b10010, &ENTRY_NODULIZES_8756363846466309349)],
        &[(0b01001, &ENTRY_NODULIZE_9262608488062865502)],
        &[(0b01001, &ENTRY_NODULIZES_8756363846466309349)],
    ],
    range: 5..=7,
};

static VARS_NOA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOA_CHILDREN),
    value: None,
};

pub static VARS_NOA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("emon")],
    values: &[&[(0b11010, &ENTRY_NOEMON_10873567031051101962)]],
    range: 4..=4,
};

static VARS_NI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_NI_CHILDREN),
    value: None,
};

static VARS_NI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_NIC_NODE),
    None,
    Some(&VARS_NIE_NODE),
    None,
    Some(&VARS_NIG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_NIP_NODE),
    None,
    None,
    None,
    Some(&VARS_NIT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_NIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NIT_CHILDREN),
    value: None,
};

pub static VARS_NIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("res"),
        dictgen::InsensitiveStr::Ascii("ridisation"),
        dictgen::InsensitiveStr::Ascii("ridisations"),
        dictgen::InsensitiveStr::Ascii("ridise"),
        dictgen::InsensitiveStr::Ascii("ridises"),
        dictgen::InsensitiveStr::Ascii("ridization"),
        dictgen::InsensitiveStr::Ascii("ridizations"),
        dictgen::InsensitiveStr::Ascii("ridize"),
        dictgen::InsensitiveStr::Ascii("ridizes"),
        dictgen::InsensitiveStr::Ascii("rogenisation"),
        dictgen::InsensitiveStr::Ascii("rogenisations"),
        dictgen::InsensitiveStr::Ascii("rogenise"),
        dictgen::InsensitiveStr::Ascii("rogenised"),
        dictgen::InsensitiveStr::Ascii("rogenises"),
        dictgen::InsensitiveStr::Ascii("rogenising"),
        dictgen::InsensitiveStr::Ascii("rogenization"),
        dictgen::InsensitiveStr::Ascii("rogenizations"),
        dictgen::InsensitiveStr::Ascii("rogenize"),
        dictgen::InsensitiveStr::Ascii("rogenized"),
        dictgen::InsensitiveStr::Ascii("rogenizes"),
        dictgen::InsensitiveStr::Ascii("rogenizing"),
        dictgen::InsensitiveStr::Ascii("roglycerin"),
        dictgen::InsensitiveStr::Ascii("roglycerins"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NIGHT_12445825267878435538)],
        &[(0b00001, &ENTRY_NITER_11730030586484906596)],
        &[(0b00001, &ENTRY_NITERS_15109525363766142335)],
        &[(0b00001, &ENTRY_NIGHTS_2853012648953157620)],
        &[(0b11010, &ENTRY_NITER_11730030586484906596)],
        &[(0b11010, &ENTRY_NITERS_15109525363766142335)],
        &[(0b10010, &ENTRY_NITRIDIZATION_16083845896083362416)],
        &[(0b10010, &ENTRY_NITRIDIZATIONS_2619922062168662007)],
        &[(0b10010, &ENTRY_NITRIDIZE_13544081686934658830)],
        &[(0b10010, &ENTRY_NITRIDIZES_1863459397472838518)],
        &[(0b01001, &ENTRY_NITRIDIZATION_16083845896083362416)],
        &[(0b01001, &ENTRY_NITRIDIZATIONS_2619922062168662007)],
        &[(0b01001, &ENTRY_NITRIDIZE_13544081686934658830)],
        &[(0b01001, &ENTRY_NITRIDIZES_1863459397472838518)],
        &[(0b10010, &ENTRY_NITROGENIZATION_14350056587973254157)],
        &[(0b10010, &ENTRY_NITROGENIZATIONS_17176486832772077313)],
        &[(0b10010, &ENTRY_NITROGENIZE_703235107353112890)],
        &[(0b10010, &ENTRY_NITROGENIZED_2806489925492009236)],
        &[(0b10010, &ENTRY_NITROGENIZES_13983524784279127593)],
        &[(0b10010, &ENTRY_NITROGENIZING_4171458431333219871)],
        &[(0b01001, &ENTRY_NITROGENIZATION_14350056587973254157)],
        &[(0b01001, &ENTRY_NITROGENIZATIONS_17176486832772077313)],
        &[(0b01001, &ENTRY_NITROGENIZE_703235107353112890)],
        &[(0b01001, &ENTRY_NITROGENIZED_2806489925492009236)],
        &[(0b01001, &ENTRY_NITROGENIZES_13983524784279127593)],
        &[(0b01001, &ENTRY_NITROGENIZING_4171458431333219871)],
        &[(0b01001, &ENTRY_NITROGLYCERIN_14614401800457155758)],
        &[(0b01001, &ENTRY_NITROGLYCERINS_868987947481490504)],
    ],
    range: 1..=13,
};

static VARS_NIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NIP_CHILDREN),
    value: None,
};

pub static VARS_NIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ponise"),
        dictgen::InsensitiveStr::Ascii("ponises"),
        dictgen::InsensitiveStr::Ascii("ponize"),
        dictgen::InsensitiveStr::Ascii("ponizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NIPPONIZE_4579132590160165644)],
        &[(0b10010, &ENTRY_NIPPONIZES_6554210241154895240)],
        &[(0b01001, &ENTRY_NIPPONIZE_4579132590160165644)],
        &[(0b01001, &ENTRY_NIPPONIZES_6554210241154895240)],
    ],
    range: 6..=7,
};

static VARS_NIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NIG_CHILDREN),
    value: None,
};

pub static VARS_NIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("gardise"),
        dictgen::InsensitiveStr::Ascii("gardised"),
        dictgen::InsensitiveStr::Ascii("gardises"),
        dictgen::InsensitiveStr::Ascii("gardising"),
        dictgen::InsensitiveStr::Ascii("gardize"),
        dictgen::InsensitiveStr::Ascii("gardized"),
        dictgen::InsensitiveStr::Ascii("gardizes"),
        dictgen::InsensitiveStr::Ascii("gardizing"),
        dictgen::InsensitiveStr::Ascii("htingalise"),
        dictgen::InsensitiveStr::Ascii("htingalises"),
        dictgen::InsensitiveStr::Ascii("htingalize"),
        dictgen::InsensitiveStr::Ascii("htingalizes"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NIGER_11201071166372852882)],
        &[(0b10010, &ENTRY_NIGGARDIZE_4254244204505193934)],
        &[(0b10010, &ENTRY_NIGGARDIZED_9427235700634115178)],
        &[(0b10010, &ENTRY_NIGGARDIZES_11798686653079866433)],
        &[(0b10010, &ENTRY_NIGGARDIZING_3373243570534227088)],
        &[(0b01001, &ENTRY_NIGGARDIZE_4254244204505193934)],
        &[(0b01001, &ENTRY_NIGGARDIZED_9427235700634115178)],
        &[(0b01001, &ENTRY_NIGGARDIZES_11798686653079866433)],
        &[(0b01001, &ENTRY_NIGGARDIZING_3373243570534227088)],
        &[(0b10010, &ENTRY_NIGHTINGALIZE_17142924367808523526)],
        &[(0b10010, &ENTRY_NIGHTINGALIZES_9830470880801498295)],
        &[(0b01001, &ENTRY_NIGHTINGALIZE_17142924367808523526)],
        &[(0b01001, &ENTRY_NIGHTINGALIZES_9830470880801498295)],
        &[(0b11010, &ENTRY_NIGER_11201071166372852882)],
    ],
    range: 2..=11,
};

static VARS_NIE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NIE_CHILDREN),
    value: None,
};

pub static VARS_NIE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("lloed"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NIELLED_9403053863620728097)],
        &[(0b11010, &ENTRY_NIELLED_9403053863620728097)],
    ],
    range: 4..=5,
};

static VARS_NIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NIC_CHILDREN),
    value: None,
};

pub static VARS_NIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("keled"),
        dictgen::InsensitiveStr::Ascii("keling"),
        dictgen::InsensitiveStr::Ascii("kelisation"),
        dictgen::InsensitiveStr::Ascii("kelisations"),
        dictgen::InsensitiveStr::Ascii("kelise"),
        dictgen::InsensitiveStr::Ascii("kelised"),
        dictgen::InsensitiveStr::Ascii("kelises"),
        dictgen::InsensitiveStr::Ascii("kelising"),
        dictgen::InsensitiveStr::Ascii("kelization"),
        dictgen::InsensitiveStr::Ascii("kelizations"),
        dictgen::InsensitiveStr::Ascii("kelize"),
        dictgen::InsensitiveStr::Ascii("kelized"),
        dictgen::InsensitiveStr::Ascii("kelizes"),
        dictgen::InsensitiveStr::Ascii("kelizing"),
        dictgen::InsensitiveStr::Ascii("kelled"),
        dictgen::InsensitiveStr::Ascii("kelling"),
        dictgen::InsensitiveStr::Ascii("otinise"),
        dictgen::InsensitiveStr::Ascii("otinised"),
        dictgen::InsensitiveStr::Ascii("otinises"),
        dictgen::InsensitiveStr::Ascii("otinising"),
        dictgen::InsensitiveStr::Ascii("otinize"),
        dictgen::InsensitiveStr::Ascii("otinized"),
        dictgen::InsensitiveStr::Ascii("otinizes"),
        dictgen::InsensitiveStr::Ascii("otinizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NICKELED_2598322456844726625)],
        &[(0b00001, &ENTRY_NICKELING_15456695821844219317)],
        &[(0b10010, &ENTRY_NICKELIZATION_14665726966731544811)],
        &[(0b10010, &ENTRY_NICKELIZATIONS_12503400902645240500)],
        &[(0b10010, &ENTRY_NICKELIZE_9935219708315169877)],
        &[(0b10010, &ENTRY_NICKELIZED_13993422313862972332)],
        &[(0b10010, &ENTRY_NICKELIZES_15031997318790044419)],
        &[(0b10010, &ENTRY_NICKELIZING_4089906927195099259)],
        &[(0b01001, &ENTRY_NICKELIZATION_14665726966731544811)],
        &[(0b01001, &ENTRY_NICKELIZATIONS_12503400902645240500)],
        &[(0b01001, &ENTRY_NICKELIZE_9935219708315169877)],
        &[(0b01001, &ENTRY_NICKELIZED_13993422313862972332)],
        &[(0b01001, &ENTRY_NICKELIZES_15031997318790044419)],
        &[(0b01001, &ENTRY_NICKELIZING_4089906927195099259)],
        &[(0b11010, &ENTRY_NICKELED_2598322456844726625)],
        &[(0b11010, &ENTRY_NICKELING_15456695821844219317)],
        &[(0b10010, &ENTRY_NICOTINIZE_15784314479049096934)],
        &[(0b10010, &ENTRY_NICOTINIZED_11525546249126469972)],
        &[(0b10010, &ENTRY_NICOTINIZES_10592308588452861660)],
        &[(0b10010, &ENTRY_NICOTINIZING_4899607697104850379)],
        &[(0b01001, &ENTRY_NICOTINIZE_15784314479049096934)],
        &[(0b01001, &ENTRY_NICOTINIZED_11525546249126469972)],
        &[(0b01001, &ENTRY_NICOTINIZES_10592308588452861660)],
        &[(0b01001, &ENTRY_NICOTINIZING_4899607697104850379)],
    ],
    range: 5..=11,
};

static VARS_NE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_NE_CHILDREN),
    value: None,
};

static VARS_NE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_NEB_NODE),
    Some(&VARS_NEC_NODE),
    None,
    Some(&VARS_NEE_NODE),
    None,
    Some(&VARS_NEG_NODE),
    None,
    Some(&VARS_NEI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_NEO_NODE),
    Some(&VARS_NEP_NODE),
    None,
    Some(&VARS_NER_NODE),
    Some(&VARS_NES_NODE),
    Some(&VARS_NET_NODE),
    Some(&VARS_NEU_NODE),
    Some(&VARS_NEV_NODE),
    Some(&VARS_NEW_NODE),
    None,
    None,
    None,
];

static VARS_NEW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEW_CHILDREN),
    value: None,
};

pub static VARS_NEW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("manise"),
        dictgen::InsensitiveStr::Ascii("manised"),
        dictgen::InsensitiveStr::Ascii("manises"),
        dictgen::InsensitiveStr::Ascii("manising"),
        dictgen::InsensitiveStr::Ascii("manize"),
        dictgen::InsensitiveStr::Ascii("manized"),
        dictgen::InsensitiveStr::Ascii("manizes"),
        dictgen::InsensitiveStr::Ascii("manizing"),
        dictgen::InsensitiveStr::Ascii("spaperised"),
        dictgen::InsensitiveStr::Ascii("spaperiseds"),
        dictgen::InsensitiveStr::Ascii("spaperized"),
        dictgen::InsensitiveStr::Ascii("spaperizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NEWMANIZE_4267502944050665424)],
        &[(0b10010, &ENTRY_NEWMANIZED_9146175780378871651)],
        &[(0b10010, &ENTRY_NEWMANIZES_7008662780500071215)],
        &[(0b10010, &ENTRY_NEWMANIZING_1248960014721661588)],
        &[(0b01001, &ENTRY_NEWMANIZE_4267502944050665424)],
        &[(0b01001, &ENTRY_NEWMANIZED_9146175780378871651)],
        &[(0b01001, &ENTRY_NEWMANIZES_7008662780500071215)],
        &[(0b01001, &ENTRY_NEWMANIZING_1248960014721661588)],
        &[(0b10010, &ENTRY_NEWSPAPERIZED_10066561383969209786)],
        &[(0b10010, &ENTRY_NEWSPAPERIZEDS_4085444114357868312)],
        &[(0b01001, &ENTRY_NEWSPAPERIZED_10066561383969209786)],
        &[(0b01001, &ENTRY_NEWSPAPERIZEDS_4085444114357868312)],
    ],
    range: 6..=11,
};

static VARS_NEV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEV_CHILDREN),
    value: None,
};

pub static VARS_NEV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("oid"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NEVES_8948066186077998625)],
        &[(0b00001, &ENTRY_NEVOID_11903217152834367665)],
    ],
    range: 2..=3,
};

static VARS_NEU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEU_CHILDREN),
    value: None,
};

pub static VARS_NEU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("repithelium"),
        dictgen::InsensitiveStr::Ascii("rocele"),
        dictgen::InsensitiveStr::Ascii("rocelian"),
        dictgen::InsensitiveStr::Ascii("rocoele"),
        dictgen::InsensitiveStr::Ascii("rocoelian"),
        dictgen::InsensitiveStr::Ascii("roepithelium"),
        dictgen::InsensitiveStr::Ascii("roticise"),
        dictgen::InsensitiveStr::Ascii("roticises"),
        dictgen::InsensitiveStr::Ascii("roticize"),
        dictgen::InsensitiveStr::Ascii("roticizes"),
        dictgen::InsensitiveStr::Ascii("tralisation"),
        dictgen::InsensitiveStr::Ascii("tralisations"),
        dictgen::InsensitiveStr::Ascii("tralise"),
        dictgen::InsensitiveStr::Ascii("tralised"),
        dictgen::InsensitiveStr::Ascii("traliser"),
        dictgen::InsensitiveStr::Ascii("tralisers"),
        dictgen::InsensitiveStr::Ascii("tralises"),
        dictgen::InsensitiveStr::Ascii("tralising"),
        dictgen::InsensitiveStr::Ascii("tralization"),
        dictgen::InsensitiveStr::Ascii("tralizations"),
        dictgen::InsensitiveStr::Ascii("tralize"),
        dictgen::InsensitiveStr::Ascii("tralized"),
        dictgen::InsensitiveStr::Ascii("tralizer"),
        dictgen::InsensitiveStr::Ascii("tralizers"),
        dictgen::InsensitiveStr::Ascii("tralizes"),
        dictgen::InsensitiveStr::Ascii("tralizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NEUREPITHELIUM_15153948946044562070)],
        &[(0b00001, &ENTRY_NEUROCELE_18314488711130096917)],
        &[(0b00001, &ENTRY_NEUROCELIAN_7181556015461931297)],
        &[(0b11010, &ENTRY_NEUROCELE_18314488711130096917)],
        &[(0b11010, &ENTRY_NEUROCELIAN_7181556015461931297)],
        &[(0b11010, &ENTRY_NEUREPITHELIUM_15153948946044562070)],
        &[(0b10010, &ENTRY_NEUROTICIZE_9554224556419287994)],
        &[(0b10010, &ENTRY_NEUROTICIZES_17967380009910329352)],
        &[(0b01001, &ENTRY_NEUROTICIZE_9554224556419287994)],
        &[(0b01001, &ENTRY_NEUROTICIZES_17967380009910329352)],
        &[(0b10010, &ENTRY_NEUTRALIZATION_3752767150712391454)],
        &[(0b10010, &ENTRY_NEUTRALIZATIONS_7938385529409734858)],
        &[(0b10010, &ENTRY_NEUTRALIZE_8250094940796239103)],
        &[(0b10010, &ENTRY_NEUTRALIZED_23570169514124780)],
        &[(0b10010, &ENTRY_NEUTRALIZER_13734573167959567076)],
        &[(0b10010, &ENTRY_NEUTRALIZERS_1000093030679533320)],
        &[(0b10010, &ENTRY_NEUTRALIZES_3865166621052534884)],
        &[(0b10010, &ENTRY_NEUTRALIZING_14844449700074149114)],
        &[(0b01001, &ENTRY_NEUTRALIZATION_3752767150712391454)],
        &[(0b01001, &ENTRY_NEUTRALIZATIONS_7938385529409734858)],
        &[(0b01001, &ENTRY_NEUTRALIZE_8250094940796239103)],
        &[(0b01001, &ENTRY_NEUTRALIZED_23570169514124780)],
        &[(0b01001, &ENTRY_NEUTRALIZER_13734573167959567076)],
        &[(0b01001, &ENTRY_NEUTRALIZERS_1000093030679533320)],
        &[(0b01001, &ENTRY_NEUTRALIZES_3865166621052534884)],
        &[(0b01001, &ENTRY_NEUTRALIZING_14844449700074149114)],
    ],
    range: 6..=12,
};

static VARS_NET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NET_CHILDREN),
    value: None,
};

pub static VARS_NET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("t"),
        dictgen::InsensitiveStr::Ascii("ts"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NET_1634985998898472374)],
        &[(0b10010, &ENTRY_NETS_165907139467352353)],
    ],
    range: 1..=2,
};

static VARS_NES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NES_CHILDREN),
    value: None,
};

pub static VARS_NES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("slerise"),
        dictgen::InsensitiveStr::Ascii("slerised"),
        dictgen::InsensitiveStr::Ascii("slerising"),
        dictgen::InsensitiveStr::Ascii("slerize"),
        dictgen::InsensitiveStr::Ascii("slerized"),
        dictgen::InsensitiveStr::Ascii("slerizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NESSLERIZE_14666129395865185325)],
        &[(0b10010, &ENTRY_NESSLERIZED_6735223692031566594)],
        &[(0b10010, &ENTRY_NESSLERIZING_4020314319948887274)],
        &[(0b01001, &ENTRY_NESSLERIZE_14666129395865185325)],
        &[(0b01001, &ENTRY_NESSLERIZED_6735223692031566594)],
        &[(0b01001, &ENTRY_NESSLERIZING_4020314319948887274)],
    ],
    range: 7..=9,
};

static VARS_NER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NER_CHILDREN),
    value: None,
};

pub static VARS_NER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b11010, &ENTRY_NEER_16368651073851802940)]],
    range: 1..=1,
};

static VARS_NEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEP_CHILDREN),
    value: None,
};

pub static VARS_NEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hrectomise"),
        dictgen::InsensitiveStr::Ascii("hrectomised"),
        dictgen::InsensitiveStr::Ascii("hrectomising"),
        dictgen::InsensitiveStr::Ascii("hrectomize"),
        dictgen::InsensitiveStr::Ascii("hrectomized"),
        dictgen::InsensitiveStr::Ascii("hrectomizing"),
        dictgen::InsensitiveStr::Ascii("hrocele"),
        dictgen::InsensitiveStr::Ascii("hrocoele"),
        dictgen::InsensitiveStr::Ascii("hrotomise"),
        dictgen::InsensitiveStr::Ascii("hrotomize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NEPHRECTOMIZE_5590748123455365447)],
        &[(0b10010, &ENTRY_NEPHRECTOMIZED_3535158641297367003)],
        &[(0b10010, &ENTRY_NEPHRECTOMIZING_4545639191156251970)],
        &[(0b01001, &ENTRY_NEPHRECTOMIZE_5590748123455365447)],
        &[(0b01001, &ENTRY_NEPHRECTOMIZED_3535158641297367003)],
        &[(0b01001, &ENTRY_NEPHRECTOMIZING_4545639191156251970)],
        &[(0b00001, &ENTRY_NEPHROCELE_4864421137682686009)],
        &[(0b11010, &ENTRY_NEPHROCELE_4864421137682686009)],
        &[(0b10010, &ENTRY_NEPHROTOMIZE_7557324606949473167)],
        &[(0b01001, &ENTRY_NEPHROTOMIZE_7557324606949473167)],
    ],
    range: 7..=12,
};

static VARS_NEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEO_CHILDREN),
    value: None,
};

pub static VARS_NEO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("encephalon"),
        dictgen::InsensitiveStr::Ascii("gaea"),
        dictgen::InsensitiveStr::Ascii("gaeal"),
        dictgen::InsensitiveStr::Ascii("gaean"),
        dictgen::InsensitiveStr::Ascii("gaeic"),
        dictgen::InsensitiveStr::Ascii("gea"),
        dictgen::InsensitiveStr::Ascii("geal"),
        dictgen::InsensitiveStr::Ascii("gean"),
        dictgen::InsensitiveStr::Ascii("geic"),
        dictgen::InsensitiveStr::Ascii("logisation"),
        dictgen::InsensitiveStr::Ascii("logise"),
        dictgen::InsensitiveStr::Ascii("logised"),
        dictgen::InsensitiveStr::Ascii("logises"),
        dictgen::InsensitiveStr::Ascii("logising"),
        dictgen::InsensitiveStr::Ascii("logization"),
        dictgen::InsensitiveStr::Ascii("logize"),
        dictgen::InsensitiveStr::Ascii("logized"),
        dictgen::InsensitiveStr::Ascii("logizes"),
        dictgen::InsensitiveStr::Ascii("logizing"),
        dictgen::InsensitiveStr::Ascii("paganise"),
        dictgen::InsensitiveStr::Ascii("paganised"),
        dictgen::InsensitiveStr::Ascii("paganises"),
        dictgen::InsensitiveStr::Ascii("paganising"),
        dictgen::InsensitiveStr::Ascii("paganize"),
        dictgen::InsensitiveStr::Ascii("paganized"),
        dictgen::InsensitiveStr::Ascii("paganizes"),
        dictgen::InsensitiveStr::Ascii("paganizing"),
        dictgen::InsensitiveStr::Ascii("terise"),
        dictgen::InsensitiveStr::Ascii("terised"),
        dictgen::InsensitiveStr::Ascii("terises"),
        dictgen::InsensitiveStr::Ascii("terising"),
        dictgen::InsensitiveStr::Ascii("terize"),
        dictgen::InsensitiveStr::Ascii("terized"),
        dictgen::InsensitiveStr::Ascii("terizes"),
        dictgen::InsensitiveStr::Ascii("terizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NEENCEPHALON_979094039364233829)],
        &[(0b11010, &ENTRY_NEOGEA_1284680222354583533)],
        &[(0b11010, &ENTRY_NEOGEAL_16251425573587958366)],
        &[(0b11010, &ENTRY_NEOGEAN_12601233030585408024)],
        &[(0b11010, &ENTRY_NEOGEIC_5021902121890301728)],
        &[(0b00001, &ENTRY_NEOGEA_1284680222354583533)],
        &[(0b00001, &ENTRY_NEOGEAL_16251425573587958366)],
        &[(0b00001, &ENTRY_NEOGEAN_12601233030585408024)],
        &[(0b00001, &ENTRY_NEOGEIC_5021902121890301728)],
        &[(0b10010, &ENTRY_NEOLOGIZATION_1831850649569469075)],
        &[(0b10010, &ENTRY_NEOLOGIZE_5094848877824842155)],
        &[(0b10010, &ENTRY_NEOLOGIZED_9476639829063323419)],
        &[(0b10010, &ENTRY_NEOLOGIZES_2611172356463477981)],
        &[(0b10010, &ENTRY_NEOLOGIZING_6439029299467534255)],
        &[(0b01001, &ENTRY_NEOLOGIZATION_1831850649569469075)],
        &[(0b01001, &ENTRY_NEOLOGIZE_5094848877824842155)],
        &[(0b01001, &ENTRY_NEOLOGIZED_9476639829063323419)],
        &[(0b01001, &ENTRY_NEOLOGIZES_2611172356463477981)],
        &[(0b01001, &ENTRY_NEOLOGIZING_6439029299467534255)],
        &[(0b10010, &ENTRY_NEOPAGANIZE_17137797559492162954)],
        &[(0b10010, &ENTRY_NEOPAGANIZED_10850521355046515785)],
        &[(0b10010, &ENTRY_NEOPAGANIZES_6716210077285627581)],
        &[(0b10010, &ENTRY_NEOPAGANIZING_7247721295390537710)],
        &[(0b01001, &ENTRY_NEOPAGANIZE_17137797559492162954)],
        &[(0b01001, &ENTRY_NEOPAGANIZED_10850521355046515785)],
        &[(0b01001, &ENTRY_NEOPAGANIZES_6716210077285627581)],
        &[(0b01001, &ENTRY_NEOPAGANIZING_7247721295390537710)],
        &[(0b10010, &ENTRY_NEOTERIZE_5399698345453637528)],
        &[(0b10010, &ENTRY_NEOTERIZED_5721029857030207574)],
        &[(0b10010, &ENTRY_NEOTERIZES_8732588249524157867)],
        &[(0b10010, &ENTRY_NEOTERIZING_10159918373796657938)],
        &[(0b01001, &ENTRY_NEOTERIZE_5399698345453637528)],
        &[(0b01001, &ENTRY_NEOTERIZED_5721029857030207574)],
        &[(0b01001, &ENTRY_NEOTERIZES_8732588249524157867)],
        &[(0b01001, &ENTRY_NEOTERIZING_10159918373796657938)],
    ],
    range: 3..=10,
};

static VARS_NEI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEI_CHILDREN),
    value: None,
};

pub static VARS_NEI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ghbor"),
        dictgen::InsensitiveStr::Ascii("ghbored"),
        dictgen::InsensitiveStr::Ascii("ghborer"),
        dictgen::InsensitiveStr::Ascii("ghborers"),
        dictgen::InsensitiveStr::Ascii("ghboress"),
        dictgen::InsensitiveStr::Ascii("ghborhood"),
        dictgen::InsensitiveStr::Ascii("ghborhoods"),
        dictgen::InsensitiveStr::Ascii("ghboring"),
        dictgen::InsensitiveStr::Ascii("ghborings"),
        dictgen::InsensitiveStr::Ascii("ghborless"),
        dictgen::InsensitiveStr::Ascii("ghborlesser"),
        dictgen::InsensitiveStr::Ascii("ghborlesses"),
        dictgen::InsensitiveStr::Ascii("ghborlessest"),
        dictgen::InsensitiveStr::Ascii("ghborlier"),
        dictgen::InsensitiveStr::Ascii("ghborliest"),
        dictgen::InsensitiveStr::Ascii("ghborlike"),
        dictgen::InsensitiveStr::Ascii("ghborlikes"),
        dictgen::InsensitiveStr::Ascii("ghborliness"),
        dictgen::InsensitiveStr::Ascii("ghborlinesses"),
        dictgen::InsensitiveStr::Ascii("ghborly"),
        dictgen::InsensitiveStr::Ascii("ghbors"),
        dictgen::InsensitiveStr::Ascii("ghborship"),
        dictgen::InsensitiveStr::Ascii("ghborships"),
        dictgen::InsensitiveStr::Ascii("ghbour"),
        dictgen::InsensitiveStr::Ascii("ghboured"),
        dictgen::InsensitiveStr::Ascii("ghbourer"),
        dictgen::InsensitiveStr::Ascii("ghbourers"),
        dictgen::InsensitiveStr::Ascii("ghbouress"),
        dictgen::InsensitiveStr::Ascii("ghbourhood"),
        dictgen::InsensitiveStr::Ascii("ghbourhoods"),
        dictgen::InsensitiveStr::Ascii("ghbouring"),
        dictgen::InsensitiveStr::Ascii("ghbourings"),
        dictgen::InsensitiveStr::Ascii("ghbourless"),
        dictgen::InsensitiveStr::Ascii("ghbourlesser"),
        dictgen::InsensitiveStr::Ascii("ghbourlesses"),
        dictgen::InsensitiveStr::Ascii("ghbourlessest"),
        dictgen::InsensitiveStr::Ascii("ghbourlier"),
        dictgen::InsensitiveStr::Ascii("ghbourliest"),
        dictgen::InsensitiveStr::Ascii("ghbourlike"),
        dictgen::InsensitiveStr::Ascii("ghbourlikes"),
        dictgen::InsensitiveStr::Ascii("ghbourliness"),
        dictgen::InsensitiveStr::Ascii("ghbourlinesses"),
        dictgen::InsensitiveStr::Ascii("ghbourly"),
        dictgen::InsensitiveStr::Ascii("ghbours"),
        dictgen::InsensitiveStr::Ascii("ghbourship"),
        dictgen::InsensitiveStr::Ascii("ghbourships"),
    ],
    values: &[
        &[(0b11001, &ENTRY_NEIGHBOR_9223532537551591313)],
        &[(0b11001, &ENTRY_NEIGHBORED_1453065315242132972)],
        &[(0b10001, &ENTRY_NEIGHBORER_13012747299862986620)],
        &[(0b10001, &ENTRY_NEIGHBORERS_3234519608682158967)],
        &[(0b10001, &ENTRY_NEIGHBORESS_9273358629774412394)],
        &[(0b11001, &ENTRY_NEIGHBORHOOD_13179978688818671082)],
        &[(0b11001, &ENTRY_NEIGHBORHOODS_13147261698969498299)],
        &[(0b11001, &ENTRY_NEIGHBORING_11318750292661541645)],
        &[(0b11001, &ENTRY_NEIGHBORINGS_12373492488609025236)],
        &[(0b10001, &ENTRY_NEIGHBORLESS_16958265927368217965)],
        &[(0b10001, &ENTRY_NEIGHBORLESSER_15998195990911091581)],
        &[(0b10001, &ENTRY_NEIGHBORLESSES_17062516910133863736)],
        &[(0b10001, &ENTRY_NEIGHBORLESSEST_16873799645280627574)],
        &[(0b11001, &ENTRY_NEIGHBORLIER_5964029050832264412)],
        &[(0b11001, &ENTRY_NEIGHBORLIEST_6163034189378516769)],
        &[(0b10001, &ENTRY_NEIGHBORLIKE_13851941964575482888)],
        &[(0b10001, &ENTRY_NEIGHBORLIKES_11602580781433436933)],
        &[(0b10001, &ENTRY_NEIGHBORLINESS_10203381514206777935)],
        &[(0b10001, &ENTRY_NEIGHBORLINESSES_15429938495896734143)],
        &[(0b11001, &ENTRY_NEIGHBORLY_1379658281742193125)],
        &[(0b11001, &ENTRY_NEIGHBORS_11834946978992293791)],
        &[(0b10001, &ENTRY_NEIGHBORSHIP_14837261908353670667)],
        &[(0b10001, &ENTRY_NEIGHBORSHIPS_5522605364924311025)],
        &[(0b11010, &ENTRY_NEIGHBOR_9223532537551591313)],
        &[(0b11010, &ENTRY_NEIGHBORED_1453065315242132972)],
        &[(0b11010, &ENTRY_NEIGHBORER_13012747299862986620)],
        &[(0b11010, &ENTRY_NEIGHBORERS_3234519608682158967)],
        &[(0b11010, &ENTRY_NEIGHBORESS_9273358629774412394)],
        &[(0b11010, &ENTRY_NEIGHBORHOOD_13179978688818671082)],
        &[(0b11010, &ENTRY_NEIGHBORHOODS_13147261698969498299)],
        &[(0b11010, &ENTRY_NEIGHBORING_11318750292661541645)],
        &[(0b11010, &ENTRY_NEIGHBORINGS_12373492488609025236)],
        &[(0b11010, &ENTRY_NEIGHBORLESS_16958265927368217965)],
        &[(0b11010, &ENTRY_NEIGHBORLESSER_15998195990911091581)],
        &[(0b11010, &ENTRY_NEIGHBORLESSES_17062516910133863736)],
        &[(0b11010, &ENTRY_NEIGHBORLESSEST_16873799645280627574)],
        &[(0b11010, &ENTRY_NEIGHBORLIER_5964029050832264412)],
        &[(0b11010, &ENTRY_NEIGHBORLIEST_6163034189378516769)],
        &[(0b11010, &ENTRY_NEIGHBORLIKE_13851941964575482888)],
        &[(0b11010, &ENTRY_NEIGHBORLIKES_11602580781433436933)],
        &[(0b11010, &ENTRY_NEIGHBORLINESS_10203381514206777935)],
        &[(0b11010, &ENTRY_NEIGHBORLINESSES_15429938495896734143)],
        &[(0b11010, &ENTRY_NEIGHBORLY_1379658281742193125)],
        &[(0b11010, &ENTRY_NEIGHBORS_11834946978992293791)],
        &[(0b11010, &ENTRY_NEIGHBORSHIP_14837261908353670667)],
        &[(0b11010, &ENTRY_NEIGHBORSHIPS_5522605364924311025)],
    ],
    range: 5..=14,
};

static VARS_NEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEG_CHILDREN),
    value: None,
};

pub static VARS_NEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lig"),
        dictgen::InsensitiveStr::Ascii("ligs"),
        dictgen::InsensitiveStr::Ascii("ritise"),
        dictgen::InsensitiveStr::Ascii("ritised"),
        dictgen::InsensitiveStr::Ascii("ritising"),
        dictgen::InsensitiveStr::Ascii("ritize"),
        dictgen::InsensitiveStr::Ascii("ritized"),
        dictgen::InsensitiveStr::Ascii("ritizing"),
        dictgen::InsensitiveStr::Ascii("roisation"),
        dictgen::InsensitiveStr::Ascii("roisations"),
        dictgen::InsensitiveStr::Ascii("roise"),
        dictgen::InsensitiveStr::Ascii("roised"),
        dictgen::InsensitiveStr::Ascii("roises"),
        dictgen::InsensitiveStr::Ascii("roising"),
        dictgen::InsensitiveStr::Ascii("roization"),
        dictgen::InsensitiveStr::Ascii("roizations"),
        dictgen::InsensitiveStr::Ascii("roize"),
        dictgen::InsensitiveStr::Ascii("roized"),
        dictgen::InsensitiveStr::Ascii("roizes"),
        dictgen::InsensitiveStr::Ascii("roizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NEGLIGEE_12210121686392984472)],
        &[(0b00001, &ENTRY_NEGLIGEES_4454821460830858983)],
        &[(0b10010, &ENTRY_NEGRITIZE_9210974913397215749)],
        &[(0b10010, &ENTRY_NEGRITIZED_15092433378035298133)],
        &[(0b10010, &ENTRY_NEGRITIZING_18411327602026760303)],
        &[(0b01001, &ENTRY_NEGRITIZE_9210974913397215749)],
        &[(0b01001, &ENTRY_NEGRITIZED_15092433378035298133)],
        &[(0b01001, &ENTRY_NEGRITIZING_18411327602026760303)],
        &[(0b10010, &ENTRY_NEGROIZATION_734165123169837681)],
        &[(0b10010, &ENTRY_NEGROIZATIONS_3017888884521311143)],
        &[(0b10010, &ENTRY_NEGROIZE_676151142023635085)],
        &[(0b10010, &ENTRY_NEGROIZED_8511374797642149972)],
        &[(0b10010, &ENTRY_NEGROIZES_2943242169344115772)],
        &[(0b10010, &ENTRY_NEGROIZING_12007313249945227181)],
        &[(0b01001, &ENTRY_NEGROIZATION_734165123169837681)],
        &[(0b01001, &ENTRY_NEGROIZATIONS_3017888884521311143)],
        &[(0b01001, &ENTRY_NEGROIZE_676151142023635085)],
        &[(0b01001, &ENTRY_NEGROIZED_8511374797642149972)],
        &[(0b01001, &ENTRY_NEGROIZES_2943242169344115772)],
        &[(0b01001, &ENTRY_NEGROIZING_12007313249945227181)],
    ],
    range: 3..=10,
};

static VARS_NEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEE_CHILDREN),
    value: None,
};

pub static VARS_NEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bor"),
        dictgen::InsensitiveStr::Ascii("bour"),
        dictgen::InsensitiveStr::Ascii("ncephalon"),
        dictgen::InsensitiveStr::Ascii("r"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NEEBOR_18269956267250848330)],
        &[(0b11010, &ENTRY_NEEBOR_18269956267250848330)],
        &[(0b00001, &ENTRY_NEENCEPHALON_979094039364233829)],
        &[(0b00001, &ENTRY_NEER_16368651073851802940)],
    ],
    range: 1..=9,
};

static VARS_NEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEC_CHILDREN),
    value: None,
};

pub static VARS_NEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("raemia"),
        dictgen::InsensitiveStr::Ascii("remia"),
        dictgen::InsensitiveStr::Ascii("rotise"),
        dictgen::InsensitiveStr::Ascii("rotised"),
        dictgen::InsensitiveStr::Ascii("rotises"),
        dictgen::InsensitiveStr::Ascii("rotising"),
        dictgen::InsensitiveStr::Ascii("rotize"),
        dictgen::InsensitiveStr::Ascii("rotized"),
        dictgen::InsensitiveStr::Ascii("rotizes"),
        dictgen::InsensitiveStr::Ascii("rotizing"),
        dictgen::InsensitiveStr::Ascii("tarise"),
        dictgen::InsensitiveStr::Ascii("tarised"),
        dictgen::InsensitiveStr::Ascii("tarises"),
        dictgen::InsensitiveStr::Ascii("tarising"),
        dictgen::InsensitiveStr::Ascii("tarize"),
        dictgen::InsensitiveStr::Ascii("tarized"),
        dictgen::InsensitiveStr::Ascii("tarizes"),
        dictgen::InsensitiveStr::Ascii("tarizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NECREMIA_2209235602725432624)],
        &[(0b10001, &ENTRY_NECREMIA_2209235602725432624)],
        &[(0b10010, &ENTRY_NECROTIZE_248925496160162456)],
        &[(0b10010, &ENTRY_NECROTIZED_16485177737821660398)],
        &[(0b10010, &ENTRY_NECROTIZES_6718759902100842968)],
        &[(0b10010, &ENTRY_NECROTIZING_992481852800391492)],
        &[(0b01001, &ENTRY_NECROTIZE_248925496160162456)],
        &[(0b01001, &ENTRY_NECROTIZED_16485177737821660398)],
        &[(0b01001, &ENTRY_NECROTIZES_6718759902100842968)],
        &[(0b01001, &ENTRY_NECROTIZING_992481852800391492)],
        &[(0b10010, &ENTRY_NECTARIZE_16440625593515876087)],
        &[(0b10010, &ENTRY_NECTARIZED_5989083498818079168)],
        &[(0b10010, &ENTRY_NECTARIZES_17994754460986475766)],
        &[(0b10010, &ENTRY_NECTARIZING_7069406744718506258)],
        &[(0b01001, &ENTRY_NECTARIZE_16440625593515876087)],
        &[(0b01001, &ENTRY_NECTARIZED_5989083498818079168)],
        &[(0b01001, &ENTRY_NECTARIZES_17994754460986475766)],
        &[(0b01001, &ENTRY_NECTARIZING_7069406744718506258)],
    ],
    range: 5..=8,
};

static VARS_NEB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEB_CHILDREN),
    value: None,
};

pub static VARS_NEB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularisations"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularizations"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("ulisation"),
        dictgen::InsensitiveStr::Ascii("ulisations"),
        dictgen::InsensitiveStr::Ascii("ulise"),
        dictgen::InsensitiveStr::Ascii("ulised"),
        dictgen::InsensitiveStr::Ascii("uliser"),
        dictgen::InsensitiveStr::Ascii("ulisers"),
        dictgen::InsensitiveStr::Ascii("ulises"),
        dictgen::InsensitiveStr::Ascii("ulising"),
        dictgen::InsensitiveStr::Ascii("ulization"),
        dictgen::InsensitiveStr::Ascii("ulizations"),
        dictgen::InsensitiveStr::Ascii("ulize"),
        dictgen::InsensitiveStr::Ascii("ulized"),
        dictgen::InsensitiveStr::Ascii("ulizer"),
        dictgen::InsensitiveStr::Ascii("ulizers"),
        dictgen::InsensitiveStr::Ascii("ulizes"),
        dictgen::InsensitiveStr::Ascii("ulizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NEBULARIZATION_3258696472450942938)],
        &[(0b10010, &ENTRY_NEBULARIZATIONS_16140717010768565468)],
        &[(0b10010, &ENTRY_NEBULARIZE_419103860158710298)],
        &[(0b10010, &ENTRY_NEBULARIZES_7468940411162471977)],
        &[(0b01001, &ENTRY_NEBULARIZATION_3258696472450942938)],
        &[(0b01001, &ENTRY_NEBULARIZATIONS_16140717010768565468)],
        &[(0b01001, &ENTRY_NEBULARIZE_419103860158710298)],
        &[(0b01001, &ENTRY_NEBULARIZES_7468940411162471977)],
        &[(0b10010, &ENTRY_NEBULIZATION_1642955319706951393)],
        &[(0b10010, &ENTRY_NEBULIZATIONS_13271366314956373563)],
        &[(0b10010, &ENTRY_NEBULIZE_897376798026210104)],
        &[(0b10010, &ENTRY_NEBULIZED_8317403402858231652)],
        &[(0b10010, &ENTRY_NEBULIZER_9105631547111211944)],
        &[(0b10010, &ENTRY_NEBULIZERS_575364184566751247)],
        &[(0b10010, &ENTRY_NEBULIZES_1042694150983522129)],
        &[(0b10010, &ENTRY_NEBULIZING_9748130735255218557)],
        &[(0b01001, &ENTRY_NEBULIZATION_1642955319706951393)],
        &[(0b01001, &ENTRY_NEBULIZATIONS_13271366314956373563)],
        &[(0b01001, &ENTRY_NEBULIZE_897376798026210104)],
        &[(0b01001, &ENTRY_NEBULIZED_8317403402858231652)],
        &[(0b01001, &ENTRY_NEBULIZER_9105631547111211944)],
        &[(0b01001, &ENTRY_NEBULIZERS_575364184566751247)],
        &[(0b01001, &ENTRY_NEBULIZES_1042694150983522129)],
        &[(0b01001, &ENTRY_NEBULIZING_9748130735255218557)],
    ],
    range: 5..=12,
};

static VARS_NA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_NA_CHILDREN),
    value: None,
};

static VARS_NA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_NAB_NODE),
    None,
    None,
    Some(&VARS_NAE_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_NAK_NODE),
    None,
    None,
    Some(&VARS_NAN_NODE),
    None,
    Some(&VARS_NAP_NODE),
    None,
    Some(&VARS_NAR_NODE),
    Some(&VARS_NAS_NODE),
    Some(&VARS_NAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_NAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAT_CHILDREN),
    value: None,
};

pub static VARS_NAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ionalisation"),
        dictgen::InsensitiveStr::Ascii("ionalisations"),
        dictgen::InsensitiveStr::Ascii("ionalise"),
        dictgen::InsensitiveStr::Ascii("ionalised"),
        dictgen::InsensitiveStr::Ascii("ionaliser"),
        dictgen::InsensitiveStr::Ascii("ionalisers"),
        dictgen::InsensitiveStr::Ascii("ionalises"),
        dictgen::InsensitiveStr::Ascii("ionalising"),
        dictgen::InsensitiveStr::Ascii("ionalization"),
        dictgen::InsensitiveStr::Ascii("ionalizations"),
        dictgen::InsensitiveStr::Ascii("ionalize"),
        dictgen::InsensitiveStr::Ascii("ionalized"),
        dictgen::InsensitiveStr::Ascii("ionalizer"),
        dictgen::InsensitiveStr::Ascii("ionalizers"),
        dictgen::InsensitiveStr::Ascii("ionalizes"),
        dictgen::InsensitiveStr::Ascii("ionalizing"),
        dictgen::InsensitiveStr::Ascii("uralisation"),
        dictgen::InsensitiveStr::Ascii("uralisations"),
        dictgen::InsensitiveStr::Ascii("uralise"),
        dictgen::InsensitiveStr::Ascii("uralised"),
        dictgen::InsensitiveStr::Ascii("uraliser"),
        dictgen::InsensitiveStr::Ascii("uralisers"),
        dictgen::InsensitiveStr::Ascii("uralises"),
        dictgen::InsensitiveStr::Ascii("uralising"),
        dictgen::InsensitiveStr::Ascii("uralization"),
        dictgen::InsensitiveStr::Ascii("uralizations"),
        dictgen::InsensitiveStr::Ascii("uralize"),
        dictgen::InsensitiveStr::Ascii("uralized"),
        dictgen::InsensitiveStr::Ascii("uralizer"),
        dictgen::InsensitiveStr::Ascii("uralizers"),
        dictgen::InsensitiveStr::Ascii("uralizes"),
        dictgen::InsensitiveStr::Ascii("uralizing"),
        dictgen::InsensitiveStr::Ascii("urise"),
        dictgen::InsensitiveStr::Ascii("urises"),
        dictgen::InsensitiveStr::Ascii("urize"),
        dictgen::InsensitiveStr::Ascii("urizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NATIONALIZATION_16093349884516853513)],
        &[(0b10010, &ENTRY_NATIONALIZATIONS_5281594635957507193)],
        &[(0b10010, &ENTRY_NATIONALIZE_1535875549943010403)],
        &[(0b10010, &ENTRY_NATIONALIZED_14123403696319407671)],
        &[(0b10010, &ENTRY_NATIONALIZER_4646678062279574784)],
        &[(0b10010, &ENTRY_NATIONALIZERS_13336757627588867669)],
        &[(0b10010, &ENTRY_NATIONALIZES_9931517547348470217)],
        &[(0b10010, &ENTRY_NATIONALIZING_154708228623797355)],
        &[(0b01001, &ENTRY_NATIONALIZATION_16093349884516853513)],
        &[(0b01001, &ENTRY_NATIONALIZATIONS_5281594635957507193)],
        &[(0b01001, &ENTRY_NATIONALIZE_1535875549943010403)],
        &[(0b01001, &ENTRY_NATIONALIZED_14123403696319407671)],
        &[(0b01001, &ENTRY_NATIONALIZER_4646678062279574784)],
        &[(0b01001, &ENTRY_NATIONALIZERS_13336757627588867669)],
        &[(0b01001, &ENTRY_NATIONALIZES_9931517547348470217)],
        &[(0b01001, &ENTRY_NATIONALIZING_154708228623797355)],
        &[(0b10010, &ENTRY_NATURALIZATION_901934936058317884)],
        &[(0b10010, &ENTRY_NATURALIZATIONS_15146375781211350844)],
        &[(0b10010, &ENTRY_NATURALIZE_15129142042727649412)],
        &[(0b10010, &ENTRY_NATURALIZED_4952898848561703349)],
        &[(0b10010, &ENTRY_NATURALIZER_13986726448266401105)],
        &[(0b10010, &ENTRY_NATURALIZERS_10150306956216872864)],
        &[(0b10010, &ENTRY_NATURALIZES_7464268429055724811)],
        &[(0b10010, &ENTRY_NATURALIZING_7589140168222731708)],
        &[(0b01001, &ENTRY_NATURALIZATION_901934936058317884)],
        &[(0b01001, &ENTRY_NATURALIZATIONS_15146375781211350844)],
        &[(0b01001, &ENTRY_NATURALIZE_15129142042727649412)],
        &[(0b01001, &ENTRY_NATURALIZED_4952898848561703349)],
        &[(0b01001, &ENTRY_NATURALIZER_13986726448266401105)],
        &[(0b01001, &ENTRY_NATURALIZERS_10150306956216872864)],
        &[(0b01001, &ENTRY_NATURALIZES_7464268429055724811)],
        &[(0b01001, &ENTRY_NATURALIZING_7589140168222731708)],
        &[(0b10010, &ENTRY_NATURIZE_17136190831997236970)],
        &[(0b10010, &ENTRY_NATURIZES_15311848507319444172)],
        &[(0b01001, &ENTRY_NATURIZE_17136190831997236970)],
        &[(0b01001, &ENTRY_NATURIZES_15311848507319444172)],
    ],
    range: 5..=13,
};

static VARS_NAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAS_CHILDREN),
    value: None,
};

pub static VARS_NAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NASALIZATION_9447471797004510318)],
        &[(0b10010, &ENTRY_NASALIZATIONS_7277160551960333351)],
        &[(0b10010, &ENTRY_NASALIZE_76311075047194658)],
        &[(0b10010, &ENTRY_NASALIZED_1043946313139330861)],
        &[(0b10010, &ENTRY_NASALIZES_6487641598131144165)],
        &[(0b10010, &ENTRY_NASALIZING_2082301516066873014)],
        &[(0b01001, &ENTRY_NASALIZATION_9447471797004510318)],
        &[(0b01001, &ENTRY_NASALIZATIONS_7277160551960333351)],
        &[(0b01001, &ENTRY_NASALIZE_76311075047194658)],
        &[(0b01001, &ENTRY_NASALIZED_1043946313139330861)],
        &[(0b01001, &ENTRY_NASALIZES_6487641598131144165)],
        &[(0b01001, &ENTRY_NASALIZING_2082301516066873014)],
    ],
    range: 5..=10,
};

static VARS_NAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAR_CHILDREN),
    value: None,
};

pub static VARS_NAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cotisation"),
        dictgen::InsensitiveStr::Ascii("cotisations"),
        dictgen::InsensitiveStr::Ascii("cotise"),
        dictgen::InsensitiveStr::Ascii("cotised"),
        dictgen::InsensitiveStr::Ascii("cotises"),
        dictgen::InsensitiveStr::Ascii("cotising"),
        dictgen::InsensitiveStr::Ascii("cotization"),
        dictgen::InsensitiveStr::Ascii("cotizations"),
        dictgen::InsensitiveStr::Ascii("cotize"),
        dictgen::InsensitiveStr::Ascii("cotized"),
        dictgen::InsensitiveStr::Ascii("cotizes"),
        dictgen::InsensitiveStr::Ascii("cotizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NARCOTIZATION_12066717855128327454)],
        &[(0b10010, &ENTRY_NARCOTIZATIONS_8442277263581755114)],
        &[(0b10010, &ENTRY_NARCOTIZE_14616380840716794484)],
        &[(0b10010, &ENTRY_NARCOTIZED_16901265805353552450)],
        &[(0b10010, &ENTRY_NARCOTIZES_5310729382357568649)],
        &[(0b10010, &ENTRY_NARCOTIZING_7516536430926503777)],
        &[(0b01001, &ENTRY_NARCOTIZATION_12066717855128327454)],
        &[(0b01001, &ENTRY_NARCOTIZATIONS_8442277263581755114)],
        &[(0b01001, &ENTRY_NARCOTIZE_14616380840716794484)],
        &[(0b01001, &ENTRY_NARCOTIZED_16901265805353552450)],
        &[(0b01001, &ENTRY_NARCOTIZES_5310729382357568649)],
        &[(0b01001, &ENTRY_NARCOTIZING_7516536430926503777)],
    ],
    range: 6..=11,
};

static VARS_NAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAP_CHILDREN),
    value: None,
};

pub static VARS_NAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aea"),
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("hthalise"),
        dictgen::InsensitiveStr::Ascii("hthalised"),
        dictgen::InsensitiveStr::Ascii("hthalises"),
        dictgen::InsensitiveStr::Ascii("hthalising"),
        dictgen::InsensitiveStr::Ascii("hthalize"),
        dictgen::InsensitiveStr::Ascii("hthalized"),
        dictgen::InsensitiveStr::Ascii("hthalizes"),
        dictgen::InsensitiveStr::Ascii("hthalizing"),
        dictgen::InsensitiveStr::Ascii("oleonise"),
        dictgen::InsensitiveStr::Ascii("oleonises"),
        dictgen::InsensitiveStr::Ascii("oleonize"),
        dictgen::InsensitiveStr::Ascii("oleonizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NAPEA_2972076182375748936)],
        &[(0b00001, &ENTRY_NAPEA_2972076182375748936)],
        &[(0b10010, &ENTRY_NAPHTHALIZE_3036249934484436937)],
        &[(0b10010, &ENTRY_NAPHTHALIZED_1033199897067261368)],
        &[(0b10010, &ENTRY_NAPHTHALIZES_5804795985920271479)],
        &[(0b10010, &ENTRY_NAPHTHALIZING_16162836589293692810)],
        &[(0b01001, &ENTRY_NAPHTHALIZE_3036249934484436937)],
        &[(0b01001, &ENTRY_NAPHTHALIZED_1033199897067261368)],
        &[(0b01001, &ENTRY_NAPHTHALIZES_5804795985920271479)],
        &[(0b01001, &ENTRY_NAPHTHALIZING_16162836589293692810)],
        &[(0b10010, &ENTRY_NAPOLEONIZE_3662659967404924605)],
        &[(0b10010, &ENTRY_NAPOLEONIZES_4379534235679670079)],
        &[(0b01001, &ENTRY_NAPOLEONIZE_3662659967404924605)],
        &[(0b01001, &ENTRY_NAPOLEONIZES_4379534235679670079)],
    ],
    range: 2..=10,
};

static VARS_NAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAN_CHILDREN),
    value: None,
};

pub static VARS_NAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ogramme"),
        dictgen::InsensitiveStr::Ascii("ogrammes"),
        dictgen::InsensitiveStr::Ascii("ometer"),
        dictgen::InsensitiveStr::Ascii("ometers"),
        dictgen::InsensitiveStr::Ascii("ometre"),
        dictgen::InsensitiveStr::Ascii("ometres"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NANIZATION_6965256141011755320)],
        &[(0b10010, &ENTRY_NANIZATIONS_9741997057394079383)],
        &[(0b01001, &ENTRY_NANIZATION_6965256141011755320)],
        &[(0b01001, &ENTRY_NANIZATIONS_9741997057394079383)],
        &[(0b10010, &ENTRY_NANOGRAM_11942860163821644329)],
        &[
            (0b10010, &ENTRY_MICROGRAMS_8250624480840600961),
            (0b10010, &ENTRY_NANOGRAMS_17642704447694885166),
        ],
        &[(0b01001, &ENTRY_NANOMETER_15050479722914391248)],
        &[(0b01001, &ENTRY_NANOMETERS_14532694249183942048)],
        &[(0b11010, &ENTRY_NANOMETER_15050479722914391248)],
        &[(0b11010, &ENTRY_NANOMETERS_14532694249183942048)],
    ],
    range: 6..=8,
};

static VARS_NAK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAK_CHILDREN),
    value: None,
};

pub static VARS_NAK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edise"),
        dictgen::InsensitiveStr::Ascii("edises"),
        dictgen::InsensitiveStr::Ascii("edize"),
        dictgen::InsensitiveStr::Ascii("edizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NAKEDIZE_16788050557980236016)],
        &[(0b10010, &ENTRY_NAKEDIZES_9777760669263216460)],
        &[(0b01001, &ENTRY_NAKEDIZE_16788050557980236016)],
        &[(0b01001, &ENTRY_NAKEDIZES_9777760669263216460)],
    ],
    range: 5..=6,
};

static VARS_NAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAE_CHILDREN),
    value: None,
};

pub static VARS_NAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ves"),
        dictgen::InsensitiveStr::Ascii("void"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NEVES_8948066186077998625)],
        &[(0b11010, &ENTRY_NEVOID_11903217152834367665)],
    ],
    range: 3..=4,
};

static VARS_NAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAB_CHILDREN),
    value: None,
};

pub static VARS_NAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ataeans"),
        dictgen::InsensitiveStr::Ascii("ateans"),
        dictgen::InsensitiveStr::Ascii("athaean"),
        dictgen::InsensitiveStr::Ascii("athean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NABATEANS_569710781128463273)],
        &[(0b00001, &ENTRY_NABATEANS_569710781128463273)],
        &[(0b11010, &ENTRY_NABATHEAN_18274860619838246891)],
        &[(0b00001, &ENTRY_NABATHEAN_18274860619838246891)],
    ],
    range: 6..=7,
};

static VARS_M_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_M_CHILDREN),
    value: None,
};

static VARS_M_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MA_NODE),
    None,
    None,
    None,
    Some(&VARS_ME_NODE),
    None,
    None,
    None,
    Some(&VARS_MI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MU_NODE),
    None,
    None,
    None,
    Some(&VARS_MY_NODE),
    None,
];

static VARS_MY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MY_CHILDREN),
    value: None,
};

static VARS_MY_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_MYC_NODE),
    None,
    Some(&VARS_MYE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MYL_NODE),
    None,
    None,
    Some(&VARS_MYO_NODE),
    None,
    None,
    Some(&VARS_MYR_NODE),
    Some(&VARS_MYS_NODE),
    Some(&VARS_MYT_NODE),
    None,
    None,
    None,
    Some(&VARS_MYX_NODE),
    None,
    None,
];

static VARS_MYX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYX_CHILDREN),
    value: None,
};

pub static VARS_MYX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("ameba"),
        dictgen::InsensitiveStr::Ascii("amoeba"),
        dictgen::InsensitiveStr::Ascii("edema"),
        dictgen::InsensitiveStr::Ascii("edemas"),
        dictgen::InsensitiveStr::Ascii("edematous"),
        dictgen::InsensitiveStr::Ascii("edemic"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("oedema"),
        dictgen::InsensitiveStr::Ascii("oedemas"),
        dictgen::InsensitiveStr::Ascii("oedematous"),
        dictgen::InsensitiveStr::Ascii("oedemic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MYXEMIA_1141130721765613596)],
        &[(0b00001, &ENTRY_MYXAMEBA_14643433663329128144)],
        &[(0b11010, &ENTRY_MYXAMEBA_14643433663329128144)],
        &[(0b11001, &ENTRY_MYXEDEMA_1555701545725524849)],
        &[(0b11001, &ENTRY_MYXEDEMAS_15468056638103415791)],
        &[(0b10001, &ENTRY_MYXEDEMATOUS_15622444540288493744)],
        &[(0b10001, &ENTRY_MYXEDEMIC_9553375441668912393)],
        &[(0b10001, &ENTRY_MYXEMIA_1141130721765613596)],
        &[(0b10010, &ENTRY_MYXEDEMA_1555701545725524849)],
        &[(0b10010, &ENTRY_MYXEDEMAS_15468056638103415791)],
        &[(0b11010, &ENTRY_MYXEDEMATOUS_15622444540288493744)],
        &[(0b11010, &ENTRY_MYXEDEMIC_9553375441668912393)],
    ],
    range: 4..=10,
};

static VARS_MYT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYT_CHILDREN),
    value: None,
};

pub static VARS_MYT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hicisation"),
        dictgen::InsensitiveStr::Ascii("hicise"),
        dictgen::InsensitiveStr::Ascii("hicised"),
        dictgen::InsensitiveStr::Ascii("hiciser"),
        dictgen::InsensitiveStr::Ascii("hicisers"),
        dictgen::InsensitiveStr::Ascii("hicises"),
        dictgen::InsensitiveStr::Ascii("hicising"),
        dictgen::InsensitiveStr::Ascii("hicization"),
        dictgen::InsensitiveStr::Ascii("hicize"),
        dictgen::InsensitiveStr::Ascii("hicized"),
        dictgen::InsensitiveStr::Ascii("hicizer"),
        dictgen::InsensitiveStr::Ascii("hicizers"),
        dictgen::InsensitiveStr::Ascii("hicizes"),
        dictgen::InsensitiveStr::Ascii("hicizing"),
        dictgen::InsensitiveStr::Ascii("hise"),
        dictgen::InsensitiveStr::Ascii("hised"),
        dictgen::InsensitiveStr::Ascii("hises"),
        dictgen::InsensitiveStr::Ascii("hising"),
        dictgen::InsensitiveStr::Ascii("hize"),
        dictgen::InsensitiveStr::Ascii("hized"),
        dictgen::InsensitiveStr::Ascii("hizes"),
        dictgen::InsensitiveStr::Ascii("hizing"),
        dictgen::InsensitiveStr::Ascii("hologisation"),
        dictgen::InsensitiveStr::Ascii("hologisations"),
        dictgen::InsensitiveStr::Ascii("hologise"),
        dictgen::InsensitiveStr::Ascii("hologised"),
        dictgen::InsensitiveStr::Ascii("hologiser"),
        dictgen::InsensitiveStr::Ascii("hologisers"),
        dictgen::InsensitiveStr::Ascii("hologises"),
        dictgen::InsensitiveStr::Ascii("hologising"),
        dictgen::InsensitiveStr::Ascii("hologization"),
        dictgen::InsensitiveStr::Ascii("hologizations"),
        dictgen::InsensitiveStr::Ascii("hologize"),
        dictgen::InsensitiveStr::Ascii("hologized"),
        dictgen::InsensitiveStr::Ascii("hologizer"),
        dictgen::InsensitiveStr::Ascii("hologizers"),
        dictgen::InsensitiveStr::Ascii("hologizes"),
        dictgen::InsensitiveStr::Ascii("hologizing"),
        dictgen::InsensitiveStr::Ascii("hopeic"),
        dictgen::InsensitiveStr::Ascii("hopeist"),
        dictgen::InsensitiveStr::Ascii("hopoeic"),
        dictgen::InsensitiveStr::Ascii("hopoeist"),
        dictgen::InsensitiveStr::Ascii("hopoetise"),
        dictgen::InsensitiveStr::Ascii("hopoetised"),
        dictgen::InsensitiveStr::Ascii("hopoetising"),
        dictgen::InsensitiveStr::Ascii("hopoetize"),
        dictgen::InsensitiveStr::Ascii("hopoetized"),
        dictgen::InsensitiveStr::Ascii("hopoetizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MYTHICIZATION_17936354132540285569)],
        &[(0b10010, &ENTRY_MYTHICIZE_15101061579084626306)],
        &[(0b10010, &ENTRY_MYTHICIZED_11662179048722869017)],
        &[(0b10010, &ENTRY_MYTHICIZER_11441938160492625382)],
        &[(0b10010, &ENTRY_MYTHICIZERS_2218909918152762607)],
        &[(0b10010, &ENTRY_MYTHICIZES_9101844747788591414)],
        &[(0b10010, &ENTRY_MYTHICIZING_8015028542255723699)],
        &[(0b01001, &ENTRY_MYTHICIZATION_17936354132540285569)],
        &[(0b01001, &ENTRY_MYTHICIZE_15101061579084626306)],
        &[(0b01001, &ENTRY_MYTHICIZED_11662179048722869017)],
        &[(0b01001, &ENTRY_MYTHICIZER_11441938160492625382)],
        &[(0b01001, &ENTRY_MYTHICIZERS_2218909918152762607)],
        &[(0b01001, &ENTRY_MYTHICIZES_9101844747788591414)],
        &[(0b01001, &ENTRY_MYTHICIZING_8015028542255723699)],
        &[(0b10010, &ENTRY_MYTHIZE_8683869589765306927)],
        &[(0b10010, &ENTRY_MYTHIZED_17688103185943122949)],
        &[(0b10010, &ENTRY_MYTHIZES_15782993228179635485)],
        &[(0b10010, &ENTRY_MYTHIZING_9315513939397212063)],
        &[(0b01001, &ENTRY_MYTHIZE_8683869589765306927)],
        &[(0b01001, &ENTRY_MYTHIZED_17688103185943122949)],
        &[(0b01001, &ENTRY_MYTHIZES_15782993228179635485)],
        &[(0b01001, &ENTRY_MYTHIZING_9315513939397212063)],
        &[(0b10010, &ENTRY_MYTHOLOGIZATION_14864001500968688244)],
        &[(0b10010, &ENTRY_MYTHOLOGIZATIONS_2783311720016567931)],
        &[(0b10010, &ENTRY_MYTHOLOGIZE_17851220199810661728)],
        &[(0b10010, &ENTRY_MYTHOLOGIZED_428065733344575408)],
        &[(0b10010, &ENTRY_MYTHOLOGIZER_5981916303789676389)],
        &[(0b10010, &ENTRY_MYTHOLOGIZERS_12949952831045609835)],
        &[(0b10010, &ENTRY_MYTHOLOGIZES_10098277791216764614)],
        &[(0b10010, &ENTRY_MYTHOLOGIZING_5599630321255412519)],
        &[(0b01001, &ENTRY_MYTHOLOGIZATION_14864001500968688244)],
        &[(0b01001, &ENTRY_MYTHOLOGIZATIONS_2783311720016567931)],
        &[(0b01001, &ENTRY_MYTHOLOGIZE_17851220199810661728)],
        &[(0b01001, &ENTRY_MYTHOLOGIZED_428065733344575408)],
        &[(0b01001, &ENTRY_MYTHOLOGIZER_5981916303789676389)],
        &[(0b01001, &ENTRY_MYTHOLOGIZERS_12949952831045609835)],
        &[(0b01001, &ENTRY_MYTHOLOGIZES_10098277791216764614)],
        &[(0b01001, &ENTRY_MYTHOLOGIZING_5599630321255412519)],
        &[(0b00001, &ENTRY_MYTHOPEIC_2516977976434896705)],
        &[(0b00001, &ENTRY_MYTHOPEIST_12174992698446027521)],
        &[(0b11010, &ENTRY_MYTHOPEIC_2516977976434896705)],
        &[(0b11010, &ENTRY_MYTHOPEIST_12174992698446027521)],
        &[(0b10010, &ENTRY_MYTHOPOETIZE_241863482006487994)],
        &[(0b10010, &ENTRY_MYTHOPOETIZED_11191151156378454201)],
        &[(0b10010, &ENTRY_MYTHOPOETIZING_9507303258741791727)],
        &[(0b01001, &ENTRY_MYTHOPOETIZE_241863482006487994)],
        &[(0b01001, &ENTRY_MYTHOPOETIZED_11191151156378454201)],
        &[(0b01001, &ENTRY_MYTHOPOETIZING_9507303258741791727)],
    ],
    range: 4..=13,
};

static VARS_MYS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYS_CHILDREN),
    value: None,
};

pub static VARS_MYS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MYSTICIZE_3876757555982084725)],
        &[(0b10010, &ENTRY_MYSTICIZES_16303159112289723878)],
        &[(0b01001, &ENTRY_MYSTICIZE_3876757555982084725)],
        &[(0b01001, &ENTRY_MYSTICIZES_16303159112289723878)],
    ],
    range: 6..=7,
};

static VARS_MYR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYR_CHILDREN),
    value: None,
};

pub static VARS_MYR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialiter"),
        dictgen::InsensitiveStr::Ascii("ialitre"),
        dictgen::InsensitiveStr::Ascii("iameter"),
        dictgen::InsensitiveStr::Ascii("iametre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MYRIALITER_2130498984813843028)],
        &[(0b11010, &ENTRY_MYRIALITER_2130498984813843028)],
        &[(0b00001, &ENTRY_MYRIAMETER_13815643917255154020)],
        &[(0b11010, &ENTRY_MYRIAMETER_13815643917255154020)],
    ],
    range: 7..=7,
};

static VARS_MYO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYO_CHILDREN),
    value: None,
};

pub static VARS_MYO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cele"),
        dictgen::InsensitiveStr::Ascii("coele"),
        dictgen::InsensitiveStr::Ascii("haematin"),
        dictgen::InsensitiveStr::Ascii("hematin"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MYOCELE_2113838931852125220)],
        &[(0b11010, &ENTRY_MYOCELE_2113838931852125220)],
        &[(0b11010, &ENTRY_MYOHEMATIN_5507843415397979353)],
        &[(0b10001, &ENTRY_MYOHEMATIN_5507843415397979353)],
    ],
    range: 4..=8,
};

static VARS_MYL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYL_CHILDREN),
    value: None,
};

pub static VARS_MYL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onitisation"),
        dictgen::InsensitiveStr::Ascii("onitisations"),
        dictgen::InsensitiveStr::Ascii("onitise"),
        dictgen::InsensitiveStr::Ascii("onitised"),
        dictgen::InsensitiveStr::Ascii("onitises"),
        dictgen::InsensitiveStr::Ascii("onitising"),
        dictgen::InsensitiveStr::Ascii("onitization"),
        dictgen::InsensitiveStr::Ascii("onitizations"),
        dictgen::InsensitiveStr::Ascii("onitize"),
        dictgen::InsensitiveStr::Ascii("onitized"),
        dictgen::InsensitiveStr::Ascii("onitizes"),
        dictgen::InsensitiveStr::Ascii("onitizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MYLONITIZATION_4418648514064972367)],
        &[(0b10010, &ENTRY_MYLONITIZATIONS_14425994255902394728)],
        &[(0b10010, &ENTRY_MYLONITIZE_4400772467779308928)],
        &[(0b10010, &ENTRY_MYLONITIZED_7329838352739442602)],
        &[(0b10010, &ENTRY_MYLONITIZES_5749138435299478867)],
        &[(0b10010, &ENTRY_MYLONITIZING_6531689896571343856)],
        &[(0b01001, &ENTRY_MYLONITIZATION_4418648514064972367)],
        &[(0b01001, &ENTRY_MYLONITIZATIONS_14425994255902394728)],
        &[(0b01001, &ENTRY_MYLONITIZE_4400772467779308928)],
        &[(0b01001, &ENTRY_MYLONITIZED_7329838352739442602)],
        &[(0b01001, &ENTRY_MYLONITIZES_5749138435299478867)],
        &[(0b01001, &ENTRY_MYLONITIZING_6531689896571343856)],
    ],
    range: 7..=12,
};

static VARS_MYE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYE_CHILDREN),
    value: None,
};

pub static VARS_MYE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("linisation"),
        dictgen::InsensitiveStr::Ascii("linisations"),
        dictgen::InsensitiveStr::Ascii("linization"),
        dictgen::InsensitiveStr::Ascii("linizations"),
        dictgen::InsensitiveStr::Ascii("locele"),
        dictgen::InsensitiveStr::Ascii("locoele"),
        dictgen::InsensitiveStr::Ascii("locythaemia"),
        dictgen::InsensitiveStr::Ascii("locythemia"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MYELINIZATION_8949840965904168512)],
        &[(0b10010, &ENTRY_MYELINIZATIONS_12624078092966683363)],
        &[(0b01001, &ENTRY_MYELINIZATION_8949840965904168512)],
        &[(0b01001, &ENTRY_MYELINIZATIONS_12624078092966683363)],
        &[(0b00001, &ENTRY_MYELOCELE_18333296943677670966)],
        &[(0b11010, &ENTRY_MYELOCELE_18333296943677670966)],
        &[(0b11010, &ENTRY_MYELOCYTHEMIA_1755047617775883552)],
        &[(0b10001, &ENTRY_MYELOCYTHEMIA_1755047617775883552)],
    ],
    range: 6..=11,
};

static VARS_MYC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYC_CHILDREN),
    value: None,
};

pub static VARS_MYC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ohaemia"),
        dictgen::InsensitiveStr::Ascii("ohemia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MYCOHEMIA_2984875008205372900)],
        &[(0b10001, &ENTRY_MYCOHEMIA_2984875008205372900)],
    ],
    range: 6..=7,
};

static VARS_MU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MU_CHILDREN),
    value: None,
};

static VARS_MU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_MUC_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MUL_NODE),
    Some(&VARS_MUM_NODE),
    Some(&VARS_MUN_NODE),
    None,
    None,
    None,
    Some(&VARS_MUR_NODE),
    Some(&VARS_MUS_NODE),
    Some(&VARS_MUT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_MUT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUT_CHILDREN),
    value: None,
};

pub static VARS_MUT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agenise"),
        dictgen::InsensitiveStr::Ascii("agenised"),
        dictgen::InsensitiveStr::Ascii("agenises"),
        dictgen::InsensitiveStr::Ascii("agenising"),
        dictgen::InsensitiveStr::Ascii("agenize"),
        dictgen::InsensitiveStr::Ascii("agenized"),
        dictgen::InsensitiveStr::Ascii("agenizes"),
        dictgen::InsensitiveStr::Ascii("agenizing"),
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MUTAGENIZE_13759825348433434239)],
        &[(0b10010, &ENTRY_MUTAGENIZED_17026143764789605127)],
        &[(0b10010, &ENTRY_MUTAGENIZES_15664626304885678569)],
        &[(0b10010, &ENTRY_MUTAGENIZING_9072964483829135116)],
        &[(0b01001, &ENTRY_MUTAGENIZE_13759825348433434239)],
        &[(0b01001, &ENTRY_MUTAGENIZED_17026143764789605127)],
        &[(0b01001, &ENTRY_MUTAGENIZES_15664626304885678569)],
        &[(0b01001, &ENTRY_MUTAGENIZING_9072964483829135116)],
        &[(0b10010, &ENTRY_MUTUALIZATION_2181481883879803980)],
        &[(0b10010, &ENTRY_MUTUALIZATIONS_1794203952948700713)],
        &[(0b10010, &ENTRY_MUTUALIZE_10015739606322901839)],
        &[(0b10010, &ENTRY_MUTUALIZED_4053112456469320411)],
        &[(0b10010, &ENTRY_MUTUALIZES_7068244903051623915)],
        &[(0b10010, &ENTRY_MUTUALIZING_17949149122720669838)],
        &[(0b01001, &ENTRY_MUTUALIZATION_2181481883879803980)],
        &[(0b01001, &ENTRY_MUTUALIZATIONS_1794203952948700713)],
        &[(0b01001, &ENTRY_MUTUALIZE_10015739606322901839)],
        &[(0b01001, &ENTRY_MUTUALIZED_4053112456469320411)],
        &[(0b01001, &ENTRY_MUTUALIZES_7068244903051623915)],
        &[(0b01001, &ENTRY_MUTUALIZING_17949149122720669838)],
    ],
    range: 6..=11,
};

static VARS_MUS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUS_CHILDREN),
    value: None,
};

pub static VARS_MUS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cularise"),
        dictgen::InsensitiveStr::Ascii("cularises"),
        dictgen::InsensitiveStr::Ascii("cularize"),
        dictgen::InsensitiveStr::Ascii("cularizes"),
        dictgen::InsensitiveStr::Ascii("eumise"),
        dictgen::InsensitiveStr::Ascii("eumises"),
        dictgen::InsensitiveStr::Ascii("eumize"),
        dictgen::InsensitiveStr::Ascii("eumizes"),
        dictgen::InsensitiveStr::Ascii("icalisation"),
        dictgen::InsensitiveStr::Ascii("icalisations"),
        dictgen::InsensitiveStr::Ascii("icalise"),
        dictgen::InsensitiveStr::Ascii("icalised"),
        dictgen::InsensitiveStr::Ascii("icalises"),
        dictgen::InsensitiveStr::Ascii("icalising"),
        dictgen::InsensitiveStr::Ascii("icalization"),
        dictgen::InsensitiveStr::Ascii("icalizations"),
        dictgen::InsensitiveStr::Ascii("icalize"),
        dictgen::InsensitiveStr::Ascii("icalized"),
        dictgen::InsensitiveStr::Ascii("icalizes"),
        dictgen::InsensitiveStr::Ascii("icalizing"),
        dictgen::InsensitiveStr::Ascii("tache"),
        dictgen::InsensitiveStr::Ascii("tached"),
        dictgen::InsensitiveStr::Ascii("taches"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MUSCULARIZE_2217027534398923764)],
        &[(0b10010, &ENTRY_MUSCULARIZES_13145618825512982567)],
        &[(0b01001, &ENTRY_MUSCULARIZE_2217027534398923764)],
        &[(0b01001, &ENTRY_MUSCULARIZES_13145618825512982567)],
        &[(0b10010, &ENTRY_MUSEUMIZE_1968563834894716277)],
        &[(0b10010, &ENTRY_MUSEUMIZES_6190118461441026569)],
        &[(0b01001, &ENTRY_MUSEUMIZE_1968563834894716277)],
        &[(0b01001, &ENTRY_MUSEUMIZES_6190118461441026569)],
        &[(0b10010, &ENTRY_MUSICALIZATION_6023814984289211559)],
        &[(0b10010, &ENTRY_MUSICALIZATIONS_7745580515258970558)],
        &[(0b10010, &ENTRY_MUSICALIZE_12036502854257975396)],
        &[(0b10010, &ENTRY_MUSICALIZED_12507869883696493968)],
        &[(0b10010, &ENTRY_MUSICALIZES_7781710158440353995)],
        &[(0b10010, &ENTRY_MUSICALIZING_225857687349487255)],
        &[(0b01001, &ENTRY_MUSICALIZATION_6023814984289211559)],
        &[(0b01001, &ENTRY_MUSICALIZATIONS_7745580515258970558)],
        &[(0b01001, &ENTRY_MUSICALIZE_12036502854257975396)],
        &[(0b01001, &ENTRY_MUSICALIZED_12507869883696493968)],
        &[(0b01001, &ENTRY_MUSICALIZES_7781710158440353995)],
        &[(0b01001, &ENTRY_MUSICALIZING_225857687349487255)],
        &[(0b01001, &ENTRY_MUSTACHE_14138320497461763274)],
        &[(0b00001, &ENTRY_MUSTACHED_2746912378249692800)],
        &[(0b01001, &ENTRY_MUSTACHES_1764222008694028144)],
    ],
    range: 5..=12,
};

static VARS_MUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUR_CHILDREN),
    value: None,
};

pub static VARS_MUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aena"),
        dictgen::InsensitiveStr::Ascii("aenas"),
        dictgen::InsensitiveStr::Ascii("ena"),
        dictgen::InsensitiveStr::Ascii("enas"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MURENA_3602800291326863112)],
        &[(0b11010, &ENTRY_MURENAS_18309887665811878489)],
        &[(0b00001, &ENTRY_MURENA_3602800291326863112)],
        &[(0b00001, &ENTRY_MURENAS_18309887665811878489)],
    ],
    range: 3..=5,
};

static VARS_MUN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUN_CHILDREN),
    value: None,
};

pub static VARS_MUN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icipalisation"),
        dictgen::InsensitiveStr::Ascii("icipalisations"),
        dictgen::InsensitiveStr::Ascii("icipalise"),
        dictgen::InsensitiveStr::Ascii("icipalised"),
        dictgen::InsensitiveStr::Ascii("icipaliser"),
        dictgen::InsensitiveStr::Ascii("icipalisers"),
        dictgen::InsensitiveStr::Ascii("icipalises"),
        dictgen::InsensitiveStr::Ascii("icipalising"),
        dictgen::InsensitiveStr::Ascii("icipalization"),
        dictgen::InsensitiveStr::Ascii("icipalizations"),
        dictgen::InsensitiveStr::Ascii("icipalize"),
        dictgen::InsensitiveStr::Ascii("icipalized"),
        dictgen::InsensitiveStr::Ascii("icipalizer"),
        dictgen::InsensitiveStr::Ascii("icipalizers"),
        dictgen::InsensitiveStr::Ascii("icipalizes"),
        dictgen::InsensitiveStr::Ascii("icipalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MUNICIPALIZATION_13296817045590651682)],
        &[(0b10010, &ENTRY_MUNICIPALIZATIONS_1982383937788912890)],
        &[(0b10010, &ENTRY_MUNICIPALIZE_13998151355165326582)],
        &[(0b10010, &ENTRY_MUNICIPALIZED_1893539661807241403)],
        &[(0b10010, &ENTRY_MUNICIPALIZER_8397559197205255552)],
        &[(0b10010, &ENTRY_MUNICIPALIZERS_15751974184161708637)],
        &[(0b10010, &ENTRY_MUNICIPALIZES_8777169176721386892)],
        &[(0b10010, &ENTRY_MUNICIPALIZING_6572106513172195095)],
        &[(0b01001, &ENTRY_MUNICIPALIZATION_13296817045590651682)],
        &[(0b01001, &ENTRY_MUNICIPALIZATIONS_1982383937788912890)],
        &[(0b01001, &ENTRY_MUNICIPALIZE_13998151355165326582)],
        &[(0b01001, &ENTRY_MUNICIPALIZED_1893539661807241403)],
        &[(0b01001, &ENTRY_MUNICIPALIZER_8397559197205255552)],
        &[(0b01001, &ENTRY_MUNICIPALIZERS_15751974184161708637)],
        &[(0b01001, &ENTRY_MUNICIPALIZES_8777169176721386892)],
        &[(0b01001, &ENTRY_MUNICIPALIZING_6572106513172195095)],
    ],
    range: 9..=14,
};

static VARS_MUM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUM_CHILDREN),
    value: None,
};

pub static VARS_MUM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("s")],
    values: &[&[(0b10010, &ENTRY_MOMS_12551587271348147263)]],
    range: 1..=1,
};

static VARS_MUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUL_CHILDREN),
    value: None,
};

pub static VARS_MUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ticolor"),
        dictgen::InsensitiveStr::Ascii("ticolored"),
        dictgen::InsensitiveStr::Ascii("ticoloredder"),
        dictgen::InsensitiveStr::Ascii("ticoloreddest"),
        dictgen::InsensitiveStr::Ascii("ticolorous"),
        dictgen::InsensitiveStr::Ascii("ticolors"),
        dictgen::InsensitiveStr::Ascii("ticolour"),
        dictgen::InsensitiveStr::Ascii("ticoloured"),
        dictgen::InsensitiveStr::Ascii("ticolouredder"),
        dictgen::InsensitiveStr::Ascii("ticoloureddest"),
        dictgen::InsensitiveStr::Ascii("ticolourous"),
        dictgen::InsensitiveStr::Ascii("ticolours"),
        dictgen::InsensitiveStr::Ascii("tifibered"),
        dictgen::InsensitiveStr::Ascii("tifibereds"),
        dictgen::InsensitiveStr::Ascii("tifibred"),
        dictgen::InsensitiveStr::Ascii("tifibreds"),
        dictgen::InsensitiveStr::Ascii("tileveled"),
        dictgen::InsensitiveStr::Ascii("tilevelled"),
    ],
    values: &[
        &[(0b10001, &ENTRY_MULTICOLOR_3173114956166714023)],
        &[(0b10001, &ENTRY_MULTICOLORED_12103500635627536666)],
        &[(0b10001, &ENTRY_MULTICOLOREDDER_1814659508380879098)],
        &[(0b10001, &ENTRY_MULTICOLOREDDEST_12879211592969011974)],
        &[(0b00001, &ENTRY_MULTICOLOROUS_17436796182494464863)],
        &[(0b10001, &ENTRY_MULTICOLORS_10160586035565921447)],
        &[(0b11010, &ENTRY_MULTICOLOR_3173114956166714023)],
        &[(0b11010, &ENTRY_MULTICOLORED_12103500635627536666)],
        &[(0b11010, &ENTRY_MULTICOLOREDDER_1814659508380879098)],
        &[(0b11010, &ENTRY_MULTICOLOREDDEST_12879211592969011974)],
        &[(0b11010, &ENTRY_MULTICOLOROUS_17436796182494464863)],
        &[(0b11010, &ENTRY_MULTICOLORS_10160586035565921447)],
        &[(0b00001, &ENTRY_MULTIFIBERED_9777656427319858043)],
        &[(0b00001, &ENTRY_MULTIFIBEREDS_15651140180032813198)],
        &[(0b11010, &ENTRY_MULTIFIBERED_9777656427319858043)],
        &[(0b11010, &ENTRY_MULTIFIBEREDS_15651140180032813198)],
        &[(0b00001, &ENTRY_MULTILEVELED_13761925714020978018)],
        &[(0b11010, &ENTRY_MULTILEVELED_13761925714020978018)],
    ],
    range: 7..=14,
};

static VARS_MUC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUC_CHILDREN),
    value: None,
};

pub static VARS_MUC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orrhea"),
        dictgen::InsensitiveStr::Ascii("orrhoea"),
        dictgen::InsensitiveStr::Ascii("osae"),
        dictgen::InsensitiveStr::Ascii("ose"),
    ],
    values: &[
        &[(0b10001, &ENTRY_MUCORRHEA_9758911000992883420)],
        &[(0b11010, &ENTRY_MUCORRHEA_9758911000992883420)],
        &[(0b11010, &ENTRY_MUCOSE_13290817895984668630)],
        &[(0b00001, &ENTRY_MUCOSE_13290817895984668630)],
    ],
    range: 3..=7,
};

static VARS_MO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MO_CHILDREN),
    value: None,
};

static VARS_MO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_MOB_NODE),
    None,
    Some(&VARS_MOD_NODE),
    Some(&VARS_MOE_NODE),
    None,
    Some(&VARS_MOG_NODE),
    Some(&VARS_MOH_NODE),
    Some(&VARS_MOI_NODE),
    None,
    None,
    Some(&VARS_MOL_NODE),
    Some(&VARS_MOM_NODE),
    Some(&VARS_MON_NODE),
    None,
    None,
    None,
    Some(&VARS_MOR_NODE),
    Some(&VARS_MOS_NODE),
    Some(&VARS_MOT_NODE),
    Some(&VARS_MOU_NODE),
    Some(&VARS_MOV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_MOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOV_CHILDREN),
    value: None,
};

pub static VARS_MOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("eability")],
    values: &[&[(0b00001, &ENTRY_MOVABILITY_2120736134131484989)]],
    range: 8..=8,
};

static VARS_MOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOU_CHILDREN),
    value: None,
};

pub static VARS_MOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ld"),
        dictgen::InsensitiveStr::Ascii("lded"),
        dictgen::InsensitiveStr::Ascii("lder"),
        dictgen::InsensitiveStr::Ascii("ldered"),
        dictgen::InsensitiveStr::Ascii("ldering"),
        dictgen::InsensitiveStr::Ascii("lders"),
        dictgen::InsensitiveStr::Ascii("ldier"),
        dictgen::InsensitiveStr::Ascii("ldiest"),
        dictgen::InsensitiveStr::Ascii("lding"),
        dictgen::InsensitiveStr::Ascii("ldings"),
        dictgen::InsensitiveStr::Ascii("lds"),
        dictgen::InsensitiveStr::Ascii("ldy"),
        dictgen::InsensitiveStr::Ascii("lt"),
        dictgen::InsensitiveStr::Ascii("lted"),
        dictgen::InsensitiveStr::Ascii("lting"),
        dictgen::InsensitiveStr::Ascii("lts"),
        dictgen::InsensitiveStr::Ascii("rne"),
        dictgen::InsensitiveStr::Ascii("rningly"),
        dictgen::InsensitiveStr::Ascii("stache"),
        dictgen::InsensitiveStr::Ascii("stached"),
        dictgen::InsensitiveStr::Ascii("staches"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MOLD_13654108368759432573)],
        &[(0b11010, &ENTRY_MOLDED_18226100678955103665)],
        &[(0b11010, &ENTRY_MOLDER_15465918692066970810)],
        &[(0b11010, &ENTRY_MOLDERED_4758916297507026457)],
        &[(0b11010, &ENTRY_MOLDERING_12580871299131147348)],
        &[(0b11010, &ENTRY_MOLDERS_13997118245436919961)],
        &[(0b11010, &ENTRY_MOLDIER_10922522589068582068)],
        &[(0b11010, &ENTRY_MOLDIEST_1317386157625536454)],
        &[(0b11010, &ENTRY_MOLDING_5803372015928130364)],
        &[(0b11010, &ENTRY_MOLDINGS_2565998909932841371)],
        &[(0b11010, &ENTRY_MOLDS_12422213630336798844)],
        &[(0b11010, &ENTRY_MOLDY_14321784814821274745)],
        &[(0b11010, &ENTRY_MOLT_17322314851966354350)],
        &[(0b11010, &ENTRY_MOLTED_15961459823560620603)],
        &[(0b11010, &ENTRY_MOLTING_8804427143377484509)],
        &[(0b11010, &ENTRY_MOLTS_9899279585297366446)],
        &[(0b11010, &ENTRY_MORNE_13877158832149230429)],
        &[(0b11010, &ENTRY_MORNINGLY_16758033098749460711)],
        &[(0b11010, &ENTRY_MUSTACHE_14138320497461763274)],
        &[(0b11010, &ENTRY_MUSTACHED_2746912378249692800)],
        &[(0b11010, &ENTRY_MUSTACHES_1764222008694028144)],
    ],
    range: 2..=7,
};

static VARS_MOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOT_CHILDREN),
    value: None,
};

pub static VARS_MOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MOTORIZATION_15203193516949680060)],
        &[(0b10010, &ENTRY_MOTORIZATIONS_5644703283678263848)],
        &[(0b10010, &ENTRY_MOTORIZE_8341729549011887242)],
        &[(0b10010, &ENTRY_MOTORIZED_10933184907556825861)],
        &[(0b10010, &ENTRY_MOTORIZES_16591316114722878019)],
        &[(0b10010, &ENTRY_MOTORIZING_5672986852014941836)],
        &[(0b01001, &ENTRY_MOTORIZATION_15203193516949680060)],
        &[(0b01001, &ENTRY_MOTORIZATIONS_5644703283678263848)],
        &[(0b01001, &ENTRY_MOTORIZE_8341729549011887242)],
        &[(0b01001, &ENTRY_MOTORIZED_10933184907556825861)],
        &[(0b01001, &ENTRY_MOTORIZES_16591316114722878019)],
        &[(0b01001, &ENTRY_MOTORIZING_5672986852014941836)],
    ],
    range: 5..=10,
};

static VARS_MOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOS_CHILDREN),
    value: None,
};

pub static VARS_MOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lemise"),
        dictgen::InsensitiveStr::Ascii("lemises"),
        dictgen::InsensitiveStr::Ascii("lemize"),
        dictgen::InsensitiveStr::Ascii("lemizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MOSLEMIZE_2447106069412629763)],
        &[(0b10010, &ENTRY_MOSLEMIZES_13236232024590556568)],
        &[(0b01001, &ENTRY_MOSLEMIZE_2447106069412629763)],
        &[(0b01001, &ENTRY_MOSLEMIZES_13236232024590556568)],
    ],
    range: 6..=7,
};

static VARS_MOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MOR_CHILDREN),
    value: None,
};

static VARS_MOR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MORA_NODE),
    Some(&VARS_MORB_NODE),
    None,
    None,
    Some(&VARS_MORE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MORN_NODE),
    None,
    Some(&VARS_MORP_NODE),
    None,
    None,
    Some(&VARS_MORS_NODE),
    Some(&VARS_MORT_NODE),
    Some(&VARS_MORU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_MORU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORU_CHILDREN),
    value: None,
};

pub static VARS_MORU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lae"),
        dictgen::InsensitiveStr::Ascii("le"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MORULE_13908092229635939804)],
        &[(0b00001, &ENTRY_MORULE_13908092229635939804)],
    ],
    range: 2..=3,
};

static VARS_MORT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORT_CHILDREN),
    value: None,
};

pub static VARS_MORT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MORTALIZE_14165173813480383415)],
        &[(0b10010, &ENTRY_MORTALIZED_16595582357656997017)],
        &[(0b10010, &ENTRY_MORTALIZES_3397908347506824477)],
        &[(0b10010, &ENTRY_MORTALIZING_15295132795832492104)],
        &[(0b01001, &ENTRY_MORTALIZE_14165173813480383415)],
        &[(0b01001, &ENTRY_MORTALIZED_16595582357656997017)],
        &[(0b01001, &ENTRY_MORTALIZES_3397908347506824477)],
        &[(0b01001, &ENTRY_MORTALIZING_15295132795832492104)],
        &[(0b10010, &ENTRY_MORTARIZE_8024753042638725661)],
        &[(0b10010, &ENTRY_MORTARIZES_189381837719695349)],
        &[(0b01001, &ENTRY_MORTARIZE_8024753042638725661)],
        &[(0b01001, &ENTRY_MORTARIZES_189381837719695349)],
    ],
    range: 5..=7,
};

static VARS_MORS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORS_CHILDREN),
    value: None,
};

pub static VARS_MORS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elisation"),
        dictgen::InsensitiveStr::Ascii("elisations"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elizations"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MORSELED_14726714058254476740)],
        &[(0b00001, &ENTRY_MORSELING_3101151610129962939)],
        &[(0b10010, &ENTRY_MORSELIZATION_17621367972561654648)],
        &[(0b10010, &ENTRY_MORSELIZATIONS_9222041810519154677)],
        &[(0b10010, &ENTRY_MORSELIZE_16639284457434622117)],
        &[(0b10010, &ENTRY_MORSELIZES_11440357553276262382)],
        &[(0b01001, &ENTRY_MORSELIZATION_17621367972561654648)],
        &[(0b01001, &ENTRY_MORSELIZATIONS_9222041810519154677)],
        &[(0b01001, &ENTRY_MORSELIZE_16639284457434622117)],
        &[(0b01001, &ENTRY_MORSELIZES_11440357553276262382)],
        &[(0b11010, &ENTRY_MORSELED_14726714058254476740)],
        &[(0b11010, &ENTRY_MORSELING_3101151610129962939)],
    ],
    range: 4..=10,
};

static VARS_MORP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORP_CHILDREN),
    value: None,
};

pub static VARS_MORP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hinisation"),
        dictgen::InsensitiveStr::Ascii("hinisations"),
        dictgen::InsensitiveStr::Ascii("hinise"),
        dictgen::InsensitiveStr::Ascii("hinises"),
        dictgen::InsensitiveStr::Ascii("hinization"),
        dictgen::InsensitiveStr::Ascii("hinizations"),
        dictgen::InsensitiveStr::Ascii("hinize"),
        dictgen::InsensitiveStr::Ascii("hinizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MORPHINIZATION_15722085196376554379)],
        &[(0b10010, &ENTRY_MORPHINIZATIONS_17459024898140526868)],
        &[(0b10010, &ENTRY_MORPHINIZE_1408570028954955957)],
        &[(0b10010, &ENTRY_MORPHINIZES_281525901207296974)],
        &[(0b01001, &ENTRY_MORPHINIZATION_15722085196376554379)],
        &[(0b01001, &ENTRY_MORPHINIZATIONS_17459024898140526868)],
        &[(0b01001, &ENTRY_MORPHINIZE_1408570028954955957)],
        &[(0b01001, &ENTRY_MORPHINIZES_281525901207296974)],
    ],
    range: 6..=11,
};

static VARS_MORN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORN_CHILDREN),
    value: None,
};

pub static VARS_MORN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ingly"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MORNE_13877158832149230429)],
        &[(0b00001, &ENTRY_MORNINGLY_16758033098749460711)],
    ],
    range: 1..=5,
};

static VARS_MORE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORE_CHILDREN),
    value: None,
};

pub static VARS_MORE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("a")],
    values: &[&[(0b00001, &ENTRY_MOREA_4710185171044665703)]],
    range: 1..=1,
};

static VARS_MORB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORB_CHILDREN),
    value: None,
};

pub static VARS_MORB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("idise"),
        dictgen::InsensitiveStr::Ascii("idises"),
        dictgen::InsensitiveStr::Ascii("idize"),
        dictgen::InsensitiveStr::Ascii("idizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MORBIDIZE_12078718734506704893)],
        &[(0b10010, &ENTRY_MORBIDIZES_12371432513893667541)],
        &[(0b01001, &ENTRY_MORBIDIZE_12078718734506704893)],
        &[(0b01001, &ENTRY_MORBIDIZES_12371432513893667541)],
    ],
    range: 5..=6,
};

static VARS_MORA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORA_CHILDREN),
    value: None,
};

pub static VARS_MORA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("liser"),
        dictgen::InsensitiveStr::Ascii("lisers"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lisinglies"),
        dictgen::InsensitiveStr::Ascii("lisingly"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizer"),
        dictgen::InsensitiveStr::Ascii("lizers"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
        dictgen::InsensitiveStr::Ascii("lizinglies"),
        dictgen::InsensitiveStr::Ascii("lizingly"),
        dictgen::InsensitiveStr::Ascii("vianised"),
        dictgen::InsensitiveStr::Ascii("vianiseds"),
        dictgen::InsensitiveStr::Ascii("vianized"),
        dictgen::InsensitiveStr::Ascii("vianizeds"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MOREA_4710185171044665703)],
        &[(0b10010, &ENTRY_MORALIZATION_14314788277554352162)],
        &[(0b10010, &ENTRY_MORALIZATIONS_1247598452579114999)],
        &[(0b10010, &ENTRY_MORALIZE_12018775556937054309)],
        &[(0b10010, &ENTRY_MORALIZED_16553177123856203000)],
        &[(0b10010, &ENTRY_MORALIZER_4189449725336148474)],
        &[(0b10010, &ENTRY_MORALIZERS_10483038900046187164)],
        &[(0b10010, &ENTRY_MORALIZES_9700732558433022344)],
        &[(0b10010, &ENTRY_MORALIZING_1210066302484943067)],
        &[(0b10010, &ENTRY_MORALIZINGLIES_11220751541860329137)],
        &[(0b10010, &ENTRY_MORALIZINGLY_11960315981427170808)],
        &[(0b01001, &ENTRY_MORALIZATION_14314788277554352162)],
        &[(0b01001, &ENTRY_MORALIZATIONS_1247598452579114999)],
        &[(0b01001, &ENTRY_MORALIZE_12018775556937054309)],
        &[(0b01001, &ENTRY_MORALIZED_16553177123856203000)],
        &[(0b01001, &ENTRY_MORALIZER_4189449725336148474)],
        &[(0b01001, &ENTRY_MORALIZERS_10483038900046187164)],
        &[(0b01001, &ENTRY_MORALIZES_9700732558433022344)],
        &[(0b01001, &ENTRY_MORALIZING_1210066302484943067)],
        &[(0b01001, &ENTRY_MORALIZINGLIES_11220751541860329137)],
        &[(0b01001, &ENTRY_MORALIZINGLY_11960315981427170808)],
        &[(0b10010, &ENTRY_MORAVIANIZED_14670220446741413727)],
        &[(0b10010, &ENTRY_MORAVIANIZEDS_13353558936917116925)],
        &[(0b01001, &ENTRY_MORAVIANIZED_14670220446741413727)],
        &[(0b01001, &ENTRY_MORAVIANIZEDS_13353558936917116925)],
    ],
    range: 2..=10,
};

static VARS_MON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MON_CHILDREN),
    value: None,
};

static VARS_MON_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MONA_NODE),
    None,
    None,
    None,
    Some(&VARS_MONE_NODE),
    None,
    Some(&VARS_MONG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MONO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MONU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_MONU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MONU_CHILDREN),
    value: None,
};

pub static VARS_MONU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mentalisation"),
        dictgen::InsensitiveStr::Ascii("mentalisations"),
        dictgen::InsensitiveStr::Ascii("mentalise"),
        dictgen::InsensitiveStr::Ascii("mentalised"),
        dictgen::InsensitiveStr::Ascii("mentalises"),
        dictgen::InsensitiveStr::Ascii("mentalising"),
        dictgen::InsensitiveStr::Ascii("mentalization"),
        dictgen::InsensitiveStr::Ascii("mentalizations"),
        dictgen::InsensitiveStr::Ascii("mentalize"),
        dictgen::InsensitiveStr::Ascii("mentalized"),
        dictgen::InsensitiveStr::Ascii("mentalizes"),
        dictgen::InsensitiveStr::Ascii("mentalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MONUMENTALIZATION_2612437042934297805)],
        &[(0b10010, &ENTRY_MONUMENTALIZATIONS_4951631867947876343)],
        &[(0b10010, &ENTRY_MONUMENTALIZE_13392828455281638997)],
        &[(0b10010, &ENTRY_MONUMENTALIZED_5711079078755470487)],
        &[(0b10010, &ENTRY_MONUMENTALIZES_504136983336154068)],
        &[(0b10010, &ENTRY_MONUMENTALIZING_135723146422787131)],
        &[(0b01001, &ENTRY_MONUMENTALIZATION_2612437042934297805)],
        &[(0b01001, &ENTRY_MONUMENTALIZATIONS_4951631867947876343)],
        &[(0b01001, &ENTRY_MONUMENTALIZE_13392828455281638997)],
        &[(0b01001, &ENTRY_MONUMENTALIZED_5711079078755470487)],
        &[(0b01001, &ENTRY_MONUMENTALIZES_504136983336154068)],
        &[(0b01001, &ENTRY_MONUMENTALIZING_135723146422787131)],
    ],
    range: 9..=14,
};

static VARS_MONO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MONO_CHILDREN),
    value: None,
};

pub static VARS_MONO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chordise"),
        dictgen::InsensitiveStr::Ascii("chordises"),
        dictgen::InsensitiveStr::Ascii("chordize"),
        dictgen::InsensitiveStr::Ascii("chordizes"),
        dictgen::InsensitiveStr::Ascii("ecian"),
        dictgen::InsensitiveStr::Ascii("estrous"),
        dictgen::InsensitiveStr::Ascii("log"),
        dictgen::InsensitiveStr::Ascii("logise"),
        dictgen::InsensitiveStr::Ascii("logised"),
        dictgen::InsensitiveStr::Ascii("logises"),
        dictgen::InsensitiveStr::Ascii("logising"),
        dictgen::InsensitiveStr::Ascii("logize"),
        dictgen::InsensitiveStr::Ascii("logized"),
        dictgen::InsensitiveStr::Ascii("logizes"),
        dictgen::InsensitiveStr::Ascii("logizing"),
        dictgen::InsensitiveStr::Ascii("logs"),
        dictgen::InsensitiveStr::Ascii("loguise"),
        dictgen::InsensitiveStr::Ascii("loguised"),
        dictgen::InsensitiveStr::Ascii("loguises"),
        dictgen::InsensitiveStr::Ascii("loguising"),
        dictgen::InsensitiveStr::Ascii("loguize"),
        dictgen::InsensitiveStr::Ascii("loguized"),
        dictgen::InsensitiveStr::Ascii("loguizes"),
        dictgen::InsensitiveStr::Ascii("loguizing"),
        dictgen::InsensitiveStr::Ascii("metalism"),
        dictgen::InsensitiveStr::Ascii("metalist"),
        dictgen::InsensitiveStr::Ascii("metallism"),
        dictgen::InsensitiveStr::Ascii("metallist"),
        dictgen::InsensitiveStr::Ascii("phthongise"),
        dictgen::InsensitiveStr::Ascii("phthongised"),
        dictgen::InsensitiveStr::Ascii("phthongises"),
        dictgen::InsensitiveStr::Ascii("phthongising"),
        dictgen::InsensitiveStr::Ascii("phthongize"),
        dictgen::InsensitiveStr::Ascii("phthongized"),
        dictgen::InsensitiveStr::Ascii("phthongizes"),
        dictgen::InsensitiveStr::Ascii("phthongizing"),
        dictgen::InsensitiveStr::Ascii("polisable"),
        dictgen::InsensitiveStr::Ascii("polisables"),
        dictgen::InsensitiveStr::Ascii("polisation"),
        dictgen::InsensitiveStr::Ascii("polisations"),
        dictgen::InsensitiveStr::Ascii("polise"),
        dictgen::InsensitiveStr::Ascii("polised"),
        dictgen::InsensitiveStr::Ascii("poliser"),
        dictgen::InsensitiveStr::Ascii("polisers"),
        dictgen::InsensitiveStr::Ascii("polises"),
        dictgen::InsensitiveStr::Ascii("polising"),
        dictgen::InsensitiveStr::Ascii("polizable"),
        dictgen::InsensitiveStr::Ascii("polizables"),
        dictgen::InsensitiveStr::Ascii("polization"),
        dictgen::InsensitiveStr::Ascii("polizations"),
        dictgen::InsensitiveStr::Ascii("polize"),
        dictgen::InsensitiveStr::Ascii("polized"),
        dictgen::InsensitiveStr::Ascii("polizer"),
        dictgen::InsensitiveStr::Ascii("polizers"),
        dictgen::InsensitiveStr::Ascii("polizes"),
        dictgen::InsensitiveStr::Ascii("polizing"),
        dictgen::InsensitiveStr::Ascii("tonise"),
        dictgen::InsensitiveStr::Ascii("tonises"),
        dictgen::InsensitiveStr::Ascii("tonize"),
        dictgen::InsensitiveStr::Ascii("tonizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MONOCHORDIZE_9437961652627754770)],
        &[(0b10010, &ENTRY_MONOCHORDIZES_5615164871706853064)],
        &[(0b01001, &ENTRY_MONOCHORDIZE_9437961652627754770)],
        &[(0b01001, &ENTRY_MONOCHORDIZES_5615164871706853064)],
        &[(0b11010, &ENTRY_MONECIAN_11450168883673844089)],
        &[(0b11010, &ENTRY_MONESTROUS_6196258053360644210)],
        &[(0b00001, &ENTRY_MONOLOGUE_3143921545359140083)],
        &[(0b10010, &ENTRY_MONOLOGIZE_16201429293272246013)],
        &[(0b10010, &ENTRY_MONOLOGIZED_16156031911401991864)],
        &[(0b10010, &ENTRY_MONOLOGIZES_13918596476650442746)],
        &[(0b10010, &ENTRY_MONOLOGIZING_11961970835142712480)],
        &[(0b01001, &ENTRY_MONOLOGIZE_16201429293272246013)],
        &[(0b01001, &ENTRY_MONOLOGIZED_16156031911401991864)],
        &[(0b01001, &ENTRY_MONOLOGIZES_13918596476650442746)],
        &[(0b01001, &ENTRY_MONOLOGIZING_11961970835142712480)],
        &[(0b00001, &ENTRY_MONOLOGUES_17834811023314193123)],
        &[(0b10010, &ENTRY_MONOLOGUIZE_5977110452781416925)],
        &[(0b10010, &ENTRY_MONOLOGUIZED_5963649767345305434)],
        &[(0b10010, &ENTRY_MONOLOGUIZES_40954755333017747)],
        &[(0b10010, &ENTRY_MONOLOGUIZING_8885404513109687921)],
        &[(0b01001, &ENTRY_MONOLOGUIZE_5977110452781416925)],
        &[(0b01001, &ENTRY_MONOLOGUIZED_5963649767345305434)],
        &[(0b01001, &ENTRY_MONOLOGUIZES_40954755333017747)],
        &[(0b01001, &ENTRY_MONOLOGUIZING_8885404513109687921)],
        &[(0b00001, &ENTRY_MONOMETALISM_6551087928155711829)],
        &[(0b00001, &ENTRY_MONOMETALIST_14189662387309527600)],
        &[(0b11010, &ENTRY_MONOMETALISM_6551087928155711829)],
        &[(0b11010, &ENTRY_MONOMETALIST_14189662387309527600)],
        &[(0b10010, &ENTRY_MONOPHTHONGIZE_15472653960750438186)],
        &[(0b10010, &ENTRY_MONOPHTHONGIZED_10522312864287160124)],
        &[(0b10010, &ENTRY_MONOPHTHONGIZES_3680420610763632670)],
        &[(0b10010, &ENTRY_MONOPHTHONGIZING_5513151536385246373)],
        &[(0b01001, &ENTRY_MONOPHTHONGIZE_15472653960750438186)],
        &[(0b01001, &ENTRY_MONOPHTHONGIZED_10522312864287160124)],
        &[(0b01001, &ENTRY_MONOPHTHONGIZES_3680420610763632670)],
        &[(0b01001, &ENTRY_MONOPHTHONGIZING_5513151536385246373)],
        &[(0b10010, &ENTRY_MONOPOLIZABLE_9755797109480546894)],
        &[(0b10010, &ENTRY_MONOPOLIZABLES_8954416702263834797)],
        &[(0b10010, &ENTRY_MONOPOLIZATION_17799440194255806413)],
        &[(0b10010, &ENTRY_MONOPOLIZATIONS_10067342361986951454)],
        &[(0b10010, &ENTRY_MONOPOLIZE_7442479439377420004)],
        &[(0b10010, &ENTRY_MONOPOLIZED_12340647197458384203)],
        &[(0b10010, &ENTRY_MONOPOLIZER_2371550496160060744)],
        &[(0b10010, &ENTRY_MONOPOLIZERS_6125991689529832032)],
        &[(0b10010, &ENTRY_MONOPOLIZES_12189941398566584704)],
        &[(0b10010, &ENTRY_MONOPOLIZING_16637234271263734393)],
        &[(0b01001, &ENTRY_MONOPOLIZABLE_9755797109480546894)],
        &[(0b01001, &ENTRY_MONOPOLIZABLES_8954416702263834797)],
        &[(0b01001, &ENTRY_MONOPOLIZATION_17799440194255806413)],
        &[(0b01001, &ENTRY_MONOPOLIZATIONS_10067342361986951454)],
        &[(0b01001, &ENTRY_MONOPOLIZE_7442479439377420004)],
        &[(0b01001, &ENTRY_MONOPOLIZED_12340647197458384203)],
        &[(0b01001, &ENTRY_MONOPOLIZER_2371550496160060744)],
        &[(0b01001, &ENTRY_MONOPOLIZERS_6125991689529832032)],
        &[(0b01001, &ENTRY_MONOPOLIZES_12189941398566584704)],
        &[(0b01001, &ENTRY_MONOPOLIZING_16637234271263734393)],
        &[(0b10010, &ENTRY_MONOTONIZE_11597278597980404355)],
        &[(0b10010, &ENTRY_MONOTONIZES_3864188890843789110)],
        &[(0b01001, &ENTRY_MONOTONIZE_11597278597980404355)],
        &[(0b01001, &ENTRY_MONOTONIZES_3864188890843789110)],
    ],
    range: 3..=12,
};

static VARS_MONG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MONG_CHILDREN),
    value: None,
};

pub static VARS_MONG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
        dictgen::InsensitiveStr::Ascii("relisation"),
        dictgen::InsensitiveStr::Ascii("relisations"),
        dictgen::InsensitiveStr::Ascii("relise"),
        dictgen::InsensitiveStr::Ascii("relised"),
        dictgen::InsensitiveStr::Ascii("reliser"),
        dictgen::InsensitiveStr::Ascii("relises"),
        dictgen::InsensitiveStr::Ascii("relising"),
        dictgen::InsensitiveStr::Ascii("relization"),
        dictgen::InsensitiveStr::Ascii("relizations"),
        dictgen::InsensitiveStr::Ascii("relize"),
        dictgen::InsensitiveStr::Ascii("relized"),
        dictgen::InsensitiveStr::Ascii("relizer"),
        dictgen::InsensitiveStr::Ascii("relizes"),
        dictgen::InsensitiveStr::Ascii("relizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MONGOLIZE_9713647571907152281)],
        &[(0b10010, &ENTRY_MONGOLIZED_5299121885656590363)],
        &[(0b10010, &ENTRY_MONGOLIZES_14085267755452553789)],
        &[(0b10010, &ENTRY_MONGOLIZING_1384426201759162743)],
        &[(0b01001, &ENTRY_MONGOLIZE_9713647571907152281)],
        &[(0b01001, &ENTRY_MONGOLIZED_5299121885656590363)],
        &[(0b01001, &ENTRY_MONGOLIZES_14085267755452553789)],
        &[(0b01001, &ENTRY_MONGOLIZING_1384426201759162743)],
        &[(0b10010, &ENTRY_MONGRELIZATION_15091053595967389048)],
        &[(0b10010, &ENTRY_MONGRELIZATIONS_2436371981269651275)],
        &[(0b10010, &ENTRY_MONGRELIZE_11229468945460271254)],
        &[(0b10010, &ENTRY_MONGRELIZED_8363623153012541092)],
        &[(0b10010, &ENTRY_MONGRELIZER_13839004276754308084)],
        &[(0b10010, &ENTRY_MONGRELIZES_8947086149363047319)],
        &[(0b10010, &ENTRY_MONGRELIZING_5997412177056765410)],
        &[(0b01001, &ENTRY_MONGRELIZATION_15091053595967389048)],
        &[(0b01001, &ENTRY_MONGRELIZATIONS_2436371981269651275)],
        &[(0b01001, &ENTRY_MONGRELIZE_11229468945460271254)],
        &[(0b01001, &ENTRY_MONGRELIZED_8363623153012541092)],
        &[(0b01001, &ENTRY_MONGRELIZER_13839004276754308084)],
        &[(0b01001, &ENTRY_MONGRELIZES_8947086149363047319)],
        &[(0b01001, &ENTRY_MONGRELIZING_5997412177056765410)],
    ],
    range: 5..=11,
};

static VARS_MONE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MONE_CHILDREN),
    value: None,
};

pub static VARS_MONE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cian"),
        dictgen::InsensitiveStr::Ascii("cious"),
        dictgen::InsensitiveStr::Ascii("strous"),
        dictgen::InsensitiveStr::Ascii("tisation"),
        dictgen::InsensitiveStr::Ascii("tisations"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tization"),
        dictgen::InsensitiveStr::Ascii("tizations"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MONECIAN_11450168883673844089)],
        &[(0b00001, &ENTRY_MONOECIOUS_9746279935101117316)],
        &[(0b00001, &ENTRY_MONESTROUS_6196258053360644210)],
        &[(0b10010, &ENTRY_MONETIZATION_13483845355572497348)],
        &[(0b10010, &ENTRY_MONETIZATIONS_14358715948666978904)],
        &[(0b10010, &ENTRY_MONETIZE_8502079722472007377)],
        &[(0b10010, &ENTRY_MONETIZED_9484572886023410910)],
        &[(0b10010, &ENTRY_MONETIZES_5492661646680399709)],
        &[(0b10010, &ENTRY_MONETIZING_3083227925499032589)],
        &[(0b01001, &ENTRY_MONETIZATION_13483845355572497348)],
        &[(0b01001, &ENTRY_MONETIZATIONS_14358715948666978904)],
        &[(0b01001, &ENTRY_MONETIZE_8502079722472007377)],
        &[(0b01001, &ENTRY_MONETIZED_9484572886023410910)],
        &[(0b01001, &ENTRY_MONETIZES_5492661646680399709)],
        &[(0b01001, &ENTRY_MONETIZING_3083227925499032589)],
    ],
    range: 4..=9,
};

static VARS_MONA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MONA_CHILDREN),
    value: None,
};

pub static VARS_MONA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rchise"),
        dictgen::InsensitiveStr::Ascii("rchised"),
        dictgen::InsensitiveStr::Ascii("rchiser"),
        dictgen::InsensitiveStr::Ascii("rchisers"),
        dictgen::InsensitiveStr::Ascii("rchises"),
        dictgen::InsensitiveStr::Ascii("rchising"),
        dictgen::InsensitiveStr::Ascii("rchize"),
        dictgen::InsensitiveStr::Ascii("rchized"),
        dictgen::InsensitiveStr::Ascii("rchizer"),
        dictgen::InsensitiveStr::Ascii("rchizers"),
        dictgen::InsensitiveStr::Ascii("rchizes"),
        dictgen::InsensitiveStr::Ascii("rchizing"),
        dictgen::InsensitiveStr::Ascii("sticise"),
        dictgen::InsensitiveStr::Ascii("sticises"),
        dictgen::InsensitiveStr::Ascii("sticize"),
        dictgen::InsensitiveStr::Ascii("sticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MONARCHIZE_9559277820673512352)],
        &[(0b10010, &ENTRY_MONARCHIZED_14485113839253836143)],
        &[(0b10010, &ENTRY_MONARCHIZER_4284095516115676620)],
        &[(0b10010, &ENTRY_MONARCHIZERS_9930135356106528857)],
        &[(0b10010, &ENTRY_MONARCHIZES_8572784744664864851)],
        &[(0b10010, &ENTRY_MONARCHIZING_7759908511293928199)],
        &[(0b01001, &ENTRY_MONARCHIZE_9559277820673512352)],
        &[(0b01001, &ENTRY_MONARCHIZED_14485113839253836143)],
        &[(0b01001, &ENTRY_MONARCHIZER_4284095516115676620)],
        &[(0b01001, &ENTRY_MONARCHIZERS_9930135356106528857)],
        &[(0b01001, &ENTRY_MONARCHIZES_8572784744664864851)],
        &[(0b01001, &ENTRY_MONARCHIZING_7759908511293928199)],
        &[(0b10010, &ENTRY_MONASTICIZE_8704681192852397467)],
        &[(0b10010, &ENTRY_MONASTICIZES_5305902420161432780)],
        &[(0b01001, &ENTRY_MONASTICIZE_8704681192852397467)],
        &[(0b01001, &ENTRY_MONASTICIZES_5305902420161432780)],
    ],
    range: 6..=8,
};

static VARS_MOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOM_CHILDREN),
    value: Some(&[(0b01001, &ENTRY_MOM_5106551349804515206)]),
};

pub static VARS_MOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("s")],
    values: &[&[(0b01001, &ENTRY_MOMS_12551587271348147263)]],
    range: 1..=1,
};

static VARS_MOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOL_CHILDREN),
    value: None,
};

pub static VARS_MOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arisation"),
        dictgen::InsensitiveStr::Ascii("arisations"),
        dictgen::InsensitiveStr::Ascii("arization"),
        dictgen::InsensitiveStr::Ascii("arizations"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("ded"),
        dictgen::InsensitiveStr::Ascii("der"),
        dictgen::InsensitiveStr::Ascii("dered"),
        dictgen::InsensitiveStr::Ascii("dering"),
        dictgen::InsensitiveStr::Ascii("ders"),
        dictgen::InsensitiveStr::Ascii("dier"),
        dictgen::InsensitiveStr::Ascii("diest"),
        dictgen::InsensitiveStr::Ascii("ding"),
        dictgen::InsensitiveStr::Ascii("dings"),
        dictgen::InsensitiveStr::Ascii("ds"),
        dictgen::InsensitiveStr::Ascii("dy"),
        dictgen::InsensitiveStr::Ascii("lusk"),
        dictgen::InsensitiveStr::Ascii("luskan"),
        dictgen::InsensitiveStr::Ascii("lusks"),
        dictgen::InsensitiveStr::Ascii("ochise"),
        dictgen::InsensitiveStr::Ascii("ochised"),
        dictgen::InsensitiveStr::Ascii("ochises"),
        dictgen::InsensitiveStr::Ascii("ochising"),
        dictgen::InsensitiveStr::Ascii("ochize"),
        dictgen::InsensitiveStr::Ascii("ochized"),
        dictgen::InsensitiveStr::Ascii("ochizes"),
        dictgen::InsensitiveStr::Ascii("ochizing"),
        dictgen::InsensitiveStr::Ascii("t"),
        dictgen::InsensitiveStr::Ascii("ted"),
        dictgen::InsensitiveStr::Ascii("ting"),
        dictgen::InsensitiveStr::Ascii("ts"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MOLARIZATION_13660005087668514663)],
        &[(0b10010, &ENTRY_MOLARIZATIONS_16507279008859766734)],
        &[(0b01001, &ENTRY_MOLARIZATION_13660005087668514663)],
        &[(0b01001, &ENTRY_MOLARIZATIONS_16507279008859766734)],
        &[(0b11001, &ENTRY_MOLD_13654108368759432573)],
        &[(0b11001, &ENTRY_MOLDED_18226100678955103665)],
        &[(0b10001, &ENTRY_MOLDER_15465918692066970810)],
        &[(0b10001, &ENTRY_MOLDERED_4758916297507026457)],
        &[(0b10001, &ENTRY_MOLDERING_12580871299131147348)],
        &[(0b10001, &ENTRY_MOLDERS_13997118245436919961)],
        &[(0b11001, &ENTRY_MOLDIER_10922522589068582068)],
        &[(0b11001, &ENTRY_MOLDIEST_1317386157625536454)],
        &[(0b11001, &ENTRY_MOLDING_5803372015928130364)],
        &[(0b11001, &ENTRY_MOLDINGS_2565998909932841371)],
        &[(0b11001, &ENTRY_MOLDS_12422213630336798844)],
        &[(0b11001, &ENTRY_MOLDY_14321784814821274745)],
        &[(0b00001, &ENTRY_MOLLUSK_6823511292751098286)],
        &[(0b00001, &ENTRY_MOLLUSCAN_17330317330413879995)],
        &[(0b00001, &ENTRY_MOLLUSKS_7011160555842704825)],
        &[(0b10010, &ENTRY_MOLOCHIZE_18208589110973869272)],
        &[(0b10010, &ENTRY_MOLOCHIZED_821791843761212929)],
        &[(0b10010, &ENTRY_MOLOCHIZES_4165788617829197688)],
        &[(0b10010, &ENTRY_MOLOCHIZING_2091155534102840219)],
        &[(0b01001, &ENTRY_MOLOCHIZE_18208589110973869272)],
        &[(0b01001, &ENTRY_MOLOCHIZED_821791843761212929)],
        &[(0b01001, &ENTRY_MOLOCHIZES_4165788617829197688)],
        &[(0b01001, &ENTRY_MOLOCHIZING_2091155534102840219)],
        &[(0b10001, &ENTRY_MOLT_17322314851966354350)],
        &[(0b10001, &ENTRY_MOLTED_15961459823560620603)],
        &[(0b10001, &ENTRY_MOLTING_8804427143377484509)],
        &[(0b10001, &ENTRY_MOLTS_9899279585297366446)],
    ],
    range: 1..=10,
};

static VARS_MOI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOI_CHILDREN),
    value: None,
};

pub static VARS_MOI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sturisation"),
        dictgen::InsensitiveStr::Ascii("sturise"),
        dictgen::InsensitiveStr::Ascii("sturised"),
        dictgen::InsensitiveStr::Ascii("sturiser"),
        dictgen::InsensitiveStr::Ascii("sturisers"),
        dictgen::InsensitiveStr::Ascii("sturises"),
        dictgen::InsensitiveStr::Ascii("sturising"),
        dictgen::InsensitiveStr::Ascii("sturization"),
        dictgen::InsensitiveStr::Ascii("sturize"),
        dictgen::InsensitiveStr::Ascii("sturized"),
        dictgen::InsensitiveStr::Ascii("sturizer"),
        dictgen::InsensitiveStr::Ascii("sturizers"),
        dictgen::InsensitiveStr::Ascii("sturizes"),
        dictgen::InsensitiveStr::Ascii("sturizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MOISTURIZATION_10380414116064573146)],
        &[(0b10010, &ENTRY_MOISTURIZE_3082181073277609007)],
        &[(0b10010, &ENTRY_MOISTURIZED_16147661633583544526)],
        &[(0b10010, &ENTRY_MOISTURIZER_976074536579829817)],
        &[(0b10010, &ENTRY_MOISTURIZERS_9974196958240719712)],
        &[(0b10010, &ENTRY_MOISTURIZES_5386452103898759766)],
        &[(0b10010, &ENTRY_MOISTURIZING_1153301405850895778)],
        &[(0b01001, &ENTRY_MOISTURIZATION_10380414116064573146)],
        &[(0b01001, &ENTRY_MOISTURIZE_3082181073277609007)],
        &[(0b01001, &ENTRY_MOISTURIZED_16147661633583544526)],
        &[(0b01001, &ENTRY_MOISTURIZER_976074536579829817)],
        &[(0b01001, &ENTRY_MOISTURIZERS_9974196958240719712)],
        &[(0b01001, &ENTRY_MOISTURIZES_5386452103898759766)],
        &[(0b01001, &ENTRY_MOISTURIZING_1153301405850895778)],
    ],
    range: 7..=11,
};

static VARS_MOH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOH_CHILDREN),
    value: None,
};

pub static VARS_MOH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ammedanisation"),
        dictgen::InsensitiveStr::Ascii("ammedanisations"),
        dictgen::InsensitiveStr::Ascii("ammedanise"),
        dictgen::InsensitiveStr::Ascii("ammedanised"),
        dictgen::InsensitiveStr::Ascii("ammedanises"),
        dictgen::InsensitiveStr::Ascii("ammedanising"),
        dictgen::InsensitiveStr::Ascii("ammedanization"),
        dictgen::InsensitiveStr::Ascii("ammedanizations"),
        dictgen::InsensitiveStr::Ascii("ammedanize"),
        dictgen::InsensitiveStr::Ascii("ammedanized"),
        dictgen::InsensitiveStr::Ascii("ammedanizes"),
        dictgen::InsensitiveStr::Ascii("ammedanizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MOHAMMEDANIZATION_16744967596386683848)],
        &[(0b10010, &ENTRY_MOHAMMEDANIZATIONS_17148982401883279782)],
        &[(0b10010, &ENTRY_MOHAMMEDANIZE_2013237486051435987)],
        &[(0b10010, &ENTRY_MOHAMMEDANIZED_15191782132430589893)],
        &[(0b10010, &ENTRY_MOHAMMEDANIZES_4957996437102920437)],
        &[(0b10010, &ENTRY_MOHAMMEDANIZING_16231921957501731765)],
        &[(0b01001, &ENTRY_MOHAMMEDANIZATION_16744967596386683848)],
        &[(0b01001, &ENTRY_MOHAMMEDANIZATIONS_17148982401883279782)],
        &[(0b01001, &ENTRY_MOHAMMEDANIZE_2013237486051435987)],
        &[(0b01001, &ENTRY_MOHAMMEDANIZED_15191782132430589893)],
        &[(0b01001, &ENTRY_MOHAMMEDANIZES_4957996437102920437)],
        &[(0b01001, &ENTRY_MOHAMMEDANIZING_16231921957501731765)],
    ],
    range: 10..=15,
};

static VARS_MOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOG_CHILDREN),
    value: None,
};

pub static VARS_MOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("gy")],
    values: &[&[(0b10011, &ENTRY_MOGGY_7403358484289979778)]],
    range: 2..=2,
};

static VARS_MOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOE_CHILDREN),
    value: None,
};

pub static VARS_MOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ck"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("llon"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MECK_5007702210116580279)],
        &[(0b11010, &ENTRY_MED_5005187106832009132)],
        &[(0b11010, &ENTRY_MELLON_660640033212487292)],
    ],
    range: 1..=4,
};

static VARS_MOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOD_CHILDREN),
    value: None,
};

pub static VARS_MOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
        dictgen::InsensitiveStr::Ascii("ernisable"),
        dictgen::InsensitiveStr::Ascii("ernisables"),
        dictgen::InsensitiveStr::Ascii("ernisation"),
        dictgen::InsensitiveStr::Ascii("ernisations"),
        dictgen::InsensitiveStr::Ascii("ernise"),
        dictgen::InsensitiveStr::Ascii("ernised"),
        dictgen::InsensitiveStr::Ascii("erniser"),
        dictgen::InsensitiveStr::Ascii("ernisers"),
        dictgen::InsensitiveStr::Ascii("ernises"),
        dictgen::InsensitiveStr::Ascii("ernising"),
        dictgen::InsensitiveStr::Ascii("ernizable"),
        dictgen::InsensitiveStr::Ascii("ernizables"),
        dictgen::InsensitiveStr::Ascii("ernization"),
        dictgen::InsensitiveStr::Ascii("ernizations"),
        dictgen::InsensitiveStr::Ascii("ernize"),
        dictgen::InsensitiveStr::Ascii("ernized"),
        dictgen::InsensitiveStr::Ascii("ernizer"),
        dictgen::InsensitiveStr::Ascii("ernizers"),
        dictgen::InsensitiveStr::Ascii("ernizes"),
        dictgen::InsensitiveStr::Ascii("ernizing"),
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularised"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularising"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularized"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("ularizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MODALIZE_16350838792808777521)],
        &[(0b10010, &ENTRY_MODALIZES_11613635884904143996)],
        &[(0b01001, &ENTRY_MODALIZE_16350838792808777521)],
        &[(0b01001, &ENTRY_MODALIZES_11613635884904143996)],
        &[(0b00001, &ENTRY_MODELED_12650479689070423426)],
        &[(0b00001, &ENTRY_MODELER_14424786862458395262)],
        &[(0b00001, &ENTRY_MODELERS_3381426157906439456)],
        &[(0b00001, &ENTRY_MODELING_2974344260900643587)],
        &[(0b00001, &ENTRY_MODELINGS_18288599171721945682)],
        &[(0b11010, &ENTRY_MODELED_12650479689070423426)],
        &[(0b11010, &ENTRY_MODELER_14424786862458395262)],
        &[(0b11010, &ENTRY_MODELERS_3381426157906439456)],
        &[(0b11010, &ENTRY_MODELING_2974344260900643587)],
        &[(0b11010, &ENTRY_MODELINGS_18288599171721945682)],
        &[(0b10010, &ENTRY_MODERNIZABLE_2241201696674028296)],
        &[(0b10010, &ENTRY_MODERNIZABLES_17762667775078181032)],
        &[(0b10010, &ENTRY_MODERNIZATION_14709070202714057545)],
        &[(0b10010, &ENTRY_MODERNIZATIONS_11584063023767292185)],
        &[(0b10010, &ENTRY_MODERNIZE_7510605744058517470)],
        &[(0b10010, &ENTRY_MODERNIZED_16345622123558324284)],
        &[(0b10010, &ENTRY_MODERNIZER_18233663007102441685)],
        &[(0b10010, &ENTRY_MODERNIZERS_17286474013116987617)],
        &[(0b10010, &ENTRY_MODERNIZES_12697791365347916756)],
        &[(0b10010, &ENTRY_MODERNIZING_5025029940522757107)],
        &[(0b01001, &ENTRY_MODERNIZABLE_2241201696674028296)],
        &[(0b01001, &ENTRY_MODERNIZABLES_17762667775078181032)],
        &[(0b01001, &ENTRY_MODERNIZATION_14709070202714057545)],
        &[(0b01001, &ENTRY_MODERNIZATIONS_11584063023767292185)],
        &[(0b01001, &ENTRY_MODERNIZE_7510605744058517470)],
        &[(0b01001, &ENTRY_MODERNIZED_16345622123558324284)],
        &[(0b01001, &ENTRY_MODERNIZER_18233663007102441685)],
        &[(0b01001, &ENTRY_MODERNIZERS_17286474013116987617)],
        &[(0b01001, &ENTRY_MODERNIZES_12697791365347916756)],
        &[(0b01001, &ENTRY_MODERNIZING_5025029940522757107)],
        &[(0b10010, &ENTRY_MODULARIZATION_1558183326417358953)],
        &[(0b10010, &ENTRY_MODULARIZE_2749267996562714054)],
        &[(0b10010, &ENTRY_MODULARIZED_10761682201246036312)],
        &[(0b10010, &ENTRY_MODULARIZES_14876821131445153583)],
        &[(0b10010, &ENTRY_MODULARIZING_18092728005779185876)],
        &[(0b01001, &ENTRY_MODULARIZATION_1558183326417358953)],
        &[(0b01001, &ENTRY_MODULARIZE_2749267996562714054)],
        &[(0b01001, &ENTRY_MODULARIZED_10761682201246036312)],
        &[(0b01001, &ENTRY_MODULARIZES_14876821131445153583)],
        &[(0b01001, &ENTRY_MODULARIZING_18092728005779185876)],
    ],
    range: 4..=11,
};

static VARS_MOB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOB_CHILDREN),
    value: None,
};

pub static VARS_MOB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilisable"),
        dictgen::InsensitiveStr::Ascii("ilisabler"),
        dictgen::InsensitiveStr::Ascii("ilisables"),
        dictgen::InsensitiveStr::Ascii("ilisablest"),
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("iliser"),
        dictgen::InsensitiveStr::Ascii("ilisers"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilizable"),
        dictgen::InsensitiveStr::Ascii("ilizabler"),
        dictgen::InsensitiveStr::Ascii("ilizables"),
        dictgen::InsensitiveStr::Ascii("ilizablest"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizer"),
        dictgen::InsensitiveStr::Ascii("ilizers"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MOBILIZABLE_4838354601271065797)],
        &[(0b10010, &ENTRY_MOBILIZABLER_550692436973252168)],
        &[(0b10010, &ENTRY_MOBILIZABLES_13069683708079300928)],
        &[(0b10010, &ENTRY_MOBILIZABLEST_2936215873432536207)],
        &[(0b10010, &ENTRY_MOBILIZATION_5777426368387580657)],
        &[(0b10010, &ENTRY_MOBILIZATIONS_14453487133355314782)],
        &[(0b10010, &ENTRY_MOBILIZE_8789464231798787986)],
        &[(0b10010, &ENTRY_MOBILIZED_5804933841881642219)],
        &[(0b10010, &ENTRY_MOBILIZER_10343085295594491112)],
        &[(0b10010, &ENTRY_MOBILIZERS_3858507952045243762)],
        &[(0b10010, &ENTRY_MOBILIZES_16439067393017229087)],
        &[(0b10010, &ENTRY_MOBILIZING_1417290482744517718)],
        &[(0b01001, &ENTRY_MOBILIZABLE_4838354601271065797)],
        &[(0b01001, &ENTRY_MOBILIZABLER_550692436973252168)],
        &[(0b01001, &ENTRY_MOBILIZABLES_13069683708079300928)],
        &[(0b01001, &ENTRY_MOBILIZABLEST_2936215873432536207)],
        &[(0b01001, &ENTRY_MOBILIZATION_5777426368387580657)],
        &[(0b01001, &ENTRY_MOBILIZATIONS_14453487133355314782)],
        &[(0b01001, &ENTRY_MOBILIZE_8789464231798787986)],
        &[(0b01001, &ENTRY_MOBILIZED_5804933841881642219)],
        &[(0b01001, &ENTRY_MOBILIZER_10343085295594491112)],
        &[(0b01001, &ENTRY_MOBILIZERS_3858507952045243762)],
        &[(0b01001, &ENTRY_MOBILIZES_16439067393017229087)],
        &[(0b01001, &ENTRY_MOBILIZING_1417290482744517718)],
    ],
    range: 5..=10,
};

static VARS_MI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MI_CHILDREN),
    value: None,
};

static VARS_MI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MIA_NODE),
    None,
    Some(&VARS_MIC_NODE),
    Some(&VARS_MID_NODE),
    None,
    None,
    Some(&VARS_MIG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_MIL_NODE),
    None,
    Some(&VARS_MIN_NODE),
    None,
    None,
    None,
    Some(&VARS_MIR_NODE),
    Some(&VARS_MIS_NODE),
    Some(&VARS_MIT_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MIZ_NODE),
];

static VARS_MIZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIZ_CHILDREN),
    value: None,
};

pub static VARS_MIZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b01001, &ENTRY_MIZE_18024382563076168859)]],
    range: 1..=1,
};

static VARS_MIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIT_CHILDREN),
    value: None,
};

pub static VARS_MIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ered"),
        dictgen::InsensitiveStr::Ascii("erer"),
        dictgen::InsensitiveStr::Ascii("erflower"),
        dictgen::InsensitiveStr::Ascii("ering"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("erwort"),
        dictgen::InsensitiveStr::Ascii("erworts"),
        dictgen::InsensitiveStr::Ascii("hridatise"),
        dictgen::InsensitiveStr::Ascii("hridatised"),
        dictgen::InsensitiveStr::Ascii("hridatises"),
        dictgen::InsensitiveStr::Ascii("hridatising"),
        dictgen::InsensitiveStr::Ascii("hridatize"),
        dictgen::InsensitiveStr::Ascii("hridatized"),
        dictgen::InsensitiveStr::Ascii("hridatizes"),
        dictgen::InsensitiveStr::Ascii("hridatizing"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("reflower"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("res"),
        dictgen::InsensitiveStr::Ascii("rewort"),
        dictgen::InsensitiveStr::Ascii("reworts"),
        dictgen::InsensitiveStr::Ascii("ring"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MITER_14901282210601132768)],
        &[(0b00001, &ENTRY_MITERED_8698507717371065494)],
        &[(0b00001, &ENTRY_MITERER_12530932115756420713)],
        &[(0b00001, &ENTRY_MITERFLOWER_14337093432563184888)],
        &[(0b00001, &ENTRY_MITERING_17472611887349673354)],
        &[(0b00001, &ENTRY_MITERS_13601882143052765005)],
        &[(0b00001, &ENTRY_MITERWORT_8547548283547590528)],
        &[(0b00001, &ENTRY_MITERWORTS_17121170244158720767)],
        &[(0b10010, &ENTRY_MITHRIDATIZE_2966636373317648004)],
        &[(0b10010, &ENTRY_MITHRIDATIZED_15226011945453367877)],
        &[(0b10010, &ENTRY_MITHRIDATIZES_17923000552005460927)],
        &[(0b10010, &ENTRY_MITHRIDATIZING_11477680424456392910)],
        &[(0b01001, &ENTRY_MITHRIDATIZE_2966636373317648004)],
        &[(0b01001, &ENTRY_MITHRIDATIZED_15226011945453367877)],
        &[(0b01001, &ENTRY_MITHRIDATIZES_17923000552005460927)],
        &[(0b01001, &ENTRY_MITHRIDATIZING_11477680424456392910)],
        &[(0b11010, &ENTRY_MITER_14901282210601132768)],
        &[(0b11010, &ENTRY_MITERED_8698507717371065494)],
        &[(0b11010, &ENTRY_MITERFLOWER_14337093432563184888)],
        &[(0b11010, &ENTRY_MITERER_12530932115756420713)],
        &[(0b11010, &ENTRY_MITERS_13601882143052765005)],
        &[(0b11010, &ENTRY_MITERWORT_8547548283547590528)],
        &[(0b11010, &ENTRY_MITERWORTS_17121170244158720767)],
        &[(0b11010, &ENTRY_MITERING_17472611887349673354)],
    ],
    range: 2..=11,
};

static VARS_MIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MIS_CHILDREN),
    value: None,
};

static VARS_MIS_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MISA_NODE),
    Some(&VARS_MISB_NODE),
    Some(&VARS_MISC_NODE),
    Some(&VARS_MISD_NODE),
    Some(&VARS_MISE_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_MISJ_NODE),
    None,
    Some(&VARS_MISL_NODE),
    None,
    None,
    Some(&VARS_MISO_NODE),
    Some(&VARS_MISP_NODE),
    None,
    Some(&VARS_MISR_NODE),
    Some(&VARS_MISS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_MISS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISS_CHILDREN),
    value: None,
};

pub static VARS_MISS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ionarise"),
        dictgen::InsensitiveStr::Ascii("ionarised"),
        dictgen::InsensitiveStr::Ascii("ionarises"),
        dictgen::InsensitiveStr::Ascii("ionarising"),
        dictgen::InsensitiveStr::Ascii("ionarize"),
        dictgen::InsensitiveStr::Ascii("ionarized"),
        dictgen::InsensitiveStr::Ascii("ionarizes"),
        dictgen::InsensitiveStr::Ascii("ionarizing"),
        dictgen::InsensitiveStr::Ascii("ionisation"),
        dictgen::InsensitiveStr::Ascii("ionise"),
        dictgen::InsensitiveStr::Ascii("ionised"),
        dictgen::InsensitiveStr::Ascii("ioniser"),
        dictgen::InsensitiveStr::Ascii("ionisers"),
        dictgen::InsensitiveStr::Ascii("ionises"),
        dictgen::InsensitiveStr::Ascii("ionising"),
        dictgen::InsensitiveStr::Ascii("ionization"),
        dictgen::InsensitiveStr::Ascii("ionize"),
        dictgen::InsensitiveStr::Ascii("ionized"),
        dictgen::InsensitiveStr::Ascii("ionizer"),
        dictgen::InsensitiveStr::Ascii("ionizers"),
        dictgen::InsensitiveStr::Ascii("ionizes"),
        dictgen::InsensitiveStr::Ascii("ionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISSIONARIZE_8659233219888427790)],
        &[(0b10010, &ENTRY_MISSIONARIZED_3550258362783566279)],
        &[(0b10010, &ENTRY_MISSIONARIZES_2865828932098182673)],
        &[(0b10010, &ENTRY_MISSIONARIZING_6713234286118309855)],
        &[(0b01001, &ENTRY_MISSIONARIZE_8659233219888427790)],
        &[(0b01001, &ENTRY_MISSIONARIZED_3550258362783566279)],
        &[(0b01001, &ENTRY_MISSIONARIZES_2865828932098182673)],
        &[(0b01001, &ENTRY_MISSIONARIZING_6713234286118309855)],
        &[(0b10010, &ENTRY_MISSIONIZATION_5386570164157640867)],
        &[(0b10010, &ENTRY_MISSIONIZE_9215465213060476024)],
        &[(0b10010, &ENTRY_MISSIONIZED_8256176424405826525)],
        &[(0b10010, &ENTRY_MISSIONIZER_15289881884612675093)],
        &[(0b10010, &ENTRY_MISSIONIZERS_11864753429827863840)],
        &[(0b10010, &ENTRY_MISSIONIZES_7974503074241187699)],
        &[(0b10010, &ENTRY_MISSIONIZING_4494832750144779312)],
        &[(0b01001, &ENTRY_MISSIONIZATION_5386570164157640867)],
        &[(0b01001, &ENTRY_MISSIONIZE_9215465213060476024)],
        &[(0b01001, &ENTRY_MISSIONIZED_8256176424405826525)],
        &[(0b01001, &ENTRY_MISSIONIZER_15289881884612675093)],
        &[(0b01001, &ENTRY_MISSIONIZERS_11864753429827863840)],
        &[(0b01001, &ENTRY_MISSIONIZES_7974503074241187699)],
        &[(0b01001, &ENTRY_MISSIONIZING_4494832750144779312)],
    ],
    range: 6..=10,
};

static VARS_MISR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISR_CHILDREN),
    value: None,
};

pub static VARS_MISR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ealise"),
        dictgen::InsensitiveStr::Ascii("ealises"),
        dictgen::InsensitiveStr::Ascii("ealize"),
        dictgen::InsensitiveStr::Ascii("ealizes"),
        dictgen::InsensitiveStr::Ascii("ecognise"),
        dictgen::InsensitiveStr::Ascii("ecognises"),
        dictgen::InsensitiveStr::Ascii("ecognize"),
        dictgen::InsensitiveStr::Ascii("ecognizes"),
        dictgen::InsensitiveStr::Ascii("outeing"),
        dictgen::InsensitiveStr::Ascii("outing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISREALIZE_46370965209688711)],
        &[(0b10010, &ENTRY_MISREALIZES_5429375807985531029)],
        &[(0b01001, &ENTRY_MISREALIZE_46370965209688711)],
        &[(0b01001, &ENTRY_MISREALIZES_5429375807985531029)],
        &[(0b10010, &ENTRY_MISRECOGNIZE_4535527973403537388)],
        &[(0b10010, &ENTRY_MISRECOGNIZES_10782325434195444690)],
        &[(0b01001, &ENTRY_MISRECOGNIZE_4535527973403537388)],
        &[(0b01001, &ENTRY_MISRECOGNIZES_10782325434195444690)],
        &[(0b11010, &ENTRY_MISROUTING_6953912846649926545)],
        &[(0b00001, &ENTRY_MISROUTING_6953912846649926545)],
    ],
    range: 6..=9,
};

static VARS_MISP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISP_CHILDREN),
    value: None,
};

pub static VARS_MISP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("risal"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("riser"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rizal"),
        dictgen::InsensitiveStr::Ascii("rizer"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISPRIZAL_1906224147210876596)],
        &[(0b11010, &ENTRY_MISPRIZE_7317761504865217596)],
        &[(0b11010, &ENTRY_MISPRIZED_15910979320445924885)],
        &[(0b10010, &ENTRY_MISPRIZER_1574809362067258794)],
        &[(0b11010, &ENTRY_MISPRIZES_16040140991463042359)],
        &[(0b11010, &ENTRY_MISPRIZING_12105379912423556571)],
        &[(0b01001, &ENTRY_MISPRIZAL_1906224147210876596)],
        &[(0b01001, &ENTRY_MISPRIZER_1574809362067258794)],
    ],
    range: 4..=6,
};

static VARS_MISO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISO_CHILDREN),
    value: None,
};

pub static VARS_MISO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("paedia"),
        dictgen::InsensitiveStr::Ascii("paedism"),
        dictgen::InsensitiveStr::Ascii("paedist"),
        dictgen::InsensitiveStr::Ascii("pedia"),
        dictgen::InsensitiveStr::Ascii("pedism"),
        dictgen::InsensitiveStr::Ascii("pedist"),
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganise"),
        dictgen::InsensitiveStr::Ascii("rganises"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("rganize"),
        dictgen::InsensitiveStr::Ascii("rganizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MISOPEDIA_3367574278824775575)],
        &[(0b11010, &ENTRY_MISOPEDISM_17961691095480486146)],
        &[(0b11010, &ENTRY_MISOPEDIST_13958701045726659475)],
        &[(0b10001, &ENTRY_MISOPEDIA_3367574278824775575)],
        &[(0b10001, &ENTRY_MISOPEDISM_17961691095480486146)],
        &[(0b10001, &ENTRY_MISOPEDIST_13958701045726659475)],
        &[(0b10010, &ENTRY_MISORGANIZATION_4528274519460006130)],
        &[(0b10010, &ENTRY_MISORGANIZATIONS_16256056216985643161)],
        &[(0b10010, &ENTRY_MISORGANIZE_8043699224147914594)],
        &[(0b10010, &ENTRY_MISORGANIZES_16396120482654767343)],
        &[(0b01001, &ENTRY_MISORGANIZATION_4528274519460006130)],
        &[(0b01001, &ENTRY_MISORGANIZATIONS_16256056216985643161)],
        &[(0b01001, &ENTRY_MISORGANIZE_8043699224147914594)],
        &[(0b01001, &ENTRY_MISORGANIZES_16396120482654767343)],
    ],
    range: 5..=12,
};

static VARS_MISL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISL_CHILDREN),
    value: None,
};

pub static VARS_MISL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abeled"),
        dictgen::InsensitiveStr::Ascii("abeling"),
        dictgen::InsensitiveStr::Ascii("abelled"),
        dictgen::InsensitiveStr::Ascii("abelling"),
        dictgen::InsensitiveStr::Ascii("abor"),
        dictgen::InsensitiveStr::Ascii("abored"),
        dictgen::InsensitiveStr::Ascii("aboring"),
        dictgen::InsensitiveStr::Ascii("abors"),
        dictgen::InsensitiveStr::Ascii("abour"),
        dictgen::InsensitiveStr::Ascii("aboured"),
        dictgen::InsensitiveStr::Ascii("abouring"),
        dictgen::InsensitiveStr::Ascii("abours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MISLABELED_7926653334976693959)],
        &[(0b00001, &ENTRY_MISLABELING_368815218416940620)],
        &[(0b11010, &ENTRY_MISLABELED_7926653334976693959)],
        &[(0b11010, &ENTRY_MISLABELING_368815218416940620)],
        &[(0b10001, &ENTRY_MISLABOR_11862740488880915405)],
        &[(0b10001, &ENTRY_MISLABORED_10704627531362921647)],
        &[(0b10001, &ENTRY_MISLABORING_3306598715211504366)],
        &[(0b10001, &ENTRY_MISLABORS_17741241387381188744)],
        &[(0b11010, &ENTRY_MISLABOR_11862740488880915405)],
        &[(0b11010, &ENTRY_MISLABORED_10704627531362921647)],
        &[(0b11010, &ENTRY_MISLABORING_3306598715211504366)],
        &[(0b11010, &ENTRY_MISLABORS_17741241387381188744)],
    ],
    range: 4..=8,
};

static VARS_MISJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISJ_CHILDREN),
    value: None,
};

pub static VARS_MISJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("udgement"),
        dictgen::InsensitiveStr::Ascii("udgements"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MISJUDGMENT_17843686745476490529)],
        &[(0b11010, &ENTRY_MISJUDGMENTS_17389672896349870910)],
    ],
    range: 8..=9,
};

static VARS_MISE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISE_CHILDREN),
    value: Some(&[(0b10010, &ENTRY_MIZE_18024382563076168859)]),
};

pub static VARS_MISE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISEMPHASIZE_2936109535805352767)],
        &[(0b10010, &ENTRY_MISEMPHASIZES_15835142756342884945)],
        &[(0b01001, &ENTRY_MISEMPHASIZE_2936109535805352767)],
        &[(0b01001, &ENTRY_MISEMPHASIZES_15835142756342884945)],
    ],
    range: 8..=9,
};

static VARS_MISD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISD_CHILDREN),
    value: None,
};

pub static VARS_MISD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emeanor"),
        dictgen::InsensitiveStr::Ascii("emeanors"),
        dictgen::InsensitiveStr::Ascii("emeanour"),
        dictgen::InsensitiveStr::Ascii("emeanours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_MISDEMEANOR_1250919998876899665)],
        &[(0b11001, &ENTRY_MISDEMEANORS_11749207148565478841)],
        &[(0b11010, &ENTRY_MISDEMEANOR_1250919998876899665)],
        &[(0b11010, &ENTRY_MISDEMEANORS_11749207148565478841)],
    ],
    range: 7..=9,
};

static VARS_MISC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISC_CHILDREN),
    value: None,
};

pub static VARS_MISC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anonise"),
        dictgen::InsensitiveStr::Ascii("anonises"),
        dictgen::InsensitiveStr::Ascii("anonize"),
        dictgen::InsensitiveStr::Ascii("anonizes"),
        dictgen::InsensitiveStr::Ascii("haracterisation"),
        dictgen::InsensitiveStr::Ascii("haracterisations"),
        dictgen::InsensitiveStr::Ascii("haracterise"),
        dictgen::InsensitiveStr::Ascii("haracterises"),
        dictgen::InsensitiveStr::Ascii("haracterization"),
        dictgen::InsensitiveStr::Ascii("haracterizations"),
        dictgen::InsensitiveStr::Ascii("haracterize"),
        dictgen::InsensitiveStr::Ascii("haracterizes"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("oloration"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("oloring"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("olouration"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olouring"),
        dictgen::InsensitiveStr::Ascii("olours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISCANONIZE_10826665566184909604)],
        &[(0b10010, &ENTRY_MISCANONIZES_7870617629942275975)],
        &[(0b01001, &ENTRY_MISCANONIZE_10826665566184909604)],
        &[(0b01001, &ENTRY_MISCANONIZES_7870617629942275975)],
        &[(0b10010, &ENTRY_MISCHARACTERIZATION_10291461125809939083)],
        &[(0b10010, &ENTRY_MISCHARACTERIZATIONS_14463836821244335501)],
        &[(0b10010, &ENTRY_MISCHARACTERIZE_17813891911357917532)],
        &[(0b10010, &ENTRY_MISCHARACTERIZES_2053463788293812639)],
        &[(0b01001, &ENTRY_MISCHARACTERIZATION_10291461125809939083)],
        &[(0b01001, &ENTRY_MISCHARACTERIZATIONS_14463836821244335501)],
        &[(0b01001, &ENTRY_MISCHARACTERIZE_17813891911357917532)],
        &[(0b01001, &ENTRY_MISCHARACTERIZES_2053463788293812639)],
        &[(0b10001, &ENTRY_MISCOLOR_1908472380673894947)],
        &[(0b00001, &ENTRY_MISCOLORATION_1690416727086001845)],
        &[(0b10001, &ENTRY_MISCOLORED_13297919653949634361)],
        &[(0b10001, &ENTRY_MISCOLORING_14732928106161795811)],
        &[(0b10001, &ENTRY_MISCOLORS_8989716299210529212)],
        &[(0b11010, &ENTRY_MISCOLOR_1908472380673894947)],
        &[(0b11010, &ENTRY_MISCOLORATION_1690416727086001845)],
        &[(0b11010, &ENTRY_MISCOLORED_13297919653949634361)],
        &[(0b11010, &ENTRY_MISCOLORING_14732928106161795811)],
        &[(0b11010, &ENTRY_MISCOLORS_8989716299210529212)],
    ],
    range: 4..=16,
};

static VARS_MISB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISB_CHILDREN),
    value: None,
};

pub static VARS_MISB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aptise"),
        dictgen::InsensitiveStr::Ascii("aptises"),
        dictgen::InsensitiveStr::Ascii("aptize"),
        dictgen::InsensitiveStr::Ascii("aptizes"),
        dictgen::InsensitiveStr::Ascii("ehavior"),
        dictgen::InsensitiveStr::Ascii("ehaviors"),
        dictgen::InsensitiveStr::Ascii("ehaviour"),
        dictgen::InsensitiveStr::Ascii("ehaviours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISBAPTIZE_1708261197362730245)],
        &[(0b10010, &ENTRY_MISBAPTIZES_3045720393639226403)],
        &[(0b01001, &ENTRY_MISBAPTIZE_1708261197362730245)],
        &[(0b01001, &ENTRY_MISBAPTIZES_3045720393639226403)],
        &[(0b10001, &ENTRY_MISBEHAVIOR_1494581758331316402)],
        &[(0b10001, &ENTRY_MISBEHAVIORS_4095360583991043350)],
        &[(0b11010, &ENTRY_MISBEHAVIOR_1494581758331316402)],
        &[(0b11010, &ENTRY_MISBEHAVIORS_4095360583991043350)],
    ],
    range: 6..=9,
};

static VARS_MISA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISA_CHILDREN),
    value: None,
};

pub static VARS_MISA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dvise"),
        dictgen::InsensitiveStr::Ascii("dvize"),
        dictgen::InsensitiveStr::Ascii("lphabetise"),
        dictgen::InsensitiveStr::Ascii("lphabetises"),
        dictgen::InsensitiveStr::Ascii("lphabetize"),
        dictgen::InsensitiveStr::Ascii("lphabetizes"),
        dictgen::InsensitiveStr::Ascii("nthropise"),
        dictgen::InsensitiveStr::Ascii("nthropised"),
        dictgen::InsensitiveStr::Ascii("nthropises"),
        dictgen::InsensitiveStr::Ascii("nthropising"),
        dictgen::InsensitiveStr::Ascii("nthropize"),
        dictgen::InsensitiveStr::Ascii("nthropized"),
        dictgen::InsensitiveStr::Ascii("nthropizes"),
        dictgen::InsensitiveStr::Ascii("nthropizing"),
        dictgen::InsensitiveStr::Ascii("uthorisation"),
        dictgen::InsensitiveStr::Ascii("uthorisations"),
        dictgen::InsensitiveStr::Ascii("uthorise"),
        dictgen::InsensitiveStr::Ascii("uthorises"),
        dictgen::InsensitiveStr::Ascii("uthorization"),
        dictgen::InsensitiveStr::Ascii("uthorizations"),
        dictgen::InsensitiveStr::Ascii("uthorize"),
        dictgen::InsensitiveStr::Ascii("uthorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISADVIZE_1613208909926045561)],
        &[(0b01001, &ENTRY_MISADVIZE_1613208909926045561)],
        &[(0b10010, &ENTRY_MISALPHABETIZE_15903925617999627004)],
        &[(0b10010, &ENTRY_MISALPHABETIZES_2749952515466087884)],
        &[(0b01001, &ENTRY_MISALPHABETIZE_15903925617999627004)],
        &[(0b01001, &ENTRY_MISALPHABETIZES_2749952515466087884)],
        &[(0b10010, &ENTRY_MISANTHROPIZE_17170767351201053555)],
        &[(0b10010, &ENTRY_MISANTHROPIZED_5494865608069126958)],
        &[(0b10010, &ENTRY_MISANTHROPIZES_8621200081370476291)],
        &[(0b10010, &ENTRY_MISANTHROPIZING_17955560059393289897)],
        &[(0b01001, &ENTRY_MISANTHROPIZE_17170767351201053555)],
        &[(0b01001, &ENTRY_MISANTHROPIZED_5494865608069126958)],
        &[(0b01001, &ENTRY_MISANTHROPIZES_8621200081370476291)],
        &[(0b01001, &ENTRY_MISANTHROPIZING_17955560059393289897)],
        &[(0b10010, &ENTRY_MISAUTHORIZATION_14891497048505685561)],
        &[(0b10010, &ENTRY_MISAUTHORIZATIONS_12436849369504879800)],
        &[(0b10010, &ENTRY_MISAUTHORIZE_2271687349975291464)],
        &[(0b10010, &ENTRY_MISAUTHORIZES_4900945154483453360)],
        &[(0b01001, &ENTRY_MISAUTHORIZATION_14891497048505685561)],
        &[(0b01001, &ENTRY_MISAUTHORIZATIONS_12436849369504879800)],
        &[(0b01001, &ENTRY_MISAUTHORIZE_2271687349975291464)],
        &[(0b01001, &ENTRY_MISAUTHORIZES_4900945154483453360)],
    ],
    range: 5..=13,
};

static VARS_MIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIR_CHILDREN),
    value: None,
};

pub static VARS_MIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aculise"),
        dictgen::InsensitiveStr::Ascii("aculised"),
        dictgen::InsensitiveStr::Ascii("aculises"),
        dictgen::InsensitiveStr::Ascii("aculising"),
        dictgen::InsensitiveStr::Ascii("aculize"),
        dictgen::InsensitiveStr::Ascii("aculized"),
        dictgen::InsensitiveStr::Ascii("aculizes"),
        dictgen::InsensitiveStr::Ascii("aculizing"),
        dictgen::InsensitiveStr::Ascii("rorise"),
        dictgen::InsensitiveStr::Ascii("rorises"),
        dictgen::InsensitiveStr::Ascii("rorize"),
        dictgen::InsensitiveStr::Ascii("rorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MIRACULIZE_12594578967332117147)],
        &[(0b10010, &ENTRY_MIRACULIZED_18124387121142671186)],
        &[(0b10010, &ENTRY_MIRACULIZES_3024248323745780201)],
        &[(0b10010, &ENTRY_MIRACULIZING_9780578229159926476)],
        &[(0b01001, &ENTRY_MIRACULIZE_12594578967332117147)],
        &[(0b01001, &ENTRY_MIRACULIZED_18124387121142671186)],
        &[(0b01001, &ENTRY_MIRACULIZES_3024248323745780201)],
        &[(0b01001, &ENTRY_MIRACULIZING_9780578229159926476)],
        &[(0b10010, &ENTRY_MIRRORIZE_17308641168637711576)],
        &[(0b10010, &ENTRY_MIRRORIZES_2859817952428182045)],
        &[(0b01001, &ENTRY_MIRRORIZE_17308641168637711576)],
        &[(0b01001, &ENTRY_MIRRORIZES_2859817952428182045)],
    ],
    range: 6..=9,
};

static VARS_MIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIN_CHILDREN),
    value: None,
};

pub static VARS_MIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eralisable"),
        dictgen::InsensitiveStr::Ascii("eralisables"),
        dictgen::InsensitiveStr::Ascii("eralisation"),
        dictgen::InsensitiveStr::Ascii("eralisations"),
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralised"),
        dictgen::InsensitiveStr::Ascii("eraliser"),
        dictgen::InsensitiveStr::Ascii("eralisers"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralising"),
        dictgen::InsensitiveStr::Ascii("eralizable"),
        dictgen::InsensitiveStr::Ascii("eralizables"),
        dictgen::InsensitiveStr::Ascii("eralization"),
        dictgen::InsensitiveStr::Ascii("eralizations"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralized"),
        dictgen::InsensitiveStr::Ascii("eralizer"),
        dictgen::InsensitiveStr::Ascii("eralizers"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("eralizing"),
        dictgen::InsensitiveStr::Ascii("eralogise"),
        dictgen::InsensitiveStr::Ascii("eralogised"),
        dictgen::InsensitiveStr::Ascii("eralogises"),
        dictgen::InsensitiveStr::Ascii("eralogising"),
        dictgen::InsensitiveStr::Ascii("eralogize"),
        dictgen::InsensitiveStr::Ascii("eralogized"),
        dictgen::InsensitiveStr::Ascii("eralogizes"),
        dictgen::InsensitiveStr::Ascii("eralogizing"),
        dictgen::InsensitiveStr::Ascii("iaturisation"),
        dictgen::InsensitiveStr::Ascii("iaturisations"),
        dictgen::InsensitiveStr::Ascii("iaturise"),
        dictgen::InsensitiveStr::Ascii("iaturised"),
        dictgen::InsensitiveStr::Ascii("iaturises"),
        dictgen::InsensitiveStr::Ascii("iaturising"),
        dictgen::InsensitiveStr::Ascii("iaturization"),
        dictgen::InsensitiveStr::Ascii("iaturizations"),
        dictgen::InsensitiveStr::Ascii("iaturize"),
        dictgen::InsensitiveStr::Ascii("iaturized"),
        dictgen::InsensitiveStr::Ascii("iaturizes"),
        dictgen::InsensitiveStr::Ascii("iaturizing"),
        dictgen::InsensitiveStr::Ascii("ibusses"),
        dictgen::InsensitiveStr::Ascii("imisation"),
        dictgen::InsensitiveStr::Ascii("imisations"),
        dictgen::InsensitiveStr::Ascii("imise"),
        dictgen::InsensitiveStr::Ascii("imised"),
        dictgen::InsensitiveStr::Ascii("imiser"),
        dictgen::InsensitiveStr::Ascii("imisers"),
        dictgen::InsensitiveStr::Ascii("imises"),
        dictgen::InsensitiveStr::Ascii("imising"),
        dictgen::InsensitiveStr::Ascii("imization"),
        dictgen::InsensitiveStr::Ascii("imizations"),
        dictgen::InsensitiveStr::Ascii("imize"),
        dictgen::InsensitiveStr::Ascii("imized"),
        dictgen::InsensitiveStr::Ascii("imizer"),
        dictgen::InsensitiveStr::Ascii("imizers"),
        dictgen::InsensitiveStr::Ascii("imizes"),
        dictgen::InsensitiveStr::Ascii("imizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MINERALIZABLE_8842518699676983946)],
        &[(0b10010, &ENTRY_MINERALIZABLES_5106780707407964970)],
        &[(0b10010, &ENTRY_MINERALIZATION_6932253078663165468)],
        &[(0b10010, &ENTRY_MINERALIZATIONS_10546963403531567133)],
        &[(0b10010, &ENTRY_MINERALIZE_7945578525483035467)],
        &[(0b10010, &ENTRY_MINERALIZED_4247107678262591457)],
        &[(0b10010, &ENTRY_MINERALIZER_3737034346131356210)],
        &[(0b10010, &ENTRY_MINERALIZERS_6700043765339885165)],
        &[(0b10010, &ENTRY_MINERALIZES_12077281629276944607)],
        &[(0b10010, &ENTRY_MINERALIZING_3182430059767749821)],
        &[(0b01001, &ENTRY_MINERALIZABLE_8842518699676983946)],
        &[(0b01001, &ENTRY_MINERALIZABLES_5106780707407964970)],
        &[(0b01001, &ENTRY_MINERALIZATION_6932253078663165468)],
        &[(0b01001, &ENTRY_MINERALIZATIONS_10546963403531567133)],
        &[(0b01001, &ENTRY_MINERALIZE_7945578525483035467)],
        &[(0b01001, &ENTRY_MINERALIZED_4247107678262591457)],
        &[(0b01001, &ENTRY_MINERALIZER_3737034346131356210)],
        &[(0b01001, &ENTRY_MINERALIZERS_6700043765339885165)],
        &[(0b01001, &ENTRY_MINERALIZES_12077281629276944607)],
        &[(0b01001, &ENTRY_MINERALIZING_3182430059767749821)],
        &[(0b10010, &ENTRY_MINERALOGIZE_12837927935605358001)],
        &[(0b10010, &ENTRY_MINERALOGIZED_13505275795027010900)],
        &[(0b10010, &ENTRY_MINERALOGIZES_10531047901674270914)],
        &[(0b10010, &ENTRY_MINERALOGIZING_7977291710561372216)],
        &[(0b01001, &ENTRY_MINERALOGIZE_12837927935605358001)],
        &[(0b01001, &ENTRY_MINERALOGIZED_13505275795027010900)],
        &[(0b01001, &ENTRY_MINERALOGIZES_10531047901674270914)],
        &[(0b01001, &ENTRY_MINERALOGIZING_7977291710561372216)],
        &[(0b10010, &ENTRY_MINIATURIZATION_11771675081402773636)],
        &[(0b10010, &ENTRY_MINIATURIZATIONS_13443825612505429435)],
        &[(0b10010, &ENTRY_MINIATURIZE_14775476687436824687)],
        &[(0b10010, &ENTRY_MINIATURIZED_3880152562256982898)],
        &[(0b10010, &ENTRY_MINIATURIZES_4987348295329229449)],
        &[(0b10010, &ENTRY_MINIATURIZING_4324908215288109965)],
        &[(0b01001, &ENTRY_MINIATURIZATION_11771675081402773636)],
        &[(0b01001, &ENTRY_MINIATURIZATIONS_13443825612505429435)],
        &[(0b01001, &ENTRY_MINIATURIZE_14775476687436824687)],
        &[(0b01001, &ENTRY_MINIATURIZED_3880152562256982898)],
        &[(0b01001, &ENTRY_MINIATURIZES_4987348295329229449)],
        &[(0b01001, &ENTRY_MINIATURIZING_4324908215288109965)],
        &[(0b00001, &ENTRY_MINIBUSES_11051687516105212429)],
        &[(0b10010, &ENTRY_MINIMIZATION_15941432212626950244)],
        &[(0b10010, &ENTRY_MINIMIZATIONS_16859838846464243203)],
        &[(0b10010, &ENTRY_MINIMIZE_2781781045543044735)],
        &[(0b10010, &ENTRY_MINIMIZED_11553117414376788475)],
        &[(0b10010, &ENTRY_MINIMIZER_5548812611203507924)],
        &[(0b10010, &ENTRY_MINIMIZERS_3612737951166107599)],
        &[(0b10010, &ENTRY_MINIMIZES_9554981472878791756)],
        &[(0b10010, &ENTRY_MINIMIZING_16481774084401198225)],
        &[(0b01001, &ENTRY_MINIMIZATION_15941432212626950244)],
        &[(0b01001, &ENTRY_MINIMIZATIONS_16859838846464243203)],
        &[(0b01001, &ENTRY_MINIMIZE_2781781045543044735)],
        &[(0b01001, &ENTRY_MINIMIZED_11553117414376788475)],
        &[(0b01001, &ENTRY_MINIMIZER_5548812611203507924)],
        &[(0b01001, &ENTRY_MINIMIZERS_3612737951166107599)],
        &[(0b01001, &ENTRY_MINIMIZES_9554981472878791756)],
        &[(0b01001, &ENTRY_MINIMIZING_16481774084401198225)],
    ],
    range: 5..=13,
};

static VARS_MIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIL_CHILDREN),
    value: None,
};

pub static VARS_MIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itarisation"),
        dictgen::InsensitiveStr::Ascii("itarisations"),
        dictgen::InsensitiveStr::Ascii("itarise"),
        dictgen::InsensitiveStr::Ascii("itarised"),
        dictgen::InsensitiveStr::Ascii("itarises"),
        dictgen::InsensitiveStr::Ascii("itarising"),
        dictgen::InsensitiveStr::Ascii("itarization"),
        dictgen::InsensitiveStr::Ascii("itarizations"),
        dictgen::InsensitiveStr::Ascii("itarize"),
        dictgen::InsensitiveStr::Ascii("itarized"),
        dictgen::InsensitiveStr::Ascii("itarizes"),
        dictgen::InsensitiveStr::Ascii("itarizing"),
        dictgen::InsensitiveStr::Ascii("ligramme"),
        dictgen::InsensitiveStr::Ascii("ligrammes"),
        dictgen::InsensitiveStr::Ascii("liliter"),
        dictgen::InsensitiveStr::Ascii("liliters"),
        dictgen::InsensitiveStr::Ascii("lilitre"),
        dictgen::InsensitiveStr::Ascii("lilitres"),
        dictgen::InsensitiveStr::Ascii("limeter"),
        dictgen::InsensitiveStr::Ascii("limeters"),
        dictgen::InsensitiveStr::Ascii("limetre"),
        dictgen::InsensitiveStr::Ascii("limetres"),
        dictgen::InsensitiveStr::Ascii("lionise"),
        dictgen::InsensitiveStr::Ascii("lionises"),
        dictgen::InsensitiveStr::Ascii("lionize"),
        dictgen::InsensitiveStr::Ascii("lionizes"),
        dictgen::InsensitiveStr::Ascii("tonise"),
        dictgen::InsensitiveStr::Ascii("tonised"),
        dictgen::InsensitiveStr::Ascii("tonises"),
        dictgen::InsensitiveStr::Ascii("tonising"),
        dictgen::InsensitiveStr::Ascii("tonize"),
        dictgen::InsensitiveStr::Ascii("tonized"),
        dictgen::InsensitiveStr::Ascii("tonizes"),
        dictgen::InsensitiveStr::Ascii("tonizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MILITARIZATION_8896321595375246390)],
        &[(0b10010, &ENTRY_MILITARIZATIONS_7705734301801515430)],
        &[(0b10010, &ENTRY_MILITARIZE_9495798303128415382)],
        &[(0b10010, &ENTRY_MILITARIZED_16232436267971009706)],
        &[(0b10010, &ENTRY_MILITARIZES_14452269897116904753)],
        &[(0b10010, &ENTRY_MILITARIZING_554769254101207928)],
        &[(0b01001, &ENTRY_MILITARIZATION_8896321595375246390)],
        &[(0b01001, &ENTRY_MILITARIZATIONS_7705734301801515430)],
        &[(0b01001, &ENTRY_MILITARIZE_9495798303128415382)],
        &[(0b01001, &ENTRY_MILITARIZED_16232436267971009706)],
        &[(0b01001, &ENTRY_MILITARIZES_14452269897116904753)],
        &[(0b01001, &ENTRY_MILITARIZING_554769254101207928)],
        &[(0b11010, &ENTRY_MILLIGRAM_13513186363380334269)],
        &[(0b11010, &ENTRY_MILLIGRAMS_1518179305136992377)],
        &[(0b00001, &ENTRY_MILLILITER_4334261634926370944)],
        &[(0b00001, &ENTRY_MILLILITERS_11102962851052563190)],
        &[(0b11010, &ENTRY_MILLILITER_4334261634926370944)],
        &[(0b11010, &ENTRY_MILLILITERS_11102962851052563190)],
        &[(0b01001, &ENTRY_MILLIMETER_910141945772637554)],
        &[(0b01001, &ENTRY_MILLIMETERS_15997711111545097679)],
        &[(0b11010, &ENTRY_MILLIMETER_910141945772637554)],
        &[(0b11010, &ENTRY_MILLIMETERS_15997711111545097679)],
        &[(0b10010, &ENTRY_MILLIONIZE_8710296959776291321)],
        &[(0b10010, &ENTRY_MILLIONIZES_8106805268939119590)],
        &[(0b01001, &ENTRY_MILLIONIZE_8710296959776291321)],
        &[(0b01001, &ENTRY_MILLIONIZES_8106805268939119590)],
        &[(0b10010, &ENTRY_MILTONIZE_5481427781071274567)],
        &[(0b10010, &ENTRY_MILTONIZED_17857068391321573364)],
        &[(0b10010, &ENTRY_MILTONIZES_4582802465496810532)],
        &[(0b10010, &ENTRY_MILTONIZING_13876342377178577317)],
        &[(0b01001, &ENTRY_MILTONIZE_5481427781071274567)],
        &[(0b01001, &ENTRY_MILTONIZED_17857068391321573364)],
        &[(0b01001, &ENTRY_MILTONIZES_4582802465496810532)],
        &[(0b01001, &ENTRY_MILTONIZING_13876342377178577317)],
    ],
    range: 6..=12,
};

static VARS_MIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIG_CHILDREN),
    value: None,
};

pub static VARS_MIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("niardise"),
        dictgen::InsensitiveStr::Ascii("niardize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MIGNIARDIZE_4149614480326600754)],
        &[(0b01001, &ENTRY_MIGNIARDIZE_4149614480326600754)],
    ],
    range: 8..=8,
};

static VARS_MID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MID_CHILDREN),
    value: None,
};

pub static VARS_MID_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("landise"),
        dictgen::InsensitiveStr::Ascii("landises"),
        dictgen::InsensitiveStr::Ascii("landize"),
        dictgen::InsensitiveStr::Ascii("landizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MIDLANDIZE_6630693690356339718)],
        &[(0b10010, &ENTRY_MIDLANDIZES_12489301275419999190)],
        &[(0b01001, &ENTRY_MIDLANDIZE_6630693690356339718)],
        &[(0b01001, &ENTRY_MIDLANDIZES_12489301275419999190)],
    ],
    range: 7..=8,
};

static VARS_MIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MIC_CHILDREN),
    value: None,
};

static VARS_MIC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_MICE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MICR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_MICR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MICR_CHILDREN),
    value: None,
};

pub static VARS_MICR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthete"),
        dictgen::InsensitiveStr::Ascii("esthete"),
        dictgen::InsensitiveStr::Ascii("ocolorimeter"),
        dictgen::InsensitiveStr::Ascii("ocolorimetric"),
        dictgen::InsensitiveStr::Ascii("ocolorimetrically"),
        dictgen::InsensitiveStr::Ascii("ocolorimetry"),
        dictgen::InsensitiveStr::Ascii("ocolourimeter"),
        dictgen::InsensitiveStr::Ascii("ocolourimetric"),
        dictgen::InsensitiveStr::Ascii("ocolourimetrically"),
        dictgen::InsensitiveStr::Ascii("ocolourimetry"),
        dictgen::InsensitiveStr::Ascii("ogramme"),
        dictgen::InsensitiveStr::Ascii("oliter"),
        dictgen::InsensitiveStr::Ascii("oliters"),
        dictgen::InsensitiveStr::Ascii("olitre"),
        dictgen::InsensitiveStr::Ascii("olitres"),
        dictgen::InsensitiveStr::Ascii("ometre"),
        dictgen::InsensitiveStr::Ascii("ometres"),
        dictgen::InsensitiveStr::Ascii("omillimeter"),
        dictgen::InsensitiveStr::Ascii("omillimeters"),
        dictgen::InsensitiveStr::Ascii("omillimetre"),
        dictgen::InsensitiveStr::Ascii("omillimetres"),
        dictgen::InsensitiveStr::Ascii("ominiaturisation"),
        dictgen::InsensitiveStr::Ascii("ominiaturisations"),
        dictgen::InsensitiveStr::Ascii("ominiaturise"),
        dictgen::InsensitiveStr::Ascii("ominiaturised"),
        dictgen::InsensitiveStr::Ascii("ominiaturiser"),
        dictgen::InsensitiveStr::Ascii("ominiaturisers"),
        dictgen::InsensitiveStr::Ascii("ominiaturises"),
        dictgen::InsensitiveStr::Ascii("ominiaturising"),
        dictgen::InsensitiveStr::Ascii("ominiaturization"),
        dictgen::InsensitiveStr::Ascii("ominiaturizations"),
        dictgen::InsensitiveStr::Ascii("ominiaturize"),
        dictgen::InsensitiveStr::Ascii("ominiaturized"),
        dictgen::InsensitiveStr::Ascii("ominiaturizer"),
        dictgen::InsensitiveStr::Ascii("ominiaturizers"),
        dictgen::InsensitiveStr::Ascii("ominiaturizes"),
        dictgen::InsensitiveStr::Ascii("ominiaturizing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("opalaeontologies"),
        dictgen::InsensitiveStr::Ascii("opalaeontologist"),
        dictgen::InsensitiveStr::Ascii("opalaeontologists"),
        dictgen::InsensitiveStr::Ascii("opalaeontology"),
        dictgen::InsensitiveStr::Ascii("opaleontologies"),
        dictgen::InsensitiveStr::Ascii("opaleontologist"),
        dictgen::InsensitiveStr::Ascii("opaleontologists"),
        dictgen::InsensitiveStr::Ascii("opaleontology"),
        dictgen::InsensitiveStr::Ascii("opolarisation"),
        dictgen::InsensitiveStr::Ascii("opolarisations"),
        dictgen::InsensitiveStr::Ascii("opolarization"),
        dictgen::InsensitiveStr::Ascii("opolarizations"),
        dictgen::InsensitiveStr::Ascii("oscopise"),
        dictgen::InsensitiveStr::Ascii("oscopises"),
        dictgen::InsensitiveStr::Ascii("oscopize"),
        dictgen::InsensitiveStr::Ascii("oscopizes"),
        dictgen::InsensitiveStr::Ascii("osphaeric"),
        dictgen::InsensitiveStr::Ascii("ospheric"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MICRESTHETE_9672005037653736575)],
        &[(0b00001, &ENTRY_MICRESTHETE_9672005037653736575)],
        &[(0b00001, &ENTRY_MICROCOLORIMETER_18004280412051238652)],
        &[(0b00001, &ENTRY_MICROCOLORIMETRIC_16673082101782053736)],
        &[(0b00001, &ENTRY_MICROCOLORIMETRICALLY_11611466844951844847)],
        &[(0b00001, &ENTRY_MICROCOLORIMETRY_14367716593404245072)],
        &[(0b11010, &ENTRY_MICROCOLORIMETER_18004280412051238652)],
        &[(0b11010, &ENTRY_MICROCOLORIMETRIC_16673082101782053736)],
        &[(0b11010, &ENTRY_MICROCOLORIMETRICALLY_11611466844951844847)],
        &[(0b11010, &ENTRY_MICROCOLORIMETRY_14367716593404245072)],
        &[(0b10010, &ENTRY_MICROGRAM_5550826611173391714)],
        &[(0b00001, &ENTRY_MICROLITER_596723014881505352)],
        &[(0b00001, &ENTRY_MICROLITERS_3234207303821669806)],
        &[(0b11010, &ENTRY_MICROLITER_596723014881505352)],
        &[(0b11010, &ENTRY_MICROLITERS_3234207303821669806)],
        &[(0b11010, &ENTRY_MICROMETER_12426531854552032888)],
        &[(0b11010, &ENTRY_MICROMETERS_17594798746021449366)],
        &[(0b00001, &ENTRY_MICROMILLIMETER_1760735628859617214)],
        &[(0b00001, &ENTRY_MICROMILLIMETERS_4239096654730961785)],
        &[(0b11010, &ENTRY_MICROMILLIMETER_1760735628859617214)],
        &[(0b11010, &ENTRY_MICROMILLIMETERS_4239096654730961785)],
        &[(0b10010, &ENTRY_MICROMINIATURIZATION_11811432514999527166)],
        &[(0b10010, &ENTRY_MICROMINIATURIZATIONS_5246749790513836150)],
        &[(0b10010, &ENTRY_MICROMINIATURIZE_12416138093292278333)],
        &[(0b10010, &ENTRY_MICROMINIATURIZED_13202761646942630780)],
        &[(0b10010, &ENTRY_MICROMINIATURIZER_13902094523123847309)],
        &[(0b10010, &ENTRY_MICROMINIATURIZERS_18300728401437591217)],
        &[(0b10010, &ENTRY_MICROMINIATURIZES_322083564052894576)],
        &[(0b10010, &ENTRY_MICROMINIATURIZING_15922056758993789047)],
        &[(0b01001, &ENTRY_MICROMINIATURIZATION_11811432514999527166)],
        &[(0b01001, &ENTRY_MICROMINIATURIZATIONS_5246749790513836150)],
        &[(0b01001, &ENTRY_MICROMINIATURIZE_12416138093292278333)],
        &[(0b01001, &ENTRY_MICROMINIATURIZED_13202761646942630780)],
        &[(0b01001, &ENTRY_MICROMINIATURIZER_13902094523123847309)],
        &[(0b01001, &ENTRY_MICROMINIATURIZERS_18300728401437591217)],
        &[(0b01001, &ENTRY_MICROMINIATURIZES_322083564052894576)],
        &[(0b01001, &ENTRY_MICROMINIATURIZING_15922056758993789047)],
        &[(0b10010, &ENTRY_MICRONIZATION_4363650953137409948)],
        &[(0b10010, &ENTRY_MICRONIZATIONS_2591998753795230500)],
        &[(0b10010, &ENTRY_MICRONIZE_17111995987212311330)],
        &[(0b10010, &ENTRY_MICRONIZES_4658653937109421785)],
        &[(0b01001, &ENTRY_MICRONIZATION_4363650953137409948)],
        &[(0b01001, &ENTRY_MICRONIZATIONS_2591998753795230500)],
        &[(0b01001, &ENTRY_MICRONIZE_17111995987212311330)],
        &[(0b01001, &ENTRY_MICRONIZES_4658653937109421785)],
        &[(0b11010, &ENTRY_MICROPALEONTOLOGIES_16970317568428882967)],
        &[(0b11010, &ENTRY_MICROPALEONTOLOGIST_7148258118564071422)],
        &[(0b11010, &ENTRY_MICROPALEONTOLOGISTS_530232495682957827)],
        &[(0b11010, &ENTRY_MICROPALEONTOLOGY_4636373730108244068)],
        &[(0b10001, &ENTRY_MICROPALEONTOLOGIES_16970317568428882967)],
        &[(0b10001, &ENTRY_MICROPALEONTOLOGIST_7148258118564071422)],
        &[(0b10001, &ENTRY_MICROPALEONTOLOGISTS_530232495682957827)],
        &[(0b10001, &ENTRY_MICROPALEONTOLOGY_4636373730108244068)],
        &[(0b10010, &ENTRY_MICROPOLARIZATION_8251585643477451806)],
        &[(0b10010, &ENTRY_MICROPOLARIZATIONS_9001859270075015688)],
        &[(0b01001, &ENTRY_MICROPOLARIZATION_8251585643477451806)],
        &[(0b01001, &ENTRY_MICROPOLARIZATIONS_9001859270075015688)],
        &[(0b10010, &ENTRY_MICROSCOPIZE_360268649475089968)],
        &[(0b10010, &ENTRY_MICROSCOPIZES_15874855682887385434)],
        &[(0b01001, &ENTRY_MICROSCOPIZE_360268649475089968)],
        &[(0b01001, &ENTRY_MICROSCOPIZES_15874855682887385434)],
        &[(0b11010, &ENTRY_MICROSPHERIC_15627383990000838305)],
        &[(0b00001, &ENTRY_MICROSPHERIC_15627383990000838305)],
    ],
    range: 5..=18,
};

static VARS_MICE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MICE_CHILDREN),
    value: None,
};

pub static VARS_MICE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("llae"),
        dictgen::InsensitiveStr::Ascii("lle"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MICELLE_7576714829270505941)],
        &[(0b00001, &ENTRY_MICELLE_7576714829270505941)],
    ],
    range: 3..=4,
};

static VARS_MIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIA_CHILDREN),
    value: None,
};

pub static VARS_MIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ow"),
        dictgen::InsensitiveStr::Ascii("owed"),
        dictgen::InsensitiveStr::Ascii("owing"),
        dictgen::InsensitiveStr::Ascii("ows"),
    ],
    values: &[
        &[(0b10011, &ENTRY_MEOW_9410098915523682519)],
        &[(0b10011, &ENTRY_MEOWED_12917082202071017756)],
        &[(0b10011, &ENTRY_MEOWING_14461347911601242891)],
        &[(0b10011, &ENTRY_MEOWS_2381455287142978475)],
    ],
    range: 2..=5,
};

static VARS_ME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ME_CHILDREN),
    value: None,
};

static VARS_ME_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MEA_NODE),
    None,
    Some(&VARS_MEC_NODE),
    Some(&VARS_MED_NODE),
    None,
    None,
    Some(&VARS_MEG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_MEL_NODE),
    Some(&VARS_MEM_NODE),
    Some(&VARS_MEN_NODE),
    None,
    Some(&VARS_MEP_NODE),
    None,
    Some(&VARS_MER_NODE),
    Some(&VARS_MES_NODE),
    Some(&VARS_MET_NODE),
    None,
    None,
    None,
    Some(&VARS_MEX_NODE),
    None,
    None,
];

static VARS_MEX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEX_CHILDREN),
    value: None,
};

pub static VARS_MEX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icanise"),
        dictgen::InsensitiveStr::Ascii("icanises"),
        dictgen::InsensitiveStr::Ascii("icanize"),
        dictgen::InsensitiveStr::Ascii("icanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MEXICANIZE_8042596661826909778)],
        &[(0b10010, &ENTRY_MEXICANIZES_15197604106394100070)],
        &[(0b01001, &ENTRY_MEXICANIZE_8042596661826909778)],
        &[(0b01001, &ENTRY_MEXICANIZES_15197604106394100070)],
    ],
    range: 7..=8,
};

static VARS_MET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MET_CHILDREN),
    value: None,
};

static VARS_MET_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_META_NODE),
    None,
    None,
    None,
    Some(&VARS_METE_NODE),
    None,
    None,
    Some(&VARS_METH_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_METO_NODE),
    None,
    None,
    Some(&VARS_METR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_METR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METR_CHILDREN),
    value: None,
};

pub static VARS_METR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("egram"),
        dictgen::InsensitiveStr::Ascii("eless"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("eship"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icizing"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("opolitanisation"),
        dictgen::InsensitiveStr::Ascii("opolitanise"),
        dictgen::InsensitiveStr::Ascii("opolitanised"),
        dictgen::InsensitiveStr::Ascii("opolitanises"),
        dictgen::InsensitiveStr::Ascii("opolitanising"),
        dictgen::InsensitiveStr::Ascii("opolitanization"),
        dictgen::InsensitiveStr::Ascii("opolitanize"),
        dictgen::InsensitiveStr::Ascii("opolitanized"),
        dictgen::InsensitiveStr::Ascii("opolitanizes"),
        dictgen::InsensitiveStr::Ascii("opolitanizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_METER_3080570475644919217)],
        &[(0b11010, &ENTRY_METERGRAM_2011699453456886332)],
        &[(0b11010, &ENTRY_METERLESS_12592948617315833276)],
        &[(0b11010, &ENTRY_METERS_1321374795298554236)],
        &[(0b11010, &ENTRY_METERSHIP_4620649639929107458)],
        &[(0b10010, &ENTRY_METRICIZE_12712778788179541034)],
        &[(0b10010, &ENTRY_METRICIZED_13837683027917960528)],
        &[(0b10010, &ENTRY_METRICIZES_6116919209404015068)],
        &[(0b10010, &ENTRY_METRICIZING_8349643762624940557)],
        &[(0b01001, &ENTRY_METRICIZE_12712778788179541034)],
        &[(0b01001, &ENTRY_METRICIZED_13837683027917960528)],
        &[(0b01001, &ENTRY_METRICIZES_6116919209404015068)],
        &[(0b01001, &ENTRY_METRICIZING_8349643762624940557)],
        &[(0b10010, &ENTRY_METRIZE_14087333133836452055)],
        &[(0b01001, &ENTRY_METRIZE_14087333133836452055)],
        &[(0b10010, &ENTRY_METROPOLITANIZATION_14198198985964840255)],
        &[(0b10010, &ENTRY_METROPOLITANIZE_10953698211072784188)],
        &[(0b10010, &ENTRY_METROPOLITANIZED_2023559975004354749)],
        &[(0b10010, &ENTRY_METROPOLITANIZES_14586245815433709014)],
        &[(0b10010, &ENTRY_METROPOLITANIZING_4475094545669127656)],
        &[(0b01001, &ENTRY_METROPOLITANIZATION_14198198985964840255)],
        &[(0b01001, &ENTRY_METROPOLITANIZE_10953698211072784188)],
        &[(0b01001, &ENTRY_METROPOLITANIZED_2023559975004354749)],
        &[(0b01001, &ENTRY_METROPOLITANIZES_14586245815433709014)],
        &[(0b01001, &ENTRY_METROPOLITANIZING_4475094545669127656)],
    ],
    range: 1..=15,
};

static VARS_METO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METO_CHILDREN),
    value: None,
};

pub static VARS_METO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("estrus"),
        dictgen::InsensitiveStr::Ascii("pae"),
        dictgen::InsensitiveStr::Ascii("pe"),
    ],
    values: &[
        &[(0b11010, &ENTRY_METESTRUS_14748773313097136439)],
        &[(0b11010, &ENTRY_METOPE_8108834617331696480)],
        &[(0b00001, &ENTRY_METOPE_8108834617331696480)],
    ],
    range: 2..=6,
};

static VARS_METH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METH_CHILDREN),
    value: None,
};

pub static VARS_METH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemoglobin"),
        dictgen::InsensitiveStr::Ascii("emoglobin"),
        dictgen::InsensitiveStr::Ascii("odisation"),
        dictgen::InsensitiveStr::Ascii("odisations"),
        dictgen::InsensitiveStr::Ascii("odise"),
        dictgen::InsensitiveStr::Ascii("odised"),
        dictgen::InsensitiveStr::Ascii("odiser"),
        dictgen::InsensitiveStr::Ascii("odisers"),
        dictgen::InsensitiveStr::Ascii("odises"),
        dictgen::InsensitiveStr::Ascii("odising"),
        dictgen::InsensitiveStr::Ascii("odization"),
        dictgen::InsensitiveStr::Ascii("odizations"),
        dictgen::InsensitiveStr::Ascii("odize"),
        dictgen::InsensitiveStr::Ascii("odized"),
        dictgen::InsensitiveStr::Ascii("odizer"),
        dictgen::InsensitiveStr::Ascii("odizers"),
        dictgen::InsensitiveStr::Ascii("odizes"),
        dictgen::InsensitiveStr::Ascii("odizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_METHEMOGLOBIN_1539963096510356106)],
        &[(0b10001, &ENTRY_METHEMOGLOBIN_1539963096510356106)],
        &[(0b10010, &ENTRY_METHODIZATION_4047996741902712542)],
        &[(0b10010, &ENTRY_METHODIZATIONS_13055113924321472470)],
        &[(0b10010, &ENTRY_METHODIZE_14573740405190546697)],
        &[(0b10010, &ENTRY_METHODIZED_2923710854870457764)],
        &[(0b10010, &ENTRY_METHODIZER_6382879261326403628)],
        &[(0b10010, &ENTRY_METHODIZERS_7660184830293053445)],
        &[(0b10010, &ENTRY_METHODIZES_5329049990835330235)],
        &[(0b10010, &ENTRY_METHODIZING_300246035838082411)],
        &[(0b01001, &ENTRY_METHODIZATION_4047996741902712542)],
        &[(0b01001, &ENTRY_METHODIZATIONS_13055113924321472470)],
        &[(0b01001, &ENTRY_METHODIZE_14573740405190546697)],
        &[(0b01001, &ENTRY_METHODIZED_2923710854870457764)],
        &[(0b01001, &ENTRY_METHODIZER_6382879261326403628)],
        &[(0b01001, &ENTRY_METHODIZERS_7660184830293053445)],
        &[(0b01001, &ENTRY_METHODIZES_5329049990835330235)],
        &[(0b01001, &ENTRY_METHODIZING_300246035838082411)],
    ],
    range: 5..=10,
};

static VARS_METE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METE_CHILDREN),
    value: None,
};

pub static VARS_METE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("rgram"),
        dictgen::InsensitiveStr::Ascii("rless"),
        dictgen::InsensitiveStr::Ascii("rship"),
        dictgen::InsensitiveStr::Ascii("strus"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METEORIZATION_14509627179308580678)],
        &[(0b10010, &ENTRY_METEORIZATIONS_4257868931766191814)],
        &[(0b10010, &ENTRY_METEORIZE_13283083497455170525)],
        &[(0b10010, &ENTRY_METEORIZES_1562060441883806775)],
        &[(0b01001, &ENTRY_METEORIZATION_14509627179308580678)],
        &[(0b01001, &ENTRY_METEORIZATIONS_4257868931766191814)],
        &[(0b01001, &ENTRY_METEORIZE_13283083497455170525)],
        &[(0b01001, &ENTRY_METEORIZES_1562060441883806775)],
        &[(0b00001, &ENTRY_METERGRAM_2011699453456886332)],
        &[(0b00001, &ENTRY_METERLESS_12592948617315833276)],
        &[(0b00001, &ENTRY_METERSHIP_4620649639929107458)],
        &[(0b00001, &ENTRY_METESTRUS_14748773313097136439)],
    ],
    range: 5..=10,
};

static VARS_META_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_META_CHILDREN),
    value: None,
};

static VARS_META_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_METAB_NODE),
    Some(&VARS_METAC_NODE),
    None,
    None,
    None,
    Some(&VARS_METAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_METAL_NODE),
    Some(&VARS_METAM_NODE),
    None,
    None,
    Some(&VARS_METAP_NODE),
    None,
    None,
    Some(&VARS_METAS_NODE),
    Some(&VARS_METAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_METAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAT_CHILDREN),
    value: None,
};

pub static VARS_METAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hesise"),
        dictgen::InsensitiveStr::Ascii("hesised"),
        dictgen::InsensitiveStr::Ascii("hesises"),
        dictgen::InsensitiveStr::Ascii("hesising"),
        dictgen::InsensitiveStr::Ascii("hesize"),
        dictgen::InsensitiveStr::Ascii("hesized"),
        dictgen::InsensitiveStr::Ascii("hesizes"),
        dictgen::InsensitiveStr::Ascii("hesizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METATHESIZE_8317290549404760172)],
        &[(0b10010, &ENTRY_METATHESIZED_17698511522871311822)],
        &[(0b10010, &ENTRY_METATHESIZES_3250355132971623620)],
        &[(0b10010, &ENTRY_METATHESIZING_13420103038593666525)],
        &[(0b01001, &ENTRY_METATHESIZE_8317290549404760172)],
        &[(0b01001, &ENTRY_METATHESIZED_17698511522871311822)],
        &[(0b01001, &ENTRY_METATHESIZES_3250355132971623620)],
        &[(0b01001, &ENTRY_METATHESIZING_13420103038593666525)],
    ],
    range: 6..=8,
};

static VARS_METAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAS_CHILDREN),
    value: None,
};

pub static VARS_METAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tasise"),
        dictgen::InsensitiveStr::Ascii("tasised"),
        dictgen::InsensitiveStr::Ascii("tasises"),
        dictgen::InsensitiveStr::Ascii("tasising"),
        dictgen::InsensitiveStr::Ascii("tasize"),
        dictgen::InsensitiveStr::Ascii("tasized"),
        dictgen::InsensitiveStr::Ascii("tasizes"),
        dictgen::InsensitiveStr::Ascii("tasizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METASTASIZE_5162116501126745804)],
        &[(0b10010, &ENTRY_METASTASIZED_6407966435125605786)],
        &[(0b10010, &ENTRY_METASTASIZES_10123690877213783906)],
        &[(0b10010, &ENTRY_METASTASIZING_6012917817918288983)],
        &[(0b01001, &ENTRY_METASTASIZE_5162116501126745804)],
        &[(0b01001, &ENTRY_METASTASIZED_6407966435125605786)],
        &[(0b01001, &ENTRY_METASTASIZES_10123690877213783906)],
        &[(0b01001, &ENTRY_METASTASIZING_6012917817918288983)],
    ],
    range: 6..=8,
};

static VARS_METAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAP_CHILDREN),
    value: None,
};

pub static VARS_METAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("honise"),
        dictgen::InsensitiveStr::Ascii("honises"),
        dictgen::InsensitiveStr::Ascii("honize"),
        dictgen::InsensitiveStr::Ascii("honizes"),
        dictgen::InsensitiveStr::Ascii("horise"),
        dictgen::InsensitiveStr::Ascii("horises"),
        dictgen::InsensitiveStr::Ascii("horize"),
        dictgen::InsensitiveStr::Ascii("horizes"),
        dictgen::InsensitiveStr::Ascii("hysicise"),
        dictgen::InsensitiveStr::Ascii("hysicises"),
        dictgen::InsensitiveStr::Ascii("hysicize"),
        dictgen::InsensitiveStr::Ascii("hysicizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METAPHONIZE_1203465835944745085)],
        &[(0b10010, &ENTRY_METAPHONIZES_12395714309695693792)],
        &[(0b01001, &ENTRY_METAPHONIZE_1203465835944745085)],
        &[(0b01001, &ENTRY_METAPHONIZES_12395714309695693792)],
        &[(0b10010, &ENTRY_METAPHORIZE_4096506888744429951)],
        &[(0b10010, &ENTRY_METAPHORIZES_10519287146723752029)],
        &[(0b01001, &ENTRY_METAPHORIZE_4096506888744429951)],
        &[(0b01001, &ENTRY_METAPHORIZES_10519287146723752029)],
        &[(0b10010, &ENTRY_METAPHYSICIZE_18217550823319187116)],
        &[(0b10010, &ENTRY_METAPHYSICIZES_10696292295026215412)],
        &[(0b01001, &ENTRY_METAPHYSICIZE_18217550823319187116)],
        &[(0b01001, &ENTRY_METAPHYSICIZES_10696292295026215412)],
    ],
    range: 6..=9,
};

static VARS_METAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAM_CHILDREN),
    value: None,
};

pub static VARS_METAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("eriseds"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METAMERIZATION_4255123050371136137)],
        &[(0b10010, &ENTRY_METAMERIZATIONS_4156955698615640017)],
        &[(0b10010, &ENTRY_METAMERIZED_9574184110864577453)],
        &[(0b10010, &ENTRY_METAMERIZEDS_15543905702563975279)],
        &[(0b01001, &ENTRY_METAMERIZATION_4255123050371136137)],
        &[(0b01001, &ENTRY_METAMERIZATIONS_4156955698615640017)],
        &[(0b01001, &ENTRY_METAMERIZED_9574184110864577453)],
        &[(0b01001, &ENTRY_METAMERIZEDS_15543905702563975279)],
    ],
    range: 6..=10,
};

static VARS_METAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAL_CHILDREN),
    value: None,
};

pub static VARS_METAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_METALED_9553049451671231773)],
        &[(0b01001, &ENTRY_METALING_15686558716068715897)],
        &[(0b00001, &ENTRY_METALIZATION_98135509290292258)],
        &[(0b00001, &ENTRY_METALIZATIONS_6695845103746956826)],
        &[(0b00001, &ENTRY_METALIZE_16814796087793133597)],
        &[(0b00001, &ENTRY_METALIZED_15261403894302784256)],
        &[(0b00001, &ENTRY_METALIZES_10341894663346117437)],
        &[(0b00001, &ENTRY_METALIZING_496172402873116442)],
        &[(0b11010, &ENTRY_METALED_9553049451671231773)],
        &[(0b11010, &ENTRY_METALING_15686558716068715897)],
        &[(0b10010, &ENTRY_METALIZATION_98135509290292258)],
        &[(0b10010, &ENTRY_METALIZATIONS_6695845103746956826)],
        &[(0b10010, &ENTRY_METALIZE_16814796087793133597)],
        &[(0b10010, &ENTRY_METALIZED_15261403894302784256)],
        &[(0b10010, &ENTRY_METALIZES_10341894663346117437)],
        &[(0b10010, &ENTRY_METALIZING_496172402873116442)],
        &[(0b01000, &ENTRY_METALIZATION_98135509290292258)],
        &[(0b01000, &ENTRY_METALIZATIONS_6695845103746956826)],
        &[(0b01000, &ENTRY_METALIZE_16814796087793133597)],
        &[(0b01000, &ENTRY_METALIZED_15261403894302784256)],
        &[(0b01000, &ENTRY_METALIZES_10341894663346117437)],
        &[(0b01000, &ENTRY_METALIZING_496172402873116442)],
    ],
    range: 2..=9,
};

static VARS_METAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAG_CHILDREN),
    value: None,
};

pub static VARS_METAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rabolise"),
        dictgen::InsensitiveStr::Ascii("rabolised"),
        dictgen::InsensitiveStr::Ascii("rabolises"),
        dictgen::InsensitiveStr::Ascii("rabolising"),
        dictgen::InsensitiveStr::Ascii("rabolize"),
        dictgen::InsensitiveStr::Ascii("rabolized"),
        dictgen::InsensitiveStr::Ascii("rabolizes"),
        dictgen::InsensitiveStr::Ascii("rabolizing"),
        dictgen::InsensitiveStr::Ascii("robolise"),
        dictgen::InsensitiveStr::Ascii("robolised"),
        dictgen::InsensitiveStr::Ascii("robolises"),
        dictgen::InsensitiveStr::Ascii("robolising"),
        dictgen::InsensitiveStr::Ascii("robolize"),
        dictgen::InsensitiveStr::Ascii("robolized"),
        dictgen::InsensitiveStr::Ascii("robolizes"),
        dictgen::InsensitiveStr::Ascii("robolizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METAGRABOLIZE_15199335552706575875)],
        &[(0b10010, &ENTRY_METAGRABOLIZED_3069196729213555991)],
        &[(0b10010, &ENTRY_METAGRABOLIZES_16179801690891399959)],
        &[(0b10010, &ENTRY_METAGRABOLIZING_7649726571267122104)],
        &[(0b01001, &ENTRY_METAGRABOLIZE_15199335552706575875)],
        &[(0b01001, &ENTRY_METAGRABOLIZED_3069196729213555991)],
        &[(0b01001, &ENTRY_METAGRABOLIZES_16179801690891399959)],
        &[(0b01001, &ENTRY_METAGRABOLIZING_7649726571267122104)],
        &[(0b10010, &ENTRY_METAGROBOLIZE_4973455702264683086)],
        &[(0b10010, &ENTRY_METAGROBOLIZED_14294598726067451953)],
        &[(0b10010, &ENTRY_METAGROBOLIZES_90893501209569579)],
        &[(0b10010, &ENTRY_METAGROBOLIZING_4424158609091001763)],
        &[(0b01001, &ENTRY_METAGROBOLIZE_4973455702264683086)],
        &[(0b01001, &ENTRY_METAGROBOLIZED_14294598726067451953)],
        &[(0b01001, &ENTRY_METAGROBOLIZES_90893501209569579)],
        &[(0b01001, &ENTRY_METAGROBOLIZING_4424158609091001763)],
    ],
    range: 8..=10,
};

static VARS_METAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAC_CHILDREN),
    value: None,
};

pub static VARS_METAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("enters"),
        dictgen::InsensitiveStr::Ascii("entre"),
        dictgen::InsensitiveStr::Ascii("entres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_METACENTER_16724078749924963707)],
        &[(0b00001, &ENTRY_METACENTERS_5577639685165206381)],
        &[(0b11010, &ENTRY_METACENTER_16724078749924963707)],
        &[(0b11010, &ENTRY_METACENTERS_5577639685165206381)],
    ],
    range: 5..=6,
};

static VARS_METAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAB_CHILDREN),
    value: None,
};

pub static VARS_METAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olisable"),
        dictgen::InsensitiveStr::Ascii("olisables"),
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olizable"),
        dictgen::InsensitiveStr::Ascii("olizables"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METABOLIZABLE_9512483414343288081)],
        &[(0b10010, &ENTRY_METABOLIZABLES_16212828364863118123)],
        &[(0b10010, &ENTRY_METABOLIZE_5263729176482445241)],
        &[(0b10010, &ENTRY_METABOLIZED_894424192524670370)],
        &[(0b10010, &ENTRY_METABOLIZES_2735479621970518981)],
        &[(0b10010, &ENTRY_METABOLIZING_8339637372408897948)],
        &[(0b01001, &ENTRY_METABOLIZABLE_9512483414343288081)],
        &[(0b01001, &ENTRY_METABOLIZABLES_16212828364863118123)],
        &[(0b01001, &ENTRY_METABOLIZE_5263729176482445241)],
        &[(0b01001, &ENTRY_METABOLIZED_894424192524670370)],
        &[(0b01001, &ENTRY_METABOLIZES_2735479621970518981)],
        &[(0b01001, &ENTRY_METABOLIZING_8339637372408897948)],
    ],
    range: 5..=9,
};

static VARS_MES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MES_CHILDREN),
    value: None,
};

pub static VARS_MES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("merisabilities"),
        dictgen::InsensitiveStr::Ascii("merisability"),
        dictgen::InsensitiveStr::Ascii("merisable"),
        dictgen::InsensitiveStr::Ascii("merisables"),
        dictgen::InsensitiveStr::Ascii("merisation"),
        dictgen::InsensitiveStr::Ascii("merisations"),
        dictgen::InsensitiveStr::Ascii("merise"),
        dictgen::InsensitiveStr::Ascii("merised"),
        dictgen::InsensitiveStr::Ascii("meriser"),
        dictgen::InsensitiveStr::Ascii("merisers"),
        dictgen::InsensitiveStr::Ascii("merises"),
        dictgen::InsensitiveStr::Ascii("merising"),
        dictgen::InsensitiveStr::Ascii("merizabilities"),
        dictgen::InsensitiveStr::Ascii("merizability"),
        dictgen::InsensitiveStr::Ascii("merizable"),
        dictgen::InsensitiveStr::Ascii("merizables"),
        dictgen::InsensitiveStr::Ascii("merization"),
        dictgen::InsensitiveStr::Ascii("merizations"),
        dictgen::InsensitiveStr::Ascii("merize"),
        dictgen::InsensitiveStr::Ascii("merized"),
        dictgen::InsensitiveStr::Ascii("merizer"),
        dictgen::InsensitiveStr::Ascii("merizers"),
        dictgen::InsensitiveStr::Ascii("merizes"),
        dictgen::InsensitiveStr::Ascii("merizing"),
        dictgen::InsensitiveStr::Ascii("oglea"),
        dictgen::InsensitiveStr::Ascii("ogleal"),
        dictgen::InsensitiveStr::Ascii("ogleas"),
        dictgen::InsensitiveStr::Ascii("ogloea"),
        dictgen::InsensitiveStr::Ascii("ogloeal"),
        dictgen::InsensitiveStr::Ascii("ogloeas"),
        dictgen::InsensitiveStr::Ascii("prise"),
        dictgen::InsensitiveStr::Ascii("prises"),
        dictgen::InsensitiveStr::Ascii("prize"),
        dictgen::InsensitiveStr::Ascii("prizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MESMERIZABILITIES_12304847665223063691)],
        &[(0b10010, &ENTRY_MESMERIZABILITY_3536639779424392826)],
        &[(0b10010, &ENTRY_MESMERIZABLE_15950937949831696970)],
        &[(0b10010, &ENTRY_MESMERIZABLES_2422389219890530110)],
        &[(0b10010, &ENTRY_MESMERIZATION_14956156599191298646)],
        &[(0b10010, &ENTRY_MESMERIZATIONS_11950161412465266055)],
        &[(0b10010, &ENTRY_MESMERIZE_5317367348452378793)],
        &[(0b10010, &ENTRY_MESMERIZED_16433180714453641642)],
        &[(0b10010, &ENTRY_MESMERIZER_14781508848355925919)],
        &[(0b10010, &ENTRY_MESMERIZERS_17679840299174687341)],
        &[(0b10010, &ENTRY_MESMERIZES_16069764006210185557)],
        &[(0b10010, &ENTRY_MESMERIZING_10029307437868883072)],
        &[(0b01001, &ENTRY_MESMERIZABILITIES_12304847665223063691)],
        &[(0b01001, &ENTRY_MESMERIZABILITY_3536639779424392826)],
        &[(0b01001, &ENTRY_MESMERIZABLE_15950937949831696970)],
        &[(0b01001, &ENTRY_MESMERIZABLES_2422389219890530110)],
        &[(0b01001, &ENTRY_MESMERIZATION_14956156599191298646)],
        &[(0b01001, &ENTRY_MESMERIZATIONS_11950161412465266055)],
        &[(0b01001, &ENTRY_MESMERIZE_5317367348452378793)],
        &[(0b01001, &ENTRY_MESMERIZED_16433180714453641642)],
        &[(0b01001, &ENTRY_MESMERIZER_14781508848355925919)],
        &[(0b01001, &ENTRY_MESMERIZERS_17679840299174687341)],
        &[(0b01001, &ENTRY_MESMERIZES_16069764006210185557)],
        &[(0b01001, &ENTRY_MESMERIZING_10029307437868883072)],
        &[(0b00001, &ENTRY_MESOGLEA_18401623678263429076)],
        &[(0b00001, &ENTRY_MESOGLEAL_1417922158905887904)],
        &[(0b00001, &ENTRY_MESOGLEAS_3496831994756905336)],
        &[(0b11010, &ENTRY_MESOGLEA_18401623678263429076)],
        &[(0b11010, &ENTRY_MESOGLEAL_1417922158905887904)],
        &[(0b11010, &ENTRY_MESOGLEAS_3496831994756905336)],
        &[(0b10010, &ENTRY_MESPRIZE_10098306562322193815)],
        &[(0b10010, &ENTRY_MESPRIZES_7758910180714977300)],
        &[(0b01001, &ENTRY_MESPRIZE_10098306562322193815)],
        &[(0b01001, &ENTRY_MESPRIZES_7758910180714977300)],
    ],
    range: 5..=14,
};

static VARS_MER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MER_CHILDREN),
    value: None,
};

pub static VARS_MER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("cerisation"),
        dictgen::InsensitiveStr::Ascii("cerisations"),
        dictgen::InsensitiveStr::Ascii("cerise"),
        dictgen::InsensitiveStr::Ascii("cerised"),
        dictgen::InsensitiveStr::Ascii("ceriser"),
        dictgen::InsensitiveStr::Ascii("cerisers"),
        dictgen::InsensitiveStr::Ascii("cerises"),
        dictgen::InsensitiveStr::Ascii("cerising"),
        dictgen::InsensitiveStr::Ascii("cerization"),
        dictgen::InsensitiveStr::Ascii("cerizations"),
        dictgen::InsensitiveStr::Ascii("cerize"),
        dictgen::InsensitiveStr::Ascii("cerized"),
        dictgen::InsensitiveStr::Ascii("cerizer"),
        dictgen::InsensitiveStr::Ascii("cerizers"),
        dictgen::InsensitiveStr::Ascii("cerizes"),
        dictgen::InsensitiveStr::Ascii("cerizing"),
        dictgen::InsensitiveStr::Ascii("curialisation"),
        dictgen::InsensitiveStr::Ascii("curialisations"),
        dictgen::InsensitiveStr::Ascii("curialise"),
        dictgen::InsensitiveStr::Ascii("curialised"),
        dictgen::InsensitiveStr::Ascii("curialises"),
        dictgen::InsensitiveStr::Ascii("curialising"),
        dictgen::InsensitiveStr::Ascii("curialization"),
        dictgen::InsensitiveStr::Ascii("curializations"),
        dictgen::InsensitiveStr::Ascii("curialize"),
        dictgen::InsensitiveStr::Ascii("curialized"),
        dictgen::InsensitiveStr::Ascii("curializes"),
        dictgen::InsensitiveStr::Ascii("curializing"),
        dictgen::InsensitiveStr::Ascii("curise"),
        dictgen::InsensitiveStr::Ascii("curised"),
        dictgen::InsensitiveStr::Ascii("curises"),
        dictgen::InsensitiveStr::Ascii("curising"),
        dictgen::InsensitiveStr::Ascii("curize"),
        dictgen::InsensitiveStr::Ascii("curized"),
        dictgen::InsensitiveStr::Ascii("curizes"),
        dictgen::InsensitiveStr::Ascii("curizing"),
        dictgen::InsensitiveStr::Ascii("oae"),
        dictgen::InsensitiveStr::Ascii("oe"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MERA_10740593344023131930)],
        &[(0b10010, &ENTRY_MERCERIZATION_7225985380401307657)],
        &[(0b10010, &ENTRY_MERCERIZATIONS_1373548936308982813)],
        &[(0b10010, &ENTRY_MERCERIZE_10358461438508840539)],
        &[(0b10010, &ENTRY_MERCERIZED_6026301924133596159)],
        &[(0b10010, &ENTRY_MERCERIZER_17418192070910227605)],
        &[(0b10010, &ENTRY_MERCERIZERS_4667586509379652583)],
        &[(0b10010, &ENTRY_MERCERIZES_14867805097673002748)],
        &[(0b10010, &ENTRY_MERCERIZING_15719429984314868087)],
        &[(0b01001, &ENTRY_MERCERIZATION_7225985380401307657)],
        &[(0b01001, &ENTRY_MERCERIZATIONS_1373548936308982813)],
        &[(0b01001, &ENTRY_MERCERIZE_10358461438508840539)],
        &[(0b01001, &ENTRY_MERCERIZED_6026301924133596159)],
        &[(0b01001, &ENTRY_MERCERIZER_17418192070910227605)],
        &[(0b01001, &ENTRY_MERCERIZERS_4667586509379652583)],
        &[(0b01001, &ENTRY_MERCERIZES_14867805097673002748)],
        &[(0b01001, &ENTRY_MERCERIZING_15719429984314868087)],
        &[(0b10010, &ENTRY_MERCURIALIZATION_3019477287363156501)],
        &[(0b10010, &ENTRY_MERCURIALIZATIONS_2925060499316503633)],
        &[(0b10010, &ENTRY_MERCURIALIZE_5840604397082793337)],
        &[(0b10010, &ENTRY_MERCURIALIZED_17489760872731595206)],
        &[(0b10010, &ENTRY_MERCURIALIZES_16718020801665912512)],
        &[(0b10010, &ENTRY_MERCURIALIZING_16302250787832211940)],
        &[(0b01001, &ENTRY_MERCURIALIZATION_3019477287363156501)],
        &[(0b01001, &ENTRY_MERCURIALIZATIONS_2925060499316503633)],
        &[(0b01001, &ENTRY_MERCURIALIZE_5840604397082793337)],
        &[(0b01001, &ENTRY_MERCURIALIZED_17489760872731595206)],
        &[(0b01001, &ENTRY_MERCURIALIZES_16718020801665912512)],
        &[(0b01001, &ENTRY_MERCURIALIZING_16302250787832211940)],
        &[(0b10010, &ENTRY_MERCURIZE_8240767278076320017)],
        &[(0b10010, &ENTRY_MERCURIZED_5448748826649481653)],
        &[(0b10010, &ENTRY_MERCURIZES_7473635049011508463)],
        &[(0b10010, &ENTRY_MERCURIZING_11754600008945629993)],
        &[(0b01001, &ENTRY_MERCURIZE_8240767278076320017)],
        &[(0b01001, &ENTRY_MERCURIZED_5448748826649481653)],
        &[(0b01001, &ENTRY_MERCURIZES_7473635049011508463)],
        &[(0b01001, &ENTRY_MERCURIZING_11754600008945629993)],
        &[(0b11010, &ENTRY_MEROE_3985235841752863979)],
        &[(0b00001, &ENTRY_MEROE_3985235841752863979)],
    ],
    range: 1..=14,
};

static VARS_MEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEP_CHILDREN),
    value: None,
};

pub static VARS_MEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hitinae"),
        dictgen::InsensitiveStr::Ascii("hitine"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MEPHITINE_2592245251947249411)],
        &[(0b00001, &ENTRY_MEPHITINE_2592245251947249411)],
    ],
    range: 6..=7,
};

static VARS_MEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEN_CHILDREN),
    value: None,
};

pub static VARS_MEN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ad"),
        dictgen::InsensitiveStr::Ascii("adic"),
        dictgen::InsensitiveStr::Ascii("ads"),
        dictgen::InsensitiveStr::Ascii("delise"),
        dictgen::InsensitiveStr::Ascii("delises"),
        dictgen::InsensitiveStr::Ascii("delize"),
        dictgen::InsensitiveStr::Ascii("delizes"),
        dictgen::InsensitiveStr::Ascii("ingorrhea"),
        dictgen::InsensitiveStr::Ascii("ingorrhoea"),
        dictgen::InsensitiveStr::Ascii("orrhea"),
        dictgen::InsensitiveStr::Ascii("orrheas"),
        dictgen::InsensitiveStr::Ascii("orrheic"),
        dictgen::InsensitiveStr::Ascii("orrhoea"),
        dictgen::InsensitiveStr::Ascii("orrhoeas"),
        dictgen::InsensitiveStr::Ascii("orrhoeic"),
        dictgen::InsensitiveStr::Ascii("sae"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("talisation"),
        dictgen::InsensitiveStr::Ascii("talisations"),
        dictgen::InsensitiveStr::Ascii("talise"),
        dictgen::InsensitiveStr::Ascii("talises"),
        dictgen::InsensitiveStr::Ascii("talization"),
        dictgen::InsensitiveStr::Ascii("talizations"),
        dictgen::InsensitiveStr::Ascii("talize"),
        dictgen::InsensitiveStr::Ascii("talizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MAENAD_17014549470545688439)],
        &[(0b00001, &ENTRY_MAENADIC_10391457552203438714)],
        &[(0b00001, &ENTRY_MAENADS_16301310937820360625)],
        &[(0b10010, &ENTRY_MENDELIZE_725660384615195139)],
        &[(0b10010, &ENTRY_MENDELIZES_3714572217602732083)],
        &[(0b01001, &ENTRY_MENDELIZE_725660384615195139)],
        &[(0b01001, &ENTRY_MENDELIZES_3714572217602732083)],
        &[(0b10001, &ENTRY_MENINGORRHEA_3280169182584942067)],
        &[(0b11010, &ENTRY_MENINGORRHEA_3280169182584942067)],
        &[(0b10001, &ENTRY_MENORRHEA_15147728501411744284)],
        &[(0b10001, &ENTRY_MENORRHEAS_4376102286533960802)],
        &[(0b10001, &ENTRY_MENORRHEIC_11950299570730209529)],
        &[(0b11010, &ENTRY_MENORRHEA_15147728501411744284)],
        &[(0b11010, &ENTRY_MENORRHEAS_4376102286533960802)],
        &[(0b11010, &ENTRY_MENORRHEIC_11950299570730209529)],
        &[(0b11010, &ENTRY_MENSE_4361400896559675654)],
        &[(0b00001, &ENTRY_MENSE_4361400896559675654)],
        &[(0b10010, &ENTRY_MENTALIZATION_5298081617361900300)],
        &[(0b10010, &ENTRY_MENTALIZATIONS_9393104229127640857)],
        &[(0b10010, &ENTRY_MENTALIZE_9941072476539187082)],
        &[(0b10010, &ENTRY_MENTALIZES_7900711112885808496)],
        &[(0b01001, &ENTRY_MENTALIZATION_5298081617361900300)],
        &[(0b01001, &ENTRY_MENTALIZATIONS_9393104229127640857)],
        &[(0b01001, &ENTRY_MENTALIZE_9941072476539187082)],
        &[(0b01001, &ENTRY_MENTALIZES_7900711112885808496)],
    ],
    range: 2..=11,
};

static VARS_MEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEM_CHILDREN),
    value: None,
};

pub static VARS_MEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orialisation"),
        dictgen::InsensitiveStr::Ascii("orialisations"),
        dictgen::InsensitiveStr::Ascii("orialise"),
        dictgen::InsensitiveStr::Ascii("orialised"),
        dictgen::InsensitiveStr::Ascii("orialiser"),
        dictgen::InsensitiveStr::Ascii("orialisers"),
        dictgen::InsensitiveStr::Ascii("orialises"),
        dictgen::InsensitiveStr::Ascii("orialising"),
        dictgen::InsensitiveStr::Ascii("orialization"),
        dictgen::InsensitiveStr::Ascii("orializations"),
        dictgen::InsensitiveStr::Ascii("orialize"),
        dictgen::InsensitiveStr::Ascii("orialized"),
        dictgen::InsensitiveStr::Ascii("orializer"),
        dictgen::InsensitiveStr::Ascii("orializers"),
        dictgen::InsensitiveStr::Ascii("orializes"),
        dictgen::InsensitiveStr::Ascii("orializing"),
        dictgen::InsensitiveStr::Ascii("orisable"),
        dictgen::InsensitiveStr::Ascii("orisables"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("oriser"),
        dictgen::InsensitiveStr::Ascii("orisers"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orizable"),
        dictgen::InsensitiveStr::Ascii("orizables"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizer"),
        dictgen::InsensitiveStr::Ascii("orizers"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MEMORIALIZATION_17445729035231672357)],
        &[(0b10010, &ENTRY_MEMORIALIZATIONS_12221954007792895141)],
        &[(0b10010, &ENTRY_MEMORIALIZE_1075532353319465636)],
        &[(0b10010, &ENTRY_MEMORIALIZED_12387502526621019454)],
        &[(0b10010, &ENTRY_MEMORIALIZER_17702355369469865313)],
        &[(0b10010, &ENTRY_MEMORIALIZERS_13528156587756561766)],
        &[(0b10010, &ENTRY_MEMORIALIZES_6025600930549122809)],
        &[(0b10010, &ENTRY_MEMORIALIZING_6464676930179799173)],
        &[(0b01001, &ENTRY_MEMORIALIZATION_17445729035231672357)],
        &[(0b01001, &ENTRY_MEMORIALIZATIONS_12221954007792895141)],
        &[(0b01001, &ENTRY_MEMORIALIZE_1075532353319465636)],
        &[(0b01001, &ENTRY_MEMORIALIZED_12387502526621019454)],
        &[(0b01001, &ENTRY_MEMORIALIZER_17702355369469865313)],
        &[(0b01001, &ENTRY_MEMORIALIZERS_13528156587756561766)],
        &[(0b01001, &ENTRY_MEMORIALIZES_6025600930549122809)],
        &[(0b01001, &ENTRY_MEMORIALIZING_6464676930179799173)],
        &[(0b10010, &ENTRY_MEMORIZABLE_1586066428099139828)],
        &[(0b10010, &ENTRY_MEMORIZABLES_1763920220382427272)],
        &[(0b10010, &ENTRY_MEMORIZATION_9905762212081933855)],
        &[(0b10010, &ENTRY_MEMORIZATIONS_9230505688495133407)],
        &[(0b10010, &ENTRY_MEMORIZE_12947638813038433309)],
        &[(0b10010, &ENTRY_MEMORIZED_6819787376078494141)],
        &[(0b10010, &ENTRY_MEMORIZER_17044084127009102585)],
        &[(0b10010, &ENTRY_MEMORIZERS_1062747053394007451)],
        &[(0b10010, &ENTRY_MEMORIZES_5171178815680156610)],
        &[(0b10010, &ENTRY_MEMORIZING_3818508847656258506)],
        &[(0b01001, &ENTRY_MEMORIZABLE_1586066428099139828)],
        &[(0b01001, &ENTRY_MEMORIZABLES_1763920220382427272)],
        &[(0b01001, &ENTRY_MEMORIZATION_9905762212081933855)],
        &[(0b01001, &ENTRY_MEMORIZATIONS_9230505688495133407)],
        &[(0b01001, &ENTRY_MEMORIZE_12947638813038433309)],
        &[(0b01001, &ENTRY_MEMORIZED_6819787376078494141)],
        &[(0b01001, &ENTRY_MEMORIZER_17044084127009102585)],
        &[(0b01001, &ENTRY_MEMORIZERS_1062747053394007451)],
        &[(0b01001, &ENTRY_MEMORIZES_5171178815680156610)],
        &[(0b01001, &ENTRY_MEMORIZING_3818508847656258506)],
    ],
    range: 5..=13,
};

static VARS_MEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEL_CHILDREN),
    value: None,
};

pub static VARS_MEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aena"),
        dictgen::InsensitiveStr::Ascii("aenic"),
        dictgen::InsensitiveStr::Ascii("anaemia"),
        dictgen::InsensitiveStr::Ascii("anaemic"),
        dictgen::InsensitiveStr::Ascii("anemia"),
        dictgen::InsensitiveStr::Ascii("anemic"),
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ena"),
        dictgen::InsensitiveStr::Ascii("enic"),
        dictgen::InsensitiveStr::Ascii("iae"),
        dictgen::InsensitiveStr::Ascii("ie"),
        dictgen::InsensitiveStr::Ascii("inae"),
        dictgen::InsensitiveStr::Ascii("ine"),
        dictgen::InsensitiveStr::Ascii("itaemia"),
        dictgen::InsensitiveStr::Ascii("itemia"),
        dictgen::InsensitiveStr::Ascii("ithaemia"),
        dictgen::InsensitiveStr::Ascii("ithemia"),
        dictgen::InsensitiveStr::Ascii("lon"),
        dictgen::InsensitiveStr::Ascii("odisation"),
        dictgen::InsensitiveStr::Ascii("odise"),
        dictgen::InsensitiveStr::Ascii("odised"),
        dictgen::InsensitiveStr::Ascii("odiser"),
        dictgen::InsensitiveStr::Ascii("odises"),
        dictgen::InsensitiveStr::Ascii("odising"),
        dictgen::InsensitiveStr::Ascii("odization"),
        dictgen::InsensitiveStr::Ascii("odize"),
        dictgen::InsensitiveStr::Ascii("odized"),
        dictgen::InsensitiveStr::Ascii("odizer"),
        dictgen::InsensitiveStr::Ascii("odizes"),
        dictgen::InsensitiveStr::Ascii("odizing"),
        dictgen::InsensitiveStr::Ascii("odramatisation"),
        dictgen::InsensitiveStr::Ascii("odramatise"),
        dictgen::InsensitiveStr::Ascii("odramatised"),
        dictgen::InsensitiveStr::Ascii("odramatises"),
        dictgen::InsensitiveStr::Ascii("odramatising"),
        dictgen::InsensitiveStr::Ascii("odramatization"),
        dictgen::InsensitiveStr::Ascii("odramatize"),
        dictgen::InsensitiveStr::Ascii("odramatized"),
        dictgen::InsensitiveStr::Ascii("odramatizes"),
        dictgen::InsensitiveStr::Ascii("odramatizing"),
        dictgen::InsensitiveStr::Ascii("oe"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MELENA_1319080246283801884)],
        &[(0b11010, &ENTRY_MELENIC_3928666269532265702)],
        &[(0b11010, &ENTRY_MELANEMIA_9412572547728781693)],
        &[(0b11010, &ENTRY_MELANEMIC_12814356237780442555)],
        &[(0b10001, &ENTRY_MELANEMIA_9412572547728781693)],
        &[(0b10001, &ENTRY_MELANEMIC_12814356237780442555)],
        &[(0b10010, &ENTRY_MELANIZATION_8548851357095187898)],
        &[(0b10010, &ENTRY_MELANIZE_4514273414820038876)],
        &[(0b10010, &ENTRY_MELANIZED_9428739129770441806)],
        &[(0b10010, &ENTRY_MELANIZES_4133910184183953718)],
        &[(0b10010, &ENTRY_MELANIZING_16999099722254777130)],
        &[(0b01001, &ENTRY_MELANIZATION_8548851357095187898)],
        &[(0b01001, &ENTRY_MELANIZE_4514273414820038876)],
        &[(0b01001, &ENTRY_MELANIZED_9428739129770441806)],
        &[(0b01001, &ENTRY_MELANIZES_4133910184183953718)],
        &[(0b01001, &ENTRY_MELANIZING_16999099722254777130)],
        &[(0b00001, &ENTRY_MELE_3468995732305175976)],
        &[(0b00001, &ENTRY_MELENA_1319080246283801884)],
        &[(0b00001, &ENTRY_MELENIC_3928666269532265702)],
        &[(0b11010, &ENTRY_MELIE_10983361518408075735)],
        &[(0b00001, &ENTRY_MELIE_10983361518408075735)],
        &[(0b11010, &ENTRY_MELINE_4877430347055832480)],
        &[(0b00001, &ENTRY_MELINE_4877430347055832480)],
        &[(0b11010, &ENTRY_MELITEMIA_13453885714439194713)],
        &[(0b00001, &ENTRY_MELITEMIA_13453885714439194713)],
        &[(0b11010, &ENTRY_MELITHEMIA_18261531354421030308)],
        &[(0b00001, &ENTRY_MELITHEMIA_18261531354421030308)],
        &[(0b00001, &ENTRY_MELLON_660640033212487292)],
        &[(0b10010, &ENTRY_MELODIZATION_9293798775884390672)],
        &[(0b10010, &ENTRY_MELODIZE_7912016393930350549)],
        &[(0b10010, &ENTRY_MELODIZED_3082275023028261392)],
        &[(0b10010, &ENTRY_MELODIZER_4236053590845193093)],
        &[(0b10010, &ENTRY_MELODIZES_2517544335598130476)],
        &[(0b10010, &ENTRY_MELODIZING_6937142596752062613)],
        &[(0b01001, &ENTRY_MELODIZATION_9293798775884390672)],
        &[(0b01001, &ENTRY_MELODIZE_7912016393930350549)],
        &[(0b01001, &ENTRY_MELODIZED_3082275023028261392)],
        &[(0b01001, &ENTRY_MELODIZER_4236053590845193093)],
        &[(0b01001, &ENTRY_MELODIZES_2517544335598130476)],
        &[(0b01001, &ENTRY_MELODIZING_6937142596752062613)],
        &[(0b10010, &ENTRY_MELODRAMATIZATION_15214542859978971170)],
        &[(0b10010, &ENTRY_MELODRAMATIZE_8158763736750286482)],
        &[(0b10010, &ENTRY_MELODRAMATIZED_8147783138457416369)],
        &[(0b10010, &ENTRY_MELODRAMATIZES_13654098972815682124)],
        &[(0b10010, &ENTRY_MELODRAMATIZING_8357301537520359496)],
        &[(0b01001, &ENTRY_MELODRAMATIZATION_15214542859978971170)],
        &[(0b01001, &ENTRY_MELODRAMATIZE_8158763736750286482)],
        &[(0b01001, &ENTRY_MELODRAMATIZED_8147783138457416369)],
        &[(0b01001, &ENTRY_MELODRAMATIZES_13654098972815682124)],
        &[(0b01001, &ENTRY_MELODRAMATIZING_8357301537520359496)],
        &[(0b11010, &ENTRY_MELE_3468995732305175976)],
    ],
    range: 1..=14,
};

static VARS_MEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEG_CHILDREN),
    value: None,
};

pub static VARS_MEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aerg"),
        dictgen::InsensitiveStr::Ascii("agramme"),
        dictgen::InsensitiveStr::Ascii("agrammes"),
        dictgen::InsensitiveStr::Ascii("ameter"),
        dictgen::InsensitiveStr::Ascii("ameters"),
        dictgen::InsensitiveStr::Ascii("ametre"),
        dictgen::InsensitiveStr::Ascii("ametres"),
        dictgen::InsensitiveStr::Ascii("bote"),
        dictgen::InsensitiveStr::Ascii("erg"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MEGERG_12697116810965677133)],
        &[(0b10010, &ENTRY_MEGAGRAM_8029617688198245061)],
        &[(0b10010, &ENTRY_MEGAGRAMS_16983511226700950884)],
        &[(0b01001, &ENTRY_MEGAMETER_13646180126000061986)],
        &[(0b01001, &ENTRY_MEGAMETERS_11568490769246802016)],
        &[(0b11010, &ENTRY_MEGAMETER_13646180126000061986)],
        &[(0b11010, &ENTRY_MEGAMETERS_11568490769246802016)],
        &[(0b00001, &ENTRY_MEGBOTE_8260748554334190230)],
        &[(0b00001, &ENTRY_MEGERG_12697116810965677133)],
    ],
    range: 3..=8,
};

static VARS_MED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MED_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_MED_5005187106832009132)]),
};

static VARS_MED_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MEDA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MEDI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_MEDI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEDI_CHILDREN),
    value: None,
};

pub static VARS_MEDI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aeval"),
        dictgen::InsensitiveStr::Ascii("aevalism"),
        dictgen::InsensitiveStr::Ascii("aevalisms"),
        dictgen::InsensitiveStr::Ascii("aevals"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("atisation"),
        dictgen::InsensitiveStr::Ascii("atisations"),
        dictgen::InsensitiveStr::Ascii("atise"),
        dictgen::InsensitiveStr::Ascii("atised"),
        dictgen::InsensitiveStr::Ascii("atises"),
        dictgen::InsensitiveStr::Ascii("atising"),
        dictgen::InsensitiveStr::Ascii("atization"),
        dictgen::InsensitiveStr::Ascii("atizations"),
        dictgen::InsensitiveStr::Ascii("atize"),
        dictgen::InsensitiveStr::Ascii("atized"),
        dictgen::InsensitiveStr::Ascii("atizes"),
        dictgen::InsensitiveStr::Ascii("atizing"),
        dictgen::InsensitiveStr::Ascii("calisation"),
        dictgen::InsensitiveStr::Ascii("calisations"),
        dictgen::InsensitiveStr::Ascii("calise"),
        dictgen::InsensitiveStr::Ascii("calised"),
        dictgen::InsensitiveStr::Ascii("calises"),
        dictgen::InsensitiveStr::Ascii("calising"),
        dictgen::InsensitiveStr::Ascii("calization"),
        dictgen::InsensitiveStr::Ascii("calizations"),
        dictgen::InsensitiveStr::Ascii("calize"),
        dictgen::InsensitiveStr::Ascii("calized"),
        dictgen::InsensitiveStr::Ascii("calizes"),
        dictgen::InsensitiveStr::Ascii("calizing"),
        dictgen::InsensitiveStr::Ascii("evalism"),
        dictgen::InsensitiveStr::Ascii("evalisms"),
        dictgen::InsensitiveStr::Ascii("evally"),
        dictgen::InsensitiveStr::Ascii("terraneanisation"),
        dictgen::InsensitiveStr::Ascii("terraneanisations"),
        dictgen::InsensitiveStr::Ascii("terraneanise"),
        dictgen::InsensitiveStr::Ascii("terraneanises"),
        dictgen::InsensitiveStr::Ascii("terraneanization"),
        dictgen::InsensitiveStr::Ascii("terraneanizations"),
        dictgen::InsensitiveStr::Ascii("terraneanize"),
        dictgen::InsensitiveStr::Ascii("terraneanizes"),
        dictgen::InsensitiveStr::Ascii("umisation"),
        dictgen::InsensitiveStr::Ascii("umisations"),
        dictgen::InsensitiveStr::Ascii("umise"),
        dictgen::InsensitiveStr::Ascii("umises"),
        dictgen::InsensitiveStr::Ascii("umization"),
        dictgen::InsensitiveStr::Ascii("umizations"),
        dictgen::InsensitiveStr::Ascii("umize"),
        dictgen::InsensitiveStr::Ascii("umizes"),
    ],
    values: &[
        &[(0b10011, &ENTRY_MEDIEVAL_17850117342556318282)],
        &[(0b11010, &ENTRY_MEDIEVALISM_12350363398481242202)],
        &[(0b11010, &ENTRY_MEDIEVALISMS_3877776466393255830)],
        &[(0b10011, &ENTRY_MEDIEVALS_565656105957485309)],
        &[(0b10010, &ENTRY_MEDIALIZATION_2773287312950879275)],
        &[(0b10010, &ENTRY_MEDIALIZATIONS_7712797253841570193)],
        &[(0b10010, &ENTRY_MEDIALIZE_4174223040152180933)],
        &[(0b10010, &ENTRY_MEDIALIZES_11093411886143030573)],
        &[(0b01001, &ENTRY_MEDIALIZATION_2773287312950879275)],
        &[(0b01001, &ENTRY_MEDIALIZATIONS_7712797253841570193)],
        &[(0b01001, &ENTRY_MEDIALIZE_4174223040152180933)],
        &[(0b01001, &ENTRY_MEDIALIZES_11093411886143030573)],
        &[(0b10010, &ENTRY_MEDIATIZATION_16965747020256741506)],
        &[(0b10010, &ENTRY_MEDIATIZATIONS_4548539761425641022)],
        &[(0b10010, &ENTRY_MEDIATIZE_1073675855124105129)],
        &[(0b10010, &ENTRY_MEDIATIZED_2185354847870653573)],
        &[(0b10010, &ENTRY_MEDIATIZES_5491715552293568451)],
        &[(0b10010, &ENTRY_MEDIATIZING_15145498889980832015)],
        &[(0b01001, &ENTRY_MEDIATIZATION_16965747020256741506)],
        &[(0b01001, &ENTRY_MEDIATIZATIONS_4548539761425641022)],
        &[(0b01001, &ENTRY_MEDIATIZE_1073675855124105129)],
        &[(0b01001, &ENTRY_MEDIATIZED_2185354847870653573)],
        &[(0b01001, &ENTRY_MEDIATIZES_5491715552293568451)],
        &[(0b01001, &ENTRY_MEDIATIZING_15145498889980832015)],
        &[(0b10010, &ENTRY_MEDICALIZATION_13901867202075475919)],
        &[(0b10010, &ENTRY_MEDICALIZATIONS_11138757215969860042)],
        &[(0b10010, &ENTRY_MEDICALIZE_12140561579340280896)],
        &[(0b10010, &ENTRY_MEDICALIZED_14637350429218388791)],
        &[(0b10010, &ENTRY_MEDICALIZES_11382808734283425833)],
        &[(0b10010, &ENTRY_MEDICALIZING_16755237480538911687)],
        &[(0b01001, &ENTRY_MEDICALIZATION_13901867202075475919)],
        &[(0b01001, &ENTRY_MEDICALIZATIONS_11138757215969860042)],
        &[(0b01001, &ENTRY_MEDICALIZE_12140561579340280896)],
        &[(0b01001, &ENTRY_MEDICALIZED_14637350429218388791)],
        &[(0b01001, &ENTRY_MEDICALIZES_11382808734283425833)],
        &[(0b01001, &ENTRY_MEDICALIZING_16755237480538911687)],
        &[(0b00001, &ENTRY_MEDIEVALISM_12350363398481242202)],
        &[(0b00001, &ENTRY_MEDIEVALISMS_3877776466393255830)],
        &[(0b00001, &ENTRY_MEDIEVALLY_7126203456978659821)],
        &[(0b10010, &ENTRY_MEDITERRANEANIZATION_14409869142875503448)],
        &[(0b10010, &ENTRY_MEDITERRANEANIZATIONS_4152813757418022161)],
        &[(0b10010, &ENTRY_MEDITERRANEANIZE_8505087008798927202)],
        &[(0b10010, &ENTRY_MEDITERRANEANIZES_14935273528506989785)],
        &[(0b01001, &ENTRY_MEDITERRANEANIZATION_14409869142875503448)],
        &[(0b01001, &ENTRY_MEDITERRANEANIZATIONS_4152813757418022161)],
        &[(0b01001, &ENTRY_MEDITERRANEANIZE_8505087008798927202)],
        &[(0b01001, &ENTRY_MEDITERRANEANIZES_14935273528506989785)],
        &[(0b10010, &ENTRY_MEDIUMIZATION_13312123412145110516)],
        &[(0b10010, &ENTRY_MEDIUMIZATIONS_8199131889328831153)],
        &[(0b10010, &ENTRY_MEDIUMIZE_2080345639943490884)],
        &[(0b10010, &ENTRY_MEDIUMIZES_481548870452861109)],
        &[(0b01001, &ENTRY_MEDIUMIZATION_13312123412145110516)],
        &[(0b01001, &ENTRY_MEDIUMIZATIONS_8199131889328831153)],
        &[(0b01001, &ENTRY_MEDIUMIZE_2080345639943490884)],
        &[(0b01001, &ENTRY_MEDIUMIZES_481548870452861109)],
    ],
    range: 5..=17,
};

static VARS_MEDA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEDA_CHILDREN),
    value: None,
};

pub static VARS_MEDA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("list"),
        dictgen::InsensitiveStr::Ascii("lists"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("llist"),
        dictgen::InsensitiveStr::Ascii("llists"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MEDALED_11601917023410661347)],
        &[(0b00001, &ENTRY_MEDALING_14602019896865311927)],
        &[(0b10010, &ENTRY_MEDALIZE_17540992999380469913)],
        &[(0b10010, &ENTRY_MEDALIZES_1584149944297837431)],
        &[(0b00001, &ENTRY_MEDALIST_17015107528020299327)],
        &[(0b00001, &ENTRY_MEDALISTS_7569600200481823699)],
        &[(0b01001, &ENTRY_MEDALIZE_17540992999380469913)],
        &[(0b01001, &ENTRY_MEDALIZES_1584149944297837431)],
        &[(0b11010, &ENTRY_MEDALED_11601917023410661347)],
        &[(0b11010, &ENTRY_MEDALING_14602019896865311927)],
        &[(0b11010, &ENTRY_MEDALIST_17015107528020299327)],
        &[(0b11010, &ENTRY_MEDALISTS_7569600200481823699)],
    ],
    range: 3..=6,
};

static VARS_MEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEC_CHILDREN),
    value: None,
};

pub static VARS_MEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hanicalisation"),
        dictgen::InsensitiveStr::Ascii("hanicalisations"),
        dictgen::InsensitiveStr::Ascii("hanicalise"),
        dictgen::InsensitiveStr::Ascii("hanicalises"),
        dictgen::InsensitiveStr::Ascii("hanicalization"),
        dictgen::InsensitiveStr::Ascii("hanicalizations"),
        dictgen::InsensitiveStr::Ascii("hanicalize"),
        dictgen::InsensitiveStr::Ascii("hanicalizes"),
        dictgen::InsensitiveStr::Ascii("hanisable"),
        dictgen::InsensitiveStr::Ascii("hanisation"),
        dictgen::InsensitiveStr::Ascii("hanisations"),
        dictgen::InsensitiveStr::Ascii("hanise"),
        dictgen::InsensitiveStr::Ascii("hanised"),
        dictgen::InsensitiveStr::Ascii("haniser"),
        dictgen::InsensitiveStr::Ascii("hanisers"),
        dictgen::InsensitiveStr::Ascii("hanises"),
        dictgen::InsensitiveStr::Ascii("hanising"),
        dictgen::InsensitiveStr::Ascii("hanizable"),
        dictgen::InsensitiveStr::Ascii("hanization"),
        dictgen::InsensitiveStr::Ascii("hanizations"),
        dictgen::InsensitiveStr::Ascii("hanize"),
        dictgen::InsensitiveStr::Ascii("hanized"),
        dictgen::InsensitiveStr::Ascii("hanizer"),
        dictgen::InsensitiveStr::Ascii("hanizers"),
        dictgen::InsensitiveStr::Ascii("hanizes"),
        dictgen::InsensitiveStr::Ascii("hanizing"),
        dictgen::InsensitiveStr::Ascii("k"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MECHANICALIZATION_4786839792074015481)],
        &[(0b10010, &ENTRY_MECHANICALIZATIONS_3581916288212780638)],
        &[(0b10010, &ENTRY_MECHANICALIZE_14122646639975689126)],
        &[(0b10010, &ENTRY_MECHANICALIZES_7598675745539959209)],
        &[(0b01001, &ENTRY_MECHANICALIZATION_4786839792074015481)],
        &[(0b01001, &ENTRY_MECHANICALIZATIONS_3581916288212780638)],
        &[(0b01001, &ENTRY_MECHANICALIZE_14122646639975689126)],
        &[(0b01001, &ENTRY_MECHANICALIZES_7598675745539959209)],
        &[(0b10010, &ENTRY_MECHANIZABLE_5249425868989509109)],
        &[(0b10010, &ENTRY_MECHANIZATION_1053035171790140063)],
        &[(0b10010, &ENTRY_MECHANIZATIONS_14663166362277345847)],
        &[(0b10010, &ENTRY_MECHANIZE_16535652198395559730)],
        &[(0b10010, &ENTRY_MECHANIZED_9673871810101964259)],
        &[(0b10010, &ENTRY_MECHANIZER_3254719858646223585)],
        &[(0b10010, &ENTRY_MECHANIZERS_14840837706803972436)],
        &[(0b10010, &ENTRY_MECHANIZES_7811802180133123379)],
        &[(0b10010, &ENTRY_MECHANIZING_15860356773348186437)],
        &[(0b01001, &ENTRY_MECHANIZABLE_5249425868989509109)],
        &[(0b01001, &ENTRY_MECHANIZATION_1053035171790140063)],
        &[(0b01001, &ENTRY_MECHANIZATIONS_14663166362277345847)],
        &[(0b01001, &ENTRY_MECHANIZE_16535652198395559730)],
        &[(0b01001, &ENTRY_MECHANIZED_9673871810101964259)],
        &[(0b01001, &ENTRY_MECHANIZER_3254719858646223585)],
        &[(0b01001, &ENTRY_MECHANIZERS_14840837706803972436)],
        &[(0b01001, &ENTRY_MECHANIZES_7811802180133123379)],
        &[(0b01001, &ENTRY_MECHANIZING_15860356773348186437)],
        &[(0b00001, &ENTRY_MECK_5007702210116580279)],
    ],
    range: 1..=15,
};

static VARS_MEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEA_CHILDREN),
    value: None,
};

pub static VARS_MEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ger"),
        dictgen::InsensitiveStr::Ascii("gerly"),
        dictgen::InsensitiveStr::Ascii("gerness"),
        dictgen::InsensitiveStr::Ascii("gernesses"),
        dictgen::InsensitiveStr::Ascii("gerrer"),
        dictgen::InsensitiveStr::Ascii("gerrest"),
        dictgen::InsensitiveStr::Ascii("gre"),
        dictgen::InsensitiveStr::Ascii("grely"),
        dictgen::InsensitiveStr::Ascii("greness"),
        dictgen::InsensitiveStr::Ascii("grenesses"),
        dictgen::InsensitiveStr::Ascii("grer"),
        dictgen::InsensitiveStr::Ascii("grest"),
        dictgen::InsensitiveStr::Ascii("ndrine"),
        dictgen::InsensitiveStr::Ascii("ndriniform"),
    ],
    values: &[
        &[(0b01001, &ENTRY_MEAGER_16437138915349494155)],
        &[(0b01001, &ENTRY_MEAGERLY_2869873257215414407)],
        &[(0b01001, &ENTRY_MEAGERNESS_12236245874669728945)],
        &[(0b01001, &ENTRY_MEAGERNESSES_3102048822221539405)],
        &[(0b01001, &ENTRY_MEAGERRER_16342562731232285770)],
        &[(0b01001, &ENTRY_MEAGERREST_10155328827598626356)],
        &[(0b11010, &ENTRY_MEAGER_16437138915349494155)],
        &[(0b11010, &ENTRY_MEAGERLY_2869873257215414407)],
        &[(0b11010, &ENTRY_MEAGERNESS_12236245874669728945)],
        &[(0b11010, &ENTRY_MEAGERNESSES_3102048822221539405)],
        &[(0b11010, &ENTRY_MEAGERRER_16342562731232285770)],
        &[(0b11010, &ENTRY_MEAGERREST_10155328827598626356)],
        &[(0b00001, &ENTRY_MEANDRINE_17403064704702625622)],
        &[(0b00001, &ENTRY_MEANDRINIFORM_447585923576901338)],
    ],
    range: 3..=10,
};

static VARS_MA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MA_CHILDREN),
    value: None,
};

static VARS_MA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MAA_NODE),
    None,
    Some(&VARS_MAC_NODE),
    Some(&VARS_MAD_NODE),
    Some(&VARS_MAE_NODE),
    None,
    Some(&VARS_MAG_NODE),
    Some(&VARS_MAH_NODE),
    Some(&VARS_MAI_NODE),
    Some(&VARS_MAJ_NODE),
    None,
    Some(&VARS_MAL_NODE),
    None,
    Some(&VARS_MAN_NODE),
    None,
    None,
    None,
    Some(&VARS_MAR_NODE),
    Some(&VARS_MAS_NODE),
    Some(&VARS_MAT_NODE),
    Some(&VARS_MAU_NODE),
    None,
    None,
    Some(&VARS_MAX_NODE),
    None,
    None,
];

static VARS_MAX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAX_CHILDREN),
    value: None,
};

pub static VARS_MAX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("imisation"),
        dictgen::InsensitiveStr::Ascii("imisations"),
        dictgen::InsensitiveStr::Ascii("imise"),
        dictgen::InsensitiveStr::Ascii("imised"),
        dictgen::InsensitiveStr::Ascii("imiser"),
        dictgen::InsensitiveStr::Ascii("imisers"),
        dictgen::InsensitiveStr::Ascii("imises"),
        dictgen::InsensitiveStr::Ascii("imising"),
        dictgen::InsensitiveStr::Ascii("imization"),
        dictgen::InsensitiveStr::Ascii("imizations"),
        dictgen::InsensitiveStr::Ascii("imize"),
        dictgen::InsensitiveStr::Ascii("imized"),
        dictgen::InsensitiveStr::Ascii("imizer"),
        dictgen::InsensitiveStr::Ascii("imizers"),
        dictgen::InsensitiveStr::Ascii("imizes"),
        dictgen::InsensitiveStr::Ascii("imizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MAXIMIZATION_3582457980210831801)],
        &[(0b10010, &ENTRY_MAXIMIZATIONS_17498251387785973609)],
        &[(0b10010, &ENTRY_MAXIMIZE_3031872585153948954)],
        &[(0b10010, &ENTRY_MAXIMIZED_18322342409602816855)],
        &[(0b10010, &ENTRY_MAXIMIZER_7689755575199270297)],
        &[(0b10010, &ENTRY_MAXIMIZERS_9246458667812951153)],
        &[(0b10010, &ENTRY_MAXIMIZES_8121680605285929508)],
        &[(0b10010, &ENTRY_MAXIMIZING_944961283075648715)],
        &[(0b01001, &ENTRY_MAXIMIZATION_3582457980210831801)],
        &[(0b01001, &ENTRY_MAXIMIZATIONS_17498251387785973609)],
        &[(0b01001, &ENTRY_MAXIMIZE_3031872585153948954)],
        &[(0b01001, &ENTRY_MAXIMIZED_18322342409602816855)],
        &[(0b01001, &ENTRY_MAXIMIZER_7689755575199270297)],
        &[(0b01001, &ENTRY_MAXIMIZERS_9246458667812951153)],
        &[(0b01001, &ENTRY_MAXIMIZES_8121680605285929508)],
        &[(0b01001, &ENTRY_MAXIMIZING_944961283075648715)],
    ],
    range: 5..=10,
};

static VARS_MAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAU_CHILDREN),
    value: None,
};

pub static VARS_MAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dlinise"),
        dictgen::InsensitiveStr::Ascii("dlinises"),
        dictgen::InsensitiveStr::Ascii("dlinize"),
        dictgen::InsensitiveStr::Ascii("dlinizes"),
        dictgen::InsensitiveStr::Ascii("ger"),
        dictgen::InsensitiveStr::Ascii("gre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MAUDLINIZE_9618965871569092413)],
        &[(0b10010, &ENTRY_MAUDLINIZES_5073047051339035071)],
        &[(0b01001, &ENTRY_MAUDLINIZE_9618965871569092413)],
        &[(0b01001, &ENTRY_MAUDLINIZES_5073047051339035071)],
        &[(0b00001, &ENTRY_MAUGER_14029214682617013006)],
        &[(0b11010, &ENTRY_MAUGER_14029214682617013006)],
    ],
    range: 3..=8,
};

static VARS_MAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAT_CHILDREN),
    value: None,
};

pub static VARS_MAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erialisation"),
        dictgen::InsensitiveStr::Ascii("erialisations"),
        dictgen::InsensitiveStr::Ascii("erialise"),
        dictgen::InsensitiveStr::Ascii("erialised"),
        dictgen::InsensitiveStr::Ascii("erialiser"),
        dictgen::InsensitiveStr::Ascii("erialisers"),
        dictgen::InsensitiveStr::Ascii("erialises"),
        dictgen::InsensitiveStr::Ascii("erialising"),
        dictgen::InsensitiveStr::Ascii("erialization"),
        dictgen::InsensitiveStr::Ascii("erializations"),
        dictgen::InsensitiveStr::Ascii("erialize"),
        dictgen::InsensitiveStr::Ascii("erialized"),
        dictgen::InsensitiveStr::Ascii("erializer"),
        dictgen::InsensitiveStr::Ascii("erializers"),
        dictgen::InsensitiveStr::Ascii("erializes"),
        dictgen::InsensitiveStr::Ascii("erializing"),
        dictgen::InsensitiveStr::Ascii("ernalise"),
        dictgen::InsensitiveStr::Ascii("ernalised"),
        dictgen::InsensitiveStr::Ascii("ernalises"),
        dictgen::InsensitiveStr::Ascii("ernalising"),
        dictgen::InsensitiveStr::Ascii("ernalize"),
        dictgen::InsensitiveStr::Ascii("ernalized"),
        dictgen::InsensitiveStr::Ascii("ernalizes"),
        dictgen::InsensitiveStr::Ascii("ernalizing"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("h"),
        dictgen::InsensitiveStr::Ascii("hematicise"),
        dictgen::InsensitiveStr::Ascii("hematicised"),
        dictgen::InsensitiveStr::Ascii("hematicises"),
        dictgen::InsensitiveStr::Ascii("hematicising"),
        dictgen::InsensitiveStr::Ascii("hematicize"),
        dictgen::InsensitiveStr::Ascii("hematicized"),
        dictgen::InsensitiveStr::Ascii("hematicizes"),
        dictgen::InsensitiveStr::Ascii("hematicizing"),
        dictgen::InsensitiveStr::Ascii("hematisation"),
        dictgen::InsensitiveStr::Ascii("hematisations"),
        dictgen::InsensitiveStr::Ascii("hematise"),
        dictgen::InsensitiveStr::Ascii("hematised"),
        dictgen::InsensitiveStr::Ascii("hematises"),
        dictgen::InsensitiveStr::Ascii("hematising"),
        dictgen::InsensitiveStr::Ascii("hematization"),
        dictgen::InsensitiveStr::Ascii("hematizations"),
        dictgen::InsensitiveStr::Ascii("hematize"),
        dictgen::InsensitiveStr::Ascii("hematized"),
        dictgen::InsensitiveStr::Ascii("hematizes"),
        dictgen::InsensitiveStr::Ascii("hematizing"),
        dictgen::InsensitiveStr::Ascii("hs"),
        dictgen::InsensitiveStr::Ascii("res"),
        dictgen::InsensitiveStr::Ascii("ronise"),
        dictgen::InsensitiveStr::Ascii("ronised"),
        dictgen::InsensitiveStr::Ascii("ronises"),
        dictgen::InsensitiveStr::Ascii("ronising"),
        dictgen::InsensitiveStr::Ascii("ronize"),
        dictgen::InsensitiveStr::Ascii("ronized"),
        dictgen::InsensitiveStr::Ascii("ronizes"),
        dictgen::InsensitiveStr::Ascii("ronizing"),
        dictgen::InsensitiveStr::Ascii("thaean"),
        dictgen::InsensitiveStr::Ascii("thean"),
        dictgen::InsensitiveStr::Ascii("ts"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MATERIALIZATION_15275246538418004637)],
        &[(0b10010, &ENTRY_MATERIALIZATIONS_2652185200878385871)],
        &[(0b10010, &ENTRY_MATERIALIZE_751513275282658322)],
        &[(0b10010, &ENTRY_MATERIALIZED_12794251805380683570)],
        &[(0b10010, &ENTRY_MATERIALIZER_11688721774965420403)],
        &[(0b10010, &ENTRY_MATERIALIZERS_17327920471884108445)],
        &[(0b10010, &ENTRY_MATERIALIZES_1701928859160069487)],
        &[(0b10010, &ENTRY_MATERIALIZING_12202103934838377179)],
        &[(0b01001, &ENTRY_MATERIALIZATION_15275246538418004637)],
        &[(0b01001, &ENTRY_MATERIALIZATIONS_2652185200878385871)],
        &[(0b01001, &ENTRY_MATERIALIZE_751513275282658322)],
        &[(0b01001, &ENTRY_MATERIALIZED_12794251805380683570)],
        &[(0b01001, &ENTRY_MATERIALIZER_11688721774965420403)],
        &[(0b01001, &ENTRY_MATERIALIZERS_17327920471884108445)],
        &[(0b01001, &ENTRY_MATERIALIZES_1701928859160069487)],
        &[(0b01001, &ENTRY_MATERIALIZING_12202103934838377179)],
        &[(0b10010, &ENTRY_MATERNALIZE_8146656266552049814)],
        &[(0b10010, &ENTRY_MATERNALIZED_15273074932454584755)],
        &[(0b10010, &ENTRY_MATERNALIZES_1361027105246711827)],
        &[(0b10010, &ENTRY_MATERNALIZING_15264839345210217548)],
        &[(0b01001, &ENTRY_MATERNALIZE_8146656266552049814)],
        &[(0b01001, &ENTRY_MATERNALIZED_15273074932454584755)],
        &[(0b01001, &ENTRY_MATERNALIZES_1361027105246711827)],
        &[(0b01001, &ENTRY_MATERNALIZING_15264839345210217548)],
        &[(0b00001, &ENTRY_MATERS_6749099045482027726)],
        &[(0b01001, &ENTRY_MATH_3909695083920851313)],
        &[(0b10010, &ENTRY_MATHEMATICIZE_7619298293588115367)],
        &[(0b10010, &ENTRY_MATHEMATICIZED_4371402645098526662)],
        &[(0b10010, &ENTRY_MATHEMATICIZES_8912469294750964039)],
        &[(0b10010, &ENTRY_MATHEMATICIZING_4735407800819113204)],
        &[(0b01001, &ENTRY_MATHEMATICIZE_7619298293588115367)],
        &[(0b01001, &ENTRY_MATHEMATICIZED_4371402645098526662)],
        &[(0b01001, &ENTRY_MATHEMATICIZES_8912469294750964039)],
        &[(0b01001, &ENTRY_MATHEMATICIZING_4735407800819113204)],
        &[(0b10010, &ENTRY_MATHEMATIZATION_4218296263451613289)],
        &[(0b10010, &ENTRY_MATHEMATIZATIONS_12482611724386674740)],
        &[(0b10010, &ENTRY_MATHEMATIZE_15531317149241859255)],
        &[(0b10010, &ENTRY_MATHEMATIZED_868413170166016625)],
        &[(0b10010, &ENTRY_MATHEMATIZES_16106848134857387696)],
        &[(0b10010, &ENTRY_MATHEMATIZING_8212888872028484322)],
        &[(0b01001, &ENTRY_MATHEMATIZATION_4218296263451613289)],
        &[(0b01001, &ENTRY_MATHEMATIZATIONS_12482611724386674740)],
        &[(0b01001, &ENTRY_MATHEMATIZE_15531317149241859255)],
        &[(0b01001, &ENTRY_MATHEMATIZED_868413170166016625)],
        &[(0b01001, &ENTRY_MATHEMATIZES_16106848134857387696)],
        &[(0b01001, &ENTRY_MATHEMATIZING_8212888872028484322)],
        &[(0b10010, &ENTRY_MATH_3909695083920851313)],
        &[(0b11010, &ENTRY_MATERS_6749099045482027726)],
        &[(0b10010, &ENTRY_MATRONIZE_9290846381271361340)],
        &[(0b10010, &ENTRY_MATRONIZED_9922374353897617495)],
        &[(0b10010, &ENTRY_MATRONIZES_6031455015684947908)],
        &[(0b10010, &ENTRY_MATRONIZING_17960105682675878116)],
        &[(0b01001, &ENTRY_MATRONIZE_9290846381271361340)],
        &[(0b01001, &ENTRY_MATRONIZED_9922374353897617495)],
        &[(0b01001, &ENTRY_MATRONIZES_6031455015684947908)],
        &[(0b01001, &ENTRY_MATRONIZING_17960105682675878116)],
        &[(0b11010, &ENTRY_MATTHEAN_1484447536407526980)],
        &[(0b00001, &ENTRY_MATTHEAN_1484447536407526980)],
        &[(0b10011, &ENTRY_MATS_9238000290813577978)],
    ],
    range: 1..=13,
};

static VARS_MAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAS_CHILDREN),
    value: None,
};

pub static VARS_MAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("culinisation"),
        dictgen::InsensitiveStr::Ascii("culinisations"),
        dictgen::InsensitiveStr::Ascii("culinise"),
        dictgen::InsensitiveStr::Ascii("culinised"),
        dictgen::InsensitiveStr::Ascii("culinises"),
        dictgen::InsensitiveStr::Ascii("culinising"),
        dictgen::InsensitiveStr::Ascii("culinization"),
        dictgen::InsensitiveStr::Ascii("culinizations"),
        dictgen::InsensitiveStr::Ascii("culinize"),
        dictgen::InsensitiveStr::Ascii("culinized"),
        dictgen::InsensitiveStr::Ascii("culinizes"),
        dictgen::InsensitiveStr::Ascii("culinizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MASCULINIZATION_476161312855423377)],
        &[(0b10010, &ENTRY_MASCULINIZATIONS_3741302049457474)],
        &[(0b10010, &ENTRY_MASCULINIZE_10465215235891946975)],
        &[(0b10010, &ENTRY_MASCULINIZED_1893478532974749197)],
        &[(0b10010, &ENTRY_MASCULINIZES_5402931026791646861)],
        &[(0b10010, &ENTRY_MASCULINIZING_5578995349640297964)],
        &[(0b01001, &ENTRY_MASCULINIZATION_476161312855423377)],
        &[(0b01001, &ENTRY_MASCULINIZATIONS_3741302049457474)],
        &[(0b01001, &ENTRY_MASCULINIZE_10465215235891946975)],
        &[(0b01001, &ENTRY_MASCULINIZED_1893478532974749197)],
        &[(0b01001, &ENTRY_MASCULINIZES_5402931026791646861)],
        &[(0b01001, &ENTRY_MASCULINIZING_5578995349640297964)],
    ],
    range: 8..=13,
};

static VARS_MAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MAR_CHILDREN),
    value: None,
};

static VARS_MAR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_MARB_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_MARG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MARM_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MARS_NODE),
    Some(&VARS_MART_NODE),
    None,
    Some(&VARS_MARV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_MARV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MARV_CHILDREN),
    value: None,
};

pub static VARS_MARV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellous"),
        dictgen::InsensitiveStr::Ascii("ellouser"),
        dictgen::InsensitiveStr::Ascii("ellousest"),
        dictgen::InsensitiveStr::Ascii("ellouslier"),
        dictgen::InsensitiveStr::Ascii("ellousliest"),
        dictgen::InsensitiveStr::Ascii("ellously"),
        dictgen::InsensitiveStr::Ascii("ellousness"),
        dictgen::InsensitiveStr::Ascii("ellousnesses"),
        dictgen::InsensitiveStr::Ascii("elous"),
        dictgen::InsensitiveStr::Ascii("elouser"),
        dictgen::InsensitiveStr::Ascii("elousest"),
        dictgen::InsensitiveStr::Ascii("elouslier"),
        dictgen::InsensitiveStr::Ascii("elousliest"),
        dictgen::InsensitiveStr::Ascii("elously"),
        dictgen::InsensitiveStr::Ascii("elousness"),
        dictgen::InsensitiveStr::Ascii("elousnesses"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MARVELED_7643699015465825056)],
        &[(0b00001, &ENTRY_MARVELER_3178046291913300644)],
        &[(0b00001, &ENTRY_MARVELING_1354065551177639579)],
        &[(0b11010, &ENTRY_MARVELED_7643699015465825056)],
        &[(0b11010, &ENTRY_MARVELER_3178046291913300644)],
        &[(0b11010, &ENTRY_MARVELING_1354065551177639579)],
        &[(0b11010, &ENTRY_MARVELOUS_82637440345212214)],
        &[(0b11010, &ENTRY_MARVELOUSER_7705396939137168592)],
        &[(0b11010, &ENTRY_MARVELOUSEST_912599784216442683)],
        &[(0b11010, &ENTRY_MARVELOUSLIER_12811886966499643595)],
        &[(0b11010, &ENTRY_MARVELOUSLIEST_16737159169599622279)],
        &[(0b11010, &ENTRY_MARVELOUSLY_18213355249698171803)],
        &[(0b11010, &ENTRY_MARVELOUSNESS_15500940188234401273)],
        &[(0b11010, &ENTRY_MARVELOUSNESSES_8865126466913012309)],
        &[(0b00001, &ENTRY_MARVELOUS_82637440345212214)],
        &[(0b00001, &ENTRY_MARVELOUSER_7705396939137168592)],
        &[(0b00001, &ENTRY_MARVELOUSEST_912599784216442683)],
        &[(0b00001, &ENTRY_MARVELOUSLIER_12811886966499643595)],
        &[(0b00001, &ENTRY_MARVELOUSLIEST_16737159169599622279)],
        &[(0b00001, &ENTRY_MARVELOUSLY_18213355249698171803)],
        &[(0b00001, &ENTRY_MARVELOUSNESS_15500940188234401273)],
        &[(0b00001, &ENTRY_MARVELOUSNESSES_8865126466913012309)],
    ],
    range: 4..=12,
};

static VARS_MART_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MART_CHILDREN),
    value: None,
};

pub static VARS_MART_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ialisation"),
        dictgen::InsensitiveStr::Ascii("ialisations"),
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialization"),
        dictgen::InsensitiveStr::Ascii("ializations"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ializes"),
        dictgen::InsensitiveStr::Ascii("yrisation"),
        dictgen::InsensitiveStr::Ascii("yrisations"),
        dictgen::InsensitiveStr::Ascii("yrise"),
        dictgen::InsensitiveStr::Ascii("yrised"),
        dictgen::InsensitiveStr::Ascii("yriser"),
        dictgen::InsensitiveStr::Ascii("yrisers"),
        dictgen::InsensitiveStr::Ascii("yrises"),
        dictgen::InsensitiveStr::Ascii("yrising"),
        dictgen::InsensitiveStr::Ascii("yrization"),
        dictgen::InsensitiveStr::Ascii("yrizations"),
        dictgen::InsensitiveStr::Ascii("yrize"),
        dictgen::InsensitiveStr::Ascii("yrized"),
        dictgen::InsensitiveStr::Ascii("yrizer"),
        dictgen::InsensitiveStr::Ascii("yrizers"),
        dictgen::InsensitiveStr::Ascii("yrizes"),
        dictgen::InsensitiveStr::Ascii("yrizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MARTE_1264890466246841604)],
        &[(0b00001, &ENTRY_MARTE_1264890466246841604)],
        &[(0b10010, &ENTRY_MARTIALIZATION_5691320795357161519)],
        &[(0b10010, &ENTRY_MARTIALIZATIONS_11331832307351504062)],
        &[(0b10010, &ENTRY_MARTIALIZE_6207600694655157640)],
        &[(0b10010, &ENTRY_MARTIALIZES_9070015199521476812)],
        &[(0b01001, &ENTRY_MARTIALIZATION_5691320795357161519)],
        &[(0b01001, &ENTRY_MARTIALIZATIONS_11331832307351504062)],
        &[(0b01001, &ENTRY_MARTIALIZE_6207600694655157640)],
        &[(0b01001, &ENTRY_MARTIALIZES_9070015199521476812)],
        &[(0b10010, &ENTRY_MARTYRIZATION_1336038246734054184)],
        &[(0b10010, &ENTRY_MARTYRIZATIONS_7865429312991140174)],
        &[(0b10010, &ENTRY_MARTYRIZE_10273613966575722757)],
        &[(0b10010, &ENTRY_MARTYRIZED_13501718715194307317)],
        &[(0b10010, &ENTRY_MARTYRIZER_352978430796310060)],
        &[(0b10010, &ENTRY_MARTYRIZERS_13107375000111031172)],
        &[(0b10010, &ENTRY_MARTYRIZES_7886905685535476589)],
        &[(0b10010, &ENTRY_MARTYRIZING_12166812365596250426)],
        &[(0b01001, &ENTRY_MARTYRIZATION_1336038246734054184)],
        &[(0b01001, &ENTRY_MARTYRIZATIONS_7865429312991140174)],
        &[(0b01001, &ENTRY_MARTYRIZE_10273613966575722757)],
        &[(0b01001, &ENTRY_MARTYRIZED_13501718715194307317)],
        &[(0b01001, &ENTRY_MARTYRIZER_352978430796310060)],
        &[(0b01001, &ENTRY_MARTYRIZERS_13107375000111031172)],
        &[(0b01001, &ENTRY_MARTYRIZES_7886905685535476589)],
        &[(0b01001, &ENTRY_MARTYRIZING_12166812365596250426)],
    ],
    range: 1..=11,
};

static VARS_MARS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MARS_CHILDREN),
    value: None,
};

pub static VARS_MARS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("haled"),
        dictgen::InsensitiveStr::Ascii("haling"),
        dictgen::InsensitiveStr::Ascii("halled"),
        dictgen::InsensitiveStr::Ascii("halling"),
        dictgen::InsensitiveStr::Ascii("upialisation"),
        dictgen::InsensitiveStr::Ascii("upialisations"),
        dictgen::InsensitiveStr::Ascii("upialise"),
        dictgen::InsensitiveStr::Ascii("upialised"),
        dictgen::InsensitiveStr::Ascii("upialises"),
        dictgen::InsensitiveStr::Ascii("upialising"),
        dictgen::InsensitiveStr::Ascii("upialization"),
        dictgen::InsensitiveStr::Ascii("upializations"),
        dictgen::InsensitiveStr::Ascii("upialize"),
        dictgen::InsensitiveStr::Ascii("upialized"),
        dictgen::InsensitiveStr::Ascii("upializes"),
        dictgen::InsensitiveStr::Ascii("upializing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MARSHALED_17388940496017695622)],
        &[(0b00001, &ENTRY_MARSHALING_14317227469213788602)],
        &[(0b11010, &ENTRY_MARSHALED_17388940496017695622)],
        &[(0b11010, &ENTRY_MARSHALING_14317227469213788602)],
        &[(0b10010, &ENTRY_MARSUPIALIZATION_10219947028803421507)],
        &[(0b10010, &ENTRY_MARSUPIALIZATIONS_3654437093276933848)],
        &[(0b10010, &ENTRY_MARSUPIALIZE_12376296445019036389)],
        &[(0b10010, &ENTRY_MARSUPIALIZED_10735344292991105898)],
        &[(0b10010, &ENTRY_MARSUPIALIZES_5341397497022180977)],
        &[(0b10010, &ENTRY_MARSUPIALIZING_11776500715390903839)],
        &[(0b01001, &ENTRY_MARSUPIALIZATION_10219947028803421507)],
        &[(0b01001, &ENTRY_MARSUPIALIZATIONS_3654437093276933848)],
        &[(0b01001, &ENTRY_MARSUPIALIZE_12376296445019036389)],
        &[(0b01001, &ENTRY_MARSUPIALIZED_10735344292991105898)],
        &[(0b01001, &ENTRY_MARSUPIALIZES_5341397497022180977)],
        &[(0b01001, &ENTRY_MARSUPIALIZING_11776500715390903839)],
    ],
    range: 5..=13,
};

static VARS_MARM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MARM_CHILDREN),
    value: None,
};

pub static VARS_MARM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arised"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arising"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arized"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("arizing"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elising"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("elizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MARMARIZE_1530762564973937962)],
        &[(0b10010, &ENTRY_MARMARIZED_6434649714306603112)],
        &[(0b10010, &ENTRY_MARMARIZES_4398920726053776800)],
        &[(0b10010, &ENTRY_MARMARIZING_10944122775049128953)],
        &[(0b01001, &ENTRY_MARMARIZE_1530762564973937962)],
        &[(0b01001, &ENTRY_MARMARIZED_6434649714306603112)],
        &[(0b01001, &ENTRY_MARMARIZES_4398920726053776800)],
        &[(0b01001, &ENTRY_MARMARIZING_10944122775049128953)],
        &[(0b10010, &ENTRY_MARMELIZE_3830049982860361754)],
        &[(0b10010, &ENTRY_MARMELIZED_14017857917576761060)],
        &[(0b10010, &ENTRY_MARMELIZES_149426436477796995)],
        &[(0b10010, &ENTRY_MARMELIZING_16367583444998062001)],
        &[(0b01001, &ENTRY_MARMELIZE_3830049982860361754)],
        &[(0b01001, &ENTRY_MARMELIZED_14017857917576761060)],
        &[(0b01001, &ENTRY_MARMELIZES_149426436477796995)],
        &[(0b01001, &ENTRY_MARMELIZING_16367583444998062001)],
    ],
    range: 5..=7,
};

static VARS_MARG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MARG_CHILDREN),
    value: None,
};

pub static VARS_MARG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aritae"),
        dictgen::InsensitiveStr::Ascii("arite"),
        dictgen::InsensitiveStr::Ascii("inalisation"),
        dictgen::InsensitiveStr::Ascii("inalise"),
        dictgen::InsensitiveStr::Ascii("inalised"),
        dictgen::InsensitiveStr::Ascii("inalises"),
        dictgen::InsensitiveStr::Ascii("inalising"),
        dictgen::InsensitiveStr::Ascii("inalization"),
        dictgen::InsensitiveStr::Ascii("inalize"),
        dictgen::InsensitiveStr::Ascii("inalized"),
        dictgen::InsensitiveStr::Ascii("inalizes"),
        dictgen::InsensitiveStr::Ascii("inalizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MARGARITE_2133834570687219123)],
        &[(0b00001, &ENTRY_MARGARITE_2133834570687219123)],
        &[(0b10010, &ENTRY_MARGINALIZATION_845141011968765477)],
        &[(0b10010, &ENTRY_MARGINALIZE_3216468021553056827)],
        &[(0b10010, &ENTRY_MARGINALIZED_7354157641651435628)],
        &[(0b10010, &ENTRY_MARGINALIZES_2216379754364106454)],
        &[(0b10010, &ENTRY_MARGINALIZING_14750515117536904615)],
        &[(0b01001, &ENTRY_MARGINALIZATION_845141011968765477)],
        &[(0b01001, &ENTRY_MARGINALIZE_3216468021553056827)],
        &[(0b01001, &ENTRY_MARGINALIZED_7354157641651435628)],
        &[(0b01001, &ENTRY_MARGINALIZES_2216379754364106454)],
        &[(0b01001, &ENTRY_MARGINALIZING_14750515117536904615)],
    ],
    range: 5..=11,
};

static VARS_MARB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MARB_CHILDREN),
    value: None,
};

pub static VARS_MARB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("leise"),
        dictgen::InsensitiveStr::Ascii("leised"),
        dictgen::InsensitiveStr::Ascii("leises"),
        dictgen::InsensitiveStr::Ascii("leising"),
        dictgen::InsensitiveStr::Ascii("leize"),
        dictgen::InsensitiveStr::Ascii("leized"),
        dictgen::InsensitiveStr::Ascii("leizes"),
        dictgen::InsensitiveStr::Ascii("leizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MARBLEIZE_1587151371458840015)],
        &[(0b10010, &ENTRY_MARBLEIZED_9909511827189901753)],
        &[(0b10010, &ENTRY_MARBLEIZES_13333904138730712912)],
        &[(0b10010, &ENTRY_MARBLEIZING_4602625009210891897)],
        &[(0b01001, &ENTRY_MARBLEIZE_1587151371458840015)],
        &[(0b01001, &ENTRY_MARBLEIZED_9909511827189901753)],
        &[(0b01001, &ENTRY_MARBLEIZES_13333904138730712912)],
        &[(0b01001, &ENTRY_MARBLEIZING_4602625009210891897)],
    ],
    range: 5..=7,
};

static VARS_MAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAN_CHILDREN),
    value: None,
};

pub static VARS_MAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("daean"),
        dictgen::InsensitiveStr::Ascii("daeans"),
        dictgen::InsensitiveStr::Ascii("darinise"),
        dictgen::InsensitiveStr::Ascii("darinises"),
        dictgen::InsensitiveStr::Ascii("darinize"),
        dictgen::InsensitiveStr::Ascii("darinizes"),
        dictgen::InsensitiveStr::Ascii("dean"),
        dictgen::InsensitiveStr::Ascii("deans"),
        dictgen::InsensitiveStr::Ascii("doer"),
        dictgen::InsensitiveStr::Ascii("dore"),
        dictgen::InsensitiveStr::Ascii("euver"),
        dictgen::InsensitiveStr::Ascii("euverabilities"),
        dictgen::InsensitiveStr::Ascii("euverability"),
        dictgen::InsensitiveStr::Ascii("euverable"),
        dictgen::InsensitiveStr::Ascii("euverabler"),
        dictgen::InsensitiveStr::Ascii("euverablest"),
        dictgen::InsensitiveStr::Ascii("euvered"),
        dictgen::InsensitiveStr::Ascii("euverer"),
        dictgen::InsensitiveStr::Ascii("euverers"),
        dictgen::InsensitiveStr::Ascii("euvering"),
        dictgen::InsensitiveStr::Ascii("euverings"),
        dictgen::InsensitiveStr::Ascii("euvers"),
        dictgen::InsensitiveStr::Ascii("hattanise"),
        dictgen::InsensitiveStr::Ascii("hattanises"),
        dictgen::InsensitiveStr::Ascii("hattanize"),
        dictgen::InsensitiveStr::Ascii("hattanizes"),
        dictgen::InsensitiveStr::Ascii("ichaeanism"),
        dictgen::InsensitiveStr::Ascii("ichaeans"),
        dictgen::InsensitiveStr::Ascii("ichaeism"),
        dictgen::InsensitiveStr::Ascii("ichaeisms"),
        dictgen::InsensitiveStr::Ascii("ichaeus"),
        dictgen::InsensitiveStr::Ascii("icheanism"),
        dictgen::InsensitiveStr::Ascii("icheans"),
        dictgen::InsensitiveStr::Ascii("icheus"),
        dictgen::InsensitiveStr::Ascii("nerise"),
        dictgen::InsensitiveStr::Ascii("nerises"),
        dictgen::InsensitiveStr::Ascii("nerize"),
        dictgen::InsensitiveStr::Ascii("nerizes"),
        dictgen::InsensitiveStr::Ascii("oeuver"),
        dictgen::InsensitiveStr::Ascii("oeuvered"),
        dictgen::InsensitiveStr::Ascii("oeuvering"),
        dictgen::InsensitiveStr::Ascii("oeuverings"),
        dictgen::InsensitiveStr::Ascii("oeuvers"),
        dictgen::InsensitiveStr::Ascii("oeuvrabilities"),
        dictgen::InsensitiveStr::Ascii("oeuvrability"),
        dictgen::InsensitiveStr::Ascii("oeuvrable"),
        dictgen::InsensitiveStr::Ascii("oeuvrabler"),
        dictgen::InsensitiveStr::Ascii("oeuvrablest"),
        dictgen::InsensitiveStr::Ascii("oeuvre"),
        dictgen::InsensitiveStr::Ascii("oeuvred"),
        dictgen::InsensitiveStr::Ascii("oeuvrer"),
        dictgen::InsensitiveStr::Ascii("oeuvrers"),
        dictgen::InsensitiveStr::Ascii("oeuvres"),
        dictgen::InsensitiveStr::Ascii("oeuvring"),
        dictgen::InsensitiveStr::Ascii("oeuvrings"),
        dictgen::InsensitiveStr::Ascii("tes"),
        dictgen::InsensitiveStr::Ascii("toes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MANDEAN_16756153629008001222)],
        &[(0b11010, &ENTRY_MANDEANS_6139983685022239651)],
        &[(0b10010, &ENTRY_MANDARINIZE_10729500110561326871)],
        &[(0b10010, &ENTRY_MANDARINIZES_2520496390400529848)],
        &[(0b01001, &ENTRY_MANDARINIZE_10729500110561326871)],
        &[(0b01001, &ENTRY_MANDARINIZES_2520496390400529848)],
        &[(0b10011, &ENTRY_MANDEAN_16756153629008001222)],
        &[(0b10011, &ENTRY_MANDEANS_6139983685022239651)],
        &[(0b00001, &ENTRY_MANDOER_4488991635236985614)],
        &[(0b11010, &ENTRY_MANDOER_4488991635236985614)],
        &[(0b01001, &ENTRY_MANEUVER_2827757268422810275)],
        &[(0b00001, &ENTRY_MANEUVERABILITIES_1191935897985178601)],
        &[(0b00001, &ENTRY_MANEUVERABILITY_13828505830247153454)],
        &[(0b00001, &ENTRY_MANEUVERABLE_15149317836898965786)],
        &[(0b00001, &ENTRY_MANEUVERABLER_8453360608082720316)],
        &[(0b00001, &ENTRY_MANEUVERABLEST_9950206171061443172)],
        &[(0b01001, &ENTRY_MANEUVERED_1283956380608823667)],
        &[(0b00001, &ENTRY_MANEUVERER_16909121286634766647)],
        &[(0b00001, &ENTRY_MANEUVERERS_16918168302778575325)],
        &[(0b01001, &ENTRY_MANEUVERING_7486833768050311559)],
        &[(0b01001, &ENTRY_MANEUVERINGS_15820076380390390309)],
        &[(0b01001, &ENTRY_MANEUVERS_11853919997692060327)],
        &[(0b10010, &ENTRY_MANHATTANIZE_5647753485098145098)],
        &[(0b10010, &ENTRY_MANHATTANIZES_14271946544415650661)],
        &[(0b01001, &ENTRY_MANHATTANIZE_5647753485098145098)],
        &[(0b01001, &ENTRY_MANHATTANIZES_14271946544415650661)],
        &[(0b11010, &ENTRY_MANICHEANISM_14488550733831474062)],
        &[(0b11010, &ENTRY_MANICHEANS_3707320145394072632)],
        &[(0b11010, &ENTRY_MANICHEISM_13987531657185741850)],
        &[(0b11010, &ENTRY_MANICHEISMS_4550426137129529134)],
        &[(0b11010, &ENTRY_MANICHEUS_2463259862210459140)],
        &[(0b00001, &ENTRY_MANICHEANISM_14488550733831474062)],
        &[(0b00001, &ENTRY_MANICHEANS_3707320145394072632)],
        &[(0b00001, &ENTRY_MANICHEUS_2463259862210459140)],
        &[(0b10010, &ENTRY_MANNERIZE_11395156809687075343)],
        &[(0b10010, &ENTRY_MANNERIZES_6256609262116879332)],
        &[(0b01001, &ENTRY_MANNERIZE_11395156809687075343)],
        &[(0b01001, &ENTRY_MANNERIZES_6256609262116879332)],
        &[(0b01000, &ENTRY_MANEUVER_2827757268422810275)],
        &[(0b01000, &ENTRY_MANEUVERED_1283956380608823667)],
        &[(0b01000, &ENTRY_MANEUVERING_7486833768050311559)],
        &[(0b01000, &ENTRY_MANEUVERINGS_15820076380390390309)],
        &[(0b01000, &ENTRY_MANEUVERS_11853919997692060327)],
        &[(0b11010, &ENTRY_MANEUVERABILITIES_1191935897985178601)],
        &[(0b11010, &ENTRY_MANEUVERABILITY_13828505830247153454)],
        &[(0b11010, &ENTRY_MANEUVERABLE_15149317836898965786)],
        &[(0b11010, &ENTRY_MANEUVERABLER_8453360608082720316)],
        &[(0b11010, &ENTRY_MANEUVERABLEST_9950206171061443172)],
        &[(0b11010, &ENTRY_MANEUVER_2827757268422810275)],
        &[(0b11010, &ENTRY_MANEUVERED_1283956380608823667)],
        &[(0b11010, &ENTRY_MANEUVERER_16909121286634766647)],
        &[(0b11010, &ENTRY_MANEUVERERS_16918168302778575325)],
        &[(0b11010, &ENTRY_MANEUVERS_11853919997692060327)],
        &[(0b11010, &ENTRY_MANEUVERING_7486833768050311559)],
        &[(0b11010, &ENTRY_MANEUVERINGS_15820076380390390309)],
        &[(0b00001, &ENTRY_MANTES_7948491308942840471)],
        &[(0b11010, &ENTRY_MANTES_7948491308942840471)],
    ],
    range: 3..=14,
};

static VARS_MAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAL_CHILDREN),
    value: None,
};

pub static VARS_MAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ayise"),
        dictgen::InsensitiveStr::Ascii("ayises"),
        dictgen::InsensitiveStr::Ascii("ayize"),
        dictgen::InsensitiveStr::Ascii("ayizes"),
        dictgen::InsensitiveStr::Ascii("leablise"),
        dictgen::InsensitiveStr::Ascii("leablises"),
        dictgen::InsensitiveStr::Ascii("leablize"),
        dictgen::InsensitiveStr::Ascii("leablizes"),
        dictgen::InsensitiveStr::Ascii("odor"),
        dictgen::InsensitiveStr::Ascii("odorousness"),
        dictgen::InsensitiveStr::Ascii("odors"),
        dictgen::InsensitiveStr::Ascii("odour"),
        dictgen::InsensitiveStr::Ascii("odourousness"),
        dictgen::InsensitiveStr::Ascii("odours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MALAYIZE_5296430804535202958)],
        &[(0b10010, &ENTRY_MALAYIZES_18276018162196625473)],
        &[(0b01001, &ENTRY_MALAYIZE_5296430804535202958)],
        &[(0b01001, &ENTRY_MALAYIZES_18276018162196625473)],
        &[(0b10010, &ENTRY_MALLEABLIZE_10318655257721603696)],
        &[(0b10010, &ENTRY_MALLEABLIZES_18366287958729116459)],
        &[(0b01001, &ENTRY_MALLEABLIZE_10318655257721603696)],
        &[(0b01001, &ENTRY_MALLEABLIZES_18366287958729116459)],
        &[(0b10001, &ENTRY_MALODOR_9484860272957019145)],
        &[(0b00001, &ENTRY_MALODOROUSNESS_10428601882655519000)],
        &[(0b10001, &ENTRY_MALODORS_5259814758580078739)],
        &[(0b11010, &ENTRY_MALODOR_9484860272957019145)],
        &[(0b11010, &ENTRY_MALODOROUSNESS_10428601882655519000)],
        &[(0b11010, &ENTRY_MALODORS_5259814758580078739)],
    ],
    range: 4..=12,
};

static VARS_MAJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAJ_CHILDREN),
    value: None,
};

pub static VARS_MAJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("usculae"),
        dictgen::InsensitiveStr::Ascii("uscule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MAJORIZE_5539776276955597241)],
        &[(0b10010, &ENTRY_MAJORIZES_12523983368341336385)],
        &[(0b01001, &ENTRY_MAJORIZE_5539776276955597241)],
        &[(0b01001, &ENTRY_MAJORIZES_12523983368341336385)],
        &[(0b11010, &ENTRY_MAJUSCULE_12033401179137388733)],
        &[(0b00001, &ENTRY_MAJUSCULE_12033401179137388733)],
    ],
    range: 5..=7,
};

static VARS_MAI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAI_CHILDREN),
    value: None,
};

pub static VARS_MAI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ger"),
        dictgen::InsensitiveStr::Ascii("gre"),
        dictgen::InsensitiveStr::Ascii("nor"),
        dictgen::InsensitiveStr::Ascii("nors"),
        dictgen::InsensitiveStr::Ascii("nour"),
        dictgen::InsensitiveStr::Ascii("nours"),
        dictgen::InsensitiveStr::Ascii("nprise"),
        dictgen::InsensitiveStr::Ascii("nprize"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("sters"),
        dictgen::InsensitiveStr::Ascii("stres"),
        dictgen::InsensitiveStr::Ascii("ze"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MAIGER_13537152603960564241)],
        &[(0b11010, &ENTRY_MAIGER_13537152603960564241)],
        &[(0b00001, &ENTRY_MAINOR_5733081872389949682)],
        &[(0b00001, &ENTRY_MAINORS_8986120186842844665)],
        &[(0b11010, &ENTRY_MAINOR_5733081872389949682)],
        &[(0b11010, &ENTRY_MAINORS_8986120186842844665)],
        &[(0b10010, &ENTRY_MAINPRIZE_16260916113631122574)],
        &[(0b01001, &ENTRY_MAINPRIZE_16260916113631122574)],
        &[(0b10010, &ENTRY_MAIZE_12062254114105624826)],
        &[(0b00001, &ENTRY_MAISTERS_17393346748487206287)],
        &[(0b11010, &ENTRY_MAISTERS_17393346748487206287)],
        &[(0b01001, &ENTRY_MAIZE_12062254114105624826)],
    ],
    range: 2..=6,
};

static VARS_MAH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAH_CHILDREN),
    value: None,
};

pub static VARS_MAH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oganise"),
        dictgen::InsensitiveStr::Ascii("oganised"),
        dictgen::InsensitiveStr::Ascii("oganises"),
        dictgen::InsensitiveStr::Ascii("oganising"),
        dictgen::InsensitiveStr::Ascii("oganize"),
        dictgen::InsensitiveStr::Ascii("oganized"),
        dictgen::InsensitiveStr::Ascii("oganizes"),
        dictgen::InsensitiveStr::Ascii("oganizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MAHOGANIZE_12704575684923134739)],
        &[(0b10010, &ENTRY_MAHOGANIZED_13765023460960760851)],
        &[(0b10010, &ENTRY_MAHOGANIZES_8869675625531273161)],
        &[(0b10010, &ENTRY_MAHOGANIZING_2157300732143181632)],
        &[(0b01001, &ENTRY_MAHOGANIZE_12704575684923134739)],
        &[(0b01001, &ENTRY_MAHOGANIZED_13765023460960760851)],
        &[(0b01001, &ENTRY_MAHOGANIZES_8869675625531273161)],
        &[(0b01001, &ENTRY_MAHOGANIZING_2157300732143181632)],
    ],
    range: 7..=9,
};

static VARS_MAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAG_CHILDREN),
    value: None,
};

pub static VARS_MAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icalise"),
        dictgen::InsensitiveStr::Ascii("icalises"),
        dictgen::InsensitiveStr::Ascii("icalize"),
        dictgen::InsensitiveStr::Ascii("icalizes"),
        dictgen::InsensitiveStr::Ascii("netisabilities"),
        dictgen::InsensitiveStr::Ascii("netisability"),
        dictgen::InsensitiveStr::Ascii("netisable"),
        dictgen::InsensitiveStr::Ascii("netisables"),
        dictgen::InsensitiveStr::Ascii("netisation"),
        dictgen::InsensitiveStr::Ascii("netisations"),
        dictgen::InsensitiveStr::Ascii("netise"),
        dictgen::InsensitiveStr::Ascii("netised"),
        dictgen::InsensitiveStr::Ascii("netiser"),
        dictgen::InsensitiveStr::Ascii("netisers"),
        dictgen::InsensitiveStr::Ascii("netises"),
        dictgen::InsensitiveStr::Ascii("netising"),
        dictgen::InsensitiveStr::Ascii("netizabilities"),
        dictgen::InsensitiveStr::Ascii("netizability"),
        dictgen::InsensitiveStr::Ascii("netizable"),
        dictgen::InsensitiveStr::Ascii("netizables"),
        dictgen::InsensitiveStr::Ascii("netization"),
        dictgen::InsensitiveStr::Ascii("netizations"),
        dictgen::InsensitiveStr::Ascii("netize"),
        dictgen::InsensitiveStr::Ascii("netized"),
        dictgen::InsensitiveStr::Ascii("netizer"),
        dictgen::InsensitiveStr::Ascii("netizers"),
        dictgen::InsensitiveStr::Ascii("netizes"),
        dictgen::InsensitiveStr::Ascii("netizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MAGICALIZE_7976953137203064254)],
        &[(0b10010, &ENTRY_MAGICALIZES_13106311844272986894)],
        &[(0b01001, &ENTRY_MAGICALIZE_7976953137203064254)],
        &[(0b01001, &ENTRY_MAGICALIZES_13106311844272986894)],
        &[(0b10010, &ENTRY_MAGNETIZABILITIES_4532976500756958585)],
        &[(0b10010, &ENTRY_MAGNETIZABILITY_8897213535690779505)],
        &[(0b10010, &ENTRY_MAGNETIZABLE_7101166656275427306)],
        &[(0b10010, &ENTRY_MAGNETIZABLES_5771377044771033482)],
        &[(0b10010, &ENTRY_MAGNETIZATION_9483881663837891030)],
        &[(0b10010, &ENTRY_MAGNETIZATIONS_4200667569204648331)],
        &[(0b10010, &ENTRY_MAGNETIZE_17032040585995329794)],
        &[(0b10010, &ENTRY_MAGNETIZED_12485429316868328420)],
        &[(0b10010, &ENTRY_MAGNETIZER_6335170645696487654)],
        &[(0b10010, &ENTRY_MAGNETIZERS_13287799402027624739)],
        &[(0b10010, &ENTRY_MAGNETIZES_15356358395494315006)],
        &[(0b10010, &ENTRY_MAGNETIZING_16368507504957955556)],
        &[(0b01001, &ENTRY_MAGNETIZABILITIES_4532976500756958585)],
        &[(0b01001, &ENTRY_MAGNETIZABILITY_8897213535690779505)],
        &[(0b01001, &ENTRY_MAGNETIZABLE_7101166656275427306)],
        &[(0b01001, &ENTRY_MAGNETIZABLES_5771377044771033482)],
        &[(0b01001, &ENTRY_MAGNETIZATION_9483881663837891030)],
        &[(0b01001, &ENTRY_MAGNETIZATIONS_4200667569204648331)],
        &[(0b01001, &ENTRY_MAGNETIZE_17032040585995329794)],
        &[(0b01001, &ENTRY_MAGNETIZED_12485429316868328420)],
        &[(0b01001, &ENTRY_MAGNETIZER_6335170645696487654)],
        &[(0b01001, &ENTRY_MAGNETIZERS_13287799402027624739)],
        &[(0b01001, &ENTRY_MAGNETIZES_15356358395494315006)],
        &[(0b01001, &ENTRY_MAGNETIZING_16368507504957955556)],
    ],
    range: 6..=14,
};

static VARS_MAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAE_CHILDREN),
    value: None,
};

pub static VARS_MAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("andrine"),
        dictgen::InsensitiveStr::Ascii("andriniform"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("gbote"),
        dictgen::InsensitiveStr::Ascii("ra"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MEANDRINE_17403064704702625622)],
        &[(0b11010, &ENTRY_MEANDRINIFORM_447585923576901338)],
        &[(0b00001, &ENTRY_MAED_10894543362537765338)],
        &[(0b11010, &ENTRY_MEGBOTE_8260748554334190230)],
        &[(0b11010, &ENTRY_MERA_10740593344023131930)],
    ],
    range: 1..=11,
};

static VARS_MAD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAD_CHILDREN),
    value: None,
};

pub static VARS_MAD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("era"),
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erising"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("erizing"),
        dictgen::InsensitiveStr::Ascii("oera"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MADERA_11374954307771265273)],
        &[(0b10010, &ENTRY_MADERIZATION_3019983916135661284)],
        &[(0b10010, &ENTRY_MADERIZATIONS_16223063707725361780)],
        &[(0b10010, &ENTRY_MADERIZE_4945810677802352669)],
        &[(0b10010, &ENTRY_MADERIZED_2215427830718499320)],
        &[(0b10010, &ENTRY_MADERIZES_4849561976516325657)],
        &[(0b10010, &ENTRY_MADERIZING_6023219948706368202)],
        &[(0b01001, &ENTRY_MADERIZATION_3019983916135661284)],
        &[(0b01001, &ENTRY_MADERIZATIONS_16223063707725361780)],
        &[(0b01001, &ENTRY_MADERIZE_4945810677802352669)],
        &[(0b01001, &ENTRY_MADERIZED_2215427830718499320)],
        &[(0b01001, &ENTRY_MADERIZES_4849561976516325657)],
        &[(0b01001, &ENTRY_MADERIZING_6023219948706368202)],
        &[(0b11010, &ENTRY_MADERA_11374954307771265273)],
    ],
    range: 3..=10,
};

static VARS_MAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAC_CHILDREN),
    value: None,
};

pub static VARS_MAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("adamisation"),
        dictgen::InsensitiveStr::Ascii("adamisations"),
        dictgen::InsensitiveStr::Ascii("adamise"),
        dictgen::InsensitiveStr::Ascii("adamised"),
        dictgen::InsensitiveStr::Ascii("adamises"),
        dictgen::InsensitiveStr::Ascii("adamising"),
        dictgen::InsensitiveStr::Ascii("adamization"),
        dictgen::InsensitiveStr::Ascii("adamizations"),
        dictgen::InsensitiveStr::Ascii("adamize"),
        dictgen::InsensitiveStr::Ascii("adamized"),
        dictgen::InsensitiveStr::Ascii("adamizes"),
        dictgen::InsensitiveStr::Ascii("adamizing"),
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arised"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arising"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arized"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("arizing"),
        dictgen::InsensitiveStr::Ascii("cabaean"),
        dictgen::InsensitiveStr::Ascii("cabean"),
        dictgen::InsensitiveStr::Ascii("hinisation"),
        dictgen::InsensitiveStr::Ascii("hinisations"),
        dictgen::InsensitiveStr::Ascii("hinise"),
        dictgen::InsensitiveStr::Ascii("hinises"),
        dictgen::InsensitiveStr::Ascii("hinization"),
        dictgen::InsensitiveStr::Ascii("hinizations"),
        dictgen::InsensitiveStr::Ascii("hinize"),
        dictgen::InsensitiveStr::Ascii("hinizes"),
        dictgen::InsensitiveStr::Ascii("rander"),
        dictgen::InsensitiveStr::Ascii("randre"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MACADAMIZATION_1584431820497876066)],
        &[(0b10010, &ENTRY_MACADAMIZATIONS_16187855466620683932)],
        &[(0b10010, &ENTRY_MACADAMIZE_1644284481314424821)],
        &[(0b10010, &ENTRY_MACADAMIZED_13516952754031008572)],
        &[(0b10010, &ENTRY_MACADAMIZES_11934694989490356459)],
        &[(0b10010, &ENTRY_MACADAMIZING_8185181599575595730)],
        &[(0b01001, &ENTRY_MACADAMIZATION_1584431820497876066)],
        &[(0b01001, &ENTRY_MACADAMIZATIONS_16187855466620683932)],
        &[(0b01001, &ENTRY_MACADAMIZE_1644284481314424821)],
        &[(0b01001, &ENTRY_MACADAMIZED_13516952754031008572)],
        &[(0b01001, &ENTRY_MACADAMIZES_11934694989490356459)],
        &[(0b01001, &ENTRY_MACADAMIZING_8185181599575595730)],
        &[(0b10010, &ENTRY_MACARIZE_14735487357752047094)],
        &[(0b10010, &ENTRY_MACARIZED_2654443907575694690)],
        &[(0b10010, &ENTRY_MACARIZES_7151048964818447107)],
        &[(0b10010, &ENTRY_MACARIZING_1437864631803225684)],
        &[(0b01001, &ENTRY_MACARIZE_14735487357752047094)],
        &[(0b01001, &ENTRY_MACARIZED_2654443907575694690)],
        &[(0b01001, &ENTRY_MACARIZES_7151048964818447107)],
        &[(0b01001, &ENTRY_MACARIZING_1437864631803225684)],
        &[(0b11010, &ENTRY_MACCABEAN_16382101033687873595)],
        &[(0b00001, &ENTRY_MACCABEAN_16382101033687873595)],
        &[(0b10010, &ENTRY_MACHINIZATION_2975760707951176713)],
        &[(0b10010, &ENTRY_MACHINIZATIONS_1639400841870117244)],
        &[(0b10010, &ENTRY_MACHINIZE_364217525312318254)],
        &[(0b10010, &ENTRY_MACHINIZES_15690933792051137186)],
        &[(0b01001, &ENTRY_MACHINIZATION_2975760707951176713)],
        &[(0b01001, &ENTRY_MACHINIZATIONS_1639400841870117244)],
        &[(0b01001, &ENTRY_MACHINIZE_364217525312318254)],
        &[(0b01001, &ENTRY_MACHINIZES_15690933792051137186)],
        &[(0b00001, &ENTRY_MACRANDER_8372772025292196647)],
        &[(0b11010, &ENTRY_MACRANDER_8372772025292196647)],
        &[(0b11010, &ENTRY_MACULE_16877936518180777160)],
        &[(0b00001, &ENTRY_MACULE_16877936518180777160)],
    ],
    range: 3..=12,
};

static VARS_MAA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAA_CHILDREN),
    value: None,
};

pub static VARS_MAA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ed")],
    values: &[&[(0b11010, &ENTRY_MAED_10894543362537765338)]],
    range: 2..=2,
};

static VARS_L_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_L_CHILDREN),
    value: None,
};

static VARS_L_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_LA_NODE),
    None,
    None,
    None,
    Some(&VARS_LE_NODE),
    None,
    None,
    None,
    Some(&VARS_LI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LU_NODE),
    None,
    None,
    None,
    Some(&VARS_LY_NODE),
    None,
];

static VARS_LY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LY_CHILDREN),
    value: None,
};

pub static VARS_LY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mphaemia"),
        dictgen::InsensitiveStr::Ascii("mphedema"),
        dictgen::InsensitiveStr::Ascii("mphemia"),
        dictgen::InsensitiveStr::Ascii("mphoedema"),
        dictgen::InsensitiveStr::Ascii("ophilisation"),
        dictgen::InsensitiveStr::Ascii("ophilisations"),
        dictgen::InsensitiveStr::Ascii("ophilise"),
        dictgen::InsensitiveStr::Ascii("ophilised"),
        dictgen::InsensitiveStr::Ascii("ophiliser"),
        dictgen::InsensitiveStr::Ascii("ophilises"),
        dictgen::InsensitiveStr::Ascii("ophilising"),
        dictgen::InsensitiveStr::Ascii("ophilization"),
        dictgen::InsensitiveStr::Ascii("ophilizations"),
        dictgen::InsensitiveStr::Ascii("ophilize"),
        dictgen::InsensitiveStr::Ascii("ophilized"),
        dictgen::InsensitiveStr::Ascii("ophilizer"),
        dictgen::InsensitiveStr::Ascii("ophilizes"),
        dictgen::InsensitiveStr::Ascii("ophilizing"),
        dictgen::InsensitiveStr::Ascii("ricisation"),
        dictgen::InsensitiveStr::Ascii("ricise"),
        dictgen::InsensitiveStr::Ascii("ricised"),
        dictgen::InsensitiveStr::Ascii("ricises"),
        dictgen::InsensitiveStr::Ascii("ricising"),
        dictgen::InsensitiveStr::Ascii("ricization"),
        dictgen::InsensitiveStr::Ascii("ricize"),
        dictgen::InsensitiveStr::Ascii("ricized"),
        dictgen::InsensitiveStr::Ascii("ricizes"),
        dictgen::InsensitiveStr::Ascii("ricizing"),
        dictgen::InsensitiveStr::Ascii("sogenisation"),
        dictgen::InsensitiveStr::Ascii("sogenise"),
        dictgen::InsensitiveStr::Ascii("sogenised"),
        dictgen::InsensitiveStr::Ascii("sogenises"),
        dictgen::InsensitiveStr::Ascii("sogenising"),
        dictgen::InsensitiveStr::Ascii("sogenization"),
        dictgen::InsensitiveStr::Ascii("sogenize"),
        dictgen::InsensitiveStr::Ascii("sogenized"),
        dictgen::InsensitiveStr::Ascii("sogenizes"),
        dictgen::InsensitiveStr::Ascii("sogenizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LYMPHEMIA_4006395487683547063)],
        &[(0b10001, &ENTRY_LYMPHEDEMA_9462257687050546686)],
        &[(0b00001, &ENTRY_LYMPHEMIA_4006395487683547063)],
        &[(0b11010, &ENTRY_LYMPHEDEMA_9462257687050546686)],
        &[(0b10010, &ENTRY_LYOPHILIZATION_238925001880862200)],
        &[(0b10010, &ENTRY_LYOPHILIZATIONS_11641961854700529778)],
        &[(0b10010, &ENTRY_LYOPHILIZE_17394361786807322599)],
        &[(0b10010, &ENTRY_LYOPHILIZED_12354358301774087178)],
        &[(0b10010, &ENTRY_LYOPHILIZER_16461672929174295949)],
        &[(0b10010, &ENTRY_LYOPHILIZES_10620381546865479198)],
        &[(0b10010, &ENTRY_LYOPHILIZING_854033355703357663)],
        &[(0b01001, &ENTRY_LYOPHILIZATION_238925001880862200)],
        &[(0b01001, &ENTRY_LYOPHILIZATIONS_11641961854700529778)],
        &[(0b01001, &ENTRY_LYOPHILIZE_17394361786807322599)],
        &[(0b01001, &ENTRY_LYOPHILIZED_12354358301774087178)],
        &[(0b01001, &ENTRY_LYOPHILIZER_16461672929174295949)],
        &[(0b01001, &ENTRY_LYOPHILIZES_10620381546865479198)],
        &[(0b01001, &ENTRY_LYOPHILIZING_854033355703357663)],
        &[(0b10010, &ENTRY_LYRICIZATION_4845217792517129539)],
        &[(0b10010, &ENTRY_LYRICIZE_3580471702679217431)],
        &[(0b10010, &ENTRY_LYRICIZED_10062582136112184480)],
        &[(0b10010, &ENTRY_LYRICIZES_17152418688457986946)],
        &[(0b10010, &ENTRY_LYRICIZING_12512179180165755609)],
        &[(0b01001, &ENTRY_LYRICIZATION_4845217792517129539)],
        &[(0b01001, &ENTRY_LYRICIZE_3580471702679217431)],
        &[(0b01001, &ENTRY_LYRICIZED_10062582136112184480)],
        &[(0b01001, &ENTRY_LYRICIZES_17152418688457986946)],
        &[(0b01001, &ENTRY_LYRICIZING_12512179180165755609)],
        &[(0b10010, &ENTRY_LYSOGENIZATION_16032634144563300808)],
        &[(0b10010, &ENTRY_LYSOGENIZE_13480065233288456493)],
        &[(0b10010, &ENTRY_LYSOGENIZED_694860359451013188)],
        &[(0b10010, &ENTRY_LYSOGENIZES_7093370063997505423)],
        &[(0b10010, &ENTRY_LYSOGENIZING_12375606902428979326)],
        &[(0b01001, &ENTRY_LYSOGENIZATION_16032634144563300808)],
        &[(0b01001, &ENTRY_LYSOGENIZE_13480065233288456493)],
        &[(0b01001, &ENTRY_LYSOGENIZED_694860359451013188)],
        &[(0b01001, &ENTRY_LYSOGENIZES_7093370063997505423)],
        &[(0b01001, &ENTRY_LYSOGENIZING_12375606902428979326)],
    ],
    range: 6..=13,
};

static VARS_LU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LU_CHILDREN),
    value: None,
};

pub static VARS_LU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mbarisation"),
        dictgen::InsensitiveStr::Ascii("mbarisations"),
        dictgen::InsensitiveStr::Ascii("mbarization"),
        dictgen::InsensitiveStr::Ascii("mbarizations"),
        dictgen::InsensitiveStr::Ascii("natise"),
        dictgen::InsensitiveStr::Ascii("natises"),
        dictgen::InsensitiveStr::Ascii("natize"),
        dictgen::InsensitiveStr::Ascii("natizes"),
        dictgen::InsensitiveStr::Ascii("nulae"),
        dictgen::InsensitiveStr::Ascii("nule"),
        dictgen::InsensitiveStr::Ascii("pines"),
        dictgen::InsensitiveStr::Ascii("ster"),
        dictgen::InsensitiveStr::Ascii("stered"),
        dictgen::InsensitiveStr::Ascii("stering"),
        dictgen::InsensitiveStr::Ascii("sterless"),
        dictgen::InsensitiveStr::Ascii("sterlesser"),
        dictgen::InsensitiveStr::Ascii("sterlessest"),
        dictgen::InsensitiveStr::Ascii("sters"),
        dictgen::InsensitiveStr::Ascii("sterware"),
        dictgen::InsensitiveStr::Ascii("sterwares"),
        dictgen::InsensitiveStr::Ascii("streless"),
        dictgen::InsensitiveStr::Ascii("strelesser"),
        dictgen::InsensitiveStr::Ascii("strelessest"),
        dictgen::InsensitiveStr::Ascii("streware"),
        dictgen::InsensitiveStr::Ascii("strewares"),
        dictgen::InsensitiveStr::Ascii("teinisation"),
        dictgen::InsensitiveStr::Ascii("teinisations"),
        dictgen::InsensitiveStr::Ascii("teinise"),
        dictgen::InsensitiveStr::Ascii("teinised"),
        dictgen::InsensitiveStr::Ascii("teinises"),
        dictgen::InsensitiveStr::Ascii("teinising"),
        dictgen::InsensitiveStr::Ascii("teinization"),
        dictgen::InsensitiveStr::Ascii("teinizations"),
        dictgen::InsensitiveStr::Ascii("teinize"),
        dictgen::InsensitiveStr::Ascii("teinized"),
        dictgen::InsensitiveStr::Ascii("teinizes"),
        dictgen::InsensitiveStr::Ascii("teinizing"),
        dictgen::InsensitiveStr::Ascii("theranise"),
        dictgen::InsensitiveStr::Ascii("theraniser"),
        dictgen::InsensitiveStr::Ascii("theranisers"),
        dictgen::InsensitiveStr::Ascii("theranises"),
        dictgen::InsensitiveStr::Ascii("theranize"),
        dictgen::InsensitiveStr::Ascii("theranizer"),
        dictgen::InsensitiveStr::Ascii("theranizers"),
        dictgen::InsensitiveStr::Ascii("theranizes"),
        dictgen::InsensitiveStr::Ascii("trinae"),
        dictgen::InsensitiveStr::Ascii("trine"),
        dictgen::InsensitiveStr::Ascii("v"),
        dictgen::InsensitiveStr::Ascii("vs"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LUMBARIZATION_4848264276836271036)],
        &[(0b10010, &ENTRY_LUMBARIZATIONS_14924040958914962850)],
        &[(0b01001, &ENTRY_LUMBARIZATION_4848264276836271036)],
        &[(0b01001, &ENTRY_LUMBARIZATIONS_14924040958914962850)],
        &[(0b10010, &ENTRY_LUNATIZE_12434524765834737617)],
        &[(0b10010, &ENTRY_LUNATIZES_13282870687606940178)],
        &[(0b01001, &ENTRY_LUNATIZE_12434524765834737617)],
        &[(0b01001, &ENTRY_LUNATIZES_13282870687606940178)],
        &[(0b11010, &ENTRY_LUNULE_15978057700030636506)],
        &[(0b00001, &ENTRY_LUNULE_15978057700030636506)],
        &[(0b01001, &ENTRY_LUPINES_16622756440390859222)],
        &[(0b00001, &ENTRY_LUSTER_34214050459909607)],
        &[(0b00001, &ENTRY_LUSTERED_11665281529057185042)],
        &[(0b00001, &ENTRY_LUSTERING_8070190029646350099)],
        &[(0b00001, &ENTRY_LUSTERLESS_18388613709739398315)],
        &[(0b00001, &ENTRY_LUSTERLESSER_2845716573356909139)],
        &[(0b00001, &ENTRY_LUSTERLESSEST_5530749287519804822)],
        &[(0b00001, &ENTRY_LUSTERS_15914131236659551229)],
        &[(0b00001, &ENTRY_LUSTERWARE_9411302114705132644)],
        &[(0b00001, &ENTRY_LUSTERWARES_13754816865182407391)],
        &[(0b11010, &ENTRY_LUSTERLESS_18388613709739398315)],
        &[(0b11010, &ENTRY_LUSTERLESSER_2845716573356909139)],
        &[(0b11010, &ENTRY_LUSTERLESSEST_5530749287519804822)],
        &[(0b11010, &ENTRY_LUSTERWARE_9411302114705132644)],
        &[(0b11010, &ENTRY_LUSTERWARES_13754816865182407391)],
        &[(0b10010, &ENTRY_LUTEINIZATION_5209056682966161126)],
        &[(0b10010, &ENTRY_LUTEINIZATIONS_5156597664222852099)],
        &[(0b10010, &ENTRY_LUTEINIZE_15983798455720539425)],
        &[(0b10010, &ENTRY_LUTEINIZED_9144184424728701800)],
        &[(0b10010, &ENTRY_LUTEINIZES_490965262104541864)],
        &[(0b10010, &ENTRY_LUTEINIZING_14093891372252248907)],
        &[(0b01001, &ENTRY_LUTEINIZATION_5209056682966161126)],
        &[(0b01001, &ENTRY_LUTEINIZATIONS_5156597664222852099)],
        &[(0b01001, &ENTRY_LUTEINIZE_15983798455720539425)],
        &[(0b01001, &ENTRY_LUTEINIZED_9144184424728701800)],
        &[(0b01001, &ENTRY_LUTEINIZES_490965262104541864)],
        &[(0b01001, &ENTRY_LUTEINIZING_14093891372252248907)],
        &[(0b10010, &ENTRY_LUTHERANIZE_3661784829525467686)],
        &[(0b10010, &ENTRY_LUTHERANIZER_4331994060702238391)],
        &[(0b10010, &ENTRY_LUTHERANIZERS_3305274308745110063)],
        &[(0b10010, &ENTRY_LUTHERANIZES_6735624303465810961)],
        &[(0b01001, &ENTRY_LUTHERANIZE_3661784829525467686)],
        &[(0b01001, &ENTRY_LUTHERANIZER_4331994060702238391)],
        &[(0b01001, &ENTRY_LUTHERANIZERS_3305274308745110063)],
        &[(0b01001, &ENTRY_LUTHERANIZES_6735624303465810961)],
        &[(0b11010, &ENTRY_LUTRINE_10287032623387360926)],
        &[(0b00001, &ENTRY_LUTRINE_10287032623387360926)],
        &[(0b00001, &ENTRY_LOVE_17065904044059271019)],
        &[(0b00001, &ENTRY_LOVES_9736395093583352222)],
    ],
    range: 1..=12,
};

static VARS_LO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_LO_CHILDREN),
    value: None,
};

static VARS_LO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_LOB_NODE),
    Some(&VARS_LOC_NODE),
    Some(&VARS_LOD_NODE),
    Some(&VARS_LOE_NODE),
    None,
    Some(&VARS_LOG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LON_NODE),
    Some(&VARS_LOO_NODE),
    None,
    None,
    Some(&VARS_LOR_NODE),
    None,
    None,
    Some(&VARS_LOU_NODE),
    Some(&VARS_LOV_NODE),
    None,
    None,
    Some(&VARS_LOY_NODE),
    None,
];

static VARS_LOY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOY_CHILDREN),
    value: None,
};

pub static VARS_LOY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LOYALIZE_2379116295027966003)],
        &[(0b10010, &ENTRY_LOYALIZES_16040945990365025303)],
        &[(0b01001, &ENTRY_LOYALIZE_2379116295027966003)],
        &[(0b01001, &ENTRY_LOYALIZES_16040945990365025303)],
    ],
    range: 5..=6,
};

static VARS_LOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOV_CHILDREN),
    value: None,
};

pub static VARS_LOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aebility"),
        dictgen::InsensitiveStr::Ascii("eableness"),
        dictgen::InsensitiveStr::Ascii("eably"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LOVABILITY_12982835729070356135)],
        &[(0b00001, &ENTRY_LOVABLENESS_15385519583573319347)],
        &[(0b00001, &ENTRY_LOVABLY_8687570857338148234)],
    ],
    range: 5..=9,
};

static VARS_LOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOU_CHILDREN),
    value: None,
};

pub static VARS_LOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rdy"),
        dictgen::InsensitiveStr::Ascii("rings"),
        dictgen::InsensitiveStr::Ascii("ry"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("ver"),
        dictgen::InsensitiveStr::Ascii("vered"),
        dictgen::InsensitiveStr::Ascii("vers"),
        dictgen::InsensitiveStr::Ascii("vre"),
        dictgen::InsensitiveStr::Ascii("vred"),
        dictgen::InsensitiveStr::Ascii("vres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LORDY_15173183331192004241)],
        &[(0b11010, &ENTRY_LORINGS_7794739241325186621)],
        &[(0b11010, &ENTRY_LORY_10409127771494675257)],
        &[(0b00001, &ENTRY_LOUTER_8528235889824422998)],
        &[(0b11010, &ENTRY_LOUTER_8528235889824422998)],
        &[(0b01001, &ENTRY_LOUVER_16383649386238497792)],
        &[(0b01001, &ENTRY_LOUVERED_4612129354743875164)],
        &[(0b01001, &ENTRY_LOUVERS_13562782101200585962)],
        &[(0b11010, &ENTRY_LOUVER_16383649386238497792)],
        &[(0b11010, &ENTRY_LOUVERED_4612129354743875164)],
        &[(0b11010, &ENTRY_LOUVERS_13562782101200585962)],
    ],
    range: 2..=5,
};

static VARS_LOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOR_CHILDREN),
    value: None,
};

pub static VARS_LOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dy"),
        dictgen::InsensitiveStr::Ascii("ings"),
        dictgen::InsensitiveStr::Ascii("y"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LORDY_15173183331192004241)],
        &[(0b00001, &ENTRY_LORINGS_7794739241325186621)],
        &[(0b00001, &ENTRY_LORY_10409127771494675257)],
    ],
    range: 1..=4,
};

static VARS_LOO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOO_CHILDREN),
    value: None,
};

pub static VARS_LOO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ed")],
    values: &[&[(0b11010, &ENTRY_LOED_8365575545159393313)]],
    range: 2..=2,
};

static VARS_LON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LON_CHILDREN),
    value: None,
};

pub static VARS_LON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("donisation"),
        dictgen::InsensitiveStr::Ascii("donisations"),
        dictgen::InsensitiveStr::Ascii("donise"),
        dictgen::InsensitiveStr::Ascii("donised"),
        dictgen::InsensitiveStr::Ascii("donises"),
        dictgen::InsensitiveStr::Ascii("donising"),
        dictgen::InsensitiveStr::Ascii("donization"),
        dictgen::InsensitiveStr::Ascii("donizations"),
        dictgen::InsensitiveStr::Ascii("donize"),
        dictgen::InsensitiveStr::Ascii("donized"),
        dictgen::InsensitiveStr::Ascii("donizes"),
        dictgen::InsensitiveStr::Ascii("donizing"),
        dictgen::InsensitiveStr::Ascii("gaeval"),
        dictgen::InsensitiveStr::Ascii("gaevous"),
        dictgen::InsensitiveStr::Ascii("geval"),
        dictgen::InsensitiveStr::Ascii("gevous"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LONDONIZATION_3483226003146039796)],
        &[(0b10010, &ENTRY_LONDONIZATIONS_5821790237984933474)],
        &[(0b10010, &ENTRY_LONDONIZE_2285619791685745756)],
        &[(0b10010, &ENTRY_LONDONIZED_13682591894069407091)],
        &[(0b10010, &ENTRY_LONDONIZES_17116389071000645306)],
        &[(0b10010, &ENTRY_LONDONIZING_5049646724184981911)],
        &[(0b01001, &ENTRY_LONDONIZATION_3483226003146039796)],
        &[(0b01001, &ENTRY_LONDONIZATIONS_5821790237984933474)],
        &[(0b01001, &ENTRY_LONDONIZE_2285619791685745756)],
        &[(0b01001, &ENTRY_LONDONIZED_13682591894069407091)],
        &[(0b01001, &ENTRY_LONDONIZES_17116389071000645306)],
        &[(0b01001, &ENTRY_LONDONIZING_5049646724184981911)],
        &[(0b11010, &ENTRY_LONGEVAL_13747105351595227774)],
        &[(0b11010, &ENTRY_LONGEVOUS_11977473951943958946)],
        &[(0b00001, &ENTRY_LONGEVAL_13747105351595227774)],
        &[(0b00001, &ENTRY_LONGEVOUS_11977473951943958946)],
    ],
    range: 5..=11,
};

static VARS_LOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOG_CHILDREN),
    value: None,
};

pub static VARS_LOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icalisation"),
        dictgen::InsensitiveStr::Ascii("icalisations"),
        dictgen::InsensitiveStr::Ascii("icalise"),
        dictgen::InsensitiveStr::Ascii("icalises"),
        dictgen::InsensitiveStr::Ascii("icalization"),
        dictgen::InsensitiveStr::Ascii("icalizations"),
        dictgen::InsensitiveStr::Ascii("icalize"),
        dictgen::InsensitiveStr::Ascii("icalizes"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icizing"),
        dictgen::InsensitiveStr::Ascii("opaedic"),
        dictgen::InsensitiveStr::Ascii("opaedics"),
        dictgen::InsensitiveStr::Ascii("opedic"),
        dictgen::InsensitiveStr::Ascii("opedics"),
        dictgen::InsensitiveStr::Ascii("orrhea"),
        dictgen::InsensitiveStr::Ascii("orrheas"),
        dictgen::InsensitiveStr::Ascii("orrhoea"),
        dictgen::InsensitiveStr::Ascii("orrhoeas"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LOGICALIZATION_18058606544682163505)],
        &[(0b10010, &ENTRY_LOGICALIZATIONS_16140088037300490067)],
        &[(0b10010, &ENTRY_LOGICALIZE_18334947113562046396)],
        &[(0b10010, &ENTRY_LOGICALIZES_2075559869050334975)],
        &[(0b01001, &ENTRY_LOGICALIZATION_18058606544682163505)],
        &[(0b01001, &ENTRY_LOGICALIZATIONS_16140088037300490067)],
        &[(0b01001, &ENTRY_LOGICALIZE_18334947113562046396)],
        &[(0b01001, &ENTRY_LOGICALIZES_2075559869050334975)],
        &[(0b10010, &ENTRY_LOGICIZE_939832317937132206)],
        &[(0b10010, &ENTRY_LOGICIZED_12091726186783944112)],
        &[(0b10010, &ENTRY_LOGICIZES_17442537854886090020)],
        &[(0b10010, &ENTRY_LOGICIZING_8064941827003577208)],
        &[(0b01001, &ENTRY_LOGICIZE_939832317937132206)],
        &[(0b01001, &ENTRY_LOGICIZED_12091726186783944112)],
        &[(0b01001, &ENTRY_LOGICIZES_17442537854886090020)],
        &[(0b01001, &ENTRY_LOGICIZING_8064941827003577208)],
        &[(0b11010, &ENTRY_LOGOPEDIC_1358074550790185466)],
        &[(0b11010, &ENTRY_LOGOPEDICS_1761751374576042069)],
        &[(0b10001, &ENTRY_LOGOPEDIC_1358074550790185466)],
        &[(0b10001, &ENTRY_LOGOPEDICS_1761751374576042069)],
        &[(0b11001, &ENTRY_LOGORRHEA_8997080484454664729)],
        &[(0b11001, &ENTRY_LOGORRHEAS_14700518672865329126)],
        &[(0b10010, &ENTRY_LOGORRHEA_8997080484454664729)],
        &[(0b10010, &ENTRY_LOGORRHEAS_14700518672865329126)],
    ],
    range: 5..=12,
};

static VARS_LOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOE_CHILDREN),
    value: None,
};

pub static VARS_LOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("sses"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LOED_8365575545159393313)],
        &[(0b11010, &ENTRY_LESSES_13624938550715380684)],
    ],
    range: 1..=4,
};

static VARS_LOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOD_CHILDREN),
    value: None,
};

pub static VARS_LOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iculae"),
        dictgen::InsensitiveStr::Ascii("icule"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LODICULE_6758636995666963377)],
        &[(0b00001, &ENTRY_LODICULE_6758636995666963377)],
    ],
    range: 5..=6,
};

static VARS_LOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOC_CHILDREN),
    value: None,
};

pub static VARS_LOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisable"),
        dictgen::InsensitiveStr::Ascii("alisabler"),
        dictgen::InsensitiveStr::Ascii("alisables"),
        dictgen::InsensitiveStr::Ascii("alisablest"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alizable"),
        dictgen::InsensitiveStr::Ascii("alizabler"),
        dictgen::InsensitiveStr::Ascii("alizables"),
        dictgen::InsensitiveStr::Ascii("alizablest"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LOCALIZABLE_18184729227341816025)],
        &[(0b10010, &ENTRY_LOCALIZABLER_4472819140531439518)],
        &[(0b10010, &ENTRY_LOCALIZABLES_14485108443499471420)],
        &[(0b10010, &ENTRY_LOCALIZABLEST_6312048620019063505)],
        &[(0b10010, &ENTRY_LOCALIZATION_1714165233158101768)],
        &[(0b10010, &ENTRY_LOCALIZATIONS_10357720798895176938)],
        &[(0b10010, &ENTRY_LOCALIZE_3508370761131546110)],
        &[(0b10010, &ENTRY_LOCALIZED_15436756507414158023)],
        &[(0b10010, &ENTRY_LOCALIZER_12500323668628991619)],
        &[(0b10010, &ENTRY_LOCALIZERS_9928746809280119061)],
        &[(0b10010, &ENTRY_LOCALIZES_128174617828783907)],
        &[(0b10010, &ENTRY_LOCALIZING_919540865361361114)],
        &[(0b01001, &ENTRY_LOCALIZABLE_18184729227341816025)],
        &[(0b01001, &ENTRY_LOCALIZABLER_4472819140531439518)],
        &[(0b01001, &ENTRY_LOCALIZABLES_14485108443499471420)],
        &[(0b01001, &ENTRY_LOCALIZABLEST_6312048620019063505)],
        &[(0b01001, &ENTRY_LOCALIZATION_1714165233158101768)],
        &[(0b01001, &ENTRY_LOCALIZATIONS_10357720798895176938)],
        &[(0b01001, &ENTRY_LOCALIZE_3508370761131546110)],
        &[(0b01001, &ENTRY_LOCALIZED_15436756507414158023)],
        &[(0b01001, &ENTRY_LOCALIZER_12500323668628991619)],
        &[(0b01001, &ENTRY_LOCALIZERS_9928746809280119061)],
        &[(0b01001, &ENTRY_LOCALIZES_128174617828783907)],
        &[(0b01001, &ENTRY_LOCALIZING_919540865361361114)],
    ],
    range: 5..=10,
};

static VARS_LOB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOB_CHILDREN),
    value: None,
};

pub static VARS_LOB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("otomise"),
        dictgen::InsensitiveStr::Ascii("otomised"),
        dictgen::InsensitiveStr::Ascii("otomises"),
        dictgen::InsensitiveStr::Ascii("otomising"),
        dictgen::InsensitiveStr::Ascii("otomize"),
        dictgen::InsensitiveStr::Ascii("otomized"),
        dictgen::InsensitiveStr::Ascii("otomizes"),
        dictgen::InsensitiveStr::Ascii("otomizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LOBOTOMIZE_8963885444869982297)],
        &[(0b10010, &ENTRY_LOBOTOMIZED_8233435547170173963)],
        &[(0b10010, &ENTRY_LOBOTOMIZES_12096959998457471825)],
        &[(0b10010, &ENTRY_LOBOTOMIZING_1629157880661707450)],
        &[(0b01001, &ENTRY_LOBOTOMIZE_8963885444869982297)],
        &[(0b01001, &ENTRY_LOBOTOMIZED_8233435547170173963)],
        &[(0b01001, &ENTRY_LOBOTOMIZES_12096959998457471825)],
        &[(0b01001, &ENTRY_LOBOTOMIZING_1629157880661707450)],
    ],
    range: 7..=9,
};

static VARS_LI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_LI_CHILDREN),
    value: None,
};

static VARS_LI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_LIB_NODE),
    Some(&VARS_LIC_NODE),
    None,
    None,
    None,
    Some(&VARS_LIG_NODE),
    None,
    None,
    None,
    Some(&VARS_LIK_NODE),
    Some(&VARS_LIL_NODE),
    None,
    Some(&VARS_LIN_NODE),
    Some(&VARS_LIO_NODE),
    Some(&VARS_LIP_NODE),
    Some(&VARS_LIQ_NODE),
    None,
    Some(&VARS_LIS_NODE),
    Some(&VARS_LIT_NODE),
    None,
    Some(&VARS_LIV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_LIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIV_CHILDREN),
    value: None,
};

pub static VARS_LIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("able")],
    values: &[&[(0b11001, &ENTRY_LIVABLE_13408079841838673902)]],
    range: 4..=4,
};

static VARS_LIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIT_CHILDREN),
    value: None,
};

pub static VARS_LIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("eralisation"),
        dictgen::InsensitiveStr::Ascii("eralisations"),
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralised"),
        dictgen::InsensitiveStr::Ascii("eraliser"),
        dictgen::InsensitiveStr::Ascii("eralisers"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralising"),
        dictgen::InsensitiveStr::Ascii("eralization"),
        dictgen::InsensitiveStr::Ascii("eralizations"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralized"),
        dictgen::InsensitiveStr::Ascii("eralizer"),
        dictgen::InsensitiveStr::Ascii("eralizers"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("eralizing"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("haemia"),
        dictgen::InsensitiveStr::Ascii("haemic"),
        dictgen::InsensitiveStr::Ascii("hed"),
        dictgen::InsensitiveStr::Ascii("hemia"),
        dictgen::InsensitiveStr::Ascii("hemic"),
        dictgen::InsensitiveStr::Ascii("hoed"),
        dictgen::InsensitiveStr::Ascii("hographise"),
        dictgen::InsensitiveStr::Ascii("hographises"),
        dictgen::InsensitiveStr::Ascii("hographize"),
        dictgen::InsensitiveStr::Ascii("hographizes"),
        dictgen::InsensitiveStr::Ascii("hopaedion"),
        dictgen::InsensitiveStr::Ascii("hopaedium"),
        dictgen::InsensitiveStr::Ascii("hopedion"),
        dictgen::InsensitiveStr::Ascii("hopedium"),
        dictgen::InsensitiveStr::Ascii("hophysae"),
        dictgen::InsensitiveStr::Ascii("hophyse"),
        dictgen::InsensitiveStr::Ascii("hotritise"),
        dictgen::InsensitiveStr::Ascii("hotritised"),
        dictgen::InsensitiveStr::Ascii("hotritises"),
        dictgen::InsensitiveStr::Ascii("hotritising"),
        dictgen::InsensitiveStr::Ascii("hotritize"),
        dictgen::InsensitiveStr::Ascii("hotritized"),
        dictgen::InsensitiveStr::Ascii("hotritizes"),
        dictgen::InsensitiveStr::Ascii("hotritizing"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("res"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LITER_6442068802085842758)],
        &[(0b10010, &ENTRY_LITERALIZATION_1756167120132481203)],
        &[(0b10010, &ENTRY_LITERALIZATIONS_12672487873607486420)],
        &[(0b10010, &ENTRY_LITERALIZE_936950175462886011)],
        &[(0b10010, &ENTRY_LITERALIZED_12392805848021505273)],
        &[(0b10010, &ENTRY_LITERALIZER_11935455981977574700)],
        &[(0b10010, &ENTRY_LITERALIZERS_8534907654562214344)],
        &[(0b10010, &ENTRY_LITERALIZES_12963354118044673239)],
        &[(0b10010, &ENTRY_LITERALIZING_4067560910880631706)],
        &[(0b01001, &ENTRY_LITERALIZATION_1756167120132481203)],
        &[(0b01001, &ENTRY_LITERALIZATIONS_12672487873607486420)],
        &[(0b01001, &ENTRY_LITERALIZE_936950175462886011)],
        &[(0b01001, &ENTRY_LITERALIZED_12392805848021505273)],
        &[(0b01001, &ENTRY_LITERALIZER_11935455981977574700)],
        &[(0b01001, &ENTRY_LITERALIZERS_8534907654562214344)],
        &[(0b01001, &ENTRY_LITERALIZES_12963354118044673239)],
        &[(0b01001, &ENTRY_LITERALIZING_4067560910880631706)],
        &[(0b00001, &ENTRY_LITERS_6702315605664025195)],
        &[(0b11010, &ENTRY_LITHEMIA_951694259866460815)],
        &[(0b11010, &ENTRY_LITHEMIC_4518089608533106528)],
        &[(0b00001, &ENTRY_LITHED_9698245383532623012)],
        &[(0b10001, &ENTRY_LITHEMIA_951694259866460815)],
        &[(0b10001, &ENTRY_LITHEMIC_4518089608533106528)],
        &[(0b11010, &ENTRY_LITHED_9698245383532623012)],
        &[(0b10010, &ENTRY_LITHOGRAPHIZE_10224940842516385348)],
        &[(0b10010, &ENTRY_LITHOGRAPHIZES_4093440307906412004)],
        &[(0b01001, &ENTRY_LITHOGRAPHIZE_10224940842516385348)],
        &[(0b01001, &ENTRY_LITHOGRAPHIZES_4093440307906412004)],
        &[(0b11010, &ENTRY_LITHOPEDION_16487916873434462293)],
        &[(0b11010, &ENTRY_LITHOPEDIUM_5496254320864204281)],
        &[(0b10001, &ENTRY_LITHOPEDION_16487916873434462293)],
        &[(0b10001, &ENTRY_LITHOPEDIUM_5496254320864204281)],
        &[(0b11010, &ENTRY_LITHOPHYSE_11706337403790507355)],
        &[(0b00001, &ENTRY_LITHOPHYSE_11706337403790507355)],
        &[(0b10010, &ENTRY_LITHOTRITIZE_8820380951742023282)],
        &[(0b10010, &ENTRY_LITHOTRITIZED_2791851903963662948)],
        &[(0b10010, &ENTRY_LITHOTRITIZES_18077690319530725305)],
        &[(0b10010, &ENTRY_LITHOTRITIZING_7988737376840854573)],
        &[(0b01001, &ENTRY_LITHOTRITIZE_8820380951742023282)],
        &[(0b01001, &ENTRY_LITHOTRITIZED_2791851903963662948)],
        &[(0b01001, &ENTRY_LITHOTRITIZES_18077690319530725305)],
        &[(0b01001, &ENTRY_LITHOTRITIZING_7988737376840854573)],
        &[(0b11010, &ENTRY_LITER_6442068802085842758)],
        &[(0b11010, &ENTRY_LITERS_6702315605664025195)],
    ],
    range: 2..=12,
};

static VARS_LIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIS_CHILDREN),
    value: None,
};

pub static VARS_LIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("someness"),
        dictgen::InsensitiveStr::Ascii("somenesses"),
        dictgen::InsensitiveStr::Ascii("somness"),
        dictgen::InsensitiveStr::Ascii("somnesses"),
        dictgen::InsensitiveStr::Ascii("terise"),
        dictgen::InsensitiveStr::Ascii("terised"),
        dictgen::InsensitiveStr::Ascii("terises"),
        dictgen::InsensitiveStr::Ascii("terising"),
        dictgen::InsensitiveStr::Ascii("terize"),
        dictgen::InsensitiveStr::Ascii("terized"),
        dictgen::InsensitiveStr::Ascii("terizes"),
        dictgen::InsensitiveStr::Ascii("terizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_LISSOMENESS_3042611249910147188)],
        &[(0b01001, &ENTRY_LISSOMENESSES_15531245348799674971)],
        &[(0b10011, &ENTRY_LISSOMENESS_3042611249910147188)],
        &[(0b10011, &ENTRY_LISSOMENESSES_15531245348799674971)],
        &[(0b10010, &ENTRY_LISTERIZE_9880759270323455733)],
        &[(0b10010, &ENTRY_LISTERIZED_14632038138125604365)],
        &[(0b10010, &ENTRY_LISTERIZES_14087757069664162339)],
        &[(0b10010, &ENTRY_LISTERIZING_3929969546134536615)],
        &[(0b01001, &ENTRY_LISTERIZE_9880759270323455733)],
        &[(0b01001, &ENTRY_LISTERIZED_14632038138125604365)],
        &[(0b01001, &ENTRY_LISTERIZES_14087757069664162339)],
        &[(0b01001, &ENTRY_LISTERIZING_3929969546134536615)],
    ],
    range: 6..=10,
};

static VARS_LIQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIQ_CHILDREN),
    value: None,
};

pub static VARS_LIQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uidisation"),
        dictgen::InsensitiveStr::Ascii("uidise"),
        dictgen::InsensitiveStr::Ascii("uidised"),
        dictgen::InsensitiveStr::Ascii("uidiser"),
        dictgen::InsensitiveStr::Ascii("uidisers"),
        dictgen::InsensitiveStr::Ascii("uidises"),
        dictgen::InsensitiveStr::Ascii("uidising"),
        dictgen::InsensitiveStr::Ascii("uidization"),
        dictgen::InsensitiveStr::Ascii("uidize"),
        dictgen::InsensitiveStr::Ascii("uidized"),
        dictgen::InsensitiveStr::Ascii("uidizer"),
        dictgen::InsensitiveStr::Ascii("uidizers"),
        dictgen::InsensitiveStr::Ascii("uidizes"),
        dictgen::InsensitiveStr::Ascii("uidizing"),
        dictgen::InsensitiveStr::Ascii("uifier"),
        dictgen::InsensitiveStr::Ascii("uifiers"),
        dictgen::InsensitiveStr::Ascii("uorice"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LIQUIDIZATION_6149909954612384940)],
        &[(0b11010, &ENTRY_LIQUIDIZE_14194923337466264130)],
        &[(0b11010, &ENTRY_LIQUIDIZED_3292692080763673196)],
        &[(0b10010, &ENTRY_LIQUIDIZER_11706828663079340333)],
        &[(0b10010, &ENTRY_LIQUIDIZERS_4929831666489438893)],
        &[(0b11010, &ENTRY_LIQUIDIZES_15521435243413925703)],
        &[(0b11010, &ENTRY_LIQUIDIZING_9649118097468787294)],
        &[(0b01001, &ENTRY_LIQUIDIZATION_6149909954612384940)],
        &[(0b01001, &ENTRY_LIQUIDIZE_14194923337466264130)],
        &[(0b01001, &ENTRY_LIQUIDIZED_3292692080763673196)],
        &[(0b01001, &ENTRY_LIQUIDIZER_11706828663079340333)],
        &[(0b01001, &ENTRY_LIQUIDIZERS_4929831666489438893)],
        &[(0b01001, &ENTRY_LIQUIDIZES_15521435243413925703)],
        &[(0b01001, &ENTRY_LIQUIDIZING_9649118097468787294)],
        &[(0b00001, &ENTRY_LIQUEFIER_8084176495582278110)],
        &[(0b00001, &ENTRY_LIQUEFIERS_3218357154702987275)],
        &[(0b10010, &ENTRY_LICORICE_12446341221870515605)],
    ],
    range: 6..=10,
};

static VARS_LIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIP_CHILDREN),
    value: None,
};

pub static VARS_LIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("oidaemia"),
        dictgen::InsensitiveStr::Ascii("oidemia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LIPEMIA_1266751727291630439)],
        &[(0b11010, &ENTRY_LIPEMIC_15466993613552317186)],
        &[(0b10001, &ENTRY_LIPEMIA_1266751727291630439)],
        &[(0b10001, &ENTRY_LIPEMIC_15466993613552317186)],
        &[(0b11010, &ENTRY_LIPOIDEMIA_14140069918960585906)],
        &[(0b10001, &ENTRY_LIPOIDEMIA_14140069918960585906)],
    ],
    range: 4..=8,
};

static VARS_LIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIO_CHILDREN),
    value: None,
};

pub static VARS_LIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisable"),
        dictgen::InsensitiveStr::Ascii("nisables"),
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nizable"),
        dictgen::InsensitiveStr::Ascii("nizables"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LIONIZABLE_5990738091543549203)],
        &[(0b10010, &ENTRY_LIONIZABLES_9433482512989969384)],
        &[(0b10010, &ENTRY_LIONIZATION_7835868583533630314)],
        &[(0b10010, &ENTRY_LIONIZATIONS_16641459291019877558)],
        &[(0b10010, &ENTRY_LIONIZE_18412797134322626457)],
        &[(0b10010, &ENTRY_LIONIZED_10011915111141731981)],
        &[(0b10010, &ENTRY_LIONIZER_8892928801781639667)],
        &[(0b10010, &ENTRY_LIONIZERS_10333415518245099706)],
        &[(0b10010, &ENTRY_LIONIZES_5684603994471877067)],
        &[(0b10010, &ENTRY_LIONIZING_9945396776786882247)],
        &[(0b01001, &ENTRY_LIONIZABLE_5990738091543549203)],
        &[(0b01001, &ENTRY_LIONIZABLES_9433482512989969384)],
        &[(0b01001, &ENTRY_LIONIZATION_7835868583533630314)],
        &[(0b01001, &ENTRY_LIONIZATIONS_16641459291019877558)],
        &[(0b01001, &ENTRY_LIONIZE_18412797134322626457)],
        &[(0b01001, &ENTRY_LIONIZED_10011915111141731981)],
        &[(0b01001, &ENTRY_LIONIZER_8892928801781639667)],
        &[(0b01001, &ENTRY_LIONIZERS_10333415518245099706)],
        &[(0b01001, &ENTRY_LIONIZES_5684603994471877067)],
        &[(0b01001, &ENTRY_LIONIZING_9945396776786882247)],
    ],
    range: 4..=9,
};

static VARS_LIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIN_CHILDREN),
    value: None,
};

pub static VARS_LIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("earisable"),
        dictgen::InsensitiveStr::Ascii("earisation"),
        dictgen::InsensitiveStr::Ascii("earisations"),
        dictgen::InsensitiveStr::Ascii("earise"),
        dictgen::InsensitiveStr::Ascii("earised"),
        dictgen::InsensitiveStr::Ascii("earises"),
        dictgen::InsensitiveStr::Ascii("earising"),
        dictgen::InsensitiveStr::Ascii("earision"),
        dictgen::InsensitiveStr::Ascii("earizable"),
        dictgen::InsensitiveStr::Ascii("earization"),
        dictgen::InsensitiveStr::Ascii("earizations"),
        dictgen::InsensitiveStr::Ascii("earize"),
        dictgen::InsensitiveStr::Ascii("earized"),
        dictgen::InsensitiveStr::Ascii("earizes"),
        dictgen::InsensitiveStr::Ascii("earizing"),
        dictgen::InsensitiveStr::Ascii("earizion"),
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("eniser"),
        dictgen::InsensitiveStr::Ascii("enisers"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enizer"),
        dictgen::InsensitiveStr::Ascii("enizers"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("ge"),
        dictgen::InsensitiveStr::Ascii("goe"),
        dictgen::InsensitiveStr::Ascii("gualise"),
        dictgen::InsensitiveStr::Ascii("gualises"),
        dictgen::InsensitiveStr::Ascii("gualize"),
        dictgen::InsensitiveStr::Ascii("gualizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LINEARIZABLE_11483091511283516869)],
        &[(0b10010, &ENTRY_LINEARIZATION_8131042847425051698)],
        &[(0b10010, &ENTRY_LINEARIZATIONS_5220379832227897986)],
        &[(0b10010, &ENTRY_LINEARIZE_6585591481529371953)],
        &[(0b10010, &ENTRY_LINEARIZED_6277814411607786019)],
        &[(0b10010, &ENTRY_LINEARIZES_9623143888404969081)],
        &[(0b10010, &ENTRY_LINEARIZING_7681767987068150150)],
        &[(0b10010, &ENTRY_LINEARIZION_2343569753841986772)],
        &[(0b01001, &ENTRY_LINEARIZABLE_11483091511283516869)],
        &[(0b01001, &ENTRY_LINEARIZATION_8131042847425051698)],
        &[(0b01001, &ENTRY_LINEARIZATIONS_5220379832227897986)],
        &[(0b01001, &ENTRY_LINEARIZE_6585591481529371953)],
        &[(0b01001, &ENTRY_LINEARIZED_6277814411607786019)],
        &[(0b01001, &ENTRY_LINEARIZES_9623143888404969081)],
        &[(0b01001, &ENTRY_LINEARIZING_7681767987068150150)],
        &[(0b01001, &ENTRY_LINEARIZION_2343569753841986772)],
        &[(0b10010, &ENTRY_LINENIZE_9065767214529230252)],
        &[(0b10010, &ENTRY_LINENIZER_15888082626595375875)],
        &[(0b10010, &ENTRY_LINENIZERS_4682205318738287968)],
        &[(0b10010, &ENTRY_LINENIZES_5878071266025614362)],
        &[(0b01001, &ENTRY_LINENIZE_9065767214529230252)],
        &[(0b01001, &ENTRY_LINENIZER_15888082626595375875)],
        &[(0b01001, &ENTRY_LINENIZERS_4682205318738287968)],
        &[(0b01001, &ENTRY_LINENIZES_5878071266025614362)],
        &[(0b00001, &ENTRY_LINGE_8045238778052659774)],
        &[(0b11010, &ENTRY_LINGE_8045238778052659774)],
        &[(0b10010, &ENTRY_LINGUALIZE_14645339856071004715)],
        &[(0b10010, &ENTRY_LINGUALIZES_4441987696052706342)],
        &[(0b01001, &ENTRY_LINGUALIZE_14645339856071004715)],
        &[(0b01001, &ENTRY_LINGUALIZES_4441987696052706342)],
    ],
    range: 2..=11,
};

static VARS_LIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIL_CHILDREN),
    value: None,
};

pub static VARS_LIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("liputianise"),
        dictgen::InsensitiveStr::Ascii("liputianises"),
        dictgen::InsensitiveStr::Ascii("liputianize"),
        dictgen::InsensitiveStr::Ascii("liputianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LILLIPUTIANIZE_13908672200948916679)],
        &[(0b10010, &ENTRY_LILLIPUTIANIZES_13473199246879296691)],
        &[(0b01001, &ENTRY_LILLIPUTIANIZE_13908672200948916679)],
        &[(0b01001, &ENTRY_LILLIPUTIANIZES_13473199246879296691)],
    ],
    range: 11..=12,
};

static VARS_LIK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIK_CHILDREN),
    value: None,
};

pub static VARS_LIK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abilities"),
        dictgen::InsensitiveStr::Ascii("ability"),
        dictgen::InsensitiveStr::Ascii("ableness"),
        dictgen::InsensitiveStr::Ascii("ablenesses"),
    ],
    values: &[
        &[(0b10001, &ENTRY_LIKABILITIES_11415080682327614883)],
        &[(0b10001, &ENTRY_LIKABILITY_14107426908958456352)],
        &[(0b10001, &ENTRY_LIKABLENESS_3894991900618167051)],
        &[(0b10001, &ENTRY_LIKABLENESSES_7732487243731741508)],
    ],
    range: 7..=10,
};

static VARS_LIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIG_CHILDREN),
    value: None,
};

pub static VARS_LIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nitise"),
        dictgen::InsensitiveStr::Ascii("nitises"),
        dictgen::InsensitiveStr::Ascii("nitize"),
        dictgen::InsensitiveStr::Ascii("nitizes"),
        dictgen::InsensitiveStr::Ascii("nosae"),
        dictgen::InsensitiveStr::Ascii("nose"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LIGNITIZE_15441220670264044611)],
        &[(0b10010, &ENTRY_LIGNITIZES_5039328976756916694)],
        &[(0b01001, &ENTRY_LIGNITIZE_15441220670264044611)],
        &[(0b01001, &ENTRY_LIGNITIZES_5039328976756916694)],
        &[(0b11010, &ENTRY_LIGNOSE_16716408399558241514)],
        &[(0b00001, &ENTRY_LIGNOSE_16716408399558241514)],
        &[(0b11010, &ENTRY_LIGULE_17419746601256779929)],
        &[(0b00001, &ENTRY_LIGULE_17419746601256779929)],
    ],
    range: 3..=7,
};

static VARS_LIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIC_CHILDREN),
    value: None,
};

pub static VARS_LIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ence"),
        dictgen::InsensitiveStr::Ascii("enced"),
        dictgen::InsensitiveStr::Ascii("enceless"),
        dictgen::InsensitiveStr::Ascii("encelesses"),
        dictgen::InsensitiveStr::Ascii("ences"),
        dictgen::InsensitiveStr::Ascii("encing"),
        dictgen::InsensitiveStr::Ascii("enseless"),
        dictgen::InsensitiveStr::Ascii("enselesses"),
        dictgen::InsensitiveStr::Ascii("henisation"),
        dictgen::InsensitiveStr::Ascii("henisations"),
        dictgen::InsensitiveStr::Ascii("henise"),
        dictgen::InsensitiveStr::Ascii("henised"),
        dictgen::InsensitiveStr::Ascii("henises"),
        dictgen::InsensitiveStr::Ascii("henising"),
        dictgen::InsensitiveStr::Ascii("henization"),
        dictgen::InsensitiveStr::Ascii("henizations"),
        dictgen::InsensitiveStr::Ascii("henize"),
        dictgen::InsensitiveStr::Ascii("henized"),
        dictgen::InsensitiveStr::Ascii("henizes"),
        dictgen::InsensitiveStr::Ascii("henizing"),
        dictgen::InsensitiveStr::Ascii("orice"),
    ],
    values: &[
        &[
            (0b00010, &ENTRY_LICENSE_15235558001562153549),
            (0b11010, &ENTRY_LICENSE_8420547614103398896),
        ],
        &[(0b00010, &ENTRY_LICENSED_17867087688345174857)],
        &[(0b11010, &ENTRY_LICENSELESS_7633778334307651396)],
        &[(0b11010, &ENTRY_LICENSELESSES_11029823360818305074)],
        &[
            (0b00010, &ENTRY_LICENSES_16200011703717675342),
            (0b11010, &ENTRY_LICENSES_6688982061827133578),
        ],
        &[(0b00010, &ENTRY_LICENSING_17752252713375594291)],
        &[(0b00001, &ENTRY_LICENSELESS_7633778334307651396)],
        &[(0b00001, &ENTRY_LICENSELESSES_11029823360818305074)],
        &[(0b10010, &ENTRY_LICHENIZATION_16602922256985188930)],
        &[(0b10010, &ENTRY_LICHENIZATIONS_10191010088103528457)],
        &[(0b10010, &ENTRY_LICHENIZE_4425261476550376752)],
        &[(0b10010, &ENTRY_LICHENIZED_10897910005345906260)],
        &[(0b10010, &ENTRY_LICHENIZES_11945949698824431881)],
        &[(0b10010, &ENTRY_LICHENIZING_11834102144389393809)],
        &[(0b01001, &ENTRY_LICHENIZATION_16602922256985188930)],
        &[(0b01001, &ENTRY_LICHENIZATIONS_10191010088103528457)],
        &[(0b01001, &ENTRY_LICHENIZE_4425261476550376752)],
        &[(0b01001, &ENTRY_LICHENIZED_10897910005345906260)],
        &[(0b01001, &ENTRY_LICHENIZES_11945949698824431881)],
        &[(0b01001, &ENTRY_LICHENIZING_11834102144389393809)],
        &[(0b11001, &ENTRY_LICORICE_12446341221870515605)],
    ],
    range: 4..=11,
};

static VARS_LIB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIB_CHILDREN),
    value: None,
};

pub static VARS_LIB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elant"),
        dictgen::InsensitiveStr::Ascii("elants"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("elee"),
        dictgen::InsensitiveStr::Ascii("elees"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("ellant"),
        dictgen::InsensitiveStr::Ascii("ellants"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("ellee"),
        dictgen::InsensitiveStr::Ascii("ellees"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellous"),
        dictgen::InsensitiveStr::Ascii("ellouser"),
        dictgen::InsensitiveStr::Ascii("ellousest"),
        dictgen::InsensitiveStr::Ascii("ellouslier"),
        dictgen::InsensitiveStr::Ascii("ellousliest"),
        dictgen::InsensitiveStr::Ascii("ellously"),
        dictgen::InsensitiveStr::Ascii("elous"),
        dictgen::InsensitiveStr::Ascii("elouser"),
        dictgen::InsensitiveStr::Ascii("elousest"),
        dictgen::InsensitiveStr::Ascii("elouslier"),
        dictgen::InsensitiveStr::Ascii("elousliest"),
        dictgen::InsensitiveStr::Ascii("elously"),
        dictgen::InsensitiveStr::Ascii("eralisation"),
        dictgen::InsensitiveStr::Ascii("eralisations"),
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralised"),
        dictgen::InsensitiveStr::Ascii("eraliser"),
        dictgen::InsensitiveStr::Ascii("eralisers"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralising"),
        dictgen::InsensitiveStr::Ascii("eralization"),
        dictgen::InsensitiveStr::Ascii("eralizations"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralized"),
        dictgen::InsensitiveStr::Ascii("eralizer"),
        dictgen::InsensitiveStr::Ascii("eralizers"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("eralizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LIBELANT_8960950444204079644)],
        &[(0b00001, &ENTRY_LIBELANTS_13936281424806279736)],
        &[(0b00001, &ENTRY_LIBELED_8051675010294297382)],
        &[(0b00001, &ENTRY_LIBELEE_8501691415848872731)],
        &[(0b00001, &ENTRY_LIBELEES_11461283383597147410)],
        &[(0b00001, &ENTRY_LIBELER_24227560685436157)],
        &[(0b00001, &ENTRY_LIBELERS_847096387317740162)],
        &[(0b00001, &ENTRY_LIBELING_928273583787085556)],
        &[(0b11010, &ENTRY_LIBELANT_8960950444204079644)],
        &[(0b11010, &ENTRY_LIBELANTS_13936281424806279736)],
        &[(0b11010, &ENTRY_LIBELED_8051675010294297382)],
        &[(0b11010, &ENTRY_LIBELEE_8501691415848872731)],
        &[(0b11010, &ENTRY_LIBELEES_11461283383597147410)],
        &[(0b11010, &ENTRY_LIBELER_24227560685436157)],
        &[(0b11010, &ENTRY_LIBELERS_847096387317740162)],
        &[(0b11010, &ENTRY_LIBELING_928273583787085556)],
        &[(0b11010, &ENTRY_LIBELOUS_17927467531006981983)],
        &[(0b11010, &ENTRY_LIBELOUSER_4863053355167467915)],
        &[(0b11010, &ENTRY_LIBELOUSEST_3829700018638160477)],
        &[(0b11010, &ENTRY_LIBELOUSLIER_6398255068664852216)],
        &[(0b11010, &ENTRY_LIBELOUSLIEST_6285056826991660688)],
        &[(0b11010, &ENTRY_LIBELOUSLY_7818112032230270971)],
        &[(0b01001, &ENTRY_LIBELOUS_17927467531006981983)],
        &[(0b01001, &ENTRY_LIBELOUSER_4863053355167467915)],
        &[(0b01001, &ENTRY_LIBELOUSEST_3829700018638160477)],
        &[(0b00001, &ENTRY_LIBELOUSLIER_6398255068664852216)],
        &[(0b00001, &ENTRY_LIBELOUSLIEST_6285056826991660688)],
        &[(0b00001, &ENTRY_LIBELOUSLY_7818112032230270971)],
        &[(0b10010, &ENTRY_LIBERALIZATION_6402945837364985631)],
        &[(0b10010, &ENTRY_LIBERALIZATIONS_10234274833724631870)],
        &[(0b10010, &ENTRY_LIBERALIZE_76622256595054540)],
        &[(0b10010, &ENTRY_LIBERALIZED_7103715465503664043)],
        &[(0b10010, &ENTRY_LIBERALIZER_6703544626598968567)],
        &[(0b10010, &ENTRY_LIBERALIZERS_17607581360244717241)],
        &[(0b10010, &ENTRY_LIBERALIZES_2300482275642251125)],
        &[(0b10010, &ENTRY_LIBERALIZING_1078842496046790451)],
        &[(0b01001, &ENTRY_LIBERALIZATION_6402945837364985631)],
        &[(0b01001, &ENTRY_LIBERALIZATIONS_10234274833724631870)],
        &[(0b01001, &ENTRY_LIBERALIZE_76622256595054540)],
        &[(0b01001, &ENTRY_LIBERALIZED_7103715465503664043)],
        &[(0b01001, &ENTRY_LIBERALIZER_6703544626598968567)],
        &[(0b01001, &ENTRY_LIBERALIZERS_17607581360244717241)],
        &[(0b01001, &ENTRY_LIBERALIZES_2300482275642251125)],
        &[(0b01001, &ENTRY_LIBERALIZING_1078842496046790451)],
    ],
    range: 4..=12,
};

static VARS_LE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_LE_CHILDREN),
    value: None,
};

static VARS_LE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_LEA_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LEG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LEM_NODE),
    None,
    None,
    Some(&VARS_LEP_NODE),
    None,
    Some(&VARS_LER_NODE),
    Some(&VARS_LES_NODE),
    Some(&VARS_LET_NODE),
    Some(&VARS_LEU_NODE),
    Some(&VARS_LEV_NODE),
    None,
    Some(&VARS_LEX_NODE),
    None,
    None,
];

static VARS_LEX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEX_CHILDREN),
    value: None,
};

pub static VARS_LEX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icalisation"),
        dictgen::InsensitiveStr::Ascii("icalisations"),
        dictgen::InsensitiveStr::Ascii("icalization"),
        dictgen::InsensitiveStr::Ascii("icalizations"),
        dictgen::InsensitiveStr::Ascii("iconise"),
        dictgen::InsensitiveStr::Ascii("iconises"),
        dictgen::InsensitiveStr::Ascii("iconize"),
        dictgen::InsensitiveStr::Ascii("iconizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LEXICALIZATION_12107898383962927204)],
        &[(0b10010, &ENTRY_LEXICALIZATIONS_6221466785295251109)],
        &[(0b01001, &ENTRY_LEXICALIZATION_12107898383962927204)],
        &[(0b01001, &ENTRY_LEXICALIZATIONS_6221466785295251109)],
        &[(0b10010, &ENTRY_LEXICONIZE_5459057741155956257)],
        &[(0b10010, &ENTRY_LEXICONIZES_6339779794516589643)],
        &[(0b01001, &ENTRY_LEXICONIZE_5459057741155956257)],
        &[(0b01001, &ENTRY_LEXICONIZES_6339779794516589643)],
    ],
    range: 7..=12,
};

static VARS_LEV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEV_CHILDREN),
    value: None,
};

pub static VARS_LEV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("elest"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("ellest"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("igate"),
        dictgen::InsensitiveStr::Ascii("igated"),
        dictgen::InsensitiveStr::Ascii("igates"),
        dictgen::InsensitiveStr::Ascii("igating"),
        dictgen::InsensitiveStr::Ascii("o"),
        dictgen::InsensitiveStr::Ascii("oduction"),
        dictgen::InsensitiveStr::Ascii("ogyrate"),
        dictgen::InsensitiveStr::Ascii("ogyre"),
        dictgen::InsensitiveStr::Ascii("ogyrous"),
        dictgen::InsensitiveStr::Ascii("olactic"),
        dictgen::InsensitiveStr::Ascii("orotation"),
        dictgen::InsensitiveStr::Ascii("orotations"),
        dictgen::InsensitiveStr::Ascii("orotatory"),
        dictgen::InsensitiveStr::Ascii("otartaric"),
        dictgen::InsensitiveStr::Ascii("oversion"),
        dictgen::InsensitiveStr::Ascii("ulin"),
        dictgen::InsensitiveStr::Ascii("ulose"),
        dictgen::InsensitiveStr::Ascii("uloses"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LEVELED_17710552579875587899)],
        &[(0b00001, &ENTRY_LEVELER_16958859746569115537)],
        &[(0b00001, &ENTRY_LEVELERS_7665258852948284339)],
        &[(0b00001, &ENTRY_LEVELEST_13356524148042532014)],
        &[(0b00001, &ENTRY_LEVELING_498798874102170149)],
        &[(0b11010, &ENTRY_LEVELED_17710552579875587899)],
        &[(0b11010, &ENTRY_LEVELER_16958859746569115537)],
        &[(0b11010, &ENTRY_LEVELERS_7665258852948284339)],
        &[(0b11010, &ENTRY_LEVELEST_13356524148042532014)],
        &[(0b11010, &ENTRY_LEVELING_498798874102170149)],
        &[(0b00001, &ENTRY_LEVIGATE_2400835299858697154)],
        &[(0b00001, &ENTRY_LEVIGATED_10802119287360824756)],
        &[(0b00001, &ENTRY_LEVIGATES_6464705000016558190)],
        &[(0b00001, &ENTRY_LEVIGATING_6360151110328481309)],
        &[(0b00001, &ENTRY_LEVO_5922397168831753216)],
        &[(0b00001, &ENTRY_LEVODUCTION_18380734240213929282)],
        &[(0b00001, &ENTRY_LEVOGYRATE_226194661300355280)],
        &[(0b00001, &ENTRY_LEVOGYRE_4490889198290332005)],
        &[(0b00001, &ENTRY_LEVOGYROUS_10758046066790011317)],
        &[(0b00001, &ENTRY_LEVOLACTIC_12858385479851123350)],
        &[(0b00001, &ENTRY_LEVOROTATION_7598609812036201504)],
        &[(0b00001, &ENTRY_LEVOROTATIONS_5775096129907291037)],
        &[(0b00001, &ENTRY_LEVOROTATORY_14202301941084413862)],
        &[(0b00001, &ENTRY_LEVOTARTARIC_16315854471180603290)],
        &[(0b00001, &ENTRY_LEVOVERSION_11776416338568601974)],
        &[(0b00001, &ENTRY_LEVULIN_14669868077101221588)],
        &[(0b00001, &ENTRY_LEVULOSE_12367098880168512961)],
        &[(0b00001, &ENTRY_LEVULOSES_15600695600027321495)],
    ],
    range: 1..=10,
};

static VARS_LEU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEU_CHILDREN),
    value: None,
};

pub static VARS_LEU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("caemia"),
        dictgen::InsensitiveStr::Ascii("caemias"),
        dictgen::InsensitiveStr::Ascii("caemic"),
        dictgen::InsensitiveStr::Ascii("cemia"),
        dictgen::InsensitiveStr::Ascii("cemias"),
        dictgen::InsensitiveStr::Ascii("cemic"),
        dictgen::InsensitiveStr::Ascii("chaemia"),
        dictgen::InsensitiveStr::Ascii("chemia"),
        dictgen::InsensitiveStr::Ascii("cocythaemia"),
        dictgen::InsensitiveStr::Ascii("cocythaemic"),
        dictgen::InsensitiveStr::Ascii("cocythemia"),
        dictgen::InsensitiveStr::Ascii("cocythemic"),
        dictgen::InsensitiveStr::Ascii("corrhea"),
        dictgen::InsensitiveStr::Ascii("corrheal"),
        dictgen::InsensitiveStr::Ascii("corrheas"),
        dictgen::InsensitiveStr::Ascii("corrhoea"),
        dictgen::InsensitiveStr::Ascii("corrhoeal"),
        dictgen::InsensitiveStr::Ascii("corrhoeas"),
        dictgen::InsensitiveStr::Ascii("cothoae"),
        dictgen::InsensitiveStr::Ascii("cothoe"),
        dictgen::InsensitiveStr::Ascii("kaemia"),
        dictgen::InsensitiveStr::Ascii("kaemias"),
        dictgen::InsensitiveStr::Ascii("kaemogeneses"),
        dictgen::InsensitiveStr::Ascii("kaemogenesis"),
        dictgen::InsensitiveStr::Ascii("kemia"),
        dictgen::InsensitiveStr::Ascii("kemias"),
        dictgen::InsensitiveStr::Ascii("kemogeneses"),
        dictgen::InsensitiveStr::Ascii("kemogenesis"),
        dictgen::InsensitiveStr::Ascii("korrhea"),
        dictgen::InsensitiveStr::Ascii("korrheal"),
        dictgen::InsensitiveStr::Ascii("korrhoea"),
        dictgen::InsensitiveStr::Ascii("korrhoeal"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LEUCEMIA_14689435826769411039)],
        &[(0b11010, &ENTRY_LEUCEMIAS_16840418369070866410)],
        &[(0b11010, &ENTRY_LEUCEMIC_2632666506755750809)],
        &[(0b00001, &ENTRY_LEUCEMIA_14689435826769411039)],
        &[(0b00001, &ENTRY_LEUCEMIAS_16840418369070866410)],
        &[(0b00001, &ENTRY_LEUCEMIC_2632666506755750809)],
        &[(0b11010, &ENTRY_LEUCHEMIA_13269968985976597970)],
        &[(0b00001, &ENTRY_LEUCHEMIA_13269968985976597970)],
        &[(0b11010, &ENTRY_LEUCOCYTHEMIA_13875285091096996286)],
        &[(0b11010, &ENTRY_LEUCOCYTHEMIC_15817224799610378261)],
        &[(0b00001, &ENTRY_LEUCOCYTHEMIA_13875285091096996286)],
        &[(0b00001, &ENTRY_LEUCOCYTHEMIC_15817224799610378261)],
        &[(0b00001, &ENTRY_LEUCORRHEA_8655224531402171021)],
        &[(0b00001, &ENTRY_LEUCORRHEAL_13098489145195233918)],
        &[(0b00001, &ENTRY_LEUCORRHEAS_1620289807160644540)],
        &[(0b11010, &ENTRY_LEUCORRHEA_8655224531402171021)],
        &[(0b11010, &ENTRY_LEUCORRHEAL_13098489145195233918)],
        &[(0b11010, &ENTRY_LEUCORRHEAS_1620289807160644540)],
        &[(0b11010, &ENTRY_LEUCOTHOE_17096848524130048559)],
        &[(0b00001, &ENTRY_LEUCOTHOE_17096848524130048559)],
        &[(0b10010, &ENTRY_LEUKEMIA_18308238259623845158)],
        &[(0b10010, &ENTRY_LEUKEMIAS_9099411686641435250)],
        &[(0b11010, &ENTRY_LEUKEMOGENESES_1067450160751314209)],
        &[(0b11010, &ENTRY_LEUKEMOGENESIS_14406918803510337444)],
        &[(0b11001, &ENTRY_LEUKEMIA_18308238259623845158)],
        &[(0b11001, &ENTRY_LEUKEMIAS_9099411686641435250)],
        &[(0b10001, &ENTRY_LEUKEMOGENESES_1067450160751314209)],
        &[(0b10001, &ENTRY_LEUKEMOGENESIS_14406918803510337444)],
        &[(0b10001, &ENTRY_LEUKORRHEA_2110491188090132168)],
        &[(0b10001, &ENTRY_LEUKORRHEAL_15536707376609629975)],
        &[(0b11010, &ENTRY_LEUKORRHEA_2110491188090132168)],
        &[(0b11010, &ENTRY_LEUKORRHEAL_15536707376609629975)],
    ],
    range: 5..=12,
};

static VARS_LET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LET_CHILDREN),
    value: None,
};

pub static VARS_LET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("halise"),
        dictgen::InsensitiveStr::Ascii("halises"),
        dictgen::InsensitiveStr::Ascii("halize"),
        dictgen::InsensitiveStr::Ascii("halizes"),
        dictgen::InsensitiveStr::Ascii("hargise"),
        dictgen::InsensitiveStr::Ascii("hargised"),
        dictgen::InsensitiveStr::Ascii("hargises"),
        dictgen::InsensitiveStr::Ascii("hargising"),
        dictgen::InsensitiveStr::Ascii("hargize"),
        dictgen::InsensitiveStr::Ascii("hargized"),
        dictgen::InsensitiveStr::Ascii("hargizes"),
        dictgen::InsensitiveStr::Ascii("hargizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LETHALIZE_18211752301676352640)],
        &[(0b10010, &ENTRY_LETHALIZES_7714094041494904740)],
        &[(0b01001, &ENTRY_LETHALIZE_18211752301676352640)],
        &[(0b01001, &ENTRY_LETHALIZES_7714094041494904740)],
        &[(0b10010, &ENTRY_LETHARGIZE_9265082133850549111)],
        &[(0b10010, &ENTRY_LETHARGIZED_9033916729242357207)],
        &[(0b10010, &ENTRY_LETHARGIZES_16077924589554016377)],
        &[(0b10010, &ENTRY_LETHARGIZING_1161802722753837372)],
        &[(0b01001, &ENTRY_LETHARGIZE_9265082133850549111)],
        &[(0b01001, &ENTRY_LETHARGIZED_9033916729242357207)],
        &[(0b01001, &ENTRY_LETHARGIZES_16077924589554016377)],
        &[(0b01001, &ENTRY_LETHARGIZING_1161802722753837372)],
    ],
    range: 6..=9,
};

static VARS_LES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LES_CHILDREN),
    value: None,
};

pub static VARS_LES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ses")],
    values: &[&[(0b00001, &ENTRY_LESSES_13624938550715380684)]],
    range: 3..=3,
};

static VARS_LER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LER_CHILDREN),
    value: None,
};

pub static VARS_LER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("naean"),
        dictgen::InsensitiveStr::Ascii("nean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LERNEAN_17960475636997592381)],
        &[(0b00001, &ENTRY_LERNEAN_17960475636997592381)],
    ],
    range: 4..=5,
};

static VARS_LEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEP_CHILDREN),
    value: None,
};

pub static VARS_LEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oridae"),
        dictgen::InsensitiveStr::Ascii("oride"),
        dictgen::InsensitiveStr::Ascii("tospirae"),
        dictgen::InsensitiveStr::Ascii("tospire"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LEPORIDE_9827185229783949880)],
        &[(0b00001, &ENTRY_LEPORIDE_9827185229783949880)],
        &[(0b11010, &ENTRY_LEPTOSPIRE_911064414787372389)],
        &[(0b00001, &ENTRY_LEPTOSPIRE_911064414787372389)],
    ],
    range: 5..=8,
};

static VARS_LEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEM_CHILDREN),
    value: None,
};

pub static VARS_LEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LEMMATIZE_3841787910701358704)],
        &[(0b10010, &ENTRY_LEMMATIZED_14288427773628086779)],
        &[(0b10010, &ENTRY_LEMMATIZES_11283410282156755354)],
        &[(0b10010, &ENTRY_LEMMATIZING_11232648392129845696)],
        &[(0b01001, &ENTRY_LEMMATIZE_3841787910701358704)],
        &[(0b01001, &ENTRY_LEMMATIZED_14288427773628086779)],
        &[(0b01001, &ENTRY_LEMMATIZES_11283410282156755354)],
        &[(0b01001, &ENTRY_LEMMATIZING_11232648392129845696)],
    ],
    range: 6..=8,
};

static VARS_LEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEG_CHILDREN),
    value: None,
};

pub static VARS_LEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("gin"),
        dictgen::InsensitiveStr::Ascii("gins"),
        dictgen::InsensitiveStr::Ascii("itimatise"),
        dictgen::InsensitiveStr::Ascii("itimatised"),
        dictgen::InsensitiveStr::Ascii("itimatises"),
        dictgen::InsensitiveStr::Ascii("itimatising"),
        dictgen::InsensitiveStr::Ascii("itimatize"),
        dictgen::InsensitiveStr::Ascii("itimatized"),
        dictgen::InsensitiveStr::Ascii("itimatizes"),
        dictgen::InsensitiveStr::Ascii("itimatizing"),
        dictgen::InsensitiveStr::Ascii("itimisation"),
        dictgen::InsensitiveStr::Ascii("itimisations"),
        dictgen::InsensitiveStr::Ascii("itimise"),
        dictgen::InsensitiveStr::Ascii("itimised"),
        dictgen::InsensitiveStr::Ascii("itimiser"),
        dictgen::InsensitiveStr::Ascii("itimises"),
        dictgen::InsensitiveStr::Ascii("itimising"),
        dictgen::InsensitiveStr::Ascii("itimization"),
        dictgen::InsensitiveStr::Ascii("itimizations"),
        dictgen::InsensitiveStr::Ascii("itimize"),
        dictgen::InsensitiveStr::Ascii("itimized"),
        dictgen::InsensitiveStr::Ascii("itimizer"),
        dictgen::InsensitiveStr::Ascii("itimizes"),
        dictgen::InsensitiveStr::Ascii("itimizing"),
        dictgen::InsensitiveStr::Ascii("uminosae"),
        dictgen::InsensitiveStr::Ascii("uminose"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LEGALIZATION_14069720183344579391)],
        &[(0b10010, &ENTRY_LEGALIZATIONS_7369809481070839600)],
        &[(0b10010, &ENTRY_LEGALIZE_6090443744031107422)],
        &[(0b10010, &ENTRY_LEGALIZED_4279297604105669391)],
        &[(0b10010, &ENTRY_LEGALIZES_15551841073682264464)],
        &[(0b10010, &ENTRY_LEGALIZING_14672145239610477044)],
        &[(0b01001, &ENTRY_LEGALIZATION_14069720183344579391)],
        &[(0b01001, &ENTRY_LEGALIZATIONS_7369809481070839600)],
        &[(0b01001, &ENTRY_LEGALIZE_6090443744031107422)],
        &[(0b01001, &ENTRY_LEGALIZED_4279297604105669391)],
        &[(0b01001, &ENTRY_LEGALIZES_15551841073682264464)],
        &[(0b01001, &ENTRY_LEGALIZING_14672145239610477044)],
        &[(0b00001, &ENTRY_LEGGING_8791551298779124491)],
        &[(0b00001, &ENTRY_LEGGINGS_18074923807625757810)],
        &[(0b10010, &ENTRY_LEGITIMATIZE_8617242106801927773)],
        &[(0b10010, &ENTRY_LEGITIMATIZED_15566517598534152764)],
        &[(0b10010, &ENTRY_LEGITIMATIZES_6190809963882788044)],
        &[(0b10010, &ENTRY_LEGITIMATIZING_9528793826013606812)],
        &[(0b01001, &ENTRY_LEGITIMATIZE_8617242106801927773)],
        &[(0b01001, &ENTRY_LEGITIMATIZED_15566517598534152764)],
        &[(0b01001, &ENTRY_LEGITIMATIZES_6190809963882788044)],
        &[(0b01001, &ENTRY_LEGITIMATIZING_9528793826013606812)],
        &[(0b10010, &ENTRY_LEGITIMIZATION_522172373867492649)],
        &[(0b10010, &ENTRY_LEGITIMIZATIONS_11689914768775001401)],
        &[(0b10010, &ENTRY_LEGITIMIZE_162184278793564767)],
        &[(0b10010, &ENTRY_LEGITIMIZED_7050352751899263729)],
        &[(0b10010, &ENTRY_LEGITIMIZER_16722148956241410759)],
        &[(0b10010, &ENTRY_LEGITIMIZES_15916033610846937765)],
        &[(0b10010, &ENTRY_LEGITIMIZING_15403346656705937661)],
        &[(0b01001, &ENTRY_LEGITIMIZATION_522172373867492649)],
        &[(0b01001, &ENTRY_LEGITIMIZATIONS_11689914768775001401)],
        &[(0b01001, &ENTRY_LEGITIMIZE_162184278793564767)],
        &[(0b01001, &ENTRY_LEGITIMIZED_7050352751899263729)],
        &[(0b01001, &ENTRY_LEGITIMIZER_16722148956241410759)],
        &[(0b01001, &ENTRY_LEGITIMIZES_15916033610846937765)],
        &[(0b01001, &ENTRY_LEGITIMIZING_15403346656705937661)],
        &[(0b11010, &ENTRY_LEGUMINOSE_8808168821933801590)],
        &[(0b00001, &ENTRY_LEGUMINOSE_8808168821933801590)],
    ],
    range: 3..=12,
};

static VARS_LEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEA_CHILDREN),
    value: None,
};

pub static VARS_LEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rnt"),
        dictgen::InsensitiveStr::Ascii("therise"),
        dictgen::InsensitiveStr::Ascii("therises"),
        dictgen::InsensitiveStr::Ascii("therize"),
        dictgen::InsensitiveStr::Ascii("therizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LEARNED_16553251450375188122)],
        &[(0b10010, &ENTRY_LEATHERIZE_2217890266002074192)],
        &[(0b10010, &ENTRY_LEATHERIZES_9057823714991730746)],
        &[(0b01001, &ENTRY_LEATHERIZE_2217890266002074192)],
        &[(0b01001, &ENTRY_LEATHERIZES_9057823714991730746)],
    ],
    range: 3..=8,
};

static VARS_LA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_LA_CHILDREN),
    value: None,
};

static VARS_LA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_LAB_NODE),
    Some(&VARS_LAC_NODE),
    None,
    Some(&VARS_LAE_NODE),
    None,
    None,
    None,
    Some(&VARS_LAI_NODE),
    None,
    None,
    None,
    Some(&VARS_LAM_NODE),
    Some(&VARS_LAN_NODE),
    Some(&VARS_LAO_NODE),
    Some(&VARS_LAP_NODE),
    None,
    None,
    Some(&VARS_LAS_NODE),
    Some(&VARS_LAT_NODE),
    Some(&VARS_LAU_NODE),
    Some(&VARS_LAV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_LAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAV_CHILDREN),
    value: None,
};

pub static VARS_LAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oltaed"),
        dictgen::InsensitiveStr::Ascii("olted"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LAVOLTED_1448117024048447761)],
        &[(0b00001, &ENTRY_LAVOLTED_1448117024048447761)],
    ],
    range: 5..=6,
};

static VARS_LAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAU_CHILDREN),
    value: None,
};

pub static VARS_LAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rae"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("reled"),
        dictgen::InsensitiveStr::Ascii("reling"),
        dictgen::InsensitiveStr::Ascii("relled"),
        dictgen::InsensitiveStr::Ascii("relling"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LAURE_622623340727413197)],
        &[(0b00001, &ENTRY_LAURE_622623340727413197)],
        &[(0b00001, &ENTRY_LAURELED_15840646900598636325)],
        &[(0b00001, &ENTRY_LAURELING_8509761833120787483)],
        &[(0b11010, &ENTRY_LAURELED_15840646900598636325)],
        &[(0b11010, &ENTRY_LAURELING_8509761833120787483)],
    ],
    range: 2..=7,
};

static VARS_LAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAT_CHILDREN),
    value: None,
};

pub static VARS_LAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entise"),
        dictgen::InsensitiveStr::Ascii("entises"),
        dictgen::InsensitiveStr::Ascii("entize"),
        dictgen::InsensitiveStr::Ascii("entizes"),
        dictgen::InsensitiveStr::Ascii("eralisation"),
        dictgen::InsensitiveStr::Ascii("eralisations"),
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralization"),
        dictgen::InsensitiveStr::Ascii("eralizations"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("inisation"),
        dictgen::InsensitiveStr::Ascii("inisations"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inised"),
        dictgen::InsensitiveStr::Ascii("iniser"),
        dictgen::InsensitiveStr::Ascii("inisers"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inising"),
        dictgen::InsensitiveStr::Ascii("inization"),
        dictgen::InsensitiveStr::Ascii("inizations"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inized"),
        dictgen::InsensitiveStr::Ascii("inizer"),
        dictgen::InsensitiveStr::Ascii("inizers"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LATENTIZE_2695337996205954263)],
        &[(0b10010, &ENTRY_LATENTIZES_15097043595238247759)],
        &[(0b01001, &ENTRY_LATENTIZE_2695337996205954263)],
        &[(0b01001, &ENTRY_LATENTIZES_15097043595238247759)],
        &[(0b10010, &ENTRY_LATERALIZATION_17558345836104634444)],
        &[(0b10010, &ENTRY_LATERALIZATIONS_17363642925358429016)],
        &[(0b10010, &ENTRY_LATERALIZE_18084168395528697129)],
        &[(0b10010, &ENTRY_LATERALIZES_4067647162402607589)],
        &[(0b01001, &ENTRY_LATERALIZATION_17558345836104634444)],
        &[(0b01001, &ENTRY_LATERALIZATIONS_17363642925358429016)],
        &[(0b01001, &ENTRY_LATERALIZE_18084168395528697129)],
        &[(0b01001, &ENTRY_LATERALIZES_4067647162402607589)],
        &[(0b10010, &ENTRY_LATERIZATION_6646665995805461681)],
        &[(0b10010, &ENTRY_LATERIZATIONS_2970297049045009789)],
        &[(0b01001, &ENTRY_LATERIZATION_6646665995805461681)],
        &[(0b01001, &ENTRY_LATERIZATIONS_2970297049045009789)],
        &[(0b10010, &ENTRY_LATINIZATION_11972451538371752217)],
        &[(0b10010, &ENTRY_LATINIZATIONS_6858424540483628997)],
        &[(0b10010, &ENTRY_LATINIZE_10995098395307448983)],
        &[(0b10010, &ENTRY_LATINIZED_10581307786903570003)],
        &[(0b10010, &ENTRY_LATINIZER_2919331145534061159)],
        &[(0b10010, &ENTRY_LATINIZERS_5094806879295804549)],
        &[(0b10010, &ENTRY_LATINIZES_9202029225723708964)],
        &[(0b10010, &ENTRY_LATINIZING_12540759379841466342)],
        &[(0b01001, &ENTRY_LATINIZATION_11972451538371752217)],
        &[(0b01001, &ENTRY_LATINIZATIONS_6858424540483628997)],
        &[(0b01001, &ENTRY_LATINIZE_10995098395307448983)],
        &[(0b01001, &ENTRY_LATINIZED_10581307786903570003)],
        &[(0b01001, &ENTRY_LATINIZER_2919331145534061159)],
        &[(0b01001, &ENTRY_LATINIZERS_5094806879295804549)],
        &[(0b01001, &ENTRY_LATINIZES_9202029225723708964)],
        &[(0b01001, &ENTRY_LATINIZING_12540759379841466342)],
    ],
    range: 5..=12,
};

static VARS_LAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAS_CHILDREN),
    value: None,
};

pub static VARS_LAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agne"),
        dictgen::InsensitiveStr::Ascii("agnes"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tre"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LASAGNA_15470141710854379425)],
        &[(0b11010, &ENTRY_LASAGNAS_12563561930970116687)],
        &[(0b00001, &ENTRY_LASTER_3064111799341855772)],
        &[(0b11010, &ENTRY_LASTER_3064111799341855772)],
    ],
    range: 3..=5,
};

static VARS_LAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAP_CHILDREN),
    value: None,
};

pub static VARS_LAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("elled"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LAPELED_3487021672158426687)],
        &[(0b11010, &ENTRY_LAPELED_3487021672158426687)],
    ],
    range: 4..=5,
};

static VARS_LAO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAO_CHILDREN),
    value: None,
};

pub static VARS_LAO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thoae"),
        dictgen::InsensitiveStr::Ascii("thoe"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LAOTHOE_18001361801867503785)],
        &[(0b00001, &ENTRY_LAOTHOE_18001361801867503785)],
    ],
    range: 4..=5,
};

static VARS_LAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAN_CHILDREN),
    value: None,
};

pub static VARS_LAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("der"),
        dictgen::InsensitiveStr::Ascii("dre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LANDER_5172285837554925117)],
        &[(0b11010, &ENTRY_LANDER_5172285837554925117)],
    ],
    range: 3..=3,
};

static VARS_LAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAM_CHILDREN),
    value: None,
};

pub static VARS_LAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("inarise"),
        dictgen::InsensitiveStr::Ascii("inarised"),
        dictgen::InsensitiveStr::Ascii("inarises"),
        dictgen::InsensitiveStr::Ascii("inarising"),
        dictgen::InsensitiveStr::Ascii("inarize"),
        dictgen::InsensitiveStr::Ascii("inarized"),
        dictgen::InsensitiveStr::Ascii("inarizes"),
        dictgen::InsensitiveStr::Ascii("inarizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LAMINARIZE_10415015838430956455)],
        &[(0b10010, &ENTRY_LAMINARIZED_9391732749259987656)],
        &[(0b10010, &ENTRY_LAMINARIZES_14331963672679618224)],
        &[(0b10010, &ENTRY_LAMINARIZING_305451454544009037)],
        &[(0b01001, &ENTRY_LAMINARIZE_10415015838430956455)],
        &[(0b01001, &ENTRY_LAMINARIZED_9391732749259987656)],
        &[(0b01001, &ENTRY_LAMINARIZES_14331963672679618224)],
        &[(0b01001, &ENTRY_LAMINARIZING_305451454544009037)],
    ],
    range: 7..=9,
};

static VARS_LAI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAI_CHILDREN),
    value: None,
};

pub static VARS_LAI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cisation"),
        dictgen::InsensitiveStr::Ascii("cisations"),
        dictgen::InsensitiveStr::Ascii("cise"),
        dictgen::InsensitiveStr::Ascii("cised"),
        dictgen::InsensitiveStr::Ascii("cises"),
        dictgen::InsensitiveStr::Ascii("cising"),
        dictgen::InsensitiveStr::Ascii("cization"),
        dictgen::InsensitiveStr::Ascii("cizations"),
        dictgen::InsensitiveStr::Ascii("cize"),
        dictgen::InsensitiveStr::Ascii("cized"),
        dictgen::InsensitiveStr::Ascii("cizes"),
        dictgen::InsensitiveStr::Ascii("cizing"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LAICIZATION_2887235584180290305)],
        &[(0b10010, &ENTRY_LAICIZATIONS_9749455722701689807)],
        &[(0b10010, &ENTRY_LAICIZE_3572230327046139216)],
        &[(0b10010, &ENTRY_LAICIZED_80445541934935273)],
        &[(0b10010, &ENTRY_LAICIZES_869459089127458605)],
        &[(0b10010, &ENTRY_LAICIZING_5309366367065705343)],
        &[(0b01001, &ENTRY_LAICIZATION_2887235584180290305)],
        &[(0b01001, &ENTRY_LAICIZATIONS_9749455722701689807)],
        &[(0b01001, &ENTRY_LAICIZE_3572230327046139216)],
        &[(0b01001, &ENTRY_LAICIZED_80445541934935273)],
        &[(0b01001, &ENTRY_LAICIZES_869459089127458605)],
        &[(0b01001, &ENTRY_LAICIZING_5309366367065705343)],
        &[(0b10010, &ENTRY_LAIRIZE_11275089526752116396)],
        &[(0b10010, &ENTRY_LAIRIZED_8262896078331257561)],
        &[(0b10010, &ENTRY_LAIRIZES_6832372099048999658)],
        &[(0b10010, &ENTRY_LAIRIZING_14359538361305990417)],
        &[(0b01001, &ENTRY_LAIRIZE_11275089526752116396)],
        &[(0b01001, &ENTRY_LAIRIZED_8262896078331257561)],
        &[(0b01001, &ENTRY_LAIRIZES_6832372099048999658)],
        &[(0b01001, &ENTRY_LAIRIZING_14359538361305990417)],
    ],
    range: 4..=9,
};

static VARS_LAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAE_CHILDREN),
    value: None,
};

pub static VARS_LAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("vigate"),
        dictgen::InsensitiveStr::Ascii("vigated"),
        dictgen::InsensitiveStr::Ascii("vigates"),
        dictgen::InsensitiveStr::Ascii("vigating"),
        dictgen::InsensitiveStr::Ascii("vo"),
        dictgen::InsensitiveStr::Ascii("voduction"),
        dictgen::InsensitiveStr::Ascii("vogyrate"),
        dictgen::InsensitiveStr::Ascii("vogyre"),
        dictgen::InsensitiveStr::Ascii("vogyrous"),
        dictgen::InsensitiveStr::Ascii("volactic"),
        dictgen::InsensitiveStr::Ascii("vorotation"),
        dictgen::InsensitiveStr::Ascii("vorotations"),
        dictgen::InsensitiveStr::Ascii("vorotatory"),
        dictgen::InsensitiveStr::Ascii("votartaric"),
        dictgen::InsensitiveStr::Ascii("voversion"),
        dictgen::InsensitiveStr::Ascii("vulin"),
        dictgen::InsensitiveStr::Ascii("vulose"),
        dictgen::InsensitiveStr::Ascii("vuloses"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LEVIGATE_2400835299858697154)],
        &[(0b11010, &ENTRY_LEVIGATED_10802119287360824756)],
        &[(0b11010, &ENTRY_LEVIGATES_6464705000016558190)],
        &[(0b11010, &ENTRY_LEVIGATING_6360151110328481309)],
        &[(0b11010, &ENTRY_LEVO_5922397168831753216)],
        &[(0b11010, &ENTRY_LEVODUCTION_18380734240213929282)],
        &[(0b11010, &ENTRY_LEVOGYRATE_226194661300355280)],
        &[(0b11010, &ENTRY_LEVOGYRE_4490889198290332005)],
        &[(0b11010, &ENTRY_LEVOGYROUS_10758046066790011317)],
        &[(0b11010, &ENTRY_LEVOLACTIC_12858385479851123350)],
        &[(0b11010, &ENTRY_LEVOROTATION_7598609812036201504)],
        &[(0b11010, &ENTRY_LEVOROTATIONS_5775096129907291037)],
        &[(0b11010, &ENTRY_LEVOROTATORY_14202301941084413862)],
        &[(0b11010, &ENTRY_LEVOTARTARIC_16315854471180603290)],
        &[(0b11010, &ENTRY_LEVOVERSION_11776416338568601974)],
        &[(0b11010, &ENTRY_LEVULIN_14669868077101221588)],
        &[(0b11010, &ENTRY_LEVULOSE_12367098880168512961)],
        &[(0b11010, &ENTRY_LEVULOSES_15600695600027321495)],
    ],
    range: 2..=11,
};

static VARS_LAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAC_CHILDREN),
    value: None,
};

pub static VARS_LAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("kluster"),
        dictgen::InsensitiveStr::Ascii("klusterrer"),
        dictgen::InsensitiveStr::Ascii("klusterrest"),
        dictgen::InsensitiveStr::Ascii("klusters"),
        dictgen::InsensitiveStr::Ascii("klustre"),
        dictgen::InsensitiveStr::Ascii("klustrer"),
        dictgen::InsensitiveStr::Ascii("klustres"),
        dictgen::InsensitiveStr::Ascii("klustrest"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("tonised"),
        dictgen::InsensitiveStr::Ascii("tonized"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LACKLUSTER_1715256487006561661)],
        &[(0b00001, &ENTRY_LACKLUSTERRER_1131236613295912206)],
        &[(0b00001, &ENTRY_LACKLUSTERREST_12506726696603302121)],
        &[(0b00001, &ENTRY_LACKLUSTERS_6612944023946392488)],
        &[(0b11010, &ENTRY_LACKLUSTER_1715256487006561661)],
        &[(0b11010, &ENTRY_LACKLUSTERRER_1131236613295912206)],
        &[(0b11010, &ENTRY_LACKLUSTERS_6612944023946392488)],
        &[(0b11010, &ENTRY_LACKLUSTERREST_12506726696603302121)],
        &[(0b10010, &ENTRY_LACONIZE_6822591394552566079)],
        &[(0b10010, &ENTRY_LACONIZED_8218300631285017302)],
        &[(0b10010, &ENTRY_LACONIZES_17382503982714857689)],
        &[(0b10010, &ENTRY_LACONIZING_6708174531909727302)],
        &[(0b01001, &ENTRY_LACONIZE_6822591394552566079)],
        &[(0b01001, &ENTRY_LACONIZED_8218300631285017302)],
        &[(0b01001, &ENTRY_LACONIZES_17382503982714857689)],
        &[(0b01001, &ENTRY_LACONIZING_6708174531909727302)],
        &[(0b10010, &ENTRY_LACTONIZED_17165917184156525672)],
        &[(0b01001, &ENTRY_LACTONIZED_17165917184156525672)],
    ],
    range: 5..=11,
};

static VARS_LAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_LAB_CHILDREN),
    value: None,
};

static VARS_LAB_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_LABE_NODE),
    None,
    None,
    None,
    Some(&VARS_LABI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LABO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_LABO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_LABO_CHILDREN),
    value: None,
};

static VARS_LABO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LABOR_NODE),
    None,
    None,
    Some(&VARS_LABOU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_LABOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LABOU_CHILDREN),
    value: None,
};

pub static VARS_LABOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rabilities"),
        dictgen::InsensitiveStr::Ascii("rability"),
        dictgen::InsensitiveStr::Ascii("rable"),
        dictgen::InsensitiveStr::Ascii("rables"),
        dictgen::InsensitiveStr::Ascii("rage"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("redlier"),
        dictgen::InsensitiveStr::Ascii("redliest"),
        dictgen::InsensitiveStr::Ascii("redly"),
        dictgen::InsensitiveStr::Ascii("redness"),
        dictgen::InsensitiveStr::Ascii("rednesses"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("ress"),
        dictgen::InsensitiveStr::Ascii("rhood"),
        dictgen::InsensitiveStr::Ascii("rhoods"),
        dictgen::InsensitiveStr::Ascii("ring"),
        dictgen::InsensitiveStr::Ascii("ringlier"),
        dictgen::InsensitiveStr::Ascii("ringliest"),
        dictgen::InsensitiveStr::Ascii("ringly"),
        dictgen::InsensitiveStr::Ascii("rings"),
        dictgen::InsensitiveStr::Ascii("rism"),
        dictgen::InsensitiveStr::Ascii("risms"),
        dictgen::InsensitiveStr::Ascii("rist"),
        dictgen::InsensitiveStr::Ascii("rists"),
        dictgen::InsensitiveStr::Ascii("rite"),
        dictgen::InsensitiveStr::Ascii("rites"),
        dictgen::InsensitiveStr::Ascii("rless"),
        dictgen::InsensitiveStr::Ascii("rlesser"),
        dictgen::InsensitiveStr::Ascii("rlesses"),
        dictgen::InsensitiveStr::Ascii("rlessest"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("rsaving"),
        dictgen::InsensitiveStr::Ascii("rsome"),
        dictgen::InsensitiveStr::Ascii("rsomely"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LABOR_17181769129422624469)],
        &[(0b11010, &ENTRY_LABORABILITIES_1374782393231225439)],
        &[(0b11010, &ENTRY_LABORABILITY_17263103500142200166)],
        &[(0b11010, &ENTRY_LABORABLE_5069469180400777649)],
        &[(0b11010, &ENTRY_LABORABLES_14898437790918563748)],
        &[(0b11010, &ENTRY_LABORAGE_4470460124023370902)],
        &[(0b11010, &ENTRY_LABORED_15774914145750785155)],
        &[(0b11010, &ENTRY_LABOREDLIER_15605691085469605442)],
        &[(0b11010, &ENTRY_LABOREDLIEST_10831075536431765156)],
        &[(0b11010, &ENTRY_LABOREDLY_6315030411151395853)],
        &[(0b11010, &ENTRY_LABOREDNESS_16418548514930234153)],
        &[(0b11010, &ENTRY_LABOREDNESSES_12342351621411660244)],
        &[(0b11010, &ENTRY_LABORER_7780947282825536960)],
        &[(0b11010, &ENTRY_LABORERS_7225219841972156021)],
        &[(0b11010, &ENTRY_LABORESS_13512364236747691122)],
        &[(0b11010, &ENTRY_LABORHOOD_12273635658052810449)],
        &[(0b11010, &ENTRY_LABORHOODS_5939892886551357822)],
        &[(0b11010, &ENTRY_LABORING_3043303013162659642)],
        &[(0b11010, &ENTRY_LABORINGLIER_3681973244253020451)],
        &[(0b11010, &ENTRY_LABORINGLIEST_2311322561763860722)],
        &[(0b11010, &ENTRY_LABORINGLY_9186457281954627517)],
        &[(0b11010, &ENTRY_LABORINGS_3319891939721158320)],
        &[(0b11010, &ENTRY_LABORISM_9169767374341726690)],
        &[(0b11010, &ENTRY_LABORISMS_4894710309638301654)],
        &[(0b11010, &ENTRY_LABORIST_6895625282299523587)],
        &[(0b11010, &ENTRY_LABORISTS_1797088670353430016)],
        &[(0b11010, &ENTRY_LABORITE_7167481098941329940)],
        &[(0b11010, &ENTRY_LABORITES_3700701955751769058)],
        &[(0b11010, &ENTRY_LABORLESS_12212925688273781595)],
        &[(0b11010, &ENTRY_LABORLESSER_3135471279426545229)],
        &[(0b11010, &ENTRY_LABORLESSES_1394050995892673233)],
        &[(0b11010, &ENTRY_LABORLESSEST_4185090035161099000)],
        &[(0b11010, &ENTRY_LABORS_911770229695768884)],
        &[(0b11010, &ENTRY_LABORSAVING_1772095626926060960)],
        &[(0b11010, &ENTRY_LABORSOME_10538594555629318753)],
        &[(0b11010, &ENTRY_LABORSOMELY_10662246512612016198)],
    ],
    range: 1..=10,
};

static VARS_LABOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LABOR_CHILDREN),
    value: Some(&[(0b11001, &ENTRY_LABOR_17181769129422624469)]),
};

pub static VARS_LABOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abilities"),
        dictgen::InsensitiveStr::Ascii("ability"),
        dictgen::InsensitiveStr::Ascii("able"),
        dictgen::InsensitiveStr::Ascii("ables"),
        dictgen::InsensitiveStr::Ascii("age"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("edlier"),
        dictgen::InsensitiveStr::Ascii("edliest"),
        dictgen::InsensitiveStr::Ascii("edly"),
        dictgen::InsensitiveStr::Ascii("edness"),
        dictgen::InsensitiveStr::Ascii("ednesses"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("ess"),
        dictgen::InsensitiveStr::Ascii("hood"),
        dictgen::InsensitiveStr::Ascii("hoods"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("inglier"),
        dictgen::InsensitiveStr::Ascii("ingliest"),
        dictgen::InsensitiveStr::Ascii("ingly"),
        dictgen::InsensitiveStr::Ascii("ings"),
        dictgen::InsensitiveStr::Ascii("ism"),
        dictgen::InsensitiveStr::Ascii("isms"),
        dictgen::InsensitiveStr::Ascii("ist"),
        dictgen::InsensitiveStr::Ascii("ists"),
        dictgen::InsensitiveStr::Ascii("ite"),
        dictgen::InsensitiveStr::Ascii("ites"),
        dictgen::InsensitiveStr::Ascii("less"),
        dictgen::InsensitiveStr::Ascii("lesser"),
        dictgen::InsensitiveStr::Ascii("lesses"),
        dictgen::InsensitiveStr::Ascii("lessest"),
        dictgen::InsensitiveStr::Ascii("s"),
        dictgen::InsensitiveStr::Ascii("saving"),
        dictgen::InsensitiveStr::Ascii("some"),
        dictgen::InsensitiveStr::Ascii("somely"),
    ],
    values: &[
        &[(0b11001, &ENTRY_LABORABILITIES_1374782393231225439)],
        &[(0b11001, &ENTRY_LABORABILITY_17263103500142200166)],
        &[(0b11001, &ENTRY_LABORABLE_5069469180400777649)],
        &[(0b11001, &ENTRY_LABORABLES_14898437790918563748)],
        &[(0b11001, &ENTRY_LABORAGE_4470460124023370902)],
        &[(0b11001, &ENTRY_LABORED_15774914145750785155)],
        &[(0b11001, &ENTRY_LABOREDLIER_15605691085469605442)],
        &[(0b11001, &ENTRY_LABOREDLIEST_10831075536431765156)],
        &[(0b11001, &ENTRY_LABOREDLY_6315030411151395853)],
        &[(0b11001, &ENTRY_LABOREDNESS_16418548514930234153)],
        &[(0b11001, &ENTRY_LABOREDNESSES_12342351621411660244)],
        &[(0b11001, &ENTRY_LABORER_7780947282825536960)],
        &[(0b11001, &ENTRY_LABORERS_7225219841972156021)],
        &[(0b11001, &ENTRY_LABORESS_13512364236747691122)],
        &[(0b11001, &ENTRY_LABORHOOD_12273635658052810449)],
        &[(0b11001, &ENTRY_LABORHOODS_5939892886551357822)],
        &[(0b11001, &ENTRY_LABORING_3043303013162659642)],
        &[(0b11001, &ENTRY_LABORINGLIER_3681973244253020451)],
        &[(0b11001, &ENTRY_LABORINGLIEST_2311322561763860722)],
        &[(0b11001, &ENTRY_LABORINGLY_9186457281954627517)],
        &[(0b11001, &ENTRY_LABORINGS_3319891939721158320)],
        &[(0b11001, &ENTRY_LABORISM_9169767374341726690)],
        &[(0b11001, &ENTRY_LABORISMS_4894710309638301654)],
        &[(0b00001, &ENTRY_LABORIST_6895625282299523587)],
        &[(0b00001, &ENTRY_LABORISTS_1797088670353430016)],
        &[(0b00001, &ENTRY_LABORITE_7167481098941329940)],
        &[(0b00001, &ENTRY_LABORITES_3700701955751769058)],
        &[(0b11001, &ENTRY_LABORLESS_12212925688273781595)],
        &[(0b11001, &ENTRY_LABORLESSER_3135471279426545229)],
        &[(0b11001, &ENTRY_LABORLESSES_1394050995892673233)],
        &[(0b11001, &ENTRY_LABORLESSEST_4185090035161099000)],
        &[(0b11001, &ENTRY_LABORS_911770229695768884)],
        &[(0b11001, &ENTRY_LABORSAVING_1772095626926060960)],
        &[(0b11001, &ENTRY_LABORSOME_10538594555629318753)],
        &[(0b11001, &ENTRY_LABORSOMELY_10662246512612016198)],
    ],
    range: 1..=9,
};

static VARS_LABI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LABI_CHILDREN),
    value: None,
};

pub static VARS_LABI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("atae"),
        dictgen::InsensitiveStr::Ascii("ate"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("ovelarisation"),
        dictgen::InsensitiveStr::Ascii("ovelarise"),
        dictgen::InsensitiveStr::Ascii("ovelarised"),
        dictgen::InsensitiveStr::Ascii("ovelarising"),
        dictgen::InsensitiveStr::Ascii("ovelarization"),
        dictgen::InsensitiveStr::Ascii("ovelarize"),
        dictgen::InsensitiveStr::Ascii("ovelarized"),
        dictgen::InsensitiveStr::Ascii("ovelarizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LABIALIZATION_16946285945330796012)],
        &[(0b10010, &ENTRY_LABIALIZATIONS_3690953183947628889)],
        &[(0b10010, &ENTRY_LABIALIZE_12309708431223536784)],
        &[(0b10010, &ENTRY_LABIALIZED_13758824402379981127)],
        &[(0b10010, &ENTRY_LABIALIZES_4066346379039880965)],
        &[(0b10010, &ENTRY_LABIALIZING_12581521144967923205)],
        &[(0b01001, &ENTRY_LABIALIZATION_16946285945330796012)],
        &[(0b01001, &ENTRY_LABIALIZATIONS_3690953183947628889)],
        &[(0b01001, &ENTRY_LABIALIZE_12309708431223536784)],
        &[(0b01001, &ENTRY_LABIALIZED_13758824402379981127)],
        &[(0b01001, &ENTRY_LABIALIZES_4066346379039880965)],
        &[(0b01001, &ENTRY_LABIALIZING_12581521144967923205)],
        &[(0b11010, &ENTRY_LABIATE_12523802628618211305)],
        &[(0b00001, &ENTRY_LABIATE_12523802628618211305)],
        &[(0b10010, &ENTRY_LABILIZATION_14178990427823362817)],
        &[(0b10010, &ENTRY_LABILIZATIONS_15897276050196647391)],
        &[(0b10010, &ENTRY_LABILIZE_18267732551973725200)],
        &[(0b10010, &ENTRY_LABILIZES_7830834372804891715)],
        &[(0b01001, &ENTRY_LABILIZATION_14178990427823362817)],
        &[(0b01001, &ENTRY_LABILIZATIONS_15897276050196647391)],
        &[(0b01001, &ENTRY_LABILIZE_18267732551973725200)],
        &[(0b01001, &ENTRY_LABILIZES_7830834372804891715)],
        &[(0b10010, &ENTRY_LABIOVELARIZATION_1388406139771404548)],
        &[(0b10010, &ENTRY_LABIOVELARIZE_14686339236476089437)],
        &[(0b10010, &ENTRY_LABIOVELARIZED_10933318847370841173)],
        &[(0b10010, &ENTRY_LABIOVELARIZING_17700134289778983903)],
        &[(0b01001, &ENTRY_LABIOVELARIZATION_1388406139771404548)],
        &[(0b01001, &ENTRY_LABIOVELARIZE_14686339236476089437)],
        &[(0b01001, &ENTRY_LABIOVELARIZED_10933318847370841173)],
        &[(0b01001, &ENTRY_LABIOVELARIZING_17700134289778983903)],
    ],
    range: 3..=13,
};

static VARS_LABE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LABE_CHILDREN),
    value: None,
};

pub static VARS_LABE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lable"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("llable"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("ller"),
        dictgen::InsensitiveStr::Ascii("llers"),
        dictgen::InsensitiveStr::Ascii("lling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LABELABLE_11309838925293352839)],
        &[(0b00001, &ENTRY_LABELED_2907482757768957656)],
        &[(0b00001, &ENTRY_LABELER_4919831389912264778)],
        &[(0b00001, &ENTRY_LABELERS_11132772436034449864)],
        &[(0b00001, &ENTRY_LABELING_17714047580259532785)],
        &[(0b11010, &ENTRY_LABELABLE_11309838925293352839)],
        &[(0b11010, &ENTRY_LABELED_2907482757768957656)],
        &[(0b11010, &ENTRY_LABELER_4919831389912264778)],
        &[(0b11010, &ENTRY_LABELERS_11132772436034449864)],
        &[(0b11010, &ENTRY_LABELING_17714047580259532785)],
    ],
    range: 3..=6,
};

static VARS_K_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_K_CHILDREN),
    value: None,
};

static VARS_K_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_KA_NODE),
    None,
    None,
    None,
    Some(&VARS_KE_NODE),
    None,
    None,
    None,
    Some(&VARS_KI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_KO_NODE),
    None,
    None,
    Some(&VARS_KR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_KY_NODE),
    None,
];

static VARS_KY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_KY_CHILDREN),
    value: None,
};

pub static VARS_KY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("loes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_KYANIZE_18259022762044268711)],
        &[(0b10010, &ENTRY_KYANIZED_7491403161764420741)],
        &[(0b10010, &ENTRY_KYANIZES_9819131922262272623)],
        &[(0b10010, &ENTRY_KYANIZING_1109891397394364587)],
        &[(0b01001, &ENTRY_KYANIZE_18259022762044268711)],
        &[(0b01001, &ENTRY_KYANIZED_7491403161764420741)],
        &[(0b01001, &ENTRY_KYANIZES_9819131922262272623)],
        &[(0b01001, &ENTRY_KYANIZING_1109891397394364587)],
        &[(0b11010, &ENTRY_KYLES_10195640480009922922)],
    ],
    range: 4..=7,
};

static VARS_KR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_KR_CHILDREN),
    value: None,
};

pub static VARS_KR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ein")],
    values: &[&[(0b11010, &ENTRY_KERIN_11573832134730158699)]],
    range: 3..=3,
};

static VARS_KO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_KO_CHILDREN),
    value: None,
};

pub static VARS_KO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ellia"),
        dictgen::InsensitiveStr::Ascii("eppel"),
        dictgen::InsensitiveStr::Ascii("ssaean"),
        dictgen::InsensitiveStr::Ascii("ssean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_KELLIA_18207542001610745483)],
        &[(0b11010, &ENTRY_KEPPEL_3250945561966438026)],
        &[(0b11010, &ENTRY_KOSSEAN_16378574701214617146)],
        &[(0b00001, &ENTRY_KOSSEAN_16378574701214617146)],
    ],
    range: 5..=6,
};

static VARS_KI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_KI_CHILDREN),
    value: None,
};

pub static VARS_KI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dnaped"),
        dictgen::InsensitiveStr::Ascii("dnaper"),
        dictgen::InsensitiveStr::Ascii("dnapers"),
        dictgen::InsensitiveStr::Ascii("dnaping"),
        dictgen::InsensitiveStr::Ascii("logramme"),
        dictgen::InsensitiveStr::Ascii("logrammes"),
        dictgen::InsensitiveStr::Ascii("loliter"),
        dictgen::InsensitiveStr::Ascii("loliters"),
        dictgen::InsensitiveStr::Ascii("lolitre"),
        dictgen::InsensitiveStr::Ascii("lolitres"),
        dictgen::InsensitiveStr::Ascii("lometer"),
        dictgen::InsensitiveStr::Ascii("lometers"),
        dictgen::InsensitiveStr::Ascii("lometre"),
        dictgen::InsensitiveStr::Ascii("lometres"),
        dictgen::InsensitiveStr::Ascii("naestheses"),
        dictgen::InsensitiveStr::Ascii("naesthesia"),
        dictgen::InsensitiveStr::Ascii("naesthesias"),
        dictgen::InsensitiveStr::Ascii("naesthesis"),
        dictgen::InsensitiveStr::Ascii("naesthetic"),
        dictgen::InsensitiveStr::Ascii("naestheticallier"),
        dictgen::InsensitiveStr::Ascii("naestheticalliest"),
        dictgen::InsensitiveStr::Ascii("naesthetically"),
        dictgen::InsensitiveStr::Ascii("naestheticer"),
        dictgen::InsensitiveStr::Ascii("naestheticest"),
        dictgen::InsensitiveStr::Ascii("naesthetics"),
        dictgen::InsensitiveStr::Ascii("ndergartener"),
        dictgen::InsensitiveStr::Ascii("ndergarteners"),
        dictgen::InsensitiveStr::Ascii("ndergartner"),
        dictgen::InsensitiveStr::Ascii("ndergartners"),
        dictgen::InsensitiveStr::Ascii("nestheses"),
        dictgen::InsensitiveStr::Ascii("nesthesia"),
        dictgen::InsensitiveStr::Ascii("nesthesias"),
        dictgen::InsensitiveStr::Ascii("nesthesis"),
        dictgen::InsensitiveStr::Ascii("nesthetic"),
        dictgen::InsensitiveStr::Ascii("nestheticallier"),
        dictgen::InsensitiveStr::Ascii("nestheticalliest"),
        dictgen::InsensitiveStr::Ascii("nesthetically"),
        dictgen::InsensitiveStr::Ascii("nestheticer"),
        dictgen::InsensitiveStr::Ascii("nestheticest"),
        dictgen::InsensitiveStr::Ascii("nesthetics"),
    ],
    values: &[
        &[(0b00001, &ENTRY_KIDNAPPED_9540389708046051348)],
        &[(0b00001, &ENTRY_KIDNAPPER_13085195688301237337)],
        &[(0b00001, &ENTRY_KIDNAPPERS_9985029854330453394)],
        &[(0b00001, &ENTRY_KIDNAPPING_70511558429659)],
        &[(0b10010, &ENTRY_KILOGRAM_7939130248079190868)],
        &[(0b10010, &ENTRY_KILOGRAMS_12915102141657973507)],
        &[(0b01001, &ENTRY_KILOLITER_8811985426912090253)],
        &[(0b01001, &ENTRY_KILOLITERS_7196014977999441896)],
        &[(0b11010, &ENTRY_KILOLITER_8811985426912090253)],
        &[(0b11010, &ENTRY_KILOLITERS_7196014977999441896)],
        &[(0b01001, &ENTRY_KILOMETER_3916092874457639239)],
        &[(0b01001, &ENTRY_KILOMETERS_7517136324284687795)],
        &[(0b11010, &ENTRY_KILOMETER_3916092874457639239)],
        &[(0b11010, &ENTRY_KILOMETERS_7517136324284687795)],
        &[(0b11010, &ENTRY_KINESTHESES_15991774592082202202)],
        &[(0b11010, &ENTRY_KINESTHESIA_4063943003598390788)],
        &[(0b11010, &ENTRY_KINESTHESIAS_5509168349661428667)],
        &[(0b11010, &ENTRY_KINESTHESIS_13862880956607670027)],
        &[(0b11010, &ENTRY_KINESTHETIC_12696136530393551560)],
        &[(0b11010, &ENTRY_KINESTHETICALLIER_8649272125040776816)],
        &[(0b11010, &ENTRY_KINESTHETICALLIEST_16611528420519039262)],
        &[(0b11010, &ENTRY_KINESTHETICALLY_6590308132254918624)],
        &[(0b11010, &ENTRY_KINESTHETICER_10688483926829306448)],
        &[(0b11010, &ENTRY_KINESTHETICEST_17532483346165398356)],
        &[(0b11010, &ENTRY_KINESTHETICS_8164390027509303384)],
        &[(0b10011, &ENTRY_KINDERGARTNER_13742901016370510532)],
        &[(0b10011, &ENTRY_KINDERGARTNERS_5091309540324859208)],
        &[(0b01001, &ENTRY_KINDERGARTNER_13742901016370510532)],
        &[(0b01001, &ENTRY_KINDERGARTNERS_5091309540324859208)],
        &[(0b10001, &ENTRY_KINESTHESES_15991774592082202202)],
        &[(0b11001, &ENTRY_KINESTHESIA_4063943003598390788)],
        &[(0b11001, &ENTRY_KINESTHESIAS_5509168349661428667)],
        &[(0b10001, &ENTRY_KINESTHESIS_13862880956607670027)],
        &[(0b11001, &ENTRY_KINESTHETIC_12696136530393551560)],
        &[(0b10001, &ENTRY_KINESTHETICALLIER_8649272125040776816)],
        &[(0b10001, &ENTRY_KINESTHETICALLIEST_16611528420519039262)],
        &[(0b10001, &ENTRY_KINESTHETICALLY_6590308132254918624)],
        &[(0b11001, &ENTRY_KINESTHETICER_10688483926829306448)],
        &[(0b11001, &ENTRY_KINESTHETICEST_17532483346165398356)],
        &[(0b11001, &ENTRY_KINESTHETICS_8164390027509303384)],
    ],
    range: 6..=17,
};

static VARS_KE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_KE_CHILDREN),
    value: None,
};

pub static VARS_KE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("iser"),
        dictgen::InsensitiveStr::Ascii("izer"),
        dictgen::InsensitiveStr::Ascii("llia"),
        dictgen::InsensitiveStr::Ascii("mbed"),
        dictgen::InsensitiveStr::Ascii("mboed"),
        dictgen::InsensitiveStr::Ascii("nneled"),
        dictgen::InsensitiveStr::Ascii("nneling"),
        dictgen::InsensitiveStr::Ascii("nnelled"),
        dictgen::InsensitiveStr::Ascii("nnelling"),
        dictgen::InsensitiveStr::Ascii("ppel"),
        dictgen::InsensitiveStr::Ascii("ratinisation"),
        dictgen::InsensitiveStr::Ascii("ratinisations"),
        dictgen::InsensitiveStr::Ascii("ratinise"),
        dictgen::InsensitiveStr::Ascii("ratinised"),
        dictgen::InsensitiveStr::Ascii("ratinises"),
        dictgen::InsensitiveStr::Ascii("ratinising"),
        dictgen::InsensitiveStr::Ascii("ratinization"),
        dictgen::InsensitiveStr::Ascii("ratinizations"),
        dictgen::InsensitiveStr::Ascii("ratinize"),
        dictgen::InsensitiveStr::Ascii("ratinized"),
        dictgen::InsensitiveStr::Ascii("ratinizes"),
        dictgen::InsensitiveStr::Ascii("ratinizing"),
        dictgen::InsensitiveStr::Ascii("rb"),
        dictgen::InsensitiveStr::Ascii("rbed"),
        dictgen::InsensitiveStr::Ascii("rbing"),
        dictgen::InsensitiveStr::Ascii("rbs"),
        dictgen::InsensitiveStr::Ascii("rin"),
        dictgen::InsensitiveStr::Ascii("rneled"),
        dictgen::InsensitiveStr::Ascii("rneling"),
        dictgen::InsensitiveStr::Ascii("rnelled"),
        dictgen::InsensitiveStr::Ascii("rnelling"),
        dictgen::InsensitiveStr::Ascii("rosine"),
        dictgen::InsensitiveStr::Ascii("rosines"),
        dictgen::InsensitiveStr::Ascii("tonaemia"),
        dictgen::InsensitiveStr::Ascii("tonemia"),
        dictgen::InsensitiveStr::Ascii("tonisation"),
        dictgen::InsensitiveStr::Ascii("tonisations"),
        dictgen::InsensitiveStr::Ascii("tonise"),
        dictgen::InsensitiveStr::Ascii("tonises"),
        dictgen::InsensitiveStr::Ascii("tonization"),
        dictgen::InsensitiveStr::Ascii("tonizations"),
        dictgen::InsensitiveStr::Ascii("tonize"),
        dictgen::InsensitiveStr::Ascii("tonizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_KED_7992567477889895157)],
        &[(0b10010, &ENTRY_KEIZER_16279072195491513044)],
        &[(0b01001, &ENTRY_KEIZER_16279072195491513044)],
        &[(0b00001, &ENTRY_KELLIA_18207542001610745483)],
        &[(0b00001, &ENTRY_KEMBED_5455940632308636783)],
        &[(0b11010, &ENTRY_KEMBED_5455940632308636783)],
        &[(0b00001, &ENTRY_KENNELED_7097387362453255328)],
        &[(0b00001, &ENTRY_KENNELING_3222702508854487680)],
        &[(0b11010, &ENTRY_KENNELED_7097387362453255328)],
        &[(0b11010, &ENTRY_KENNELING_3222702508854487680)],
        &[(0b00001, &ENTRY_KEPPEL_3250945561966438026)],
        &[(0b10010, &ENTRY_KERATINIZATION_9287269898372096209)],
        &[(0b10010, &ENTRY_KERATINIZATIONS_11148703562572717517)],
        &[(0b10010, &ENTRY_KERATINIZE_5854314817304010708)],
        &[(0b10010, &ENTRY_KERATINIZED_9532404537119161326)],
        &[(0b10010, &ENTRY_KERATINIZES_6869237603626021135)],
        &[(0b10010, &ENTRY_KERATINIZING_6928540492051600473)],
        &[(0b01001, &ENTRY_KERATINIZATION_9287269898372096209)],
        &[(0b01001, &ENTRY_KERATINIZATIONS_11148703562572717517)],
        &[(0b01001, &ENTRY_KERATINIZE_5854314817304010708)],
        &[(0b01001, &ENTRY_KERATINIZED_9532404537119161326)],
        &[(0b01001, &ENTRY_KERATINIZES_6869237603626021135)],
        &[(0b01001, &ENTRY_KERATINIZING_6928540492051600473)],
        &[(0b10010, &ENTRY_CURB_9612809176224939948)],
        &[(0b10010, &ENTRY_CURBED_1749064354422368895)],
        &[(0b10010, &ENTRY_CURBING_4261884005739231831)],
        &[(0b10010, &ENTRY_CURBS_3570783962680392558)],
        &[(0b00001, &ENTRY_KERIN_11573832134730158699)],
        &[(0b00001, &ENTRY_KERNELED_16844207359376744747)],
        &[(0b00001, &ENTRY_KERNELING_12862192556676476135)],
        &[(0b11010, &ENTRY_KERNELED_16844207359376744747)],
        &[(0b11010, &ENTRY_KERNELING_12862192556676476135)],
        &[(0b10011, &ENTRY_KEROSENE_5237608390797685560)],
        &[(0b10011, &ENTRY_KEROSENES_9607995162491837420)],
        &[(0b11010, &ENTRY_KETONEMIA_12805799450504016636)],
        &[(0b10001, &ENTRY_KETONEMIA_12805799450504016636)],
        &[(0b10010, &ENTRY_KETONIZATION_13151004879407765304)],
        &[(0b10010, &ENTRY_KETONIZATIONS_14849157462001694089)],
        &[(0b10010, &ENTRY_KETONIZE_456616172246125509)],
        &[(0b10010, &ENTRY_KETONIZES_13135406478710592228)],
        &[(0b01001, &ENTRY_KETONIZATION_13151004879407765304)],
        &[(0b01001, &ENTRY_KETONIZATIONS_14849157462001694089)],
        &[(0b01001, &ENTRY_KETONIZE_456616172246125509)],
        &[(0b01001, &ENTRY_KETONIZES_13135406478710592228)],
    ],
    range: 1..=13,
};

static VARS_KA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_KA_CHILDREN),
    value: None,
};

pub static VARS_KA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("nae"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("olinisation"),
        dictgen::InsensitiveStr::Ascii("olinisations"),
        dictgen::InsensitiveStr::Ascii("olinise"),
        dictgen::InsensitiveStr::Ascii("olinised"),
        dictgen::InsensitiveStr::Ascii("olinises"),
        dictgen::InsensitiveStr::Ascii("olinising"),
        dictgen::InsensitiveStr::Ascii("olinization"),
        dictgen::InsensitiveStr::Ascii("olinizations"),
        dictgen::InsensitiveStr::Ascii("olinize"),
        dictgen::InsensitiveStr::Ascii("olinized"),
        dictgen::InsensitiveStr::Ascii("olinizes"),
        dictgen::InsensitiveStr::Ascii("olinizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_KED_7992567477889895157)],
        &[(0b11010, &ENTRY_KANE_6625073156856396398)],
        &[(0b00001, &ENTRY_KANE_6625073156856396398)],
        &[(0b10010, &ENTRY_KAOLINIZATION_3243954716236483625)],
        &[(0b10010, &ENTRY_KAOLINIZATIONS_6857713841926809034)],
        &[(0b10010, &ENTRY_KAOLINIZE_1540770554993870553)],
        &[(0b10010, &ENTRY_KAOLINIZED_6353288544737897076)],
        &[(0b10010, &ENTRY_KAOLINIZES_14280727638122409305)],
        &[(0b10010, &ENTRY_KAOLINIZING_16455578064118109141)],
        &[(0b01001, &ENTRY_KAOLINIZATION_3243954716236483625)],
        &[(0b01001, &ENTRY_KAOLINIZATIONS_6857713841926809034)],
        &[(0b01001, &ENTRY_KAOLINIZE_1540770554993870553)],
        &[(0b01001, &ENTRY_KAOLINIZED_6353288544737897076)],
        &[(0b01001, &ENTRY_KAOLINIZES_14280727638122409305)],
        &[(0b01001, &ENTRY_KAOLINIZING_16455578064118109141)],
    ],
    range: 2..=12,
};

static VARS_J_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_J_CHILDREN),
    value: None,
};

static VARS_J_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_JA_NODE),
    None,
    None,
    None,
    Some(&VARS_JE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_JO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_JU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_JU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_JU_CHILDREN),
    value: None,
};

pub static VARS_JU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("daean"),
        dictgen::InsensitiveStr::Ascii("daeans"),
        dictgen::InsensitiveStr::Ascii("daeophobia"),
        dictgen::InsensitiveStr::Ascii("daisation"),
        dictgen::InsensitiveStr::Ascii("daise"),
        dictgen::InsensitiveStr::Ascii("daised"),
        dictgen::InsensitiveStr::Ascii("daiser"),
        dictgen::InsensitiveStr::Ascii("daising"),
        dictgen::InsensitiveStr::Ascii("daization"),
        dictgen::InsensitiveStr::Ascii("daize"),
        dictgen::InsensitiveStr::Ascii("daized"),
        dictgen::InsensitiveStr::Ascii("daizer"),
        dictgen::InsensitiveStr::Ascii("daizing"),
        dictgen::InsensitiveStr::Ascii("dean"),
        dictgen::InsensitiveStr::Ascii("deans"),
        dictgen::InsensitiveStr::Ascii("deophobia"),
        dictgen::InsensitiveStr::Ascii("dgement"),
        dictgen::InsensitiveStr::Ascii("dgements"),
        dictgen::InsensitiveStr::Ascii("dicialise"),
        dictgen::InsensitiveStr::Ascii("dicialises"),
        dictgen::InsensitiveStr::Ascii("dicialize"),
        dictgen::InsensitiveStr::Ascii("dicializes"),
        dictgen::InsensitiveStr::Ascii("lidae"),
        dictgen::InsensitiveStr::Ascii("lide"),
        dictgen::InsensitiveStr::Ascii("mboise"),
        dictgen::InsensitiveStr::Ascii("mboised"),
        dictgen::InsensitiveStr::Ascii("mboises"),
        dictgen::InsensitiveStr::Ascii("mboising"),
        dictgen::InsensitiveStr::Ascii("mboize"),
        dictgen::InsensitiveStr::Ascii("mboized"),
        dictgen::InsensitiveStr::Ascii("mboizes"),
        dictgen::InsensitiveStr::Ascii("mboizing"),
        dictgen::InsensitiveStr::Ascii("venilise"),
        dictgen::InsensitiveStr::Ascii("venilises"),
        dictgen::InsensitiveStr::Ascii("venilize"),
        dictgen::InsensitiveStr::Ascii("venilizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_JUDEAN_941286922202375422)],
        &[(0b11010, &ENTRY_JUDEANS_9104141413565020951)],
        &[(0b11010, &ENTRY_JUDEOPHOBIA_5648063668971673358)],
        &[(0b10010, &ENTRY_JUDAIZATION_8802637711012973186)],
        &[(0b10010, &ENTRY_JUDAIZE_12262219091800711286)],
        &[(0b10010, &ENTRY_JUDAIZED_11097537345612695567)],
        &[(0b10010, &ENTRY_JUDAIZER_9074198258934684563)],
        &[(0b10010, &ENTRY_JUDAIZING_3118358796769865883)],
        &[(0b01001, &ENTRY_JUDAIZATION_8802637711012973186)],
        &[(0b01001, &ENTRY_JUDAIZE_12262219091800711286)],
        &[(0b01001, &ENTRY_JUDAIZED_11097537345612695567)],
        &[(0b01001, &ENTRY_JUDAIZER_9074198258934684563)],
        &[(0b01001, &ENTRY_JUDAIZING_3118358796769865883)],
        &[(0b00001, &ENTRY_JUDEAN_941286922202375422)],
        &[(0b00001, &ENTRY_JUDEANS_9104141413565020951)],
        &[(0b00001, &ENTRY_JUDEOPHOBIA_5648063668971673358)],
        &[(0b11010, &ENTRY_JUDGMENT_16033544137863724757)],
        &[(0b11010, &ENTRY_JUDGMENTS_3887014541133672054)],
        &[(0b10010, &ENTRY_JUDICIALIZE_2368190414477914253)],
        &[(0b10010, &ENTRY_JUDICIALIZES_2293404910703458939)],
        &[(0b01001, &ENTRY_JUDICIALIZE_2368190414477914253)],
        &[(0b01001, &ENTRY_JUDICIALIZES_2293404910703458939)],
        &[(0b11010, &ENTRY_JULIDE_528656478496277011)],
        &[(0b00001, &ENTRY_JULIDE_528656478496277011)],
        &[(0b10010, &ENTRY_JUMBOIZE_7712117084015749654)],
        &[(0b10010, &ENTRY_JUMBOIZED_18212256537106696792)],
        &[(0b10010, &ENTRY_JUMBOIZES_2354824516718999834)],
        &[(0b10010, &ENTRY_JUMBOIZING_11206648409875659758)],
        &[(0b01001, &ENTRY_JUMBOIZE_7712117084015749654)],
        &[(0b01001, &ENTRY_JUMBOIZED_18212256537106696792)],
        &[(0b01001, &ENTRY_JUMBOIZES_2354824516718999834)],
        &[(0b01001, &ENTRY_JUMBOIZING_11206648409875659758)],
        &[(0b10010, &ENTRY_JUVENILIZE_10243628665762694787)],
        &[(0b10010, &ENTRY_JUVENILIZES_1699288187481999237)],
        &[(0b01001, &ENTRY_JUVENILIZE_10243628665762694787)],
        &[(0b01001, &ENTRY_JUVENILIZES_1699288187481999237)],
    ],
    range: 4..=10,
};

static VARS_JO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_JO_CHILDREN),
    value: None,
};

pub static VARS_JO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ky"),
        dictgen::InsensitiveStr::Ascii("nathanisation"),
        dictgen::InsensitiveStr::Ascii("nathanisations"),
        dictgen::InsensitiveStr::Ascii("nathanization"),
        dictgen::InsensitiveStr::Ascii("nathanizations"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("ur"),
        dictgen::InsensitiveStr::Ascii("urnalisation"),
        dictgen::InsensitiveStr::Ascii("urnalisations"),
        dictgen::InsensitiveStr::Ascii("urnalise"),
        dictgen::InsensitiveStr::Ascii("urnalised"),
        dictgen::InsensitiveStr::Ascii("urnaliser"),
        dictgen::InsensitiveStr::Ascii("urnalisers"),
        dictgen::InsensitiveStr::Ascii("urnalises"),
        dictgen::InsensitiveStr::Ascii("urnalising"),
        dictgen::InsensitiveStr::Ascii("urnalization"),
        dictgen::InsensitiveStr::Ascii("urnalizations"),
        dictgen::InsensitiveStr::Ascii("urnalize"),
        dictgen::InsensitiveStr::Ascii("urnalized"),
        dictgen::InsensitiveStr::Ascii("urnalizer"),
        dictgen::InsensitiveStr::Ascii("urnalizers"),
        dictgen::InsensitiveStr::Ascii("urnalizes"),
        dictgen::InsensitiveStr::Ascii("urnalizing"),
        dictgen::InsensitiveStr::Ascii("urs"),
        dictgen::InsensitiveStr::Ascii("vialise"),
        dictgen::InsensitiveStr::Ascii("vialises"),
        dictgen::InsensitiveStr::Ascii("vialize"),
        dictgen::InsensitiveStr::Ascii("vializes"),
    ],
    values: &[
        &[(0b10011, &ENTRY_JOKEY_1401133516029317070)],
        &[(0b10010, &ENTRY_JONATHANIZATION_349407157278376320)],
        &[(0b10010, &ENTRY_JONATHANIZATIONS_9684819613638525720)],
        &[(0b01001, &ENTRY_JONATHANIZATION_349407157278376320)],
        &[(0b01001, &ENTRY_JONATHANIZATIONS_9684819613638525720)],
        &[(0b00001, &ENTRY_JOR_4372776148473778988)],
        &[(0b00001, &ENTRY_JORS_13869203658420639286)],
        &[(0b11010, &ENTRY_JOR_4372776148473778988)],
        &[(0b10010, &ENTRY_JOURNALIZATION_13869741869452298927)],
        &[(0b10010, &ENTRY_JOURNALIZATIONS_8360098568590750822)],
        &[(0b10010, &ENTRY_JOURNALIZE_7557433468559833421)],
        &[(0b10010, &ENTRY_JOURNALIZED_8816090977822832287)],
        &[(0b10010, &ENTRY_JOURNALIZER_16230238068690488425)],
        &[(0b10010, &ENTRY_JOURNALIZERS_6645590336287424690)],
        &[(0b10010, &ENTRY_JOURNALIZES_12274656852355418094)],
        &[(0b10010, &ENTRY_JOURNALIZING_2527188867008816103)],
        &[(0b01001, &ENTRY_JOURNALIZATION_13869741869452298927)],
        &[(0b01001, &ENTRY_JOURNALIZATIONS_8360098568590750822)],
        &[(0b01001, &ENTRY_JOURNALIZE_7557433468559833421)],
        &[(0b01001, &ENTRY_JOURNALIZED_8816090977822832287)],
        &[(0b01001, &ENTRY_JOURNALIZER_16230238068690488425)],
        &[(0b01001, &ENTRY_JOURNALIZERS_6645590336287424690)],
        &[(0b01001, &ENTRY_JOURNALIZES_12274656852355418094)],
        &[(0b01001, &ENTRY_JOURNALIZING_2527188867008816103)],
        &[(0b11010, &ENTRY_JORS_13869203658420639286)],
        &[(0b10010, &ENTRY_JOVIALIZE_6055513817327603369)],
        &[(0b10010, &ENTRY_JOVIALIZES_16003736818573545855)],
        &[(0b01001, &ENTRY_JOVIALIZE_6055513817327603369)],
        &[(0b01001, &ENTRY_JOVIALIZES_16003736818573545855)],
    ],
    range: 1..=14,
};

static VARS_JE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_JE_CHILDREN),
    value: None,
};

pub static VARS_JE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("opardisation"),
        dictgen::InsensitiveStr::Ascii("opardise"),
        dictgen::InsensitiveStr::Ascii("opardised"),
        dictgen::InsensitiveStr::Ascii("opardises"),
        dictgen::InsensitiveStr::Ascii("opardising"),
        dictgen::InsensitiveStr::Ascii("opardization"),
        dictgen::InsensitiveStr::Ascii("opardize"),
        dictgen::InsensitiveStr::Ascii("opardized"),
        dictgen::InsensitiveStr::Ascii("opardizes"),
        dictgen::InsensitiveStr::Ascii("opardizing"),
        dictgen::InsensitiveStr::Ascii("suitisation"),
        dictgen::InsensitiveStr::Ascii("suitise"),
        dictgen::InsensitiveStr::Ascii("suitised"),
        dictgen::InsensitiveStr::Ascii("suitises"),
        dictgen::InsensitiveStr::Ascii("suitising"),
        dictgen::InsensitiveStr::Ascii("suitization"),
        dictgen::InsensitiveStr::Ascii("suitize"),
        dictgen::InsensitiveStr::Ascii("suitized"),
        dictgen::InsensitiveStr::Ascii("suitizes"),
        dictgen::InsensitiveStr::Ascii("suitizing"),
        dictgen::InsensitiveStr::Ascii("weled"),
        dictgen::InsensitiveStr::Ascii("weler"),
        dictgen::InsensitiveStr::Ascii("welers"),
        dictgen::InsensitiveStr::Ascii("weling"),
        dictgen::InsensitiveStr::Ascii("welled"),
        dictgen::InsensitiveStr::Ascii("weller"),
        dictgen::InsensitiveStr::Ascii("wellers"),
        dictgen::InsensitiveStr::Ascii("wellery"),
        dictgen::InsensitiveStr::Ascii("welling"),
        dictgen::InsensitiveStr::Ascii("welry"),
    ],
    values: &[
        &[(0b10010, &ENTRY_JEOPARDIZATION_8233628518568267550)],
        &[(0b10010, &ENTRY_JEOPARDIZE_7563132171286021122)],
        &[(0b10010, &ENTRY_JEOPARDIZED_4290897290667261086)],
        &[(0b10010, &ENTRY_JEOPARDIZES_1770057888942412589)],
        &[(0b10010, &ENTRY_JEOPARDIZING_11478877839793401266)],
        &[(0b01001, &ENTRY_JEOPARDIZATION_8233628518568267550)],
        &[(0b01001, &ENTRY_JEOPARDIZE_7563132171286021122)],
        &[(0b01001, &ENTRY_JEOPARDIZED_4290897290667261086)],
        &[(0b01001, &ENTRY_JEOPARDIZES_1770057888942412589)],
        &[(0b01001, &ENTRY_JEOPARDIZING_11478877839793401266)],
        &[(0b10010, &ENTRY_JESUITIZATION_12076627418335111216)],
        &[(0b10010, &ENTRY_JESUITIZE_14648103267389726386)],
        &[(0b10010, &ENTRY_JESUITIZED_5064316526791201394)],
        &[(0b10010, &ENTRY_JESUITIZES_8149561683144943800)],
        &[(0b10010, &ENTRY_JESUITIZING_1670456186993799400)],
        &[(0b01001, &ENTRY_JESUITIZATION_12076627418335111216)],
        &[(0b01001, &ENTRY_JESUITIZE_14648103267389726386)],
        &[(0b01001, &ENTRY_JESUITIZED_5064316526791201394)],
        &[(0b01001, &ENTRY_JESUITIZES_8149561683144943800)],
        &[(0b01001, &ENTRY_JESUITIZING_1670456186993799400)],
        &[(0b00001, &ENTRY_JEWELED_1164673326064560766)],
        &[(0b00001, &ENTRY_JEWELER_11683392478209510720)],
        &[(0b00001, &ENTRY_JEWELERS_4919007304834585018)],
        &[(0b00001, &ENTRY_JEWELING_17397805769460286766)],
        &[(0b11010, &ENTRY_JEWELED_1164673326064560766)],
        &[(0b11010, &ENTRY_JEWELER_11683392478209510720)],
        &[(0b11010, &ENTRY_JEWELERS_4919007304834585018)],
        &[(0b11010, &ENTRY_JEWELRY_1265691138331552301)],
        &[(0b11010, &ENTRY_JEWELING_17397805769460286766)],
        &[(0b01001, &ENTRY_JEWELRY_1265691138331552301)],
    ],
    range: 5..=12,
};

static VARS_JA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_JA_CHILDREN),
    value: None,
};

pub static VARS_JA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cobaean"),
        dictgen::InsensitiveStr::Ascii("cobean"),
        dictgen::InsensitiveStr::Ascii("cobinisation"),
        dictgen::InsensitiveStr::Ascii("cobinise"),
        dictgen::InsensitiveStr::Ascii("cobinised"),
        dictgen::InsensitiveStr::Ascii("cobinises"),
        dictgen::InsensitiveStr::Ascii("cobinising"),
        dictgen::InsensitiveStr::Ascii("cobinization"),
        dictgen::InsensitiveStr::Ascii("cobinize"),
        dictgen::InsensitiveStr::Ascii("cobinized"),
        dictgen::InsensitiveStr::Ascii("cobinizes"),
        dictgen::InsensitiveStr::Ascii("cobinizing"),
        dictgen::InsensitiveStr::Ascii("ilor"),
        dictgen::InsensitiveStr::Ascii("ilors"),
        dictgen::InsensitiveStr::Ascii("nisaries"),
        dictgen::InsensitiveStr::Ascii("nisary"),
        dictgen::InsensitiveStr::Ascii("nizaries"),
        dictgen::InsensitiveStr::Ascii("nizary"),
        dictgen::InsensitiveStr::Ascii("panisation"),
        dictgen::InsensitiveStr::Ascii("panisations"),
        dictgen::InsensitiveStr::Ascii("panise"),
        dictgen::InsensitiveStr::Ascii("panised"),
        dictgen::InsensitiveStr::Ascii("panises"),
        dictgen::InsensitiveStr::Ascii("panising"),
        dictgen::InsensitiveStr::Ascii("panization"),
        dictgen::InsensitiveStr::Ascii("panizations"),
        dictgen::InsensitiveStr::Ascii("panize"),
        dictgen::InsensitiveStr::Ascii("panized"),
        dictgen::InsensitiveStr::Ascii("panizes"),
        dictgen::InsensitiveStr::Ascii("panizing"),
        dictgen::InsensitiveStr::Ascii("rgonisation"),
        dictgen::InsensitiveStr::Ascii("rgonisations"),
        dictgen::InsensitiveStr::Ascii("rgonise"),
        dictgen::InsensitiveStr::Ascii("rgonised"),
        dictgen::InsensitiveStr::Ascii("rgonises"),
        dictgen::InsensitiveStr::Ascii("rgonising"),
        dictgen::InsensitiveStr::Ascii("rgonization"),
        dictgen::InsensitiveStr::Ascii("rgonizations"),
        dictgen::InsensitiveStr::Ascii("rgonize"),
        dictgen::InsensitiveStr::Ascii("rgonized"),
        dictgen::InsensitiveStr::Ascii("rgonizes"),
        dictgen::InsensitiveStr::Ascii("rgonizing"),
        dictgen::InsensitiveStr::Ascii("sperise"),
        dictgen::InsensitiveStr::Ascii("sperised"),
        dictgen::InsensitiveStr::Ascii("sperises"),
        dictgen::InsensitiveStr::Ascii("sperising"),
        dictgen::InsensitiveStr::Ascii("sperize"),
        dictgen::InsensitiveStr::Ascii("sperized"),
        dictgen::InsensitiveStr::Ascii("sperizes"),
        dictgen::InsensitiveStr::Ascii("sperizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_JACOBEAN_11417760184890412965)],
        &[(0b00001, &ENTRY_JACOBEAN_11417760184890412965)],
        &[(0b10010, &ENTRY_JACOBINIZATION_12620112081606324932)],
        &[(0b10010, &ENTRY_JACOBINIZE_5488043839092421303)],
        &[(0b10010, &ENTRY_JACOBINIZED_16734740525018333391)],
        &[(0b10010, &ENTRY_JACOBINIZES_12439906396616333709)],
        &[(0b10010, &ENTRY_JACOBINIZING_5827891129505509789)],
        &[(0b01001, &ENTRY_JACOBINIZATION_12620112081606324932)],
        &[(0b01001, &ENTRY_JACOBINIZE_5488043839092421303)],
        &[(0b01001, &ENTRY_JACOBINIZED_16734740525018333391)],
        &[(0b01001, &ENTRY_JACOBINIZES_12439906396616333709)],
        &[(0b01001, &ENTRY_JACOBINIZING_5827891129505509789)],
        &[(0b01001, &ENTRY_JAILER_16794396359446182049)],
        &[(0b01001, &ENTRY_JAILERS_15685267405324816915)],
        &[(0b10010, &ENTRY_JANIZARIES_6121939418222984809)],
        &[(0b10010, &ENTRY_JANIZARY_16123637942103352791)],
        &[(0b01001, &ENTRY_JANIZARIES_6121939418222984809)],
        &[(0b01001, &ENTRY_JANIZARY_16123637942103352791)],
        &[(0b10010, &ENTRY_JAPANIZATION_6491057515566715056)],
        &[(0b10010, &ENTRY_JAPANIZATIONS_10733258963864816943)],
        &[(0b10010, &ENTRY_JAPANIZE_2996326662592191647)],
        &[(0b10010, &ENTRY_JAPANIZED_16699065610857482639)],
        &[(0b10010, &ENTRY_JAPANIZES_14638537624267830566)],
        &[(0b10010, &ENTRY_JAPANIZING_3419333967684428117)],
        &[(0b01001, &ENTRY_JAPANIZATION_6491057515566715056)],
        &[(0b01001, &ENTRY_JAPANIZATIONS_10733258963864816943)],
        &[(0b01001, &ENTRY_JAPANIZE_2996326662592191647)],
        &[(0b01001, &ENTRY_JAPANIZED_16699065610857482639)],
        &[(0b01001, &ENTRY_JAPANIZES_14638537624267830566)],
        &[(0b01001, &ENTRY_JAPANIZING_3419333967684428117)],
        &[(0b10010, &ENTRY_JARGONIZATION_13803541119877702185)],
        &[(0b10010, &ENTRY_JARGONIZATIONS_6985667935933000202)],
        &[(0b10010, &ENTRY_JARGONIZE_17586054368036140712)],
        &[(0b10010, &ENTRY_JARGONIZED_15791162347082638293)],
        &[(0b10010, &ENTRY_JARGONIZES_4998631633267950571)],
        &[(0b10010, &ENTRY_JARGONIZING_4259002532402415391)],
        &[(0b01001, &ENTRY_JARGONIZATION_13803541119877702185)],
        &[(0b01001, &ENTRY_JARGONIZATIONS_6985667935933000202)],
        &[(0b01001, &ENTRY_JARGONIZE_17586054368036140712)],
        &[(0b01001, &ENTRY_JARGONIZED_15791162347082638293)],
        &[(0b01001, &ENTRY_JARGONIZES_4998631633267950571)],
        &[(0b01001, &ENTRY_JARGONIZING_4259002532402415391)],
        &[(0b10010, &ENTRY_JASPERIZE_15228065557735283312)],
        &[(0b10010, &ENTRY_JASPERIZED_9097196520965048273)],
        &[(0b10010, &ENTRY_JASPERIZES_9601062795594168200)],
        &[(0b10010, &ENTRY_JASPERIZING_15834223553296081409)],
        &[(0b01001, &ENTRY_JASPERIZE_15228065557735283312)],
        &[(0b01001, &ENTRY_JASPERIZED_9097196520965048273)],
        &[(0b01001, &ENTRY_JASPERIZES_9601062795594168200)],
        &[(0b01001, &ENTRY_JASPERIZING_15834223553296081409)],
    ],
    range: 4..=12,
};

static VARS_I_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_I_CHILDREN),
    value: None,
};

static VARS_I_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_IC_NODE),
    Some(&VARS_ID_NODE),
    Some(&VARS_IE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IL_NODE),
    Some(&VARS_IM_NODE),
    Some(&VARS_IN_NODE),
    Some(&VARS_IO_NODE),
    Some(&VARS_IP_NODE),
    None,
    Some(&VARS_IR_NODE),
    Some(&VARS_IS_NODE),
    Some(&VARS_IT_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IZ_NODE),
];

static VARS_IZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IZ_CHILDREN),
    value: None,
};

pub static VARS_IZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ing")],
    values: &[&[(0b01001, &ENTRY_IZING_17568077577465584284)]],
    range: 3..=3,
};

static VARS_IT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IT_CHILDREN),
    value: None,
};

pub static VARS_IT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alianisation"),
        dictgen::InsensitiveStr::Ascii("alianisations"),
        dictgen::InsensitiveStr::Ascii("alianise"),
        dictgen::InsensitiveStr::Ascii("alianised"),
        dictgen::InsensitiveStr::Ascii("alianiser"),
        dictgen::InsensitiveStr::Ascii("alianisers"),
        dictgen::InsensitiveStr::Ascii("alianises"),
        dictgen::InsensitiveStr::Ascii("alianising"),
        dictgen::InsensitiveStr::Ascii("alianization"),
        dictgen::InsensitiveStr::Ascii("alianizations"),
        dictgen::InsensitiveStr::Ascii("alianize"),
        dictgen::InsensitiveStr::Ascii("alianized"),
        dictgen::InsensitiveStr::Ascii("alianizer"),
        dictgen::InsensitiveStr::Ascii("alianizers"),
        dictgen::InsensitiveStr::Ascii("alianizes"),
        dictgen::InsensitiveStr::Ascii("alianizing"),
        dictgen::InsensitiveStr::Ascii("alicisation"),
        dictgen::InsensitiveStr::Ascii("alicisations"),
        dictgen::InsensitiveStr::Ascii("alicise"),
        dictgen::InsensitiveStr::Ascii("alicised"),
        dictgen::InsensitiveStr::Ascii("alicises"),
        dictgen::InsensitiveStr::Ascii("alicising"),
        dictgen::InsensitiveStr::Ascii("alicization"),
        dictgen::InsensitiveStr::Ascii("alicizations"),
        dictgen::InsensitiveStr::Ascii("alicize"),
        dictgen::InsensitiveStr::Ascii("alicized"),
        dictgen::InsensitiveStr::Ascii("alicizes"),
        dictgen::InsensitiveStr::Ascii("alicizing"),
        dictgen::InsensitiveStr::Ascii("emisation"),
        dictgen::InsensitiveStr::Ascii("emisations"),
        dictgen::InsensitiveStr::Ascii("emise"),
        dictgen::InsensitiveStr::Ascii("emised"),
        dictgen::InsensitiveStr::Ascii("emiser"),
        dictgen::InsensitiveStr::Ascii("emisers"),
        dictgen::InsensitiveStr::Ascii("emises"),
        dictgen::InsensitiveStr::Ascii("emising"),
        dictgen::InsensitiveStr::Ascii("emization"),
        dictgen::InsensitiveStr::Ascii("emizations"),
        dictgen::InsensitiveStr::Ascii("emize"),
        dictgen::InsensitiveStr::Ascii("emized"),
        dictgen::InsensitiveStr::Ascii("emizer"),
        dictgen::InsensitiveStr::Ascii("emizers"),
        dictgen::InsensitiveStr::Ascii("emizes"),
        dictgen::InsensitiveStr::Ascii("emizing"),
        dictgen::InsensitiveStr::Ascii("uraean"),
        dictgen::InsensitiveStr::Ascii("uraeans"),
        dictgen::InsensitiveStr::Ascii("urean"),
        dictgen::InsensitiveStr::Ascii("ureans"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ITALIANIZATION_14250016015990552361)],
        &[(0b10010, &ENTRY_ITALIANIZATIONS_10474942165716231128)],
        &[(0b10010, &ENTRY_ITALIANIZE_7918264133057804472)],
        &[(0b10010, &ENTRY_ITALIANIZED_10760695417857256941)],
        &[(0b10010, &ENTRY_ITALIANIZER_2672999761166439124)],
        &[(0b10010, &ENTRY_ITALIANIZERS_11063192194163579764)],
        &[(0b10010, &ENTRY_ITALIANIZES_8123053655370321631)],
        &[(0b10010, &ENTRY_ITALIANIZING_2433552009640661421)],
        &[(0b01001, &ENTRY_ITALIANIZATION_14250016015990552361)],
        &[(0b01001, &ENTRY_ITALIANIZATIONS_10474942165716231128)],
        &[(0b01001, &ENTRY_ITALIANIZE_7918264133057804472)],
        &[(0b01001, &ENTRY_ITALIANIZED_10760695417857256941)],
        &[(0b01001, &ENTRY_ITALIANIZER_2672999761166439124)],
        &[(0b01001, &ENTRY_ITALIANIZERS_11063192194163579764)],
        &[(0b01001, &ENTRY_ITALIANIZES_8123053655370321631)],
        &[(0b01001, &ENTRY_ITALIANIZING_2433552009640661421)],
        &[(0b10010, &ENTRY_ITALICIZATION_7637072269958036418)],
        &[(0b10010, &ENTRY_ITALICIZATIONS_8504692545843995442)],
        &[(0b10010, &ENTRY_ITALICIZE_13351991321688846658)],
        &[(0b10010, &ENTRY_ITALICIZED_18008158115597569175)],
        &[(0b10010, &ENTRY_ITALICIZES_14940618929368461253)],
        &[(0b10010, &ENTRY_ITALICIZING_14716378013800458429)],
        &[(0b01001, &ENTRY_ITALICIZATION_7637072269958036418)],
        &[(0b01001, &ENTRY_ITALICIZATIONS_8504692545843995442)],
        &[(0b01001, &ENTRY_ITALICIZE_13351991321688846658)],
        &[(0b01001, &ENTRY_ITALICIZED_18008158115597569175)],
        &[(0b01001, &ENTRY_ITALICIZES_14940618929368461253)],
        &[(0b01001, &ENTRY_ITALICIZING_14716378013800458429)],
        &[(0b10010, &ENTRY_ITEMIZATION_2083084966275745571)],
        &[(0b10010, &ENTRY_ITEMIZATIONS_6647254086503275130)],
        &[(0b10010, &ENTRY_ITEMIZE_1075679219292232313)],
        &[(0b10010, &ENTRY_ITEMIZED_72220609705553029)],
        &[(0b10010, &ENTRY_ITEMIZER_7796142704743741765)],
        &[(0b10010, &ENTRY_ITEMIZERS_15813642202533812081)],
        &[(0b10010, &ENTRY_ITEMIZES_9916875436104019879)],
        &[(0b10010, &ENTRY_ITEMIZING_2983331397312369622)],
        &[(0b01001, &ENTRY_ITEMIZATION_2083084966275745571)],
        &[(0b01001, &ENTRY_ITEMIZATIONS_6647254086503275130)],
        &[(0b01001, &ENTRY_ITEMIZE_1075679219292232313)],
        &[(0b01001, &ENTRY_ITEMIZED_72220609705553029)],
        &[(0b01001, &ENTRY_ITEMIZER_7796142704743741765)],
        &[(0b01001, &ENTRY_ITEMIZERS_15813642202533812081)],
        &[(0b01001, &ENTRY_ITEMIZES_9916875436104019879)],
        &[(0b01001, &ENTRY_ITEMIZING_2983331397312369622)],
        &[(0b11010, &ENTRY_ITUREAN_913167053546568742)],
        &[(0b11010, &ENTRY_ITUREANS_10856642442618574214)],
        &[(0b00001, &ENTRY_ITUREAN_913167053546568742)],
        &[(0b00001, &ENTRY_ITUREANS_10856642442618574214)],
    ],
    range: 5..=13,
};

static VARS_IS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IS_CHILDREN),
    value: None,
};

pub static VARS_IS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chaemia"),
        dictgen::InsensitiveStr::Ascii("chaemias"),
        dictgen::InsensitiveStr::Ascii("chaemic"),
        dictgen::InsensitiveStr::Ascii("chemia"),
        dictgen::InsensitiveStr::Ascii("chemias"),
        dictgen::InsensitiveStr::Ascii("chemic"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("lamicise"),
        dictgen::InsensitiveStr::Ascii("lamicised"),
        dictgen::InsensitiveStr::Ascii("lamicises"),
        dictgen::InsensitiveStr::Ascii("lamicising"),
        dictgen::InsensitiveStr::Ascii("lamicize"),
        dictgen::InsensitiveStr::Ascii("lamicized"),
        dictgen::InsensitiveStr::Ascii("lamicizes"),
        dictgen::InsensitiveStr::Ascii("lamicizing"),
        dictgen::InsensitiveStr::Ascii("lamisation"),
        dictgen::InsensitiveStr::Ascii("lamisations"),
        dictgen::InsensitiveStr::Ascii("lamise"),
        dictgen::InsensitiveStr::Ascii("lamised"),
        dictgen::InsensitiveStr::Ascii("lamises"),
        dictgen::InsensitiveStr::Ascii("lamising"),
        dictgen::InsensitiveStr::Ascii("lamization"),
        dictgen::InsensitiveStr::Ascii("lamizations"),
        dictgen::InsensitiveStr::Ascii("lamize"),
        dictgen::InsensitiveStr::Ascii("lamized"),
        dictgen::InsensitiveStr::Ascii("lamizes"),
        dictgen::InsensitiveStr::Ascii("lamizing"),
        dictgen::InsensitiveStr::Ascii("ochronisation"),
        dictgen::InsensitiveStr::Ascii("ochronise"),
        dictgen::InsensitiveStr::Ascii("ochronised"),
        dictgen::InsensitiveStr::Ascii("ochronises"),
        dictgen::InsensitiveStr::Ascii("ochronising"),
        dictgen::InsensitiveStr::Ascii("ochronization"),
        dictgen::InsensitiveStr::Ascii("ochronize"),
        dictgen::InsensitiveStr::Ascii("ochronized"),
        dictgen::InsensitiveStr::Ascii("ochronizes"),
        dictgen::InsensitiveStr::Ascii("ochronizing"),
        dictgen::InsensitiveStr::Ascii("oimmunisation"),
        dictgen::InsensitiveStr::Ascii("oimmunisations"),
        dictgen::InsensitiveStr::Ascii("oimmunise"),
        dictgen::InsensitiveStr::Ascii("oimmunises"),
        dictgen::InsensitiveStr::Ascii("oimmunization"),
        dictgen::InsensitiveStr::Ascii("oimmunizations"),
        dictgen::InsensitiveStr::Ascii("oimmunize"),
        dictgen::InsensitiveStr::Ascii("oimmunizes"),
        dictgen::InsensitiveStr::Ascii("omerisation"),
        dictgen::InsensitiveStr::Ascii("omerisations"),
        dictgen::InsensitiveStr::Ascii("omerise"),
        dictgen::InsensitiveStr::Ascii("omerised"),
        dictgen::InsensitiveStr::Ascii("omerises"),
        dictgen::InsensitiveStr::Ascii("omerising"),
        dictgen::InsensitiveStr::Ascii("omerization"),
        dictgen::InsensitiveStr::Ascii("omerizations"),
        dictgen::InsensitiveStr::Ascii("omerize"),
        dictgen::InsensitiveStr::Ascii("omerized"),
        dictgen::InsensitiveStr::Ascii("omerizes"),
        dictgen::InsensitiveStr::Ascii("omerizing"),
        dictgen::InsensitiveStr::Ascii("raelitise"),
        dictgen::InsensitiveStr::Ascii("raelitises"),
        dictgen::InsensitiveStr::Ascii("raelitize"),
        dictgen::InsensitiveStr::Ascii("raelitizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ISCHEMIA_10554201921415637717)],
        &[(0b10010, &ENTRY_ISCHEMIAS_9916394730153752763)],
        &[(0b10010, &ENTRY_ISCHEMIC_2442996153770242671)],
        &[(0b11001, &ENTRY_ISCHEMIA_10554201921415637717)],
        &[(0b11001, &ENTRY_ISCHEMIAS_9916394730153752763)],
        &[(0b11001, &ENTRY_ISCHEMIC_2442996153770242671)],
        &[(0b10010, &ENTRY_IZING_17568077577465584284)],
        &[(0b10010, &ENTRY_ISLAMICIZE_7735780420905674726)],
        &[(0b10010, &ENTRY_ISLAMICIZED_18380651844723736945)],
        &[(0b10010, &ENTRY_ISLAMICIZES_6531803858717004235)],
        &[(0b10010, &ENTRY_ISLAMICIZING_15651039107985160416)],
        &[(0b01001, &ENTRY_ISLAMICIZE_7735780420905674726)],
        &[(0b01001, &ENTRY_ISLAMICIZED_18380651844723736945)],
        &[(0b01001, &ENTRY_ISLAMICIZES_6531803858717004235)],
        &[(0b01001, &ENTRY_ISLAMICIZING_15651039107985160416)],
        &[(0b10010, &ENTRY_ISLAMIZATION_5161145827363720674)],
        &[(0b10010, &ENTRY_ISLAMIZATIONS_9381105898108737278)],
        &[(0b10010, &ENTRY_ISLAMIZE_10031573866824775797)],
        &[(0b10010, &ENTRY_ISLAMIZED_15758879196999391070)],
        &[(0b10010, &ENTRY_ISLAMIZES_367713927834001617)],
        &[(0b10010, &ENTRY_ISLAMIZING_18257296169100318444)],
        &[(0b01001, &ENTRY_ISLAMIZATION_5161145827363720674)],
        &[(0b01001, &ENTRY_ISLAMIZATIONS_9381105898108737278)],
        &[(0b01001, &ENTRY_ISLAMIZE_10031573866824775797)],
        &[(0b01001, &ENTRY_ISLAMIZED_15758879196999391070)],
        &[(0b01001, &ENTRY_ISLAMIZES_367713927834001617)],
        &[(0b01001, &ENTRY_ISLAMIZING_18257296169100318444)],
        &[(0b10010, &ENTRY_ISOCHRONIZATION_6483472804939717463)],
        &[(0b10010, &ENTRY_ISOCHRONIZE_14918820840136762657)],
        &[(0b10010, &ENTRY_ISOCHRONIZED_2637250779429085922)],
        &[(0b10010, &ENTRY_ISOCHRONIZES_1872858779043339096)],
        &[(0b10010, &ENTRY_ISOCHRONIZING_8854802670752531573)],
        &[(0b01001, &ENTRY_ISOCHRONIZATION_6483472804939717463)],
        &[(0b01001, &ENTRY_ISOCHRONIZE_14918820840136762657)],
        &[(0b01001, &ENTRY_ISOCHRONIZED_2637250779429085922)],
        &[(0b01001, &ENTRY_ISOCHRONIZES_1872858779043339096)],
        &[(0b01001, &ENTRY_ISOCHRONIZING_8854802670752531573)],
        &[(0b10010, &ENTRY_ISOIMMUNIZATION_6552840998782404550)],
        &[(0b10010, &ENTRY_ISOIMMUNIZATIONS_4834172440028031413)],
        &[(0b10010, &ENTRY_ISOIMMUNIZE_8748728447679167149)],
        &[(0b10010, &ENTRY_ISOIMMUNIZES_1487221929616437869)],
        &[(0b01001, &ENTRY_ISOIMMUNIZATION_6552840998782404550)],
        &[(0b01001, &ENTRY_ISOIMMUNIZATIONS_4834172440028031413)],
        &[(0b01001, &ENTRY_ISOIMMUNIZE_8748728447679167149)],
        &[(0b01001, &ENTRY_ISOIMMUNIZES_1487221929616437869)],
        &[(0b10010, &ENTRY_ISOMERIZATION_3238007314114624559)],
        &[(0b10010, &ENTRY_ISOMERIZATIONS_15721561442741022660)],
        &[(0b10010, &ENTRY_ISOMERIZE_16508288804812196036)],
        &[(0b10010, &ENTRY_ISOMERIZED_1507665941808946263)],
        &[(0b10010, &ENTRY_ISOMERIZES_13699385029679805302)],
        &[(0b10010, &ENTRY_ISOMERIZING_15692416232400028339)],
        &[(0b01001, &ENTRY_ISOMERIZATION_3238007314114624559)],
        &[(0b01001, &ENTRY_ISOMERIZATIONS_15721561442741022660)],
        &[(0b01001, &ENTRY_ISOMERIZE_16508288804812196036)],
        &[(0b01001, &ENTRY_ISOMERIZED_1507665941808946263)],
        &[(0b01001, &ENTRY_ISOMERIZES_13699385029679805302)],
        &[(0b01001, &ENTRY_ISOMERIZING_15692416232400028339)],
        &[(0b10010, &ENTRY_ISRAELITIZE_3246052146927689302)],
        &[(0b10010, &ENTRY_ISRAELITIZES_11908037988878925722)],
        &[(0b01001, &ENTRY_ISRAELITIZE_3246052146927689302)],
        &[(0b01001, &ENTRY_ISRAELITIZES_11908037988878925722)],
    ],
    range: 3..=14,
};

static VARS_IR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IR_CHILDREN),
    value: None,
};

pub static VARS_IR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizing"),
        dictgen::InsensitiveStr::Ascii("idectomise"),
        dictgen::InsensitiveStr::Ascii("idectomised"),
        dictgen::InsensitiveStr::Ascii("idectomising"),
        dictgen::InsensitiveStr::Ascii("idectomize"),
        dictgen::InsensitiveStr::Ascii("idectomized"),
        dictgen::InsensitiveStr::Ascii("idectomizing"),
        dictgen::InsensitiveStr::Ascii("idisation"),
        dictgen::InsensitiveStr::Ascii("idisations"),
        dictgen::InsensitiveStr::Ascii("idise"),
        dictgen::InsensitiveStr::Ascii("idised"),
        dictgen::InsensitiveStr::Ascii("idises"),
        dictgen::InsensitiveStr::Ascii("idising"),
        dictgen::InsensitiveStr::Ascii("idization"),
        dictgen::InsensitiveStr::Ascii("idizations"),
        dictgen::InsensitiveStr::Ascii("idize"),
        dictgen::InsensitiveStr::Ascii("idized"),
        dictgen::InsensitiveStr::Ascii("idizes"),
        dictgen::InsensitiveStr::Ascii("idizing"),
        dictgen::InsensitiveStr::Ascii("ishise"),
        dictgen::InsensitiveStr::Ascii("ishised"),
        dictgen::InsensitiveStr::Ascii("ishises"),
        dictgen::InsensitiveStr::Ascii("ishising"),
        dictgen::InsensitiveStr::Ascii("ishize"),
        dictgen::InsensitiveStr::Ascii("ishized"),
        dictgen::InsensitiveStr::Ascii("ishizes"),
        dictgen::InsensitiveStr::Ascii("ishizing"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("rationalise"),
        dictgen::InsensitiveStr::Ascii("rationalised"),
        dictgen::InsensitiveStr::Ascii("rationalises"),
        dictgen::InsensitiveStr::Ascii("rationalising"),
        dictgen::InsensitiveStr::Ascii("rationalize"),
        dictgen::InsensitiveStr::Ascii("rationalized"),
        dictgen::InsensitiveStr::Ascii("rationalizes"),
        dictgen::InsensitiveStr::Ascii("rationalizing"),
        dictgen::InsensitiveStr::Ascii("realisable"),
        dictgen::InsensitiveStr::Ascii("realizable"),
        dictgen::InsensitiveStr::Ascii("recognisable"),
        dictgen::InsensitiveStr::Ascii("recognizable"),
        dictgen::InsensitiveStr::Ascii("regularise"),
        dictgen::InsensitiveStr::Ascii("regularises"),
        dictgen::InsensitiveStr::Ascii("regularize"),
        dictgen::InsensitiveStr::Ascii("regularizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IRANIZE_16097053982564268585)],
        &[(0b10010, &ENTRY_IRANIZES_68228530325041736)],
        &[(0b01001, &ENTRY_IRANIZE_16097053982564268585)],
        &[(0b01001, &ENTRY_IRANIZES_68228530325041736)],
        &[(0b11010, &ENTRY_IER_15235430992881202856)],
        &[(0b10010, &ENTRY_IRICIZE_13420716537315253439)],
        &[(0b10010, &ENTRY_IRICIZED_3558520207738706190)],
        &[(0b10010, &ENTRY_IRICIZING_6592551583850585470)],
        &[(0b01001, &ENTRY_IRICIZE_13420716537315253439)],
        &[(0b01001, &ENTRY_IRICIZED_3558520207738706190)],
        &[(0b01001, &ENTRY_IRICIZING_6592551583850585470)],
        &[(0b10010, &ENTRY_IRIDECTOMIZE_14800091260065604008)],
        &[(0b10010, &ENTRY_IRIDECTOMIZED_5854155027181535016)],
        &[(0b10010, &ENTRY_IRIDECTOMIZING_8902043056320366009)],
        &[(0b01001, &ENTRY_IRIDECTOMIZE_14800091260065604008)],
        &[(0b01001, &ENTRY_IRIDECTOMIZED_5854155027181535016)],
        &[(0b01001, &ENTRY_IRIDECTOMIZING_8902043056320366009)],
        &[(0b10010, &ENTRY_IRIDIZATION_7181298283830728332)],
        &[(0b10010, &ENTRY_IRIDIZATIONS_4735971979530479099)],
        &[(0b10010, &ENTRY_IRIDIZE_6299505185614291769)],
        &[(0b10010, &ENTRY_IRIDIZED_8119592807478143588)],
        &[(0b10010, &ENTRY_IRIDIZES_7904221985039237377)],
        &[(0b10010, &ENTRY_IRIDIZING_9856895728412037323)],
        &[(0b01001, &ENTRY_IRIDIZATION_7181298283830728332)],
        &[(0b01001, &ENTRY_IRIDIZATIONS_4735971979530479099)],
        &[(0b01001, &ENTRY_IRIDIZE_6299505185614291769)],
        &[(0b01001, &ENTRY_IRIDIZED_8119592807478143588)],
        &[(0b01001, &ENTRY_IRIDIZES_7904221985039237377)],
        &[(0b01001, &ENTRY_IRIDIZING_9856895728412037323)],
        &[(0b10010, &ENTRY_IRISHIZE_8208979161436390733)],
        &[(0b10010, &ENTRY_IRISHIZED_16512539711227053972)],
        &[(0b10010, &ENTRY_IRISHIZES_17227074225879136075)],
        &[(0b10010, &ENTRY_IRISHIZING_6073346360037358565)],
        &[(0b01001, &ENTRY_IRISHIZE_8208979161436390733)],
        &[(0b01001, &ENTRY_IRISHIZED_16512539711227053972)],
        &[(0b01001, &ENTRY_IRISHIZES_17227074225879136075)],
        &[(0b01001, &ENTRY_IRISHIZING_6073346360037358565)],
        &[(0b10010, &ENTRY_IRONIZE_17130349938134447427)],
        &[(0b10010, &ENTRY_IRONIZED_12346354122830372870)],
        &[(0b10010, &ENTRY_IRONIZES_13827125916393146079)],
        &[(0b10010, &ENTRY_IRONIZING_1675961958393611973)],
        &[(0b01001, &ENTRY_IRONIZE_17130349938134447427)],
        &[(0b01001, &ENTRY_IRONIZED_12346354122830372870)],
        &[(0b01001, &ENTRY_IRONIZES_13827125916393146079)],
        &[(0b01001, &ENTRY_IRONIZING_1675961958393611973)],
        &[(0b10010, &ENTRY_IRRATIONALIZE_4790151684217192380)],
        &[(0b10010, &ENTRY_IRRATIONALIZED_4894371714487406565)],
        &[(0b10010, &ENTRY_IRRATIONALIZES_11632524485207866679)],
        &[(0b10010, &ENTRY_IRRATIONALIZING_9204654902470879187)],
        &[(0b01001, &ENTRY_IRRATIONALIZE_4790151684217192380)],
        &[(0b01001, &ENTRY_IRRATIONALIZED_4894371714487406565)],
        &[(0b01001, &ENTRY_IRRATIONALIZES_11632524485207866679)],
        &[(0b01001, &ENTRY_IRRATIONALIZING_9204654902470879187)],
        &[(0b10010, &ENTRY_IRREALIZABLE_15796792683122916865)],
        &[(0b01001, &ENTRY_IRREALIZABLE_15796792683122916865)],
        &[(0b10010, &ENTRY_IRRECOGNIZABLE_3060885004389452161)],
        &[(0b01001, &ENTRY_IRRECOGNIZABLE_3060885004389452161)],
        &[(0b10010, &ENTRY_IRREGULARIZE_5521004822910043625)],
        &[(0b10010, &ENTRY_IRREGULARIZES_4400387657632970784)],
        &[(0b01001, &ENTRY_IRREGULARIZE_5521004822910043625)],
        &[(0b01001, &ENTRY_IRREGULARIZES_4400387657632970784)],
    ],
    range: 1..=13,
};

static VARS_IP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IP_CHILDREN),
    value: None,
};

pub static VARS_IP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hinoae"),
        dictgen::InsensitiveStr::Ascii("hinoe"),
        dictgen::InsensitiveStr::Ascii("omea"),
        dictgen::InsensitiveStr::Ascii("omoea"),
    ],
    values: &[
        &[(0b11010, &ENTRY_IPHINOE_10820574830726341241)],
        &[(0b00001, &ENTRY_IPHINOE_10820574830726341241)],
        &[(0b10001, &ENTRY_IPOMEA_6176464903246802743)],
        &[(0b11010, &ENTRY_IPOMEA_6176464903246802743)],
    ],
    range: 4..=6,
};

static VARS_IO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IO_CHILDREN),
    value: None,
};

pub static VARS_IO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("disation"),
        dictgen::InsensitiveStr::Ascii("dise"),
        dictgen::InsensitiveStr::Ascii("dised"),
        dictgen::InsensitiveStr::Ascii("diser"),
        dictgen::InsensitiveStr::Ascii("disers"),
        dictgen::InsensitiveStr::Ascii("dises"),
        dictgen::InsensitiveStr::Ascii("dising"),
        dictgen::InsensitiveStr::Ascii("dization"),
        dictgen::InsensitiveStr::Ascii("dize"),
        dictgen::InsensitiveStr::Ascii("dized"),
        dictgen::InsensitiveStr::Ascii("dizer"),
        dictgen::InsensitiveStr::Ascii("dizers"),
        dictgen::InsensitiveStr::Ascii("dizes"),
        dictgen::InsensitiveStr::Ascii("dizing"),
        dictgen::InsensitiveStr::Ascii("nicisation"),
        dictgen::InsensitiveStr::Ascii("nicisations"),
        dictgen::InsensitiveStr::Ascii("nicise"),
        dictgen::InsensitiveStr::Ascii("nicised"),
        dictgen::InsensitiveStr::Ascii("nicises"),
        dictgen::InsensitiveStr::Ascii("nicising"),
        dictgen::InsensitiveStr::Ascii("nicization"),
        dictgen::InsensitiveStr::Ascii("nicizations"),
        dictgen::InsensitiveStr::Ascii("nicize"),
        dictgen::InsensitiveStr::Ascii("nicized"),
        dictgen::InsensitiveStr::Ascii("nicizes"),
        dictgen::InsensitiveStr::Ascii("nicizing"),
        dictgen::InsensitiveStr::Ascii("nisable"),
        dictgen::InsensitiveStr::Ascii("nisabler"),
        dictgen::InsensitiveStr::Ascii("nisables"),
        dictgen::InsensitiveStr::Ascii("nisablest"),
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nisings"),
        dictgen::InsensitiveStr::Ascii("nision"),
        dictgen::InsensitiveStr::Ascii("nisions"),
        dictgen::InsensitiveStr::Ascii("nizable"),
        dictgen::InsensitiveStr::Ascii("nizabler"),
        dictgen::InsensitiveStr::Ascii("nizables"),
        dictgen::InsensitiveStr::Ascii("nizablest"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
        dictgen::InsensitiveStr::Ascii("nizings"),
        dictgen::InsensitiveStr::Ascii("nizion"),
        dictgen::InsensitiveStr::Ascii("nizions"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IODIZATION_7852412987887174351)],
        &[(0b10010, &ENTRY_IODIZE_1306425172808849701)],
        &[(0b10010, &ENTRY_IODIZED_5589078459430909426)],
        &[(0b10010, &ENTRY_IODIZER_1540933078597474373)],
        &[(0b10010, &ENTRY_IODIZERS_1535695457797432568)],
        &[(0b10010, &ENTRY_IODIZES_6118120030788983283)],
        &[(0b10010, &ENTRY_IODIZING_930016750218813133)],
        &[(0b01001, &ENTRY_IODIZATION_7852412987887174351)],
        &[(0b01001, &ENTRY_IODIZE_1306425172808849701)],
        &[(0b01001, &ENTRY_IODIZED_5589078459430909426)],
        &[(0b01001, &ENTRY_IODIZER_1540933078597474373)],
        &[(0b01001, &ENTRY_IODIZERS_1535695457797432568)],
        &[(0b01001, &ENTRY_IODIZES_6118120030788983283)],
        &[(0b01001, &ENTRY_IODIZING_930016750218813133)],
        &[(0b10010, &ENTRY_IONICIZATION_8114160155312209553)],
        &[(0b10010, &ENTRY_IONICIZATIONS_1024474224969699416)],
        &[(0b10010, &ENTRY_IONICIZE_17749931681916567842)],
        &[(0b10010, &ENTRY_IONICIZED_10948195635909827159)],
        &[(0b10010, &ENTRY_IONICIZES_12301869180645911206)],
        &[(0b10010, &ENTRY_IONICIZING_9793219008400567780)],
        &[(0b01001, &ENTRY_IONICIZATION_8114160155312209553)],
        &[(0b01001, &ENTRY_IONICIZATIONS_1024474224969699416)],
        &[(0b01001, &ENTRY_IONICIZE_17749931681916567842)],
        &[(0b01001, &ENTRY_IONICIZED_10948195635909827159)],
        &[(0b01001, &ENTRY_IONICIZES_12301869180645911206)],
        &[(0b01001, &ENTRY_IONICIZING_9793219008400567780)],
        &[(0b10010, &ENTRY_IONIZABLE_2644993999701298176)],
        &[(0b10010, &ENTRY_IONIZABLER_16464484515284442321)],
        &[(0b10010, &ENTRY_IONIZABLES_8313950107455257059)],
        &[(0b10010, &ENTRY_IONIZABLEST_11814301960561543823)],
        &[(0b10010, &ENTRY_IONIZATION_8191072411043319491)],
        &[(0b10010, &ENTRY_IONIZATIONS_13158526918879542436)],
        &[(0b10010, &ENTRY_IONIZE_7165534751673675076)],
        &[(0b10010, &ENTRY_IONIZED_2589085332884313053)],
        &[(0b10010, &ENTRY_IONIZER_16865151505607853304)],
        &[(0b10010, &ENTRY_IONIZERS_17432893927149158571)],
        &[(0b10010, &ENTRY_IONIZES_10700550406719206692)],
        &[(0b10010, &ENTRY_IONIZING_6475308404816427379)],
        &[(0b10010, &ENTRY_IONIZINGS_654410480601582690)],
        &[(0b10010, &ENTRY_IONIZION_9972155122605885625)],
        &[(0b10010, &ENTRY_IONIZIONS_997469529664998632)],
        &[(0b01001, &ENTRY_IONIZABLE_2644993999701298176)],
        &[(0b01001, &ENTRY_IONIZABLER_16464484515284442321)],
        &[(0b01001, &ENTRY_IONIZABLES_8313950107455257059)],
        &[(0b01001, &ENTRY_IONIZABLEST_11814301960561543823)],
        &[(0b01001, &ENTRY_IONIZATION_8191072411043319491)],
        &[(0b01001, &ENTRY_IONIZATIONS_13158526918879542436)],
        &[(0b01001, &ENTRY_IONIZE_7165534751673675076)],
        &[(0b01001, &ENTRY_IONIZED_2589085332884313053)],
        &[(0b01001, &ENTRY_IONIZES_10700550406719206692)],
        &[(0b01001, &ENTRY_IONIZING_6475308404816427379)],
        &[(0b01001, &ENTRY_IONIZINGS_654410480601582690)],
        &[(0b01001, &ENTRY_IONIZION_9972155122605885625)],
        &[(0b01001, &ENTRY_IONIZIONS_997469529664998632)],
    ],
    range: 4..=11,
};

static VARS_IN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_IN_CHILDREN),
    value: None,
};

static VARS_IN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_INA_NODE),
    None,
    Some(&VARS_INC_NODE),
    Some(&VARS_IND_NODE),
    Some(&VARS_INE_NODE),
    Some(&VARS_INF_NODE),
    Some(&VARS_ING_NODE),
    Some(&VARS_INH_NODE),
    Some(&VARS_INI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_INO_NODE),
    None,
    None,
    None,
    Some(&VARS_INS_NODE),
    Some(&VARS_INT_NODE),
    None,
    Some(&VARS_INV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_INV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INV_CHILDREN),
    value: None,
};

pub static VARS_INV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("igor"),
        dictgen::InsensitiveStr::Ascii("igour"),
    ],
    values: &[
        &[(0b10001, &ENTRY_INVIGOR_819999460986594740)],
        &[(0b11010, &ENTRY_INVIGOR_819999460986594740)],
    ],
    range: 4..=5,
};

static VARS_INT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_INT_CHILDREN),
    value: None,
};

static VARS_INT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_INTE_NODE),
    None,
    None,
    Some(&VARS_INTH_NODE),
    Some(&VARS_INTI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_INTR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_INTR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTR_CHILDREN),
    value: None,
};

pub static VARS_INTR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aorganisation"),
        dictgen::InsensitiveStr::Ascii("aorganisations"),
        dictgen::InsensitiveStr::Ascii("aorganization"),
        dictgen::InsensitiveStr::Ascii("aorganizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTRAORGANIZATION_16469167469278073028)],
        &[(0b10010, &ENTRY_INTRAORGANIZATIONS_17967234739758363124)],
        &[(0b01001, &ENTRY_INTRAORGANIZATION_16469167469278073028)],
        &[(0b01001, &ENTRY_INTRAORGANIZATIONS_17967234739758363124)],
    ],
    range: 13..=14,
};

static VARS_INTI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTI_CHILDREN),
    value: None,
};

pub static VARS_INTI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mae"),
        dictgen::InsensitiveStr::Ascii("me"),
    ],
    values: &[
        &[(0b11010, &ENTRY_INTIME_5742590895735721416)],
        &[(0b00001, &ENTRY_INTIME_5742590895735721416)],
    ],
    range: 2..=3,
};

static VARS_INTH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTH_CHILDREN),
    value: None,
};

pub static VARS_INTH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rall"),
        dictgen::InsensitiveStr::Ascii("ralled"),
        dictgen::InsensitiveStr::Ascii("ralling"),
        dictgen::InsensitiveStr::Ascii("ralls"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ENTHRALL_5942778214277993445)],
        &[(0b11010, &ENTRY_ENTHRALLED_11841948867063911915)],
        &[(0b11010, &ENTRY_ENTHRALLING_1804014087037406105)],
        &[(0b10010, &ENTRY_ENTHRALLS_4931585169072696150)],
    ],
    range: 4..=7,
};

static VARS_INTE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_INTE_CHILDREN),
    value: None,
};

static VARS_INTE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_INTEG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_INTEL_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_INTER_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_INTER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_INTER_CHILDREN),
    value: None,
};

static VARS_INTER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_INTERC_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_INTERH_NODE),
    Some(&VARS_INTERI_NODE),
    Some(&VARS_INTERJ_NODE),
    None,
    None,
    None,
    Some(&VARS_INTERN_NODE),
    Some(&VARS_INTERO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_INTERO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTERO_CHILDREN),
    value: None,
};

pub static VARS_INTERO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rganisational"),
        dictgen::InsensitiveStr::Ascii("rganizational"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTERORGANIZATIONAL_7529374351884504219)],
        &[(0b01001, &ENTRY_INTERORGANIZATIONAL_7529374351884504219)],
    ],
    range: 13..=13,
};

static VARS_INTERN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTERN_CHILDREN),
    value: None,
};

pub static VARS_INTERN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("ationalisation"),
        dictgen::InsensitiveStr::Ascii("ationalisations"),
        dictgen::InsensitiveStr::Ascii("ationalise"),
        dictgen::InsensitiveStr::Ascii("ationalised"),
        dictgen::InsensitiveStr::Ascii("ationalises"),
        dictgen::InsensitiveStr::Ascii("ationalising"),
        dictgen::InsensitiveStr::Ascii("ationalization"),
        dictgen::InsensitiveStr::Ascii("ationalizations"),
        dictgen::InsensitiveStr::Ascii("ationalize"),
        dictgen::InsensitiveStr::Ascii("ationalized"),
        dictgen::InsensitiveStr::Ascii("ationalizes"),
        dictgen::InsensitiveStr::Ascii("ationalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTERNALIZATION_603288853246606634)],
        &[(0b10010, &ENTRY_INTERNALIZATIONS_5057687877137841458)],
        &[(0b10010, &ENTRY_INTERNALIZE_3793676571111920632)],
        &[(0b10010, &ENTRY_INTERNALIZED_16309550961213758253)],
        &[(0b10010, &ENTRY_INTERNALIZES_13136383420864185970)],
        &[(0b10010, &ENTRY_INTERNALIZING_13806294993771050282)],
        &[(0b01001, &ENTRY_INTERNALIZATION_603288853246606634)],
        &[(0b01001, &ENTRY_INTERNALIZATIONS_5057687877137841458)],
        &[(0b01001, &ENTRY_INTERNALIZE_3793676571111920632)],
        &[(0b01001, &ENTRY_INTERNALIZED_16309550961213758253)],
        &[(0b01001, &ENTRY_INTERNALIZES_13136383420864185970)],
        &[(0b01001, &ENTRY_INTERNALIZING_13806294993771050282)],
        &[(0b10010, &ENTRY_INTERNATIONALIZATION_6644139225428402812)],
        &[(0b10010, &ENTRY_INTERNATIONALIZATIONS_6708926163950225930)],
        &[(0b10010, &ENTRY_INTERNATIONALIZE_10844257627404265374)],
        &[(0b10010, &ENTRY_INTERNATIONALIZED_12532701823222614624)],
        &[(0b10010, &ENTRY_INTERNATIONALIZES_3638667411109828830)],
        &[(0b10010, &ENTRY_INTERNATIONALIZING_1991011473935504392)],
        &[(0b01001, &ENTRY_INTERNATIONALIZATION_6644139225428402812)],
        &[(0b01001, &ENTRY_INTERNATIONALIZATIONS_6708926163950225930)],
        &[(0b01001, &ENTRY_INTERNATIONALIZE_10844257627404265374)],
        &[(0b01001, &ENTRY_INTERNATIONALIZED_12532701823222614624)],
        &[(0b01001, &ENTRY_INTERNATIONALIZES_3638667411109828830)],
        &[(0b01001, &ENTRY_INTERNATIONALIZING_1991011473935504392)],
    ],
    range: 5..=15,
};

static VARS_INTERJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTERJ_CHILDREN),
    value: None,
};

pub static VARS_INTERJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectionalise"),
        dictgen::InsensitiveStr::Ascii("ectionalised"),
        dictgen::InsensitiveStr::Ascii("ectionalises"),
        dictgen::InsensitiveStr::Ascii("ectionalising"),
        dictgen::InsensitiveStr::Ascii("ectionalize"),
        dictgen::InsensitiveStr::Ascii("ectionalized"),
        dictgen::InsensitiveStr::Ascii("ectionalizes"),
        dictgen::InsensitiveStr::Ascii("ectionalizing"),
        dictgen::InsensitiveStr::Ascii("ectionise"),
        dictgen::InsensitiveStr::Ascii("ectionises"),
        dictgen::InsensitiveStr::Ascii("ectionize"),
        dictgen::InsensitiveStr::Ascii("ectionizes"),
        dictgen::InsensitiveStr::Ascii("udgement"),
        dictgen::InsensitiveStr::Ascii("udgements"),
        dictgen::InsensitiveStr::Ascii("udgment"),
        dictgen::InsensitiveStr::Ascii("udgments"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTERJECTIONALIZE_13118177918009055653)],
        &[(0b10010, &ENTRY_INTERJECTIONALIZED_3066085716805350356)],
        &[(0b10010, &ENTRY_INTERJECTIONALIZES_4573160062771210721)],
        &[(0b10010, &ENTRY_INTERJECTIONALIZING_5359472829969423658)],
        &[(0b01001, &ENTRY_INTERJECTIONALIZE_13118177918009055653)],
        &[(0b01001, &ENTRY_INTERJECTIONALIZED_3066085716805350356)],
        &[(0b01001, &ENTRY_INTERJECTIONALIZES_4573160062771210721)],
        &[(0b01001, &ENTRY_INTERJECTIONALIZING_5359472829969423658)],
        &[(0b10010, &ENTRY_INTERJECTIONIZE_9169632213587887120)],
        &[(0b10010, &ENTRY_INTERJECTIONIZES_11959393792338129862)],
        &[(0b01001, &ENTRY_INTERJECTIONIZE_9169632213587887120)],
        &[(0b01001, &ENTRY_INTERJECTIONIZES_11959393792338129862)],
        &[(0b11010, &ENTRY_INTERJUDGMENT_1640083221699385249)],
        &[(0b11010, &ENTRY_INTERJUDGMENTS_2098512032698607985)],
        &[(0b00001, &ENTRY_INTERJUDGMENT_1640083221699385249)],
        &[(0b00001, &ENTRY_INTERJUDGMENTS_2098512032698607985)],
    ],
    range: 7..=13,
};

static VARS_INTERI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTERI_CHILDREN),
    value: None,
};

pub static VARS_INTERI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTERIORIZATION_17483234302135311883)],
        &[(0b10010, &ENTRY_INTERIORIZE_1278621744135628260)],
        &[(0b10010, &ENTRY_INTERIORIZED_6788051806688856581)],
        &[(0b10010, &ENTRY_INTERIORIZES_7201579775546454896)],
        &[(0b10010, &ENTRY_INTERIORIZING_4906116630681746350)],
        &[(0b01001, &ENTRY_INTERIORIZATION_17483234302135311883)],
        &[(0b01001, &ENTRY_INTERIORIZE_1278621744135628260)],
        &[(0b01001, &ENTRY_INTERIORIZED_6788051806688856581)],
        &[(0b01001, &ENTRY_INTERIORIZES_7201579775546454896)],
        &[(0b01001, &ENTRY_INTERIORIZING_4906116630681746350)],
    ],
    range: 5..=9,
};

static VARS_INTERH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTERH_CHILDREN),
    value: None,
};

pub static VARS_INTERH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemal"),
        dictgen::InsensitiveStr::Ascii("emal"),
        dictgen::InsensitiveStr::Ascii("ybridise"),
        dictgen::InsensitiveStr::Ascii("ybridises"),
        dictgen::InsensitiveStr::Ascii("ybridize"),
        dictgen::InsensitiveStr::Ascii("ybridizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_INTERHEMAL_15034494580751452155)],
        &[(0b10001, &ENTRY_INTERHEMAL_15034494580751452155)],
        &[(0b10010, &ENTRY_INTERHYBRIDIZE_668520718186808081)],
        &[(0b10010, &ENTRY_INTERHYBRIDIZES_497894455147107388)],
        &[(0b01001, &ENTRY_INTERHYBRIDIZE_668520718186808081)],
        &[(0b01001, &ENTRY_INTERHYBRIDIZES_497894455147107388)],
    ],
    range: 4..=9,
};

static VARS_INTERC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTERC_CHILDREN),
    value: None,
};

pub static VARS_INTERC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ivilisation"),
        dictgen::InsensitiveStr::Ascii("ivilisations"),
        dictgen::InsensitiveStr::Ascii("ivilization"),
        dictgen::InsensitiveStr::Ascii("ivilizations"),
        dictgen::InsensitiveStr::Ascii("olonisation"),
        dictgen::InsensitiveStr::Ascii("olonisations"),
        dictgen::InsensitiveStr::Ascii("olonization"),
        dictgen::InsensitiveStr::Ascii("olonizations"),
        dictgen::InsensitiveStr::Ascii("rystallisation"),
        dictgen::InsensitiveStr::Ascii("rystallisations"),
        dictgen::InsensitiveStr::Ascii("rystallise"),
        dictgen::InsensitiveStr::Ascii("rystallises"),
        dictgen::InsensitiveStr::Ascii("rystallization"),
        dictgen::InsensitiveStr::Ascii("rystallizations"),
        dictgen::InsensitiveStr::Ascii("rystallize"),
        dictgen::InsensitiveStr::Ascii("rystallizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTERCIVILIZATION_6730243652879059378)],
        &[(0b10010, &ENTRY_INTERCIVILIZATIONS_3542228287854093291)],
        &[(0b01001, &ENTRY_INTERCIVILIZATION_6730243652879059378)],
        &[(0b01001, &ENTRY_INTERCIVILIZATIONS_3542228287854093291)],
        &[(0b10010, &ENTRY_INTERCOLONIZATION_17649422504500509174)],
        &[(0b10010, &ENTRY_INTERCOLONIZATIONS_3566824182005074807)],
        &[(0b01001, &ENTRY_INTERCOLONIZATION_17649422504500509174)],
        &[(0b01001, &ENTRY_INTERCOLONIZATIONS_3566824182005074807)],
        &[(0b10010, &ENTRY_INTERCRYSTALLIZATION_12999096268518190465)],
        &[(0b10010, &ENTRY_INTERCRYSTALLIZATIONS_17753756237124408594)],
        &[(0b10010, &ENTRY_INTERCRYSTALLIZE_14628274758100113148)],
        &[(0b10010, &ENTRY_INTERCRYSTALLIZES_11383858119955128987)],
        &[(0b01001, &ENTRY_INTERCRYSTALLIZATION_12999096268518190465)],
        &[(0b01001, &ENTRY_INTERCRYSTALLIZATIONS_17753756237124408594)],
        &[(0b01001, &ENTRY_INTERCRYSTALLIZE_14628274758100113148)],
        &[(0b01001, &ENTRY_INTERCRYSTALLIZES_11383858119955128987)],
    ],
    range: 10..=15,
};

static VARS_INTEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTEL_CHILDREN),
    value: None,
};

pub static VARS_INTEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lectualisation"),
        dictgen::InsensitiveStr::Ascii("lectualisations"),
        dictgen::InsensitiveStr::Ascii("lectualise"),
        dictgen::InsensitiveStr::Ascii("lectualised"),
        dictgen::InsensitiveStr::Ascii("lectualiser"),
        dictgen::InsensitiveStr::Ascii("lectualisers"),
        dictgen::InsensitiveStr::Ascii("lectualises"),
        dictgen::InsensitiveStr::Ascii("lectualising"),
        dictgen::InsensitiveStr::Ascii("lectualization"),
        dictgen::InsensitiveStr::Ascii("lectualizations"),
        dictgen::InsensitiveStr::Ascii("lectualize"),
        dictgen::InsensitiveStr::Ascii("lectualized"),
        dictgen::InsensitiveStr::Ascii("lectualizer"),
        dictgen::InsensitiveStr::Ascii("lectualizers"),
        dictgen::InsensitiveStr::Ascii("lectualizes"),
        dictgen::InsensitiveStr::Ascii("lectualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTELLECTUALIZATION_5603740918704433815)],
        &[(0b10010, &ENTRY_INTELLECTUALIZATIONS_4063570221687495690)],
        &[(0b10010, &ENTRY_INTELLECTUALIZE_11938342110187123902)],
        &[(0b10010, &ENTRY_INTELLECTUALIZED_1369730666677628659)],
        &[(0b10010, &ENTRY_INTELLECTUALIZER_18038380741729552808)],
        &[(0b10010, &ENTRY_INTELLECTUALIZERS_5257248536965240227)],
        &[(0b10010, &ENTRY_INTELLECTUALIZES_7905351319809097487)],
        &[(0b10010, &ENTRY_INTELLECTUALIZING_11651251432471897085)],
        &[(0b01001, &ENTRY_INTELLECTUALIZATION_5603740918704433815)],
        &[(0b01001, &ENTRY_INTELLECTUALIZATIONS_4063570221687495690)],
        &[(0b01001, &ENTRY_INTELLECTUALIZE_11938342110187123902)],
        &[(0b01001, &ENTRY_INTELLECTUALIZED_1369730666677628659)],
        &[(0b01001, &ENTRY_INTELLECTUALIZER_18038380741729552808)],
        &[(0b01001, &ENTRY_INTELLECTUALIZERS_5257248536965240227)],
        &[(0b01001, &ENTRY_INTELLECTUALIZES_7905351319809097487)],
        &[(0b01001, &ENTRY_INTELLECTUALIZING_11651251432471897085)],
    ],
    range: 10..=15,
};

static VARS_INTEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTEG_CHILDREN),
    value: None,
};

pub static VARS_INTEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ralisation"),
        dictgen::InsensitiveStr::Ascii("ralisations"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralization"),
        dictgen::InsensitiveStr::Ascii("ralizations"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTEGRALIZATION_6109417690368879082)],
        &[(0b10010, &ENTRY_INTEGRALIZATIONS_5667120705219825596)],
        &[(0b10010, &ENTRY_INTEGRALIZE_4916756234988815852)],
        &[(0b10010, &ENTRY_INTEGRALIZES_9034345402956567798)],
        &[(0b01001, &ENTRY_INTEGRALIZATION_6109417690368879082)],
        &[(0b01001, &ENTRY_INTEGRALIZATIONS_5667120705219825596)],
        &[(0b01001, &ENTRY_INTEGRALIZE_4916756234988815852)],
        &[(0b01001, &ENTRY_INTEGRALIZES_9034345402956567798)],
    ],
    range: 6..=11,
};

static VARS_INS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INS_CHILDREN),
    value: None,
};

pub static VARS_INS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olubilisation"),
        dictgen::InsensitiveStr::Ascii("olubilise"),
        dictgen::InsensitiveStr::Ascii("olubilised"),
        dictgen::InsensitiveStr::Ascii("olubilises"),
        dictgen::InsensitiveStr::Ascii("olubilising"),
        dictgen::InsensitiveStr::Ascii("olubilization"),
        dictgen::InsensitiveStr::Ascii("olubilize"),
        dictgen::InsensitiveStr::Ascii("olubilized"),
        dictgen::InsensitiveStr::Ascii("olubilizes"),
        dictgen::InsensitiveStr::Ascii("olubilizing"),
        dictgen::InsensitiveStr::Ascii("tal"),
        dictgen::InsensitiveStr::Ascii("tallment"),
        dictgen::InsensitiveStr::Ascii("tallments"),
        dictgen::InsensitiveStr::Ascii("talment"),
        dictgen::InsensitiveStr::Ascii("talments"),
        dictgen::InsensitiveStr::Ascii("tals"),
        dictgen::InsensitiveStr::Ascii("til"),
        dictgen::InsensitiveStr::Ascii("tils"),
        dictgen::InsensitiveStr::Ascii("titutionalisation"),
        dictgen::InsensitiveStr::Ascii("titutionalisations"),
        dictgen::InsensitiveStr::Ascii("titutionalise"),
        dictgen::InsensitiveStr::Ascii("titutionalised"),
        dictgen::InsensitiveStr::Ascii("titutionalises"),
        dictgen::InsensitiveStr::Ascii("titutionalising"),
        dictgen::InsensitiveStr::Ascii("titutionalization"),
        dictgen::InsensitiveStr::Ascii("titutionalizations"),
        dictgen::InsensitiveStr::Ascii("titutionalize"),
        dictgen::InsensitiveStr::Ascii("titutionalized"),
        dictgen::InsensitiveStr::Ascii("titutionalizes"),
        dictgen::InsensitiveStr::Ascii("titutionalizing"),
        dictgen::InsensitiveStr::Ascii("titutionise"),
        dictgen::InsensitiveStr::Ascii("titutionises"),
        dictgen::InsensitiveStr::Ascii("titutionize"),
        dictgen::InsensitiveStr::Ascii("titutionizes"),
        dictgen::InsensitiveStr::Ascii("trumentalise"),
        dictgen::InsensitiveStr::Ascii("trumentalises"),
        dictgen::InsensitiveStr::Ascii("trumentalize"),
        dictgen::InsensitiveStr::Ascii("trumentalizes"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("urrectionise"),
        dictgen::InsensitiveStr::Ascii("urrectionised"),
        dictgen::InsensitiveStr::Ascii("urrectionises"),
        dictgen::InsensitiveStr::Ascii("urrectionising"),
        dictgen::InsensitiveStr::Ascii("urrectionize"),
        dictgen::InsensitiveStr::Ascii("urrectionized"),
        dictgen::InsensitiveStr::Ascii("urrectionizes"),
        dictgen::InsensitiveStr::Ascii("urrectionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INSOLUBILIZATION_2468206011000375939)],
        &[(0b10010, &ENTRY_INSOLUBILIZE_11207340293843755530)],
        &[(0b10010, &ENTRY_INSOLUBILIZED_8213269300954716710)],
        &[(0b10010, &ENTRY_INSOLUBILIZES_6981064901436679943)],
        &[(0b10010, &ENTRY_INSOLUBILIZING_6097839015347270218)],
        &[(0b01001, &ENTRY_INSOLUBILIZATION_2468206011000375939)],
        &[(0b01001, &ENTRY_INSOLUBILIZE_11207340293843755530)],
        &[(0b01001, &ENTRY_INSOLUBILIZED_8213269300954716710)],
        &[(0b01001, &ENTRY_INSOLUBILIZES_6981064901436679943)],
        &[(0b01001, &ENTRY_INSOLUBILIZING_6097839015347270218)],
        &[(0b11010, &ENTRY_INSTALL_15816930015169857728)],
        &[(0b01001, &ENTRY_INSTALLMENT_12886693295291815493)],
        &[(0b01001, &ENTRY_INSTALLMENTS_12858268561173152905)],
        &[(0b11010, &ENTRY_INSTALLMENT_12886693295291815493)],
        &[(0b11010, &ENTRY_INSTALLMENTS_12858268561173152905)],
        &[(0b11010, &ENTRY_INSTALLS_3461768427562416254)],
        &[(0b11010, &ENTRY_INSTILL_818656269309790815)],
        &[(0b11010, &ENTRY_INSTILLS_5925820004112489897)],
        &[(0b10010, &ENTRY_INSTITUTIONALIZATION_16914483925074067352)],
        &[(0b10010, &ENTRY_INSTITUTIONALIZATIONS_9914961461183238934)],
        &[(0b10010, &ENTRY_INSTITUTIONALIZE_17179024303922716440)],
        &[(0b10010, &ENTRY_INSTITUTIONALIZED_7693436138088669527)],
        &[(0b10010, &ENTRY_INSTITUTIONALIZES_14636735774131912950)],
        &[(0b10010, &ENTRY_INSTITUTIONALIZING_16851706637198417031)],
        &[(0b01001, &ENTRY_INSTITUTIONALIZATION_16914483925074067352)],
        &[(0b01001, &ENTRY_INSTITUTIONALIZATIONS_9914961461183238934)],
        &[(0b01001, &ENTRY_INSTITUTIONALIZE_17179024303922716440)],
        &[(0b01001, &ENTRY_INSTITUTIONALIZED_7693436138088669527)],
        &[(0b01001, &ENTRY_INSTITUTIONALIZES_14636735774131912950)],
        &[(0b01001, &ENTRY_INSTITUTIONALIZING_16851706637198417031)],
        &[(0b10010, &ENTRY_INSTITUTIONIZE_7513388810568141965)],
        &[(0b10010, &ENTRY_INSTITUTIONIZES_14238203048319257623)],
        &[(0b01001, &ENTRY_INSTITUTIONIZE_7513388810568141965)],
        &[(0b01001, &ENTRY_INSTITUTIONIZES_14238203048319257623)],
        &[(0b10010, &ENTRY_INSTRUMENTALIZE_10032785258018795465)],
        &[(0b10010, &ENTRY_INSTRUMENTALIZES_4326655277485916636)],
        &[(0b01001, &ENTRY_INSTRUMENTALIZE_10032785258018795465)],
        &[(0b01001, &ENTRY_INSTRUMENTALIZES_4326655277485916636)],
        &[(0b10010, &ENTRY_INSULARIZE_5847883247395880273)],
        &[(0b10010, &ENTRY_INSULARIZES_14593326132116957735)],
        &[(0b01001, &ENTRY_INSULARIZE_5847883247395880273)],
        &[(0b01001, &ENTRY_INSULARIZES_14593326132116957735)],
        &[(0b10010, &ENTRY_INSURRECTIONIZE_15791518478893150782)],
        &[(0b10010, &ENTRY_INSURRECTIONIZED_6658943096112240684)],
        &[(0b10010, &ENTRY_INSURRECTIONIZES_2098678701227756077)],
        &[(0b10010, &ENTRY_INSURRECTIONIZING_9166144284813042774)],
        &[(0b01001, &ENTRY_INSURRECTIONIZE_15791518478893150782)],
        &[(0b01001, &ENTRY_INSURRECTIONIZED_6658943096112240684)],
        &[(0b01001, &ENTRY_INSURRECTIONIZES_2098678701227756077)],
        &[(0b01001, &ENTRY_INSURRECTIONIZING_9166144284813042774)],
    ],
    range: 3..=18,
};

static VARS_INO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INO_CHILDREN),
    value: None,
};

pub static VARS_INO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganised"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("rganized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INORGANIZATION_6464080564328640776)],
        &[(0b10010, &ENTRY_INORGANIZATIONS_11391650383722001073)],
        &[(0b10010, &ENTRY_INORGANIZED_11950679744367883661)],
        &[(0b01001, &ENTRY_INORGANIZATION_6464080564328640776)],
        &[(0b01001, &ENTRY_INORGANIZATIONS_11391650383722001073)],
        &[(0b01001, &ENTRY_INORGANIZED_11950679744367883661)],
    ],
    range: 8..=12,
};

static VARS_INI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INI_CHILDREN),
    value: None,
};

pub static VARS_INI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tialed"),
        dictgen::InsensitiveStr::Ascii("tialer"),
        dictgen::InsensitiveStr::Ascii("tialers"),
        dictgen::InsensitiveStr::Ascii("tialing"),
        dictgen::InsensitiveStr::Ascii("tialisable"),
        dictgen::InsensitiveStr::Ascii("tialisation"),
        dictgen::InsensitiveStr::Ascii("tialisations"),
        dictgen::InsensitiveStr::Ascii("tialise"),
        dictgen::InsensitiveStr::Ascii("tialised"),
        dictgen::InsensitiveStr::Ascii("tialiser"),
        dictgen::InsensitiveStr::Ascii("tialisers"),
        dictgen::InsensitiveStr::Ascii("tialises"),
        dictgen::InsensitiveStr::Ascii("tialising"),
        dictgen::InsensitiveStr::Ascii("tializable"),
        dictgen::InsensitiveStr::Ascii("tialization"),
        dictgen::InsensitiveStr::Ascii("tializations"),
        dictgen::InsensitiveStr::Ascii("tialize"),
        dictgen::InsensitiveStr::Ascii("tialized"),
        dictgen::InsensitiveStr::Ascii("tializer"),
        dictgen::InsensitiveStr::Ascii("tializers"),
        dictgen::InsensitiveStr::Ascii("tializes"),
        dictgen::InsensitiveStr::Ascii("tializing"),
        dictgen::InsensitiveStr::Ascii("tialled"),
        dictgen::InsensitiveStr::Ascii("tialler"),
        dictgen::InsensitiveStr::Ascii("tiallers"),
        dictgen::InsensitiveStr::Ascii("tialling"),
    ],
    values: &[
        &[(0b01001, &ENTRY_INITIALED_15902103209860719864)],
        &[(0b00001, &ENTRY_INITIALER_5954000900659273870)],
        &[(0b00001, &ENTRY_INITIALERS_14216906570899119339)],
        &[(0b01001, &ENTRY_INITIALING_12788057999224789960)],
        &[(0b10010, &ENTRY_INITIALIZABLE_13567465264773221447)],
        &[(0b10010, &ENTRY_INITIALIZATION_590649834113769182)],
        &[(0b10010, &ENTRY_INITIALIZATIONS_11293364423346468549)],
        &[(0b10010, &ENTRY_INITIALIZE_12324019979030561655)],
        &[(0b10010, &ENTRY_INITIALIZED_15301195923117397100)],
        &[(0b10010, &ENTRY_INITIALIZER_15184707483335003268)],
        &[(0b10010, &ENTRY_INITIALIZERS_11909320122902748010)],
        &[(0b10010, &ENTRY_INITIALIZES_18102819297915065203)],
        &[(0b10010, &ENTRY_INITIALIZING_12464707441303468819)],
        &[(0b01001, &ENTRY_INITIALIZABLE_13567465264773221447)],
        &[(0b01001, &ENTRY_INITIALIZATION_590649834113769182)],
        &[(0b01001, &ENTRY_INITIALIZATIONS_11293364423346468549)],
        &[(0b01001, &ENTRY_INITIALIZE_12324019979030561655)],
        &[(0b01001, &ENTRY_INITIALIZED_15301195923117397100)],
        &[(0b01001, &ENTRY_INITIALIZER_15184707483335003268)],
        &[(0b01001, &ENTRY_INITIALIZERS_11909320122902748010)],
        &[(0b01001, &ENTRY_INITIALIZES_18102819297915065203)],
        &[(0b01001, &ENTRY_INITIALIZING_12464707441303468819)],
        &[(0b11010, &ENTRY_INITIALED_15902103209860719864)],
        &[(0b11010, &ENTRY_INITIALER_5954000900659273870)],
        &[(0b11010, &ENTRY_INITIALERS_14216906570899119339)],
        &[(0b11010, &ENTRY_INITIALING_12788057999224789960)],
    ],
    range: 6..=12,
};

static VARS_INH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INH_CHILDREN),
    value: None,
};

pub static VARS_INH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("umanise"),
        dictgen::InsensitiveStr::Ascii("umanises"),
        dictgen::InsensitiveStr::Ascii("umanize"),
        dictgen::InsensitiveStr::Ascii("umanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INHUMANIZE_3302484678912696855)],
        &[(0b10010, &ENTRY_INHUMANIZES_6552273656617294035)],
        &[(0b01001, &ENTRY_INHUMANIZE_3302484678912696855)],
        &[(0b01001, &ENTRY_INHUMANIZES_6552273656617294035)],
    ],
    range: 7..=8,
};

static VARS_ING_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ING_CHILDREN),
    value: None,
};

pub static VARS_ING_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("vaeonic"),
        dictgen::InsensitiveStr::Ascii("veonic"),
        dictgen::InsensitiveStr::Ascii("waeonic"),
        dictgen::InsensitiveStr::Ascii("weonic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_INGVEONIC_413063112298926439)],
        &[(0b00001, &ENTRY_INGVEONIC_413063112298926439)],
        &[(0b11010, &ENTRY_INGWEONIC_16714590859602524090)],
        &[(0b00001, &ENTRY_INGWEONIC_16714590859602524090)],
    ],
    range: 6..=7,
};

static VARS_INF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INF_CHILDREN),
    value: None,
};

pub static VARS_INF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("amise"),
        dictgen::InsensitiveStr::Ascii("amised"),
        dictgen::InsensitiveStr::Ascii("amises"),
        dictgen::InsensitiveStr::Ascii("amising"),
        dictgen::InsensitiveStr::Ascii("amize"),
        dictgen::InsensitiveStr::Ascii("amized"),
        dictgen::InsensitiveStr::Ascii("amizes"),
        dictgen::InsensitiveStr::Ascii("amizing"),
        dictgen::InsensitiveStr::Ascii("amonise"),
        dictgen::InsensitiveStr::Ascii("amonised"),
        dictgen::InsensitiveStr::Ascii("amonises"),
        dictgen::InsensitiveStr::Ascii("amonising"),
        dictgen::InsensitiveStr::Ascii("amonize"),
        dictgen::InsensitiveStr::Ascii("amonized"),
        dictgen::InsensitiveStr::Ascii("amonizes"),
        dictgen::InsensitiveStr::Ascii("amonizing"),
        dictgen::InsensitiveStr::Ascii("ere"),
        dictgen::InsensitiveStr::Ascii("eriorise"),
        dictgen::InsensitiveStr::Ascii("eriorises"),
        dictgen::InsensitiveStr::Ascii("eriorize"),
        dictgen::InsensitiveStr::Ascii("eriorizes"),
        dictgen::InsensitiveStr::Ascii("ernalise"),
        dictgen::InsensitiveStr::Ascii("ernalises"),
        dictgen::InsensitiveStr::Ascii("ernalize"),
        dictgen::InsensitiveStr::Ascii("ernalizes"),
        dictgen::InsensitiveStr::Ascii("idelise"),
        dictgen::InsensitiveStr::Ascii("idelises"),
        dictgen::InsensitiveStr::Ascii("idelize"),
        dictgen::InsensitiveStr::Ascii("idelizes"),
        dictgen::InsensitiveStr::Ascii("initise"),
        dictgen::InsensitiveStr::Ascii("initises"),
        dictgen::InsensitiveStr::Ascii("initize"),
        dictgen::InsensitiveStr::Ascii("initizes"),
        dictgen::InsensitiveStr::Ascii("lexion"),
        dictgen::InsensitiveStr::Ascii("lexions"),
        dictgen::InsensitiveStr::Ascii("ormalise"),
        dictgen::InsensitiveStr::Ascii("ormalises"),
        dictgen::InsensitiveStr::Ascii("ormalize"),
        dictgen::InsensitiveStr::Ascii("ormalizes"),
        dictgen::InsensitiveStr::Ascii("ree"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INFAMIZE_18394174721818129022)],
        &[(0b10010, &ENTRY_INFAMIZED_8686570708963178953)],
        &[(0b10010, &ENTRY_INFAMIZES_12652390020335388371)],
        &[(0b10010, &ENTRY_INFAMIZING_13586882845116750692)],
        &[(0b01001, &ENTRY_INFAMIZE_18394174721818129022)],
        &[(0b01001, &ENTRY_INFAMIZED_8686570708963178953)],
        &[(0b01001, &ENTRY_INFAMIZES_12652390020335388371)],
        &[(0b01001, &ENTRY_INFAMIZING_13586882845116750692)],
        &[(0b10010, &ENTRY_INFAMONIZE_11667946505084232707)],
        &[(0b10010, &ENTRY_INFAMONIZED_10035723014416988237)],
        &[(0b10010, &ENTRY_INFAMONIZES_11901093378762506596)],
        &[(0b10010, &ENTRY_INFAMONIZING_1761524099304748028)],
        &[(0b01001, &ENTRY_INFAMONIZE_11667946505084232707)],
        &[(0b01001, &ENTRY_INFAMONIZED_10035723014416988237)],
        &[(0b01001, &ENTRY_INFAMONIZES_11901093378762506596)],
        &[(0b01001, &ENTRY_INFAMONIZING_1761524099304748028)],
        &[(0b00001, &ENTRY_INFERE_5312705532266488477)],
        &[(0b10010, &ENTRY_INFERIORIZE_11223909632506235818)],
        &[(0b10010, &ENTRY_INFERIORIZES_13036000105274936197)],
        &[(0b01001, &ENTRY_INFERIORIZE_11223909632506235818)],
        &[(0b01001, &ENTRY_INFERIORIZES_13036000105274936197)],
        &[(0b10010, &ENTRY_INFERNALIZE_10062329537653335936)],
        &[(0b10010, &ENTRY_INFERNALIZES_7151282121739105899)],
        &[(0b01001, &ENTRY_INFERNALIZE_10062329537653335936)],
        &[(0b01001, &ENTRY_INFERNALIZES_7151282121739105899)],
        &[(0b10010, &ENTRY_INFIDELIZE_13385979360953022316)],
        &[(0b10010, &ENTRY_INFIDELIZES_2918972068143693835)],
        &[(0b01001, &ENTRY_INFIDELIZE_13385979360953022316)],
        &[(0b01001, &ENTRY_INFIDELIZES_2918972068143693835)],
        &[(0b10010, &ENTRY_INFINITIZE_6261338332347990433)],
        &[(0b10010, &ENTRY_INFINITIZES_4515016592588905048)],
        &[(0b01001, &ENTRY_INFINITIZE_6261338332347990433)],
        &[(0b01001, &ENTRY_INFINITIZES_4515016592588905048)],
        &[(0b10010, &ENTRY_INFLECTION_18277295203675481446)],
        &[(0b10010, &ENTRY_INFLECTIONS_16947371245746328476)],
        &[(0b10010, &ENTRY_INFORMALIZE_17940073891680185003)],
        &[(0b10010, &ENTRY_INFORMALIZES_18331346153817933485)],
        &[(0b01001, &ENTRY_INFORMALIZE_17940073891680185003)],
        &[(0b01001, &ENTRY_INFORMALIZES_18331346153817933485)],
        &[(0b11010, &ENTRY_INFERE_5312705532266488477)],
    ],
    range: 3..=9,
};

static VARS_INE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INE_CHILDREN),
    value: None,
};

pub static VARS_INE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("sthetic")],
    values: &[&[(0b00001, &ENTRY_INESTHETIC_4642492739468968957)]],
    range: 7..=7,
};

static VARS_IND_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IND_CHILDREN),
    value: None,
};

pub static VARS_IND_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ianisation"),
        dictgen::InsensitiveStr::Ascii("ianise"),
        dictgen::InsensitiveStr::Ascii("ianised"),
        dictgen::InsensitiveStr::Ascii("ianises"),
        dictgen::InsensitiveStr::Ascii("ianising"),
        dictgen::InsensitiveStr::Ascii("ianization"),
        dictgen::InsensitiveStr::Ascii("ianize"),
        dictgen::InsensitiveStr::Ascii("ianized"),
        dictgen::InsensitiveStr::Ascii("ianizes"),
        dictgen::InsensitiveStr::Ascii("ianizing"),
        dictgen::InsensitiveStr::Ascii("igenae"),
        dictgen::InsensitiveStr::Ascii("igene"),
        dictgen::InsensitiveStr::Ascii("igenisation"),
        dictgen::InsensitiveStr::Ascii("igenisations"),
        dictgen::InsensitiveStr::Ascii("igenise"),
        dictgen::InsensitiveStr::Ascii("igenised"),
        dictgen::InsensitiveStr::Ascii("igenises"),
        dictgen::InsensitiveStr::Ascii("igenising"),
        dictgen::InsensitiveStr::Ascii("igenization"),
        dictgen::InsensitiveStr::Ascii("igenizations"),
        dictgen::InsensitiveStr::Ascii("igenize"),
        dictgen::InsensitiveStr::Ascii("igenized"),
        dictgen::InsensitiveStr::Ascii("igenizes"),
        dictgen::InsensitiveStr::Ascii("igenizing"),
        dictgen::InsensitiveStr::Ascii("ividualisation"),
        dictgen::InsensitiveStr::Ascii("ividualisations"),
        dictgen::InsensitiveStr::Ascii("ividualise"),
        dictgen::InsensitiveStr::Ascii("ividualised"),
        dictgen::InsensitiveStr::Ascii("ividualiser"),
        dictgen::InsensitiveStr::Ascii("ividualisers"),
        dictgen::InsensitiveStr::Ascii("ividualises"),
        dictgen::InsensitiveStr::Ascii("ividualising"),
        dictgen::InsensitiveStr::Ascii("ividualisingly"),
        dictgen::InsensitiveStr::Ascii("ividualization"),
        dictgen::InsensitiveStr::Ascii("ividualizations"),
        dictgen::InsensitiveStr::Ascii("ividualize"),
        dictgen::InsensitiveStr::Ascii("ividualized"),
        dictgen::InsensitiveStr::Ascii("ividualizer"),
        dictgen::InsensitiveStr::Ascii("ividualizers"),
        dictgen::InsensitiveStr::Ascii("ividualizes"),
        dictgen::InsensitiveStr::Ascii("ividualizing"),
        dictgen::InsensitiveStr::Ascii("ividualizingly"),
        dictgen::InsensitiveStr::Ascii("raft"),
        dictgen::InsensitiveStr::Ascii("rafts"),
        dictgen::InsensitiveStr::Ascii("raught"),
        dictgen::InsensitiveStr::Ascii("raughts"),
        dictgen::InsensitiveStr::Ascii("ustrialisation"),
        dictgen::InsensitiveStr::Ascii("ustrialisations"),
        dictgen::InsensitiveStr::Ascii("ustrialise"),
        dictgen::InsensitiveStr::Ascii("ustrialised"),
        dictgen::InsensitiveStr::Ascii("ustrialises"),
        dictgen::InsensitiveStr::Ascii("ustrialising"),
        dictgen::InsensitiveStr::Ascii("ustrialization"),
        dictgen::InsensitiveStr::Ascii("ustrializations"),
        dictgen::InsensitiveStr::Ascii("ustrialize"),
        dictgen::InsensitiveStr::Ascii("ustrialized"),
        dictgen::InsensitiveStr::Ascii("ustrializes"),
        dictgen::InsensitiveStr::Ascii("ustrializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INDIANIZATION_1716413238822798201)],
        &[(0b10010, &ENTRY_INDIANIZE_15318260537100967280)],
        &[(0b10010, &ENTRY_INDIANIZED_6681655339922669663)],
        &[(0b10010, &ENTRY_INDIANIZES_451682467374866405)],
        &[(0b10010, &ENTRY_INDIANIZING_17001518438969414024)],
        &[(0b01001, &ENTRY_INDIANIZATION_1716413238822798201)],
        &[(0b01001, &ENTRY_INDIANIZE_15318260537100967280)],
        &[(0b01001, &ENTRY_INDIANIZED_6681655339922669663)],
        &[(0b01001, &ENTRY_INDIANIZES_451682467374866405)],
        &[(0b01001, &ENTRY_INDIANIZING_17001518438969414024)],
        &[(0b11010, &ENTRY_INDIGENE_4819583243782851729)],
        &[(0b00001, &ENTRY_INDIGENE_4819583243782851729)],
        &[(0b10010, &ENTRY_INDIGENIZATION_12186530112926947999)],
        &[(0b10010, &ENTRY_INDIGENIZATIONS_13844088182117443972)],
        &[(0b10010, &ENTRY_INDIGENIZE_7645648345209455462)],
        &[(0b10010, &ENTRY_INDIGENIZED_12785276256883238057)],
        &[(0b10010, &ENTRY_INDIGENIZES_6885065470536932314)],
        &[(0b10010, &ENTRY_INDIGENIZING_14409860332630821709)],
        &[(0b01001, &ENTRY_INDIGENIZATION_12186530112926947999)],
        &[(0b01001, &ENTRY_INDIGENIZATIONS_13844088182117443972)],
        &[(0b01001, &ENTRY_INDIGENIZE_7645648345209455462)],
        &[(0b01001, &ENTRY_INDIGENIZED_12785276256883238057)],
        &[(0b01001, &ENTRY_INDIGENIZES_6885065470536932314)],
        &[(0b01001, &ENTRY_INDIGENIZING_14409860332630821709)],
        &[(0b10010, &ENTRY_INDIVIDUALIZATION_12161892009800116926)],
        &[(0b10010, &ENTRY_INDIVIDUALIZATIONS_16008274701567236397)],
        &[(0b10010, &ENTRY_INDIVIDUALIZE_14128117353720123820)],
        &[(0b10010, &ENTRY_INDIVIDUALIZED_12615286571022762701)],
        &[(0b10010, &ENTRY_INDIVIDUALIZER_10202329538410288235)],
        &[(0b10010, &ENTRY_INDIVIDUALIZERS_2446587753454807307)],
        &[(0b10010, &ENTRY_INDIVIDUALIZES_5313824086917745418)],
        &[(0b10010, &ENTRY_INDIVIDUALIZING_15464150109564265891)],
        &[(0b10010, &ENTRY_INDIVIDUALIZINGLY_7651768127321435917)],
        &[(0b01001, &ENTRY_INDIVIDUALIZATION_12161892009800116926)],
        &[(0b01001, &ENTRY_INDIVIDUALIZATIONS_16008274701567236397)],
        &[(0b01001, &ENTRY_INDIVIDUALIZE_14128117353720123820)],
        &[(0b01001, &ENTRY_INDIVIDUALIZED_12615286571022762701)],
        &[(0b01001, &ENTRY_INDIVIDUALIZER_10202329538410288235)],
        &[(0b01001, &ENTRY_INDIVIDUALIZERS_2446587753454807307)],
        &[(0b01001, &ENTRY_INDIVIDUALIZES_5313824086917745418)],
        &[(0b01001, &ENTRY_INDIVIDUALIZING_15464150109564265891)],
        &[(0b01001, &ENTRY_INDIVIDUALIZINGLY_7651768127321435917)],
        &[(0b01001, &ENTRY_INDRAFT_1882858010909385258)],
        &[(0b01001, &ENTRY_INDRAFTS_9423407568172028790)],
        &[(0b10010, &ENTRY_INDRAFT_1882858010909385258)],
        &[(0b10010, &ENTRY_INDRAFTS_9423407568172028790)],
        &[(0b10010, &ENTRY_INDUSTRIALIZATION_350753450895865005)],
        &[(0b10010, &ENTRY_INDUSTRIALIZATIONS_17597998929798495645)],
        &[(0b10010, &ENTRY_INDUSTRIALIZE_9725131420784308416)],
        &[(0b10010, &ENTRY_INDUSTRIALIZED_9347966852221416739)],
        &[(0b10010, &ENTRY_INDUSTRIALIZES_17591656646172403685)],
        &[(0b10010, &ENTRY_INDUSTRIALIZING_3256987218630221135)],
        &[(0b01001, &ENTRY_INDUSTRIALIZATION_350753450895865005)],
        &[(0b01001, &ENTRY_INDUSTRIALIZATIONS_17597998929798495645)],
        &[(0b01001, &ENTRY_INDUSTRIALIZE_9725131420784308416)],
        &[(0b01001, &ENTRY_INDUSTRIALIZED_9347966852221416739)],
        &[(0b01001, &ENTRY_INDUSTRIALIZES_17591656646172403685)],
        &[(0b01001, &ENTRY_INDUSTRIALIZING_3256987218630221135)],
    ],
    range: 4..=15,
};

static VARS_INC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INC_CHILDREN),
    value: None,
};

pub static VARS_INC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arnalise"),
        dictgen::InsensitiveStr::Ascii("arnalised"),
        dictgen::InsensitiveStr::Ascii("arnalising"),
        dictgen::InsensitiveStr::Ascii("arnalize"),
        dictgen::InsensitiveStr::Ascii("arnalized"),
        dictgen::InsensitiveStr::Ascii("arnalizing"),
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("enters"),
        dictgen::InsensitiveStr::Ascii("entivisation"),
        dictgen::InsensitiveStr::Ascii("entivisations"),
        dictgen::InsensitiveStr::Ascii("entivise"),
        dictgen::InsensitiveStr::Ascii("entivised"),
        dictgen::InsensitiveStr::Ascii("entivises"),
        dictgen::InsensitiveStr::Ascii("entivising"),
        dictgen::InsensitiveStr::Ascii("entivization"),
        dictgen::InsensitiveStr::Ascii("entivizations"),
        dictgen::InsensitiveStr::Ascii("entivize"),
        dictgen::InsensitiveStr::Ascii("entivized"),
        dictgen::InsensitiveStr::Ascii("entivizes"),
        dictgen::InsensitiveStr::Ascii("entivizing"),
        dictgen::InsensitiveStr::Ascii("entre"),
        dictgen::InsensitiveStr::Ascii("entres"),
        dictgen::InsensitiveStr::Ascii("erate"),
        dictgen::InsensitiveStr::Ascii("lose"),
        dictgen::InsensitiveStr::Ascii("losed"),
        dictgen::InsensitiveStr::Ascii("loses"),
        dictgen::InsensitiveStr::Ascii("losing"),
        dictgen::InsensitiveStr::Ascii("ognisable"),
        dictgen::InsensitiveStr::Ascii("ognisance"),
        dictgen::InsensitiveStr::Ascii("ognisances"),
        dictgen::InsensitiveStr::Ascii("ognisant"),
        dictgen::InsensitiveStr::Ascii("ognizable"),
        dictgen::InsensitiveStr::Ascii("ognizance"),
        dictgen::InsensitiveStr::Ascii("ognizances"),
        dictgen::InsensitiveStr::Ascii("ognizant"),
        dictgen::InsensitiveStr::Ascii("reate"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INCARNALIZE_7292849573624396827)],
        &[(0b10010, &ENTRY_INCARNALIZED_16198812654340664293)],
        &[(0b10010, &ENTRY_INCARNALIZING_7229408943846118357)],
        &[(0b01001, &ENTRY_INCARNALIZE_7292849573624396827)],
        &[(0b01001, &ENTRY_INCARNALIZED_16198812654340664293)],
        &[(0b01001, &ENTRY_INCARNALIZING_7229408943846118357)],
        &[(0b00001, &ENTRY_INCENTER_9810686460356413191)],
        &[(0b00001, &ENTRY_INCENTERS_17129252522264689574)],
        &[(0b10010, &ENTRY_INCENTIVIZATION_14381857720793942653)],
        &[(0b10010, &ENTRY_INCENTIVIZATIONS_4037716705715303421)],
        &[(0b10010, &ENTRY_INCENTIVIZE_16078554441117960885)],
        &[(0b10010, &ENTRY_INCENTIVIZED_16632919930346554292)],
        &[(0b10010, &ENTRY_INCENTIVIZES_8999169043411056754)],
        &[(0b10010, &ENTRY_INCENTIVIZING_2171837523441254972)],
        &[(0b01001, &ENTRY_INCENTIVIZATION_14381857720793942653)],
        &[(0b01001, &ENTRY_INCENTIVIZATIONS_4037716705715303421)],
        &[(0b01001, &ENTRY_INCENTIVIZE_16078554441117960885)],
        &[(0b01001, &ENTRY_INCENTIVIZED_16632919930346554292)],
        &[(0b01001, &ENTRY_INCENTIVIZES_8999169043411056754)],
        &[(0b01001, &ENTRY_INCENTIVIZING_2171837523441254972)],
        &[(0b11010, &ENTRY_INCENTER_9810686460356413191)],
        &[(0b11010, &ENTRY_INCENTERS_17129252522264689574)],
        &[(0b00001, &ENTRY_INCERATE_18445841595936741392)],
        &[(0b00001, &ENTRY_ENCLOSE_10842906381131425887)],
        &[(0b00001, &ENTRY_ENCLOSED_1563410036667921820)],
        &[(0b00001, &ENTRY_ENCLOSES_18044907393387133378)],
        &[(0b00001, &ENTRY_ENCLOSING_16339276559305482445)],
        &[(0b10010, &ENTRY_INCOGNIZABLE_10885527175806322091)],
        &[(0b10010, &ENTRY_INCOGNIZANCE_8307360386742125799)],
        &[(0b10010, &ENTRY_INCOGNIZANCES_15070962290717221665)],
        &[(0b10010, &ENTRY_INCOGNIZANT_15888512407120483355)],
        &[(0b01001, &ENTRY_INCOGNIZABLE_10885527175806322091)],
        &[(0b01001, &ENTRY_INCOGNIZANCE_8307360386742125799)],
        &[(0b01001, &ENTRY_INCOGNIZANCES_15070962290717221665)],
        &[(0b01001, &ENTRY_INCOGNIZANT_15888512407120483355)],
        &[(0b11010, &ENTRY_INCERATE_18445841595936741392)],
    ],
    range: 4..=13,
};

static VARS_INA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INA_CHILDREN),
    value: None,
};

pub static VARS_INA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("esthetic")],
    values: &[&[(0b11010, &ENTRY_INESTHETIC_4642492739468968957)]],
    range: 8..=8,
};

static VARS_IM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_IM_CHILDREN),
    value: None,
};

static VARS_IM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_IMB_NODE),
    None,
    None,
    Some(&VARS_IME_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IMM_NODE),
    None,
    None,
    Some(&VARS_IMP_NODE),
    None,
    Some(&VARS_IMR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_IMR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMR_CHILDREN),
    value: None,
};

pub static VARS_IMR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b11010, &ENTRY_IMER_11358538646216832658)]],
    range: 1..=1,
};

static VARS_IMP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMP_CHILDREN),
    value: None,
};

pub static VARS_IMP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("actionise"),
        dictgen::InsensitiveStr::Ascii("actionises"),
        dictgen::InsensitiveStr::Ascii("actionize"),
        dictgen::InsensitiveStr::Ascii("actionizes"),
        dictgen::InsensitiveStr::Ascii("aneled"),
        dictgen::InsensitiveStr::Ascii("aneling"),
        dictgen::InsensitiveStr::Ascii("anelled"),
        dictgen::InsensitiveStr::Ascii("anelling"),
        dictgen::InsensitiveStr::Ascii("asted"),
        dictgen::InsensitiveStr::Ascii("astoed"),
        dictgen::InsensitiveStr::Ascii("erialisation"),
        dictgen::InsensitiveStr::Ascii("erialisations"),
        dictgen::InsensitiveStr::Ascii("erialise"),
        dictgen::InsensitiveStr::Ascii("erialised"),
        dictgen::InsensitiveStr::Ascii("erialises"),
        dictgen::InsensitiveStr::Ascii("erialising"),
        dictgen::InsensitiveStr::Ascii("erialization"),
        dictgen::InsensitiveStr::Ascii("erializations"),
        dictgen::InsensitiveStr::Ascii("erialize"),
        dictgen::InsensitiveStr::Ascii("erialized"),
        dictgen::InsensitiveStr::Ascii("erializes"),
        dictgen::InsensitiveStr::Ascii("erializing"),
        dictgen::InsensitiveStr::Ascii("eriled"),
        dictgen::InsensitiveStr::Ascii("eriling"),
        dictgen::InsensitiveStr::Ascii("erilled"),
        dictgen::InsensitiveStr::Ascii("erilling"),
        dictgen::InsensitiveStr::Ascii("erscriptible"),
        dictgen::InsensitiveStr::Ascii("ersonalisation"),
        dictgen::InsensitiveStr::Ascii("ersonalisations"),
        dictgen::InsensitiveStr::Ascii("ersonalise"),
        dictgen::InsensitiveStr::Ascii("ersonalised"),
        dictgen::InsensitiveStr::Ascii("ersonalises"),
        dictgen::InsensitiveStr::Ascii("ersonalising"),
        dictgen::InsensitiveStr::Ascii("ersonalization"),
        dictgen::InsensitiveStr::Ascii("ersonalizations"),
        dictgen::InsensitiveStr::Ascii("ersonalize"),
        dictgen::InsensitiveStr::Ascii("ersonalized"),
        dictgen::InsensitiveStr::Ascii("ersonalizes"),
        dictgen::InsensitiveStr::Ascii("ersonalizing"),
        dictgen::InsensitiveStr::Ascii("rescriptible"),
        dictgen::InsensitiveStr::Ascii("rovisatorise"),
        dictgen::InsensitiveStr::Ascii("rovisatorises"),
        dictgen::InsensitiveStr::Ascii("rovisatorize"),
        dictgen::InsensitiveStr::Ascii("rovisatorizes"),
        dictgen::InsensitiveStr::Ascii("rovizatorize"),
        dictgen::InsensitiveStr::Ascii("rovizatorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IMPACTIONIZE_6659733183241501977)],
        &[(0b10010, &ENTRY_IMPACTIONIZES_3797144053702390759)],
        &[(0b01001, &ENTRY_IMPACTIONIZE_6659733183241501977)],
        &[(0b01001, &ENTRY_IMPACTIONIZES_3797144053702390759)],
        &[(0b00001, &ENTRY_IMPANELED_5408518347675931541)],
        &[(0b00001, &ENTRY_IMPANELING_2814603235256758547)],
        &[(0b11010, &ENTRY_IMPANELED_5408518347675931541)],
        &[(0b11010, &ENTRY_IMPANELING_2814603235256758547)],
        &[(0b00001, &ENTRY_IMPASTED_17189632727971693462)],
        &[(0b11010, &ENTRY_IMPASTED_17189632727971693462)],
        &[(0b10010, &ENTRY_IMPERIALIZATION_11626604416338067521)],
        &[(0b10010, &ENTRY_IMPERIALIZATIONS_7589841721847748726)],
        &[(0b10010, &ENTRY_IMPERIALIZE_4756932431788884861)],
        &[(0b10010, &ENTRY_IMPERIALIZED_6901045873287587401)],
        &[(0b10010, &ENTRY_IMPERIALIZES_17659651406501700766)],
        &[(0b10010, &ENTRY_IMPERIALIZING_12509349088788350886)],
        &[(0b01001, &ENTRY_IMPERIALIZATION_11626604416338067521)],
        &[(0b01001, &ENTRY_IMPERIALIZATIONS_7589841721847748726)],
        &[(0b01001, &ENTRY_IMPERIALIZE_4756932431788884861)],
        &[(0b01001, &ENTRY_IMPERIALIZED_6901045873287587401)],
        &[(0b01001, &ENTRY_IMPERIALIZES_17659651406501700766)],
        &[(0b01001, &ENTRY_IMPERIALIZING_12509349088788350886)],
        &[(0b00001, &ENTRY_IMPERILED_8444551636021682618)],
        &[(0b00001, &ENTRY_IMPERILING_4650244730518368073)],
        &[(0b11010, &ENTRY_IMPERILED_8444551636021682618)],
        &[(0b11010, &ENTRY_IMPERILING_4650244730518368073)],
        &[(0b00001, &ENTRY_IMPERSCRIPTIBLE_7856896163677005608)],
        &[(0b10010, &ENTRY_IMPERSONALIZATION_14849806748268928930)],
        &[(0b10010, &ENTRY_IMPERSONALIZATIONS_3405968491722535892)],
        &[(0b10010, &ENTRY_IMPERSONALIZE_14038642006477198579)],
        &[(0b10010, &ENTRY_IMPERSONALIZED_15300682061313699483)],
        &[(0b10010, &ENTRY_IMPERSONALIZES_7941945459626836659)],
        &[(0b10010, &ENTRY_IMPERSONALIZING_16023910359670403281)],
        &[(0b01001, &ENTRY_IMPERSONALIZATION_14849806748268928930)],
        &[(0b01001, &ENTRY_IMPERSONALIZATIONS_3405968491722535892)],
        &[(0b01001, &ENTRY_IMPERSONALIZE_14038642006477198579)],
        &[(0b01001, &ENTRY_IMPERSONALIZED_15300682061313699483)],
        &[(0b01001, &ENTRY_IMPERSONALIZES_7941945459626836659)],
        &[(0b01001, &ENTRY_IMPERSONALIZING_16023910359670403281)],
        &[(0b11010, &ENTRY_IMPERSCRIPTIBLE_7856896163677005608)],
        &[(0b10010, &ENTRY_IMPROVIZATORIZE_8480332828250113268)],
        &[(0b10010, &ENTRY_IMPROVIZATORIZES_16215791512694135642)],
        &[(0b01000, &ENTRY_IMPROVIZATORIZE_8480332828250113268)],
        &[(0b01000, &ENTRY_IMPROVIZATORIZES_16215791512694135642)],
        &[(0b00001, &ENTRY_IMPROVIZATORIZE_8480332828250113268)],
        &[(0b00001, &ENTRY_IMPROVIZATORIZES_16215791512694135642)],
    ],
    range: 5..=15,
};

static VARS_IMM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_IMM_CHILDREN),
    value: None,
};

static VARS_IMM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_IMMA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IMMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IMMO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IMMU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_IMMU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMMU_CHILDREN),
    value: None,
};

pub static VARS_IMMU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IMMUNIZATION_41859105662498323)],
        &[(0b10010, &ENTRY_IMMUNIZATIONS_6777054902061161290)],
        &[(0b10010, &ENTRY_IMMUNIZE_7761802139818992811)],
        &[(0b10010, &ENTRY_IMMUNIZED_14708964453824556295)],
        &[(0b10010, &ENTRY_IMMUNIZER_397316735795648135)],
        &[(0b10010, &ENTRY_IMMUNIZES_4888824548752332625)],
        &[(0b10010, &ENTRY_IMMUNIZING_12247538481370716233)],
        &[(0b01001, &ENTRY_IMMUNIZATION_41859105662498323)],
        &[(0b01001, &ENTRY_IMMUNIZATIONS_6777054902061161290)],
        &[(0b01001, &ENTRY_IMMUNIZE_7761802139818992811)],
        &[(0b01001, &ENTRY_IMMUNIZED_14708964453824556295)],
        &[(0b01001, &ENTRY_IMMUNIZER_397316735795648135)],
        &[(0b01001, &ENTRY_IMMUNIZES_4888824548752332625)],
        &[(0b01001, &ENTRY_IMMUNIZING_12247538481370716233)],
    ],
    range: 4..=9,
};

static VARS_IMMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMMO_CHILDREN),
    value: None,
};

pub static VARS_IMMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilisation"),
        dictgen::InsensitiveStr::Ascii("bilisations"),
        dictgen::InsensitiveStr::Ascii("bilise"),
        dictgen::InsensitiveStr::Ascii("bilised"),
        dictgen::InsensitiveStr::Ascii("biliser"),
        dictgen::InsensitiveStr::Ascii("bilisers"),
        dictgen::InsensitiveStr::Ascii("bilises"),
        dictgen::InsensitiveStr::Ascii("bilising"),
        dictgen::InsensitiveStr::Ascii("bilization"),
        dictgen::InsensitiveStr::Ascii("bilizations"),
        dictgen::InsensitiveStr::Ascii("bilize"),
        dictgen::InsensitiveStr::Ascii("bilized"),
        dictgen::InsensitiveStr::Ascii("bilizer"),
        dictgen::InsensitiveStr::Ascii("bilizers"),
        dictgen::InsensitiveStr::Ascii("bilizes"),
        dictgen::InsensitiveStr::Ascii("bilizing"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralised"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralising"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralized"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralizing"),
        dictgen::InsensitiveStr::Ascii("rtalisable"),
        dictgen::InsensitiveStr::Ascii("rtalisabler"),
        dictgen::InsensitiveStr::Ascii("rtalisables"),
        dictgen::InsensitiveStr::Ascii("rtalisablest"),
        dictgen::InsensitiveStr::Ascii("rtalisation"),
        dictgen::InsensitiveStr::Ascii("rtalisations"),
        dictgen::InsensitiveStr::Ascii("rtalise"),
        dictgen::InsensitiveStr::Ascii("rtalised"),
        dictgen::InsensitiveStr::Ascii("rtaliser"),
        dictgen::InsensitiveStr::Ascii("rtalisers"),
        dictgen::InsensitiveStr::Ascii("rtalises"),
        dictgen::InsensitiveStr::Ascii("rtalising"),
        dictgen::InsensitiveStr::Ascii("rtalizable"),
        dictgen::InsensitiveStr::Ascii("rtalizabler"),
        dictgen::InsensitiveStr::Ascii("rtalizables"),
        dictgen::InsensitiveStr::Ascii("rtalizablest"),
        dictgen::InsensitiveStr::Ascii("rtalization"),
        dictgen::InsensitiveStr::Ascii("rtalizations"),
        dictgen::InsensitiveStr::Ascii("rtalize"),
        dictgen::InsensitiveStr::Ascii("rtalized"),
        dictgen::InsensitiveStr::Ascii("rtalizer"),
        dictgen::InsensitiveStr::Ascii("rtalizers"),
        dictgen::InsensitiveStr::Ascii("rtalizes"),
        dictgen::InsensitiveStr::Ascii("rtalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IMMOBILIZATION_11535874786657183681)],
        &[(0b10010, &ENTRY_IMMOBILIZATIONS_11913395493106272461)],
        &[(0b10010, &ENTRY_IMMOBILIZE_409138148493531223)],
        &[(0b10010, &ENTRY_IMMOBILIZED_2218449348429448480)],
        &[(0b10010, &ENTRY_IMMOBILIZER_2052176910993424670)],
        &[(0b10010, &ENTRY_IMMOBILIZERS_3641715443719698453)],
        &[(0b10010, &ENTRY_IMMOBILIZES_3228156254989919907)],
        &[(0b10010, &ENTRY_IMMOBILIZING_16170310105570993627)],
        &[(0b01001, &ENTRY_IMMOBILIZATION_11535874786657183681)],
        &[(0b01001, &ENTRY_IMMOBILIZATIONS_11913395493106272461)],
        &[(0b01001, &ENTRY_IMMOBILIZE_409138148493531223)],
        &[(0b01001, &ENTRY_IMMOBILIZED_2218449348429448480)],
        &[(0b01001, &ENTRY_IMMOBILIZER_2052176910993424670)],
        &[(0b01001, &ENTRY_IMMOBILIZERS_3641715443719698453)],
        &[(0b01001, &ENTRY_IMMOBILIZES_3228156254989919907)],
        &[(0b01001, &ENTRY_IMMOBILIZING_16170310105570993627)],
        &[(0b10010, &ENTRY_IMMORALIZE_6360519991935141046)],
        &[(0b10010, &ENTRY_IMMORALIZED_14794307099201904380)],
        &[(0b10010, &ENTRY_IMMORALIZES_10642942003506554241)],
        &[(0b10010, &ENTRY_IMMORALIZING_16713408483837116926)],
        &[(0b01001, &ENTRY_IMMORALIZE_6360519991935141046)],
        &[(0b01001, &ENTRY_IMMORALIZED_14794307099201904380)],
        &[(0b01001, &ENTRY_IMMORALIZES_10642942003506554241)],
        &[(0b01001, &ENTRY_IMMORALIZING_16713408483837116926)],
        &[(0b10010, &ENTRY_IMMORTALIZABLE_4987032698605112948)],
        &[(0b10010, &ENTRY_IMMORTALIZABLER_9804560428950355369)],
        &[(0b10010, &ENTRY_IMMORTALIZABLES_5485137714027314044)],
        &[(0b10010, &ENTRY_IMMORTALIZABLEST_10465023541515947294)],
        &[(0b10010, &ENTRY_IMMORTALIZATION_10488407014653410612)],
        &[(0b10010, &ENTRY_IMMORTALIZATIONS_13947110718243595455)],
        &[(0b10010, &ENTRY_IMMORTALIZE_709590795785947525)],
        &[(0b10010, &ENTRY_IMMORTALIZED_13104274410574807419)],
        &[(0b10010, &ENTRY_IMMORTALIZER_17669586674033110270)],
        &[(0b10010, &ENTRY_IMMORTALIZERS_18081771581509933059)],
        &[(0b10010, &ENTRY_IMMORTALIZES_5576583787201540554)],
        &[(0b10010, &ENTRY_IMMORTALIZING_5453074279253364520)],
        &[(0b01001, &ENTRY_IMMORTALIZABLE_4987032698605112948)],
        &[(0b01001, &ENTRY_IMMORTALIZABLER_9804560428950355369)],
        &[(0b01001, &ENTRY_IMMORTALIZABLES_5485137714027314044)],
        &[(0b01001, &ENTRY_IMMORTALIZABLEST_10465023541515947294)],
        &[(0b01001, &ENTRY_IMMORTALIZATION_10488407014653410612)],
        &[(0b01001, &ENTRY_IMMORTALIZATIONS_13947110718243595455)],
        &[(0b01001, &ENTRY_IMMORTALIZE_709590795785947525)],
        &[(0b01001, &ENTRY_IMMORTALIZED_13104274410574807419)],
        &[(0b01001, &ENTRY_IMMORTALIZER_17669586674033110270)],
        &[(0b01001, &ENTRY_IMMORTALIZERS_18081771581509933059)],
        &[(0b01001, &ENTRY_IMMORTALIZES_5576583787201540554)],
        &[(0b01001, &ENTRY_IMMORTALIZING_5453074279253364520)],
    ],
    range: 6..=12,
};

static VARS_IMMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMMI_CHILDREN),
    value: None,
};

pub static VARS_IMMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("serisation"),
        dictgen::InsensitiveStr::Ascii("serisations"),
        dictgen::InsensitiveStr::Ascii("serise"),
        dictgen::InsensitiveStr::Ascii("serised"),
        dictgen::InsensitiveStr::Ascii("serises"),
        dictgen::InsensitiveStr::Ascii("serising"),
        dictgen::InsensitiveStr::Ascii("serization"),
        dictgen::InsensitiveStr::Ascii("serizations"),
        dictgen::InsensitiveStr::Ascii("serize"),
        dictgen::InsensitiveStr::Ascii("serized"),
        dictgen::InsensitiveStr::Ascii("serizes"),
        dictgen::InsensitiveStr::Ascii("serizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IMMISERIZATION_1212978393167876038)],
        &[(0b10010, &ENTRY_IMMISERIZATIONS_11180702474698433176)],
        &[(0b10010, &ENTRY_IMMISERIZE_11661578537191697492)],
        &[(0b10010, &ENTRY_IMMISERIZED_10641322361888904268)],
        &[(0b10010, &ENTRY_IMMISERIZES_17351381594017861987)],
        &[(0b10010, &ENTRY_IMMISERIZING_79621541282531560)],
        &[(0b01001, &ENTRY_IMMISERIZATION_1212978393167876038)],
        &[(0b01001, &ENTRY_IMMISERIZATIONS_11180702474698433176)],
        &[(0b01001, &ENTRY_IMMISERIZE_11661578537191697492)],
        &[(0b01001, &ENTRY_IMMISERIZED_10641322361888904268)],
        &[(0b01001, &ENTRY_IMMISERIZES_17351381594017861987)],
        &[(0b01001, &ENTRY_IMMISERIZING_79621541282531560)],
    ],
    range: 6..=11,
};

static VARS_IMMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMMA_CHILDREN),
    value: None,
};

pub static VARS_IMMA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("terialisation"),
        dictgen::InsensitiveStr::Ascii("terialise"),
        dictgen::InsensitiveStr::Ascii("terialised"),
        dictgen::InsensitiveStr::Ascii("terialises"),
        dictgen::InsensitiveStr::Ascii("terialising"),
        dictgen::InsensitiveStr::Ascii("terialization"),
        dictgen::InsensitiveStr::Ascii("terialize"),
        dictgen::InsensitiveStr::Ascii("terialized"),
        dictgen::InsensitiveStr::Ascii("terializes"),
        dictgen::InsensitiveStr::Ascii("terializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IMMATERIALIZATION_8380883612637374324)],
        &[(0b10010, &ENTRY_IMMATERIALIZE_14298505658374117395)],
        &[(0b10010, &ENTRY_IMMATERIALIZED_16945821848352162336)],
        &[(0b10010, &ENTRY_IMMATERIALIZES_6651277863813618111)],
        &[(0b10010, &ENTRY_IMMATERIALIZING_5412215182771884286)],
        &[(0b01001, &ENTRY_IMMATERIALIZATION_8380883612637374324)],
        &[(0b01001, &ENTRY_IMMATERIALIZE_14298505658374117395)],
        &[(0b01001, &ENTRY_IMMATERIALIZED_16945821848352162336)],
        &[(0b01001, &ENTRY_IMMATERIALIZES_6651277863813618111)],
        &[(0b01001, &ENTRY_IMMATERIALIZING_5412215182771884286)],
    ],
    range: 9..=13,
};

static VARS_IME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IME_CHILDREN),
    value: None,
};

pub static VARS_IME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("r")],
    values: &[&[(0b00001, &ENTRY_IMER_11358538646216832658)]],
    range: 1..=1,
};

static VARS_IMB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMB_CHILDREN),
    value: None,
};

pub static VARS_IMB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edment"),
        dictgen::InsensitiveStr::Ascii("edments"),
    ],
    values: &[
        &[(0b00001, &ENTRY_EMBEDMENT_4196454539976023920)],
        &[(0b00001, &ENTRY_EMBEDMENTS_3554420096971369231)],
    ],
    range: 6..=7,
};

static VARS_IL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IL_CHILDREN),
    value: None,
};

pub static VARS_IL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eocaecal"),
        dictgen::InsensitiveStr::Ascii("eocecal"),
        dictgen::InsensitiveStr::Ascii("iadise"),
        dictgen::InsensitiveStr::Ascii("iadises"),
        dictgen::InsensitiveStr::Ascii("iadize"),
        dictgen::InsensitiveStr::Ascii("iadizes"),
        dictgen::InsensitiveStr::Ascii("legalisation"),
        dictgen::InsensitiveStr::Ascii("legalisations"),
        dictgen::InsensitiveStr::Ascii("legalise"),
        dictgen::InsensitiveStr::Ascii("legalised"),
        dictgen::InsensitiveStr::Ascii("legalises"),
        dictgen::InsensitiveStr::Ascii("legalising"),
        dictgen::InsensitiveStr::Ascii("legalization"),
        dictgen::InsensitiveStr::Ascii("legalizations"),
        dictgen::InsensitiveStr::Ascii("legalize"),
        dictgen::InsensitiveStr::Ascii("legalized"),
        dictgen::InsensitiveStr::Ascii("legalizes"),
        dictgen::InsensitiveStr::Ascii("legalizing"),
        dictgen::InsensitiveStr::Ascii("legitimatise"),
        dictgen::InsensitiveStr::Ascii("legitimatised"),
        dictgen::InsensitiveStr::Ascii("legitimatises"),
        dictgen::InsensitiveStr::Ascii("legitimatising"),
        dictgen::InsensitiveStr::Ascii("legitimatize"),
        dictgen::InsensitiveStr::Ascii("legitimatized"),
        dictgen::InsensitiveStr::Ascii("legitimatizes"),
        dictgen::InsensitiveStr::Ascii("legitimatizing"),
        dictgen::InsensitiveStr::Ascii("liberalise"),
        dictgen::InsensitiveStr::Ascii("liberalised"),
        dictgen::InsensitiveStr::Ascii("liberalises"),
        dictgen::InsensitiveStr::Ascii("liberalising"),
        dictgen::InsensitiveStr::Ascii("liberalize"),
        dictgen::InsensitiveStr::Ascii("liberalized"),
        dictgen::InsensitiveStr::Ascii("liberalizes"),
        dictgen::InsensitiveStr::Ascii("liberalizing"),
        dictgen::InsensitiveStr::Ascii("luminise"),
        dictgen::InsensitiveStr::Ascii("luminises"),
        dictgen::InsensitiveStr::Ascii("luminize"),
        dictgen::InsensitiveStr::Ascii("luminizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ILEOCECAL_16522185353890210636)],
        &[(0b00001, &ENTRY_ILEOCECAL_16522185353890210636)],
        &[(0b10010, &ENTRY_ILIADIZE_14724051555313125629)],
        &[(0b10010, &ENTRY_ILIADIZES_6394336660130229939)],
        &[(0b01001, &ENTRY_ILIADIZE_14724051555313125629)],
        &[(0b01001, &ENTRY_ILIADIZES_6394336660130229939)],
        &[(0b10010, &ENTRY_ILLEGALIZATION_5065614305999469096)],
        &[(0b10010, &ENTRY_ILLEGALIZATIONS_13407750311781863370)],
        &[(0b10010, &ENTRY_ILLEGALIZE_17263792211302709645)],
        &[(0b10010, &ENTRY_ILLEGALIZED_1320492579784200491)],
        &[(0b10010, &ENTRY_ILLEGALIZES_11275140355726748310)],
        &[(0b10010, &ENTRY_ILLEGALIZING_7477590631836755179)],
        &[(0b01001, &ENTRY_ILLEGALIZATION_5065614305999469096)],
        &[(0b01001, &ENTRY_ILLEGALIZATIONS_13407750311781863370)],
        &[(0b01001, &ENTRY_ILLEGALIZE_17263792211302709645)],
        &[(0b01001, &ENTRY_ILLEGALIZED_1320492579784200491)],
        &[(0b01001, &ENTRY_ILLEGALIZES_11275140355726748310)],
        &[(0b01001, &ENTRY_ILLEGALIZING_7477590631836755179)],
        &[(0b10010, &ENTRY_ILLEGITIMATIZE_17918774402943591962)],
        &[(0b10010, &ENTRY_ILLEGITIMATIZED_7171891093799492298)],
        &[(0b10010, &ENTRY_ILLEGITIMATIZES_2052102366472178705)],
        &[(0b10010, &ENTRY_ILLEGITIMATIZING_17784745931325324901)],
        &[(0b01001, &ENTRY_ILLEGITIMATIZE_17918774402943591962)],
        &[(0b01001, &ENTRY_ILLEGITIMATIZED_7171891093799492298)],
        &[(0b01001, &ENTRY_ILLEGITIMATIZES_2052102366472178705)],
        &[(0b01001, &ENTRY_ILLEGITIMATIZING_17784745931325324901)],
        &[(0b10010, &ENTRY_ILLIBERALIZE_6577399060213673218)],
        &[(0b10010, &ENTRY_ILLIBERALIZED_6707533947713890737)],
        &[(0b10010, &ENTRY_ILLIBERALIZES_4937030393518036499)],
        &[(0b10010, &ENTRY_ILLIBERALIZING_13464989021623401848)],
        &[(0b01001, &ENTRY_ILLIBERALIZE_6577399060213673218)],
        &[(0b01001, &ENTRY_ILLIBERALIZED_6707533947713890737)],
        &[(0b01001, &ENTRY_ILLIBERALIZES_4937030393518036499)],
        &[(0b01001, &ENTRY_ILLIBERALIZING_13464989021623401848)],
        &[(0b10010, &ENTRY_ILLUMINIZE_14457097272904324504)],
        &[(0b10010, &ENTRY_ILLUMINIZES_16019239520986572742)],
        &[(0b01001, &ENTRY_ILLUMINIZE_14457097272904324504)],
        &[(0b01001, &ENTRY_ILLUMINIZES_16019239520986572742)],
    ],
    range: 6..=14,
};

static VARS_IE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IE_CHILDREN),
    value: None,
};

pub static VARS_IE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("r")],
    values: &[&[(0b00001, &ENTRY_IER_15235430992881202856)]],
    range: 1..=1,
};

static VARS_ID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ID_CHILDREN),
    value: None,
};

static VARS_ID_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_IDA_NODE),
    None,
    None,
    None,
    Some(&VARS_IDE_NODE),
    None,
    None,
    None,
    Some(&VARS_IDI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IDO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IDU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_IDU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IDU_CHILDREN),
    value: None,
};

pub static VARS_IDU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("maea"),
        dictgen::InsensitiveStr::Ascii("maean"),
        dictgen::InsensitiveStr::Ascii("maeans"),
        dictgen::InsensitiveStr::Ascii("mea"),
        dictgen::InsensitiveStr::Ascii("mean"),
        dictgen::InsensitiveStr::Ascii("means"),
    ],
    values: &[
        &[(0b11010, &ENTRY_IDUMEA_17899406367831340010)],
        &[(0b11010, &ENTRY_IDUMEAN_5255599416439761824)],
        &[(0b11010, &ENTRY_IDUMEANS_18228820638132012965)],
        &[(0b00001, &ENTRY_IDUMEA_17899406367831340010)],
        &[(0b00001, &ENTRY_IDUMEAN_5255599416439761824)],
        &[(0b00001, &ENTRY_IDUMEANS_18228820638132012965)],
    ],
    range: 3..=6,
};

static VARS_IDO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IDO_CHILDREN),
    value: None,
};

pub static VARS_IDO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("laster"),
        dictgen::InsensitiveStr::Ascii("lastre"),
        dictgen::InsensitiveStr::Ascii("latrise"),
        dictgen::InsensitiveStr::Ascii("latrised"),
        dictgen::InsensitiveStr::Ascii("latriser"),
        dictgen::InsensitiveStr::Ascii("latrises"),
        dictgen::InsensitiveStr::Ascii("latrising"),
        dictgen::InsensitiveStr::Ascii("latrize"),
        dictgen::InsensitiveStr::Ascii("latrized"),
        dictgen::InsensitiveStr::Ascii("latrizer"),
        dictgen::InsensitiveStr::Ascii("latrizes"),
        dictgen::InsensitiveStr::Ascii("latrizing"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("liser"),
        dictgen::InsensitiveStr::Ascii("lisers"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizer"),
        dictgen::InsensitiveStr::Ascii("lizers"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_IDOLASTER_1606884119199496212)],
        &[(0b11010, &ENTRY_IDOLASTER_1606884119199496212)],
        &[(0b10010, &ENTRY_IDOLATRIZE_17980797854680013339)],
        &[(0b10010, &ENTRY_IDOLATRIZED_10874059237199920636)],
        &[(0b10010, &ENTRY_IDOLATRIZER_9734451679415511293)],
        &[(0b10010, &ENTRY_IDOLATRIZES_16288993125152158763)],
        &[(0b10010, &ENTRY_IDOLATRIZING_1695347286696911693)],
        &[(0b01001, &ENTRY_IDOLATRIZE_17980797854680013339)],
        &[(0b01001, &ENTRY_IDOLATRIZED_10874059237199920636)],
        &[(0b01001, &ENTRY_IDOLATRIZER_9734451679415511293)],
        &[(0b01001, &ENTRY_IDOLATRIZES_16288993125152158763)],
        &[(0b01001, &ENTRY_IDOLATRIZING_1695347286696911693)],
        &[(0b10010, &ENTRY_IDOLIZATION_15105118948886829092)],
        &[(0b10010, &ENTRY_IDOLIZATIONS_4690624939733294253)],
        &[(0b10010, &ENTRY_IDOLIZE_8242557763652368312)],
        &[(0b10010, &ENTRY_IDOLIZED_3011013183847203085)],
        &[(0b10010, &ENTRY_IDOLIZER_6262630986106221245)],
        &[(0b10010, &ENTRY_IDOLIZERS_3155462085555547150)],
        &[(0b10010, &ENTRY_IDOLIZES_7288494209899528996)],
        &[(0b10010, &ENTRY_IDOLIZING_5172443194465202077)],
        &[(0b01001, &ENTRY_IDOLIZATION_15105118948886829092)],
        &[(0b01001, &ENTRY_IDOLIZATIONS_4690624939733294253)],
        &[(0b01001, &ENTRY_IDOLIZE_8242557763652368312)],
        &[(0b01001, &ENTRY_IDOLIZED_3011013183847203085)],
        &[(0b01001, &ENTRY_IDOLIZER_6262630986106221245)],
        &[(0b01001, &ENTRY_IDOLIZERS_3155462085555547150)],
        &[(0b01001, &ENTRY_IDOLIZES_7288494209899528996)],
        &[(0b01001, &ENTRY_IDOLIZING_5172443194465202077)],
    ],
    range: 4..=9,
};

static VARS_IDI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IDI_CHILDREN),
    value: None,
};

pub static VARS_IDI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otised"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otising"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otized"),
        dictgen::InsensitiveStr::Ascii("otizes"),
        dictgen::InsensitiveStr::Ascii("otizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IDIOTIZE_12917906860396891070)],
        &[(0b10010, &ENTRY_IDIOTIZED_6771429521996563043)],
        &[(0b10010, &ENTRY_IDIOTIZES_12814032023791935267)],
        &[(0b10010, &ENTRY_IDIOTIZING_5961105820849234369)],
        &[(0b01001, &ENTRY_IDIOTIZE_12917906860396891070)],
        &[(0b01001, &ENTRY_IDIOTIZED_6771429521996563043)],
        &[(0b01001, &ENTRY_IDIOTIZES_12814032023791935267)],
        &[(0b01001, &ENTRY_IDIOTIZING_5961105820849234369)],
    ],
    range: 5..=7,
};

static VARS_IDE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IDE_CHILDREN),
    value: None,
};

pub static VARS_IDE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("an"),
        dictgen::InsensitiveStr::Ascii("ologise"),
        dictgen::InsensitiveStr::Ascii("ologised"),
        dictgen::InsensitiveStr::Ascii("ologising"),
        dictgen::InsensitiveStr::Ascii("ologize"),
        dictgen::InsensitiveStr::Ascii("ologized"),
        dictgen::InsensitiveStr::Ascii("ologizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_IDEA_1183701720980357352)],
        &[(0b10010, &ENTRY_IDEALIZATION_13571578580847994239)],
        &[(0b10010, &ENTRY_IDEALIZATIONS_3729750012626226945)],
        &[(0b10010, &ENTRY_IDEALIZE_10907881421979440742)],
        &[(0b10010, &ENTRY_IDEALIZED_5103962997156504752)],
        &[(0b10010, &ENTRY_IDEALIZER_12565075479493888894)],
        &[(0b10010, &ENTRY_IDEALIZERS_13463195698737940264)],
        &[(0b10010, &ENTRY_IDEALIZES_17744034669185196667)],
        &[(0b10010, &ENTRY_IDEALIZING_1544218102413826617)],
        &[(0b01001, &ENTRY_IDEALIZATION_13571578580847994239)],
        &[(0b01001, &ENTRY_IDEALIZATIONS_3729750012626226945)],
        &[(0b01001, &ENTRY_IDEALIZE_10907881421979440742)],
        &[(0b01001, &ENTRY_IDEALIZED_5103962997156504752)],
        &[(0b01001, &ENTRY_IDEALIZER_12565075479493888894)],
        &[(0b01001, &ENTRY_IDEALIZERS_13463195698737940264)],
        &[(0b01001, &ENTRY_IDEALIZES_17744034669185196667)],
        &[(0b01001, &ENTRY_IDEALIZING_1544218102413826617)],
        &[(0b00001, &ENTRY_IDEAN_11620335570699525177)],
        &[(0b10010, &ENTRY_IDEOLOGIZE_6285081699594159906)],
        &[(0b10010, &ENTRY_IDEOLOGIZED_14733634681578557936)],
        &[(0b10010, &ENTRY_IDEOLOGIZING_15450303981107523469)],
        &[(0b01001, &ENTRY_IDEOLOGIZE_6285081699594159906)],
        &[(0b01001, &ENTRY_IDEOLOGIZED_14733634681578557936)],
        &[(0b01001, &ENTRY_IDEOLOGIZING_15450303981107523469)],
    ],
    range: 1..=10,
};

static VARS_IDA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IDA_CHILDREN),
    value: None,
};

pub static VARS_IDA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("ean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_IDEA_1183701720980357352)],
        &[(0b11010, &ENTRY_IDEAN_11620335570699525177)],
    ],
    range: 2..=3,
};

static VARS_IC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IC_CHILDREN),
    value: None,
};

pub static VARS_IC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hneumonised"),
        dictgen::InsensitiveStr::Ascii("hneumoniseds"),
        dictgen::InsensitiveStr::Ascii("hneumonized"),
        dictgen::InsensitiveStr::Ascii("hneumonizeds"),
        dictgen::InsensitiveStr::Ascii("horrhaemia"),
        dictgen::InsensitiveStr::Ascii("horrhea"),
        dictgen::InsensitiveStr::Ascii("horrhemia"),
        dictgen::InsensitiveStr::Ascii("horrhoea"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ICHNEUMONIZED_14580421766806791127)],
        &[(0b10010, &ENTRY_ICHNEUMONIZEDS_224406158324301972)],
        &[(0b01001, &ENTRY_ICHNEUMONIZED_14580421766806791127)],
        &[(0b01001, &ENTRY_ICHNEUMONIZEDS_224406158324301972)],
        &[(0b11010, &ENTRY_ICHORRHEMIA_5590679225774569274)],
        &[(0b10001, &ENTRY_ICHORRHEA_3856500369693916341)],
        &[(0b10001, &ENTRY_ICHORRHEMIA_5590679225774569274)],
        &[(0b11010, &ENTRY_ICHORRHEA_3856500369693916341)],
        &[(0b10010, &ENTRY_ICONIZE_11215091059030087912)],
        &[(0b10010, &ENTRY_ICONIZED_6721332614366408866)],
        &[(0b10010, &ENTRY_ICONIZES_18252899495281313317)],
        &[(0b10010, &ENTRY_ICONIZING_13309072660625193134)],
        &[(0b01001, &ENTRY_ICONIZE_11215091059030087912)],
        &[(0b01001, &ENTRY_ICONIZED_6721332614366408866)],
        &[(0b01001, &ENTRY_ICONIZES_18252899495281313317)],
        &[(0b01001, &ENTRY_ICONIZING_13309072660625193134)],
    ],
    range: 5..=12,
};

static VARS_H_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_H_CHILDREN),
    value: None,
};

static VARS_H_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HA_NODE),
    None,
    None,
    None,
    Some(&VARS_HE_NODE),
    None,
    None,
    None,
    Some(&VARS_HI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HU_NODE),
    None,
    None,
    None,
    Some(&VARS_HY_NODE),
    None,
];

static VARS_HY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HY_CHILDREN),
    value: None,
};

static VARS_HY_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HYA_NODE),
    Some(&VARS_HYB_NODE),
    None,
    Some(&VARS_HYD_NODE),
    Some(&VARS_HYE_NODE),
    None,
    Some(&VARS_HYG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HYM_NODE),
    None,
    None,
    Some(&VARS_HYP_NODE),
    None,
    None,
    Some(&VARS_HYS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HYS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYS_CHILDREN),
    value: None,
};

pub static VARS_HYS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("terectomise"),
        dictgen::InsensitiveStr::Ascii("terectomised"),
        dictgen::InsensitiveStr::Ascii("terectomises"),
        dictgen::InsensitiveStr::Ascii("terectomising"),
        dictgen::InsensitiveStr::Ascii("terectomize"),
        dictgen::InsensitiveStr::Ascii("terectomized"),
        dictgen::InsensitiveStr::Ascii("terectomizes"),
        dictgen::InsensitiveStr::Ascii("terectomizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYSTERECTOMIZE_8681246009628031525)],
        &[(0b10010, &ENTRY_HYSTERECTOMIZED_8515162559842878159)],
        &[(0b10010, &ENTRY_HYSTERECTOMIZES_12491381132060525295)],
        &[(0b10010, &ENTRY_HYSTERECTOMIZING_6176446475438696766)],
        &[(0b01001, &ENTRY_HYSTERECTOMIZE_8681246009628031525)],
        &[(0b01001, &ENTRY_HYSTERECTOMIZED_8515162559842878159)],
        &[(0b01001, &ENTRY_HYSTERECTOMIZES_12491381132060525295)],
        &[(0b01001, &ENTRY_HYSTERECTOMIZING_6176446475438696766)],
    ],
    range: 11..=13,
};

static VARS_HYP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HYP_CHILDREN),
    value: None,
};

static VARS_HYP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HYPA_NODE),
    None,
    None,
    None,
    Some(&VARS_HYPE_NODE),
    None,
    None,
    Some(&VARS_HYPH_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HYPN_NODE),
    Some(&VARS_HYPO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HYPO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HYPO_CHILDREN),
    value: None,
};

static VARS_HYPO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_HYPOC_NODE),
    None,
    None,
    None,
    Some(&VARS_HYPOG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HYPOM_NODE),
    None,
    None,
    Some(&VARS_HYPOP_NODE),
    None,
    None,
    Some(&VARS_HYPOS_NODE),
    Some(&VARS_HYPOT_NODE),
    None,
    None,
    None,
    Some(&VARS_HYPOX_NODE),
    None,
    None,
];

static VARS_HYPOX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOX_CHILDREN),
    value: None,
};

pub static VARS_HYPOX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("aemias"),
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emias"),
        dictgen::InsensitiveStr::Ascii("emic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPOXEMIA_17993402685193079339)],
        &[(0b11010, &ENTRY_HYPOXEMIAS_14672501546678381889)],
        &[(0b11010, &ENTRY_HYPOXEMIC_17342712296732938343)],
        &[(0b10001, &ENTRY_HYPOXEMIA_17993402685193079339)],
        &[(0b10001, &ENTRY_HYPOXEMIAS_14672501546678381889)],
        &[(0b10001, &ENTRY_HYPOXEMIC_17342712296732938343)],
    ],
    range: 4..=6,
};

static VARS_HYPOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOT_CHILDREN),
    value: None,
};

pub static VARS_HYPOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hesise"),
        dictgen::InsensitiveStr::Ascii("hesised"),
        dictgen::InsensitiveStr::Ascii("hesiser"),
        dictgen::InsensitiveStr::Ascii("hesisers"),
        dictgen::InsensitiveStr::Ascii("hesises"),
        dictgen::InsensitiveStr::Ascii("hesising"),
        dictgen::InsensitiveStr::Ascii("hesize"),
        dictgen::InsensitiveStr::Ascii("hesized"),
        dictgen::InsensitiveStr::Ascii("hesizer"),
        dictgen::InsensitiveStr::Ascii("hesizers"),
        dictgen::InsensitiveStr::Ascii("hesizes"),
        dictgen::InsensitiveStr::Ascii("hesizing"),
        dictgen::InsensitiveStr::Ascii("hetise"),
        dictgen::InsensitiveStr::Ascii("hetised"),
        dictgen::InsensitiveStr::Ascii("hetises"),
        dictgen::InsensitiveStr::Ascii("hetising"),
        dictgen::InsensitiveStr::Ascii("hetize"),
        dictgen::InsensitiveStr::Ascii("hetized"),
        dictgen::InsensitiveStr::Ascii("hetizes"),
        dictgen::InsensitiveStr::Ascii("hetizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPOTHESIZE_3825963791328606413)],
        &[(0b10010, &ENTRY_HYPOTHESIZED_14110128970476142821)],
        &[(0b10010, &ENTRY_HYPOTHESIZER_2472052824551896236)],
        &[(0b10010, &ENTRY_HYPOTHESIZERS_55820786179370701)],
        &[(0b10010, &ENTRY_HYPOTHESIZES_3305988013143404614)],
        &[(0b10010, &ENTRY_HYPOTHESIZING_7325923156843990124)],
        &[(0b01001, &ENTRY_HYPOTHESIZE_3825963791328606413)],
        &[(0b01001, &ENTRY_HYPOTHESIZED_14110128970476142821)],
        &[(0b01001, &ENTRY_HYPOTHESIZER_2472052824551896236)],
        &[(0b01001, &ENTRY_HYPOTHESIZERS_55820786179370701)],
        &[(0b01001, &ENTRY_HYPOTHESIZES_3305988013143404614)],
        &[(0b01001, &ENTRY_HYPOTHESIZING_7325923156843990124)],
        &[(0b10010, &ENTRY_HYPOTHETIZE_12616552221739079011)],
        &[(0b10010, &ENTRY_HYPOTHETIZED_8186536952516454687)],
        &[(0b10010, &ENTRY_HYPOTHETIZES_5252732551677489496)],
        &[(0b10010, &ENTRY_HYPOTHETIZING_12650785144462407190)],
        &[(0b01001, &ENTRY_HYPOTHETIZE_12616552221739079011)],
        &[(0b01001, &ENTRY_HYPOTHETIZED_8186536952516454687)],
        &[(0b01001, &ENTRY_HYPOTHETIZES_5252732551677489496)],
        &[(0b01001, &ENTRY_HYPOTHETIZING_12650785144462407190)],
    ],
    range: 6..=8,
};

static VARS_HYPOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOS_CHILDREN),
    value: None,
};

pub static VARS_HYPOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ensitisation"),
        dictgen::InsensitiveStr::Ascii("ensitise"),
        dictgen::InsensitiveStr::Ascii("ensitization"),
        dictgen::InsensitiveStr::Ascii("ensitize"),
        dictgen::InsensitiveStr::Ascii("tasise"),
        dictgen::InsensitiveStr::Ascii("tasised"),
        dictgen::InsensitiveStr::Ascii("tasises"),
        dictgen::InsensitiveStr::Ascii("tasising"),
        dictgen::InsensitiveStr::Ascii("tasize"),
        dictgen::InsensitiveStr::Ascii("tasized"),
        dictgen::InsensitiveStr::Ascii("tasizes"),
        dictgen::InsensitiveStr::Ascii("tasizing"),
        dictgen::InsensitiveStr::Ascii("tatisation"),
        dictgen::InsensitiveStr::Ascii("tatisations"),
        dictgen::InsensitiveStr::Ascii("tatise"),
        dictgen::InsensitiveStr::Ascii("tatised"),
        dictgen::InsensitiveStr::Ascii("tatises"),
        dictgen::InsensitiveStr::Ascii("tatising"),
        dictgen::InsensitiveStr::Ascii("tatization"),
        dictgen::InsensitiveStr::Ascii("tatizations"),
        dictgen::InsensitiveStr::Ascii("tatize"),
        dictgen::InsensitiveStr::Ascii("tatized"),
        dictgen::InsensitiveStr::Ascii("tatizes"),
        dictgen::InsensitiveStr::Ascii("tatizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPOSENSITIZATION_15528129983330572518)],
        &[(0b10010, &ENTRY_HYPOSENSITIZE_5903465904740790285)],
        &[(0b01001, &ENTRY_HYPOSENSITIZATION_15528129983330572518)],
        &[(0b01001, &ENTRY_HYPOSENSITIZE_5903465904740790285)],
        &[(0b10010, &ENTRY_HYPOSTASIZE_16100413099795742054)],
        &[(0b10010, &ENTRY_HYPOSTASIZED_11672079523808552915)],
        &[(0b10010, &ENTRY_HYPOSTASIZES_12098952916923008604)],
        &[(0b10010, &ENTRY_HYPOSTASIZING_8088482663168944782)],
        &[(0b01001, &ENTRY_HYPOSTASIZE_16100413099795742054)],
        &[(0b01001, &ENTRY_HYPOSTASIZED_11672079523808552915)],
        &[(0b01001, &ENTRY_HYPOSTASIZES_12098952916923008604)],
        &[(0b01001, &ENTRY_HYPOSTASIZING_8088482663168944782)],
        &[(0b10010, &ENTRY_HYPOSTATIZATION_11089927936491984161)],
        &[(0b10010, &ENTRY_HYPOSTATIZATIONS_6954932085574725526)],
        &[(0b10010, &ENTRY_HYPOSTATIZE_18306361123837315572)],
        &[(0b10010, &ENTRY_HYPOSTATIZED_1632743900632980509)],
        &[(0b10010, &ENTRY_HYPOSTATIZES_6850133111163957406)],
        &[(0b10010, &ENTRY_HYPOSTATIZING_7675432982784792920)],
        &[(0b01001, &ENTRY_HYPOSTATIZATION_11089927936491984161)],
        &[(0b01001, &ENTRY_HYPOSTATIZATIONS_6954932085574725526)],
        &[(0b01001, &ENTRY_HYPOSTATIZE_18306361123837315572)],
        &[(0b01001, &ENTRY_HYPOSTATIZED_1632743900632980509)],
        &[(0b01001, &ENTRY_HYPOSTATIZES_6850133111163957406)],
        &[(0b01001, &ENTRY_HYPOSTATIZING_7675432982784792920)],
    ],
    range: 6..=12,
};

static VARS_HYPOP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOP_CHILDREN),
    value: None,
};

pub static VARS_HYPOP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hysectomise"),
        dictgen::InsensitiveStr::Ascii("hysectomised"),
        dictgen::InsensitiveStr::Ascii("hysectomize"),
        dictgen::InsensitiveStr::Ascii("hysectomized"),
        dictgen::InsensitiveStr::Ascii("nea"),
        dictgen::InsensitiveStr::Ascii("noea"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPOPHYSECTOMIZE_7441432223206368484)],
        &[(0b10010, &ENTRY_HYPOPHYSECTOMIZED_11810018005356862443)],
        &[(0b01001, &ENTRY_HYPOPHYSECTOMIZE_7441432223206368484)],
        &[(0b01001, &ENTRY_HYPOPHYSECTOMIZED_11810018005356862443)],
        &[(0b10001, &ENTRY_HYPOPNEA_8136477563229617115)],
        &[(0b11010, &ENTRY_HYPOPNEA_8136477563229617115)],
    ],
    range: 3..=12,
};

static VARS_HYPOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOM_CHILDREN),
    value: None,
};

pub static VARS_HYPOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agnesaemia"),
        dictgen::InsensitiveStr::Ascii("agnesaemias"),
        dictgen::InsensitiveStr::Ascii("agnesemia"),
        dictgen::InsensitiveStr::Ascii("agnesemias"),
        dictgen::InsensitiveStr::Ascii("enorrhea"),
        dictgen::InsensitiveStr::Ascii("enorrheas"),
        dictgen::InsensitiveStr::Ascii("enorrhoea"),
        dictgen::InsensitiveStr::Ascii("enorrhoeas"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPOMAGNESEMIA_13749607509052652094)],
        &[(0b11010, &ENTRY_HYPOMAGNESEMIAS_7320429522378376279)],
        &[(0b10001, &ENTRY_HYPOMAGNESEMIA_13749607509052652094)],
        &[(0b10001, &ENTRY_HYPOMAGNESEMIAS_7320429522378376279)],
        &[(0b10001, &ENTRY_HYPOMENORRHEA_4150580092110671155)],
        &[(0b10001, &ENTRY_HYPOMENORRHEAS_12448521431273870133)],
        &[(0b11010, &ENTRY_HYPOMENORRHEA_4150580092110671155)],
        &[(0b11010, &ENTRY_HYPOMENORRHEAS_12448521431273870133)],
    ],
    range: 8..=11,
};

static VARS_HYPOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOG_CHILDREN),
    value: None,
};

pub static VARS_HYPOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aea"),
        dictgen::InsensitiveStr::Ascii("aeal"),
        dictgen::InsensitiveStr::Ascii("aean"),
        dictgen::InsensitiveStr::Ascii("aeic"),
        dictgen::InsensitiveStr::Ascii("aeous"),
        dictgen::InsensitiveStr::Ascii("aeum"),
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("eal"),
        dictgen::InsensitiveStr::Ascii("ean"),
        dictgen::InsensitiveStr::Ascii("eic"),
        dictgen::InsensitiveStr::Ascii("eous"),
        dictgen::InsensitiveStr::Ascii("eum"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPOGEA_5547650658352096585)],
        &[(0b11010, &ENTRY_HYPOGEAL_16228427341032137597)],
        &[(0b11010, &ENTRY_HYPOGEAN_817591283440453496)],
        &[(0b11010, &ENTRY_HYPOGEIC_17994122167340611658)],
        &[(0b11010, &ENTRY_HYPOGEOUS_18395587689172074500)],
        &[(0b11010, &ENTRY_HYPOGEUM_692403338728273782)],
        &[(0b10001, &ENTRY_HYPOGEA_5547650658352096585)],
        &[(0b10001, &ENTRY_HYPOGEAL_16228427341032137597)],
        &[(0b10001, &ENTRY_HYPOGEAN_817591283440453496)],
        &[(0b10001, &ENTRY_HYPOGEIC_17994122167340611658)],
        &[(0b10001, &ENTRY_HYPOGEOUS_18395587689172074500)],
        &[(0b10001, &ENTRY_HYPOGEUM_692403338728273782)],
    ],
    range: 2..=5,
};

static VARS_HYPOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOC_CHILDREN),
    value: None,
};

pub static VARS_HYPOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("enters"),
        dictgen::InsensitiveStr::Ascii("entre"),
        dictgen::InsensitiveStr::Ascii("entres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HYPOCENTER_313042704668341320)],
        &[(0b00001, &ENTRY_HYPOCENTERS_7336977377559114220)],
        &[(0b11010, &ENTRY_HYPOCENTER_313042704668341320)],
        &[(0b11010, &ENTRY_HYPOCENTERS_7336977377559114220)],
    ],
    range: 5..=6,
};

static VARS_HYPN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPN_CHILDREN),
    value: None,
};

pub static VARS_HYPN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oidise"),
        dictgen::InsensitiveStr::Ascii("oidised"),
        dictgen::InsensitiveStr::Ascii("oidises"),
        dictgen::InsensitiveStr::Ascii("oidising"),
        dictgen::InsensitiveStr::Ascii("oidize"),
        dictgen::InsensitiveStr::Ascii("oidized"),
        dictgen::InsensitiveStr::Ascii("oidizes"),
        dictgen::InsensitiveStr::Ascii("oidizing"),
        dictgen::InsensitiveStr::Ascii("opaedia"),
        dictgen::InsensitiveStr::Ascii("opaedias"),
        dictgen::InsensitiveStr::Ascii("opedia"),
        dictgen::InsensitiveStr::Ascii("opedias"),
        dictgen::InsensitiveStr::Ascii("otisabilities"),
        dictgen::InsensitiveStr::Ascii("otisability"),
        dictgen::InsensitiveStr::Ascii("otisable"),
        dictgen::InsensitiveStr::Ascii("otisabler"),
        dictgen::InsensitiveStr::Ascii("otisables"),
        dictgen::InsensitiveStr::Ascii("otisablest"),
        dictgen::InsensitiveStr::Ascii("otisation"),
        dictgen::InsensitiveStr::Ascii("otisations"),
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otised"),
        dictgen::InsensitiveStr::Ascii("otiser"),
        dictgen::InsensitiveStr::Ascii("otisers"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otising"),
        dictgen::InsensitiveStr::Ascii("otizabilities"),
        dictgen::InsensitiveStr::Ascii("otizability"),
        dictgen::InsensitiveStr::Ascii("otizable"),
        dictgen::InsensitiveStr::Ascii("otizabler"),
        dictgen::InsensitiveStr::Ascii("otizables"),
        dictgen::InsensitiveStr::Ascii("otizablest"),
        dictgen::InsensitiveStr::Ascii("otization"),
        dictgen::InsensitiveStr::Ascii("otizations"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otized"),
        dictgen::InsensitiveStr::Ascii("otizer"),
        dictgen::InsensitiveStr::Ascii("otizers"),
        dictgen::InsensitiveStr::Ascii("otizes"),
        dictgen::InsensitiveStr::Ascii("otizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPNOIDIZE_879115482501125749)],
        &[(0b10010, &ENTRY_HYPNOIDIZED_8369898236853174546)],
        &[(0b10010, &ENTRY_HYPNOIDIZES_2097426277708644881)],
        &[(0b10010, &ENTRY_HYPNOIDIZING_6170044007311971095)],
        &[(0b01001, &ENTRY_HYPNOIDIZE_879115482501125749)],
        &[(0b01001, &ENTRY_HYPNOIDIZED_8369898236853174546)],
        &[(0b01001, &ENTRY_HYPNOIDIZES_2097426277708644881)],
        &[(0b01001, &ENTRY_HYPNOIDIZING_6170044007311971095)],
        &[(0b11010, &ENTRY_HYPNOPEDIA_15887285651417738221)],
        &[(0b11010, &ENTRY_HYPNOPEDIAS_9606774705113272510)],
        &[(0b10001, &ENTRY_HYPNOPEDIA_15887285651417738221)],
        &[(0b10001, &ENTRY_HYPNOPEDIAS_9606774705113272510)],
        &[(0b10010, &ENTRY_HYPNOTIZABILITIES_3555702283468310358)],
        &[(0b10010, &ENTRY_HYPNOTIZABILITY_3193312628696225164)],
        &[(0b10010, &ENTRY_HYPNOTIZABLE_1111458195931571372)],
        &[(0b10010, &ENTRY_HYPNOTIZABLER_16475549704606191881)],
        &[(0b10010, &ENTRY_HYPNOTIZABLES_15256571692608743267)],
        &[(0b10010, &ENTRY_HYPNOTIZABLEST_570003064636075490)],
        &[(0b10010, &ENTRY_HYPNOTIZATION_7421948723228572667)],
        &[(0b10010, &ENTRY_HYPNOTIZATIONS_1603572274241018729)],
        &[(0b10010, &ENTRY_HYPNOTIZE_15259856905514903130)],
        &[(0b10010, &ENTRY_HYPNOTIZED_3155367972836581303)],
        &[(0b10010, &ENTRY_HYPNOTIZER_2163198826903259375)],
        &[(0b10010, &ENTRY_HYPNOTIZERS_18259914050110653108)],
        &[(0b10010, &ENTRY_HYPNOTIZES_15369403272790064853)],
        &[(0b10010, &ENTRY_HYPNOTIZING_12709364564970055556)],
        &[(0b01001, &ENTRY_HYPNOTIZABILITIES_3555702283468310358)],
        &[(0b01001, &ENTRY_HYPNOTIZABILITY_3193312628696225164)],
        &[(0b01001, &ENTRY_HYPNOTIZABLE_1111458195931571372)],
        &[(0b01001, &ENTRY_HYPNOTIZABLER_16475549704606191881)],
        &[(0b01001, &ENTRY_HYPNOTIZABLES_15256571692608743267)],
        &[(0b01001, &ENTRY_HYPNOTIZABLEST_570003064636075490)],
        &[(0b01001, &ENTRY_HYPNOTIZATION_7421948723228572667)],
        &[(0b01001, &ENTRY_HYPNOTIZATIONS_1603572274241018729)],
        &[(0b01001, &ENTRY_HYPNOTIZE_15259856905514903130)],
        &[(0b01001, &ENTRY_HYPNOTIZED_3155367972836581303)],
        &[(0b01001, &ENTRY_HYPNOTIZER_2163198826903259375)],
        &[(0b01001, &ENTRY_HYPNOTIZERS_18259914050110653108)],
        &[(0b01001, &ENTRY_HYPNOTIZES_15369403272790064853)],
        &[(0b01001, &ENTRY_HYPNOTIZING_12709364564970055556)],
    ],
    range: 5..=13,
};

static VARS_HYPH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPH_CHILDREN),
    value: None,
};

pub static VARS_HYPH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enisation"),
        dictgen::InsensitiveStr::Ascii("enisations"),
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("enised"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enising"),
        dictgen::InsensitiveStr::Ascii("enization"),
        dictgen::InsensitiveStr::Ascii("enizations"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enized"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("enizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPHENIZATION_10017420697137470773)],
        &[(0b10010, &ENTRY_HYPHENIZATIONS_8540218098232685932)],
        &[(0b10010, &ENTRY_HYPHENIZE_15302714032482214487)],
        &[(0b10010, &ENTRY_HYPHENIZED_14280183610433481117)],
        &[(0b10010, &ENTRY_HYPHENIZES_15047089195146038815)],
        &[(0b10010, &ENTRY_HYPHENIZING_14826999785045511543)],
        &[(0b01001, &ENTRY_HYPHENIZATION_10017420697137470773)],
        &[(0b01001, &ENTRY_HYPHENIZATIONS_8540218098232685932)],
        &[(0b01001, &ENTRY_HYPHENIZE_15302714032482214487)],
        &[(0b01001, &ENTRY_HYPHENIZED_14280183610433481117)],
        &[(0b01001, &ENTRY_HYPHENIZES_15047089195146038815)],
        &[(0b01001, &ENTRY_HYPHENIZING_14826999785045511543)],
    ],
    range: 5..=10,
};

static VARS_HYPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HYPE_CHILDREN),
    value: None,
};

static VARS_HYPE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HYPER_NODE),
    Some(&VARS_HYPES_NODE),
    Some(&VARS_HYPET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HYPET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPET_CHILDREN),
    value: None,
};

pub static VARS_HYPET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("hral")],
    values: &[&[(0b10001, &ENTRY_HYPETHRAL_14201019373187172019)]],
    range: 4..=4,
};

static VARS_HYPES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPES_CHILDREN),
    value: None,
};

pub static VARS_HYPES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thesia"),
        dictgen::InsensitiveStr::Ascii("thesias"),
        dictgen::InsensitiveStr::Ascii("thesic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HYPESTHESIA_16196465189141300744)],
        &[(0b10001, &ENTRY_HYPESTHESIAS_1838024351778836132)],
        &[(0b10001, &ENTRY_HYPESTHESIC_16905452400970791194)],
    ],
    range: 6..=7,
};

static VARS_HYPER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HYPER_CHILDREN),
    value: None,
};

static VARS_HYPER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HYPERA_NODE),
    Some(&VARS_HYPERB_NODE),
    Some(&VARS_HYPERC_NODE),
    None,
    Some(&VARS_HYPERE_NODE),
    None,
    Some(&VARS_HYPERG_NODE),
    None,
    Some(&VARS_HYPERI_NODE),
    None,
    None,
    Some(&VARS_HYPERL_NODE),
    None,
    Some(&VARS_HYPERN_NODE),
    Some(&VARS_HYPERO_NODE),
    Some(&VARS_HYPERP_NODE),
    None,
    Some(&VARS_HYPERR_NODE),
    Some(&VARS_HYPERS_NODE),
    Some(&VARS_HYPERT_NODE),
    None,
    Some(&VARS_HYPERV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_HYPERV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERV_CHILDREN),
    value: None,
};

pub static VARS_HYPERV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("italisation"),
        dictgen::InsensitiveStr::Ascii("italisations"),
        dictgen::InsensitiveStr::Ascii("italise"),
        dictgen::InsensitiveStr::Ascii("italises"),
        dictgen::InsensitiveStr::Ascii("italization"),
        dictgen::InsensitiveStr::Ascii("italizations"),
        dictgen::InsensitiveStr::Ascii("italize"),
        dictgen::InsensitiveStr::Ascii("italizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERVITALIZATION_15336704625235287557)],
        &[(0b10010, &ENTRY_HYPERVITALIZATIONS_5318502760253977651)],
        &[(0b10010, &ENTRY_HYPERVITALIZE_10124681016900035288)],
        &[(0b10010, &ENTRY_HYPERVITALIZES_3178121801376655810)],
        &[(0b01001, &ENTRY_HYPERVITALIZATION_15336704625235287557)],
        &[(0b01001, &ENTRY_HYPERVITALIZATIONS_5318502760253977651)],
        &[(0b01001, &ENTRY_HYPERVITALIZE_10124681016900035288)],
        &[(0b01001, &ENTRY_HYPERVITALIZES_3178121801376655810)],
    ],
    range: 7..=12,
};

static VARS_HYPERT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERT_CHILDREN),
    value: None,
};

pub static VARS_HYPERT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hyroidisation"),
        dictgen::InsensitiveStr::Ascii("hyroidisations"),
        dictgen::InsensitiveStr::Ascii("hyroidise"),
        dictgen::InsensitiveStr::Ascii("hyroidises"),
        dictgen::InsensitiveStr::Ascii("hyroidization"),
        dictgen::InsensitiveStr::Ascii("hyroidizations"),
        dictgen::InsensitiveStr::Ascii("hyroidize"),
        dictgen::InsensitiveStr::Ascii("hyroidizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERTHYROIDIZATION_13217016915972693933)],
        &[(0b10010, &ENTRY_HYPERTHYROIDIZATIONS_1743064878801216887)],
        &[(0b10010, &ENTRY_HYPERTHYROIDIZE_5417946722085898259)],
        &[(0b10010, &ENTRY_HYPERTHYROIDIZES_11754202158703775232)],
        &[(0b01001, &ENTRY_HYPERTHYROIDIZATION_13217016915972693933)],
        &[(0b01001, &ENTRY_HYPERTHYROIDIZATIONS_1743064878801216887)],
        &[(0b01001, &ENTRY_HYPERTHYROIDIZE_5417946722085898259)],
        &[(0b01001, &ENTRY_HYPERTHYROIDIZES_11754202158703775232)],
    ],
    range: 9..=14,
};

static VARS_HYPERS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERS_CHILDREN),
    value: None,
};

pub static VARS_HYPERS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ensitisation"),
        dictgen::InsensitiveStr::Ascii("ensitisations"),
        dictgen::InsensitiveStr::Ascii("ensitise"),
        dictgen::InsensitiveStr::Ascii("ensitised"),
        dictgen::InsensitiveStr::Ascii("ensitises"),
        dictgen::InsensitiveStr::Ascii("ensitising"),
        dictgen::InsensitiveStr::Ascii("ensitization"),
        dictgen::InsensitiveStr::Ascii("ensitizations"),
        dictgen::InsensitiveStr::Ascii("ensitize"),
        dictgen::InsensitiveStr::Ascii("ensitized"),
        dictgen::InsensitiveStr::Ascii("ensitizes"),
        dictgen::InsensitiveStr::Ascii("ensitizing"),
        dictgen::InsensitiveStr::Ascii("piritualising"),
        dictgen::InsensitiveStr::Ascii("piritualisings"),
        dictgen::InsensitiveStr::Ascii("piritualizing"),
        dictgen::InsensitiveStr::Ascii("piritualizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERSENSITIZATION_2559704586898281279)],
        &[(0b10010, &ENTRY_HYPERSENSITIZATIONS_14693900323393495348)],
        &[(0b10010, &ENTRY_HYPERSENSITIZE_6280726783656545963)],
        &[(0b10010, &ENTRY_HYPERSENSITIZED_7944194294133330943)],
        &[(0b10010, &ENTRY_HYPERSENSITIZES_6762279008165528502)],
        &[(0b10010, &ENTRY_HYPERSENSITIZING_3535038257675270244)],
        &[(0b01001, &ENTRY_HYPERSENSITIZATION_2559704586898281279)],
        &[(0b01001, &ENTRY_HYPERSENSITIZATIONS_14693900323393495348)],
        &[(0b01001, &ENTRY_HYPERSENSITIZE_6280726783656545963)],
        &[(0b01001, &ENTRY_HYPERSENSITIZED_7944194294133330943)],
        &[(0b01001, &ENTRY_HYPERSENSITIZES_6762279008165528502)],
        &[(0b01001, &ENTRY_HYPERSENSITIZING_3535038257675270244)],
        &[(0b10010, &ENTRY_HYPERSPIRITUALIZING_16460640116515835042)],
        &[(0b10010, &ENTRY_HYPERSPIRITUALIZINGS_14278575746904121990)],
        &[(0b01001, &ENTRY_HYPERSPIRITUALIZING_16460640116515835042)],
        &[(0b01001, &ENTRY_HYPERSPIRITUALIZINGS_14278575746904121990)],
    ],
    range: 8..=14,
};

static VARS_HYPERR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERR_CHILDREN),
    value: None,
};

pub static VARS_HYPERR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ealise"),
        dictgen::InsensitiveStr::Ascii("ealises"),
        dictgen::InsensitiveStr::Ascii("ealize"),
        dictgen::InsensitiveStr::Ascii("ealizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERREALIZE_555118691017631561)],
        &[(0b10010, &ENTRY_HYPERREALIZES_816890107094523513)],
        &[(0b01001, &ENTRY_HYPERREALIZE_555118691017631561)],
        &[(0b01001, &ENTRY_HYPERREALIZES_816890107094523513)],
    ],
    range: 6..=7,
};

static VARS_HYPERP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERP_CHILDREN),
    value: None,
};

pub static VARS_HYPERP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arasitise"),
        dictgen::InsensitiveStr::Ascii("arasitises"),
        dictgen::InsensitiveStr::Ascii("arasitize"),
        dictgen::InsensitiveStr::Ascii("arasitizes"),
        dictgen::InsensitiveStr::Ascii("nea"),
        dictgen::InsensitiveStr::Ascii("noea"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERPARASITIZE_16105780322488378828)],
        &[(0b10010, &ENTRY_HYPERPARASITIZES_14079459076340974669)],
        &[(0b01001, &ENTRY_HYPERPARASITIZE_16105780322488378828)],
        &[(0b01001, &ENTRY_HYPERPARASITIZES_14079459076340974669)],
        &[(0b10001, &ENTRY_HYPERPNEA_11441677197331315893)],
        &[(0b11010, &ENTRY_HYPERPNEA_11441677197331315893)],
    ],
    range: 3..=10,
};

static VARS_HYPERO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERO_CHILDREN),
    value: None,
};

pub static VARS_HYPERO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("xygenise"),
        dictgen::InsensitiveStr::Ascii("xygenises"),
        dictgen::InsensitiveStr::Ascii("xygenize"),
        dictgen::InsensitiveStr::Ascii("xygenizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPEROXYGENIZE_4509020112349763954)],
        &[(0b10010, &ENTRY_HYPEROXYGENIZES_1378354644160911943)],
        &[(0b01001, &ENTRY_HYPEROXYGENIZE_4509020112349763954)],
        &[(0b01001, &ENTRY_HYPEROXYGENIZES_1378354644160911943)],
    ],
    range: 8..=9,
};

static VARS_HYPERN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERN_CHILDREN),
    value: None,
};

pub static VARS_HYPERN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atraemia"),
        dictgen::InsensitiveStr::Ascii("atremia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPERNATREMIA_15755713506919882473)],
        &[(0b10001, &ENTRY_HYPERNATREMIA_15755713506919882473)],
    ],
    range: 7..=8,
};

static VARS_HYPERL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERL_CHILDREN),
    value: None,
};

pub static VARS_HYPERL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ipaemia"),
        dictgen::InsensitiveStr::Ascii("ipaemic"),
        dictgen::InsensitiveStr::Ascii("ipemia"),
        dictgen::InsensitiveStr::Ascii("ipemic"),
        dictgen::InsensitiveStr::Ascii("ipidaemia"),
        dictgen::InsensitiveStr::Ascii("ipidemia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPERLIPEMIA_17092876738860011414)],
        &[(0b11010, &ENTRY_HYPERLIPEMIC_43883570874153479)],
        &[(0b10001, &ENTRY_HYPERLIPEMIA_17092876738860011414)],
        &[(0b10001, &ENTRY_HYPERLIPEMIC_43883570874153479)],
        &[(0b11010, &ENTRY_HYPERLIPIDEMIA_11437229962186470279)],
        &[(0b10001, &ENTRY_HYPERLIPIDEMIA_11437229962186470279)],
    ],
    range: 6..=9,
};

static VARS_HYPERI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERI_CHILDREN),
    value: None,
};

pub static VARS_HYPERI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mmunisation"),
        dictgen::InsensitiveStr::Ascii("mmunisations"),
        dictgen::InsensitiveStr::Ascii("mmunise"),
        dictgen::InsensitiveStr::Ascii("mmunises"),
        dictgen::InsensitiveStr::Ascii("mmunization"),
        dictgen::InsensitiveStr::Ascii("mmunizations"),
        dictgen::InsensitiveStr::Ascii("mmunize"),
        dictgen::InsensitiveStr::Ascii("mmunizes"),
        dictgen::InsensitiveStr::Ascii("nsulinisation"),
        dictgen::InsensitiveStr::Ascii("nsulinisations"),
        dictgen::InsensitiveStr::Ascii("nsulinise"),
        dictgen::InsensitiveStr::Ascii("nsulinises"),
        dictgen::InsensitiveStr::Ascii("nsulinization"),
        dictgen::InsensitiveStr::Ascii("nsulinizations"),
        dictgen::InsensitiveStr::Ascii("nsulinize"),
        dictgen::InsensitiveStr::Ascii("nsulinizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERIMMUNIZATION_2495485152326430573)],
        &[(0b10010, &ENTRY_HYPERIMMUNIZATIONS_4951142413886672236)],
        &[(0b10010, &ENTRY_HYPERIMMUNIZE_9019335689416385702)],
        &[(0b10010, &ENTRY_HYPERIMMUNIZES_12098415096912500474)],
        &[(0b01001, &ENTRY_HYPERIMMUNIZATION_2495485152326430573)],
        &[(0b01001, &ENTRY_HYPERIMMUNIZATIONS_4951142413886672236)],
        &[(0b01001, &ENTRY_HYPERIMMUNIZE_9019335689416385702)],
        &[(0b01001, &ENTRY_HYPERIMMUNIZES_12098415096912500474)],
        &[(0b10010, &ENTRY_HYPERINSULINIZATION_2999598606550891341)],
        &[(0b10010, &ENTRY_HYPERINSULINIZATIONS_9195485943946903403)],
        &[(0b10010, &ENTRY_HYPERINSULINIZE_14913679736749969579)],
        &[(0b10010, &ENTRY_HYPERINSULINIZES_12978176799201291300)],
        &[(0b01001, &ENTRY_HYPERINSULINIZATION_2999598606550891341)],
        &[(0b01001, &ENTRY_HYPERINSULINIZATIONS_9195485943946903403)],
        &[(0b01001, &ENTRY_HYPERINSULINIZE_14913679736749969579)],
        &[(0b01001, &ENTRY_HYPERINSULINIZES_12978176799201291300)],
    ],
    range: 7..=14,
};

static VARS_HYPERG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERG_CHILDREN),
    value: None,
};

pub static VARS_HYPERG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lycaemic"),
        dictgen::InsensitiveStr::Ascii("lycemic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPERGLYCEMIC_9687962488251265608)],
        &[(0b10001, &ENTRY_HYPERGLYCEMIC_9687962488251265608)],
    ],
    range: 7..=8,
};

static VARS_HYPERE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERE_CHILDREN),
    value: None,
};

pub static VARS_HYPERE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mia"),
        dictgen::InsensitiveStr::Ascii("mias"),
        dictgen::InsensitiveStr::Ascii("mic"),
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthete"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
        dictgen::InsensitiveStr::Ascii("stheticer"),
        dictgen::InsensitiveStr::Ascii("stheticest"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HYPEREMIA_12277248942196498109)],
        &[(0b10001, &ENTRY_HYPEREMIAS_6998648938587873401)],
        &[(0b10001, &ENTRY_HYPEREMIC_570993563030938406)],
        &[(0b10010, &ENTRY_HYPEREMPHASIZE_6296306065623289212)],
        &[(0b10010, &ENTRY_HYPEREMPHASIZES_12026029947023914198)],
        &[(0b01001, &ENTRY_HYPEREMPHASIZE_6296306065623289212)],
        &[(0b01001, &ENTRY_HYPEREMPHASIZES_12026029947023914198)],
        &[(0b10001, &ENTRY_HYPERESTHESIA_4632423926913384933)],
        &[(0b10001, &ENTRY_HYPERESTHESIAS_14403575251595502945)],
        &[(0b10001, &ENTRY_HYPERESTHETE_12422140998781729014)],
        &[(0b10001, &ENTRY_HYPERESTHETIC_18284481883670857002)],
        &[(0b10001, &ENTRY_HYPERESTHETICER_2523595003905077411)],
        &[(0b10001, &ENTRY_HYPERESTHETICEST_15286134872893657494)],
    ],
    range: 3..=10,
};

static VARS_HYPERC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERC_CHILDREN),
    value: None,
};

pub static VARS_HYPERC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alcaemia"),
        dictgen::InsensitiveStr::Ascii("alcaemias"),
        dictgen::InsensitiveStr::Ascii("alcemia"),
        dictgen::InsensitiveStr::Ascii("alcemias"),
        dictgen::InsensitiveStr::Ascii("alcinaemia"),
        dictgen::InsensitiveStr::Ascii("alcinemia"),
        dictgen::InsensitiveStr::Ascii("atharses"),
        dictgen::InsensitiveStr::Ascii("atharsises"),
        dictgen::InsensitiveStr::Ascii("hloraemia"),
        dictgen::InsensitiveStr::Ascii("hloremia"),
        dictgen::InsensitiveStr::Ascii("holesterolaemia"),
        dictgen::InsensitiveStr::Ascii("holesterolaemias"),
        dictgen::InsensitiveStr::Ascii("holesterolemia"),
        dictgen::InsensitiveStr::Ascii("holesterolemias"),
        dictgen::InsensitiveStr::Ascii("ivilisation"),
        dictgen::InsensitiveStr::Ascii("ivilisations"),
        dictgen::InsensitiveStr::Ascii("ivilised"),
        dictgen::InsensitiveStr::Ascii("iviliseds"),
        dictgen::InsensitiveStr::Ascii("ivilization"),
        dictgen::InsensitiveStr::Ascii("ivilizations"),
        dictgen::InsensitiveStr::Ascii("ivilized"),
        dictgen::InsensitiveStr::Ascii("ivilizeds"),
        dictgen::InsensitiveStr::Ascii("riticise"),
        dictgen::InsensitiveStr::Ascii("riticised"),
        dictgen::InsensitiveStr::Ascii("riticises"),
        dictgen::InsensitiveStr::Ascii("riticising"),
        dictgen::InsensitiveStr::Ascii("riticize"),
        dictgen::InsensitiveStr::Ascii("riticized"),
        dictgen::InsensitiveStr::Ascii("riticizes"),
        dictgen::InsensitiveStr::Ascii("riticizing"),
        dictgen::InsensitiveStr::Ascii("ryaesthesia"),
        dictgen::InsensitiveStr::Ascii("ryesthesia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPERCALCEMIA_13843206769388452645)],
        &[(0b11010, &ENTRY_HYPERCALCEMIAS_5408133520899563192)],
        &[(0b10001, &ENTRY_HYPERCALCEMIA_13843206769388452645)],
        &[(0b10001, &ENTRY_HYPERCALCEMIAS_5408133520899563192)],
        &[(0b11010, &ENTRY_HYPERCALCINEMIA_13976366975495435303)],
        &[(0b10001, &ENTRY_HYPERCALCINEMIA_13976366975495435303)],
        &[(0b11010, &ENTRY_HYPERCATHARSISES_3652483176188389035)],
        &[(0b00001, &ENTRY_HYPERCATHARSISES_3652483176188389035)],
        &[(0b11010, &ENTRY_HYPERCHLOREMIA_17565413549481257710)],
        &[(0b10001, &ENTRY_HYPERCHLOREMIA_17565413549481257710)],
        &[(0b11010, &ENTRY_HYPERCHOLESTEROLEMIA_4754609931003278536)],
        &[(0b11010, &ENTRY_HYPERCHOLESTEROLEMIAS_18411903243384849460)],
        &[(0b10001, &ENTRY_HYPERCHOLESTEROLEMIA_4754609931003278536)],
        &[(0b10001, &ENTRY_HYPERCHOLESTEROLEMIAS_18411903243384849460)],
        &[(0b10010, &ENTRY_HYPERCIVILIZATION_13591435940520562735)],
        &[(0b10010, &ENTRY_HYPERCIVILIZATIONS_16026626403207941950)],
        &[(0b10010, &ENTRY_HYPERCIVILIZED_5448923133916718271)],
        &[(0b10010, &ENTRY_HYPERCIVILIZEDS_14031306534307147011)],
        &[(0b01001, &ENTRY_HYPERCIVILIZATION_13591435940520562735)],
        &[(0b01001, &ENTRY_HYPERCIVILIZATIONS_16026626403207941950)],
        &[(0b01001, &ENTRY_HYPERCIVILIZED_5448923133916718271)],
        &[(0b01001, &ENTRY_HYPERCIVILIZEDS_14031306534307147011)],
        &[(0b10010, &ENTRY_HYPERCRITICIZE_7153853318741720978)],
        &[(0b10010, &ENTRY_HYPERCRITICIZED_17847050966992957591)],
        &[(0b10010, &ENTRY_HYPERCRITICIZES_15577646304300312864)],
        &[(0b10010, &ENTRY_HYPERCRITICIZING_11659786261622400970)],
        &[(0b01001, &ENTRY_HYPERCRITICIZE_7153853318741720978)],
        &[(0b01001, &ENTRY_HYPERCRITICIZED_17847050966992957591)],
        &[(0b01001, &ENTRY_HYPERCRITICIZES_15577646304300312864)],
        &[(0b01001, &ENTRY_HYPERCRITICIZING_11659786261622400970)],
        &[(0b11010, &ENTRY_HYPERCRYESTHESIA_13272859349292800228)],
        &[(0b00001, &ENTRY_HYPERCRYESTHESIA_13272859349292800228)],
    ],
    range: 7..=16,
};

static VARS_HYPERB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERB_CHILDREN),
    value: None,
};

pub static VARS_HYPERB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERBOLIZE_10617131659797415639)],
        &[(0b10010, &ENTRY_HYPERBOLIZED_8135053452196902615)],
        &[(0b10010, &ENTRY_HYPERBOLIZES_11501290385346315262)],
        &[(0b10010, &ENTRY_HYPERBOLIZING_2165490899143205915)],
        &[(0b01001, &ENTRY_HYPERBOLIZE_10617131659797415639)],
        &[(0b01001, &ENTRY_HYPERBOLIZED_8135053452196902615)],
        &[(0b01001, &ENTRY_HYPERBOLIZES_11501290385346315262)],
        &[(0b01001, &ENTRY_HYPERBOLIZING_2165490899143205915)],
    ],
    range: 5..=7,
};

static VARS_HYPERA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERA_CHILDREN),
    value: None,
};

pub static VARS_HYPERA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emias"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthesias"),
        dictgen::InsensitiveStr::Ascii("esthete"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
        dictgen::InsensitiveStr::Ascii("estheticer"),
        dictgen::InsensitiveStr::Ascii("estheticest"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPEREMIA_12277248942196498109)],
        &[(0b11010, &ENTRY_HYPEREMIAS_6998648938587873401)],
        &[(0b11010, &ENTRY_HYPEREMIC_570993563030938406)],
        &[(0b11010, &ENTRY_HYPERESTHESIA_4632423926913384933)],
        &[(0b11010, &ENTRY_HYPERESTHESIAS_14403575251595502945)],
        &[(0b11010, &ENTRY_HYPERESTHETE_12422140998781729014)],
        &[(0b11010, &ENTRY_HYPERESTHETIC_18284481883670857002)],
        &[(0b11010, &ENTRY_HYPERESTHETICER_2523595003905077411)],
        &[(0b11010, &ENTRY_HYPERESTHETICEST_15286134872893657494)],
    ],
    range: 4..=11,
};

static VARS_HYPA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPA_CHILDREN),
    value: None,
};

pub static VARS_HYPA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthesias"),
        dictgen::InsensitiveStr::Ascii("esthesic"),
        dictgen::InsensitiveStr::Ascii("ethral"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPESTHESIA_16196465189141300744)],
        &[(0b11010, &ENTRY_HYPESTHESIAS_1838024351778836132)],
        &[(0b11010, &ENTRY_HYPESTHESIC_16905452400970791194)],
        &[(0b11010, &ENTRY_HYPETHRAL_14201019373187172019)],
    ],
    range: 6..=9,
};

static VARS_HYM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYM_CHILDREN),
    value: None,
};

pub static VARS_HYM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enaean"),
        dictgen::InsensitiveStr::Ascii("enean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYMENEAN_15041651575315743056)],
        &[(0b10001, &ENTRY_HYMENEAN_15041651575315743056)],
    ],
    range: 5..=6,
};

static VARS_HYG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYG_CHILDREN),
    value: None,
};

pub static VARS_HYG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ienisation"),
        dictgen::InsensitiveStr::Ascii("ienisations"),
        dictgen::InsensitiveStr::Ascii("ienise"),
        dictgen::InsensitiveStr::Ascii("ienises"),
        dictgen::InsensitiveStr::Ascii("ienization"),
        dictgen::InsensitiveStr::Ascii("ienizations"),
        dictgen::InsensitiveStr::Ascii("ienize"),
        dictgen::InsensitiveStr::Ascii("ienizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYGIENIZATION_1338761212726482109)],
        &[(0b10010, &ENTRY_HYGIENIZATIONS_12897154916673520999)],
        &[(0b10010, &ENTRY_HYGIENIZE_8360515227989834222)],
        &[(0b10010, &ENTRY_HYGIENIZES_957059778120364333)],
        &[(0b01001, &ENTRY_HYGIENIZATION_1338761212726482109)],
        &[(0b01001, &ENTRY_HYGIENIZATIONS_12897154916673520999)],
        &[(0b01001, &ENTRY_HYGIENIZE_8360515227989834222)],
        &[(0b01001, &ENTRY_HYGIENIZES_957059778120364333)],
    ],
    range: 6..=11,
};

static VARS_HYE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYE_CHILDREN),
    value: None,
};

pub static VARS_HYE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("nic")],
    values: &[&[(0b00001, &ENTRY_HYENIC_7100169606816276173)]],
    range: 3..=3,
};

static VARS_HYD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYD_CHILDREN),
    value: None,
};

pub static VARS_HYD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("raemia"),
        dictgen::InsensitiveStr::Ascii("raemias"),
        dictgen::InsensitiveStr::Ascii("raemic"),
        dictgen::InsensitiveStr::Ascii("remia"),
        dictgen::InsensitiveStr::Ascii("remias"),
        dictgen::InsensitiveStr::Ascii("remic"),
        dictgen::InsensitiveStr::Ascii("rocele"),
        dictgen::InsensitiveStr::Ascii("rocoele"),
        dictgen::InsensitiveStr::Ascii("rogenisation"),
        dictgen::InsensitiveStr::Ascii("rogenisations"),
        dictgen::InsensitiveStr::Ascii("rogenise"),
        dictgen::InsensitiveStr::Ascii("rogenised"),
        dictgen::InsensitiveStr::Ascii("rogenises"),
        dictgen::InsensitiveStr::Ascii("rogenising"),
        dictgen::InsensitiveStr::Ascii("rogenization"),
        dictgen::InsensitiveStr::Ascii("rogenizations"),
        dictgen::InsensitiveStr::Ascii("rogenize"),
        dictgen::InsensitiveStr::Ascii("rogenized"),
        dictgen::InsensitiveStr::Ascii("rogenizes"),
        dictgen::InsensitiveStr::Ascii("rogenizing"),
        dictgen::InsensitiveStr::Ascii("rolise"),
        dictgen::InsensitiveStr::Ascii("rolize"),
        dictgen::InsensitiveStr::Ascii("rolysable"),
        dictgen::InsensitiveStr::Ascii("rolysabler"),
        dictgen::InsensitiveStr::Ascii("rolysables"),
        dictgen::InsensitiveStr::Ascii("rolysablest"),
        dictgen::InsensitiveStr::Ascii("rolysate"),
        dictgen::InsensitiveStr::Ascii("rolysates"),
        dictgen::InsensitiveStr::Ascii("rolysation"),
        dictgen::InsensitiveStr::Ascii("rolyse"),
        dictgen::InsensitiveStr::Ascii("rolysed"),
        dictgen::InsensitiveStr::Ascii("rolyser"),
        dictgen::InsensitiveStr::Ascii("rolysing"),
        dictgen::InsensitiveStr::Ascii("rolyzable"),
        dictgen::InsensitiveStr::Ascii("rolyzabler"),
        dictgen::InsensitiveStr::Ascii("rolyzables"),
        dictgen::InsensitiveStr::Ascii("rolyzablest"),
        dictgen::InsensitiveStr::Ascii("rolyzate"),
        dictgen::InsensitiveStr::Ascii("rolyzates"),
        dictgen::InsensitiveStr::Ascii("rolyzation"),
        dictgen::InsensitiveStr::Ascii("rolyze"),
        dictgen::InsensitiveStr::Ascii("rolyzed"),
        dictgen::InsensitiveStr::Ascii("rolyzer"),
        dictgen::InsensitiveStr::Ascii("rolyzes"),
        dictgen::InsensitiveStr::Ascii("rolyzing"),
        dictgen::InsensitiveStr::Ascii("rorrhea"),
        dictgen::InsensitiveStr::Ascii("rorrhoea"),
        dictgen::InsensitiveStr::Ascii("roxylisation"),
        dictgen::InsensitiveStr::Ascii("roxylisations"),
        dictgen::InsensitiveStr::Ascii("roxylise"),
        dictgen::InsensitiveStr::Ascii("roxylises"),
        dictgen::InsensitiveStr::Ascii("roxylization"),
        dictgen::InsensitiveStr::Ascii("roxylizations"),
        dictgen::InsensitiveStr::Ascii("roxylize"),
        dictgen::InsensitiveStr::Ascii("roxylizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYDREMIA_7034931649899021452)],
        &[(0b11010, &ENTRY_HYDREMIAS_15535936146594468577)],
        &[(0b11010, &ENTRY_HYDREMIC_14370893596020089811)],
        &[(0b10001, &ENTRY_HYDREMIA_7034931649899021452)],
        &[(0b10001, &ENTRY_HYDREMIAS_15535936146594468577)],
        &[(0b10001, &ENTRY_HYDREMIC_14370893596020089811)],
        &[(0b10001, &ENTRY_HYDROCELE_12890782663387310276)],
        &[(0b11010, &ENTRY_HYDROCELE_12890782663387310276)],
        &[(0b10010, &ENTRY_HYDROGENIZATION_6861190364962876775)],
        &[(0b10010, &ENTRY_HYDROGENIZATIONS_9839501985127249002)],
        &[(0b10010, &ENTRY_HYDROGENIZE_8896845372338892854)],
        &[(0b10010, &ENTRY_HYDROGENIZED_14561092317743851347)],
        &[(0b10010, &ENTRY_HYDROGENIZES_13310822950999698482)],
        &[(0b10010, &ENTRY_HYDROGENIZING_658446219570799178)],
        &[(0b01001, &ENTRY_HYDROGENIZATION_6861190364962876775)],
        &[(0b01001, &ENTRY_HYDROGENIZATIONS_9839501985127249002)],
        &[(0b01001, &ENTRY_HYDROGENIZE_8896845372338892854)],
        &[(0b01001, &ENTRY_HYDROGENIZED_14561092317743851347)],
        &[(0b01001, &ENTRY_HYDROGENIZES_13310822950999698482)],
        &[(0b01001, &ENTRY_HYDROGENIZING_658446219570799178)],
        &[(0b10010, &ENTRY_HYDROLIZE_5556407722330866199)],
        &[(0b01001, &ENTRY_HYDROLIZE_5556407722330866199)],
        &[(0b10010, &ENTRY_HYDROLYZABLE_12528075959517847768)],
        &[(0b10010, &ENTRY_HYDROLYZABLER_5507333977830072797)],
        &[(0b10010, &ENTRY_HYDROLYZABLES_5561576541070137183)],
        &[(0b10010, &ENTRY_HYDROLYZABLEST_8915579809275139364)],
        &[(0b10010, &ENTRY_HYDROLYZATE_689293659933279867)],
        &[(0b10010, &ENTRY_HYDROLYZATES_6542145074318638373)],
        &[(0b10010, &ENTRY_HYDROLYZATION_1129190381404237761)],
        &[(0b11010, &ENTRY_HYDROLYZE_14101715282298871514)],
        &[(0b11010, &ENTRY_HYDROLYZED_13508052463277306099)],
        &[(0b10010, &ENTRY_HYDROLYZER_5223552143056672994)],
        &[(0b11010, &ENTRY_HYDROLYZING_18045157705495274283)],
        &[(0b01001, &ENTRY_HYDROLYZABLE_12528075959517847768)],
        &[(0b01001, &ENTRY_HYDROLYZABLER_5507333977830072797)],
        &[(0b01001, &ENTRY_HYDROLYZABLES_5561576541070137183)],
        &[(0b01001, &ENTRY_HYDROLYZABLEST_8915579809275139364)],
        &[(0b01001, &ENTRY_HYDROLYZATE_689293659933279867)],
        &[(0b01001, &ENTRY_HYDROLYZATES_6542145074318638373)],
        &[(0b01001, &ENTRY_HYDROLYZATION_1129190381404237761)],
        &[(0b01001, &ENTRY_HYDROLYZE_14101715282298871514)],
        &[(0b01001, &ENTRY_HYDROLYZED_13508052463277306099)],
        &[(0b01001, &ENTRY_HYDROLYZER_5223552143056672994)],
        &[(0b01001, &ENTRY_HYDROLYZES_1708953578311006919)],
        &[(0b01001, &ENTRY_HYDROLYZING_18045157705495274283)],
        &[(0b10001, &ENTRY_HYDRORRHEA_6093314805700249034)],
        &[(0b11010, &ENTRY_HYDRORRHEA_6093314805700249034)],
        &[(0b10010, &ENTRY_HYDROXYLIZATION_13321261281242119975)],
        &[(0b10010, &ENTRY_HYDROXYLIZATIONS_2049257758926080378)],
        &[(0b10010, &ENTRY_HYDROXYLIZE_6840189330452427589)],
        &[(0b10010, &ENTRY_HYDROXYLIZES_11944972790326564810)],
        &[(0b01001, &ENTRY_HYDROXYLIZATION_13321261281242119975)],
        &[(0b01001, &ENTRY_HYDROXYLIZATIONS_2049257758926080378)],
        &[(0b01001, &ENTRY_HYDROXYLIZE_6840189330452427589)],
        &[(0b01001, &ENTRY_HYDROXYLIZES_11944972790326564810)],
    ],
    range: 5..=13,
};

static VARS_HYB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYB_CHILDREN),
    value: None,
};

pub static VARS_HYB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ridisable"),
        dictgen::InsensitiveStr::Ascii("ridisabler"),
        dictgen::InsensitiveStr::Ascii("ridisables"),
        dictgen::InsensitiveStr::Ascii("ridisablest"),
        dictgen::InsensitiveStr::Ascii("ridisation"),
        dictgen::InsensitiveStr::Ascii("ridisations"),
        dictgen::InsensitiveStr::Ascii("ridise"),
        dictgen::InsensitiveStr::Ascii("ridised"),
        dictgen::InsensitiveStr::Ascii("ridiser"),
        dictgen::InsensitiveStr::Ascii("ridisers"),
        dictgen::InsensitiveStr::Ascii("ridises"),
        dictgen::InsensitiveStr::Ascii("ridising"),
        dictgen::InsensitiveStr::Ascii("ridizable"),
        dictgen::InsensitiveStr::Ascii("ridizabler"),
        dictgen::InsensitiveStr::Ascii("ridizables"),
        dictgen::InsensitiveStr::Ascii("ridizablest"),
        dictgen::InsensitiveStr::Ascii("ridization"),
        dictgen::InsensitiveStr::Ascii("ridizations"),
        dictgen::InsensitiveStr::Ascii("ridize"),
        dictgen::InsensitiveStr::Ascii("ridized"),
        dictgen::InsensitiveStr::Ascii("ridizer"),
        dictgen::InsensitiveStr::Ascii("ridizers"),
        dictgen::InsensitiveStr::Ascii("ridizes"),
        dictgen::InsensitiveStr::Ascii("ridizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYBRIDIZABLE_15539830790317538897)],
        &[(0b10010, &ENTRY_HYBRIDIZABLER_14819123538336949488)],
        &[(0b10010, &ENTRY_HYBRIDIZABLES_17797450459897065062)],
        &[(0b10010, &ENTRY_HYBRIDIZABLEST_10233706175812001084)],
        &[(0b10010, &ENTRY_HYBRIDIZATION_4332178131605916168)],
        &[(0b10010, &ENTRY_HYBRIDIZATIONS_10283609484469810765)],
        &[(0b10010, &ENTRY_HYBRIDIZE_8248491254784836054)],
        &[(0b10010, &ENTRY_HYBRIDIZED_7034214956457758537)],
        &[(0b10010, &ENTRY_HYBRIDIZER_2748552798742818278)],
        &[(0b10010, &ENTRY_HYBRIDIZERS_7357049388164342672)],
        &[(0b10010, &ENTRY_HYBRIDIZES_5507688108918127290)],
        &[(0b10010, &ENTRY_HYBRIDIZING_1851952307355033640)],
        &[(0b01001, &ENTRY_HYBRIDIZABLE_15539830790317538897)],
        &[(0b01001, &ENTRY_HYBRIDIZABLER_14819123538336949488)],
        &[(0b01001, &ENTRY_HYBRIDIZABLES_17797450459897065062)],
        &[(0b01001, &ENTRY_HYBRIDIZABLEST_10233706175812001084)],
        &[(0b01001, &ENTRY_HYBRIDIZATION_4332178131605916168)],
        &[(0b01001, &ENTRY_HYBRIDIZATIONS_10283609484469810765)],
        &[(0b01001, &ENTRY_HYBRIDIZE_8248491254784836054)],
        &[(0b01001, &ENTRY_HYBRIDIZED_7034214956457758537)],
        &[(0b01001, &ENTRY_HYBRIDIZER_2748552798742818278)],
        &[(0b01001, &ENTRY_HYBRIDIZERS_7357049388164342672)],
        &[(0b01001, &ENTRY_HYBRIDIZES_5507688108918127290)],
        &[(0b01001, &ENTRY_HYBRIDIZING_1851952307355033640)],
    ],
    range: 6..=11,
};

static VARS_HYA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYA_CHILDREN),
    value: None,
};

pub static VARS_HYA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enic"),
        dictgen::InsensitiveStr::Ascii("linisation"),
        dictgen::InsensitiveStr::Ascii("linisations"),
        dictgen::InsensitiveStr::Ascii("linise"),
        dictgen::InsensitiveStr::Ascii("linised"),
        dictgen::InsensitiveStr::Ascii("linises"),
        dictgen::InsensitiveStr::Ascii("linising"),
        dictgen::InsensitiveStr::Ascii("linization"),
        dictgen::InsensitiveStr::Ascii("linizations"),
        dictgen::InsensitiveStr::Ascii("linize"),
        dictgen::InsensitiveStr::Ascii("linized"),
        dictgen::InsensitiveStr::Ascii("linizes"),
        dictgen::InsensitiveStr::Ascii("linizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYENIC_7100169606816276173)],
        &[(0b10010, &ENTRY_HYALINIZATION_16929766893950103561)],
        &[(0b10010, &ENTRY_HYALINIZATIONS_17682006298999670485)],
        &[(0b10010, &ENTRY_HYALINIZE_10280283688023876531)],
        &[(0b10010, &ENTRY_HYALINIZED_1966392632245301360)],
        &[(0b10010, &ENTRY_HYALINIZES_13813485450023194701)],
        &[(0b10010, &ENTRY_HYALINIZING_10561711059507010773)],
        &[(0b01001, &ENTRY_HYALINIZATION_16929766893950103561)],
        &[(0b01001, &ENTRY_HYALINIZATIONS_17682006298999670485)],
        &[(0b01001, &ENTRY_HYALINIZE_10280283688023876531)],
        &[(0b01001, &ENTRY_HYALINIZED_1966392632245301360)],
        &[(0b01001, &ENTRY_HYALINIZES_13813485450023194701)],
        &[(0b01001, &ENTRY_HYALINIZING_10561711059507010773)],
    ],
    range: 4..=11,
};

static VARS_HU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HU_CHILDREN),
    value: None,
};

static VARS_HU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_HUC_NODE),
    None,
    Some(&VARS_HUE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HUM_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_HUR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HUR_CHILDREN),
    value: None,
};

pub static VARS_HUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("rahes"),
        dictgen::InsensitiveStr::Ascii("ricanise"),
        dictgen::InsensitiveStr::Ascii("ricanises"),
        dictgen::InsensitiveStr::Ascii("ricanize"),
        dictgen::InsensitiveStr::Ascii("ricanizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HUER_10747049949003885908)],
        &[(0b00001, &ENTRY_HURRAHS_1533032267235892768)],
        &[(0b10010, &ENTRY_HURRICANIZE_15900593187601705032)],
        &[(0b10010, &ENTRY_HURRICANIZES_14709272545639239012)],
        &[(0b01001, &ENTRY_HURRICANIZE_15900593187601705032)],
        &[(0b01001, &ENTRY_HURRICANIZES_14709272545639239012)],
    ],
    range: 1..=9,
};

static VARS_HUM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HUM_CHILDREN),
    value: None,
};

pub static VARS_HUM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anisations"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("aniser"),
        dictgen::InsensitiveStr::Ascii("anisers"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anitarianise"),
        dictgen::InsensitiveStr::Ascii("anitarianises"),
        dictgen::InsensitiveStr::Ascii("anitarianize"),
        dictgen::InsensitiveStr::Ascii("anitarianizes"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anizations"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizer"),
        dictgen::InsensitiveStr::Ascii("anizers"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("orer"),
        dictgen::InsensitiveStr::Ascii("orers"),
        dictgen::InsensitiveStr::Ascii("orful"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orless"),
        dictgen::InsensitiveStr::Ascii("orlesser"),
        dictgen::InsensitiveStr::Ascii("orlesses"),
        dictgen::InsensitiveStr::Ascii("orlessest"),
        dictgen::InsensitiveStr::Ascii("orlessness"),
        dictgen::InsensitiveStr::Ascii("orlessnesses"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("orsome"),
        dictgen::InsensitiveStr::Ascii("orsomeness"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("oural"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ourer"),
        dictgen::InsensitiveStr::Ascii("ourers"),
        dictgen::InsensitiveStr::Ascii("ourful"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ourless"),
        dictgen::InsensitiveStr::Ascii("ourlesser"),
        dictgen::InsensitiveStr::Ascii("ourlesses"),
        dictgen::InsensitiveStr::Ascii("ourlessest"),
        dictgen::InsensitiveStr::Ascii("ourlessness"),
        dictgen::InsensitiveStr::Ascii("ourlessnesses"),
        dictgen::InsensitiveStr::Ascii("ours"),
        dictgen::InsensitiveStr::Ascii("oursome"),
        dictgen::InsensitiveStr::Ascii("oursomeness"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HUMANIZATION_15705527931514057427)],
        &[(0b10010, &ENTRY_HUMANIZATIONS_15582377768763436651)],
        &[(0b10010, &ENTRY_HUMANIZE_12698260631072657271)],
        &[(0b10010, &ENTRY_HUMANIZED_6176873167717917443)],
        &[(0b10010, &ENTRY_HUMANIZER_13992683254986422169)],
        &[(0b10010, &ENTRY_HUMANIZERS_8923077805056759577)],
        &[(0b10010, &ENTRY_HUMANIZES_799641267605433339)],
        &[(0b10010, &ENTRY_HUMANIZING_11718797637513438180)],
        &[(0b10010, &ENTRY_HUMANITARIANIZE_15353412717570230575)],
        &[(0b10010, &ENTRY_HUMANITARIANIZES_14035572334353916626)],
        &[(0b01001, &ENTRY_HUMANITARIANIZE_15353412717570230575)],
        &[(0b01001, &ENTRY_HUMANITARIANIZES_14035572334353916626)],
        &[(0b01001, &ENTRY_HUMANIZATION_15705527931514057427)],
        &[(0b01001, &ENTRY_HUMANIZATIONS_15582377768763436651)],
        &[(0b01001, &ENTRY_HUMANIZE_12698260631072657271)],
        &[(0b01001, &ENTRY_HUMANIZED_6176873167717917443)],
        &[(0b01001, &ENTRY_HUMANIZER_13992683254986422169)],
        &[(0b01001, &ENTRY_HUMANIZERS_8923077805056759577)],
        &[(0b01001, &ENTRY_HUMANIZES_799641267605433339)],
        &[(0b01001, &ENTRY_HUMANIZING_11718797637513438180)],
        &[(0b11001, &ENTRY_HUMOR_3738238959900212968)],
        &[(0b11001, &ENTRY_HUMORED_10786336881623276233)],
        &[(0b11001, &ENTRY_HUMORER_7006391541848572245)],
        &[(0b11001, &ENTRY_HUMORERS_9970467724151930844)],
        &[(0b11001, &ENTRY_HUMORFUL_9341394925730313409)],
        &[(0b11001, &ENTRY_HUMORING_11392688200375000188)],
        &[(0b10010, &ENTRY_HUMORIZE_13039467990673202648)],
        &[(0b10010, &ENTRY_HUMORIZES_2488290093371657967)],
        &[(0b01001, &ENTRY_HUMORIZE_13039467990673202648)],
        &[(0b01001, &ENTRY_HUMORIZES_2488290093371657967)],
        &[(0b11001, &ENTRY_HUMORLESS_14939288701032885532)],
        &[(0b11001, &ENTRY_HUMORLESSER_5799000569275879062)],
        &[(0b11001, &ENTRY_HUMORLESSES_1813588940197371446)],
        &[(0b11001, &ENTRY_HUMORLESSEST_7303152498734358734)],
        &[(0b11001, &ENTRY_HUMORLESSNESS_15579411466297936763)],
        &[(0b11001, &ENTRY_HUMORLESSNESSES_14163478094240283512)],
        &[(0b11001, &ENTRY_HUMORS_3898460867445362619)],
        &[(0b11001, &ENTRY_HUMORSOME_10596220543381321499)],
        &[(0b11001, &ENTRY_HUMORSOMENESS_15432803237613045742)],
        &[(0b11010, &ENTRY_HUMOR_3738238959900212968)],
        &[(0b11010, &ENTRY_HUMORAL_9922553401713391974)],
        &[(0b11010, &ENTRY_HUMORED_10786336881623276233)],
        &[(0b11010, &ENTRY_HUMORER_7006391541848572245)],
        &[(0b11010, &ENTRY_HUMORERS_9970467724151930844)],
        &[(0b11010, &ENTRY_HUMORFUL_9341394925730313409)],
        &[(0b11010, &ENTRY_HUMORING_11392688200375000188)],
        &[(0b11010, &ENTRY_HUMORLESS_14939288701032885532)],
        &[(0b11010, &ENTRY_HUMORLESSER_5799000569275879062)],
        &[(0b11010, &ENTRY_HUMORLESSES_1813588940197371446)],
        &[(0b11010, &ENTRY_HUMORLESSEST_7303152498734358734)],
        &[(0b11010, &ENTRY_HUMORLESSNESS_15579411466297936763)],
        &[(0b11010, &ENTRY_HUMORLESSNESSES_14163478094240283512)],
        &[(0b11010, &ENTRY_HUMORS_3898460867445362619)],
        &[(0b11010, &ENTRY_HUMORSOME_10596220543381321499)],
        &[(0b11010, &ENTRY_HUMORSOMENESS_15432803237613045742)],
    ],
    range: 2..=13,
};

static VARS_HUE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HUE_CHILDREN),
    value: None,
};

pub static VARS_HUE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("r")],
    values: &[&[(0b00001, &ENTRY_HUER_10747049949003885908)]],
    range: 1..=1,
};

static VARS_HUC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HUC_CHILDREN),
    value: None,
};

pub static VARS_HUC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ksterise"),
        dictgen::InsensitiveStr::Ascii("ksterises"),
        dictgen::InsensitiveStr::Ascii("ksterize"),
        dictgen::InsensitiveStr::Ascii("ksterizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HUCKSTERIZE_13066281932873001441)],
        &[(0b10010, &ENTRY_HUCKSTERIZES_11602253187655515741)],
        &[(0b01001, &ENTRY_HUCKSTERIZE_13066281932873001441)],
        &[(0b01001, &ENTRY_HUCKSTERIZES_11602253187655515741)],
    ],
    range: 8..=9,
};

static VARS_HO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HO_CHILDREN),
    value: None,
};

static VARS_HO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HOL_NODE),
    Some(&VARS_HOM_NODE),
    Some(&VARS_HON_NODE),
    Some(&VARS_HOO_NODE),
    None,
    None,
    Some(&VARS_HOR_NODE),
    Some(&VARS_HOS_NODE),
    Some(&VARS_HOT_NODE),
    Some(&VARS_HOU_NODE),
    Some(&VARS_HOV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_HOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOV_CHILDREN),
    value: None,
};

pub static VARS_HOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HOVELED_2287662750830577737)],
        &[(0b00001, &ENTRY_HOVELER_14601501376595739029)],
        &[(0b00001, &ENTRY_HOVELERS_8325626138781872872)],
        &[(0b00001, &ENTRY_HOVELING_7608925720102783878)],
        &[(0b11010, &ENTRY_HOVELED_2287662750830577737)],
        &[(0b11010, &ENTRY_HOVELER_14601501376595739029)],
        &[(0b11010, &ENTRY_HOVELERS_8325626138781872872)],
        &[(0b11010, &ENTRY_HOVELING_7608925720102783878)],
    ],
    range: 4..=6,
};

static VARS_HOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOU_CHILDREN),
    value: None,
};

pub static VARS_HOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("seled"),
        dictgen::InsensitiveStr::Ascii("seling"),
        dictgen::InsensitiveStr::Ascii("selings"),
        dictgen::InsensitiveStr::Ascii("selled"),
        dictgen::InsensitiveStr::Ascii("selling"),
        dictgen::InsensitiveStr::Ascii("sellings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HOUSELED_16972580900287546401)],
        &[(0b00001, &ENTRY_HOUSELING_14185027689441346891)],
        &[(0b00001, &ENTRY_HOUSELINGS_4554080295903689036)],
        &[(0b11010, &ENTRY_HOUSELED_16972580900287546401)],
        &[(0b11010, &ENTRY_HOUSELING_14185027689441346891)],
        &[(0b11010, &ENTRY_HOUSELINGS_4554080295903689036)],
    ],
    range: 5..=8,
};

static VARS_HOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOT_CHILDREN),
    value: None,
};

pub static VARS_HOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elisation"),
        dictgen::InsensitiveStr::Ascii("elisations"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elizations"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HOTELIZATION_2621800487749172229)],
        &[(0b10010, &ENTRY_HOTELIZATIONS_8489202423610554111)],
        &[(0b10010, &ENTRY_HOTELIZE_16562047620597541376)],
        &[(0b10010, &ENTRY_HOTELIZES_16329539079245052960)],
        &[(0b01001, &ENTRY_HOTELIZATION_2621800487749172229)],
        &[(0b01001, &ENTRY_HOTELIZATIONS_8489202423610554111)],
        &[(0b01001, &ENTRY_HOTELIZE_16562047620597541376)],
        &[(0b01001, &ENTRY_HOTELIZES_16329539079245052960)],
    ],
    range: 5..=10,
};

static VARS_HOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOS_CHILDREN),
    value: None,
};

pub static VARS_HOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("pitalisation"),
        dictgen::InsensitiveStr::Ascii("pitalisations"),
        dictgen::InsensitiveStr::Ascii("pitalise"),
        dictgen::InsensitiveStr::Ascii("pitalised"),
        dictgen::InsensitiveStr::Ascii("pitalises"),
        dictgen::InsensitiveStr::Ascii("pitalising"),
        dictgen::InsensitiveStr::Ascii("pitalization"),
        dictgen::InsensitiveStr::Ascii("pitalizations"),
        dictgen::InsensitiveStr::Ascii("pitalize"),
        dictgen::InsensitiveStr::Ascii("pitalized"),
        dictgen::InsensitiveStr::Ascii("pitalizes"),
        dictgen::InsensitiveStr::Ascii("pitalizing"),
        dictgen::InsensitiveStr::Ascii("tilise"),
        dictgen::InsensitiveStr::Ascii("tilises"),
        dictgen::InsensitiveStr::Ascii("tilize"),
        dictgen::InsensitiveStr::Ascii("tilizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HOSPITALIZATION_5040452602598774204)],
        &[(0b10010, &ENTRY_HOSPITALIZATIONS_4719313081670515361)],
        &[(0b10010, &ENTRY_HOSPITALIZE_13160741346544894903)],
        &[(0b10010, &ENTRY_HOSPITALIZED_7758414069821260041)],
        &[(0b10010, &ENTRY_HOSPITALIZES_5958151208692605706)],
        &[(0b10010, &ENTRY_HOSPITALIZING_10285779206835646544)],
        &[(0b01001, &ENTRY_HOSPITALIZATION_5040452602598774204)],
        &[(0b01001, &ENTRY_HOSPITALIZATIONS_4719313081670515361)],
        &[(0b01001, &ENTRY_HOSPITALIZE_13160741346544894903)],
        &[(0b01001, &ENTRY_HOSPITALIZED_7758414069821260041)],
        &[(0b01001, &ENTRY_HOSPITALIZES_5958151208692605706)],
        &[(0b01001, &ENTRY_HOSPITALIZING_10285779206835646544)],
        &[(0b10010, &ENTRY_HOSTILIZE_14961635697224585108)],
        &[(0b10010, &ENTRY_HOSTILIZES_13937088386052302757)],
        &[(0b01001, &ENTRY_HOSTILIZE_14961635697224585108)],
        &[(0b01001, &ENTRY_HOSTILIZES_13937088386052302757)],
    ],
    range: 6..=13,
};

static VARS_HOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOR_CHILDREN),
    value: None,
};

pub static VARS_HOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("izontalisation"),
        dictgen::InsensitiveStr::Ascii("izontalisations"),
        dictgen::InsensitiveStr::Ascii("izontalise"),
        dictgen::InsensitiveStr::Ascii("izontalises"),
        dictgen::InsensitiveStr::Ascii("izontalization"),
        dictgen::InsensitiveStr::Ascii("izontalizations"),
        dictgen::InsensitiveStr::Ascii("izontalize"),
        dictgen::InsensitiveStr::Ascii("izontalizes"),
        dictgen::InsensitiveStr::Ascii("monise"),
        dictgen::InsensitiveStr::Ascii("monises"),
        dictgen::InsensitiveStr::Ascii("monize"),
        dictgen::InsensitiveStr::Ascii("monizes"),
        dictgen::InsensitiveStr::Ascii("rorise"),
        dictgen::InsensitiveStr::Ascii("rorises"),
        dictgen::InsensitiveStr::Ascii("rorize"),
        dictgen::InsensitiveStr::Ascii("rorizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HORE_3390393391903925430)],
        &[(0b00001, &ENTRY_HORE_3390393391903925430)],
        &[(0b10010, &ENTRY_HORIZONTALIZATION_1854951276399796821)],
        &[(0b10010, &ENTRY_HORIZONTALIZATIONS_14542806755819602636)],
        &[(0b10010, &ENTRY_HORIZONTALIZE_4380057593065562287)],
        &[(0b10010, &ENTRY_HORIZONTALIZES_480288781636427917)],
        &[(0b01001, &ENTRY_HORIZONTALIZATION_1854951276399796821)],
        &[(0b01001, &ENTRY_HORIZONTALIZATIONS_14542806755819602636)],
        &[(0b01001, &ENTRY_HORIZONTALIZE_4380057593065562287)],
        &[(0b01001, &ENTRY_HORIZONTALIZES_480288781636427917)],
        &[(0b10010, &ENTRY_HORMONIZE_13767090928132589394)],
        &[(0b10010, &ENTRY_HORMONIZES_4194755045782431350)],
        &[(0b01001, &ENTRY_HORMONIZE_13767090928132589394)],
        &[(0b01001, &ENTRY_HORMONIZES_4194755045782431350)],
        &[(0b10010, &ENTRY_HORRORIZE_2806837544429029157)],
        &[(0b10010, &ENTRY_HORRORIZES_18387092614244896707)],
        &[(0b01001, &ENTRY_HORRORIZE_2806837544429029157)],
        &[(0b01001, &ENTRY_HORRORIZES_18387092614244896707)],
    ],
    range: 1..=15,
};

static VARS_HOO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOO_CHILDREN),
    value: None,
};

pub static VARS_HOO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dlumise"),
        dictgen::InsensitiveStr::Ascii("dlumises"),
        dictgen::InsensitiveStr::Ascii("dlumize"),
        dictgen::InsensitiveStr::Ascii("dlumizes"),
        dictgen::InsensitiveStr::Ascii("liganise"),
        dictgen::InsensitiveStr::Ascii("liganises"),
        dictgen::InsensitiveStr::Ascii("liganize"),
        dictgen::InsensitiveStr::Ascii("liganizes"),
        dictgen::InsensitiveStr::Ascii("rah"),
        dictgen::InsensitiveStr::Ascii("rahs"),
        dictgen::InsensitiveStr::Ascii("sierise"),
        dictgen::InsensitiveStr::Ascii("sierises"),
        dictgen::InsensitiveStr::Ascii("sierize"),
        dictgen::InsensitiveStr::Ascii("sierizes"),
        dictgen::InsensitiveStr::Ascii("verise"),
        dictgen::InsensitiveStr::Ascii("verises"),
        dictgen::InsensitiveStr::Ascii("verize"),
        dictgen::InsensitiveStr::Ascii("verizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HOODLUMIZE_6984933085091962905)],
        &[(0b10010, &ENTRY_HOODLUMIZES_4118588160754440363)],
        &[(0b01001, &ENTRY_HOODLUMIZE_6984933085091962905)],
        &[(0b01001, &ENTRY_HOODLUMIZES_4118588160754440363)],
        &[(0b10010, &ENTRY_HOOLIGANIZE_12500916511980195978)],
        &[(0b10010, &ENTRY_HOOLIGANIZES_8800539654166191774)],
        &[(0b01001, &ENTRY_HOOLIGANIZE_12500916511980195978)],
        &[(0b01001, &ENTRY_HOOLIGANIZES_8800539654166191774)],
        &[(0b00001, &ENTRY_HURRAH_8390607640434840198)],
        &[(0b00001, &ENTRY_HURRAHS_1533032267235892768)],
        &[(0b10010, &ENTRY_HOOSIERIZE_14083736118237757739)],
        &[(0b10010, &ENTRY_HOOSIERIZES_1886781026111147436)],
        &[(0b01001, &ENTRY_HOOSIERIZE_14083736118237757739)],
        &[(0b01001, &ENTRY_HOOSIERIZES_1886781026111147436)],
        &[(0b10010, &ENTRY_HOOVERIZE_14070528923375609155)],
        &[(0b10010, &ENTRY_HOOVERIZES_6952740409766921744)],
        &[(0b01001, &ENTRY_HOOVERIZE_14070528923375609155)],
        &[(0b01001, &ENTRY_HOOVERIZES_6952740409766921744)],
    ],
    range: 3..=9,
};

static VARS_HON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HON_CHILDREN),
    value: None,
};

pub static VARS_HON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("orabilities"),
        dictgen::InsensitiveStr::Ascii("orability"),
        dictgen::InsensitiveStr::Ascii("orable"),
        dictgen::InsensitiveStr::Ascii("orableness"),
        dictgen::InsensitiveStr::Ascii("orablenesses"),
        dictgen::InsensitiveStr::Ascii("orabler"),
        dictgen::InsensitiveStr::Ascii("orables"),
        dictgen::InsensitiveStr::Ascii("orableship"),
        dictgen::InsensitiveStr::Ascii("orableships"),
        dictgen::InsensitiveStr::Ascii("orablest"),
        dictgen::InsensitiveStr::Ascii("orablier"),
        dictgen::InsensitiveStr::Ascii("orablies"),
        dictgen::InsensitiveStr::Ascii("orabliest"),
        dictgen::InsensitiveStr::Ascii("orably"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("oree"),
        dictgen::InsensitiveStr::Ascii("orees"),
        dictgen::InsensitiveStr::Ascii("orer"),
        dictgen::InsensitiveStr::Ascii("orers"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("orless"),
        dictgen::InsensitiveStr::Ascii("orlesser"),
        dictgen::InsensitiveStr::Ascii("orlesses"),
        dictgen::InsensitiveStr::Ascii("orlessest"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ourabilities"),
        dictgen::InsensitiveStr::Ascii("ourability"),
        dictgen::InsensitiveStr::Ascii("ourable"),
        dictgen::InsensitiveStr::Ascii("ourableness"),
        dictgen::InsensitiveStr::Ascii("ourablenesses"),
        dictgen::InsensitiveStr::Ascii("ourabler"),
        dictgen::InsensitiveStr::Ascii("ourables"),
        dictgen::InsensitiveStr::Ascii("ourableship"),
        dictgen::InsensitiveStr::Ascii("ourableships"),
        dictgen::InsensitiveStr::Ascii("ourablest"),
        dictgen::InsensitiveStr::Ascii("ourablier"),
        dictgen::InsensitiveStr::Ascii("ourablies"),
        dictgen::InsensitiveStr::Ascii("ourabliest"),
        dictgen::InsensitiveStr::Ascii("ourably"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ouree"),
        dictgen::InsensitiveStr::Ascii("ourees"),
        dictgen::InsensitiveStr::Ascii("ourer"),
        dictgen::InsensitiveStr::Ascii("ourers"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ourless"),
        dictgen::InsensitiveStr::Ascii("ourlesser"),
        dictgen::InsensitiveStr::Ascii("ourlesses"),
        dictgen::InsensitiveStr::Ascii("ourlessest"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_HONOR_15399646154796433816)],
        &[(0b11001, &ENTRY_HONORABILITIES_9405068382369759044)],
        &[(0b11001, &ENTRY_HONORABILITY_12035052376298826958)],
        &[(0b11001, &ENTRY_HONORABLE_5267590017508289195)],
        &[(0b11001, &ENTRY_HONORABLENESS_15173649896519914801)],
        &[(0b11001, &ENTRY_HONORABLENESSES_9431133268909004141)],
        &[(0b11001, &ENTRY_HONORABLER_7881684582071414508)],
        &[(0b11001, &ENTRY_HONORABLES_1953687291526751468)],
        &[(0b11001, &ENTRY_HONORABLESHIP_541846460375714678)],
        &[(0b11001, &ENTRY_HONORABLESHIPS_10171277772968959220)],
        &[(0b11001, &ENTRY_HONORABLEST_11032014460277721019)],
        &[(0b11001, &ENTRY_HONORABLIER_6189546938867907020)],
        &[(0b11001, &ENTRY_HONORABLIES_15207939272996415718)],
        &[(0b11001, &ENTRY_HONORABLIEST_12608350415220368236)],
        &[(0b11001, &ENTRY_HONORABLY_12699768841379405701)],
        &[(0b11001, &ENTRY_HONORED_11309103293723691238)],
        &[(0b11001, &ENTRY_HONOREE_17606335168000129607)],
        &[(0b11001, &ENTRY_HONOREES_7470068483735697619)],
        &[(0b11001, &ENTRY_HONORER_11221021715751894613)],
        &[(0b11001, &ENTRY_HONORERS_3170682135201203116)],
        &[(0b11001, &ENTRY_HONORING_8233222848637053479)],
        &[(0b11001, &ENTRY_HONORLESS_5078983171515487979)],
        &[(0b11001, &ENTRY_HONORLESSER_15516332619067141447)],
        &[(0b11001, &ENTRY_HONORLESSES_17714568716629301214)],
        &[(0b11001, &ENTRY_HONORLESSEST_13284756641208288383)],
        &[(0b11001, &ENTRY_HONORS_11917319892138194792)],
        &[(0b11010, &ENTRY_HONOR_15399646154796433816)],
        &[(0b11010, &ENTRY_HONORABILITIES_9405068382369759044)],
        &[(0b11010, &ENTRY_HONORABILITY_12035052376298826958)],
        &[(0b11010, &ENTRY_HONORABLE_5267590017508289195)],
        &[(0b11010, &ENTRY_HONORABLENESS_15173649896519914801)],
        &[(0b11010, &ENTRY_HONORABLENESSES_9431133268909004141)],
        &[(0b11010, &ENTRY_HONORABLER_7881684582071414508)],
        &[(0b11010, &ENTRY_HONORABLES_1953687291526751468)],
        &[(0b11010, &ENTRY_HONORABLESHIP_541846460375714678)],
        &[(0b11010, &ENTRY_HONORABLESHIPS_10171277772968959220)],
        &[(0b11010, &ENTRY_HONORABLEST_11032014460277721019)],
        &[(0b11010, &ENTRY_HONORABLIER_6189546938867907020)],
        &[(0b11010, &ENTRY_HONORABLIES_15207939272996415718)],
        &[(0b11010, &ENTRY_HONORABLIEST_12608350415220368236)],
        &[(0b11010, &ENTRY_HONORABLY_12699768841379405701)],
        &[(0b11010, &ENTRY_HONORED_11309103293723691238)],
        &[(0b11010, &ENTRY_HONOREE_17606335168000129607)],
        &[(0b11010, &ENTRY_HONOREES_7470068483735697619)],
        &[(0b11010, &ENTRY_HONORER_11221021715751894613)],
        &[(0b11010, &ENTRY_HONORERS_3170682135201203116)],
        &[(0b11010, &ENTRY_HONORING_8233222848637053479)],
        &[(0b11010, &ENTRY_HONORLESS_5078983171515487979)],
        &[(0b11010, &ENTRY_HONORLESSER_15516332619067141447)],
        &[(0b11010, &ENTRY_HONORLESSES_17714568716629301214)],
        &[(0b11010, &ENTRY_HONORLESSEST_13284756641208288383)],
        &[(0b11010, &ENTRY_HONORS_11917319892138194792)],
    ],
    range: 2..=13,
};

static VARS_HOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HOM_CHILDREN),
    value: None,
};

static VARS_HOM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HOMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HOMO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HOMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HOMO_CHILDREN),
    value: None,
};

static VARS_HOMO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_HOMOE_NODE),
    None,
    Some(&VARS_HOMOG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_HOMOL_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HOMOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOMOL_CHILDREN),
    value: None,
};

pub static VARS_HOMOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("og"),
        dictgen::InsensitiveStr::Ascii("ogisation"),
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogiser"),
        dictgen::InsensitiveStr::Ascii("ogisers"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogization"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizer"),
        dictgen::InsensitiveStr::Ascii("ogizers"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
        dictgen::InsensitiveStr::Ascii("ogs"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HOMOLOGUE_3154994007582088030)],
        &[(0b10010, &ENTRY_HOMOLOGIZATION_16886532379242854540)],
        &[(0b10010, &ENTRY_HOMOLOGIZE_11175870910521621561)],
        &[(0b10010, &ENTRY_HOMOLOGIZED_14063866540046840119)],
        &[(0b10010, &ENTRY_HOMOLOGIZER_9348541694261802707)],
        &[(0b10010, &ENTRY_HOMOLOGIZERS_2389120733785680363)],
        &[(0b10010, &ENTRY_HOMOLOGIZES_14027542917284050646)],
        &[(0b10010, &ENTRY_HOMOLOGIZING_11333343336294935163)],
        &[(0b01001, &ENTRY_HOMOLOGIZATION_16886532379242854540)],
        &[(0b01001, &ENTRY_HOMOLOGIZE_11175870910521621561)],
        &[(0b01001, &ENTRY_HOMOLOGIZED_14063866540046840119)],
        &[(0b01001, &ENTRY_HOMOLOGIZER_9348541694261802707)],
        &[(0b01001, &ENTRY_HOMOLOGIZERS_2389120733785680363)],
        &[(0b01001, &ENTRY_HOMOLOGIZES_14027542917284050646)],
        &[(0b01001, &ENTRY_HOMOLOGIZING_11333343336294935163)],
        &[(0b00001, &ENTRY_HOMOLOGUES_16835140375228019862)],
    ],
    range: 2..=9,
};

static VARS_HOMOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOMOG_CHILDREN),
    value: None,
};

pub static VARS_HOMOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enisation"),
        dictgen::InsensitiveStr::Ascii("enisations"),
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("enised"),
        dictgen::InsensitiveStr::Ascii("eniser"),
        dictgen::InsensitiveStr::Ascii("enisers"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enising"),
        dictgen::InsensitiveStr::Ascii("enization"),
        dictgen::InsensitiveStr::Ascii("enizations"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enized"),
        dictgen::InsensitiveStr::Ascii("enizer"),
        dictgen::InsensitiveStr::Ascii("enizers"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("enizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HOMOGENIZATION_4287750092569292868)],
        &[(0b10010, &ENTRY_HOMOGENIZATIONS_17792406420314111467)],
        &[(0b10010, &ENTRY_HOMOGENIZE_2370634469192321173)],
        &[(0b10010, &ENTRY_HOMOGENIZED_1883548529710793939)],
        &[(0b10010, &ENTRY_HOMOGENIZER_15311593186707876916)],
        &[(0b10010, &ENTRY_HOMOGENIZERS_5505783736797997695)],
        &[(0b10010, &ENTRY_HOMOGENIZES_13436650567116217979)],
        &[(0b10010, &ENTRY_HOMOGENIZING_12711102365188412108)],
        &[(0b01001, &ENTRY_HOMOGENIZATION_4287750092569292868)],
        &[(0b01001, &ENTRY_HOMOGENIZATIONS_17792406420314111467)],
        &[(0b01001, &ENTRY_HOMOGENIZE_2370634469192321173)],
        &[(0b01001, &ENTRY_HOMOGENIZED_1883548529710793939)],
        &[(0b01001, &ENTRY_HOMOGENIZER_15311593186707876916)],
        &[(0b01001, &ENTRY_HOMOGENIZERS_5505783736797997695)],
        &[(0b01001, &ENTRY_HOMOGENIZES_13436650567116217979)],
        &[(0b01001, &ENTRY_HOMOGENIZING_12711102365188412108)],
    ],
    range: 5..=10,
};

static VARS_HOMOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOMOE_CHILDREN),
    value: None,
};

pub static VARS_HOMOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oblastic"),
        dictgen::InsensitiveStr::Ascii("obox"),
        dictgen::InsensitiveStr::Ascii("ochromatic"),
        dictgen::InsensitiveStr::Ascii("ochronous"),
        dictgen::InsensitiveStr::Ascii("ocrystalline"),
        dictgen::InsensitiveStr::Ascii("ogenic"),
        dictgen::InsensitiveStr::Ascii("ogenous"),
        dictgen::InsensitiveStr::Ascii("oid"),
        dictgen::InsensitiveStr::Ascii("okinesis"),
        dictgen::InsensitiveStr::Ascii("omeric"),
        dictgen::InsensitiveStr::Ascii("omeries"),
        dictgen::InsensitiveStr::Ascii("omerous"),
        dictgen::InsensitiveStr::Ascii("omery"),
        dictgen::InsensitiveStr::Ascii("omorph"),
        dictgen::InsensitiveStr::Ascii("omorphic"),
        dictgen::InsensitiveStr::Ascii("omorphies"),
        dictgen::InsensitiveStr::Ascii("omorphous"),
        dictgen::InsensitiveStr::Ascii("omorphs"),
        dictgen::InsensitiveStr::Ascii("omorphy"),
        dictgen::InsensitiveStr::Ascii("opath"),
        dictgen::InsensitiveStr::Ascii("opathic"),
        dictgen::InsensitiveStr::Ascii("opathicallier"),
        dictgen::InsensitiveStr::Ascii("opathicalliest"),
        dictgen::InsensitiveStr::Ascii("opathically"),
        dictgen::InsensitiveStr::Ascii("opathicer"),
        dictgen::InsensitiveStr::Ascii("opathicest"),
        dictgen::InsensitiveStr::Ascii("opathician"),
        dictgen::InsensitiveStr::Ascii("opathicity"),
        dictgen::InsensitiveStr::Ascii("opathies"),
        dictgen::InsensitiveStr::Ascii("opathist"),
        dictgen::InsensitiveStr::Ascii("opathists"),
        dictgen::InsensitiveStr::Ascii("opaths"),
        dictgen::InsensitiveStr::Ascii("opathy"),
        dictgen::InsensitiveStr::Ascii("ophony"),
        dictgen::InsensitiveStr::Ascii("oplasia"),
        dictgen::InsensitiveStr::Ascii("oplastic"),
        dictgen::InsensitiveStr::Ascii("oplasy"),
        dictgen::InsensitiveStr::Ascii("opolar"),
        dictgen::InsensitiveStr::Ascii("oses"),
        dictgen::InsensitiveStr::Ascii("osis"),
        dictgen::InsensitiveStr::Ascii("ostases"),
        dictgen::InsensitiveStr::Ascii("ostasis"),
        dictgen::InsensitiveStr::Ascii("ostatic"),
        dictgen::InsensitiveStr::Ascii("oteleuton"),
        dictgen::InsensitiveStr::Ascii("oteleutons"),
        dictgen::InsensitiveStr::Ascii("othermal"),
        dictgen::InsensitiveStr::Ascii("othermic"),
        dictgen::InsensitiveStr::Ascii("othermous"),
        dictgen::InsensitiveStr::Ascii("otic"),
        dictgen::InsensitiveStr::Ascii("otype"),
        dictgen::InsensitiveStr::Ascii("otypic"),
        dictgen::InsensitiveStr::Ascii("otypical"),
        dictgen::InsensitiveStr::Ascii("ozoic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HOMEOBLASTIC_116551251797444094)],
        &[(0b11010, &ENTRY_HOMEOBOX_17743046375220444429)],
        &[(0b11010, &ENTRY_HOMEOCHROMATIC_10691375472279262101)],
        &[(0b11010, &ENTRY_HOMEOCHRONOUS_12681685748192342069)],
        &[(0b11010, &ENTRY_HOMEOCRYSTALLINE_8788492394679460167)],
        &[(0b11010, &ENTRY_HOMEOGENIC_4885190725568612904)],
        &[(0b11010, &ENTRY_HOMEOGENOUS_7245049588807987009)],
        &[(0b11010, &ENTRY_HOMEOID_13376838327554243707)],
        &[(0b11010, &ENTRY_HOMEOKINESIS_1983100426040447559)],
        &[(0b11010, &ENTRY_HOMEOMERIC_15410476051343199567)],
        &[(0b11010, &ENTRY_HOMEOMERIES_15566208689977406588)],
        &[(0b11010, &ENTRY_HOMEOMEROUS_11515808442666977794)],
        &[(0b11010, &ENTRY_HOMEOMERY_8506899789125124263)],
        &[(0b11010, &ENTRY_HOMEOMORPH_1041802269253692998)],
        &[(0b11010, &ENTRY_HOMEOMORPHIC_16493293489759340224)],
        &[(0b11010, &ENTRY_HOMEOMORPHIES_7511914822948646959)],
        &[(0b11010, &ENTRY_HOMEOMORPHOUS_14653498815981894166)],
        &[(0b11010, &ENTRY_HOMEOMORPHS_15699536692310041526)],
        &[(0b11010, &ENTRY_HOMEOMORPHY_7278817926527493376)],
        &[(0b10010, &ENTRY_HOMEOPATH_5229181903591905312)],
        &[(0b10010, &ENTRY_HOMEOPATHIC_1676669387100956776)],
        &[(0b11010, &ENTRY_HOMEOPATHICALLIER_17068058788005394590)],
        &[(0b11010, &ENTRY_HOMEOPATHICALLIEST_2245363706876703938)],
        &[(0b11010, &ENTRY_HOMEOPATHICALLY_9973356241490765591)],
        &[(0b10010, &ENTRY_HOMEOPATHICER_15560122889304365087)],
        &[(0b10010, &ENTRY_HOMEOPATHICEST_13516270066115997921)],
        &[(0b11010, &ENTRY_HOMEOPATHICIAN_13772062524104826953)],
        &[(0b11010, &ENTRY_HOMEOPATHICITY_14961058671927167811)],
        &[(0b10010, &ENTRY_HOMEOPATHIES_2232350069189750480)],
        &[(0b11010, &ENTRY_HOMEOPATHIST_2303562841958448149)],
        &[(0b11010, &ENTRY_HOMEOPATHISTS_9064143144281892418)],
        &[(0b10010, &ENTRY_HOMEOPATHS_4695543130932217571)],
        &[(0b10010, &ENTRY_HOMEOPATHY_72053453141065048)],
        &[(0b11010, &ENTRY_HOMEOPHONY_18292965130704485386)],
        &[(0b11010, &ENTRY_HOMEOPLASIA_2298070151804770749)],
        &[(0b11010, &ENTRY_HOMEOPLASTIC_9441091798059156924)],
        &[(0b11010, &ENTRY_HOMEOPLASY_9267348127459854811)],
        &[(0b11010, &ENTRY_HOMEOPOLAR_14830052284176516344)],
        &[(0b11010, &ENTRY_HOMEOSES_11737725868417290715)],
        &[(0b11010, &ENTRY_HOMEOSIS_810436539877800798)],
        &[(0b11010, &ENTRY_HOMEOSTASES_16422707729244431228)],
        &[(0b11010, &ENTRY_HOMEOSTASIS_14104730469321046574)],
        &[(0b11010, &ENTRY_HOMEOSTATIC_16235185197438287529)],
        &[(0b11010, &ENTRY_HOMEOTELEUTON_1150276415755322067)],
        &[(0b11010, &ENTRY_HOMEOTELEUTONS_1760360029803513450)],
        &[(0b11010, &ENTRY_HOMEOTHERMAL_13603267069493942420)],
        &[(0b11010, &ENTRY_HOMEOTHERMIC_12410028191564372933)],
        &[(0b11010, &ENTRY_HOMEOTHERMOUS_5728789716135532723)],
        &[(0b11010, &ENTRY_HOMEOTIC_17162223258171300354)],
        &[(0b11010, &ENTRY_HOMEOTYPE_10903969133007650443)],
        &[(0b11010, &ENTRY_HOMEOTYPIC_15533990626512993512)],
        &[(0b11010, &ENTRY_HOMEOTYPICAL_3199435291743240536)],
        &[(0b11010, &ENTRY_HOMEOZOIC_12767024647166837852)],
    ],
    range: 3..=14,
};

static VARS_HOMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOMI_CHILDREN),
    value: None,
};

pub static VARS_HOMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HOMINIZATION_8698022690719820562)],
        &[(0b10010, &ENTRY_HOMINIZED_3408013659776791571)],
        &[(0b01001, &ENTRY_HOMINIZATION_8698022690719820562)],
        &[(0b01001, &ENTRY_HOMINIZED_3408013659776791571)],
    ],
    range: 5..=8,
};

static VARS_HOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOL_CHILDREN),
    value: None,
};

pub static VARS_HOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lywoodise"),
        dictgen::InsensitiveStr::Ascii("lywoodised"),
        dictgen::InsensitiveStr::Ascii("lywoodises"),
        dictgen::InsensitiveStr::Ascii("lywoodising"),
        dictgen::InsensitiveStr::Ascii("lywoodize"),
        dictgen::InsensitiveStr::Ascii("lywoodized"),
        dictgen::InsensitiveStr::Ascii("lywoodizes"),
        dictgen::InsensitiveStr::Ascii("lywoodizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HOLLYWOODIZE_3616601579568204910)],
        &[(0b10010, &ENTRY_HOLLYWOODIZED_15803046821319488532)],
        &[(0b10010, &ENTRY_HOLLYWOODIZES_4277134239348624276)],
        &[(0b10010, &ENTRY_HOLLYWOODIZING_6706537646076294291)],
        &[(0b01001, &ENTRY_HOLLYWOODIZE_3616601579568204910)],
        &[(0b01001, &ENTRY_HOLLYWOODIZED_15803046821319488532)],
        &[(0b01001, &ENTRY_HOLLYWOODIZES_4277134239348624276)],
        &[(0b01001, &ENTRY_HOLLYWOODIZING_6706537646076294291)],
    ],
    range: 9..=11,
};

static VARS_HI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HI_CHILDREN),
    value: None,
};

static VARS_HI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_HIB_NODE),
    Some(&VARS_HIC_NODE),
    None,
    Some(&VARS_HIE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HIL_NODE),
    None,
    Some(&VARS_HIN_NODE),
    None,
    None,
    None,
    Some(&VARS_HIR_NODE),
    Some(&VARS_HIS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIS_CHILDREN),
    value: None,
};

pub static VARS_HIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("panicisation"),
        dictgen::InsensitiveStr::Ascii("panicisations"),
        dictgen::InsensitiveStr::Ascii("panicise"),
        dictgen::InsensitiveStr::Ascii("panicised"),
        dictgen::InsensitiveStr::Ascii("panicises"),
        dictgen::InsensitiveStr::Ascii("panicising"),
        dictgen::InsensitiveStr::Ascii("panicization"),
        dictgen::InsensitiveStr::Ascii("panicizations"),
        dictgen::InsensitiveStr::Ascii("panicize"),
        dictgen::InsensitiveStr::Ascii("panicized"),
        dictgen::InsensitiveStr::Ascii("panicizes"),
        dictgen::InsensitiveStr::Ascii("panicizing"),
        dictgen::InsensitiveStr::Ascii("paniolise"),
        dictgen::InsensitiveStr::Ascii("paniolised"),
        dictgen::InsensitiveStr::Ascii("paniolises"),
        dictgen::InsensitiveStr::Ascii("paniolising"),
        dictgen::InsensitiveStr::Ascii("paniolize"),
        dictgen::InsensitiveStr::Ascii("paniolized"),
        dictgen::InsensitiveStr::Ascii("paniolizes"),
        dictgen::InsensitiveStr::Ascii("paniolizing"),
        dictgen::InsensitiveStr::Ascii("toricise"),
        dictgen::InsensitiveStr::Ascii("toricised"),
        dictgen::InsensitiveStr::Ascii("toricises"),
        dictgen::InsensitiveStr::Ascii("toricising"),
        dictgen::InsensitiveStr::Ascii("toricize"),
        dictgen::InsensitiveStr::Ascii("toricized"),
        dictgen::InsensitiveStr::Ascii("toricizes"),
        dictgen::InsensitiveStr::Ascii("toricizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HISPANICIZATION_10179325605161634602)],
        &[(0b10010, &ENTRY_HISPANICIZATIONS_6144814973963714881)],
        &[(0b10010, &ENTRY_HISPANICIZE_5569049257972807545)],
        &[(0b10010, &ENTRY_HISPANICIZED_13356089989930073997)],
        &[(0b10010, &ENTRY_HISPANICIZES_714224352915567074)],
        &[(0b10010, &ENTRY_HISPANICIZING_4649080031779009424)],
        &[(0b01001, &ENTRY_HISPANICIZATION_10179325605161634602)],
        &[(0b01001, &ENTRY_HISPANICIZATIONS_6144814973963714881)],
        &[(0b01001, &ENTRY_HISPANICIZE_5569049257972807545)],
        &[(0b01001, &ENTRY_HISPANICIZED_13356089989930073997)],
        &[(0b01001, &ENTRY_HISPANICIZES_714224352915567074)],
        &[(0b01001, &ENTRY_HISPANICIZING_4649080031779009424)],
        &[(0b10010, &ENTRY_HISPANIOLIZE_2714451964856493901)],
        &[(0b10010, &ENTRY_HISPANIOLIZED_17671390796065364051)],
        &[(0b10010, &ENTRY_HISPANIOLIZES_9761019512121194277)],
        &[(0b10010, &ENTRY_HISPANIOLIZING_2412049156656096282)],
        &[(0b01001, &ENTRY_HISPANIOLIZE_2714451964856493901)],
        &[(0b01001, &ENTRY_HISPANIOLIZED_17671390796065364051)],
        &[(0b01001, &ENTRY_HISPANIOLIZES_9761019512121194277)],
        &[(0b01001, &ENTRY_HISPANIOLIZING_2412049156656096282)],
        &[(0b10010, &ENTRY_HISTORICIZE_13738209779856267617)],
        &[(0b10010, &ENTRY_HISTORICIZED_4477210962297319607)],
        &[(0b10010, &ENTRY_HISTORICIZES_4470232853457690850)],
        &[(0b10010, &ENTRY_HISTORICIZING_4593407917384797019)],
        &[(0b01001, &ENTRY_HISTORICIZE_13738209779856267617)],
        &[(0b01001, &ENTRY_HISTORICIZED_4477210962297319607)],
        &[(0b01001, &ENTRY_HISTORICIZES_4470232853457690850)],
        &[(0b01001, &ENTRY_HISTORICIZING_4593407917384797019)],
    ],
    range: 8..=13,
};

static VARS_HIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIR_CHILDREN),
    value: None,
};

pub static VARS_HIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("seled"),
        dictgen::InsensitiveStr::Ascii("seling"),
        dictgen::InsensitiveStr::Ascii("selled"),
        dictgen::InsensitiveStr::Ascii("selling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HIRSELED_18076009615056451805)],
        &[(0b00001, &ENTRY_HIRSELING_2556773690895991425)],
        &[(0b11010, &ENTRY_HIRSELED_18076009615056451805)],
        &[(0b11010, &ENTRY_HIRSELING_2556773690895991425)],
    ],
    range: 5..=7,
};

static VARS_HIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIN_CHILDREN),
    value: None,
};

pub static VARS_HIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("duise"),
        dictgen::InsensitiveStr::Ascii("duised"),
        dictgen::InsensitiveStr::Ascii("duises"),
        dictgen::InsensitiveStr::Ascii("duising"),
        dictgen::InsensitiveStr::Ascii("duize"),
        dictgen::InsensitiveStr::Ascii("duized"),
        dictgen::InsensitiveStr::Ascii("duizes"),
        dictgen::InsensitiveStr::Ascii("duizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HINDUIZE_1079507685818211649)],
        &[(0b10010, &ENTRY_HINDUIZED_1479360559613540500)],
        &[(0b10010, &ENTRY_HINDUIZES_8675577031524468618)],
        &[(0b10010, &ENTRY_HINDUIZING_14941208918762953335)],
        &[(0b01001, &ENTRY_HINDUIZE_1079507685818211649)],
        &[(0b01001, &ENTRY_HINDUIZED_1479360559613540500)],
        &[(0b01001, &ENTRY_HINDUIZES_8675577031524468618)],
        &[(0b01001, &ENTRY_HINDUIZING_14941208918762953335)],
    ],
    range: 5..=7,
};

static VARS_HIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIL_CHILDREN),
    value: None,
};

pub static VARS_HIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("loaed"),
        dictgen::InsensitiveStr::Ascii("loed"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HILLOED_11954365269279544751)],
        &[(0b00001, &ENTRY_HILLOED_11954365269279544751)],
    ],
    range: 4..=5,
};

static VARS_HIE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIE_CHILDREN),
    value: None,
};

pub static VARS_HIE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rarchise"),
        dictgen::InsensitiveStr::Ascii("rarchised"),
        dictgen::InsensitiveStr::Ascii("rarchising"),
        dictgen::InsensitiveStr::Ascii("rarchize"),
        dictgen::InsensitiveStr::Ascii("rarchized"),
        dictgen::InsensitiveStr::Ascii("rarchizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HIERARCHIZE_16104584967271198045)],
        &[(0b10010, &ENTRY_HIERARCHIZED_16218874539182971788)],
        &[(0b10010, &ENTRY_HIERARCHIZING_8072837221828080257)],
        &[(0b01001, &ENTRY_HIERARCHIZE_16104584967271198045)],
        &[(0b01001, &ENTRY_HIERARCHIZED_16218874539182971788)],
        &[(0b01001, &ENTRY_HIERARCHIZING_8072837221828080257)],
    ],
    range: 8..=10,
};

static VARS_HIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIC_CHILDREN),
    value: None,
};

pub static VARS_HIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cupped"),
        dictgen::InsensitiveStr::Ascii("cupping"),
    ],
    values: &[
        &[(0b01000, &ENTRY_HICCUPED_10125331953329560167)],
        &[(0b01000, &ENTRY_HICCUPING_14277666795637273542)],
    ],
    range: 6..=7,
};

static VARS_HIB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIB_CHILDREN),
    value: None,
};

pub static VARS_HIB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ernicise"),
        dictgen::InsensitiveStr::Ascii("ernicised"),
        dictgen::InsensitiveStr::Ascii("ernicises"),
        dictgen::InsensitiveStr::Ascii("ernicising"),
        dictgen::InsensitiveStr::Ascii("ernicize"),
        dictgen::InsensitiveStr::Ascii("ernicized"),
        dictgen::InsensitiveStr::Ascii("ernicizes"),
        dictgen::InsensitiveStr::Ascii("ernicizing"),
        dictgen::InsensitiveStr::Ascii("ernisation"),
        dictgen::InsensitiveStr::Ascii("ernisations"),
        dictgen::InsensitiveStr::Ascii("ernise"),
        dictgen::InsensitiveStr::Ascii("ernised"),
        dictgen::InsensitiveStr::Ascii("ernises"),
        dictgen::InsensitiveStr::Ascii("ernising"),
        dictgen::InsensitiveStr::Ascii("ernization"),
        dictgen::InsensitiveStr::Ascii("ernizations"),
        dictgen::InsensitiveStr::Ascii("ernize"),
        dictgen::InsensitiveStr::Ascii("ernized"),
        dictgen::InsensitiveStr::Ascii("ernizes"),
        dictgen::InsensitiveStr::Ascii("ernizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HIBERNICIZE_3470806717863110401)],
        &[(0b10010, &ENTRY_HIBERNICIZED_18381403222365205426)],
        &[(0b10010, &ENTRY_HIBERNICIZES_8504841140657962943)],
        &[(0b10010, &ENTRY_HIBERNICIZING_12237920868399803779)],
        &[(0b01001, &ENTRY_HIBERNICIZE_3470806717863110401)],
        &[(0b01001, &ENTRY_HIBERNICIZED_18381403222365205426)],
        &[(0b01001, &ENTRY_HIBERNICIZES_8504841140657962943)],
        &[(0b01001, &ENTRY_HIBERNICIZING_12237920868399803779)],
        &[(0b10010, &ENTRY_HIBERNIZATION_3006579217265811606)],
        &[(0b10010, &ENTRY_HIBERNIZATIONS_5650569713694187831)],
        &[(0b10010, &ENTRY_HIBERNIZE_750212256722303375)],
        &[(0b10010, &ENTRY_HIBERNIZED_16602927325875706195)],
        &[(0b10010, &ENTRY_HIBERNIZES_7753606908031329667)],
        &[(0b10010, &ENTRY_HIBERNIZING_1183885855013493036)],
        &[(0b01001, &ENTRY_HIBERNIZATION_3006579217265811606)],
        &[(0b01001, &ENTRY_HIBERNIZATIONS_5650569713694187831)],
        &[(0b01001, &ENTRY_HIBERNIZE_750212256722303375)],
        &[(0b01001, &ENTRY_HIBERNIZED_16602927325875706195)],
        &[(0b01001, &ENTRY_HIBERNIZES_7753606908031329667)],
        &[(0b01001, &ENTRY_HIBERNIZING_1183885855013493036)],
    ],
    range: 6..=11,
};

static VARS_HE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HE_CHILDREN),
    value: None,
};

static VARS_HE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HEA_NODE),
    Some(&VARS_HEB_NODE),
    Some(&VARS_HEC_NODE),
    Some(&VARS_HED_NODE),
    None,
    None,
    Some(&VARS_HEG_NODE),
    None,
    None,
    None,
    Some(&VARS_HEK_NODE),
    Some(&VARS_HEL_NODE),
    Some(&VARS_HEM_NODE),
    None,
    None,
    Some(&VARS_HEP_NODE),
    None,
    Some(&VARS_HER_NODE),
    None,
    Some(&VARS_HET_NODE),
    None,
    None,
    None,
    Some(&VARS_HEX_NODE),
    None,
    None,
];

static VARS_HEX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEX_CHILDREN),
    value: None,
};

pub static VARS_HEX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("achlorethane"),
        dictgen::InsensitiveStr::Ascii("achlorethanes"),
        dictgen::InsensitiveStr::Ascii("achloroethane"),
        dictgen::InsensitiveStr::Ascii("achloroethanes"),
        dictgen::InsensitiveStr::Ascii("ametrise"),
        dictgen::InsensitiveStr::Ascii("ametrised"),
        dictgen::InsensitiveStr::Ascii("ametrises"),
        dictgen::InsensitiveStr::Ascii("ametrising"),
        dictgen::InsensitiveStr::Ascii("ametrize"),
        dictgen::InsensitiveStr::Ascii("ametrized"),
        dictgen::InsensitiveStr::Ascii("ametrizes"),
        dictgen::InsensitiveStr::Ascii("ametrizing"),
        dictgen::InsensitiveStr::Ascii("estrol"),
        dictgen::InsensitiveStr::Ascii("oestrol"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HEXACHLORETHANE_13880804086836995242)],
        &[(0b00001, &ENTRY_HEXACHLORETHANES_16683094668819210196)],
        &[(0b11010, &ENTRY_HEXACHLORETHANE_13880804086836995242)],
        &[(0b11010, &ENTRY_HEXACHLORETHANES_16683094668819210196)],
        &[(0b10010, &ENTRY_HEXAMETRIZE_5547414406662974434)],
        &[(0b10010, &ENTRY_HEXAMETRIZED_13605811822316402905)],
        &[(0b10010, &ENTRY_HEXAMETRIZES_1813592333034482642)],
        &[(0b10010, &ENTRY_HEXAMETRIZING_10582887862350659124)],
        &[(0b01001, &ENTRY_HEXAMETRIZE_5547414406662974434)],
        &[(0b01001, &ENTRY_HEXAMETRIZED_13605811822316402905)],
        &[(0b01001, &ENTRY_HEXAMETRIZES_1813592333034482642)],
        &[(0b01001, &ENTRY_HEXAMETRIZING_10582887862350659124)],
        &[(0b00001, &ENTRY_HEXESTROL_9909297945109173360)],
        &[(0b11010, &ENTRY_HEXESTROL_9909297945109173360)],
    ],
    range: 6..=14,
};

static VARS_HET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HET_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_HET_3711738254301522053)]),
};

pub static VARS_HET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aeric"),
        dictgen::InsensitiveStr::Ascii("aerism"),
        dictgen::InsensitiveStr::Ascii("erecious"),
        dictgen::InsensitiveStr::Ascii("eric"),
        dictgen::InsensitiveStr::Ascii("erism"),
        dictgen::InsensitiveStr::Ascii("eroecious"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HETERIC_12696738005922554091)],
        &[(0b11010, &ENTRY_HETERISM_13266915073943432738)],
        &[(0b00001, &ENTRY_HETERECIOUS_17020960417462354136)],
        &[(0b10001, &ENTRY_HETERIC_12696738005922554091)],
        &[(0b10001, &ENTRY_HETERISM_13266915073943432738)],
        &[(0b11010, &ENTRY_HETERECIOUS_17020960417462354136)],
        &[(0b00001, &ENTRY_HETS_18190453795920851209)],
    ],
    range: 1..=9,
};

static VARS_HER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HER_CHILDREN),
    value: None,
};

pub static VARS_HER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aldise"),
        dictgen::InsensitiveStr::Ascii("aldises"),
        dictgen::InsensitiveStr::Ascii("aldize"),
        dictgen::InsensitiveStr::Ascii("aldizes"),
        dictgen::InsensitiveStr::Ascii("borisation"),
        dictgen::InsensitiveStr::Ascii("borisations"),
        dictgen::InsensitiveStr::Ascii("borise"),
        dictgen::InsensitiveStr::Ascii("borised"),
        dictgen::InsensitiveStr::Ascii("borises"),
        dictgen::InsensitiveStr::Ascii("borising"),
        dictgen::InsensitiveStr::Ascii("borization"),
        dictgen::InsensitiveStr::Ascii("borizations"),
        dictgen::InsensitiveStr::Ascii("borize"),
        dictgen::InsensitiveStr::Ascii("borized"),
        dictgen::InsensitiveStr::Ascii("borizes"),
        dictgen::InsensitiveStr::Ascii("borizing"),
        dictgen::InsensitiveStr::Ascii("edes"),
        dictgen::InsensitiveStr::Ascii("eticise"),
        dictgen::InsensitiveStr::Ascii("eticises"),
        dictgen::InsensitiveStr::Ascii("eticize"),
        dictgen::InsensitiveStr::Ascii("eticizes"),
        dictgen::InsensitiveStr::Ascii("oinise"),
        dictgen::InsensitiveStr::Ascii("oinises"),
        dictgen::InsensitiveStr::Ascii("oinize"),
        dictgen::InsensitiveStr::Ascii("oinizes"),
        dictgen::InsensitiveStr::Ascii("oisation"),
        dictgen::InsensitiveStr::Ascii("oisations"),
        dictgen::InsensitiveStr::Ascii("oise"),
        dictgen::InsensitiveStr::Ascii("oised"),
        dictgen::InsensitiveStr::Ascii("oises"),
        dictgen::InsensitiveStr::Ascii("oising"),
        dictgen::InsensitiveStr::Ascii("oization"),
        dictgen::InsensitiveStr::Ascii("oizations"),
        dictgen::InsensitiveStr::Ascii("oize"),
        dictgen::InsensitiveStr::Ascii("oized"),
        dictgen::InsensitiveStr::Ascii("oizes"),
        dictgen::InsensitiveStr::Ascii("oizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HERALDIZE_1299246729599142888)],
        &[(0b10010, &ENTRY_HERALDIZES_9625869039077628339)],
        &[(0b01001, &ENTRY_HERALDIZE_1299246729599142888)],
        &[(0b01001, &ENTRY_HERALDIZES_9625869039077628339)],
        &[(0b10010, &ENTRY_HERBORIZATION_9694510769904043574)],
        &[(0b10010, &ENTRY_HERBORIZATIONS_15092465489013217159)],
        &[(0b10010, &ENTRY_HERBORIZE_6087792157086937690)],
        &[(0b10010, &ENTRY_HERBORIZED_2101485275481463372)],
        &[(0b10010, &ENTRY_HERBORIZES_5862208448182471834)],
        &[(0b10010, &ENTRY_HERBORIZING_13693985247710999928)],
        &[(0b01001, &ENTRY_HERBORIZATION_9694510769904043574)],
        &[(0b01001, &ENTRY_HERBORIZATIONS_15092465489013217159)],
        &[(0b01001, &ENTRY_HERBORIZE_6087792157086937690)],
        &[(0b01001, &ENTRY_HERBORIZED_2101485275481463372)],
        &[(0b01001, &ENTRY_HERBORIZES_5862208448182471834)],
        &[(0b01001, &ENTRY_HERBORIZING_13693985247710999928)],
        &[(0b00001, &ENTRY_HEREDES_13554981120907052697)],
        &[(0b10010, &ENTRY_HERETICIZE_1833772869289401363)],
        &[(0b10010, &ENTRY_HERETICIZES_4776141255720716932)],
        &[(0b01001, &ENTRY_HERETICIZE_1833772869289401363)],
        &[(0b01001, &ENTRY_HERETICIZES_4776141255720716932)],
        &[(0b10010, &ENTRY_HEROINIZE_16854385387045389288)],
        &[(0b10010, &ENTRY_HEROINIZES_8533965791893198494)],
        &[(0b01001, &ENTRY_HEROINIZE_16854385387045389288)],
        &[(0b01001, &ENTRY_HEROINIZES_8533965791893198494)],
        &[(0b10010, &ENTRY_HEROIZATION_3743029117640967144)],
        &[(0b10010, &ENTRY_HEROIZATIONS_12643862966875221323)],
        &[(0b10010, &ENTRY_HEROIZE_10047540448061749836)],
        &[(0b10010, &ENTRY_HEROIZED_8987274669079875509)],
        &[(0b10010, &ENTRY_HEROIZES_1706830083011002298)],
        &[(0b10010, &ENTRY_HEROIZING_8120983839711587732)],
        &[(0b01001, &ENTRY_HEROIZATION_3743029117640967144)],
        &[(0b01001, &ENTRY_HEROIZATIONS_12643862966875221323)],
        &[(0b01001, &ENTRY_HEROIZE_10047540448061749836)],
        &[(0b01001, &ENTRY_HEROIZED_8987274669079875509)],
        &[(0b01001, &ENTRY_HEROIZES_1706830083011002298)],
        &[(0b01001, &ENTRY_HEROIZING_8120983839711587732)],
    ],
    range: 4..=11,
};

static VARS_HEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEP_CHILDREN),
    value: None,
};

pub static VARS_HEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arinise"),
        dictgen::InsensitiveStr::Ascii("arinize"),
        dictgen::InsensitiveStr::Ascii("atisation"),
        dictgen::InsensitiveStr::Ascii("atisations"),
        dictgen::InsensitiveStr::Ascii("atise"),
        dictgen::InsensitiveStr::Ascii("atised"),
        dictgen::InsensitiveStr::Ascii("atises"),
        dictgen::InsensitiveStr::Ascii("atising"),
        dictgen::InsensitiveStr::Ascii("atization"),
        dictgen::InsensitiveStr::Ascii("atizations"),
        dictgen::InsensitiveStr::Ascii("atize"),
        dictgen::InsensitiveStr::Ascii("atized"),
        dictgen::InsensitiveStr::Ascii("atizes"),
        dictgen::InsensitiveStr::Ascii("atizing"),
        dictgen::InsensitiveStr::Ascii("atorrhea"),
        dictgen::InsensitiveStr::Ascii("atorrhoea"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HEPARINIZE_9400135191946821735)],
        &[(0b01001, &ENTRY_HEPARINIZE_9400135191946821735)],
        &[(0b10010, &ENTRY_HEPATIZATION_9072640861820695879)],
        &[(0b10010, &ENTRY_HEPATIZATIONS_3467705694436693139)],
        &[(0b10010, &ENTRY_HEPATIZE_16744808070227801764)],
        &[(0b10010, &ENTRY_HEPATIZED_14001625043891502185)],
        &[(0b10010, &ENTRY_HEPATIZES_1714881038322610197)],
        &[(0b10010, &ENTRY_HEPATIZING_4990710191594309212)],
        &[(0b01001, &ENTRY_HEPATIZATION_9072640861820695879)],
        &[(0b01001, &ENTRY_HEPATIZATIONS_3467705694436693139)],
        &[(0b01001, &ENTRY_HEPATIZE_16744808070227801764)],
        &[(0b01001, &ENTRY_HEPATIZED_14001625043891502185)],
        &[(0b01001, &ENTRY_HEPATIZES_1714881038322610197)],
        &[(0b01001, &ENTRY_HEPATIZING_4990710191594309212)],
        &[(0b10001, &ENTRY_HEPATORRHEA_16055155629543690649)],
        &[(0b11010, &ENTRY_HEPATORRHEA_16055155629543690649)],
    ],
    range: 5..=10,
};

static VARS_HEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HEM_CHILDREN),
    value: None,
};

static VARS_HEM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HEMA_NODE),
    None,
    None,
    None,
    Some(&VARS_HEME_NODE),
    None,
    None,
    None,
    Some(&VARS_HEMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HEMO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HEMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMO_CHILDREN),
    value: None,
};

pub static VARS_HEMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("blast"),
        dictgen::InsensitiveStr::Ascii("chromatoses"),
        dictgen::InsensitiveStr::Ascii("chromatosis"),
        dictgen::InsensitiveStr::Ascii("chrome"),
        dictgen::InsensitiveStr::Ascii("coel"),
        dictgen::InsensitiveStr::Ascii("coels"),
        dictgen::InsensitiveStr::Ascii("concentration"),
        dictgen::InsensitiveStr::Ascii("conia"),
        dictgen::InsensitiveStr::Ascii("cyanin"),
        dictgen::InsensitiveStr::Ascii("cyanins"),
        dictgen::InsensitiveStr::Ascii("cyte"),
        dictgen::InsensitiveStr::Ascii("cytes"),
        dictgen::InsensitiveStr::Ascii("cytoblast"),
        dictgen::InsensitiveStr::Ascii("cytoblastic"),
        dictgen::InsensitiveStr::Ascii("cytometer"),
        dictgen::InsensitiveStr::Ascii("dialyses"),
        dictgen::InsensitiveStr::Ascii("dialysis"),
        dictgen::InsensitiveStr::Ascii("dilution"),
        dictgen::InsensitiveStr::Ascii("dynamic"),
        dictgen::InsensitiveStr::Ascii("dynamics"),
        dictgen::InsensitiveStr::Ascii("erythrin"),
        dictgen::InsensitiveStr::Ascii("flagellate"),
        dictgen::InsensitiveStr::Ascii("globic"),
        dictgen::InsensitiveStr::Ascii("globin"),
        dictgen::InsensitiveStr::Ascii("globinopathies"),
        dictgen::InsensitiveStr::Ascii("globinopathy"),
        dictgen::InsensitiveStr::Ascii("globinous"),
        dictgen::InsensitiveStr::Ascii("globinuria"),
        dictgen::InsensitiveStr::Ascii("gram"),
        dictgen::InsensitiveStr::Ascii("id"),
        dictgen::InsensitiveStr::Ascii("lysin"),
        dictgen::InsensitiveStr::Ascii("lysis"),
        dictgen::InsensitiveStr::Ascii("lytic"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("n"),
        dictgen::InsensitiveStr::Ascii("phile"),
        dictgen::InsensitiveStr::Ascii("philia"),
        dictgen::InsensitiveStr::Ascii("philiac"),
        dictgen::InsensitiveStr::Ascii("philiacs"),
        dictgen::InsensitiveStr::Ascii("philic"),
        dictgen::InsensitiveStr::Ascii("pod"),
        dictgen::InsensitiveStr::Ascii("poiesis"),
        dictgen::InsensitiveStr::Ascii("ptyses"),
        dictgen::InsensitiveStr::Ascii("ptysis"),
        dictgen::InsensitiveStr::Ascii("rrhage"),
        dictgen::InsensitiveStr::Ascii("rrhaged"),
        dictgen::InsensitiveStr::Ascii("rrhages"),
        dictgen::InsensitiveStr::Ascii("rrhaging"),
        dictgen::InsensitiveStr::Ascii("rrhoid"),
        dictgen::InsensitiveStr::Ascii("rrhoidal"),
        dictgen::InsensitiveStr::Ascii("rrhoidectomy"),
        dictgen::InsensitiveStr::Ascii("rrhoids"),
        dictgen::InsensitiveStr::Ascii("sporid"),
        dictgen::InsensitiveStr::Ascii("sporidian"),
        dictgen::InsensitiveStr::Ascii("stases"),
        dictgen::InsensitiveStr::Ascii("stasia"),
        dictgen::InsensitiveStr::Ascii("stasis"),
        dictgen::InsensitiveStr::Ascii("static"),
        dictgen::InsensitiveStr::Ascii("thorax"),
        dictgen::InsensitiveStr::Ascii("toxic"),
        dictgen::InsensitiveStr::Ascii("toxin"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMOBLAST_2649725051858088271)],
        &[(0b10001, &ENTRY_HEMOCHROMATOSES_10907072426647588457)],
        &[(0b10001, &ENTRY_HEMOCHROMATOSIS_12928559471676134380)],
        &[(0b10001, &ENTRY_HEMOCHROME_9228123554665839557)],
        &[(0b10001, &ENTRY_HEMOCOEL_16919582459376619162)],
        &[(0b10001, &ENTRY_HEMOCOELS_6456260620954605946)],
        &[(0b10001, &ENTRY_HEMOCONCENTRATION_13535154840039489558)],
        &[(0b10001, &ENTRY_HEMOCONIA_16736345270230227681)],
        &[(0b10001, &ENTRY_HEMOCYANIN_9642423587808035318)],
        &[(0b10001, &ENTRY_HEMOCYANINS_13211158798270421692)],
        &[(0b10001, &ENTRY_HEMOCYTE_9056880844554795657)],
        &[(0b10001, &ENTRY_HEMOCYTES_11970486144013002814)],
        &[(0b10001, &ENTRY_HEMOCYTOBLAST_3749643051292331307)],
        &[(0b10001, &ENTRY_HEMOCYTOBLASTIC_2891142520537992931)],
        &[(0b10001, &ENTRY_HEMOCYTOMETER_9911855835830563156)],
        &[(0b11001, &ENTRY_HEMODIALYSES_7416791187084499531)],
        &[(0b11001, &ENTRY_HEMODIALYSIS_2356269218981689445)],
        &[(0b10001, &ENTRY_HEMODILUTION_8908658927910101249)],
        &[(0b10001, &ENTRY_HEMODYNAMIC_99687820226271458)],
        &[(0b10001, &ENTRY_HEMODYNAMICS_13468985183469387770)],
        &[(0b11010, &ENTRY_HEMERYTHRIN_1502730445847671207)],
        &[(0b10001, &ENTRY_HEMOFLAGELLATE_1909016951558476190)],
        &[(0b10001, &ENTRY_HEMOGLOBIC_12569293265233239479)],
        &[(0b11001, &ENTRY_HEMOGLOBIN_7404896410383089627)],
        &[(0b10001, &ENTRY_HEMOGLOBINOPATHIES_14362809746066184976)],
        &[(0b10001, &ENTRY_HEMOGLOBINOPATHY_12649532936999683142)],
        &[(0b10001, &ENTRY_HEMOGLOBINOUS_1428697249377514098)],
        &[(0b10001, &ENTRY_HEMOGLOBINURIA_2281539742314619937)],
        &[(0b10001, &ENTRY_HEMOGRAM_4160553122541107842)],
        &[(0b10001, &ENTRY_HEMOID_18441428178335197003)],
        &[(0b10001, &ENTRY_HEMOLYSIN_4766300835176555554)],
        &[(0b11001, &ENTRY_HEMOLYSIS_6121455356135496493)],
        &[(0b10001, &ENTRY_HEMOLYTIC_15374482328757058560)],
        &[(0b10001, &ENTRY_HEMOMETER_3114013764107256805)],
        &[(0b10001, &ENTRY_HEMON_15552272331833168453)],
        &[(0b10001, &ENTRY_HEMOPHILE_12901546318135530373)],
        &[(0b11001, &ENTRY_HEMOPHILIA_7379790116520405129)],
        &[(0b11001, &ENTRY_HEMOPHILIAC_15127098181926005330)],
        &[(0b11001, &ENTRY_HEMOPHILIACS_1819791222881034020)],
        &[(0b11001, &ENTRY_HEMOPHILIC_14674123167547417778)],
        &[(0b10001, &ENTRY_HEMOPOD_2878895326095181845)],
        &[(0b10001, &ENTRY_HEMOPOIESIS_4521489762869246287)],
        &[(0b10001, &ENTRY_HEMOPTYSES_9711906895580892150)],
        &[(0b10001, &ENTRY_HEMOPTYSIS_6606896046225564524)],
        &[(0b11001, &ENTRY_HEMORRHAGE_13487833252665047802)],
        &[(0b11001, &ENTRY_HEMORRHAGED_3567508913732842236)],
        &[(0b11001, &ENTRY_HEMORRHAGES_11033424934560552856)],
        &[(0b11001, &ENTRY_HEMORRHAGING_14700849159949160924)],
        &[(0b11001, &ENTRY_HEMORRHOID_7766599523154289018)],
        &[(0b11001, &ENTRY_HEMORRHOIDAL_10501532313574976310)],
        &[(0b10001, &ENTRY_HEMORRHOIDECTOMY_4750049726844559549)],
        &[(0b11001, &ENTRY_HEMORRHOIDS_13714329857736517214)],
        &[(0b10001, &ENTRY_HEMOSPORID_17787470410905331344)],
        &[(0b10001, &ENTRY_HEMOSPORIDIAN_16163775887165910953)],
        &[(0b10001, &ENTRY_HEMOSTASES_17875899375851174427)],
        &[(0b10001, &ENTRY_HEMOSTASIA_2990592071271355209)],
        &[(0b10001, &ENTRY_HEMOSTASIS_10601607695856646551)],
        &[(0b10001, &ENTRY_HEMOSTATIC_11321860210181124752)],
        &[(0b10001, &ENTRY_HEMOTHORAX_6930101878147813840)],
        &[(0b10001, &ENTRY_HEMOTOXIC_9808851015011198385)],
        &[(0b10001, &ENTRY_HEMOTOXIN_12328861364395861819)],
    ],
    range: 1..=14,
};

static VARS_HEMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMI_CHILDREN),
    value: None,
};

pub static VARS_HEMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("c"),
        dictgen::InsensitiveStr::Ascii("hypesthesia"),
        dictgen::InsensitiveStr::Ascii("hypoesthesia"),
        dictgen::InsensitiveStr::Ascii("n"),
        dictgen::InsensitiveStr::Ascii("ns"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMIC_10115849406341667247)],
        &[(0b00001, &ENTRY_HEMIHYPESTHESIA_12771702401961338683)],
        &[(0b11010, &ENTRY_HEMIHYPESTHESIA_12771702401961338683)],
        &[(0b10001, &ENTRY_HEMIN_13635073169658330154)],
        &[(0b10001, &ENTRY_HEMINS_1405124450165077449)],
    ],
    range: 1..=12,
};

static VARS_HEME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEME_CHILDREN),
    value: Some(&[(0b10001, &ENTRY_HEME_10581684147735415352)]),
};

pub static VARS_HEME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("rythrin")],
    values: &[&[(0b00001, &ENTRY_HEMERYTHRIN_1502730445847671207)]],
    range: 7..=7,
};

static VARS_HEMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HEMA_CHILDREN),
    value: None,
};

static VARS_HEMA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_HEMAC_NODE),
    Some(&VARS_HEMAD_NODE),
    None,
    None,
    Some(&VARS_HEMAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_HEMAL_NODE),
    Some(&VARS_HEMAM_NODE),
    Some(&VARS_HEMAN_NODE),
    None,
    Some(&VARS_HEMAP_NODE),
    None,
    None,
    Some(&VARS_HEMAS_NODE),
    Some(&VARS_HEMAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HEMAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAT_CHILDREN),
    value: None,
};

pub static VARS_HEMAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("al"),
        dictgen::InsensitiveStr::Ascii("ein"),
        dictgen::InsensitiveStr::Ascii("emesis"),
        dictgen::InsensitiveStr::Ascii("herm"),
        dictgen::InsensitiveStr::Ascii("hermal"),
        dictgen::InsensitiveStr::Ascii("hermous"),
        dictgen::InsensitiveStr::Ascii("ic"),
        dictgen::InsensitiveStr::Ascii("ics"),
        dictgen::InsensitiveStr::Ascii("id"),
        dictgen::InsensitiveStr::Ascii("in"),
        dictgen::InsensitiveStr::Ascii("inic"),
        dictgen::InsensitiveStr::Ascii("inics"),
        dictgen::InsensitiveStr::Ascii("ins"),
        dictgen::InsensitiveStr::Ascii("ite"),
        dictgen::InsensitiveStr::Ascii("ites"),
        dictgen::InsensitiveStr::Ascii("itic"),
        dictgen::InsensitiveStr::Ascii("oblast"),
        dictgen::InsensitiveStr::Ascii("oblasts"),
        dictgen::InsensitiveStr::Ascii("obranchiate"),
        dictgen::InsensitiveStr::Ascii("ocele"),
        dictgen::InsensitiveStr::Ascii("ocrit"),
        dictgen::InsensitiveStr::Ascii("ocrits"),
        dictgen::InsensitiveStr::Ascii("ocryal"),
        dictgen::InsensitiveStr::Ascii("ocyst"),
        dictgen::InsensitiveStr::Ascii("ocystis"),
        dictgen::InsensitiveStr::Ascii("ocyte"),
        dictgen::InsensitiveStr::Ascii("ogeneses"),
        dictgen::InsensitiveStr::Ascii("ogenesis"),
        dictgen::InsensitiveStr::Ascii("ogenous"),
        dictgen::InsensitiveStr::Ascii("oid"),
        dictgen::InsensitiveStr::Ascii("oidin"),
        dictgen::InsensitiveStr::Ascii("ologic"),
        dictgen::InsensitiveStr::Ascii("ological"),
        dictgen::InsensitiveStr::Ascii("ologies"),
        dictgen::InsensitiveStr::Ascii("ologist"),
        dictgen::InsensitiveStr::Ascii("ologists"),
        dictgen::InsensitiveStr::Ascii("ology"),
        dictgen::InsensitiveStr::Ascii("olysis"),
        dictgen::InsensitiveStr::Ascii("oma"),
        dictgen::InsensitiveStr::Ascii("omas"),
        dictgen::InsensitiveStr::Ascii("omata"),
        dictgen::InsensitiveStr::Ascii("ometer"),
        dictgen::InsensitiveStr::Ascii("ophyte"),
        dictgen::InsensitiveStr::Ascii("opoieses"),
        dictgen::InsensitiveStr::Ascii("opoiesis"),
        dictgen::InsensitiveStr::Ascii("opoietic"),
        dictgen::InsensitiveStr::Ascii("orrhachis"),
        dictgen::InsensitiveStr::Ascii("osepsis"),
        dictgen::InsensitiveStr::Ascii("osin"),
        dictgen::InsensitiveStr::Ascii("osis"),
        dictgen::InsensitiveStr::Ascii("othermal"),
        dictgen::InsensitiveStr::Ascii("oxylic"),
        dictgen::InsensitiveStr::Ascii("oxylin"),
        dictgen::InsensitiveStr::Ascii("oxylins"),
        dictgen::InsensitiveStr::Ascii("ozoa"),
        dictgen::InsensitiveStr::Ascii("ozoal"),
        dictgen::InsensitiveStr::Ascii("ozoic"),
        dictgen::InsensitiveStr::Ascii("ozoon"),
        dictgen::InsensitiveStr::Ascii("ozzoa"),
        dictgen::InsensitiveStr::Ascii("uria"),
        dictgen::InsensitiveStr::Ascii("urias"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMATAL_3473810694033526440)],
        &[(0b10001, &ENTRY_HEMATEIN_10299149840045810913)],
        &[(0b10001, &ENTRY_HEMATEMESIS_9702571717419169155)],
        &[(0b10001, &ENTRY_HEMATHERM_7916536178037640325)],
        &[(0b10001, &ENTRY_HEMATHERMAL_5311148388316154601)],
        &[(0b10001, &ENTRY_HEMATHERMOUS_11665424966689074429)],
        &[(0b10001, &ENTRY_HEMATIC_11297008998147653262)],
        &[(0b10001, &ENTRY_HEMATICS_2072799741740171039)],
        &[(0b10001, &ENTRY_HEMATID_3667205209302242194)],
        &[(0b10001, &ENTRY_HEMATIN_17310006637994072946)],
        &[(0b10001, &ENTRY_HEMATINIC_5947779393945499901)],
        &[(0b10001, &ENTRY_HEMATINICS_5405890465468753688)],
        &[(0b10001, &ENTRY_HEMATINS_5995391549674023251)],
        &[(0b11001, &ENTRY_HEMATITE_14468869663106727324)],
        &[(0b11001, &ENTRY_HEMATITES_16432545135150625666)],
        &[(0b10001, &ENTRY_HEMATITIC_1011725836724738056)],
        &[(0b10001, &ENTRY_HEMATOBLAST_11319499306489037671)],
        &[(0b10001, &ENTRY_HEMATOBLASTS_15227166432548606675)],
        &[(0b10001, &ENTRY_HEMATOBRANCHIATE_2844231569938030599)],
        &[(0b11001, &ENTRY_HEMATOCELE_1972666202637019639)],
        &[(0b10001, &ENTRY_HEMATOCRIT_11776543127174567971)],
        &[(0b10001, &ENTRY_HEMATOCRITS_16251852522040291719)],
        &[(0b10001, &ENTRY_HEMATOCRYAL_4555256092073194861)],
        &[(0b10001, &ENTRY_HEMATOCYST_464557994908851606)],
        &[(0b10001, &ENTRY_HEMATOCYSTIS_7706855010020816013)],
        &[(0b10001, &ENTRY_HEMATOCYTE_2489259526058226349)],
        &[(0b10001, &ENTRY_HEMATOGENESES_2202464054562607490)],
        &[(0b10001, &ENTRY_HEMATOGENESIS_7325937725699823684)],
        &[(0b10001, &ENTRY_HEMATOGENOUS_7648472768292588686)],
        &[(0b10001, &ENTRY_HEMATOID_1808679171388326204)],
        &[(0b10001, &ENTRY_HEMATOIDIN_5202724309086507251)],
        &[(0b11001, &ENTRY_HEMATOLOGIC_18220046089117542599)],
        &[(0b11001, &ENTRY_HEMATOLOGICAL_1312253959057451336)],
        &[(0b11001, &ENTRY_HEMATOLOGIES_16189544558993565198)],
        &[(0b11001, &ENTRY_HEMATOLOGIST_14280007862665204292)],
        &[(0b11001, &ENTRY_HEMATOLOGISTS_4782136239490629800)],
        &[(0b11001, &ENTRY_HEMATOLOGY_15238707498752205552)],
        &[(0b10001, &ENTRY_HEMATOLYSIS_18079015402986824465)],
        &[(0b10001, &ENTRY_HEMATOMA_15558161368313999362)],
        &[(0b10001, &ENTRY_HEMATOMAS_908833652817460466)],
        &[(0b10001, &ENTRY_HEMATOMATA_17333608130883052853)],
        &[(0b10001, &ENTRY_HEMATOMETER_8659377563531118312)],
        &[(0b10001, &ENTRY_HEMATOPHYTE_7980419769606343875)],
        &[(0b10001, &ENTRY_HEMATOPOIESES_1762593598918477279)],
        &[(0b10001, &ENTRY_HEMATOPOIESIS_14957246204910848242)],
        &[(0b10001, &ENTRY_HEMATOPOIETIC_5636580279732200517)],
        &[(0b10001, &ENTRY_HEMATORRHACHIS_3244347879185405245)],
        &[(0b10001, &ENTRY_HEMATOSEPSIS_11620038395306762074)],
        &[(0b10001, &ENTRY_HEMATOSIN_9020358802336175805)],
        &[(0b10001, &ENTRY_HEMATOSIS_3383158544475611837)],
        &[(0b10001, &ENTRY_HEMATOTHERMAL_8194902579206605957)],
        &[(0b10001, &ENTRY_HEMATOXYLIC_15238360661772109231)],
        &[(0b11001, &ENTRY_HEMATOXYLIN_6889865558698001812)],
        &[(0b11001, &ENTRY_HEMATOXYLINS_16418497755495172078)],
        &[(0b10001, &ENTRY_HEMATOZOA_16310785411433507697)],
        &[(0b10001, &ENTRY_HEMATOZOAL_5612358861578154128)],
        &[(0b10001, &ENTRY_HEMATOZOIC_6811181829581742874)],
        &[(0b10001, &ENTRY_HEMATOZOON_9291195545747434433)],
        &[(0b10001, &ENTRY_HEMATOZZOA_17098302032357442259)],
        &[(0b11001, &ENTRY_HEMATURIA_2017961132280396424)],
        &[(0b11001, &ENTRY_HEMATURIAS_9554717110278540795)],
    ],
    range: 2..=11,
};

static VARS_HEMAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAS_CHILDREN),
    value: None,
};

pub static VARS_HEMAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("pectroscope")],
    values: &[&[(0b10001, &ENTRY_HEMASPECTROSCOPE_16029860263959084403)]],
    range: 11..=11,
};

static VARS_HEMAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAP_CHILDREN),
    value: None,
};

pub static VARS_HEMAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ophysis")],
    values: &[&[(0b10001, &ENTRY_HEMAPOPHYSIS_5976691613656262020)]],
    range: 7..=7,
};

static VARS_HEMAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAN_CHILDREN),
    value: None,
};

pub static VARS_HEMAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gioma"),
        dictgen::InsensitiveStr::Ascii("giomas"),
        dictgen::InsensitiveStr::Ascii("giomata"),
        dictgen::InsensitiveStr::Ascii("giomatosis"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMANGIOMA_15185992059473862053)],
        &[(0b10001, &ENTRY_HEMANGIOMAS_3389015659974672405)],
        &[(0b10001, &ENTRY_HEMANGIOMATA_14171539534972503880)],
        &[(0b10001, &ENTRY_HEMANGIOMATOSIS_18422709517634643109)],
    ],
    range: 5..=10,
};

static VARS_HEMAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAM_CHILDREN),
    value: None,
};

pub static VARS_HEMAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eba"),
        dictgen::InsensitiveStr::Ascii("oeba"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMAMEBA_3568248103119765389)],
        &[(0b11010, &ENTRY_HEMAMEBA_3568248103119765389)],
    ],
    range: 3..=4,
};

static VARS_HEMAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAL_CHILDREN),
    value: Some(&[(0b10001, &ENTRY_HEMAL_17441393171650814474)]),
};

pub static VARS_HEMAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_HEMAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAG_CHILDREN),
    value: None,
};

pub static VARS_HEMAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("glutinate"),
        dictgen::InsensitiveStr::Ascii("glutinated"),
        dictgen::InsensitiveStr::Ascii("glutinating"),
        dictgen::InsensitiveStr::Ascii("glutination"),
        dictgen::InsensitiveStr::Ascii("glutinative"),
        dictgen::InsensitiveStr::Ascii("glutinin"),
        dictgen::InsensitiveStr::Ascii("ogue"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMAGGLUTINATE_7259240567955031710)],
        &[(0b10001, &ENTRY_HEMAGGLUTINATED_3077985582864313404)],
        &[(0b10001, &ENTRY_HEMAGGLUTINATING_8254766798057399155)],
        &[(0b10001, &ENTRY_HEMAGGLUTINATION_8886672716726419818)],
        &[(0b10001, &ENTRY_HEMAGGLUTINATIVE_303261690448078143)],
        &[(0b10001, &ENTRY_HEMAGGLUTININ_15923049545494135264)],
        &[(0b10001, &ENTRY_HEMAGOGUE_11741387198881455915)],
    ],
    range: 4..=11,
};

static VARS_HEMAD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAD_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_HEMAD_17500113374481638242)]),
};

pub static VARS_HEMAD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_HEMAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAC_CHILDREN),
    value: None,
};

pub static VARS_HEMAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hrome"),
        dictgen::InsensitiveStr::Ascii("ytometer"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMACHROME_3729476956483251061)],
        &[(0b10001, &ENTRY_HEMACYTOMETER_7645968025995756392)],
    ],
    range: 5..=8,
};

static VARS_HEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEL_CHILDREN),
    value: None,
};

pub static VARS_HEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("lenisation"),
        dictgen::InsensitiveStr::Ascii("lenisations"),
        dictgen::InsensitiveStr::Ascii("lenise"),
        dictgen::InsensitiveStr::Ascii("lenised"),
        dictgen::InsensitiveStr::Ascii("leniser"),
        dictgen::InsensitiveStr::Ascii("lenises"),
        dictgen::InsensitiveStr::Ascii("lenising"),
        dictgen::InsensitiveStr::Ascii("lenization"),
        dictgen::InsensitiveStr::Ascii("lenizations"),
        dictgen::InsensitiveStr::Ascii("lenize"),
        dictgen::InsensitiveStr::Ascii("lenized"),
        dictgen::InsensitiveStr::Ascii("lenizer"),
        dictgen::InsensitiveStr::Ascii("lenizes"),
        dictgen::InsensitiveStr::Ascii("lenizing"),
        dictgen::InsensitiveStr::Ascii("loed"),
        dictgen::InsensitiveStr::Ascii("oe"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HELE_9666054502463899057)],
        &[(0b00001, &ENTRY_HELLED_574727018671827478)],
        &[(0b10010, &ENTRY_HELLENIZATION_13783607174000789408)],
        &[(0b10010, &ENTRY_HELLENIZATIONS_8710172968727451939)],
        &[(0b10010, &ENTRY_HELLENIZE_15853764160002328426)],
        &[(0b10010, &ENTRY_HELLENIZED_14906317295118144102)],
        &[(0b10010, &ENTRY_HELLENIZER_7915427692830284272)],
        &[(0b10010, &ENTRY_HELLENIZES_16596514924514097835)],
        &[(0b10010, &ENTRY_HELLENIZING_11296376674365030923)],
        &[(0b01001, &ENTRY_HELLENIZATION_13783607174000789408)],
        &[(0b01001, &ENTRY_HELLENIZATIONS_8710172968727451939)],
        &[(0b01001, &ENTRY_HELLENIZE_15853764160002328426)],
        &[(0b01001, &ENTRY_HELLENIZED_14906317295118144102)],
        &[(0b01001, &ENTRY_HELLENIZER_7915427692830284272)],
        &[(0b01001, &ENTRY_HELLENIZES_16596514924514097835)],
        &[(0b01001, &ENTRY_HELLENIZING_11296376674365030923)],
        &[(0b11010, &ENTRY_HELLED_574727018671827478)],
        &[(0b11010, &ENTRY_HELE_9666054502463899057)],
    ],
    range: 1..=11,
};

static VARS_HEK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEK_CHILDREN),
    value: None,
};

pub static VARS_HEK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ataean"),
        dictgen::InsensitiveStr::Ascii("atean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEKATEAN_12026259618893411500)],
        &[(0b00001, &ENTRY_HEKATEAN_12026259618893411500)],
    ],
    range: 5..=6,
};

static VARS_HEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEG_CHILDREN),
    value: None,
};

pub static VARS_HEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elianise"),
        dictgen::InsensitiveStr::Ascii("elianises"),
        dictgen::InsensitiveStr::Ascii("elianize"),
        dictgen::InsensitiveStr::Ascii("elianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HEGELIANIZE_16578015590815155196)],
        &[(0b10010, &ENTRY_HEGELIANIZES_8605025952633908200)],
        &[(0b01001, &ENTRY_HEGELIANIZE_16578015590815155196)],
        &[(0b01001, &ENTRY_HEGELIANIZES_8605025952633908200)],
    ],
    range: 8..=9,
};

static VARS_HED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HED_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_HED_5256048441648265391)]),
};

pub static VARS_HED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_HEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEC_CHILDREN),
    value: None,
};

pub static VARS_HEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ataean"),
        dictgen::InsensitiveStr::Ascii("atean"),
        dictgen::InsensitiveStr::Ascii("togramme"),
        dictgen::InsensitiveStr::Ascii("togrammes"),
        dictgen::InsensitiveStr::Ascii("toliter"),
        dictgen::InsensitiveStr::Ascii("toliters"),
        dictgen::InsensitiveStr::Ascii("tolitre"),
        dictgen::InsensitiveStr::Ascii("tolitres"),
        dictgen::InsensitiveStr::Ascii("tometer"),
        dictgen::InsensitiveStr::Ascii("tometers"),
        dictgen::InsensitiveStr::Ascii("tometre"),
        dictgen::InsensitiveStr::Ascii("tometres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HECATEAN_17050327951336563792)],
        &[(0b00001, &ENTRY_HECATEAN_17050327951336563792)],
        &[(0b10010, &ENTRY_HECTOGRAM_5003794503916308235)],
        &[(0b10010, &ENTRY_HECTOGRAMS_12165348482753150057)],
        &[(0b00001, &ENTRY_HECTOLITER_11797212009084644420)],
        &[(0b00001, &ENTRY_HECTOLITERS_10663113073214490065)],
        &[(0b11010, &ENTRY_HECTOLITER_11797212009084644420)],
        &[(0b11010, &ENTRY_HECTOLITERS_10663113073214490065)],
        &[(0b01001, &ENTRY_HECTOMETER_13063905498394725108)],
        &[(0b01001, &ENTRY_HECTOMETERS_8178246137676970270)],
        &[(0b11010, &ENTRY_HECTOMETER_13063905498394725108)],
        &[(0b11010, &ENTRY_HECTOMETERS_8178246137676970270)],
    ],
    range: 5..=9,
};

static VARS_HEB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEB_CHILDREN),
    value: None,
};

pub static VARS_HEB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("raicise"),
        dictgen::InsensitiveStr::Ascii("raicises"),
        dictgen::InsensitiveStr::Ascii("raicize"),
        dictgen::InsensitiveStr::Ascii("raicizes"),
        dictgen::InsensitiveStr::Ascii("raisation"),
        dictgen::InsensitiveStr::Ascii("raisations"),
        dictgen::InsensitiveStr::Ascii("raise"),
        dictgen::InsensitiveStr::Ascii("raised"),
        dictgen::InsensitiveStr::Ascii("raiser"),
        dictgen::InsensitiveStr::Ascii("raises"),
        dictgen::InsensitiveStr::Ascii("raising"),
        dictgen::InsensitiveStr::Ascii("raization"),
        dictgen::InsensitiveStr::Ascii("raizations"),
        dictgen::InsensitiveStr::Ascii("raize"),
        dictgen::InsensitiveStr::Ascii("raized"),
        dictgen::InsensitiveStr::Ascii("raizer"),
        dictgen::InsensitiveStr::Ascii("raizes"),
        dictgen::InsensitiveStr::Ascii("raizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HEBRAICIZE_4514131522170985476)],
        &[(0b10010, &ENTRY_HEBRAICIZES_9558284926005653742)],
        &[(0b01001, &ENTRY_HEBRAICIZE_4514131522170985476)],
        &[(0b01001, &ENTRY_HEBRAICIZES_9558284926005653742)],
        &[(0b10010, &ENTRY_HEBRAIZATION_6999932964448487456)],
        &[(0b10010, &ENTRY_HEBRAIZATIONS_9122079239866871837)],
        &[(0b10010, &ENTRY_HEBRAIZE_11806255597737775133)],
        &[(0b10010, &ENTRY_HEBRAIZED_15890797870447255830)],
        &[(0b10010, &ENTRY_HEBRAIZER_6789183935043085226)],
        &[(0b10010, &ENTRY_HEBRAIZES_8311891020625852527)],
        &[(0b10010, &ENTRY_HEBRAIZING_6478640508596731098)],
        &[(0b01001, &ENTRY_HEBRAIZATION_6999932964448487456)],
        &[(0b01001, &ENTRY_HEBRAIZATIONS_9122079239866871837)],
        &[(0b01001, &ENTRY_HEBRAIZE_11806255597737775133)],
        &[(0b01001, &ENTRY_HEBRAIZED_15890797870447255830)],
        &[(0b01001, &ENTRY_HEBRAIZER_6789183935043085226)],
        &[(0b01001, &ENTRY_HEBRAIZES_8311891020625852527)],
        &[(0b01001, &ENTRY_HEBRAIZING_6478640508596731098)],
    ],
    range: 5..=10,
};

static VARS_HEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEA_CHILDREN),
    value: None,
};

pub static VARS_HEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thenisation"),
        dictgen::InsensitiveStr::Ascii("thenise"),
        dictgen::InsensitiveStr::Ascii("thenised"),
        dictgen::InsensitiveStr::Ascii("thenises"),
        dictgen::InsensitiveStr::Ascii("thenising"),
        dictgen::InsensitiveStr::Ascii("thenization"),
        dictgen::InsensitiveStr::Ascii("thenize"),
        dictgen::InsensitiveStr::Ascii("thenized"),
        dictgen::InsensitiveStr::Ascii("thenizes"),
        dictgen::InsensitiveStr::Ascii("thenizing"),
        dictgen::InsensitiveStr::Ascii("venise"),
        dictgen::InsensitiveStr::Ascii("venises"),
        dictgen::InsensitiveStr::Ascii("venize"),
        dictgen::InsensitiveStr::Ascii("venizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HEATHENIZATION_11110636948237254370)],
        &[(0b10010, &ENTRY_HEATHENIZE_11684551967371253714)],
        &[(0b10010, &ENTRY_HEATHENIZED_11182183490559881321)],
        &[(0b10010, &ENTRY_HEATHENIZES_16990989076680612437)],
        &[(0b10010, &ENTRY_HEATHENIZING_9668189960205339110)],
        &[(0b01001, &ENTRY_HEATHENIZATION_11110636948237254370)],
        &[(0b01001, &ENTRY_HEATHENIZE_11684551967371253714)],
        &[(0b01001, &ENTRY_HEATHENIZED_11182183490559881321)],
        &[(0b01001, &ENTRY_HEATHENIZES_16990989076680612437)],
        &[(0b01001, &ENTRY_HEATHENIZING_9668189960205339110)],
        &[(0b10010, &ENTRY_HEAVENIZE_12981074350052381166)],
        &[(0b10010, &ENTRY_HEAVENIZES_16270636662518817293)],
        &[(0b01001, &ENTRY_HEAVENIZE_12981074350052381166)],
        &[(0b01001, &ENTRY_HEAVENIZES_16270636662518817293)],
    ],
    range: 6..=11,
};

static VARS_HA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HA_CHILDREN),
    value: None,
};

static VARS_HA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_HAB_NODE),
    None,
    None,
    Some(&VARS_HAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HAM_NODE),
    Some(&VARS_HAN_NODE),
    None,
    None,
    None,
    Some(&VARS_HAR_NODE),
    Some(&VARS_HAS_NODE),
    Some(&VARS_HAT_NODE),
    Some(&VARS_HAU_NODE),
    Some(&VARS_HAV_NODE),
    None,
    None,
    None,
    Some(&VARS_HAZ_NODE),
];

static VARS_HAZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAZ_CHILDREN),
    value: None,
};

pub static VARS_HAZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ardise"),
        dictgen::InsensitiveStr::Ascii("ardises"),
        dictgen::InsensitiveStr::Ascii("ardize"),
        dictgen::InsensitiveStr::Ascii("ardizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HAZARDIZE_11333969271620915584)],
        &[(0b10010, &ENTRY_HAZARDIZES_17139324560601958900)],
        &[(0b01001, &ENTRY_HAZARDIZE_11333969271620915584)],
        &[(0b01001, &ENTRY_HAZARDIZES_17139324560601958900)],
    ],
    range: 6..=7,
};

static VARS_HAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAV_CHILDREN),
    value: None,
};

pub static VARS_HAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ior"),
        dictgen::InsensitiveStr::Ascii("iored"),
        dictgen::InsensitiveStr::Ascii("iors"),
        dictgen::InsensitiveStr::Ascii("iour"),
        dictgen::InsensitiveStr::Ascii("ioured"),
        dictgen::InsensitiveStr::Ascii("iours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_HAVIOR_10199035616705557158)],
        &[(0b11001, &ENTRY_HAVIORED_8097855145736080224)],
        &[(0b11001, &ENTRY_HAVIORS_5444880612094961134)],
        &[(0b11010, &ENTRY_HAVIOR_10199035616705557158)],
        &[(0b11010, &ENTRY_HAVIORED_8097855145736080224)],
        &[(0b11010, &ENTRY_HAVIORS_5444880612094961134)],
    ],
    range: 3..=6,
};

static VARS_HAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAU_CHILDREN),
    value: None,
};

pub static VARS_HAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ssmannisation"),
        dictgen::InsensitiveStr::Ascii("ssmannisations"),
        dictgen::InsensitiveStr::Ascii("ssmannise"),
        dictgen::InsensitiveStr::Ascii("ssmannised"),
        dictgen::InsensitiveStr::Ascii("ssmannises"),
        dictgen::InsensitiveStr::Ascii("ssmannising"),
        dictgen::InsensitiveStr::Ascii("ssmannization"),
        dictgen::InsensitiveStr::Ascii("ssmannizations"),
        dictgen::InsensitiveStr::Ascii("ssmannize"),
        dictgen::InsensitiveStr::Ascii("ssmannized"),
        dictgen::InsensitiveStr::Ascii("ssmannizes"),
        dictgen::InsensitiveStr::Ascii("ssmannizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HAUSSMANNIZATION_6579157371759620134)],
        &[(0b10010, &ENTRY_HAUSSMANNIZATIONS_13595920704368529011)],
        &[(0b10010, &ENTRY_HAUSSMANNIZE_12521195846882016200)],
        &[(0b10010, &ENTRY_HAUSSMANNIZED_7571602618111456009)],
        &[(0b10010, &ENTRY_HAUSSMANNIZES_3919133269135566133)],
        &[(0b10010, &ENTRY_HAUSSMANNIZING_14415612566710014005)],
        &[(0b01001, &ENTRY_HAUSSMANNIZATION_6579157371759620134)],
        &[(0b01001, &ENTRY_HAUSSMANNIZATIONS_13595920704368529011)],
        &[(0b01001, &ENTRY_HAUSSMANNIZE_12521195846882016200)],
        &[(0b01001, &ENTRY_HAUSSMANNIZED_7571602618111456009)],
        &[(0b01001, &ENTRY_HAUSSMANNIZES_3919133269135566133)],
        &[(0b01001, &ENTRY_HAUSSMANNIZING_14415612566710014005)],
    ],
    range: 9..=14,
};

static VARS_HAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAT_CHILDREN),
    value: None,
};

pub static VARS_HAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cheled"),
        dictgen::InsensitiveStr::Ascii("cheling"),
        dictgen::InsensitiveStr::Ascii("chelled"),
        dictgen::InsensitiveStr::Ascii("chelling"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HATCHELED_1160531518767605341)],
        &[(0b00001, &ENTRY_HATCHELING_16333231487227219003)],
        &[(0b11010, &ENTRY_HATCHELED_1160531518767605341)],
        &[(0b11010, &ENTRY_HATCHELING_16333231487227219003)],
        &[(0b10010, &ENTRY_HATTIZE_17233718368280146103)],
        &[(0b10010, &ENTRY_HATTIZES_15099511290428270020)],
        &[(0b01001, &ENTRY_HATTIZE_17233718368280146103)],
        &[(0b01001, &ENTRY_HATTIZES_15099511290428270020)],
    ],
    range: 4..=8,
};

static VARS_HAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAS_CHILDREN),
    value: None,
};

pub static VARS_HAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("idaean"),
        dictgen::InsensitiveStr::Ascii("idean"),
        dictgen::InsensitiveStr::Ascii("monaean"),
        dictgen::InsensitiveStr::Ascii("monaeans"),
        dictgen::InsensitiveStr::Ascii("monean"),
        dictgen::InsensitiveStr::Ascii("moneans"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HASIDEAN_14801716241755178634)],
        &[(0b00001, &ENTRY_HASIDEAN_14801716241755178634)],
        &[(0b11010, &ENTRY_HASMONEAN_14311223713885956483)],
        &[(0b11010, &ENTRY_HASMONEANS_13743887271629822483)],
        &[(0b00001, &ENTRY_HASMONEAN_14311223713885956483)],
        &[(0b00001, &ENTRY_HASMONEANS_13743887271629822483)],
    ],
    range: 5..=8,
};

static VARS_HAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HAR_CHILDREN),
    value: None,
};

static VARS_HAR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_HARB_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HARM_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HARV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_HARV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HARV_CHILDREN),
    value: None,
};

pub static VARS_HARV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ardise"),
        dictgen::InsensitiveStr::Ascii("ardises"),
        dictgen::InsensitiveStr::Ascii("ardize"),
        dictgen::InsensitiveStr::Ascii("ardizes"),
        dictgen::InsensitiveStr::Ascii("eyise"),
        dictgen::InsensitiveStr::Ascii("eyises"),
        dictgen::InsensitiveStr::Ascii("eyize"),
        dictgen::InsensitiveStr::Ascii("eyizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HARVARDIZE_16493875396723735413)],
        &[(0b10010, &ENTRY_HARVARDIZES_10339860156255664794)],
        &[(0b01001, &ENTRY_HARVARDIZE_16493875396723735413)],
        &[(0b01001, &ENTRY_HARVARDIZES_10339860156255664794)],
        &[(0b10010, &ENTRY_HARVEYIZE_1826440362127190508)],
        &[(0b10010, &ENTRY_HARVEYIZES_11140932716217956681)],
        &[(0b01001, &ENTRY_HARVEYIZE_1826440362127190508)],
        &[(0b01001, &ENTRY_HARVEYIZES_11140932716217956681)],
    ],
    range: 5..=7,
};

static VARS_HARM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HARM_CHILDREN),
    value: None,
};

pub static VARS_HARM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onisable"),
        dictgen::InsensitiveStr::Ascii("onisabler"),
        dictgen::InsensitiveStr::Ascii("onisables"),
        dictgen::InsensitiveStr::Ascii("onisablest"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniser"),
        dictgen::InsensitiveStr::Ascii("onisers"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onizable"),
        dictgen::InsensitiveStr::Ascii("onizabler"),
        dictgen::InsensitiveStr::Ascii("onizables"),
        dictgen::InsensitiveStr::Ascii("onizablest"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizer"),
        dictgen::InsensitiveStr::Ascii("onizers"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("othoae"),
        dictgen::InsensitiveStr::Ascii("othoe"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HARMONIZABLE_729301759379091227)],
        &[(0b10010, &ENTRY_HARMONIZABLER_7404427142026247092)],
        &[(0b10010, &ENTRY_HARMONIZABLES_8899243318045925912)],
        &[(0b10010, &ENTRY_HARMONIZABLEST_2322931221738260941)],
        &[(0b10010, &ENTRY_HARMONIZATION_13372020123799276914)],
        &[(0b10010, &ENTRY_HARMONIZATIONS_6188790709212492045)],
        &[(0b10010, &ENTRY_HARMONIZE_8848752875563823524)],
        &[(0b10010, &ENTRY_HARMONIZED_10072567516328574029)],
        &[(0b10010, &ENTRY_HARMONIZER_11613954086587370839)],
        &[(0b10010, &ENTRY_HARMONIZERS_7428199368959927446)],
        &[(0b10010, &ENTRY_HARMONIZES_11674618683147479548)],
        &[(0b10010, &ENTRY_HARMONIZING_15304155413238255688)],
        &[(0b01001, &ENTRY_HARMONIZABLE_729301759379091227)],
        &[(0b01001, &ENTRY_HARMONIZABLER_7404427142026247092)],
        &[(0b01001, &ENTRY_HARMONIZABLES_8899243318045925912)],
        &[(0b01001, &ENTRY_HARMONIZABLEST_2322931221738260941)],
        &[(0b01001, &ENTRY_HARMONIZATION_13372020123799276914)],
        &[(0b01001, &ENTRY_HARMONIZATIONS_6188790709212492045)],
        &[(0b01001, &ENTRY_HARMONIZE_8848752875563823524)],
        &[(0b01001, &ENTRY_HARMONIZED_10072567516328574029)],
        &[(0b01001, &ENTRY_HARMONIZER_11613954086587370839)],
        &[(0b01001, &ENTRY_HARMONIZERS_7428199368959927446)],
        &[(0b01001, &ENTRY_HARMONIZES_11674618683147479548)],
        &[(0b01001, &ENTRY_HARMONIZING_15304155413238255688)],
        &[(0b11010, &ENTRY_HARMOTHOE_1964350150618023866)],
        &[(0b00001, &ENTRY_HARMOTHOE_1964350150618023866)],
    ],
    range: 5..=10,
};

static VARS_HARB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HARB_CHILDREN),
    value: None,
};

pub static VARS_HARB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("orage"),
        dictgen::InsensitiveStr::Ascii("orages"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("orer"),
        dictgen::InsensitiveStr::Ascii("orers"),
        dictgen::InsensitiveStr::Ascii("orful"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("orless"),
        dictgen::InsensitiveStr::Ascii("orlesser"),
        dictgen::InsensitiveStr::Ascii("orlesses"),
        dictgen::InsensitiveStr::Ascii("orlessest"),
        dictgen::InsensitiveStr::Ascii("orous"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("orside"),
        dictgen::InsensitiveStr::Ascii("orward"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ourage"),
        dictgen::InsensitiveStr::Ascii("ourages"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ourer"),
        dictgen::InsensitiveStr::Ascii("ourers"),
        dictgen::InsensitiveStr::Ascii("ourful"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ourless"),
        dictgen::InsensitiveStr::Ascii("ourlesser"),
        dictgen::InsensitiveStr::Ascii("ourlesses"),
        dictgen::InsensitiveStr::Ascii("ourlessest"),
        dictgen::InsensitiveStr::Ascii("ourous"),
        dictgen::InsensitiveStr::Ascii("ours"),
        dictgen::InsensitiveStr::Ascii("ourside"),
        dictgen::InsensitiveStr::Ascii("ourward"),
    ],
    values: &[
        &[(0b11001, &ENTRY_HARBOR_5806650173337038030)],
        &[(0b11001, &ENTRY_HARBORAGE_18081919961627336647)],
        &[(0b11001, &ENTRY_HARBORAGES_15869490209413392347)],
        &[(0b11001, &ENTRY_HARBORED_3058577388408571447)],
        &[(0b11001, &ENTRY_HARBORER_12057721507680863886)],
        &[(0b11001, &ENTRY_HARBORERS_13449068087647702937)],
        &[(0b11001, &ENTRY_HARBORFUL_3026394863252792305)],
        &[(0b11001, &ENTRY_HARBORING_4045224059910485868)],
        &[(0b11001, &ENTRY_HARBORLESS_17223712074031778563)],
        &[(0b11001, &ENTRY_HARBORLESSER_7367286280433451753)],
        &[(0b11001, &ENTRY_HARBORLESSES_8784862775655562494)],
        &[(0b11001, &ENTRY_HARBORLESSEST_9587382522823705631)],
        &[(0b00001, &ENTRY_HARBOROUS_12367039363418754232)],
        &[(0b11001, &ENTRY_HARBORS_17563481687131959756)],
        &[(0b11001, &ENTRY_HARBORSIDE_9189215847440263967)],
        &[(0b11001, &ENTRY_HARBORWARD_925016071949079689)],
        &[(0b11010, &ENTRY_HARBOR_5806650173337038030)],
        &[(0b11010, &ENTRY_HARBORAGE_18081919961627336647)],
        &[(0b11010, &ENTRY_HARBORAGES_15869490209413392347)],
        &[(0b11010, &ENTRY_HARBORED_3058577388408571447)],
        &[(0b11010, &ENTRY_HARBORER_12057721507680863886)],
        &[(0b11010, &ENTRY_HARBORERS_13449068087647702937)],
        &[(0b11010, &ENTRY_HARBORFUL_3026394863252792305)],
        &[(0b11010, &ENTRY_HARBORING_4045224059910485868)],
        &[(0b11010, &ENTRY_HARBORLESS_17223712074031778563)],
        &[(0b11010, &ENTRY_HARBORLESSER_7367286280433451753)],
        &[(0b11010, &ENTRY_HARBORLESSES_8784862775655562494)],
        &[(0b11010, &ENTRY_HARBORLESSEST_9587382522823705631)],
        &[(0b11010, &ENTRY_HARBOROUS_12367039363418754232)],
        &[(0b11010, &ENTRY_HARBORS_17563481687131959756)],
        &[(0b11010, &ENTRY_HARBORSIDE_9189215847440263967)],
        &[(0b11010, &ENTRY_HARBORWARD_925016071949079689)],
    ],
    range: 2..=10,
};

static VARS_HAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAN_CHILDREN),
    value: None,
};

pub static VARS_HAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dseled"),
        dictgen::InsensitiveStr::Ascii("dseling"),
        dictgen::InsensitiveStr::Ascii("dselled"),
        dictgen::InsensitiveStr::Ascii("dselling"),
        dictgen::InsensitiveStr::Ascii("overianise"),
        dictgen::InsensitiveStr::Ascii("overianises"),
        dictgen::InsensitiveStr::Ascii("overianize"),
        dictgen::InsensitiveStr::Ascii("overianizes"),
        dictgen::InsensitiveStr::Ascii("overise"),
        dictgen::InsensitiveStr::Ascii("overises"),
        dictgen::InsensitiveStr::Ascii("overize"),
        dictgen::InsensitiveStr::Ascii("overizes"),
        dictgen::InsensitiveStr::Ascii("sardise"),
        dictgen::InsensitiveStr::Ascii("sardised"),
        dictgen::InsensitiveStr::Ascii("sardises"),
        dictgen::InsensitiveStr::Ascii("sardising"),
        dictgen::InsensitiveStr::Ascii("sardize"),
        dictgen::InsensitiveStr::Ascii("sardized"),
        dictgen::InsensitiveStr::Ascii("sardizes"),
        dictgen::InsensitiveStr::Ascii("sardizing"),
        dictgen::InsensitiveStr::Ascii("seled"),
        dictgen::InsensitiveStr::Ascii("seling"),
        dictgen::InsensitiveStr::Ascii("selled"),
        dictgen::InsensitiveStr::Ascii("selling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HANDSELED_1601691335316168918)],
        &[(0b00001, &ENTRY_HANDSELING_12635054089707091230)],
        &[(0b11010, &ENTRY_HANDSELED_1601691335316168918)],
        &[(0b11010, &ENTRY_HANDSELING_12635054089707091230)],
        &[(0b10010, &ENTRY_HANOVERIANIZE_12937441892704551309)],
        &[(0b10010, &ENTRY_HANOVERIANIZES_1060714123380568078)],
        &[(0b01001, &ENTRY_HANOVERIANIZE_12937441892704551309)],
        &[(0b01001, &ENTRY_HANOVERIANIZES_1060714123380568078)],
        &[(0b10010, &ENTRY_HANOVERIZE_1037492501562492246)],
        &[(0b10010, &ENTRY_HANOVERIZES_2912973620982216821)],
        &[(0b01001, &ENTRY_HANOVERIZE_1037492501562492246)],
        &[(0b01001, &ENTRY_HANOVERIZES_2912973620982216821)],
        &[(0b10010, &ENTRY_HANSARDIZE_15841512842392553595)],
        &[(0b10010, &ENTRY_HANSARDIZED_10211126682279113594)],
        &[(0b10010, &ENTRY_HANSARDIZES_10105974452213715690)],
        &[(0b10010, &ENTRY_HANSARDIZING_3871451417190379754)],
        &[(0b01001, &ENTRY_HANSARDIZE_15841512842392553595)],
        &[(0b01001, &ENTRY_HANSARDIZED_10211126682279113594)],
        &[(0b01001, &ENTRY_HANSARDIZES_10105974452213715690)],
        &[(0b01001, &ENTRY_HANSARDIZING_3871451417190379754)],
        &[(0b00001, &ENTRY_HANSELED_10669977240917095178)],
        &[(0b00001, &ENTRY_HANSELING_17863717275762765019)],
        &[(0b11010, &ENTRY_HANSELED_10669977240917095178)],
        &[(0b11010, &ENTRY_HANSELING_17863717275762765019)],
    ],
    range: 5..=11,
};

static VARS_HAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAM_CHILDREN),
    value: None,
};

pub static VARS_HAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("letisation"),
        dictgen::InsensitiveStr::Ascii("letisations"),
        dictgen::InsensitiveStr::Ascii("letise"),
        dictgen::InsensitiveStr::Ascii("letises"),
        dictgen::InsensitiveStr::Ascii("letization"),
        dictgen::InsensitiveStr::Ascii("letizations"),
        dictgen::InsensitiveStr::Ascii("letize"),
        dictgen::InsensitiveStr::Ascii("letizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HAMLETIZATION_7068220455675423527)],
        &[(0b10010, &ENTRY_HAMLETIZATIONS_8418036370581575950)],
        &[(0b10010, &ENTRY_HAMLETIZE_16914726912103891937)],
        &[(0b10010, &ENTRY_HAMLETIZES_12242920833710714304)],
        &[(0b01001, &ENTRY_HAMLETIZATION_7068220455675423527)],
        &[(0b01001, &ENTRY_HAMLETIZATIONS_8418036370581575950)],
        &[(0b01001, &ENTRY_HAMLETIZE_16914726912103891937)],
        &[(0b01001, &ENTRY_HAMLETIZES_12242920833710714304)],
    ],
    range: 6..=11,
};

static VARS_HAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HAE_CHILDREN),
    value: None,
};

static VARS_HAE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    Some(&VARS_HAED_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HAEM_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_HAER_NODE),
    None,
    Some(&VARS_HAET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HAET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAET_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_HET_3711738254301522053)]),
};

pub static VARS_HAET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("s")],
    values: &[&[(0b11010, &ENTRY_HETS_18190453795920851209)]],
    range: 1..=1,
};

static VARS_HAER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAER_CHILDREN),
    value: None,
};

pub static VARS_HAER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("edes")],
    values: &[&[(0b11010, &ENTRY_HEREDES_13554981120907052697)]],
    range: 4..=4,
};

static VARS_HAEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HAEM_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_HEME_10581684147735415352)]),
};

static VARS_HAEM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HAEMA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HAEMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HAEMO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HAEMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMO_CHILDREN),
    value: None,
};

pub static VARS_HAEMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("blast"),
        dictgen::InsensitiveStr::Ascii("chromatoses"),
        dictgen::InsensitiveStr::Ascii("chromatosis"),
        dictgen::InsensitiveStr::Ascii("chrome"),
        dictgen::InsensitiveStr::Ascii("coel"),
        dictgen::InsensitiveStr::Ascii("coels"),
        dictgen::InsensitiveStr::Ascii("concentration"),
        dictgen::InsensitiveStr::Ascii("conia"),
        dictgen::InsensitiveStr::Ascii("cyanin"),
        dictgen::InsensitiveStr::Ascii("cyanins"),
        dictgen::InsensitiveStr::Ascii("cyte"),
        dictgen::InsensitiveStr::Ascii("cytes"),
        dictgen::InsensitiveStr::Ascii("cytoblast"),
        dictgen::InsensitiveStr::Ascii("cytoblastic"),
        dictgen::InsensitiveStr::Ascii("cytometer"),
        dictgen::InsensitiveStr::Ascii("dialyses"),
        dictgen::InsensitiveStr::Ascii("dialysis"),
        dictgen::InsensitiveStr::Ascii("dilution"),
        dictgen::InsensitiveStr::Ascii("dynamic"),
        dictgen::InsensitiveStr::Ascii("dynamics"),
        dictgen::InsensitiveStr::Ascii("flagellate"),
        dictgen::InsensitiveStr::Ascii("globic"),
        dictgen::InsensitiveStr::Ascii("globin"),
        dictgen::InsensitiveStr::Ascii("globinopathies"),
        dictgen::InsensitiveStr::Ascii("globinopathy"),
        dictgen::InsensitiveStr::Ascii("globinous"),
        dictgen::InsensitiveStr::Ascii("globinuria"),
        dictgen::InsensitiveStr::Ascii("gram"),
        dictgen::InsensitiveStr::Ascii("id"),
        dictgen::InsensitiveStr::Ascii("lysin"),
        dictgen::InsensitiveStr::Ascii("lysis"),
        dictgen::InsensitiveStr::Ascii("lytic"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("n"),
        dictgen::InsensitiveStr::Ascii("phile"),
        dictgen::InsensitiveStr::Ascii("philia"),
        dictgen::InsensitiveStr::Ascii("philiac"),
        dictgen::InsensitiveStr::Ascii("philiacs"),
        dictgen::InsensitiveStr::Ascii("philic"),
        dictgen::InsensitiveStr::Ascii("pod"),
        dictgen::InsensitiveStr::Ascii("poiesis"),
        dictgen::InsensitiveStr::Ascii("ptyses"),
        dictgen::InsensitiveStr::Ascii("ptysis"),
        dictgen::InsensitiveStr::Ascii("rrhage"),
        dictgen::InsensitiveStr::Ascii("rrhaged"),
        dictgen::InsensitiveStr::Ascii("rrhages"),
        dictgen::InsensitiveStr::Ascii("rrhaging"),
        dictgen::InsensitiveStr::Ascii("rrhoid"),
        dictgen::InsensitiveStr::Ascii("rrhoidal"),
        dictgen::InsensitiveStr::Ascii("rrhoidectomy"),
        dictgen::InsensitiveStr::Ascii("rrhoids"),
        dictgen::InsensitiveStr::Ascii("sporid"),
        dictgen::InsensitiveStr::Ascii("sporidian"),
        dictgen::InsensitiveStr::Ascii("stases"),
        dictgen::InsensitiveStr::Ascii("stasia"),
        dictgen::InsensitiveStr::Ascii("stasis"),
        dictgen::InsensitiveStr::Ascii("static"),
        dictgen::InsensitiveStr::Ascii("thorax"),
        dictgen::InsensitiveStr::Ascii("toxic"),
        dictgen::InsensitiveStr::Ascii("toxin"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEMOBLAST_2649725051858088271)],
        &[(0b11010, &ENTRY_HEMOCHROMATOSES_10907072426647588457)],
        &[(0b11010, &ENTRY_HEMOCHROMATOSIS_12928559471676134380)],
        &[(0b11010, &ENTRY_HEMOCHROME_9228123554665839557)],
        &[(0b11010, &ENTRY_HEMOCOEL_16919582459376619162)],
        &[(0b11010, &ENTRY_HEMOCOELS_6456260620954605946)],
        &[(0b11010, &ENTRY_HEMOCONCENTRATION_13535154840039489558)],
        &[(0b11010, &ENTRY_HEMOCONIA_16736345270230227681)],
        &[(0b11010, &ENTRY_HEMOCYANIN_9642423587808035318)],
        &[(0b11010, &ENTRY_HEMOCYANINS_13211158798270421692)],
        &[(0b11010, &ENTRY_HEMOCYTE_9056880844554795657)],
        &[(0b11010, &ENTRY_HEMOCYTES_11970486144013002814)],
        &[(0b11010, &ENTRY_HEMOCYTOBLAST_3749643051292331307)],
        &[(0b11010, &ENTRY_HEMOCYTOBLASTIC_2891142520537992931)],
        &[(0b11010, &ENTRY_HEMOCYTOMETER_9911855835830563156)],
        &[(0b10010, &ENTRY_HEMODIALYSES_7416791187084499531)],
        &[(0b10010, &ENTRY_HEMODIALYSIS_2356269218981689445)],
        &[(0b11010, &ENTRY_HEMODILUTION_8908658927910101249)],
        &[(0b11010, &ENTRY_HEMODYNAMIC_99687820226271458)],
        &[(0b11010, &ENTRY_HEMODYNAMICS_13468985183469387770)],
        &[(0b11010, &ENTRY_HEMOFLAGELLATE_1909016951558476190)],
        &[(0b11010, &ENTRY_HEMOGLOBIC_12569293265233239479)],
        &[(0b10010, &ENTRY_HEMOGLOBIN_7404896410383089627)],
        &[(0b11010, &ENTRY_HEMOGLOBINOPATHIES_14362809746066184976)],
        &[(0b11010, &ENTRY_HEMOGLOBINOPATHY_12649532936999683142)],
        &[(0b11010, &ENTRY_HEMOGLOBINOUS_1428697249377514098)],
        &[(0b11010, &ENTRY_HEMOGLOBINURIA_2281539742314619937)],
        &[(0b11010, &ENTRY_HEMOGRAM_4160553122541107842)],
        &[(0b11010, &ENTRY_HEMOID_18441428178335197003)],
        &[(0b11010, &ENTRY_HEMOLYSIN_4766300835176555554)],
        &[(0b10010, &ENTRY_HEMOLYSIS_6121455356135496493)],
        &[(0b11010, &ENTRY_HEMOLYTIC_15374482328757058560)],
        &[(0b11010, &ENTRY_HEMOMETER_3114013764107256805)],
        &[(0b11010, &ENTRY_HEMON_15552272331833168453)],
        &[(0b11010, &ENTRY_HEMOPHILE_12901546318135530373)],
        &[(0b10010, &ENTRY_HEMOPHILIA_7379790116520405129)],
        &[(0b10010, &ENTRY_HEMOPHILIAC_15127098181926005330)],
        &[(0b10010, &ENTRY_HEMOPHILIACS_1819791222881034020)],
        &[(0b10010, &ENTRY_HEMOPHILIC_14674123167547417778)],
        &[(0b11010, &ENTRY_HEMOPOD_2878895326095181845)],
        &[(0b11010, &ENTRY_HEMOPOIESIS_4521489762869246287)],
        &[(0b11010, &ENTRY_HEMOPTYSES_9711906895580892150)],
        &[(0b11010, &ENTRY_HEMOPTYSIS_6606896046225564524)],
        &[(0b10010, &ENTRY_HEMORRHAGE_13487833252665047802)],
        &[(0b10010, &ENTRY_HEMORRHAGED_3567508913732842236)],
        &[(0b10010, &ENTRY_HEMORRHAGES_11033424934560552856)],
        &[(0b10010, &ENTRY_HEMORRHAGING_14700849159949160924)],
        &[(0b10010, &ENTRY_HEMORRHOID_7766599523154289018)],
        &[(0b10010, &ENTRY_HEMORRHOIDAL_10501532313574976310)],
        &[(0b11010, &ENTRY_HEMORRHOIDECTOMY_4750049726844559549)],
        &[(0b10010, &ENTRY_HEMORRHOIDS_13714329857736517214)],
        &[(0b11010, &ENTRY_HEMOSPORID_17787470410905331344)],
        &[(0b11010, &ENTRY_HEMOSPORIDIAN_16163775887165910953)],
        &[(0b11010, &ENTRY_HEMOSTASES_17875899375851174427)],
        &[(0b11010, &ENTRY_HEMOSTASIA_2990592071271355209)],
        &[(0b11010, &ENTRY_HEMOSTASIS_10601607695856646551)],
        &[(0b11010, &ENTRY_HEMOSTATIC_11321860210181124752)],
        &[(0b11010, &ENTRY_HEMOTHORAX_6930101878147813840)],
        &[(0b11010, &ENTRY_HEMOTOXIC_9808851015011198385)],
        &[(0b11010, &ENTRY_HEMOTOXIN_12328861364395861819)],
    ],
    range: 1..=14,
};

static VARS_HAEMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMI_CHILDREN),
    value: None,
};

pub static VARS_HAEMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("c"),
        dictgen::InsensitiveStr::Ascii("n"),
        dictgen::InsensitiveStr::Ascii("ns"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEMIC_10115849406341667247)],
        &[(0b11010, &ENTRY_HEMIN_13635073169658330154)],
        &[(0b11010, &ENTRY_HEMINS_1405124450165077449)],
    ],
    range: 1..=2,
};

static VARS_HAEMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HAEMA_CHILDREN),
    value: None,
};

static VARS_HAEMA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_HAEMAC_NODE),
    Some(&VARS_HAEMAD_NODE),
    None,
    None,
    Some(&VARS_HAEMAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_HAEMAL_NODE),
    None,
    Some(&VARS_HAEMAN_NODE),
    None,
    Some(&VARS_HAEMAP_NODE),
    None,
    None,
    Some(&VARS_HAEMAS_NODE),
    Some(&VARS_HAEMAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HAEMAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAT_CHILDREN),
    value: None,
};

pub static VARS_HAEMAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("al"),
        dictgen::InsensitiveStr::Ascii("ein"),
        dictgen::InsensitiveStr::Ascii("emesis"),
        dictgen::InsensitiveStr::Ascii("herm"),
        dictgen::InsensitiveStr::Ascii("hermal"),
        dictgen::InsensitiveStr::Ascii("hermous"),
        dictgen::InsensitiveStr::Ascii("ic"),
        dictgen::InsensitiveStr::Ascii("ics"),
        dictgen::InsensitiveStr::Ascii("id"),
        dictgen::InsensitiveStr::Ascii("in"),
        dictgen::InsensitiveStr::Ascii("inic"),
        dictgen::InsensitiveStr::Ascii("inics"),
        dictgen::InsensitiveStr::Ascii("ins"),
        dictgen::InsensitiveStr::Ascii("ite"),
        dictgen::InsensitiveStr::Ascii("ites"),
        dictgen::InsensitiveStr::Ascii("itic"),
        dictgen::InsensitiveStr::Ascii("oblast"),
        dictgen::InsensitiveStr::Ascii("oblasts"),
        dictgen::InsensitiveStr::Ascii("obranchiate"),
        dictgen::InsensitiveStr::Ascii("ocele"),
        dictgen::InsensitiveStr::Ascii("ocrit"),
        dictgen::InsensitiveStr::Ascii("ocrits"),
        dictgen::InsensitiveStr::Ascii("ocryal"),
        dictgen::InsensitiveStr::Ascii("ocyst"),
        dictgen::InsensitiveStr::Ascii("ocystis"),
        dictgen::InsensitiveStr::Ascii("ocyte"),
        dictgen::InsensitiveStr::Ascii("ogeneses"),
        dictgen::InsensitiveStr::Ascii("ogenesis"),
        dictgen::InsensitiveStr::Ascii("ogenous"),
        dictgen::InsensitiveStr::Ascii("oid"),
        dictgen::InsensitiveStr::Ascii("oidin"),
        dictgen::InsensitiveStr::Ascii("ologic"),
        dictgen::InsensitiveStr::Ascii("ological"),
        dictgen::InsensitiveStr::Ascii("ologies"),
        dictgen::InsensitiveStr::Ascii("ologist"),
        dictgen::InsensitiveStr::Ascii("ologists"),
        dictgen::InsensitiveStr::Ascii("ology"),
        dictgen::InsensitiveStr::Ascii("olysis"),
        dictgen::InsensitiveStr::Ascii("oma"),
        dictgen::InsensitiveStr::Ascii("omas"),
        dictgen::InsensitiveStr::Ascii("omata"),
        dictgen::InsensitiveStr::Ascii("ometer"),
        dictgen::InsensitiveStr::Ascii("ophyte"),
        dictgen::InsensitiveStr::Ascii("opoieses"),
        dictgen::InsensitiveStr::Ascii("opoiesis"),
        dictgen::InsensitiveStr::Ascii("opoietic"),
        dictgen::InsensitiveStr::Ascii("orrhachis"),
        dictgen::InsensitiveStr::Ascii("osepsis"),
        dictgen::InsensitiveStr::Ascii("osin"),
        dictgen::InsensitiveStr::Ascii("osis"),
        dictgen::InsensitiveStr::Ascii("othermal"),
        dictgen::InsensitiveStr::Ascii("oxylic"),
        dictgen::InsensitiveStr::Ascii("oxylin"),
        dictgen::InsensitiveStr::Ascii("oxylins"),
        dictgen::InsensitiveStr::Ascii("ozoa"),
        dictgen::InsensitiveStr::Ascii("ozoal"),
        dictgen::InsensitiveStr::Ascii("ozoic"),
        dictgen::InsensitiveStr::Ascii("ozoon"),
        dictgen::InsensitiveStr::Ascii("ozzoa"),
        dictgen::InsensitiveStr::Ascii("uria"),
        dictgen::InsensitiveStr::Ascii("urias"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEMATAL_3473810694033526440)],
        &[(0b11010, &ENTRY_HEMATEIN_10299149840045810913)],
        &[(0b11010, &ENTRY_HEMATEMESIS_9702571717419169155)],
        &[(0b11010, &ENTRY_HEMATHERM_7916536178037640325)],
        &[(0b11010, &ENTRY_HEMATHERMAL_5311148388316154601)],
        &[(0b11010, &ENTRY_HEMATHERMOUS_11665424966689074429)],
        &[(0b11010, &ENTRY_HEMATIC_11297008998147653262)],
        &[(0b11010, &ENTRY_HEMATICS_2072799741740171039)],
        &[(0b11010, &ENTRY_HEMATID_3667205209302242194)],
        &[(0b11010, &ENTRY_HEMATIN_17310006637994072946)],
        &[(0b11010, &ENTRY_HEMATINIC_5947779393945499901)],
        &[(0b11010, &ENTRY_HEMATINICS_5405890465468753688)],
        &[(0b11010, &ENTRY_HEMATINS_5995391549674023251)],
        &[(0b10010, &ENTRY_HEMATITE_14468869663106727324)],
        &[(0b10010, &ENTRY_HEMATITES_16432545135150625666)],
        &[(0b11010, &ENTRY_HEMATITIC_1011725836724738056)],
        &[(0b11010, &ENTRY_HEMATOBLAST_11319499306489037671)],
        &[(0b11010, &ENTRY_HEMATOBLASTS_15227166432548606675)],
        &[(0b11010, &ENTRY_HEMATOBRANCHIATE_2844231569938030599)],
        &[(0b10010, &ENTRY_HEMATOCELE_1972666202637019639)],
        &[(0b11010, &ENTRY_HEMATOCRIT_11776543127174567971)],
        &[(0b11010, &ENTRY_HEMATOCRITS_16251852522040291719)],
        &[(0b11010, &ENTRY_HEMATOCRYAL_4555256092073194861)],
        &[(0b11010, &ENTRY_HEMATOCYST_464557994908851606)],
        &[(0b11010, &ENTRY_HEMATOCYSTIS_7706855010020816013)],
        &[(0b11010, &ENTRY_HEMATOCYTE_2489259526058226349)],
        &[(0b11010, &ENTRY_HEMATOGENESES_2202464054562607490)],
        &[(0b11010, &ENTRY_HEMATOGENESIS_7325937725699823684)],
        &[(0b11010, &ENTRY_HEMATOGENOUS_7648472768292588686)],
        &[(0b11010, &ENTRY_HEMATOID_1808679171388326204)],
        &[(0b11010, &ENTRY_HEMATOIDIN_5202724309086507251)],
        &[(0b10010, &ENTRY_HEMATOLOGIC_18220046089117542599)],
        &[(0b10010, &ENTRY_HEMATOLOGICAL_1312253959057451336)],
        &[(0b10010, &ENTRY_HEMATOLOGIES_16189544558993565198)],
        &[(0b10010, &ENTRY_HEMATOLOGIST_14280007862665204292)],
        &[(0b10010, &ENTRY_HEMATOLOGISTS_4782136239490629800)],
        &[(0b10010, &ENTRY_HEMATOLOGY_15238707498752205552)],
        &[(0b11010, &ENTRY_HEMATOLYSIS_18079015402986824465)],
        &[(0b11010, &ENTRY_HEMATOMA_15558161368313999362)],
        &[(0b11010, &ENTRY_HEMATOMAS_908833652817460466)],
        &[(0b11010, &ENTRY_HEMATOMATA_17333608130883052853)],
        &[(0b11010, &ENTRY_HEMATOMETER_8659377563531118312)],
        &[(0b11010, &ENTRY_HEMATOPHYTE_7980419769606343875)],
        &[(0b11010, &ENTRY_HEMATOPOIESES_1762593598918477279)],
        &[(0b11010, &ENTRY_HEMATOPOIESIS_14957246204910848242)],
        &[(0b11010, &ENTRY_HEMATOPOIETIC_5636580279732200517)],
        &[(0b11010, &ENTRY_HEMATORRHACHIS_3244347879185405245)],
        &[(0b11010, &ENTRY_HEMATOSEPSIS_11620038395306762074)],
        &[(0b11010, &ENTRY_HEMATOSIN_9020358802336175805)],
        &[(0b11010, &ENTRY_HEMATOSIS_3383158544475611837)],
        &[(0b11010, &ENTRY_HEMATOTHERMAL_8194902579206605957)],
        &[(0b11010, &ENTRY_HEMATOXYLIC_15238360661772109231)],
        &[(0b10010, &ENTRY_HEMATOXYLIN_6889865558698001812)],
        &[(0b10010, &ENTRY_HEMATOXYLINS_16418497755495172078)],
        &[(0b11010, &ENTRY_HEMATOZOA_16310785411433507697)],
        &[(0b11010, &ENTRY_HEMATOZOAL_5612358861578154128)],
        &[(0b11010, &ENTRY_HEMATOZOIC_6811181829581742874)],
        &[(0b11010, &ENTRY_HEMATOZOON_9291195545747434433)],
        &[(0b11010, &ENTRY_HEMATOZZOA_17098302032357442259)],
        &[(0b10010, &ENTRY_HEMATURIA_2017961132280396424)],
        &[(0b10010, &ENTRY_HEMATURIAS_9554717110278540795)],
    ],
    range: 2..=11,
};

static VARS_HAEMAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAS_CHILDREN),
    value: None,
};

pub static VARS_HAEMAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("pectroscope")],
    values: &[&[(0b11010, &ENTRY_HEMASPECTROSCOPE_16029860263959084403)]],
    range: 11..=11,
};

static VARS_HAEMAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAP_CHILDREN),
    value: None,
};

pub static VARS_HAEMAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ophysis")],
    values: &[&[(0b11010, &ENTRY_HEMAPOPHYSIS_5976691613656262020)]],
    range: 7..=7,
};

static VARS_HAEMAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAN_CHILDREN),
    value: None,
};

pub static VARS_HAEMAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gioma"),
        dictgen::InsensitiveStr::Ascii("giomas"),
        dictgen::InsensitiveStr::Ascii("giomata"),
        dictgen::InsensitiveStr::Ascii("giomatosis"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEMANGIOMA_15185992059473862053)],
        &[(0b11010, &ENTRY_HEMANGIOMAS_3389015659974672405)],
        &[(0b11010, &ENTRY_HEMANGIOMATA_14171539534972503880)],
        &[(0b11010, &ENTRY_HEMANGIOMATOSIS_18422709517634643109)],
    ],
    range: 5..=10,
};

static VARS_HAEMAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAL_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_HEMAL_17441393171650814474)]),
};

pub static VARS_HAEMAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_HAEMAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAG_CHILDREN),
    value: None,
};

pub static VARS_HAEMAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("glutinate"),
        dictgen::InsensitiveStr::Ascii("glutinated"),
        dictgen::InsensitiveStr::Ascii("glutinating"),
        dictgen::InsensitiveStr::Ascii("glutination"),
        dictgen::InsensitiveStr::Ascii("glutinative"),
        dictgen::InsensitiveStr::Ascii("glutinin"),
        dictgen::InsensitiveStr::Ascii("ogue"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEMAGGLUTINATE_7259240567955031710)],
        &[(0b11010, &ENTRY_HEMAGGLUTINATED_3077985582864313404)],
        &[(0b11010, &ENTRY_HEMAGGLUTINATING_8254766798057399155)],
        &[(0b11010, &ENTRY_HEMAGGLUTINATION_8886672716726419818)],
        &[(0b11010, &ENTRY_HEMAGGLUTINATIVE_303261690448078143)],
        &[(0b11010, &ENTRY_HEMAGGLUTININ_15923049545494135264)],
        &[(0b11010, &ENTRY_HEMAGOGUE_11741387198881455915)],
    ],
    range: 4..=11,
};

static VARS_HAEMAD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAD_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_HEMAD_17500113374481638242)]),
};

pub static VARS_HAEMAD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_HAEMAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAC_CHILDREN),
    value: None,
};

pub static VARS_HAEMAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hrome"),
        dictgen::InsensitiveStr::Ascii("ytometer"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEMACHROME_3729476956483251061)],
        &[(0b11010, &ENTRY_HEMACYTOMETER_7645968025995756392)],
    ],
    range: 5..=8,
};

static VARS_HAED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAED_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_HED_5256048441648265391)]),
};

pub static VARS_HAED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_HAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAB_CHILDREN),
    value: None,
};

pub static VARS_HAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itualise"),
        dictgen::InsensitiveStr::Ascii("itualises"),
        dictgen::InsensitiveStr::Ascii("itualize"),
        dictgen::InsensitiveStr::Ascii("itualizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HABITUALIZE_4203840421950334477)],
        &[(0b10010, &ENTRY_HABITUALIZES_16212776537383243642)],
        &[(0b01001, &ENTRY_HABITUALIZE_4203840421950334477)],
        &[(0b01001, &ENTRY_HABITUALIZES_16212776537383243642)],
    ],
    range: 8..=9,
};

static VARS_G_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_G_CHILDREN),
    value: None,
};

static VARS_G_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_GA_NODE),
    None,
    None,
    None,
    Some(&VARS_GE_NODE),
    None,
    None,
    Some(&VARS_GH_NODE),
    Some(&VARS_GI_NODE),
    None,
    None,
    Some(&VARS_GL_NODE),
    None,
    Some(&VARS_GN_NODE),
    Some(&VARS_GO_NODE),
    None,
    None,
    Some(&VARS_GR_NODE),
    None,
    None,
    Some(&VARS_GU_NODE),
    None,
    None,
    None,
    Some(&VARS_GY_NODE),
    None,
];

static VARS_GY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GY_CHILDREN),
    value: None,
};

static VARS_GY_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GYN_NODE),
    None,
    None,
    None,
    Some(&VARS_GYR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_GYR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GYR_CHILDREN),
    value: None,
};

pub static VARS_GYR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ostabilisation"),
        dictgen::InsensitiveStr::Ascii("ostabilisations"),
        dictgen::InsensitiveStr::Ascii("ostabiliser"),
        dictgen::InsensitiveStr::Ascii("ostabilisers"),
        dictgen::InsensitiveStr::Ascii("ostabilization"),
        dictgen::InsensitiveStr::Ascii("ostabilizations"),
        dictgen::InsensitiveStr::Ascii("ostabilizer"),
        dictgen::InsensitiveStr::Ascii("ostabilizers"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GYROSTABILIZATION_7833567575472897725)],
        &[(0b10010, &ENTRY_GYROSTABILIZATIONS_14377043501796299026)],
        &[(0b10010, &ENTRY_GYROSTABILIZER_5766982365169984991)],
        &[(0b10010, &ENTRY_GYROSTABILIZERS_1151210600208488533)],
        &[(0b01001, &ENTRY_GYROSTABILIZATION_7833567575472897725)],
        &[(0b01001, &ENTRY_GYROSTABILIZATIONS_14377043501796299026)],
        &[(0b01001, &ENTRY_GYROSTABILIZER_5766982365169984991)],
        &[(0b01001, &ENTRY_GYROSTABILIZERS_1151210600208488533)],
    ],
    range: 11..=15,
};

static VARS_GYN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GYN_CHILDREN),
    value: None,
};

static VARS_GYN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_GYNA_NODE),
    None,
    None,
    None,
    Some(&VARS_GYNE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GYNO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_GYNO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GYNO_CHILDREN),
    value: None,
};

pub static VARS_GYNO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("monecious"),
        dictgen::InsensitiveStr::Ascii("monoecious"),
    ],
    values: &[
        &[(0b10001, &ENTRY_GYNOMONECIOUS_610910634720209122)],
        &[(0b11010, &ENTRY_GYNOMONECIOUS_610910634720209122)],
    ],
    range: 9..=10,
};

static VARS_GYNE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GYNE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_GYNE_11492145333652169582)]),
};

pub static VARS_GYNE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cic"),
        dictgen::InsensitiveStr::Ascii("cocracies"),
        dictgen::InsensitiveStr::Ascii("cocracy"),
        dictgen::InsensitiveStr::Ascii("cocrat"),
        dictgen::InsensitiveStr::Ascii("cocratic"),
        dictgen::InsensitiveStr::Ascii("cocraticer"),
        dictgen::InsensitiveStr::Ascii("cocraticest"),
        dictgen::InsensitiveStr::Ascii("cocrats"),
        dictgen::InsensitiveStr::Ascii("coid"),
        dictgen::InsensitiveStr::Ascii("col"),
        dictgen::InsensitiveStr::Ascii("cologic"),
        dictgen::InsensitiveStr::Ascii("cological"),
        dictgen::InsensitiveStr::Ascii("cologicaler"),
        dictgen::InsensitiveStr::Ascii("cologicalest"),
        dictgen::InsensitiveStr::Ascii("cologicals"),
        dictgen::InsensitiveStr::Ascii("cologicer"),
        dictgen::InsensitiveStr::Ascii("cologicest"),
        dictgen::InsensitiveStr::Ascii("cologics"),
        dictgen::InsensitiveStr::Ascii("cologies"),
        dictgen::InsensitiveStr::Ascii("cologist"),
        dictgen::InsensitiveStr::Ascii("cologists"),
        dictgen::InsensitiveStr::Ascii("cology"),
        dictgen::InsensitiveStr::Ascii("comastia"),
        dictgen::InsensitiveStr::Ascii("comastias"),
        dictgen::InsensitiveStr::Ascii("comasty"),
        dictgen::InsensitiveStr::Ascii("comorphous"),
        dictgen::InsensitiveStr::Ascii("conitis"),
        dictgen::InsensitiveStr::Ascii("ocracy"),
        dictgen::InsensitiveStr::Ascii("olater"),
        dictgen::InsensitiveStr::Ascii("olatry"),
    ],
    values: &[
        &[(0b10001, &ENTRY_GYNECIC_11400947530619276843)],
        &[(0b10001, &ENTRY_GYNECOCRACIES_4146735725336382856)],
        &[(0b10001, &ENTRY_GYNECOCRACY_12364327428525738345)],
        &[(0b10001, &ENTRY_GYNECOCRAT_5136932759212429718)],
        &[(0b10001, &ENTRY_GYNECOCRATIC_7409449360121943743)],
        &[(0b10001, &ENTRY_GYNECOCRATICER_11125263222450989759)],
        &[(0b10001, &ENTRY_GYNECOCRATICEST_12037974266743513062)],
        &[(0b10001, &ENTRY_GYNECOCRATS_17873741619796682189)],
        &[(0b10001, &ENTRY_GYNECOID_7912530212797782324)],
        &[(0b10001, &ENTRY_GYNECOL_5663216141561132674)],
        &[(0b10001, &ENTRY_GYNECOLOGIC_10610170504252042060)],
        &[(0b11001, &ENTRY_GYNECOLOGICAL_10068656459548202370)],
        &[(0b11001, &ENTRY_GYNECOLOGICALER_5828237580949279739)],
        &[(0b11001, &ENTRY_GYNECOLOGICALEST_11608781569016296041)],
        &[(0b11001, &ENTRY_GYNECOLOGICALS_16704040688018194960)],
        &[(0b10001, &ENTRY_GYNECOLOGICER_12168946939743180099)],
        &[(0b10001, &ENTRY_GYNECOLOGICEST_18236154890722287831)],
        &[(0b10001, &ENTRY_GYNECOLOGICS_13595002505435197512)],
        &[(0b11001, &ENTRY_GYNECOLOGIES_7633791099195262658)],
        &[(0b11001, &ENTRY_GYNECOLOGIST_2204758927405939841)],
        &[(0b11001, &ENTRY_GYNECOLOGISTS_8430092894671465244)],
        &[(0b11001, &ENTRY_GYNECOLOGY_6636046866210569760)],
        &[(0b11001, &ENTRY_GYNECOMASTIA_14330546154000297664)],
        &[(0b11001, &ENTRY_GYNECOMASTIAS_4871542087429003006)],
        &[(0b10001, &ENTRY_GYNECOMASTY_18357916230291548808)],
        &[(0b10001, &ENTRY_GYNECOMORPHOUS_16181722902078327778)],
        &[(0b10001, &ENTRY_GYNECONITIS_10352018651930377014)],
        &[(0b10001, &ENTRY_GYNEOCRACY_3724321183261322247)],
        &[(0b10001, &ENTRY_GYNEOLATER_7201516700429061903)],
        &[(0b10001, &ENTRY_GYNEOLATRY_7952197731609201219)],
    ],
    range: 3..=12,
};

static VARS_GYNA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GYNA_CHILDREN),
    value: None,
};

pub static VARS_GYNA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ecic"),
        dictgen::InsensitiveStr::Ascii("ecocracies"),
        dictgen::InsensitiveStr::Ascii("ecocracy"),
        dictgen::InsensitiveStr::Ascii("ecocrat"),
        dictgen::InsensitiveStr::Ascii("ecocratic"),
        dictgen::InsensitiveStr::Ascii("ecocraticer"),
        dictgen::InsensitiveStr::Ascii("ecocraticest"),
        dictgen::InsensitiveStr::Ascii("ecocrats"),
        dictgen::InsensitiveStr::Ascii("ecoid"),
        dictgen::InsensitiveStr::Ascii("ecol"),
        dictgen::InsensitiveStr::Ascii("ecologic"),
        dictgen::InsensitiveStr::Ascii("ecological"),
        dictgen::InsensitiveStr::Ascii("ecologicaler"),
        dictgen::InsensitiveStr::Ascii("ecologicalest"),
        dictgen::InsensitiveStr::Ascii("ecologicals"),
        dictgen::InsensitiveStr::Ascii("ecologicer"),
        dictgen::InsensitiveStr::Ascii("ecologicest"),
        dictgen::InsensitiveStr::Ascii("ecologics"),
        dictgen::InsensitiveStr::Ascii("ecologies"),
        dictgen::InsensitiveStr::Ascii("ecologist"),
        dictgen::InsensitiveStr::Ascii("ecologists"),
        dictgen::InsensitiveStr::Ascii("ecology"),
        dictgen::InsensitiveStr::Ascii("ecomastia"),
        dictgen::InsensitiveStr::Ascii("ecomastias"),
        dictgen::InsensitiveStr::Ascii("ecomasty"),
        dictgen::InsensitiveStr::Ascii("ecomorphous"),
        dictgen::InsensitiveStr::Ascii("econitis"),
        dictgen::InsensitiveStr::Ascii("eocracy"),
        dictgen::InsensitiveStr::Ascii("eolater"),
        dictgen::InsensitiveStr::Ascii("eolatry"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GYNE_11492145333652169582)],
        &[(0b11010, &ENTRY_GYNECIC_11400947530619276843)],
        &[(0b11010, &ENTRY_GYNECOCRACIES_4146735725336382856)],
        &[(0b11010, &ENTRY_GYNECOCRACY_12364327428525738345)],
        &[(0b11010, &ENTRY_GYNECOCRAT_5136932759212429718)],
        &[(0b11010, &ENTRY_GYNECOCRATIC_7409449360121943743)],
        &[(0b11010, &ENTRY_GYNECOCRATICER_11125263222450989759)],
        &[(0b11010, &ENTRY_GYNECOCRATICEST_12037974266743513062)],
        &[(0b11010, &ENTRY_GYNECOCRATS_17873741619796682189)],
        &[(0b11010, &ENTRY_GYNECOID_7912530212797782324)],
        &[(0b11010, &ENTRY_GYNECOL_5663216141561132674)],
        &[(0b11010, &ENTRY_GYNECOLOGIC_10610170504252042060)],
        &[(0b10010, &ENTRY_GYNECOLOGICAL_10068656459548202370)],
        &[(0b10010, &ENTRY_GYNECOLOGICALER_5828237580949279739)],
        &[(0b10010, &ENTRY_GYNECOLOGICALEST_11608781569016296041)],
        &[(0b10010, &ENTRY_GYNECOLOGICALS_16704040688018194960)],
        &[(0b11010, &ENTRY_GYNECOLOGICER_12168946939743180099)],
        &[(0b11010, &ENTRY_GYNECOLOGICEST_18236154890722287831)],
        &[(0b11010, &ENTRY_GYNECOLOGICS_13595002505435197512)],
        &[(0b11010, &ENTRY_GYNECOLOGIES_7633791099195262658)],
        &[(0b10010, &ENTRY_GYNECOLOGIST_2204758927405939841)],
        &[(0b10010, &ENTRY_GYNECOLOGISTS_8430092894671465244)],
        &[(0b11010, &ENTRY_GYNECOLOGY_6636046866210569760)],
        &[(0b11010, &ENTRY_GYNECOMASTIA_14330546154000297664)],
        &[(0b11010, &ENTRY_GYNECOMASTIAS_4871542087429003006)],
        &[(0b11010, &ENTRY_GYNECOMASTY_18357916230291548808)],
        &[(0b11010, &ENTRY_GYNECOMORPHOUS_16181722902078327778)],
        &[(0b11010, &ENTRY_GYNECONITIS_10352018651930377014)],
        &[(0b11010, &ENTRY_GYNEOCRACY_3724321183261322247)],
        &[(0b11010, &ENTRY_GYNEOLATER_7201516700429061903)],
        &[(0b11010, &ENTRY_GYNEOLATRY_7952197731609201219)],
    ],
    range: 1..=13,
};

static VARS_GU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GU_CHILDREN),
    value: None,
};

pub static VARS_GU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eber"),
        dictgen::InsensitiveStr::Ascii("ebers"),
        dictgen::InsensitiveStr::Ascii("ebre"),
        dictgen::InsensitiveStr::Ascii("ebres"),
        dictgen::InsensitiveStr::Ascii("iser"),
        dictgen::InsensitiveStr::Ascii("isers"),
        dictgen::InsensitiveStr::Ascii("izer"),
        dictgen::InsensitiveStr::Ascii("izers"),
        dictgen::InsensitiveStr::Ascii("lae"),
        dictgen::InsensitiveStr::Ascii("le"),
        dictgen::InsensitiveStr::Ascii("ttae"),
        dictgen::InsensitiveStr::Ascii("tte"),
        dictgen::InsensitiveStr::Ascii("ttulae"),
        dictgen::InsensitiveStr::Ascii("ttule"),
        dictgen::InsensitiveStr::Ascii("tturalisation"),
        dictgen::InsensitiveStr::Ascii("tturalisations"),
        dictgen::InsensitiveStr::Ascii("tturalise"),
        dictgen::InsensitiveStr::Ascii("tturalised"),
        dictgen::InsensitiveStr::Ascii("tturalises"),
        dictgen::InsensitiveStr::Ascii("tturalising"),
        dictgen::InsensitiveStr::Ascii("tturalization"),
        dictgen::InsensitiveStr::Ascii("tturalizations"),
        dictgen::InsensitiveStr::Ascii("tturalize"),
        dictgen::InsensitiveStr::Ascii("tturalized"),
        dictgen::InsensitiveStr::Ascii("tturalizes"),
        dictgen::InsensitiveStr::Ascii("tturalizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GUEBER_15352407594453289171)],
        &[(0b00001, &ENTRY_GUEBERS_6286021004437496479)],
        &[(0b11010, &ENTRY_GUEBER_15352407594453289171)],
        &[(0b11010, &ENTRY_GUEBERS_6286021004437496479)],
        &[(0b10010, &ENTRY_GUIZER_580820017456619679)],
        &[(0b10010, &ENTRY_GUIZERS_2986544585266099405)],
        &[(0b01001, &ENTRY_GUIZER_580820017456619679)],
        &[(0b01001, &ENTRY_GUIZERS_2986544585266099405)],
        &[(0b11010, &ENTRY_GULE_11860123527431622005)],
        &[(0b00001, &ENTRY_GULE_11860123527431622005)],
        &[(0b11010, &ENTRY_GUTTE_16752124103215891589)],
        &[(0b00001, &ENTRY_GUTTE_16752124103215891589)],
        &[(0b11010, &ENTRY_GUTTULE_17990999550881257571)],
        &[(0b00001, &ENTRY_GUTTULE_17990999550881257571)],
        &[(0b10010, &ENTRY_GUTTURALIZATION_12853736513139068391)],
        &[(0b10010, &ENTRY_GUTTURALIZATIONS_6761955224769799830)],
        &[(0b10010, &ENTRY_GUTTURALIZE_16045921878572260792)],
        &[(0b10010, &ENTRY_GUTTURALIZED_17598926382362141161)],
        &[(0b10010, &ENTRY_GUTTURALIZES_17434359303702224403)],
        &[(0b10010, &ENTRY_GUTTURALIZING_18344702995674578601)],
        &[(0b01001, &ENTRY_GUTTURALIZATION_12853736513139068391)],
        &[(0b01001, &ENTRY_GUTTURALIZATIONS_6761955224769799830)],
        &[(0b01001, &ENTRY_GUTTURALIZE_16045921878572260792)],
        &[(0b01001, &ENTRY_GUTTURALIZED_17598926382362141161)],
        &[(0b01001, &ENTRY_GUTTURALIZES_17434359303702224403)],
        &[(0b01001, &ENTRY_GUTTURALIZING_18344702995674578601)],
    ],
    range: 2..=14,
};

static VARS_GR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GR_CHILDREN),
    value: None,
};

static VARS_GR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_GRA_NODE),
    None,
    None,
    None,
    Some(&VARS_GRE_NODE),
    None,
    None,
    None,
    Some(&VARS_GRI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GRO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GRU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_GRU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRU_CHILDREN),
    value: None,
};

pub static VARS_GRU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elingly"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellingly"),
        dictgen::InsensitiveStr::Ascii("ellings"),
    ],
    values: &[
        &[(0b01001, &ENTRY_GRUELED_11469179107855937094)],
        &[(0b00001, &ENTRY_GRUELER_9066861558472330595)],
        &[(0b00001, &ENTRY_GRUELERS_2726513939754824802)],
        &[(0b01001, &ENTRY_GRUELING_10540189782332096170)],
        &[(0b00001, &ENTRY_GRUELINGLY_17624749743431370706)],
        &[(0b01001, &ENTRY_GRUELINGS_2606568893918528496)],
        &[(0b11010, &ENTRY_GRUELED_11469179107855937094)],
        &[(0b11010, &ENTRY_GRUELER_9066861558472330595)],
        &[(0b11010, &ENTRY_GRUELERS_2726513939754824802)],
        &[(0b11010, &ENTRY_GRUELING_10540189782332096170)],
        &[(0b11010, &ENTRY_GRUELINGLY_17624749743431370706)],
        &[(0b11010, &ENTRY_GRUELINGS_2606568893918528496)],
    ],
    range: 4..=8,
};

static VARS_GRO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRO_CHILDREN),
    value: None,
};

pub static VARS_GRO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ined"),
        dictgen::InsensitiveStr::Ascii("ining"),
        dictgen::InsensitiveStr::Ascii("veled"),
        dictgen::InsensitiveStr::Ascii("veler"),
        dictgen::InsensitiveStr::Ascii("velers"),
        dictgen::InsensitiveStr::Ascii("veling"),
        dictgen::InsensitiveStr::Ascii("velinglier"),
        dictgen::InsensitiveStr::Ascii("velingliest"),
        dictgen::InsensitiveStr::Ascii("velingly"),
        dictgen::InsensitiveStr::Ascii("velled"),
        dictgen::InsensitiveStr::Ascii("veller"),
        dictgen::InsensitiveStr::Ascii("vellers"),
        dictgen::InsensitiveStr::Ascii("velling"),
        dictgen::InsensitiveStr::Ascii("vellinglier"),
        dictgen::InsensitiveStr::Ascii("vellingliest"),
        dictgen::InsensitiveStr::Ascii("vellingly"),
        dictgen::InsensitiveStr::Ascii("yne"),
        dictgen::InsensitiveStr::Ascii("yned"),
        dictgen::InsensitiveStr::Ascii("ynes"),
        dictgen::InsensitiveStr::Ascii("yning"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GROINED_2809452461899594102)],
        &[(0b00001, &ENTRY_GROINING_7538300092747501321)],
        &[(0b01001, &ENTRY_GROVELED_11655386549337225742)],
        &[(0b00001, &ENTRY_GROVELER_17000057584571165802)],
        &[(0b00001, &ENTRY_GROVELERS_1063263311160407851)],
        &[(0b01001, &ENTRY_GROVELING_12072037399255827644)],
        &[(0b00001, &ENTRY_GROVELINGLIER_1214630554400703346)],
        &[(0b00001, &ENTRY_GROVELINGLIEST_11811119470500539386)],
        &[(0b00001, &ENTRY_GROVELINGLY_8701513157425366439)],
        &[(0b11010, &ENTRY_GROVELED_11655386549337225742)],
        &[(0b11010, &ENTRY_GROVELER_17000057584571165802)],
        &[(0b11010, &ENTRY_GROVELERS_1063263311160407851)],
        &[(0b11010, &ENTRY_GROVELING_12072037399255827644)],
        &[(0b11010, &ENTRY_GROVELINGLIER_1214630554400703346)],
        &[(0b11010, &ENTRY_GROVELINGLIEST_11811119470500539386)],
        &[(0b11010, &ENTRY_GROVELINGLY_8701513157425366439)],
        &[(0b11010, &ENTRY_GROIN_5340788760231681661)],
        &[(0b11010, &ENTRY_GROINED_2809452461899594102)],
        &[(0b11010, &ENTRY_GROINS_7022214519428560367)],
        &[(0b11010, &ENTRY_GROINING_7538300092747501321)],
    ],
    range: 3..=12,
};

static VARS_GRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRI_CHILDREN),
    value: None,
};

pub static VARS_GRI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sard"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("zard"),
        dictgen::InsensitiveStr::Ascii("ze"),
        dictgen::InsensitiveStr::Ascii("zes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GRIZARD_17782998727447276529)],
        &[(0b10010, &ENTRY_GRIZE_16222725373368809072)],
        &[(0b10010, &ENTRY_GRIZES_14846823474697979680)],
        &[(0b01001, &ENTRY_GRIZARD_17782998727447276529)],
        &[(0b01001, &ENTRY_GRIZE_16222725373368809072)],
        &[(0b01001, &ENTRY_GRIZES_14846823474697979680)],
    ],
    range: 2..=4,
};

static VARS_GRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_GER_16895190685118522343)]),
};

pub static VARS_GRE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cian"),
        dictgen::InsensitiveStr::Ascii("cianise"),
        dictgen::InsensitiveStr::Ascii("cianises"),
        dictgen::InsensitiveStr::Ascii("cianize"),
        dictgen::InsensitiveStr::Ascii("cianizes"),
        dictgen::InsensitiveStr::Ascii("cise"),
        dictgen::InsensitiveStr::Ascii("cised"),
        dictgen::InsensitiveStr::Ascii("cises"),
        dictgen::InsensitiveStr::Ascii("cising"),
        dictgen::InsensitiveStr::Ascii("cize"),
        dictgen::InsensitiveStr::Ascii("cized"),
        dictgen::InsensitiveStr::Ascii("cizes"),
        dictgen::InsensitiveStr::Ascii("cizing"),
        dictgen::InsensitiveStr::Ascii("ekise"),
        dictgen::InsensitiveStr::Ascii("ekises"),
        dictgen::InsensitiveStr::Ascii("ekize"),
        dictgen::InsensitiveStr::Ascii("ekizes"),
        dictgen::InsensitiveStr::Ascii("enuk"),
        dictgen::InsensitiveStr::Ascii("isenisation"),
        dictgen::InsensitiveStr::Ascii("isenisations"),
        dictgen::InsensitiveStr::Ascii("isenise"),
        dictgen::InsensitiveStr::Ascii("isenised"),
        dictgen::InsensitiveStr::Ascii("isenises"),
        dictgen::InsensitiveStr::Ascii("isenising"),
        dictgen::InsensitiveStr::Ascii("isenization"),
        dictgen::InsensitiveStr::Ascii("isenizations"),
        dictgen::InsensitiveStr::Ascii("isenize"),
        dictgen::InsensitiveStr::Ascii("isenized"),
        dictgen::InsensitiveStr::Ascii("isenizes"),
        dictgen::InsensitiveStr::Ascii("isenizing"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("s"),
        dictgen::InsensitiveStr::Ascii("yish"),
        dictgen::InsensitiveStr::Ascii("yness"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GRECIAN_14860038034904089388)],
        &[(0b10010, &ENTRY_GRECIANIZE_12105732338554948425)],
        &[(0b10010, &ENTRY_GRECIANIZES_11174673507196729238)],
        &[(0b01001, &ENTRY_GRECIANIZE_12105732338554948425)],
        &[(0b01001, &ENTRY_GRECIANIZES_11174673507196729238)],
        &[
            (0b00001, &ENTRY_GRECISE_2532359423804381452),
            (0b10010, &ENTRY_GRECIZE_1961618991901266428),
            (0b10010, &ENTRY_GRECIZE_8007863070307700465),
        ],
        &[
            (0b00001, &ENTRY_GRECISED_8365655558591252453),
            (0b10010, &ENTRY_GRECIZED_11474072803323083598),
            (0b10010, &ENTRY_GRECIZED_5137584389270183448),
        ],
        &[(0b10010, &ENTRY_GRECIZES_1632490107158427095)],
        &[
            (0b00001, &ENTRY_GRECISING_10216329489666935575),
            (0b10010, &ENTRY_GRECIZING_1729797461872700220),
            (0b10010, &ENTRY_GRECIZING_8731072674304692212),
        ],
        &[
            (0b01001, &ENTRY_GRECIZE_1961618991901266428),
            (0b01001, &ENTRY_GRECIZE_8007863070307700465),
        ],
        &[
            (0b01001, &ENTRY_GRECIZED_11474072803323083598),
            (0b01001, &ENTRY_GRECIZED_5137584389270183448),
        ],
        &[(0b01001, &ENTRY_GRECIZES_1632490107158427095)],
        &[
            (0b01001, &ENTRY_GRECIZING_1729797461872700220),
            (0b01001, &ENTRY_GRECIZING_8731072674304692212),
        ],
        &[(0b10010, &ENTRY_GREEKIZE_15689792812774790072)],
        &[(0b10010, &ENTRY_GREEKIZES_6949350197314496533)],
        &[(0b01001, &ENTRY_GREEKIZE_15689792812774790072)],
        &[(0b01001, &ENTRY_GREEKIZES_6949350197314496533)],
        &[(0b11010, &ENTRY_GERENUK_5878790639893838830)],
        &[(0b10010, &ENTRY_GREISENIZATION_13825850823267727625)],
        &[(0b10010, &ENTRY_GREISENIZATIONS_6238511961327542361)],
        &[(0b10010, &ENTRY_GREISENIZE_16424858506500854091)],
        &[(0b10010, &ENTRY_GREISENIZED_17732441181252344688)],
        &[(0b10010, &ENTRY_GREISENIZES_13261726167693334943)],
        &[(0b10010, &ENTRY_GREISENIZING_10722346677413921325)],
        &[(0b01001, &ENTRY_GREISENIZATION_13825850823267727625)],
        &[(0b01001, &ENTRY_GREISENIZATIONS_6238511961327542361)],
        &[(0b01001, &ENTRY_GREISENIZE_16424858506500854091)],
        &[(0b01001, &ENTRY_GREISENIZED_17732441181252344688)],
        &[(0b01001, &ENTRY_GREISENIZES_13261726167693334943)],
        &[(0b01001, &ENTRY_GREISENIZING_10722346677413921325)],
        &[(0b11010, &ENTRY_GERNE_6398098570056353740)],
        &[(0b11010, &ENTRY_GERS_16671815364143402799)],
        &[(0b11010, &ENTRY_GRAYISH_1156907900107349696)],
        &[(0b11010, &ENTRY_GRAYNESS_14336126497721340945)],
    ],
    range: 1..=12,
};

static VARS_GRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GRA_CHILDREN),
    value: None,
};

static VARS_GRA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_GRAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GRAM_NODE),
    Some(&VARS_GRAN_NODE),
    None,
    Some(&VARS_GRAP_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GRAV_NODE),
    None,
    None,
    Some(&VARS_GRAY_NODE),
    None,
];

static VARS_GRAY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRAY_CHILDREN),
    value: None,
};

pub static VARS_GRAY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("est"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("ish"),
        dictgen::InsensitiveStr::Ascii("ness"),
    ],
    values: &[
        &[(0b01001, &ENTRY_GRAYED_2126221854892912128)],
        &[(0b01001, &ENTRY_GRAYER_16353903293922225810)],
        &[(0b01001, &ENTRY_GRAYEST_9398546240809766238)],
        &[(0b01001, &ENTRY_GRAYING_17334366481873759110)],
        &[(0b00001, &ENTRY_GRAYISH_1156907900107349696)],
        &[(0b00001, &ENTRY_GRAYNESS_14336126497721340945)],
    ],
    range: 2..=4,
};

static VARS_GRAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRAV_CHILDREN),
    value: None,
};

pub static VARS_GRAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GRAVELED_2807681232939008308)],
        &[(0b00001, &ENTRY_GRAVELING_10440686553850601055)],
        &[(0b11010, &ENTRY_GRAVELED_2807681232939008308)],
        &[(0b11010, &ENTRY_GRAVELING_10440686553850601055)],
    ],
    range: 4..=6,
};

static VARS_GRAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRAP_CHILDREN),
    value: None,
};

pub static VARS_GRAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hitisable"),
        dictgen::InsensitiveStr::Ascii("hitisation"),
        dictgen::InsensitiveStr::Ascii("hitisations"),
        dictgen::InsensitiveStr::Ascii("hitise"),
        dictgen::InsensitiveStr::Ascii("hitised"),
        dictgen::InsensitiveStr::Ascii("hitises"),
        dictgen::InsensitiveStr::Ascii("hitising"),
        dictgen::InsensitiveStr::Ascii("hitizable"),
        dictgen::InsensitiveStr::Ascii("hitization"),
        dictgen::InsensitiveStr::Ascii("hitizations"),
        dictgen::InsensitiveStr::Ascii("hitize"),
        dictgen::InsensitiveStr::Ascii("hitized"),
        dictgen::InsensitiveStr::Ascii("hitizes"),
        dictgen::InsensitiveStr::Ascii("hitizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GRAPHITIZABLE_4023736760922492467)],
        &[(0b10010, &ENTRY_GRAPHITIZATION_2583924609541307295)],
        &[(0b10010, &ENTRY_GRAPHITIZATIONS_11033090213797442310)],
        &[(0b10010, &ENTRY_GRAPHITIZE_820728043344395996)],
        &[(0b10010, &ENTRY_GRAPHITIZED_6227783366697728706)],
        &[(0b10010, &ENTRY_GRAPHITIZES_4200881641591371190)],
        &[(0b10010, &ENTRY_GRAPHITIZING_8705628871531345361)],
        &[(0b01001, &ENTRY_GRAPHITIZABLE_4023736760922492467)],
        &[(0b01001, &ENTRY_GRAPHITIZATION_2583924609541307295)],
        &[(0b01001, &ENTRY_GRAPHITIZATIONS_11033090213797442310)],
        &[(0b01001, &ENTRY_GRAPHITIZE_820728043344395996)],
        &[(0b01001, &ENTRY_GRAPHITIZED_6227783366697728706)],
        &[(0b01001, &ENTRY_GRAPHITIZES_4200881641591371190)],
        &[(0b01001, &ENTRY_GRAPHITIZING_8705628871531345361)],
    ],
    range: 6..=11,
};

static VARS_GRAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRAN_CHILDREN),
    value: None,
};

pub static VARS_GRAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gerisation"),
        dictgen::InsensitiveStr::Ascii("gerisations"),
        dictgen::InsensitiveStr::Ascii("gerise"),
        dictgen::InsensitiveStr::Ascii("gerised"),
        dictgen::InsensitiveStr::Ascii("geriser"),
        dictgen::InsensitiveStr::Ascii("gerisers"),
        dictgen::InsensitiveStr::Ascii("gerises"),
        dictgen::InsensitiveStr::Ascii("gerising"),
        dictgen::InsensitiveStr::Ascii("gerization"),
        dictgen::InsensitiveStr::Ascii("gerizations"),
        dictgen::InsensitiveStr::Ascii("gerize"),
        dictgen::InsensitiveStr::Ascii("gerized"),
        dictgen::InsensitiveStr::Ascii("gerizer"),
        dictgen::InsensitiveStr::Ascii("gerizers"),
        dictgen::InsensitiveStr::Ascii("gerizes"),
        dictgen::InsensitiveStr::Ascii("gerizing"),
        dictgen::InsensitiveStr::Ascii("itisation"),
        dictgen::InsensitiveStr::Ascii("itisations"),
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itization"),
        dictgen::InsensitiveStr::Ascii("itizations"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
        dictgen::InsensitiveStr::Ascii("ulise"),
        dictgen::InsensitiveStr::Ascii("ulises"),
        dictgen::InsensitiveStr::Ascii("ulitisation"),
        dictgen::InsensitiveStr::Ascii("ulitisations"),
        dictgen::InsensitiveStr::Ascii("ulitization"),
        dictgen::InsensitiveStr::Ascii("ulitizations"),
        dictgen::InsensitiveStr::Ascii("ulize"),
        dictgen::InsensitiveStr::Ascii("ulizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GRANGERIZATION_9648135893564549333)],
        &[(0b10010, &ENTRY_GRANGERIZATIONS_964259139336744472)],
        &[(0b10010, &ENTRY_GRANGERIZE_11480909331809274858)],
        &[(0b10010, &ENTRY_GRANGERIZED_17258742687972795253)],
        &[(0b10010, &ENTRY_GRANGERIZER_5049165606212077831)],
        &[(0b10010, &ENTRY_GRANGERIZERS_8651613919277864726)],
        &[(0b10010, &ENTRY_GRANGERIZES_10405739052106575692)],
        &[(0b10010, &ENTRY_GRANGERIZING_14698907453901269575)],
        &[(0b01001, &ENTRY_GRANGERIZATION_9648135893564549333)],
        &[(0b01001, &ENTRY_GRANGERIZATIONS_964259139336744472)],
        &[(0b01001, &ENTRY_GRANGERIZE_11480909331809274858)],
        &[(0b01001, &ENTRY_GRANGERIZED_17258742687972795253)],
        &[(0b01001, &ENTRY_GRANGERIZER_5049165606212077831)],
        &[(0b01001, &ENTRY_GRANGERIZERS_8651613919277864726)],
        &[(0b01001, &ENTRY_GRANGERIZES_10405739052106575692)],
        &[(0b01001, &ENTRY_GRANGERIZING_14698907453901269575)],
        &[(0b10010, &ENTRY_GRANITIZATION_1851229670882829451)],
        &[(0b10010, &ENTRY_GRANITIZATIONS_7558118776122917287)],
        &[(0b10010, &ENTRY_GRANITIZE_18215727739855140563)],
        &[(0b10010, &ENTRY_GRANITIZED_1449233752463750138)],
        &[(0b10010, &ENTRY_GRANITIZES_5080962380592360311)],
        &[(0b10010, &ENTRY_GRANITIZING_9024106896826166145)],
        &[(0b01001, &ENTRY_GRANITIZATION_1851229670882829451)],
        &[(0b01001, &ENTRY_GRANITIZATIONS_7558118776122917287)],
        &[(0b01001, &ENTRY_GRANITIZE_18215727739855140563)],
        &[(0b01001, &ENTRY_GRANITIZED_1449233752463750138)],
        &[(0b01001, &ENTRY_GRANITIZES_5080962380592360311)],
        &[(0b01001, &ENTRY_GRANITIZING_9024106896826166145)],
        &[(0b10010, &ENTRY_GRANULIZE_7605163095922224765)],
        &[(0b10010, &ENTRY_GRANULIZES_15431459479870139428)],
        &[(0b10010, &ENTRY_GRANULITIZATION_15290542958063369460)],
        &[(0b10010, &ENTRY_GRANULITIZATIONS_12012456772504363468)],
        &[(0b01001, &ENTRY_GRANULITIZATION_15290542958063369460)],
        &[(0b01001, &ENTRY_GRANULITIZATIONS_12012456772504363468)],
        &[(0b01001, &ENTRY_GRANULIZE_7605163095922224765)],
        &[(0b01001, &ENTRY_GRANULIZES_15431459479870139428)],
    ],
    range: 5..=12,
};

static VARS_GRAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRAM_CHILDREN),
    value: None,
};

pub static VARS_GRAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("maticise"),
        dictgen::InsensitiveStr::Ascii("maticised"),
        dictgen::InsensitiveStr::Ascii("maticises"),
        dictgen::InsensitiveStr::Ascii("maticising"),
        dictgen::InsensitiveStr::Ascii("maticize"),
        dictgen::InsensitiveStr::Ascii("maticized"),
        dictgen::InsensitiveStr::Ascii("maticizes"),
        dictgen::InsensitiveStr::Ascii("maticizing"),
        dictgen::InsensitiveStr::Ascii("me"),
        dictgen::InsensitiveStr::Ascii("mes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GRAMMATICIZE_13927750396162050191)],
        &[(0b10010, &ENTRY_GRAMMATICIZED_1825495211699211254)],
        &[(0b10010, &ENTRY_GRAMMATICIZES_14936594258820535817)],
        &[(0b10010, &ENTRY_GRAMMATICIZING_692121205682654749)],
        &[(0b01001, &ENTRY_GRAMMATICIZE_13927750396162050191)],
        &[(0b01001, &ENTRY_GRAMMATICIZED_1825495211699211254)],
        &[(0b01001, &ENTRY_GRAMMATICIZES_14936594258820535817)],
        &[(0b01001, &ENTRY_GRAMMATICIZING_692121205682654749)],
        &[(0b10010, &ENTRY_GRAM_12153808189248219413)],
        &[(0b10010, &ENTRY_GRAMS_7239637483562572698)],
    ],
    range: 2..=10,
};

static VARS_GRAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRAE_CHILDREN),
    value: None,
};

pub static VARS_GRAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cian"),
        dictgen::InsensitiveStr::Ascii("cise"),
        dictgen::InsensitiveStr::Ascii("cised"),
        dictgen::InsensitiveStr::Ascii("cises"),
        dictgen::InsensitiveStr::Ascii("cising"),
        dictgen::InsensitiveStr::Ascii("cism"),
        dictgen::InsensitiveStr::Ascii("cisms"),
        dictgen::InsensitiveStr::Ascii("cize"),
        dictgen::InsensitiveStr::Ascii("cized"),
        dictgen::InsensitiveStr::Ascii("cizes"),
        dictgen::InsensitiveStr::Ascii("cizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GRECIAN_14860038034904089388)],
        &[
            (0b10010, &ENTRY_GRAECIZE_926966918917595487),
            (0b11010, &ENTRY_GRECISE_2532359423804381452),
        ],
        &[
            (0b10010, &ENTRY_GRAECIZED_12313346476953283931),
            (0b11010, &ENTRY_GRECISED_8365655558591252453),
        ],
        &[(0b10010, &ENTRY_GRAECIZES_3310961711255910918)],
        &[
            (0b10010, &ENTRY_GRAECIZING_3548832957287094505),
            (0b11010, &ENTRY_GRECISING_10216329489666935575),
        ],
        &[(0b11010, &ENTRY_GRECISM_11998927259268433496)],
        &[(0b11010, &ENTRY_GRECISMS_14469374135032380871)],
        &[(0b01001, &ENTRY_GRAECIZE_926966918917595487)],
        &[(0b01001, &ENTRY_GRAECIZED_12313346476953283931)],
        &[(0b01001, &ENTRY_GRAECIZES_3310961711255910918)],
        &[(0b01001, &ENTRY_GRAECIZING_3548832957287094505)],
    ],
    range: 4..=6,
};

static VARS_GO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GO_CHILDREN),
    value: None,
};

static VARS_GO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    Some(&VARS_GOD_NODE),
    Some(&VARS_GOE_NODE),
    None,
    None,
    None,
    Some(&VARS_GOI_NODE),
    None,
    None,
    Some(&VARS_GOL_NODE),
    None,
    Some(&VARS_GON_NODE),
    Some(&VARS_GOO_NODE),
    None,
    None,
    Some(&VARS_GOR_NODE),
    Some(&VARS_GOS_NODE),
    Some(&VARS_GOT_NODE),
    Some(&VARS_GOU_NODE),
    Some(&VARS_GOV_NODE),
    None,
    None,
    Some(&VARS_GOY_NODE),
    None,
];

static VARS_GOY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOY_CHILDREN),
    value: None,
};

pub static VARS_GOY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesque"),
        dictgen::InsensitiveStr::Ascii("esque"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GOYESQUE_9513998646544349741)],
        &[(0b00001, &ENTRY_GOYESQUE_9513998646544349741)],
    ],
    range: 5..=6,
};

static VARS_GOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOV_CHILDREN),
    value: None,
};

pub static VARS_GOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ernmentalise"),
        dictgen::InsensitiveStr::Ascii("ernmentalised"),
        dictgen::InsensitiveStr::Ascii("ernmentalises"),
        dictgen::InsensitiveStr::Ascii("ernmentalising"),
        dictgen::InsensitiveStr::Ascii("ernmentalize"),
        dictgen::InsensitiveStr::Ascii("ernmentalized"),
        dictgen::InsensitiveStr::Ascii("ernmentalizes"),
        dictgen::InsensitiveStr::Ascii("ernmentalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GOVERNMENTALIZE_12139326096501644734)],
        &[(0b10010, &ENTRY_GOVERNMENTALIZED_535639565110473785)],
        &[(0b10010, &ENTRY_GOVERNMENTALIZES_7078858643697476593)],
        &[(0b10010, &ENTRY_GOVERNMENTALIZING_6416864298050708496)],
        &[(0b01001, &ENTRY_GOVERNMENTALIZE_12139326096501644734)],
        &[(0b01001, &ENTRY_GOVERNMENTALIZED_535639565110473785)],
        &[(0b01001, &ENTRY_GOVERNMENTALIZES_7078858643697476593)],
        &[(0b01001, &ENTRY_GOVERNMENTALIZING_6416864298050708496)],
    ],
    range: 12..=14,
};

static VARS_GOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOU_CHILDREN),
    value: None,
};

pub static VARS_GOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("ra"),
        dictgen::InsensitiveStr::Ascii("ramies"),
        dictgen::InsensitiveStr::Ascii("rmandise"),
        dictgen::InsensitiveStr::Ascii("rmandised"),
        dictgen::InsensitiveStr::Ascii("rmandises"),
        dictgen::InsensitiveStr::Ascii("rmandising"),
        dictgen::InsensitiveStr::Ascii("rmandism"),
        dictgen::InsensitiveStr::Ascii("rmandisms"),
        dictgen::InsensitiveStr::Ascii("rmandize"),
        dictgen::InsensitiveStr::Ascii("rmandized"),
        dictgen::InsensitiveStr::Ascii("rmandizes"),
        dictgen::InsensitiveStr::Ascii("rmandizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GOR_10234665398861859619)],
        &[(0b11010, &ENTRY_GORA_11814218514390079181)],
        &[(0b11010, &ENTRY_GORAMIES_10337124831051177070)],
        &[(0b10010, &ENTRY_GOURMANDIZE_7543527779362954128)],
        &[(0b10010, &ENTRY_GOURMANDIZED_9573100300470535877)],
        &[(0b10010, &ENTRY_GOURMANDIZES_3953018647595098599)],
        &[(0b10010, &ENTRY_GOURMANDIZING_13613830637929717449)],
        &[(0b11010, &ENTRY_GORMANDISM_8691357582554313830)],
        &[(0b11010, &ENTRY_GORMANDISMS_2350716439672562789)],
        &[(0b01001, &ENTRY_GOURMANDIZE_7543527779362954128)],
        &[(0b01001, &ENTRY_GOURMANDIZED_9573100300470535877)],
        &[(0b01001, &ENTRY_GOURMANDIZES_3953018647595098599)],
        &[(0b01001, &ENTRY_GOURMANDIZING_13613830637929717449)],
    ],
    range: 1..=10,
};

static VARS_GOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOT_CHILDREN),
    value: None,
};

pub static VARS_GOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hicise"),
        dictgen::InsensitiveStr::Ascii("hicised"),
        dictgen::InsensitiveStr::Ascii("hiciser"),
        dictgen::InsensitiveStr::Ascii("hicisers"),
        dictgen::InsensitiveStr::Ascii("hicises"),
        dictgen::InsensitiveStr::Ascii("hicising"),
        dictgen::InsensitiveStr::Ascii("hicize"),
        dictgen::InsensitiveStr::Ascii("hicized"),
        dictgen::InsensitiveStr::Ascii("hicizer"),
        dictgen::InsensitiveStr::Ascii("hicizers"),
        dictgen::InsensitiveStr::Ascii("hicizes"),
        dictgen::InsensitiveStr::Ascii("hicizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GOTHICIZE_14957672080392530959)],
        &[(0b10010, &ENTRY_GOTHICIZED_11880161405473571941)],
        &[(0b10010, &ENTRY_GOTHICIZER_2689071523633726352)],
        &[(0b10010, &ENTRY_GOTHICIZERS_6983380456533659804)],
        &[(0b10010, &ENTRY_GOTHICIZES_6292706177931544569)],
        &[(0b10010, &ENTRY_GOTHICIZING_13822856579122185612)],
        &[(0b01001, &ENTRY_GOTHICIZE_14957672080392530959)],
        &[(0b01001, &ENTRY_GOTHICIZED_11880161405473571941)],
        &[(0b01001, &ENTRY_GOTHICIZER_2689071523633726352)],
        &[(0b01001, &ENTRY_GOTHICIZERS_6983380456533659804)],
        &[(0b01001, &ENTRY_GOTHICIZES_6292706177931544569)],
        &[(0b01001, &ENTRY_GOTHICIZING_13822856579122185612)],
    ],
    range: 6..=8,
};

static VARS_GOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOS_CHILDREN),
    value: None,
};

pub static VARS_GOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("peler"),
        dictgen::InsensitiveStr::Ascii("pelers"),
        dictgen::InsensitiveStr::Ascii("pelise"),
        dictgen::InsensitiveStr::Ascii("pelised"),
        dictgen::InsensitiveStr::Ascii("pelises"),
        dictgen::InsensitiveStr::Ascii("pelising"),
        dictgen::InsensitiveStr::Ascii("pelize"),
        dictgen::InsensitiveStr::Ascii("pelized"),
        dictgen::InsensitiveStr::Ascii("pelizes"),
        dictgen::InsensitiveStr::Ascii("pelizing"),
        dictgen::InsensitiveStr::Ascii("peller"),
        dictgen::InsensitiveStr::Ascii("pellers"),
        dictgen::InsensitiveStr::Ascii("pellise"),
        dictgen::InsensitiveStr::Ascii("pellised"),
        dictgen::InsensitiveStr::Ascii("pellises"),
        dictgen::InsensitiveStr::Ascii("pellising"),
        dictgen::InsensitiveStr::Ascii("pellize"),
        dictgen::InsensitiveStr::Ascii("pellized"),
        dictgen::InsensitiveStr::Ascii("pellizes"),
        dictgen::InsensitiveStr::Ascii("pellizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GOSPELER_16178320832840793633)],
        &[(0b00001, &ENTRY_GOSPELERS_5510274928883452290)],
        &[(0b10010, &ENTRY_GOSPELIZE_8463793062364479872)],
        &[(0b10010, &ENTRY_GOSPELIZED_6118230251869259140)],
        &[(0b10010, &ENTRY_GOSPELIZES_8351431571866342962)],
        &[(0b10010, &ENTRY_GOSPELIZING_1522616819248499417)],
        &[(0b01001, &ENTRY_GOSPELIZE_8463793062364479872)],
        &[(0b01001, &ENTRY_GOSPELIZED_6118230251869259140)],
        &[(0b01001, &ENTRY_GOSPELIZES_8351431571866342962)],
        &[(0b01001, &ENTRY_GOSPELIZING_1522616819248499417)],
        &[(0b11010, &ENTRY_GOSPELER_16178320832840793633)],
        &[(0b11010, &ENTRY_GOSPELERS_5510274928883452290)],
        &[(0b10010, &ENTRY_GOSPELLIZE_7948270018046384376)],
        &[(0b10010, &ENTRY_GOSPELLIZED_11952462176156283256)],
        &[(0b10010, &ENTRY_GOSPELLIZES_1146933159825487782)],
        &[(0b10010, &ENTRY_GOSPELLIZING_9061660358257705871)],
        &[(0b01001, &ENTRY_GOSPELLIZE_7948270018046384376)],
        &[(0b01001, &ENTRY_GOSPELLIZED_11952462176156283256)],
        &[(0b01001, &ENTRY_GOSPELLIZES_1146933159825487782)],
        &[(0b01001, &ENTRY_GOSPELLIZING_9061660358257705871)],
    ],
    range: 5..=9,
};

static VARS_GOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOR_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_GOR_10234665398861859619)]),
};

pub static VARS_GOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("amies"),
        dictgen::InsensitiveStr::Ascii("gonise"),
        dictgen::InsensitiveStr::Ascii("gonised"),
        dictgen::InsensitiveStr::Ascii("gonises"),
        dictgen::InsensitiveStr::Ascii("gonising"),
        dictgen::InsensitiveStr::Ascii("gonize"),
        dictgen::InsensitiveStr::Ascii("gonized"),
        dictgen::InsensitiveStr::Ascii("gonizes"),
        dictgen::InsensitiveStr::Ascii("gonizing"),
        dictgen::InsensitiveStr::Ascii("mandise"),
        dictgen::InsensitiveStr::Ascii("mandised"),
        dictgen::InsensitiveStr::Ascii("mandiser"),
        dictgen::InsensitiveStr::Ascii("mandisers"),
        dictgen::InsensitiveStr::Ascii("mandises"),
        dictgen::InsensitiveStr::Ascii("mandising"),
        dictgen::InsensitiveStr::Ascii("mandisings"),
        dictgen::InsensitiveStr::Ascii("mandism"),
        dictgen::InsensitiveStr::Ascii("mandisms"),
        dictgen::InsensitiveStr::Ascii("mandize"),
        dictgen::InsensitiveStr::Ascii("mandized"),
        dictgen::InsensitiveStr::Ascii("mandizer"),
        dictgen::InsensitiveStr::Ascii("mandizers"),
        dictgen::InsensitiveStr::Ascii("mandizes"),
        dictgen::InsensitiveStr::Ascii("mandizing"),
        dictgen::InsensitiveStr::Ascii("mandizings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GORA_11814218514390079181)],
        &[(0b00001, &ENTRY_GORAMIES_10337124831051177070)],
        &[(0b10010, &ENTRY_GORGONIZE_7339952104907739670)],
        &[(0b10010, &ENTRY_GORGONIZED_17578232270564441154)],
        &[(0b10010, &ENTRY_GORGONIZES_5235778045234676926)],
        &[(0b10010, &ENTRY_GORGONIZING_11753481170900914529)],
        &[(0b01001, &ENTRY_GORGONIZE_7339952104907739670)],
        &[(0b01001, &ENTRY_GORGONIZED_17578232270564441154)],
        &[(0b01001, &ENTRY_GORGONIZES_5235778045234676926)],
        &[(0b01001, &ENTRY_GORGONIZING_11753481170900914529)],
        &[(0b10010, &ENTRY_GORMANDIZE_4048474911133469516)],
        &[(0b10010, &ENTRY_GORMANDIZED_18123314320901330563)],
        &[(0b10010, &ENTRY_GORMANDIZER_7967324301588641636)],
        &[(0b10010, &ENTRY_GORMANDIZERS_9718907960263867951)],
        &[(0b10010, &ENTRY_GORMANDIZES_2367633408225245450)],
        &[(0b10010, &ENTRY_GORMANDIZING_3190158527790286976)],
        &[(0b10010, &ENTRY_GORMANDIZINGS_10351566511774807493)],
        &[(0b00001, &ENTRY_GORMANDISM_8691357582554313830)],
        &[(0b00001, &ENTRY_GORMANDISMS_2350716439672562789)],
        &[(0b01001, &ENTRY_GORMANDIZE_4048474911133469516)],
        &[(0b01001, &ENTRY_GORMANDIZED_18123314320901330563)],
        &[(0b01001, &ENTRY_GORMANDIZER_7967324301588641636)],
        &[(0b01001, &ENTRY_GORMANDIZERS_9718907960263867951)],
        &[(0b01001, &ENTRY_GORMANDIZES_2367633408225245450)],
        &[(0b01001, &ENTRY_GORMANDIZING_3190158527790286976)],
        &[(0b01001, &ENTRY_GORMANDIZINGS_10351566511774807493)],
    ],
    range: 1..=10,
};

static VARS_GOO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOO_CHILDREN),
    value: None,
};

pub static VARS_GOO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dby"),
        dictgen::InsensitiveStr::Ascii("dbys"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GOODBYE_955015322523257602)],
        &[(0b00001, &ENTRY_GOODBYES_4328442898272974601)],
    ],
    range: 3..=4,
};

static VARS_GON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GON_CHILDREN),
    value: None,
};

pub static VARS_GON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orrhea"),
        dictgen::InsensitiveStr::Ascii("orrheal"),
        dictgen::InsensitiveStr::Ascii("orrhealer"),
        dictgen::InsensitiveStr::Ascii("orrhealest"),
        dictgen::InsensitiveStr::Ascii("orrheas"),
        dictgen::InsensitiveStr::Ascii("orrheic"),
        dictgen::InsensitiveStr::Ascii("orrhoea"),
        dictgen::InsensitiveStr::Ascii("orrhoeal"),
        dictgen::InsensitiveStr::Ascii("orrhoealer"),
        dictgen::InsensitiveStr::Ascii("orrhoealest"),
        dictgen::InsensitiveStr::Ascii("orrhoeas"),
        dictgen::InsensitiveStr::Ascii("orrhoeic"),
    ],
    values: &[
        &[(0b11001, &ENTRY_GONORRHEA_14553002728173647424)],
        &[(0b11001, &ENTRY_GONORRHEAL_1953933058900099744)],
        &[(0b11001, &ENTRY_GONORRHEALER_6558496656666898706)],
        &[(0b11001, &ENTRY_GONORRHEALEST_7101359392395224585)],
        &[(0b11001, &ENTRY_GONORRHEAS_3200457042710401964)],
        &[(0b11001, &ENTRY_GONORRHEIC_11150089290859461093)],
        &[(0b10010, &ENTRY_GONORRHEA_14553002728173647424)],
        &[(0b10010, &ENTRY_GONORRHEAL_1953933058900099744)],
        &[(0b10010, &ENTRY_GONORRHEALER_6558496656666898706)],
        &[(0b10010, &ENTRY_GONORRHEALEST_7101359392395224585)],
        &[(0b10010, &ENTRY_GONORRHEAS_3200457042710401964)],
        &[(0b10010, &ENTRY_GONORRHEIC_11150089290859461093)],
    ],
    range: 6..=11,
};

static VARS_GOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOL_CHILDREN),
    value: None,
};

pub static VARS_GOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("iathise"),
        dictgen::InsensitiveStr::Ascii("iathised"),
        dictgen::InsensitiveStr::Ascii("iathises"),
        dictgen::InsensitiveStr::Ascii("iathising"),
        dictgen::InsensitiveStr::Ascii("iathize"),
        dictgen::InsensitiveStr::Ascii("iathized"),
        dictgen::InsensitiveStr::Ascii("iathizes"),
        dictgen::InsensitiveStr::Ascii("iathizing"),
        dictgen::InsensitiveStr::Ascii("oe"),
        dictgen::InsensitiveStr::Ascii("oshes"),
        dictgen::InsensitiveStr::Ascii("oshoes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GOLE_5489584880290326329)],
        &[(0b10010, &ENTRY_GOLIATHIZE_3207199351366822344)],
        &[(0b10010, &ENTRY_GOLIATHIZED_7371615732561488733)],
        &[(0b10010, &ENTRY_GOLIATHIZES_10251762427882918658)],
        &[(0b10010, &ENTRY_GOLIATHIZING_3247167634988452816)],
        &[(0b01001, &ENTRY_GOLIATHIZE_3207199351366822344)],
        &[(0b01001, &ENTRY_GOLIATHIZED_7371615732561488733)],
        &[(0b01001, &ENTRY_GOLIATHIZES_10251762427882918658)],
        &[(0b01001, &ENTRY_GOLIATHIZING_3247167634988452816)],
        &[(0b11010, &ENTRY_GOLE_5489584880290326329)],
        &[(0b00001, &ENTRY_GOLOSHES_6685403831800870010)],
        &[(0b11010, &ENTRY_GOLOSHES_6685403831800870010)],
    ],
    range: 1..=9,
};

static VARS_GOI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOI_CHILDREN),
    value: None,
};

pub static VARS_GOI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GOITER_14429026844787476944)],
        &[(0b00001, &ENTRY_GOITERS_5380033633196816136)],
        &[(0b11010, &ENTRY_GOITER_14429026844787476944)],
        &[(0b11010, &ENTRY_GOITERS_5380033633196816136)],
    ],
    range: 3..=4,
};

static VARS_GOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_GE_1824382053019322407)]),
};

pub static VARS_GOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("s"),
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("tz"),
        dictgen::InsensitiveStr::Ascii("tzville"),
        dictgen::InsensitiveStr::Ascii("y"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GES_12643481567446569340)],
        &[(0b11010, &ENTRY_GETAE_3364151983605314101)],
        &[(0b11010, &ENTRY_GETZ_6379956379813569580)],
        &[(0b11010, &ENTRY_GETZVILLE_9900952534801874442)],
        &[(0b11010, &ENTRY_GEY_14521748764899533154)],
    ],
    range: 1..=7,
};

static VARS_GOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOD_CHILDREN),
    value: None,
};

pub static VARS_GOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dise"),
        dictgen::InsensitiveStr::Ascii("dises"),
        dictgen::InsensitiveStr::Ascii("dize"),
        dictgen::InsensitiveStr::Ascii("dizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GODDIZE_12638634784459187474)],
        &[(0b10010, &ENTRY_GODDIZES_10711930831789780733)],
        &[(0b01001, &ENTRY_GODDIZE_12638634784459187474)],
        &[(0b01001, &ENTRY_GODDIZES_10711930831789780733)],
    ],
    range: 4..=5,
};

static VARS_GN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GN_CHILDREN),
    value: None,
};

pub static VARS_GN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("osticise"),
        dictgen::InsensitiveStr::Ascii("osticised"),
        dictgen::InsensitiveStr::Ascii("osticiser"),
        dictgen::InsensitiveStr::Ascii("osticisers"),
        dictgen::InsensitiveStr::Ascii("osticises"),
        dictgen::InsensitiveStr::Ascii("osticising"),
        dictgen::InsensitiveStr::Ascii("osticize"),
        dictgen::InsensitiveStr::Ascii("osticized"),
        dictgen::InsensitiveStr::Ascii("osticizer"),
        dictgen::InsensitiveStr::Ascii("osticizers"),
        dictgen::InsensitiveStr::Ascii("osticizes"),
        dictgen::InsensitiveStr::Ascii("osticizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GNOSTICIZE_8298366457877404969)],
        &[(0b10010, &ENTRY_GNOSTICIZED_2833607619405753217)],
        &[(0b10010, &ENTRY_GNOSTICIZER_13549736729171636644)],
        &[(0b10010, &ENTRY_GNOSTICIZERS_6416088953515594469)],
        &[(0b10010, &ENTRY_GNOSTICIZES_18176506546501435848)],
        &[(0b10010, &ENTRY_GNOSTICIZING_17078143553180201273)],
        &[(0b01001, &ENTRY_GNOSTICIZE_8298366457877404969)],
        &[(0b01001, &ENTRY_GNOSTICIZED_2833607619405753217)],
        &[(0b01001, &ENTRY_GNOSTICIZER_13549736729171636644)],
        &[(0b01001, &ENTRY_GNOSTICIZERS_6416088953515594469)],
        &[(0b01001, &ENTRY_GNOSTICIZES_18176506546501435848)],
        &[(0b01001, &ENTRY_GNOSTICIZING_17078143553180201273)],
    ],
    range: 8..=10,
};

static VARS_GL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GL_CHILDREN),
    value: None,
};

static VARS_GL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_GLA_NODE),
    None,
    None,
    None,
    Some(&VARS_GLE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GLO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GLU_NODE),
    None,
    None,
    None,
    Some(&VARS_GLY_NODE),
    None,
];

static VARS_GLY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GLY_CHILDREN),
    value: None,
};

pub static VARS_GLY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("caemia"),
        dictgen::InsensitiveStr::Ascii("caemic"),
        dictgen::InsensitiveStr::Ascii("cemia"),
        dictgen::InsensitiveStr::Ascii("cemic"),
        dictgen::InsensitiveStr::Ascii("cerin"),
        dictgen::InsensitiveStr::Ascii("cerinise"),
        dictgen::InsensitiveStr::Ascii("cerinises"),
        dictgen::InsensitiveStr::Ascii("cerinize"),
        dictgen::InsensitiveStr::Ascii("cerinizes"),
        dictgen::InsensitiveStr::Ascii("cerins"),
        dictgen::InsensitiveStr::Ascii("cerolise"),
        dictgen::InsensitiveStr::Ascii("cerolised"),
        dictgen::InsensitiveStr::Ascii("cerolises"),
        dictgen::InsensitiveStr::Ascii("cerolize"),
        dictgen::InsensitiveStr::Ascii("cerolized"),
        dictgen::InsensitiveStr::Ascii("cerolizes"),
        dictgen::InsensitiveStr::Ascii("cogenise"),
        dictgen::InsensitiveStr::Ascii("cogenises"),
        dictgen::InsensitiveStr::Ascii("cogenize"),
        dictgen::InsensitiveStr::Ascii("cogenizes"),
        dictgen::InsensitiveStr::Ascii("cohaemia"),
        dictgen::InsensitiveStr::Ascii("cohemia"),
        dictgen::InsensitiveStr::Ascii("cosaemia"),
        dictgen::InsensitiveStr::Ascii("cosemia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GLYCEMIA_16242341716012342356)],
        &[(0b11010, &ENTRY_GLYCEMIC_13665133085585909129)],
        &[(0b10001, &ENTRY_GLYCEMIA_16242341716012342356)],
        &[(0b10001, &ENTRY_GLYCEMIC_13665133085585909129)],
        &[(0b00001, &ENTRY_GLYCERIN_6083208262382782239)],
        &[(0b10010, &ENTRY_GLYCERINIZE_2782882431705716101)],
        &[(0b10010, &ENTRY_GLYCERINIZES_952982692568880676)],
        &[(0b01001, &ENTRY_GLYCERINIZE_2782882431705716101)],
        &[(0b01001, &ENTRY_GLYCERINIZES_952982692568880676)],
        &[(0b00001, &ENTRY_GLYCERINS_10842297970680678300)],
        &[(0b10010, &ENTRY_GLYCEROLIZE_14536989508087415076)],
        &[(0b10010, &ENTRY_GLYCEROLIZED_800457376227447393)],
        &[(0b10010, &ENTRY_GLYCEROLIZES_3740315663712429181)],
        &[(0b01001, &ENTRY_GLYCEROLIZE_14536989508087415076)],
        &[(0b01001, &ENTRY_GLYCEROLIZED_800457376227447393)],
        &[(0b01001, &ENTRY_GLYCEROLIZES_3740315663712429181)],
        &[(0b10010, &ENTRY_GLYCOGENIZE_15974845978276880617)],
        &[(0b10010, &ENTRY_GLYCOGENIZES_9362481468651756393)],
        &[(0b01001, &ENTRY_GLYCOGENIZE_15974845978276880617)],
        &[(0b01001, &ENTRY_GLYCOGENIZES_9362481468651756393)],
        &[(0b11010, &ENTRY_GLYCOHEMIA_15342224868378622029)],
        &[(0b10001, &ENTRY_GLYCOHEMIA_15342224868378622029)],
        &[(0b11010, &ENTRY_GLYCOSEMIA_17576889605547296607)],
        &[(0b10001, &ENTRY_GLYCOSEMIA_17576889605547296607)],
    ],
    range: 5..=9,
};

static VARS_GLU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GLU_CHILDREN),
    value: None,
};

pub static VARS_GLU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("caemia"),
        dictgen::InsensitiveStr::Ascii("cemia"),
        dictgen::InsensitiveStr::Ascii("cosaemia"),
        dictgen::InsensitiveStr::Ascii("cosemia"),
        dictgen::InsensitiveStr::Ascii("taeal"),
        dictgen::InsensitiveStr::Ascii("taei"),
        dictgen::InsensitiveStr::Ascii("taeus"),
        dictgen::InsensitiveStr::Ascii("tei"),
        dictgen::InsensitiveStr::Ascii("teus"),
        dictgen::InsensitiveStr::Ascii("ttonise"),
        dictgen::InsensitiveStr::Ascii("ttonised"),
        dictgen::InsensitiveStr::Ascii("ttonises"),
        dictgen::InsensitiveStr::Ascii("ttonising"),
        dictgen::InsensitiveStr::Ascii("ttonize"),
        dictgen::InsensitiveStr::Ascii("ttonized"),
        dictgen::InsensitiveStr::Ascii("ttonizes"),
        dictgen::InsensitiveStr::Ascii("ttonizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GLUCEMIA_2529316768824479585)],
        &[(0b10001, &ENTRY_GLUCEMIA_2529316768824479585)],
        &[(0b11010, &ENTRY_GLUCOSEMIA_115924351177583586)],
        &[(0b10001, &ENTRY_GLUCOSEMIA_115924351177583586)],
        &[(0b11010, &ENTRY_GLUTEAL_7146771961772255008)],
        &[(0b11010, &ENTRY_GLUTEI_7369598864146530008)],
        &[(0b11010, &ENTRY_GLUTEUS_17400782784216365634)],
        &[(0b00001, &ENTRY_GLUTEI_7369598864146530008)],
        &[(0b00001, &ENTRY_GLUTEUS_17400782784216365634)],
        &[(0b10010, &ENTRY_GLUTTONIZE_1551255015733249461)],
        &[(0b10010, &ENTRY_GLUTTONIZED_9137718586964556019)],
        &[(0b10010, &ENTRY_GLUTTONIZES_14463796411495767760)],
        &[(0b10010, &ENTRY_GLUTTONIZING_13071722447885495721)],
        &[(0b01001, &ENTRY_GLUTTONIZE_1551255015733249461)],
        &[(0b01001, &ENTRY_GLUTTONIZED_9137718586964556019)],
        &[(0b01001, &ENTRY_GLUTTONIZES_14463796411495767760)],
        &[(0b01001, &ENTRY_GLUTTONIZING_13071722447885495721)],
    ],
    range: 3..=9,
};

static VARS_GLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GLO_CHILDREN),
    value: None,
};

pub static VARS_GLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("balisation"),
        dictgen::InsensitiveStr::Ascii("balisations"),
        dictgen::InsensitiveStr::Ascii("balise"),
        dictgen::InsensitiveStr::Ascii("balised"),
        dictgen::InsensitiveStr::Ascii("balises"),
        dictgen::InsensitiveStr::Ascii("balising"),
        dictgen::InsensitiveStr::Ascii("balization"),
        dictgen::InsensitiveStr::Ascii("balizations"),
        dictgen::InsensitiveStr::Ascii("balize"),
        dictgen::InsensitiveStr::Ascii("balized"),
        dictgen::InsensitiveStr::Ascii("balizes"),
        dictgen::InsensitiveStr::Ascii("balizing"),
        dictgen::InsensitiveStr::Ascii("bigerinae"),
        dictgen::InsensitiveStr::Ascii("bigerine"),
        dictgen::InsensitiveStr::Ascii("ttalisation"),
        dictgen::InsensitiveStr::Ascii("ttalise"),
        dictgen::InsensitiveStr::Ascii("ttalises"),
        dictgen::InsensitiveStr::Ascii("ttalization"),
        dictgen::InsensitiveStr::Ascii("ttalize"),
        dictgen::InsensitiveStr::Ascii("ttalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GLOBALIZATION_12699369965025909498)],
        &[(0b10010, &ENTRY_GLOBALIZATIONS_5052956206367697156)],
        &[(0b10010, &ENTRY_GLOBALIZE_3759893079231687276)],
        &[(0b10010, &ENTRY_GLOBALIZED_6495417237922060299)],
        &[(0b10010, &ENTRY_GLOBALIZES_15478358400156150387)],
        &[(0b10010, &ENTRY_GLOBALIZING_3545733493688582389)],
        &[(0b01001, &ENTRY_GLOBALIZATION_12699369965025909498)],
        &[(0b01001, &ENTRY_GLOBALIZATIONS_5052956206367697156)],
        &[(0b01001, &ENTRY_GLOBALIZE_3759893079231687276)],
        &[(0b01001, &ENTRY_GLOBALIZED_6495417237922060299)],
        &[(0b01001, &ENTRY_GLOBALIZES_15478358400156150387)],
        &[(0b01001, &ENTRY_GLOBALIZING_3545733493688582389)],
        &[(0b11010, &ENTRY_GLOBIGERINE_2405734374814364255)],
        &[(0b00001, &ENTRY_GLOBIGERINE_2405734374814364255)],
        &[(0b10010, &ENTRY_GLOTTALIZATION_11392971986615366214)],
        &[(0b10010, &ENTRY_GLOTTALIZE_17907399977543814184)],
        &[(0b10010, &ENTRY_GLOTTALIZES_524293217691696666)],
        &[(0b01001, &ENTRY_GLOTTALIZATION_11392971986615366214)],
        &[(0b01001, &ENTRY_GLOTTALIZE_17907399977543814184)],
        &[(0b01001, &ENTRY_GLOTTALIZES_524293217691696666)],
    ],
    range: 6..=11,
};

static VARS_GLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GLE_CHILDREN),
    value: None,
};

pub static VARS_GLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bae"),
        dictgen::InsensitiveStr::Ascii("be"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GLEBE_5074401865696506801)],
        &[(0b00001, &ENTRY_GLEBE_5074401865696506801)],
    ],
    range: 2..=3,
};

static VARS_GLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GLA_CHILDREN),
    value: None,
};

pub static VARS_GLA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cialise"),
        dictgen::InsensitiveStr::Ascii("cialises"),
        dictgen::InsensitiveStr::Ascii("cialize"),
        dictgen::InsensitiveStr::Ascii("cializes"),
        dictgen::InsensitiveStr::Ascii("mor"),
        dictgen::InsensitiveStr::Ascii("mored"),
        dictgen::InsensitiveStr::Ascii("moring"),
        dictgen::InsensitiveStr::Ascii("morisation"),
        dictgen::InsensitiveStr::Ascii("morisations"),
        dictgen::InsensitiveStr::Ascii("morise"),
        dictgen::InsensitiveStr::Ascii("morised"),
        dictgen::InsensitiveStr::Ascii("moriser"),
        dictgen::InsensitiveStr::Ascii("morisers"),
        dictgen::InsensitiveStr::Ascii("morises"),
        dictgen::InsensitiveStr::Ascii("morising"),
        dictgen::InsensitiveStr::Ascii("morization"),
        dictgen::InsensitiveStr::Ascii("morizations"),
        dictgen::InsensitiveStr::Ascii("morize"),
        dictgen::InsensitiveStr::Ascii("morized"),
        dictgen::InsensitiveStr::Ascii("morizer"),
        dictgen::InsensitiveStr::Ascii("morizers"),
        dictgen::InsensitiveStr::Ascii("morizes"),
        dictgen::InsensitiveStr::Ascii("morizing"),
        dictgen::InsensitiveStr::Ascii("morless"),
        dictgen::InsensitiveStr::Ascii("mors"),
        dictgen::InsensitiveStr::Ascii("mourization"),
        dictgen::InsensitiveStr::Ascii("mourize"),
        dictgen::InsensitiveStr::Ascii("mourized"),
        dictgen::InsensitiveStr::Ascii("mourizer"),
        dictgen::InsensitiveStr::Ascii("mourizers"),
        dictgen::InsensitiveStr::Ascii("mourizes"),
        dictgen::InsensitiveStr::Ascii("mourizing"),
        dictgen::InsensitiveStr::Ascii("mourless"),
        dictgen::InsensitiveStr::Ascii("mourous"),
        dictgen::InsensitiveStr::Ascii("mourousness"),
        dictgen::InsensitiveStr::Ascii("uconitisation"),
        dictgen::InsensitiveStr::Ascii("uconitisations"),
        dictgen::InsensitiveStr::Ascii("uconitization"),
        dictgen::InsensitiveStr::Ascii("uconitizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GLACIALIZE_11661539622508415646)],
        &[(0b10010, &ENTRY_GLACIALIZES_15254428920934986178)],
        &[(0b01001, &ENTRY_GLACIALIZE_11661539622508415646)],
        &[(0b01001, &ENTRY_GLACIALIZES_15254428920934986178)],
        &[(0b11001, &ENTRY_GLAMOUR_12012756924820660610)],
        &[(0b11001, &ENTRY_GLAMOURED_12641645216907215470)],
        &[(0b11001, &ENTRY_GLAMOURING_8071112096581134588)],
        &[(0b10010, &ENTRY_GLAMORIZATION_17390559971758126451)],
        &[(0b10010, &ENTRY_GLAMORIZATIONS_11025706385369300820)],
        &[(0b10010, &ENTRY_GLAMORIZE_16872152441454086075)],
        &[(0b10010, &ENTRY_GLAMORIZED_14235641202752203193)],
        &[(0b10010, &ENTRY_GLAMORIZER_442849527990103618)],
        &[(0b10010, &ENTRY_GLAMORIZERS_8453946154216751074)],
        &[(0b10010, &ENTRY_GLAMORIZES_30562212031075527)],
        &[(0b10010, &ENTRY_GLAMORIZING_2022801147073053480)],
        &[(0b01001, &ENTRY_GLAMORIZATION_17390559971758126451)],
        &[(0b01001, &ENTRY_GLAMORIZATIONS_11025706385369300820)],
        &[(0b01001, &ENTRY_GLAMORIZE_16872152441454086075)],
        &[(0b01001, &ENTRY_GLAMORIZED_14235641202752203193)],
        &[(0b01001, &ENTRY_GLAMORIZER_442849527990103618)],
        &[(0b01001, &ENTRY_GLAMORIZERS_8453946154216751074)],
        &[(0b01001, &ENTRY_GLAMORIZES_30562212031075527)],
        &[(0b01001, &ENTRY_GLAMORIZING_2022801147073053480)],
        &[(0b10001, &ENTRY_GLAMORLESS_6110869941543847167)],
        &[(0b11001, &ENTRY_GLAMOURS_5834129166696821991)],
        &[(0b00001, &ENTRY_GLAMORIZATION_17390559971758126451)],
        &[(0b01001, &ENTRY_GLAMORIZE_16872152441454086075)],
        &[(0b01001, &ENTRY_GLAMORIZED_14235641202752203193)],
        &[(0b00001, &ENTRY_GLAMORIZER_442849527990103618)],
        &[(0b00001, &ENTRY_GLAMORIZERS_8453946154216751074)],
        &[(0b01001, &ENTRY_GLAMORIZES_30562212031075527)],
        &[(0b01001, &ENTRY_GLAMORIZING_2022801147073053480)],
        &[(0b11010, &ENTRY_GLAMORLESS_6110869941543847167)],
        &[(0b11010, &ENTRY_GLAMOROUS_16076170602432207668)],
        &[(0b11010, &ENTRY_GLAMOROUSNESS_1477615640674820584)],
        &[(0b10010, &ENTRY_GLAUCONITIZATION_17258720868513399337)],
        &[(0b10010, &ENTRY_GLAUCONITIZATIONS_1566737227533984902)],
        &[(0b01001, &ENTRY_GLAUCONITIZATION_17258720868513399337)],
        &[(0b01001, &ENTRY_GLAUCONITIZATIONS_1566737227533984902)],
    ],
    range: 3..=14,
};

static VARS_GI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GI_CHILDREN),
    value: None,
};

pub static VARS_GI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("antise"),
        dictgen::InsensitiveStr::Ascii("antises"),
        dictgen::InsensitiveStr::Ascii("antize"),
        dictgen::InsensitiveStr::Ascii("antizes"),
        dictgen::InsensitiveStr::Ascii("gagramme"),
        dictgen::InsensitiveStr::Ascii("gagrammes"),
        dictgen::InsensitiveStr::Ascii("gameter"),
        dictgen::InsensitiveStr::Ascii("gameters"),
        dictgen::InsensitiveStr::Ascii("gametre"),
        dictgen::InsensitiveStr::Ascii("gametres"),
        dictgen::InsensitiveStr::Ascii("mbaled"),
        dictgen::InsensitiveStr::Ascii("mbaling"),
        dictgen::InsensitiveStr::Ascii("mballed"),
        dictgen::InsensitiveStr::Ascii("mballing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GIANTIZE_8830577708614030805)],
        &[(0b10010, &ENTRY_GIANTIZES_5379255686506063622)],
        &[(0b01001, &ENTRY_GIANTIZE_8830577708614030805)],
        &[(0b01001, &ENTRY_GIANTIZES_5379255686506063622)],
        &[(0b10010, &ENTRY_GIGAGRAM_7417691256052791905)],
        &[(0b10010, &ENTRY_GIGAGRAMS_13735334786282432453)],
        &[(0b01001, &ENTRY_GIGAMETER_16808372513218698068)],
        &[(0b01001, &ENTRY_GIGAMETERS_17403496110313778840)],
        &[(0b11010, &ENTRY_GIGAMETER_16808372513218698068)],
        &[(0b11010, &ENTRY_GIGAMETERS_17403496110313778840)],
        &[(0b00001, &ENTRY_GIMBALED_16661584012551514273)],
        &[(0b00001, &ENTRY_GIMBALING_2001739272630955218)],
        &[(0b11010, &ENTRY_GIMBALED_16661584012551514273)],
        &[(0b11010, &ENTRY_GIMBALING_2001739272630955218)],
    ],
    range: 6..=9,
};

static VARS_GH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GH_CHILDREN),
    value: None,
};

pub static VARS_GH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eber"),
        dictgen::InsensitiveStr::Ascii("ebers"),
        dictgen::InsensitiveStr::Ascii("ebre"),
        dictgen::InsensitiveStr::Ascii("ebres"),
        dictgen::InsensitiveStr::Ascii("ettoisation"),
        dictgen::InsensitiveStr::Ascii("ettoisations"),
        dictgen::InsensitiveStr::Ascii("ettoise"),
        dictgen::InsensitiveStr::Ascii("ettoised"),
        dictgen::InsensitiveStr::Ascii("ettoises"),
        dictgen::InsensitiveStr::Ascii("ettoising"),
        dictgen::InsensitiveStr::Ascii("ettoization"),
        dictgen::InsensitiveStr::Ascii("ettoizations"),
        dictgen::InsensitiveStr::Ascii("ettoize"),
        dictgen::InsensitiveStr::Ascii("ettoized"),
        dictgen::InsensitiveStr::Ascii("ettoizes"),
        dictgen::InsensitiveStr::Ascii("ettoizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GHEBER_10923919185224261943)],
        &[(0b00001, &ENTRY_GHEBERS_1228305519613347380)],
        &[(0b11010, &ENTRY_GHEBER_10923919185224261943)],
        &[(0b11010, &ENTRY_GHEBERS_1228305519613347380)],
        &[(0b10010, &ENTRY_GHETTOIZATION_9347494697012841103)],
        &[(0b10010, &ENTRY_GHETTOIZATIONS_14465065685022919973)],
        &[(0b10010, &ENTRY_GHETTOIZE_3920432753121390069)],
        &[(0b10010, &ENTRY_GHETTOIZED_15432712263833756702)],
        &[(0b10010, &ENTRY_GHETTOIZES_15179150910854310387)],
        &[(0b10010, &ENTRY_GHETTOIZING_6347419295465163704)],
        &[(0b01001, &ENTRY_GHETTOIZATION_9347494697012841103)],
        &[(0b01001, &ENTRY_GHETTOIZATIONS_14465065685022919973)],
        &[(0b01001, &ENTRY_GHETTOIZE_3920432753121390069)],
        &[(0b01001, &ENTRY_GHETTOIZED_15432712263833756702)],
        &[(0b01001, &ENTRY_GHETTOIZES_15179150910854310387)],
        &[(0b01001, &ENTRY_GHETTOIZING_6347419295465163704)],
    ],
    range: 4..=12,
};

static VARS_GE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GE_CHILDREN),
    value: Some(&[
        (0b00001, &ENTRY_GE_1686355618410687291),
        (0b00001, &ENTRY_GE_1824382053019322407),
    ]),
};

static VARS_GE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    Some(&VARS_GED_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GEL_NODE),
    Some(&VARS_GEM_NODE),
    Some(&VARS_GEN_NODE),
    Some(&VARS_GEO_NODE),
    None,
    None,
    Some(&VARS_GER_NODE),
    Some(&VARS_GES_NODE),
    Some(&VARS_GET_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_GEY_NODE),
    None,
];

static VARS_GEY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GEY_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_GEY_14521748764899533154)]),
};

pub static VARS_GEY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_GET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GET_CHILDREN),
    value: None,
};

pub static VARS_GET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("z"),
        dictgen::InsensitiveStr::Ascii("zville"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GETAE_3364151983605314101)],
        &[(0b00001, &ENTRY_GETZ_6379956379813569580)],
        &[(0b00001, &ENTRY_GETZVILLE_9900952534801874442)],
    ],
    range: 1..=6,
};

static VARS_GES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GES_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_GES_12643481567446569340)]),
};

pub static VARS_GES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sed"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("soed"),
        dictgen::InsensitiveStr::Ascii("soes"),
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GESSED_9634112193833828464)],
        &[(0b00001, &ENTRY_GESSES_2437319557909204547)],
        &[(0b11010, &ENTRY_GESSED_9634112193833828464)],
        &[(0b11010, &ENTRY_GESSES_2437319557909204547)],
        &[(0b11010, &ENTRY_GESTE_1005156404234659116)],
        &[(0b00001, &ENTRY_GESTE_1005156404234659116)],
    ],
    range: 2..=4,
};

static VARS_GER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GER_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_GER_16895190685118522343)]),
};

pub static VARS_GER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enuk"),
        dictgen::InsensitiveStr::Ascii("manisation"),
        dictgen::InsensitiveStr::Ascii("manisations"),
        dictgen::InsensitiveStr::Ascii("manise"),
        dictgen::InsensitiveStr::Ascii("manised"),
        dictgen::InsensitiveStr::Ascii("maniser"),
        dictgen::InsensitiveStr::Ascii("manisers"),
        dictgen::InsensitiveStr::Ascii("manises"),
        dictgen::InsensitiveStr::Ascii("manising"),
        dictgen::InsensitiveStr::Ascii("manization"),
        dictgen::InsensitiveStr::Ascii("manizations"),
        dictgen::InsensitiveStr::Ascii("manize"),
        dictgen::InsensitiveStr::Ascii("manized"),
        dictgen::InsensitiveStr::Ascii("manizer"),
        dictgen::InsensitiveStr::Ascii("manizers"),
        dictgen::InsensitiveStr::Ascii("manizes"),
        dictgen::InsensitiveStr::Ascii("manizing"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GERENUK_5878790639893838830)],
        &[(0b10010, &ENTRY_GERMANIZATION_2883408131349264299)],
        &[(0b10010, &ENTRY_GERMANIZATIONS_13849203249084570742)],
        &[(0b10010, &ENTRY_GERMANIZE_8307775270233359640)],
        &[(0b10010, &ENTRY_GERMANIZED_319268402101247236)],
        &[(0b10010, &ENTRY_GERMANIZER_6949268779695565000)],
        &[(0b10010, &ENTRY_GERMANIZERS_2735174671441399165)],
        &[(0b10010, &ENTRY_GERMANIZES_13078334630601947229)],
        &[(0b10010, &ENTRY_GERMANIZING_17507553227341498972)],
        &[(0b01001, &ENTRY_GERMANIZATION_2883408131349264299)],
        &[(0b01001, &ENTRY_GERMANIZATIONS_13849203249084570742)],
        &[(0b01001, &ENTRY_GERMANIZE_8307775270233359640)],
        &[(0b01001, &ENTRY_GERMANIZED_319268402101247236)],
        &[(0b01001, &ENTRY_GERMANIZER_6949268779695565000)],
        &[(0b01001, &ENTRY_GERMANIZERS_2735174671441399165)],
        &[(0b01001, &ENTRY_GERMANIZES_13078334630601947229)],
        &[(0b01001, &ENTRY_GERMANIZING_17507553227341498972)],
        &[(0b00001, &ENTRY_GERNE_6398098570056353740)],
        &[(0b00001, &ENTRY_GERS_16671815364143402799)],
    ],
    range: 1..=11,
};

static VARS_GEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GEO_CHILDREN),
    value: None,
};

pub static VARS_GEO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("daesia"),
        dictgen::InsensitiveStr::Ascii("desia"),
        dictgen::InsensitiveStr::Ascii("logise"),
        dictgen::InsensitiveStr::Ascii("logised"),
        dictgen::InsensitiveStr::Ascii("logises"),
        dictgen::InsensitiveStr::Ascii("logising"),
        dictgen::InsensitiveStr::Ascii("logize"),
        dictgen::InsensitiveStr::Ascii("logized"),
        dictgen::InsensitiveStr::Ascii("logizes"),
        dictgen::InsensitiveStr::Ascii("logizing"),
        dictgen::InsensitiveStr::Ascii("metricise"),
        dictgen::InsensitiveStr::Ascii("metricises"),
        dictgen::InsensitiveStr::Ascii("metricize"),
        dictgen::InsensitiveStr::Ascii("metricizes"),
        dictgen::InsensitiveStr::Ascii("metrisation"),
        dictgen::InsensitiveStr::Ascii("metrisations"),
        dictgen::InsensitiveStr::Ascii("metrise"),
        dictgen::InsensitiveStr::Ascii("metrised"),
        dictgen::InsensitiveStr::Ascii("metrises"),
        dictgen::InsensitiveStr::Ascii("metrising"),
        dictgen::InsensitiveStr::Ascii("metrization"),
        dictgen::InsensitiveStr::Ascii("metrizations"),
        dictgen::InsensitiveStr::Ascii("metrize"),
        dictgen::InsensitiveStr::Ascii("metrized"),
        dictgen::InsensitiveStr::Ascii("metrizes"),
        dictgen::InsensitiveStr::Ascii("metrizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GEODESIA_15004587233872373961)],
        &[(0b00001, &ENTRY_GEODESIA_15004587233872373961)],
        &[(0b10010, &ENTRY_GEOLOGIZE_11123257417328877516)],
        &[(0b10010, &ENTRY_GEOLOGIZED_14818288061091294770)],
        &[(0b10010, &ENTRY_GEOLOGIZES_8761505022080731433)],
        &[(0b10010, &ENTRY_GEOLOGIZING_9697520321475002890)],
        &[(0b01001, &ENTRY_GEOLOGIZE_11123257417328877516)],
        &[(0b01001, &ENTRY_GEOLOGIZED_14818288061091294770)],
        &[(0b01001, &ENTRY_GEOLOGIZES_8761505022080731433)],
        &[(0b01001, &ENTRY_GEOLOGIZING_9697520321475002890)],
        &[(0b10010, &ENTRY_GEOMETRICIZE_6568047407572070557)],
        &[(0b10010, &ENTRY_GEOMETRICIZES_12860871121273916888)],
        &[(0b01001, &ENTRY_GEOMETRICIZE_6568047407572070557)],
        &[(0b01001, &ENTRY_GEOMETRICIZES_12860871121273916888)],
        &[(0b10010, &ENTRY_GEOMETRIZATION_6048827286641016156)],
        &[(0b10010, &ENTRY_GEOMETRIZATIONS_2014947061710926876)],
        &[(0b10010, &ENTRY_GEOMETRIZE_17676461405396435621)],
        &[(0b10010, &ENTRY_GEOMETRIZED_9584717817506517773)],
        &[(0b10010, &ENTRY_GEOMETRIZES_3954498979112526923)],
        &[(0b10010, &ENTRY_GEOMETRIZING_13116207017987408289)],
        &[(0b01001, &ENTRY_GEOMETRIZATION_6048827286641016156)],
        &[(0b01001, &ENTRY_GEOMETRIZATIONS_2014947061710926876)],
        &[(0b01001, &ENTRY_GEOMETRIZE_17676461405396435621)],
        &[(0b01001, &ENTRY_GEOMETRIZED_9584717817506517773)],
        &[(0b01001, &ENTRY_GEOMETRIZES_3954498979112526923)],
        &[(0b01001, &ENTRY_GEOMETRIZING_13116207017987408289)],
    ],
    range: 5..=12,
};

static VARS_GEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GEN_CHILDREN),
    value: None,
};

static VARS_GEN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_GENE_NODE),
    None,
    None,
    None,
    Some(&VARS_GENI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GENT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_GENT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GENT_CHILDREN),
    value: None,
};

pub static VARS_GENT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eelise"),
        dictgen::InsensitiveStr::Ascii("eelised"),
        dictgen::InsensitiveStr::Ascii("eelises"),
        dictgen::InsensitiveStr::Ascii("eelising"),
        dictgen::InsensitiveStr::Ascii("eelize"),
        dictgen::InsensitiveStr::Ascii("eelized"),
        dictgen::InsensitiveStr::Ascii("eelizes"),
        dictgen::InsensitiveStr::Ascii("eelizing"),
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
        dictgen::InsensitiveStr::Ascii("lemanise"),
        dictgen::InsensitiveStr::Ascii("lemanises"),
        dictgen::InsensitiveStr::Ascii("lemanize"),
        dictgen::InsensitiveStr::Ascii("lemanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GENTEELIZE_9903988894337114750)],
        &[(0b10010, &ENTRY_GENTEELIZED_4414971612441032598)],
        &[(0b10010, &ENTRY_GENTEELIZES_17054840204815850898)],
        &[(0b10010, &ENTRY_GENTEELIZING_6331688651248936908)],
        &[(0b01001, &ENTRY_GENTEELIZE_9903988894337114750)],
        &[(0b01001, &ENTRY_GENTEELIZED_4414971612441032598)],
        &[(0b01001, &ENTRY_GENTEELIZES_17054840204815850898)],
        &[(0b01001, &ENTRY_GENTEELIZING_6331688651248936908)],
        &[(0b10010, &ENTRY_GENTILIZATION_2967799069574563693)],
        &[(0b10010, &ENTRY_GENTILIZATIONS_4535777487794529619)],
        &[(0b10010, &ENTRY_GENTILIZE_2787391103676254332)],
        &[(0b10010, &ENTRY_GENTILIZED_15798295471925528719)],
        &[(0b10010, &ENTRY_GENTILIZES_10650533704141599278)],
        &[(0b10010, &ENTRY_GENTILIZING_4440287943707241933)],
        &[(0b01001, &ENTRY_GENTILIZATION_2967799069574563693)],
        &[(0b01001, &ENTRY_GENTILIZATIONS_4535777487794529619)],
        &[(0b01001, &ENTRY_GENTILIZE_2787391103676254332)],
        &[(0b01001, &ENTRY_GENTILIZED_15798295471925528719)],
        &[(0b01001, &ENTRY_GENTILIZES_10650533704141599278)],
        &[(0b01001, &ENTRY_GENTILIZING_4440287943707241933)],
        &[(0b10010, &ENTRY_GENTLEMANIZE_14844186125575594131)],
        &[(0b10010, &ENTRY_GENTLEMANIZES_16940194571953457595)],
        &[(0b01001, &ENTRY_GENTLEMANIZE_14844186125575594131)],
        &[(0b01001, &ENTRY_GENTLEMANIZES_16940194571953457595)],
    ],
    range: 5..=10,
};

static VARS_GENI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GENI_CHILDREN),
    value: None,
};

pub static VARS_GENI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GENIALIZE_11537483722321773336)],
        &[(0b10010, &ENTRY_GENIALIZED_1791020290394598690)],
        &[(0b10010, &ENTRY_GENIALIZES_1276462676939887760)],
        &[(0b10010, &ENTRY_GENIALIZING_2290635448853801652)],
        &[(0b01001, &ENTRY_GENIALIZE_11537483722321773336)],
        &[(0b01001, &ENTRY_GENIALIZED_1791020290394598690)],
        &[(0b01001, &ENTRY_GENIALIZES_1276462676939887760)],
        &[(0b01001, &ENTRY_GENIALIZING_2290635448853801652)],
    ],
    range: 5..=7,
};

static VARS_GENE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GENE_CHILDREN),
    value: None,
};

pub static VARS_GENE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alogise"),
        dictgen::InsensitiveStr::Ascii("alogised"),
        dictgen::InsensitiveStr::Ascii("alogises"),
        dictgen::InsensitiveStr::Ascii("alogising"),
        dictgen::InsensitiveStr::Ascii("alogize"),
        dictgen::InsensitiveStr::Ascii("alogized"),
        dictgen::InsensitiveStr::Ascii("alogizes"),
        dictgen::InsensitiveStr::Ascii("alogizing"),
        dictgen::InsensitiveStr::Ascii("ralisability"),
        dictgen::InsensitiveStr::Ascii("ralisable"),
        dictgen::InsensitiveStr::Ascii("ralisabler"),
        dictgen::InsensitiveStr::Ascii("ralisables"),
        dictgen::InsensitiveStr::Ascii("ralisablest"),
        dictgen::InsensitiveStr::Ascii("ralisation"),
        dictgen::InsensitiveStr::Ascii("ralisational"),
        dictgen::InsensitiveStr::Ascii("ralisations"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralised"),
        dictgen::InsensitiveStr::Ascii("raliser"),
        dictgen::InsensitiveStr::Ascii("ralisers"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralising"),
        dictgen::InsensitiveStr::Ascii("ralizability"),
        dictgen::InsensitiveStr::Ascii("ralizable"),
        dictgen::InsensitiveStr::Ascii("ralizabler"),
        dictgen::InsensitiveStr::Ascii("ralizables"),
        dictgen::InsensitiveStr::Ascii("ralizablest"),
        dictgen::InsensitiveStr::Ascii("ralization"),
        dictgen::InsensitiveStr::Ascii("ralizational"),
        dictgen::InsensitiveStr::Ascii("ralizations"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralized"),
        dictgen::InsensitiveStr::Ascii("ralizer"),
        dictgen::InsensitiveStr::Ascii("ralizers"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GENEALOGIZE_12620268584199932329)],
        &[(0b10010, &ENTRY_GENEALOGIZED_12042020584202560965)],
        &[(0b10010, &ENTRY_GENEALOGIZES_17168583404877040399)],
        &[(0b10010, &ENTRY_GENEALOGIZING_5132448372195022070)],
        &[(0b01001, &ENTRY_GENEALOGIZE_12620268584199932329)],
        &[(0b01001, &ENTRY_GENEALOGIZED_12042020584202560965)],
        &[(0b01001, &ENTRY_GENEALOGIZES_17168583404877040399)],
        &[(0b01001, &ENTRY_GENEALOGIZING_5132448372195022070)],
        &[(0b10010, &ENTRY_GENERALIZABILITY_14379431587366972360)],
        &[(0b10010, &ENTRY_GENERALIZABLE_18295725543642075611)],
        &[(0b10010, &ENTRY_GENERALIZABLER_18102132003690783604)],
        &[(0b10010, &ENTRY_GENERALIZABLES_154180711840966000)],
        &[(0b10010, &ENTRY_GENERALIZABLEST_11553065349222479768)],
        &[(0b10010, &ENTRY_GENERALIZATION_2013961301751158492)],
        &[(0b10010, &ENTRY_GENERALIZATIONAL_3161056560131790765)],
        &[(0b10010, &ENTRY_GENERALIZATIONS_2731364307838232099)],
        &[(0b10010, &ENTRY_GENERALIZE_7119013892575487093)],
        &[(0b10010, &ENTRY_GENERALIZED_7165523126062259290)],
        &[(0b10010, &ENTRY_GENERALIZER_10108415814272974359)],
        &[(0b10010, &ENTRY_GENERALIZERS_16845345421553349857)],
        &[(0b10010, &ENTRY_GENERALIZES_4170424702375409863)],
        &[(0b10010, &ENTRY_GENERALIZING_1808553508228690165)],
        &[(0b01001, &ENTRY_GENERALIZABILITY_14379431587366972360)],
        &[(0b01001, &ENTRY_GENERALIZABLE_18295725543642075611)],
        &[(0b01001, &ENTRY_GENERALIZABLER_18102132003690783604)],
        &[(0b01001, &ENTRY_GENERALIZABLES_154180711840966000)],
        &[(0b01001, &ENTRY_GENERALIZABLEST_11553065349222479768)],
        &[(0b01001, &ENTRY_GENERALIZATION_2013961301751158492)],
        &[(0b01001, &ENTRY_GENERALIZATIONAL_3161056560131790765)],
        &[(0b01001, &ENTRY_GENERALIZATIONS_2731364307838232099)],
        &[(0b01001, &ENTRY_GENERALIZE_7119013892575487093)],
        &[(0b01001, &ENTRY_GENERALIZED_7165523126062259290)],
        &[(0b01001, &ENTRY_GENERALIZER_10108415814272974359)],
        &[(0b01001, &ENTRY_GENERALIZERS_16845345421553349857)],
        &[(0b01001, &ENTRY_GENERALIZES_4170424702375409863)],
        &[(0b01001, &ENTRY_GENERALIZING_1808553508228690165)],
    ],
    range: 6..=12,
};

static VARS_GEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GEM_CHILDREN),
    value: None,
};

pub static VARS_GEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mologies"),
        dictgen::InsensitiveStr::Ascii("mology"),
        dictgen::InsensitiveStr::Ascii("ologies"),
        dictgen::InsensitiveStr::Ascii("ology"),
    ],
    values: &[
        &[(0b10011, &ENTRY_GEMOLOGIES_10089052264640071050)],
        &[(0b10011, &ENTRY_GEMOLOGY_6361260868768825578)],
        &[(0b01001, &ENTRY_GEMOLOGIES_10089052264640071050)],
        &[(0b01001, &ENTRY_GEMOLOGY_6361260868768825578)],
    ],
    range: 5..=8,
};

static VARS_GEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GEL_CHILDREN),
    value: None,
};

pub static VARS_GEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atinisabilities"),
        dictgen::InsensitiveStr::Ascii("atinisability"),
        dictgen::InsensitiveStr::Ascii("atinisable"),
        dictgen::InsensitiveStr::Ascii("atinisables"),
        dictgen::InsensitiveStr::Ascii("atinisation"),
        dictgen::InsensitiveStr::Ascii("atinisations"),
        dictgen::InsensitiveStr::Ascii("atinise"),
        dictgen::InsensitiveStr::Ascii("atinised"),
        dictgen::InsensitiveStr::Ascii("atiniser"),
        dictgen::InsensitiveStr::Ascii("atinisers"),
        dictgen::InsensitiveStr::Ascii("atinises"),
        dictgen::InsensitiveStr::Ascii("atinising"),
        dictgen::InsensitiveStr::Ascii("atinizabilities"),
        dictgen::InsensitiveStr::Ascii("atinizability"),
        dictgen::InsensitiveStr::Ascii("atinizable"),
        dictgen::InsensitiveStr::Ascii("atinizables"),
        dictgen::InsensitiveStr::Ascii("atinization"),
        dictgen::InsensitiveStr::Ascii("atinizations"),
        dictgen::InsensitiveStr::Ascii("atinize"),
        dictgen::InsensitiveStr::Ascii("atinized"),
        dictgen::InsensitiveStr::Ascii("atinizer"),
        dictgen::InsensitiveStr::Ascii("atinizers"),
        dictgen::InsensitiveStr::Ascii("atinizes"),
        dictgen::InsensitiveStr::Ascii("atinizing"),
        dictgen::InsensitiveStr::Ascii("ofer"),
        dictgen::InsensitiveStr::Ascii("ofre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GELATINIZABILITIES_11843732787771445770)],
        &[(0b10010, &ENTRY_GELATINIZABILITY_5316896028355440686)],
        &[(0b10010, &ENTRY_GELATINIZABLE_11531656402349149191)],
        &[(0b10010, &ENTRY_GELATINIZABLES_16322119396476682092)],
        &[(0b10010, &ENTRY_GELATINIZATION_10171589934060374244)],
        &[(0b10010, &ENTRY_GELATINIZATIONS_3461490016782968866)],
        &[(0b10010, &ENTRY_GELATINIZE_16970171286224203718)],
        &[(0b10010, &ENTRY_GELATINIZED_3461761477823005775)],
        &[(0b10010, &ENTRY_GELATINIZER_15651599974102221586)],
        &[(0b10010, &ENTRY_GELATINIZERS_10767802126531471218)],
        &[(0b10010, &ENTRY_GELATINIZES_15322238107724094444)],
        &[(0b10010, &ENTRY_GELATINIZING_15953751603785988233)],
        &[(0b01001, &ENTRY_GELATINIZABILITIES_11843732787771445770)],
        &[(0b01001, &ENTRY_GELATINIZABILITY_5316896028355440686)],
        &[(0b01001, &ENTRY_GELATINIZABLE_11531656402349149191)],
        &[(0b01001, &ENTRY_GELATINIZABLES_16322119396476682092)],
        &[(0b01001, &ENTRY_GELATINIZATION_10171589934060374244)],
        &[(0b01001, &ENTRY_GELATINIZATIONS_3461490016782968866)],
        &[(0b01001, &ENTRY_GELATINIZE_16970171286224203718)],
        &[(0b01001, &ENTRY_GELATINIZED_3461761477823005775)],
        &[(0b01001, &ENTRY_GELATINIZER_15651599974102221586)],
        &[(0b01001, &ENTRY_GELATINIZERS_10767802126531471218)],
        &[(0b01001, &ENTRY_GELATINIZES_15322238107724094444)],
        &[(0b01001, &ENTRY_GELATINIZING_15953751603785988233)],
        &[(0b00001, &ENTRY_GELOFER_9829183028786462049)],
        &[(0b11010, &ENTRY_GELOFER_9829183028786462049)],
    ],
    range: 4..=15,
};

static VARS_GED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GED_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_GED_3160770251205469873)]),
};

pub static VARS_GED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_GA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GA_CHILDREN),
    value: None,
};

static VARS_GA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_GAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GAL_NODE),
    Some(&VARS_GAM_NODE),
    None,
    Some(&VARS_GAO_NODE),
    None,
    None,
    Some(&VARS_GAR_NODE),
    Some(&VARS_GAS_NODE),
    None,
    Some(&VARS_GAU_NODE),
    Some(&VARS_GAV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_GAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAV_CHILDREN),
    value: None,
};

pub static VARS_GAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("elling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GAVELED_2754242970907308344)],
        &[(0b00001, &ENTRY_GAVELER_5299756916204132265)],
        &[(0b00001, &ENTRY_GAVELING_2064376598913459154)],
        &[(0b11010, &ENTRY_GAVELED_2754242970907308344)],
        &[(0b11010, &ENTRY_GAVELER_5299756916204132265)],
        &[(0b11010, &ENTRY_GAVELING_2064376598913459154)],
    ],
    range: 4..=6,
};

static VARS_GAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAU_CHILDREN),
    value: None,
};

pub static VARS_GAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fer"),
        dictgen::InsensitiveStr::Ascii("fers"),
        dictgen::InsensitiveStr::Ascii("ffer"),
        dictgen::InsensitiveStr::Ascii("ffre"),
        dictgen::InsensitiveStr::Ascii("fre"),
        dictgen::InsensitiveStr::Ascii("fres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GAUFER_15601008999281180791)],
        &[(0b00001, &ENTRY_GAUFERS_16074905635291767722)],
        &[(0b00001, &ENTRY_GAUFFER_313132899569716823)],
        &[(0b11010, &ENTRY_GAUFFER_313132899569716823)],
        &[(0b11010, &ENTRY_GAUFER_15601008999281180791)],
        &[(0b11010, &ENTRY_GAUFERS_16074905635291767722)],
    ],
    range: 3..=4,
};

static VARS_GAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAS_CHILDREN),
    value: None,
};

pub static VARS_GAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olene"),
        dictgen::InsensitiveStr::Ascii("olenes"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("traea"),
        dictgen::InsensitiveStr::Ascii("traeas"),
        dictgen::InsensitiveStr::Ascii("trea"),
        dictgen::InsensitiveStr::Ascii("treas"),
        dictgen::InsensitiveStr::Ascii("trocele"),
        dictgen::InsensitiveStr::Ascii("trocoele"),
    ],
    values: &[
        &[(0b10011, &ENTRY_GASOLINE_2174214619583348604)],
        &[(0b10011, &ENTRY_GASOLINES_1372889667055729574)],
        &[(0b00001, &ENTRY_GASES_3527587012732480671)],
        &[(0b11010, &ENTRY_GASTREA_1797131144605883399)],
        &[(0b11010, &ENTRY_GASTREAS_18033590203799166427)],
        &[(0b00001, &ENTRY_GASTREA_1797131144605883399)],
        &[(0b00001, &ENTRY_GASTREAS_18033590203799166427)],
        &[(0b00001, &ENTRY_GASTROCELE_12395541434337095709)],
        &[(0b11010, &ENTRY_GASTROCELE_12395541434337095709)],
    ],
    range: 3..=8,
};

static VARS_GAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAR_CHILDREN),
    value: None,
};

pub static VARS_GAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("garise"),
        dictgen::InsensitiveStr::Ascii("garised"),
        dictgen::InsensitiveStr::Ascii("garises"),
        dictgen::InsensitiveStr::Ascii("garising"),
        dictgen::InsensitiveStr::Ascii("garize"),
        dictgen::InsensitiveStr::Ascii("garized"),
        dictgen::InsensitiveStr::Ascii("garizes"),
        dictgen::InsensitiveStr::Ascii("garizing"),
        dictgen::InsensitiveStr::Ascii("rulinae"),
        dictgen::InsensitiveStr::Ascii("ruline"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GARGARIZE_3473168342864934344)],
        &[(0b10010, &ENTRY_GARGARIZED_9705368656504750107)],
        &[(0b10010, &ENTRY_GARGARIZES_480205376438599450)],
        &[(0b10010, &ENTRY_GARGARIZING_9383881113728329904)],
        &[(0b01001, &ENTRY_GARGARIZE_3473168342864934344)],
        &[(0b01001, &ENTRY_GARGARIZED_9705368656504750107)],
        &[(0b01001, &ENTRY_GARGARIZES_480205376438599450)],
        &[(0b01001, &ENTRY_GARGARIZING_9383881113728329904)],
        &[(0b11010, &ENTRY_GARRULINE_11266272558421031577)],
        &[(0b00001, &ENTRY_GARRULINE_11266272558421031577)],
    ],
    range: 6..=8,
};

static VARS_GAO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAO_CHILDREN),
    value: None,
};

pub static VARS_GAO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("l"),
        dictgen::InsensitiveStr::Ascii("lbird"),
        dictgen::InsensitiveStr::Ascii("lbirds"),
        dictgen::InsensitiveStr::Ascii("lbreak"),
        dictgen::InsensitiveStr::Ascii("lbreaks"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("ls"),
    ],
    values: &[
        &[(0b11010, &ENTRY_JAIL_9355766415908209672)],
        &[(0b11010, &ENTRY_JAILBIRD_1212632149307874383)],
        &[(0b11010, &ENTRY_JAILBIRDS_6287442130171297097)],
        &[(0b11010, &ENTRY_JAILBREAK_4699850190274924246)],
        &[(0b11010, &ENTRY_JAILBREAKS_17258526740881807361)],
        &[(0b11010, &ENTRY_JAILED_1125764234507810906)],
        &[(0b10010, &ENTRY_JAILER_16794396359446182049)],
        &[(0b10010, &ENTRY_JAILERS_15685267405324816915)],
        &[(0b11010, &ENTRY_JAILING_1957609231097707934)],
        &[(0b11010, &ENTRY_JAILS_3678144083221559157)],
    ],
    range: 1..=7,
};

static VARS_GAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAM_CHILDREN),
    value: None,
};

pub static VARS_GAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bades"),
        dictgen::InsensitiveStr::Ascii("badoes"),
        dictgen::InsensitiveStr::Ascii("boled"),
        dictgen::InsensitiveStr::Ascii("boling"),
        dictgen::InsensitiveStr::Ascii("bolled"),
        dictgen::InsensitiveStr::Ascii("bolling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GAMBADES_2795034114389963904)],
        &[(0b11010, &ENTRY_GAMBADES_2795034114389963904)],
        &[(0b00001, &ENTRY_GAMBOLED_4664830494285802567)],
        &[(0b00001, &ENTRY_GAMBOLING_15706579681008403067)],
        &[(0b11010, &ENTRY_GAMBOLED_4664830494285802567)],
        &[(0b11010, &ENTRY_GAMBOLING_15706579681008403067)],
    ],
    range: 5..=7,
};

static VARS_GAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAL_CHILDREN),
    value: None,
};

pub static VARS_GAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("actorrhea"),
        dictgen::InsensitiveStr::Ascii("actorrheas"),
        dictgen::InsensitiveStr::Ascii("actorrhoea"),
        dictgen::InsensitiveStr::Ascii("actorrhoeas"),
        dictgen::InsensitiveStr::Ascii("actosaemia"),
        dictgen::InsensitiveStr::Ascii("actosaemias"),
        dictgen::InsensitiveStr::Ascii("actosemia"),
        dictgen::InsensitiveStr::Ascii("actosemias"),
        dictgen::InsensitiveStr::Ascii("eae"),
        dictgen::InsensitiveStr::Ascii("ee"),
        dictgen::InsensitiveStr::Ascii("lantise"),
        dictgen::InsensitiveStr::Ascii("lantises"),
        dictgen::InsensitiveStr::Ascii("lantize"),
        dictgen::InsensitiveStr::Ascii("lantizes"),
        dictgen::InsensitiveStr::Ascii("liardise"),
        dictgen::InsensitiveStr::Ascii("liardize"),
        dictgen::InsensitiveStr::Ascii("licisation"),
        dictgen::InsensitiveStr::Ascii("licisations"),
        dictgen::InsensitiveStr::Ascii("licise"),
        dictgen::InsensitiveStr::Ascii("licised"),
        dictgen::InsensitiveStr::Ascii("liciser"),
        dictgen::InsensitiveStr::Ascii("licises"),
        dictgen::InsensitiveStr::Ascii("licising"),
        dictgen::InsensitiveStr::Ascii("licization"),
        dictgen::InsensitiveStr::Ascii("licizations"),
        dictgen::InsensitiveStr::Ascii("licize"),
        dictgen::InsensitiveStr::Ascii("licized"),
        dictgen::InsensitiveStr::Ascii("licizer"),
        dictgen::InsensitiveStr::Ascii("licizes"),
        dictgen::InsensitiveStr::Ascii("licizing"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lisise"),
        dictgen::InsensitiveStr::Ascii("lisised"),
        dictgen::InsensitiveStr::Ascii("lisises"),
        dictgen::InsensitiveStr::Ascii("lisising"),
        dictgen::InsensitiveStr::Ascii("lisize"),
        dictgen::InsensitiveStr::Ascii("lisized"),
        dictgen::InsensitiveStr::Ascii("lisizes"),
        dictgen::InsensitiveStr::Ascii("lisizing"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
        dictgen::InsensitiveStr::Ascii("vanisation"),
        dictgen::InsensitiveStr::Ascii("vanisations"),
        dictgen::InsensitiveStr::Ascii("vanise"),
        dictgen::InsensitiveStr::Ascii("vanised"),
        dictgen::InsensitiveStr::Ascii("vaniser"),
        dictgen::InsensitiveStr::Ascii("vanisers"),
        dictgen::InsensitiveStr::Ascii("vanises"),
        dictgen::InsensitiveStr::Ascii("vanising"),
        dictgen::InsensitiveStr::Ascii("vanization"),
        dictgen::InsensitiveStr::Ascii("vanizations"),
        dictgen::InsensitiveStr::Ascii("vanize"),
        dictgen::InsensitiveStr::Ascii("vanized"),
        dictgen::InsensitiveStr::Ascii("vanizer"),
        dictgen::InsensitiveStr::Ascii("vanizers"),
        dictgen::InsensitiveStr::Ascii("vanizes"),
        dictgen::InsensitiveStr::Ascii("vanizing"),
    ],
    values: &[
        &[(0b10001, &ENTRY_GALACTORRHEA_13861449240295747405)],
        &[(0b10001, &ENTRY_GALACTORRHEAS_15234978692364003152)],
        &[(0b11010, &ENTRY_GALACTORRHEA_13861449240295747405)],
        &[(0b11010, &ENTRY_GALACTORRHEAS_15234978692364003152)],
        &[(0b11010, &ENTRY_GALACTOSEMIA_8989534188768018492)],
        &[(0b11010, &ENTRY_GALACTOSEMIAS_992575803852959477)],
        &[(0b10001, &ENTRY_GALACTOSEMIA_8989534188768018492)],
        &[(0b10001, &ENTRY_GALACTOSEMIAS_992575803852959477)],
        &[(0b11010, &ENTRY_GALEE_979378817344313906)],
        &[(0b00001, &ENTRY_GALEE_979378817344313906)],
        &[(0b10010, &ENTRY_GALLANTIZE_11952937995017042016)],
        &[(0b10010, &ENTRY_GALLANTIZES_15362373933325224978)],
        &[(0b01001, &ENTRY_GALLANTIZE_11952937995017042016)],
        &[(0b01001, &ENTRY_GALLANTIZES_15362373933325224978)],
        &[(0b10010, &ENTRY_GALLIARDIZE_6778063741977884289)],
        &[(0b01001, &ENTRY_GALLIARDIZE_6778063741977884289)],
        &[(0b10010, &ENTRY_GALLICIZATION_9242388362936141521)],
        &[(0b10010, &ENTRY_GALLICIZATIONS_17628077438516611604)],
        &[(0b10010, &ENTRY_GALLICIZE_18203286620435437022)],
        &[(0b10010, &ENTRY_GALLICIZED_2802912364772929047)],
        &[(0b10010, &ENTRY_GALLICIZER_5355064225731153450)],
        &[(0b10010, &ENTRY_GALLICIZES_2239235669702708730)],
        &[(0b10010, &ENTRY_GALLICIZING_6975607554354786209)],
        &[(0b01001, &ENTRY_GALLICIZATION_9242388362936141521)],
        &[(0b01001, &ENTRY_GALLICIZATIONS_17628077438516611604)],
        &[(0b01001, &ENTRY_GALLICIZE_18203286620435437022)],
        &[(0b01001, &ENTRY_GALLICIZED_2802912364772929047)],
        &[(0b01001, &ENTRY_GALLICIZER_5355064225731153450)],
        &[(0b01001, &ENTRY_GALLICIZES_2239235669702708730)],
        &[(0b01001, &ENTRY_GALLICIZING_6975607554354786209)],
        &[(0b10010, &ENTRY_GALLIZE_2458866677576798762)],
        &[(0b10010, &ENTRY_GALLIZED_15522001731940226700)],
        &[(0b10010, &ENTRY_GALLIZES_11429714912572540635)],
        &[(0b10010, &ENTRY_GALLIZING_11621131501652178351)],
        &[(0b10010, &ENTRY_GALLISIZE_15420643426503619914)],
        &[(0b10010, &ENTRY_GALLISIZED_15995593182854587948)],
        &[(0b10010, &ENTRY_GALLISIZES_7538536560398951325)],
        &[(0b10010, &ENTRY_GALLISIZING_7030944615053144646)],
        &[(0b01001, &ENTRY_GALLISIZE_15420643426503619914)],
        &[(0b01001, &ENTRY_GALLISIZED_15995593182854587948)],
        &[(0b01001, &ENTRY_GALLISIZES_7538536560398951325)],
        &[(0b01001, &ENTRY_GALLISIZING_7030944615053144646)],
        &[(0b01001, &ENTRY_GALLIZE_2458866677576798762)],
        &[(0b01001, &ENTRY_GALLIZED_15522001731940226700)],
        &[(0b01001, &ENTRY_GALLIZES_11429714912572540635)],
        &[(0b01001, &ENTRY_GALLIZING_11621131501652178351)],
        &[(0b10010, &ENTRY_GALVANIZATION_5717361496948402685)],
        &[(0b10010, &ENTRY_GALVANIZATIONS_94633790537656998)],
        &[(0b10010, &ENTRY_GALVANIZE_13754138134384178626)],
        &[(0b10010, &ENTRY_GALVANIZED_6983753273153337994)],
        &[(0b10010, &ENTRY_GALVANIZER_9294868075827996057)],
        &[(0b10010, &ENTRY_GALVANIZERS_12527605368925810121)],
        &[(0b10010, &ENTRY_GALVANIZES_5332765103438806141)],
        &[(0b10010, &ENTRY_GALVANIZING_1108449218863508353)],
        &[(0b01001, &ENTRY_GALVANIZATION_5717361496948402685)],
        &[(0b01001, &ENTRY_GALVANIZATIONS_94633790537656998)],
        &[(0b01001, &ENTRY_GALVANIZE_13754138134384178626)],
        &[(0b01001, &ENTRY_GALVANIZED_6983753273153337994)],
        &[(0b01001, &ENTRY_GALVANIZER_9294868075827996057)],
        &[(0b01001, &ENTRY_GALVANIZERS_12527605368925810121)],
        &[(0b01001, &ENTRY_GALVANIZES_5332765103438806141)],
        &[(0b01001, &ENTRY_GALVANIZING_1108449218863508353)],
    ],
    range: 2..=11,
};

static VARS_GAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_GE_1686355618410687291)]),
};

pub static VARS_GAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("licisation"),
        dictgen::InsensitiveStr::Ascii("licisations"),
        dictgen::InsensitiveStr::Ascii("licise"),
        dictgen::InsensitiveStr::Ascii("licised"),
        dictgen::InsensitiveStr::Ascii("licises"),
        dictgen::InsensitiveStr::Ascii("licising"),
        dictgen::InsensitiveStr::Ascii("licization"),
        dictgen::InsensitiveStr::Ascii("licizations"),
        dictgen::InsensitiveStr::Ascii("licize"),
        dictgen::InsensitiveStr::Ascii("licized"),
        dictgen::InsensitiveStr::Ascii("licizes"),
        dictgen::InsensitiveStr::Ascii("licizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GED_3160770251205469873)],
        &[(0b10010, &ENTRY_GAELICIZATION_4844070600760866038)],
        &[(0b10010, &ENTRY_GAELICIZATIONS_17696860649831504754)],
        &[(0b10010, &ENTRY_GAELICIZE_1407556659501295001)],
        &[(0b10010, &ENTRY_GAELICIZED_15866795337678251270)],
        &[(0b10010, &ENTRY_GAELICIZES_17031855669643476498)],
        &[(0b10010, &ENTRY_GAELICIZING_12815210015437537089)],
        &[(0b01001, &ENTRY_GAELICIZATION_4844070600760866038)],
        &[(0b01001, &ENTRY_GAELICIZATIONS_17696860649831504754)],
        &[(0b01001, &ENTRY_GAELICIZE_1407556659501295001)],
        &[(0b01001, &ENTRY_GAELICIZED_15866795337678251270)],
        &[(0b01001, &ENTRY_GAELICIZES_17031855669643476498)],
        &[(0b01001, &ENTRY_GAELICIZING_12815210015437537089)],
    ],
    range: 1..=11,
};

static VARS_F_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_F_CHILDREN),
    value: None,
};

static VARS_F_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_FA_NODE),
    None,
    None,
    None,
    Some(&VARS_FE_NODE),
    None,
    None,
    None,
    Some(&VARS_FI_NODE),
    None,
    None,
    Some(&VARS_FL_NODE),
    None,
    None,
    Some(&VARS_FO_NODE),
    None,
    None,
    Some(&VARS_FR_NODE),
    None,
    None,
    Some(&VARS_FU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_FU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FU_CHILDREN),
    value: None,
};

static VARS_FU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_FUE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FUL_NODE),
    None,
    Some(&VARS_FUN_NODE),
    None,
    None,
    None,
    Some(&VARS_FUR_NODE),
    Some(&VARS_FUS_NODE),
    Some(&VARS_FUT_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FUZ_NODE),
];

static VARS_FUZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUZ_CHILDREN),
    value: None,
};

pub static VARS_FUZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("ing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_FUSE_13721350294892050426)],
        &[(0b01001, &ENTRY_FUSED_16220222527302259642)],
        &[(0b01001, &ENTRY_FUSES_6052488625673233414)],
        &[(0b01001, &ENTRY_FUSING_4402212491712141583)],
    ],
    range: 1..=3,
};

static VARS_FUT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUT_CHILDREN),
    value: None,
};

pub static VARS_FUT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("urise"),
        dictgen::InsensitiveStr::Ascii("urises"),
        dictgen::InsensitiveStr::Ascii("urize"),
        dictgen::InsensitiveStr::Ascii("urizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FUTILIZE_11119974740228332037)],
        &[(0b10010, &ENTRY_FUTILIZES_3019005313253578090)],
        &[(0b01001, &ENTRY_FUTILIZE_11119974740228332037)],
        &[(0b01001, &ENTRY_FUTILIZES_3019005313253578090)],
        &[(0b10010, &ENTRY_FUTURIZE_440985091352933094)],
        &[(0b10010, &ENTRY_FUTURIZES_15904912381443733442)],
        &[(0b01001, &ENTRY_FUTURIZE_440985091352933094)],
        &[(0b01001, &ENTRY_FUTURIZES_15904912381443733442)],
    ],
    range: 5..=6,
};

static VARS_FUS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUS_CHILDREN),
    value: None,
};

pub static VARS_FUS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tianise"),
        dictgen::InsensitiveStr::Ascii("tianised"),
        dictgen::InsensitiveStr::Ascii("tianises"),
        dictgen::InsensitiveStr::Ascii("tianising"),
        dictgen::InsensitiveStr::Ascii("tianize"),
        dictgen::InsensitiveStr::Ascii("tianized"),
        dictgen::InsensitiveStr::Ascii("tianizes"),
        dictgen::InsensitiveStr::Ascii("tianizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FUSTIANIZE_7532541978986663145)],
        &[(0b10010, &ENTRY_FUSTIANIZED_6857323956586456405)],
        &[(0b10010, &ENTRY_FUSTIANIZES_14263302384765637245)],
        &[(0b10010, &ENTRY_FUSTIANIZING_8877334472530223768)],
        &[(0b01001, &ENTRY_FUSTIANIZE_7532541978986663145)],
        &[(0b01001, &ENTRY_FUSTIANIZED_6857323956586456405)],
        &[(0b01001, &ENTRY_FUSTIANIZES_14263302384765637245)],
        &[(0b01001, &ENTRY_FUSTIANIZING_8877334472530223768)],
    ],
    range: 7..=9,
};

static VARS_FUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUR_CHILDREN),
    value: None,
};

pub static VARS_FUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("culae"),
        dictgen::InsensitiveStr::Ascii("cule"),
        dictgen::InsensitiveStr::Ascii("iae"),
        dictgen::InsensitiveStr::Ascii("ie"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ore"),
        dictgen::InsensitiveStr::Ascii("ores"),
        dictgen::InsensitiveStr::Ascii("ors"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FURCULE_4500392567637304895)],
        &[(0b00001, &ENTRY_FURCULE_4500392567637304895)],
        &[(0b11010, &ENTRY_FURIE_2816987526743473529)],
        &[(0b00001, &ENTRY_FURIE_2816987526743473529)],
        &[(0b11001, &ENTRY_FUROR_9905139920010048702)],
        &[(0b10010, &ENTRY_FUROR_9905139920010048702)],
        &[(0b10010, &ENTRY_FURORS_11654983778967796186)],
        &[(0b11001, &ENTRY_FURORS_11654983778967796186)],
    ],
    range: 2..=5,
};

static VARS_FUN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUN_CHILDREN),
    value: None,
};

pub static VARS_FUN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ctionalise"),
        dictgen::InsensitiveStr::Ascii("ctionalises"),
        dictgen::InsensitiveStr::Ascii("ctionalize"),
        dictgen::InsensitiveStr::Ascii("ctionalizes"),
        dictgen::InsensitiveStr::Ascii("ctionise"),
        dictgen::InsensitiveStr::Ascii("ctionises"),
        dictgen::InsensitiveStr::Ascii("ctionize"),
        dictgen::InsensitiveStr::Ascii("ctionizes"),
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("neled"),
        dictgen::InsensitiveStr::Ascii("neler"),
        dictgen::InsensitiveStr::Ascii("neling"),
        dictgen::InsensitiveStr::Ascii("nelled"),
        dictgen::InsensitiveStr::Ascii("neller"),
        dictgen::InsensitiveStr::Ascii("nelling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FUNCTIONALIZE_5200513031891278249)],
        &[(0b10010, &ENTRY_FUNCTIONALIZES_8846469370790846555)],
        &[(0b01001, &ENTRY_FUNCTIONALIZE_5200513031891278249)],
        &[(0b01001, &ENTRY_FUNCTIONALIZES_8846469370790846555)],
        &[(0b10010, &ENTRY_FUNCTIONIZE_590437862985052700)],
        &[(0b10010, &ENTRY_FUNCTIONIZES_206660126975387910)],
        &[(0b01001, &ENTRY_FUNCTIONIZE_590437862985052700)],
        &[(0b01001, &ENTRY_FUNCTIONIZES_206660126975387910)],
        &[(0b10010, &ENTRY_FUNERALIZE_6939628183239081771)],
        &[(0b10010, &ENTRY_FUNERALIZES_9727791744771513558)],
        &[(0b01001, &ENTRY_FUNERALIZE_6939628183239081771)],
        &[(0b01001, &ENTRY_FUNERALIZES_9727791744771513558)],
        &[(0b00001, &ENTRY_FUNNELED_12440004640602776962)],
        &[(0b00001, &ENTRY_FUNNELER_5464699882596191112)],
        &[(0b00001, &ENTRY_FUNNELING_3433367811767870104)],
        &[(0b11010, &ENTRY_FUNNELED_12440004640602776962)],
        &[(0b11010, &ENTRY_FUNNELER_5464699882596191112)],
        &[(0b11010, &ENTRY_FUNNELING_3433367811767870104)],
    ],
    range: 5..=11,
};

static VARS_FUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUL_CHILDREN),
    value: None,
};

pub static VARS_FUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fil"),
        dictgen::InsensitiveStr::Ascii("fill"),
        dictgen::InsensitiveStr::Ascii("fillment"),
        dictgen::InsensitiveStr::Ascii("fillments"),
        dictgen::InsensitiveStr::Ascii("fills"),
        dictgen::InsensitiveStr::Ascii("filment"),
        dictgen::InsensitiveStr::Ascii("filments"),
        dictgen::InsensitiveStr::Ascii("fils"),
        dictgen::InsensitiveStr::Ascii("gor"),
        dictgen::InsensitiveStr::Ascii("gorous"),
        dictgen::InsensitiveStr::Ascii("gors"),
        dictgen::InsensitiveStr::Ascii("gour"),
        dictgen::InsensitiveStr::Ascii("gourous"),
        dictgen::InsensitiveStr::Ascii("gours"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FULFILL_9378496470221325385)],
        &[(0b11001, &ENTRY_FULFILL_9378496470221325385)],
        &[(0b01001, &ENTRY_FULFILLMENT_7148807446626431675)],
        &[(0b01001, &ENTRY_FULFILLMENTS_1418454263886981690)],
        &[(0b11001, &ENTRY_FULFILLS_3570272199614377288)],
        &[(0b11010, &ENTRY_FULFILLMENT_7148807446626431675)],
        &[(0b11010, &ENTRY_FULFILLMENTS_1418454263886981690)],
        &[(0b11010, &ENTRY_FULFILLS_3570272199614377288)],
        &[(0b00001, &ENTRY_FULGOR_3603133681706621725)],
        &[(0b00001, &ENTRY_FULGOROUS_7876443384003563272)],
        &[(0b00001, &ENTRY_FULGORS_6876524141780705677)],
        &[(0b11010, &ENTRY_FULGOR_3603133681706621725)],
        &[(0b11010, &ENTRY_FULGOROUS_7876443384003563272)],
        &[(0b11010, &ENTRY_FULGORS_6876524141780705677)],
    ],
    range: 3..=9,
};

static VARS_FUE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUE_CHILDREN),
    value: None,
};

pub static VARS_FUE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("liser"),
        dictgen::InsensitiveStr::Ascii("lisers"),
        dictgen::InsensitiveStr::Ascii("lizer"),
        dictgen::InsensitiveStr::Ascii("lizers"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("ller"),
        dictgen::InsensitiveStr::Ascii("llers"),
        dictgen::InsensitiveStr::Ascii("lling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FUELED_1405501076484499618)],
        &[(0b00001, &ENTRY_FUELER_15360085798704172702)],
        &[(0b00001, &ENTRY_FUELERS_14375576697530944446)],
        &[(0b00001, &ENTRY_FUELING_13174491634544185979)],
        &[(0b10010, &ENTRY_FUELIZER_197436267427694078)],
        &[(0b10010, &ENTRY_FUELIZERS_319090579847564711)],
        &[(0b01001, &ENTRY_FUELIZER_197436267427694078)],
        &[(0b01001, &ENTRY_FUELIZERS_319090579847564711)],
        &[(0b11010, &ENTRY_FUELED_1405501076484499618)],
        &[(0b11010, &ENTRY_FUELER_15360085798704172702)],
        &[(0b11010, &ENTRY_FUELERS_14375576697530944446)],
        &[(0b11010, &ENTRY_FUELING_13174491634544185979)],
    ],
    range: 3..=6,
};

static VARS_FR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FR_CHILDREN),
    value: None,
};

static VARS_FR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_FRA_NODE),
    None,
    None,
    None,
    Some(&VARS_FRE_NODE),
    None,
    None,
    None,
    Some(&VARS_FRI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_FRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRI_CHILDREN),
    value: None,
};

pub static VARS_FRI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("borg"),
        dictgen::InsensitiveStr::Ascii("bourg"),
        dictgen::InsensitiveStr::Ascii("ctionise"),
        dictgen::InsensitiveStr::Ascii("ctionises"),
        dictgen::InsensitiveStr::Ascii("ctionize"),
        dictgen::InsensitiveStr::Ascii("ctionizes"),
        dictgen::InsensitiveStr::Ascii("sado"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("sette"),
        dictgen::InsensitiveStr::Ascii("settes"),
        dictgen::InsensitiveStr::Ascii("voled"),
        dictgen::InsensitiveStr::Ascii("voler"),
        dictgen::InsensitiveStr::Ascii("volers"),
        dictgen::InsensitiveStr::Ascii("voling"),
        dictgen::InsensitiveStr::Ascii("volled"),
        dictgen::InsensitiveStr::Ascii("voller"),
        dictgen::InsensitiveStr::Ascii("vollers"),
        dictgen::InsensitiveStr::Ascii("volling"),
        dictgen::InsensitiveStr::Ascii("zado"),
        dictgen::InsensitiveStr::Ascii("ze"),
        dictgen::InsensitiveStr::Ascii("zette"),
        dictgen::InsensitiveStr::Ascii("zettes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FRIBORG_14998222602089863011)],
        &[(0b11010, &ENTRY_FRIBORG_14998222602089863011)],
        &[(0b10010, &ENTRY_FRICTIONIZE_13167776211997189353)],
        &[(0b10010, &ENTRY_FRICTIONIZES_13370622118045354659)],
        &[(0b01001, &ENTRY_FRICTIONIZE_13167776211997189353)],
        &[(0b01001, &ENTRY_FRICTIONIZES_13370622118045354659)],
        &[(0b10010, &ENTRY_FRIZADO_7132644256144212836)],
        &[(0b10010, &ENTRY_FRIZE_18317112308802773864)],
        &[(0b10010, &ENTRY_FRIZETTE_7935539353493442254)],
        &[(0b10010, &ENTRY_FRIZETTES_7971399902959741267)],
        &[(0b00001, &ENTRY_FRIVOLED_10810709816607291145)],
        &[(0b00001, &ENTRY_FRIVOLER_2817825932076218971)],
        &[(0b00001, &ENTRY_FRIVOLERS_14649857547767057396)],
        &[(0b00001, &ENTRY_FRIVOLING_16952070309248351114)],
        &[(0b11010, &ENTRY_FRIVOLED_10810709816607291145)],
        &[(0b11010, &ENTRY_FRIVOLER_2817825932076218971)],
        &[(0b11010, &ENTRY_FRIVOLERS_14649857547767057396)],
        &[(0b11010, &ENTRY_FRIVOLING_16952070309248351114)],
        &[(0b01001, &ENTRY_FRIZADO_7132644256144212836)],
        &[(0b01001, &ENTRY_FRIZE_18317112308802773864)],
        &[(0b01001, &ENTRY_FRIZETTE_7935539353493442254)],
        &[(0b01001, &ENTRY_FRIZETTES_7971399902959741267)],
    ],
    range: 2..=9,
};

static VARS_FRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRE_CHILDREN),
    value: None,
};

pub static VARS_FRE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("ity"),
        dictgen::InsensitiveStr::Ascii("na"),
        dictgen::InsensitiveStr::Ascii("nchise"),
        dictgen::InsensitiveStr::Ascii("nchises"),
        dictgen::InsensitiveStr::Ascii("nchize"),
        dictgen::InsensitiveStr::Ascii("nchizes"),
        dictgen::InsensitiveStr::Ascii("neau"),
        dictgen::InsensitiveStr::Ascii("nula"),
        dictgen::InsensitiveStr::Ascii("nular"),
        dictgen::InsensitiveStr::Ascii("nulum"),
        dictgen::InsensitiveStr::Ascii("num"),
        dictgen::InsensitiveStr::Ascii("nums"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FERD_14446691116670344833)],
        &[(0b11010, &ENTRY_FERITY_13311389916744452456)],
        &[(0b00001, &ENTRY_FRENA_9256148821059642646)],
        &[(0b10010, &ENTRY_FRENCHIZE_5282928364010596499)],
        &[(0b10010, &ENTRY_FRENCHIZES_13171453204737829989)],
        &[(0b01001, &ENTRY_FRENCHIZE_5282928364010596499)],
        &[(0b01001, &ENTRY_FRENCHIZES_13171453204737829989)],
        &[(0b11010, &ENTRY_FERNEAU_15772716514172526627)],
        &[(0b00001, &ENTRY_FRENULA_17174405168241583244)],
        &[(0b00001, &ENTRY_FRENULAR_6156340314741914755)],
        &[(0b00001, &ENTRY_FRENULUM_16387614517776586745)],
        &[(0b00001, &ENTRY_FRENUM_12416692539021246592)],
        &[(0b00001, &ENTRY_FRENUMS_14492633245925017206)],
    ],
    range: 1..=7,
};

static VARS_FRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FRA_CHILDREN),
    value: None,
};

static VARS_FRA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_FRAC_NODE),
    None,
    Some(&VARS_FRAE_NODE),
    None,
    Some(&VARS_FRAG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FRAM_NODE),
    Some(&VARS_FRAN_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FRAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_FRAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRAT_CHILDREN),
    value: None,
};

pub static VARS_FRAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ernisation"),
        dictgen::InsensitiveStr::Ascii("ernisations"),
        dictgen::InsensitiveStr::Ascii("ernise"),
        dictgen::InsensitiveStr::Ascii("ernised"),
        dictgen::InsensitiveStr::Ascii("erniser"),
        dictgen::InsensitiveStr::Ascii("ernisers"),
        dictgen::InsensitiveStr::Ascii("ernises"),
        dictgen::InsensitiveStr::Ascii("ernising"),
        dictgen::InsensitiveStr::Ascii("ernization"),
        dictgen::InsensitiveStr::Ascii("ernizations"),
        dictgen::InsensitiveStr::Ascii("ernize"),
        dictgen::InsensitiveStr::Ascii("ernized"),
        dictgen::InsensitiveStr::Ascii("ernizer"),
        dictgen::InsensitiveStr::Ascii("ernizers"),
        dictgen::InsensitiveStr::Ascii("ernizes"),
        dictgen::InsensitiveStr::Ascii("ernizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FRATERNIZATION_17491532297861507226)],
        &[(0b10010, &ENTRY_FRATERNIZATIONS_2264901292350066915)],
        &[(0b10010, &ENTRY_FRATERNIZE_6114828862653151704)],
        &[(0b10010, &ENTRY_FRATERNIZED_40843362060401503)],
        &[(0b10010, &ENTRY_FRATERNIZER_8545635095936020045)],
        &[(0b10010, &ENTRY_FRATERNIZERS_17211381996632496983)],
        &[(0b10010, &ENTRY_FRATERNIZES_11999482520269062840)],
        &[(0b10010, &ENTRY_FRATERNIZING_17486557641907645835)],
        &[(0b01001, &ENTRY_FRATERNIZATION_17491532297861507226)],
        &[(0b01001, &ENTRY_FRATERNIZATIONS_2264901292350066915)],
        &[(0b01001, &ENTRY_FRATERNIZE_6114828862653151704)],
        &[(0b01001, &ENTRY_FRATERNIZED_40843362060401503)],
        &[(0b01001, &ENTRY_FRATERNIZER_8545635095936020045)],
        &[(0b01001, &ENTRY_FRATERNIZERS_17211381996632496983)],
        &[(0b01001, &ENTRY_FRATERNIZES_11999482520269062840)],
        &[(0b01001, &ENTRY_FRATERNIZING_17486557641907645835)],
    ],
    range: 6..=11,
};

static VARS_FRAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRAN_CHILDREN),
    value: None,
};

pub static VARS_FRAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cise"),
        dictgen::InsensitiveStr::Ascii("cises"),
        dictgen::InsensitiveStr::Ascii("cize"),
        dictgen::InsensitiveStr::Ascii("cizes"),
        dictgen::InsensitiveStr::Ascii("klinisation"),
        dictgen::InsensitiveStr::Ascii("klinisations"),
        dictgen::InsensitiveStr::Ascii("klinization"),
        dictgen::InsensitiveStr::Ascii("klinizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FRANCIZE_13649175539545993519)],
        &[(0b10010, &ENTRY_FRANCIZES_4289708258444944079)],
        &[(0b01001, &ENTRY_FRANCIZE_13649175539545993519)],
        &[(0b01001, &ENTRY_FRANCIZES_4289708258444944079)],
        &[(0b10010, &ENTRY_FRANKLINIZATION_13025384598101464262)],
        &[(0b10010, &ENTRY_FRANKLINIZATIONS_12423021383400433032)],
        &[(0b01001, &ENTRY_FRANKLINIZATION_13025384598101464262)],
        &[(0b01001, &ENTRY_FRANKLINIZATIONS_12423021383400433032)],
    ],
    range: 4..=12,
};

static VARS_FRAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRAM_CHILDREN),
    value: None,
};

pub static VARS_FRAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("besia"),
        dictgen::InsensitiveStr::Ascii("besias"),
        dictgen::InsensitiveStr::Ascii("boesia"),
        dictgen::InsensitiveStr::Ascii("boesias"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FRAMBESIA_5861085960963562398)],
        &[(0b00001, &ENTRY_FRAMBESIAS_12235414527947368126)],
        &[(0b11010, &ENTRY_FRAMBESIA_5861085960963562398)],
        &[(0b11010, &ENTRY_FRAMBESIAS_12235414527947368126)],
    ],
    range: 5..=7,
};

static VARS_FRAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRAG_CHILDREN),
    value: None,
};

pub static VARS_FRAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mentisation"),
        dictgen::InsensitiveStr::Ascii("mentise"),
        dictgen::InsensitiveStr::Ascii("mentised"),
        dictgen::InsensitiveStr::Ascii("mentiser"),
        dictgen::InsensitiveStr::Ascii("mentises"),
        dictgen::InsensitiveStr::Ascii("mentising"),
        dictgen::InsensitiveStr::Ascii("mentization"),
        dictgen::InsensitiveStr::Ascii("mentize"),
        dictgen::InsensitiveStr::Ascii("mentized"),
        dictgen::InsensitiveStr::Ascii("mentizer"),
        dictgen::InsensitiveStr::Ascii("mentizes"),
        dictgen::InsensitiveStr::Ascii("mentizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FRAGMENTIZATION_11311522493510806007)],
        &[(0b10010, &ENTRY_FRAGMENTIZE_11591563595037284264)],
        &[(0b10010, &ENTRY_FRAGMENTIZED_7624364982594162254)],
        &[(0b10010, &ENTRY_FRAGMENTIZER_11875792900792650033)],
        &[(0b10010, &ENTRY_FRAGMENTIZES_7273396024325138788)],
        &[(0b10010, &ENTRY_FRAGMENTIZING_4493708054049080561)],
        &[(0b01001, &ENTRY_FRAGMENTIZATION_11311522493510806007)],
        &[(0b01001, &ENTRY_FRAGMENTIZE_11591563595037284264)],
        &[(0b01001, &ENTRY_FRAGMENTIZED_7624364982594162254)],
        &[(0b01001, &ENTRY_FRAGMENTIZER_11875792900792650033)],
        &[(0b01001, &ENTRY_FRAGMENTIZES_7273396024325138788)],
        &[(0b01001, &ENTRY_FRAGMENTIZING_4493708054049080561)],
    ],
    range: 7..=11,
};

static VARS_FRAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRAE_CHILDREN),
    value: None,
};

pub static VARS_FRAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("na"),
        dictgen::InsensitiveStr::Ascii("nula"),
        dictgen::InsensitiveStr::Ascii("nular"),
        dictgen::InsensitiveStr::Ascii("nulum"),
        dictgen::InsensitiveStr::Ascii("num"),
        dictgen::InsensitiveStr::Ascii("nums"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FRENA_9256148821059642646)],
        &[(0b11010, &ENTRY_FRENULA_17174405168241583244)],
        &[(0b11010, &ENTRY_FRENULAR_6156340314741914755)],
        &[(0b11010, &ENTRY_FRENULUM_16387614517776586745)],
        &[(0b11010, &ENTRY_FRENUM_12416692539021246592)],
        &[(0b11010, &ENTRY_FRENUMS_14492633245925017206)],
    ],
    range: 2..=5,
};

static VARS_FRAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRAC_CHILDREN),
    value: None,
};

pub static VARS_FRAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tionalisation"),
        dictgen::InsensitiveStr::Ascii("tionalisations"),
        dictgen::InsensitiveStr::Ascii("tionalise"),
        dictgen::InsensitiveStr::Ascii("tionalised"),
        dictgen::InsensitiveStr::Ascii("tionalises"),
        dictgen::InsensitiveStr::Ascii("tionalising"),
        dictgen::InsensitiveStr::Ascii("tionalization"),
        dictgen::InsensitiveStr::Ascii("tionalizations"),
        dictgen::InsensitiveStr::Ascii("tionalize"),
        dictgen::InsensitiveStr::Ascii("tionalized"),
        dictgen::InsensitiveStr::Ascii("tionalizes"),
        dictgen::InsensitiveStr::Ascii("tionalizing"),
        dictgen::InsensitiveStr::Ascii("tionisation"),
        dictgen::InsensitiveStr::Ascii("tionisations"),
        dictgen::InsensitiveStr::Ascii("tionise"),
        dictgen::InsensitiveStr::Ascii("tionised"),
        dictgen::InsensitiveStr::Ascii("tionises"),
        dictgen::InsensitiveStr::Ascii("tionising"),
        dictgen::InsensitiveStr::Ascii("tionization"),
        dictgen::InsensitiveStr::Ascii("tionizations"),
        dictgen::InsensitiveStr::Ascii("tionize"),
        dictgen::InsensitiveStr::Ascii("tionized"),
        dictgen::InsensitiveStr::Ascii("tionizes"),
        dictgen::InsensitiveStr::Ascii("tionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FRACTIONALIZATION_16384909557987092874)],
        &[(0b10010, &ENTRY_FRACTIONALIZATIONS_13179689836045633268)],
        &[(0b10010, &ENTRY_FRACTIONALIZE_11145753951508722721)],
        &[(0b10010, &ENTRY_FRACTIONALIZED_13769926033588137385)],
        &[(0b10010, &ENTRY_FRACTIONALIZES_17666163749894726979)],
        &[(0b10010, &ENTRY_FRACTIONALIZING_18417565787016805561)],
        &[(0b01001, &ENTRY_FRACTIONALIZATION_16384909557987092874)],
        &[(0b01001, &ENTRY_FRACTIONALIZATIONS_13179689836045633268)],
        &[(0b01001, &ENTRY_FRACTIONALIZE_11145753951508722721)],
        &[(0b01001, &ENTRY_FRACTIONALIZED_13769926033588137385)],
        &[(0b01001, &ENTRY_FRACTIONALIZES_17666163749894726979)],
        &[(0b01001, &ENTRY_FRACTIONALIZING_18417565787016805561)],
        &[(0b10010, &ENTRY_FRACTIONIZATION_11310553652346900287)],
        &[(0b10010, &ENTRY_FRACTIONIZATIONS_8008183611215290136)],
        &[(0b10010, &ENTRY_FRACTIONIZE_17146847402825816377)],
        &[(0b10010, &ENTRY_FRACTIONIZED_9636630884367605738)],
        &[(0b10010, &ENTRY_FRACTIONIZES_1122151038872899386)],
        &[(0b10010, &ENTRY_FRACTIONIZING_7844279074827159878)],
        &[(0b01001, &ENTRY_FRACTIONIZATION_11310553652346900287)],
        &[(0b01001, &ENTRY_FRACTIONIZATIONS_8008183611215290136)],
        &[(0b01001, &ENTRY_FRACTIONIZE_17146847402825816377)],
        &[(0b01001, &ENTRY_FRACTIONIZED_9636630884367605738)],
        &[(0b01001, &ENTRY_FRACTIONIZES_1122151038872899386)],
        &[(0b01001, &ENTRY_FRACTIONIZING_7844279074827159878)],
    ],
    range: 7..=14,
};

static VARS_FO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FO_CHILDREN),
    value: None,
};

static VARS_FO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_FOC_NODE),
    None,
    Some(&VARS_FOE_NODE),
    None,
    Some(&VARS_FOG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FON_NODE),
    Some(&VARS_FOO_NODE),
    None,
    None,
    Some(&VARS_FOR_NODE),
    Some(&VARS_FOS_NODE),
    None,
    Some(&VARS_FOU_NODE),
    Some(&VARS_FOV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_FOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOV_CHILDREN),
    value: None,
};

pub static VARS_FOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eolae"),
        dictgen::InsensitiveStr::Ascii("eole"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FOVEOLE_15698905273647136338)],
        &[(0b00001, &ENTRY_FOVEOLE_15698905273647136338)],
    ],
    range: 4..=5,
};

static VARS_FOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOU_CHILDREN),
    value: None,
};

pub static VARS_FOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lder"),
        dictgen::InsensitiveStr::Ascii("ldre"),
        dictgen::InsensitiveStr::Ascii("rb"),
        dictgen::InsensitiveStr::Ascii("rche"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FOULDER_16108707272330673330)],
        &[(0b11010, &ENTRY_FOULDER_16108707272330673330)],
        &[(0b11010, &ENTRY_FORB_6126634977774856175)],
        &[(0b11010, &ENTRY_FORCHE_1402256314253192740)],
        &[(0b00001, &ENTRY_FOUTER_14629881838259893932)],
        &[(0b00001, &ENTRY_FOUTERS_2811207748622809965)],
        &[(0b11010, &ENTRY_FOUTER_14629881838259893932)],
        &[(0b11010, &ENTRY_FOUTERS_2811207748622809965)],
    ],
    range: 2..=4,
};

static VARS_FOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOS_CHILDREN),
    value: None,
};

pub static VARS_FOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sae"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("siled"),
        dictgen::InsensitiveStr::Ascii("silisable"),
        dictgen::InsensitiveStr::Ascii("silisabler"),
        dictgen::InsensitiveStr::Ascii("silisables"),
        dictgen::InsensitiveStr::Ascii("silisablest"),
        dictgen::InsensitiveStr::Ascii("silisation"),
        dictgen::InsensitiveStr::Ascii("silisations"),
        dictgen::InsensitiveStr::Ascii("silise"),
        dictgen::InsensitiveStr::Ascii("silised"),
        dictgen::InsensitiveStr::Ascii("silises"),
        dictgen::InsensitiveStr::Ascii("silising"),
        dictgen::InsensitiveStr::Ascii("silizable"),
        dictgen::InsensitiveStr::Ascii("silizabler"),
        dictgen::InsensitiveStr::Ascii("silizables"),
        dictgen::InsensitiveStr::Ascii("silizablest"),
        dictgen::InsensitiveStr::Ascii("silization"),
        dictgen::InsensitiveStr::Ascii("silizations"),
        dictgen::InsensitiveStr::Ascii("silize"),
        dictgen::InsensitiveStr::Ascii("silized"),
        dictgen::InsensitiveStr::Ascii("silizes"),
        dictgen::InsensitiveStr::Ascii("silizing"),
        dictgen::InsensitiveStr::Ascii("silled"),
        dictgen::InsensitiveStr::Ascii("sulae"),
        dictgen::InsensitiveStr::Ascii("sule"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FOSSE_3258749641128695749)],
        &[(0b00001, &ENTRY_FOSSE_3258749641128695749)],
        &[(0b00001, &ENTRY_FOSSILED_7388917284102970861)],
        &[(0b10010, &ENTRY_FOSSILIZABLE_18179987864109440980)],
        &[(0b10010, &ENTRY_FOSSILIZABLER_18074000082058380580)],
        &[(0b10010, &ENTRY_FOSSILIZABLES_17849243195390470932)],
        &[(0b10010, &ENTRY_FOSSILIZABLEST_8988007686369551192)],
        &[(0b10010, &ENTRY_FOSSILIZATION_8495765767484914666)],
        &[(0b10010, &ENTRY_FOSSILIZATIONS_13043864217790465526)],
        &[(0b10010, &ENTRY_FOSSILIZE_15956386341505137526)],
        &[(0b10010, &ENTRY_FOSSILIZED_9532911763478840886)],
        &[(0b10010, &ENTRY_FOSSILIZES_1575017333804498872)],
        &[(0b10010, &ENTRY_FOSSILIZING_12802087173792026745)],
        &[(0b01001, &ENTRY_FOSSILIZABLE_18179987864109440980)],
        &[(0b01001, &ENTRY_FOSSILIZABLER_18074000082058380580)],
        &[(0b01001, &ENTRY_FOSSILIZABLES_17849243195390470932)],
        &[(0b01001, &ENTRY_FOSSILIZABLEST_8988007686369551192)],
        &[(0b01001, &ENTRY_FOSSILIZATION_8495765767484914666)],
        &[(0b01001, &ENTRY_FOSSILIZATIONS_13043864217790465526)],
        &[(0b01001, &ENTRY_FOSSILIZE_15956386341505137526)],
        &[(0b01001, &ENTRY_FOSSILIZED_9532911763478840886)],
        &[(0b01001, &ENTRY_FOSSILIZES_1575017333804498872)],
        &[(0b01001, &ENTRY_FOSSILIZING_12802087173792026745)],
        &[(0b11010, &ENTRY_FOSSILED_7388917284102970861)],
        &[(0b11010, &ENTRY_FOSSULE_16030537484007901649)],
        &[(0b00001, &ENTRY_FOSSULE_16030537484007901649)],
    ],
    range: 2..=11,
};

static VARS_FOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FOR_CHILDREN),
    value: None,
};

static VARS_FOR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_FORB_NODE),
    Some(&VARS_FORC_NODE),
    None,
    Some(&VARS_FORE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FORM_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FORU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_FORU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FORU_CHILDREN),
    value: None,
};

pub static VARS_FORU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mise"),
        dictgen::InsensitiveStr::Ascii("mises"),
        dictgen::InsensitiveStr::Ascii("mize"),
        dictgen::InsensitiveStr::Ascii("mizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FORUMIZE_8419530003404584902)],
        &[(0b10010, &ENTRY_FORUMIZES_12018353002631822802)],
        &[(0b01001, &ENTRY_FORUMIZE_8419530003404584902)],
        &[(0b01001, &ENTRY_FORUMIZES_12018353002631822802)],
    ],
    range: 4..=5,
};

static VARS_FORM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FORM_CHILDREN),
    value: None,
};

pub static VARS_FORM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("alisable"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alizable"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("icidae"),
        dictgen::InsensitiveStr::Ascii("icide"),
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularisations"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularised"),
        dictgen::InsensitiveStr::Ascii("ulariser"),
        dictgen::InsensitiveStr::Ascii("ularisers"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularising"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularizations"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularized"),
        dictgen::InsensitiveStr::Ascii("ularizer"),
        dictgen::InsensitiveStr::Ascii("ularizers"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("ularizing"),
        dictgen::InsensitiveStr::Ascii("ulisation"),
        dictgen::InsensitiveStr::Ascii("ulisations"),
        dictgen::InsensitiveStr::Ascii("ulise"),
        dictgen::InsensitiveStr::Ascii("ulised"),
        dictgen::InsensitiveStr::Ascii("uliser"),
        dictgen::InsensitiveStr::Ascii("ulises"),
        dictgen::InsensitiveStr::Ascii("ulising"),
        dictgen::InsensitiveStr::Ascii("ulization"),
        dictgen::InsensitiveStr::Ascii("ulizations"),
        dictgen::InsensitiveStr::Ascii("ulize"),
        dictgen::InsensitiveStr::Ascii("ulized"),
        dictgen::InsensitiveStr::Ascii("ulizer"),
        dictgen::InsensitiveStr::Ascii("ulizes"),
        dictgen::InsensitiveStr::Ascii("ulizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FORME_8817057189260314567)],
        &[(0b10010, &ENTRY_FORMALIZABLE_7585059673108358079)],
        &[(0b10010, &ENTRY_FORMALIZATION_2591485126762882449)],
        &[(0b10010, &ENTRY_FORMALIZATIONS_8555578184919419751)],
        &[(0b10010, &ENTRY_FORMALIZE_1679468906044255450)],
        &[(0b10010, &ENTRY_FORMALIZED_9806599668393286541)],
        &[(0b10010, &ENTRY_FORMALIZER_4036745239171518381)],
        &[(0b10010, &ENTRY_FORMALIZERS_4493481399447794615)],
        &[(0b10010, &ENTRY_FORMALIZES_15752365028447713270)],
        &[(0b10010, &ENTRY_FORMALIZING_5721392513252990643)],
        &[(0b01001, &ENTRY_FORMALIZABLE_7585059673108358079)],
        &[(0b01001, &ENTRY_FORMALIZATION_2591485126762882449)],
        &[(0b01001, &ENTRY_FORMALIZATIONS_8555578184919419751)],
        &[(0b01001, &ENTRY_FORMALIZE_1679468906044255450)],
        &[(0b01001, &ENTRY_FORMALIZED_9806599668393286541)],
        &[(0b01001, &ENTRY_FORMALIZER_4036745239171518381)],
        &[(0b01001, &ENTRY_FORMALIZERS_4493481399447794615)],
        &[(0b01001, &ENTRY_FORMALIZES_15752365028447713270)],
        &[(0b01001, &ENTRY_FORMALIZING_5721392513252990643)],
        &[(0b00001, &ENTRY_FORME_8817057189260314567)],
        &[(0b11010, &ENTRY_FORMICIDE_14400080074027357649)],
        &[(0b00001, &ENTRY_FORMICIDE_14400080074027357649)],
        &[(0b10010, &ENTRY_FORMULARIZATION_4096021351742803243)],
        &[(0b10010, &ENTRY_FORMULARIZATIONS_9630465214768761062)],
        &[(0b10010, &ENTRY_FORMULARIZE_16840729465120564209)],
        &[(0b10010, &ENTRY_FORMULARIZED_14755186046923001561)],
        &[(0b10010, &ENTRY_FORMULARIZER_13491153773141977702)],
        &[(0b10010, &ENTRY_FORMULARIZERS_5805308029962586697)],
        &[(0b10010, &ENTRY_FORMULARIZES_6077920602945622346)],
        &[(0b10010, &ENTRY_FORMULARIZING_3458666980856017654)],
        &[(0b01001, &ENTRY_FORMULARIZATION_4096021351742803243)],
        &[(0b01001, &ENTRY_FORMULARIZATIONS_9630465214768761062)],
        &[(0b01001, &ENTRY_FORMULARIZE_16840729465120564209)],
        &[(0b01001, &ENTRY_FORMULARIZED_14755186046923001561)],
        &[(0b01001, &ENTRY_FORMULARIZER_13491153773141977702)],
        &[(0b01001, &ENTRY_FORMULARIZERS_5805308029962586697)],
        &[(0b01001, &ENTRY_FORMULARIZES_6077920602945622346)],
        &[(0b01001, &ENTRY_FORMULARIZING_3458666980856017654)],
        &[(0b10010, &ENTRY_FORMULIZATION_15762814181405703881)],
        &[(0b10010, &ENTRY_FORMULIZATIONS_7651203325038229389)],
        &[(0b10010, &ENTRY_FORMULIZE_7249621384300709725)],
        &[(0b10010, &ENTRY_FORMULIZED_7061613765094184503)],
        &[(0b10010, &ENTRY_FORMULIZER_1938134547151236987)],
        &[(0b10010, &ENTRY_FORMULIZES_10074978617027689565)],
        &[(0b10010, &ENTRY_FORMULIZING_613748303971363524)],
        &[(0b01001, &ENTRY_FORMULIZATION_15762814181405703881)],
        &[(0b01001, &ENTRY_FORMULIZATIONS_7651203325038229389)],
        &[(0b01001, &ENTRY_FORMULIZE_7249621384300709725)],
        &[(0b01001, &ENTRY_FORMULIZED_7061613765094184503)],
        &[(0b01001, &ENTRY_FORMULIZER_1938134547151236987)],
        &[(0b01001, &ENTRY_FORMULIZES_10074978617027689565)],
        &[(0b01001, &ENTRY_FORMULIZING_613748303971363524)],
    ],
    range: 1..=12,
};

static VARS_FORE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FORE_CHILDREN),
    value: None,
};

pub static VARS_FORE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ignisation"),
        dictgen::InsensitiveStr::Ascii("ignisations"),
        dictgen::InsensitiveStr::Ascii("ignise"),
        dictgen::InsensitiveStr::Ascii("ignises"),
        dictgen::InsensitiveStr::Ascii("ignization"),
        dictgen::InsensitiveStr::Ascii("ignizations"),
        dictgen::InsensitiveStr::Ascii("ignize"),
        dictgen::InsensitiveStr::Ascii("ignizes"),
        dictgen::InsensitiveStr::Ascii("judgement"),
        dictgen::InsensitiveStr::Ascii("judgements"),
        dictgen::InsensitiveStr::Ascii("judgment"),
        dictgen::InsensitiveStr::Ascii("judgments"),
        dictgen::InsensitiveStr::Ascii("prise"),
        dictgen::InsensitiveStr::Ascii("prize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FOREIGNIZATION_15293014747107118614)],
        &[(0b10010, &ENTRY_FOREIGNIZATIONS_15541407490261464144)],
        &[(0b10010, &ENTRY_FOREIGNIZE_11198008980056672481)],
        &[(0b10010, &ENTRY_FOREIGNIZES_12119955402842918681)],
        &[(0b01001, &ENTRY_FOREIGNIZATION_15293014747107118614)],
        &[(0b01001, &ENTRY_FOREIGNIZATIONS_15541407490261464144)],
        &[(0b01001, &ENTRY_FOREIGNIZE_11198008980056672481)],
        &[(0b01001, &ENTRY_FOREIGNIZES_12119955402842918681)],
        &[(0b11010, &ENTRY_FOREJUDGMENT_9237290865507679025)],
        &[(0b11010, &ENTRY_FOREJUDGMENTS_18086623748196401092)],
        &[(0b00001, &ENTRY_FOREJUDGMENT_9237290865507679025)],
        &[(0b00001, &ENTRY_FOREJUDGMENTS_18086623748196401092)],
        &[(0b10010, &ENTRY_FOREPRIZE_15696928659273283812)],
        &[(0b01001, &ENTRY_FOREPRIZE_15696928659273283812)],
    ],
    range: 5..=11,
};

static VARS_FORC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FORC_CHILDREN),
    value: None,
};

pub static VARS_FORC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("he")],
    values: &[&[(0b00001, &ENTRY_FORCHE_1402256314253192740)]],
    range: 2..=2,
};

static VARS_FORB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FORB_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_FORB_6126634977774856175)]),
};

pub static VARS_FORB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_FOO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOO_CHILDREN),
    value: None,
};

pub static VARS_FOO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lhardise"),
        dictgen::InsensitiveStr::Ascii("lhardised"),
        dictgen::InsensitiveStr::Ascii("lhardises"),
        dictgen::InsensitiveStr::Ascii("lhardising"),
        dictgen::InsensitiveStr::Ascii("lhardize"),
        dictgen::InsensitiveStr::Ascii("lhardized"),
        dictgen::InsensitiveStr::Ascii("lhardizes"),
        dictgen::InsensitiveStr::Ascii("lhardizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FOOLHARDIZE_12653115974016256941)],
        &[(0b10010, &ENTRY_FOOLHARDIZED_11630837856384924834)],
        &[(0b10010, &ENTRY_FOOLHARDIZES_11669778763770885098)],
        &[(0b10010, &ENTRY_FOOLHARDIZING_237204071785291493)],
        &[(0b01001, &ENTRY_FOOLHARDIZE_12653115974016256941)],
        &[(0b01001, &ENTRY_FOOLHARDIZED_11630837856384924834)],
        &[(0b01001, &ENTRY_FOOLHARDIZES_11669778763770885098)],
        &[(0b01001, &ENTRY_FOOLHARDIZING_237204071785291493)],
    ],
    range: 8..=10,
};

static VARS_FON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FON_CHILDREN),
    value: None,
};

pub static VARS_FON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tanel"),
        dictgen::InsensitiveStr::Ascii("tanels"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FONTANEL_10062742686753308418)],
        &[(0b00001, &ENTRY_FONTANELS_4866743522768096750)],
    ],
    range: 5..=6,
};

static VARS_FOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOG_CHILDREN),
    value: None,
};

pub static VARS_FOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ey"),
        dictgen::InsensitiveStr::Ascii("eys"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FOGY_7754829639070054468)],
        &[(0b11010, &ENTRY_FOGIES_5940521606153956705)],
    ],
    range: 2..=3,
};

static VARS_FOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOE_CHILDREN),
    value: None,
};

pub static VARS_FOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cunditatis"),
        dictgen::InsensitiveStr::Ascii("darie"),
        dictgen::InsensitiveStr::Ascii("daries"),
        dictgen::InsensitiveStr::Ascii("tal"),
        dictgen::InsensitiveStr::Ascii("talism"),
        dictgen::InsensitiveStr::Ascii("tation"),
        dictgen::InsensitiveStr::Ascii("ticidal"),
        dictgen::InsensitiveStr::Ascii("ticide"),
        dictgen::InsensitiveStr::Ascii("ticides"),
        dictgen::InsensitiveStr::Ascii("tid"),
        dictgen::InsensitiveStr::Ascii("tider"),
        dictgen::InsensitiveStr::Ascii("tidest"),
        dictgen::InsensitiveStr::Ascii("tiferous"),
        dictgen::InsensitiveStr::Ascii("tiparous"),
        dictgen::InsensitiveStr::Ascii("tor"),
        dictgen::InsensitiveStr::Ascii("tors"),
        dictgen::InsensitiveStr::Ascii("toscopies"),
        dictgen::InsensitiveStr::Ascii("toscopy"),
        dictgen::InsensitiveStr::Ascii("ture"),
        dictgen::InsensitiveStr::Ascii("tus"),
        dictgen::InsensitiveStr::Ascii("tuses"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FECUNDITATIS_9429833736788096175)],
        &[(0b11010, &ENTRY_FEDARIE_10275114146235963561)],
        &[(0b11010, &ENTRY_FEDARIES_1925286557832729703)],
        &[(0b10010, &ENTRY_FETAL_16307774344388919965)],
        &[(0b10010, &ENTRY_FETALISM_18283011397236157925)],
        &[(0b10010, &ENTRY_FETATION_3755941875523282058)],
        &[(0b10010, &ENTRY_FETICIDAL_4949929401672725612)],
        &[(0b10010, &ENTRY_FETICIDE_15531271432046692445)],
        &[(0b10010, &ENTRY_FETICIDES_3169254784407521473)],
        &[(0b10010, &ENTRY_FETID_2099281485779081953)],
        &[(0b10010, &ENTRY_FETIDER_17182410576284038642)],
        &[(0b10010, &ENTRY_FETIDEST_14215422447438146768)],
        &[(0b11010, &ENTRY_FETIFEROUS_13556662435387579595)],
        &[(0b11010, &ENTRY_FETIPAROUS_17812808700113336448)],
        &[(0b11010, &ENTRY_FETOR_11492418604517658947)],
        &[(0b11010, &ENTRY_FETORS_9158697288365525100)],
        &[(0b11010, &ENTRY_FETOSCOPIES_11704594850300880722)],
        &[(0b11010, &ENTRY_FETOSCOPY_1200059214877142470)],
        &[(0b11010, &ENTRY_FETURE_5152410073967522436)],
        &[(0b10010, &ENTRY_FETUS_2053571947879381898)],
        &[(0b10010, &ENTRY_FETUSES_7564330503533825550)],
    ],
    range: 3..=10,
};

static VARS_FOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOC_CHILDREN),
    value: None,
};

pub static VARS_FOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FOCALIZATION_14563255569333889153)],
        &[(0b10010, &ENTRY_FOCALIZATIONS_656464172871381508)],
        &[(0b10010, &ENTRY_FOCALIZE_9001114145740139167)],
        &[(0b10010, &ENTRY_FOCALIZED_6456532754500655101)],
        &[(0b10010, &ENTRY_FOCALIZES_4692085235969656840)],
        &[(0b10010, &ENTRY_FOCALIZING_4389775854829490698)],
        &[(0b01001, &ENTRY_FOCALIZATION_14563255569333889153)],
        &[(0b01001, &ENTRY_FOCALIZATIONS_656464172871381508)],
        &[(0b01001, &ENTRY_FOCALIZE_9001114145740139167)],
        &[(0b01001, &ENTRY_FOCALIZED_6456532754500655101)],
        &[(0b01001, &ENTRY_FOCALIZES_4692085235969656840)],
        &[(0b01001, &ENTRY_FOCALIZING_4389775854829490698)],
    ],
    range: 5..=10,
};

static VARS_FL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FL_CHILDREN),
    value: None,
};

static VARS_FL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_FLA_NODE),
    None,
    None,
    None,
    Some(&VARS_FLE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FLO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FLU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_FLU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FLU_CHILDREN),
    value: None,
};

pub static VARS_FLU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("idisation"),
        dictgen::InsensitiveStr::Ascii("idisations"),
        dictgen::InsensitiveStr::Ascii("idise"),
        dictgen::InsensitiveStr::Ascii("idised"),
        dictgen::InsensitiveStr::Ascii("idiser"),
        dictgen::InsensitiveStr::Ascii("idisers"),
        dictgen::InsensitiveStr::Ascii("idises"),
        dictgen::InsensitiveStr::Ascii("idising"),
        dictgen::InsensitiveStr::Ascii("idization"),
        dictgen::InsensitiveStr::Ascii("idizations"),
        dictgen::InsensitiveStr::Ascii("idize"),
        dictgen::InsensitiveStr::Ascii("idized"),
        dictgen::InsensitiveStr::Ascii("idizer"),
        dictgen::InsensitiveStr::Ascii("idizers"),
        dictgen::InsensitiveStr::Ascii("idizes"),
        dictgen::InsensitiveStr::Ascii("idizing"),
        dictgen::InsensitiveStr::Ascii("oridisation"),
        dictgen::InsensitiveStr::Ascii("oridisations"),
        dictgen::InsensitiveStr::Ascii("oridise"),
        dictgen::InsensitiveStr::Ascii("oridised"),
        dictgen::InsensitiveStr::Ascii("oridises"),
        dictgen::InsensitiveStr::Ascii("oridising"),
        dictgen::InsensitiveStr::Ascii("oridization"),
        dictgen::InsensitiveStr::Ascii("oridizations"),
        dictgen::InsensitiveStr::Ascii("oridize"),
        dictgen::InsensitiveStr::Ascii("oridized"),
        dictgen::InsensitiveStr::Ascii("oridizes"),
        dictgen::InsensitiveStr::Ascii("oridizing"),
        dictgen::InsensitiveStr::Ascii("tist"),
        dictgen::InsensitiveStr::Ascii("tists"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FLUIDIZATION_11969565540843536522)],
        &[(0b10010, &ENTRY_FLUIDIZATIONS_5389462904710287795)],
        &[(0b10010, &ENTRY_FLUIDIZE_1455252710765083915)],
        &[(0b10010, &ENTRY_FLUIDIZED_16610704945227594739)],
        &[(0b10010, &ENTRY_FLUIDIZER_11704131419355126038)],
        &[(0b10010, &ENTRY_FLUIDIZERS_3958616063238696252)],
        &[(0b10010, &ENTRY_FLUIDIZES_406786174709282531)],
        &[(0b10010, &ENTRY_FLUIDIZING_3867188207098201511)],
        &[(0b01001, &ENTRY_FLUIDIZATION_11969565540843536522)],
        &[(0b01001, &ENTRY_FLUIDIZATIONS_5389462904710287795)],
        &[(0b01001, &ENTRY_FLUIDIZE_1455252710765083915)],
        &[(0b01001, &ENTRY_FLUIDIZED_16610704945227594739)],
        &[(0b01001, &ENTRY_FLUIDIZER_11704131419355126038)],
        &[(0b01001, &ENTRY_FLUIDIZERS_3958616063238696252)],
        &[(0b01001, &ENTRY_FLUIDIZES_406786174709282531)],
        &[(0b01001, &ENTRY_FLUIDIZING_3867188207098201511)],
        &[(0b10010, &ENTRY_FLUORIDIZATION_1280860877521174385)],
        &[(0b10010, &ENTRY_FLUORIDIZATIONS_11927169473008860358)],
        &[(0b10010, &ENTRY_FLUORIDIZE_16455851797679281502)],
        &[(0b10010, &ENTRY_FLUORIDIZED_1588370394858922120)],
        &[(0b10010, &ENTRY_FLUORIDIZES_3296309858810834391)],
        &[(0b10010, &ENTRY_FLUORIDIZING_12894945638877400542)],
        &[(0b01001, &ENTRY_FLUORIDIZATION_1280860877521174385)],
        &[(0b01001, &ENTRY_FLUORIDIZATIONS_11927169473008860358)],
        &[(0b01001, &ENTRY_FLUORIDIZE_16455851797679281502)],
        &[(0b01001, &ENTRY_FLUORIDIZED_1588370394858922120)],
        &[(0b01001, &ENTRY_FLUORIDIZES_3296309858810834391)],
        &[(0b01001, &ENTRY_FLUORIDIZING_12894945638877400542)],
        &[(0b01001, &ENTRY_FLUTIST_8416620116439104202)],
        &[(0b01001, &ENTRY_FLUTISTS_1304316840696127041)],
    ],
    range: 4..=12,
};

static VARS_FLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FLO_CHILDREN),
    value: None,
};

pub static VARS_FLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ramor"),
        dictgen::InsensitiveStr::Ascii("ramour"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FLORALIZE_1627350310190043452)],
        &[(0b10010, &ENTRY_FLORALIZES_9002365200591546886)],
        &[(0b01001, &ENTRY_FLORALIZE_1627350310190043452)],
        &[(0b01001, &ENTRY_FLORALIZES_9002365200591546886)],
        &[(0b00001, &ENTRY_FLORAMOR_16582942827359883333)],
        &[(0b11010, &ENTRY_FLORAMOR_16582942827359883333)],
    ],
    range: 5..=7,
};

static VARS_FLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FLE_CHILDREN),
    value: None,
};

pub static VARS_FLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dgeling"),
        dictgen::InsensitiveStr::Ascii("dgelings"),
        dictgen::InsensitiveStr::Ascii("tcherise"),
        dictgen::InsensitiveStr::Ascii("tcherised"),
        dictgen::InsensitiveStr::Ascii("tcherises"),
        dictgen::InsensitiveStr::Ascii("tcherising"),
        dictgen::InsensitiveStr::Ascii("tcherize"),
        dictgen::InsensitiveStr::Ascii("tcherized"),
        dictgen::InsensitiveStr::Ascii("tcherizes"),
        dictgen::InsensitiveStr::Ascii("tcherizing"),
    ],
    values: &[
        &[(0b10011, &ENTRY_FLEDGLING_7994074526705315877)],
        &[(0b10011, &ENTRY_FLEDGLINGS_13590009262290363932)],
        &[(0b10010, &ENTRY_FLETCHERIZE_2938326935179785107)],
        &[(0b10010, &ENTRY_FLETCHERIZED_13650083698674644519)],
        &[(0b10010, &ENTRY_FLETCHERIZES_11092269357737681439)],
        &[(0b10010, &ENTRY_FLETCHERIZING_2070710165649975625)],
        &[(0b01001, &ENTRY_FLETCHERIZE_2938326935179785107)],
        &[(0b01001, &ENTRY_FLETCHERIZED_13650083698674644519)],
        &[(0b01001, &ENTRY_FLETCHERIZES_11092269357737681439)],
        &[(0b01001, &ENTRY_FLETCHERIZING_2070710165649975625)],
    ],
    range: 7..=10,
};

static VARS_FLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FLA_CHILDREN),
    value: None,
};

pub static VARS_FLA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mboyantise"),
        dictgen::InsensitiveStr::Ascii("mboyantises"),
        dictgen::InsensitiveStr::Ascii("mboyantize"),
        dictgen::InsensitiveStr::Ascii("mboyantizes"),
        dictgen::InsensitiveStr::Ascii("nneled"),
        dictgen::InsensitiveStr::Ascii("nnelet"),
        dictgen::InsensitiveStr::Ascii("nneling"),
        dictgen::InsensitiveStr::Ascii("nnelled"),
        dictgen::InsensitiveStr::Ascii("nnelling"),
        dictgen::InsensitiveStr::Ascii("utist"),
        dictgen::InsensitiveStr::Ascii("utists"),
        dictgen::InsensitiveStr::Ascii("vor"),
        dictgen::InsensitiveStr::Ascii("vored"),
        dictgen::InsensitiveStr::Ascii("vorer"),
        dictgen::InsensitiveStr::Ascii("vorers"),
        dictgen::InsensitiveStr::Ascii("vorful"),
        dictgen::InsensitiveStr::Ascii("vorfuler"),
        dictgen::InsensitiveStr::Ascii("vorfulest"),
        dictgen::InsensitiveStr::Ascii("vorfullier"),
        dictgen::InsensitiveStr::Ascii("vorfulliest"),
        dictgen::InsensitiveStr::Ascii("vorfully"),
        dictgen::InsensitiveStr::Ascii("vorier"),
        dictgen::InsensitiveStr::Ascii("voriest"),
        dictgen::InsensitiveStr::Ascii("voring"),
        dictgen::InsensitiveStr::Ascii("vorings"),
        dictgen::InsensitiveStr::Ascii("vorless"),
        dictgen::InsensitiveStr::Ascii("vorlesser"),
        dictgen::InsensitiveStr::Ascii("vorlesses"),
        dictgen::InsensitiveStr::Ascii("vorlessest"),
        dictgen::InsensitiveStr::Ascii("vors"),
        dictgen::InsensitiveStr::Ascii("vorsome"),
        dictgen::InsensitiveStr::Ascii("vorsomer"),
        dictgen::InsensitiveStr::Ascii("vorsomest"),
        dictgen::InsensitiveStr::Ascii("vory"),
        dictgen::InsensitiveStr::Ascii("vour"),
        dictgen::InsensitiveStr::Ascii("voured"),
        dictgen::InsensitiveStr::Ascii("vourer"),
        dictgen::InsensitiveStr::Ascii("vourers"),
        dictgen::InsensitiveStr::Ascii("vourful"),
        dictgen::InsensitiveStr::Ascii("vourfuler"),
        dictgen::InsensitiveStr::Ascii("vourfulest"),
        dictgen::InsensitiveStr::Ascii("vourfullier"),
        dictgen::InsensitiveStr::Ascii("vourfulliest"),
        dictgen::InsensitiveStr::Ascii("vourfully"),
        dictgen::InsensitiveStr::Ascii("vourier"),
        dictgen::InsensitiveStr::Ascii("vouriest"),
        dictgen::InsensitiveStr::Ascii("vouring"),
        dictgen::InsensitiveStr::Ascii("vourings"),
        dictgen::InsensitiveStr::Ascii("vourless"),
        dictgen::InsensitiveStr::Ascii("vourlesser"),
        dictgen::InsensitiveStr::Ascii("vourlesses"),
        dictgen::InsensitiveStr::Ascii("vourlessest"),
        dictgen::InsensitiveStr::Ascii("vourous"),
        dictgen::InsensitiveStr::Ascii("vours"),
        dictgen::InsensitiveStr::Ascii("voursome"),
        dictgen::InsensitiveStr::Ascii("voursomer"),
        dictgen::InsensitiveStr::Ascii("voursomest"),
        dictgen::InsensitiveStr::Ascii("voury"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FLAMBOYANTIZE_10739085749969945339)],
        &[(0b10010, &ENTRY_FLAMBOYANTIZES_3390037775777669851)],
        &[(0b01001, &ENTRY_FLAMBOYANTIZE_10739085749969945339)],
        &[(0b01001, &ENTRY_FLAMBOYANTIZES_3390037775777669851)],
        &[(0b01001, &ENTRY_FLANNELED_3360043852230682699)],
        &[(0b00001, &ENTRY_FLANNELETTE_12069498104014004076)],
        &[(0b01001, &ENTRY_FLANNELING_4012495315920627349)],
        &[(0b11010, &ENTRY_FLANNELED_3360043852230682699)],
        &[(0b11010, &ENTRY_FLANNELING_4012495315920627349)],
        &[(0b11010, &ENTRY_FLUTIST_8416620116439104202)],
        &[(0b11010, &ENTRY_FLUTISTS_1304316840696127041)],
        &[(0b11001, &ENTRY_FLAVOR_13147746738852786676)],
        &[(0b11001, &ENTRY_FLAVORED_5627247048743299150)],
        &[(0b11001, &ENTRY_FLAVORER_4047795277880865277)],
        &[(0b11001, &ENTRY_FLAVORERS_11272413788636554077)],
        &[(0b11001, &ENTRY_FLAVORFUL_5944085188485911509)],
        &[(0b11001, &ENTRY_FLAVORFULER_6696273803305785559)],
        &[(0b11001, &ENTRY_FLAVORFULEST_11637668202952292143)],
        &[(0b11001, &ENTRY_FLAVORFULLIER_4653961700222736607)],
        &[(0b11001, &ENTRY_FLAVORFULLIEST_1942998500709732048)],
        &[(0b11001, &ENTRY_FLAVORFULLY_7477538950157672595)],
        &[(0b11001, &ENTRY_FLAVORIER_14486196458812907070)],
        &[(0b11001, &ENTRY_FLAVORIEST_9321543981933061232)],
        &[(0b11001, &ENTRY_FLAVORING_1040976265495793448)],
        &[(0b11001, &ENTRY_FLAVORINGS_4333914468476562312)],
        &[(0b11001, &ENTRY_FLAVORLESS_11245042299561592850)],
        &[(0b11001, &ENTRY_FLAVORLESSER_6704080193000679945)],
        &[(0b11001, &ENTRY_FLAVORLESSES_328096443616320440)],
        &[(0b11001, &ENTRY_FLAVORLESSEST_5257507821497526035)],
        &[(0b11001, &ENTRY_FLAVORS_7502432271130276472)],
        &[(0b11001, &ENTRY_FLAVORSOME_3715740836293625146)],
        &[(0b11001, &ENTRY_FLAVORSOMER_9283046503206827837)],
        &[(0b11001, &ENTRY_FLAVORSOMEST_15528669799121213414)],
        &[(0b11001, &ENTRY_FLAVORY_5581256405708500009)],
        &[(0b11010, &ENTRY_FLAVOR_13147746738852786676)],
        &[(0b11010, &ENTRY_FLAVORED_5627247048743299150)],
        &[(0b11010, &ENTRY_FLAVORER_4047795277880865277)],
        &[(0b11010, &ENTRY_FLAVORERS_11272413788636554077)],
        &[(0b11010, &ENTRY_FLAVORFUL_5944085188485911509)],
        &[(0b11010, &ENTRY_FLAVORFULER_6696273803305785559)],
        &[(0b11010, &ENTRY_FLAVORFULEST_11637668202952292143)],
        &[(0b11010, &ENTRY_FLAVORFULLIER_4653961700222736607)],
        &[(0b11010, &ENTRY_FLAVORFULLIEST_1942998500709732048)],
        &[(0b11010, &ENTRY_FLAVORFULLY_7477538950157672595)],
        &[(0b11010, &ENTRY_FLAVORIER_14486196458812907070)],
        &[(0b11010, &ENTRY_FLAVORIEST_9321543981933061232)],
        &[(0b11010, &ENTRY_FLAVORING_1040976265495793448)],
        &[(0b11010, &ENTRY_FLAVORINGS_4333914468476562312)],
        &[(0b11010, &ENTRY_FLAVORLESS_11245042299561592850)],
        &[(0b11010, &ENTRY_FLAVORLESSER_6704080193000679945)],
        &[(0b11010, &ENTRY_FLAVORLESSES_328096443616320440)],
        &[(0b11010, &ENTRY_FLAVORLESSEST_5257507821497526035)],
        &[(0b11010, &ENTRY_FLAVOROUS_16069319827243586679)],
        &[(0b11010, &ENTRY_FLAVORS_7502432271130276472)],
        &[(0b11010, &ENTRY_FLAVORSOME_3715740836293625146)],
        &[(0b11010, &ENTRY_FLAVORSOMER_9283046503206827837)],
        &[(0b11010, &ENTRY_FLAVORSOMEST_15528669799121213414)],
        &[(0b11010, &ENTRY_FLAVORY_5581256405708500009)],
    ],
    range: 3..=12,
};

static VARS_FI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FI_CHILDREN),
    value: None,
};

static VARS_FI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_FIB_NODE),
    Some(&VARS_FIC_NODE),
    None,
    None,
    None,
    Some(&VARS_FIG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_FIL_NODE),
    None,
    Some(&VARS_FIN_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_FIS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_FIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FIS_CHILDREN),
    value: None,
};

pub static VARS_FIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("calisation"),
        dictgen::InsensitiveStr::Ascii("calisations"),
        dictgen::InsensitiveStr::Ascii("calise"),
        dictgen::InsensitiveStr::Ascii("calises"),
        dictgen::InsensitiveStr::Ascii("calization"),
        dictgen::InsensitiveStr::Ascii("calizations"),
        dictgen::InsensitiveStr::Ascii("calize"),
        dictgen::InsensitiveStr::Ascii("calizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FISCALIZATION_15214196836508290213)],
        &[(0b10010, &ENTRY_FISCALIZATIONS_15013088357283335917)],
        &[(0b10010, &ENTRY_FISCALIZE_12383058975332866270)],
        &[(0b10010, &ENTRY_FISCALIZES_17651635012695062469)],
        &[(0b01001, &ENTRY_FISCALIZATION_15214196836508290213)],
        &[(0b01001, &ENTRY_FISCALIZATIONS_15013088357283335917)],
        &[(0b01001, &ENTRY_FISCALIZE_12383058975332866270)],
        &[(0b01001, &ENTRY_FISCALIZES_17651635012695062469)],
    ],
    range: 6..=11,
};

static VARS_FIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FIN_CHILDREN),
    value: None,
};

pub static VARS_FIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("landisation"),
        dictgen::InsensitiveStr::Ascii("landisations"),
        dictgen::InsensitiveStr::Ascii("landization"),
        dictgen::InsensitiveStr::Ascii("landizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FINALIZATION_1713663724954282799)],
        &[(0b10010, &ENTRY_FINALIZATIONS_8331454203854375513)],
        &[(0b10010, &ENTRY_FINALIZE_6361287847222643044)],
        &[(0b10010, &ENTRY_FINALIZED_12365738080071899916)],
        &[(0b10010, &ENTRY_FINALIZES_10983321682404972812)],
        &[(0b10010, &ENTRY_FINALIZING_10636713064978874210)],
        &[(0b01001, &ENTRY_FINALIZATION_1713663724954282799)],
        &[(0b01001, &ENTRY_FINALIZATIONS_8331454203854375513)],
        &[(0b01001, &ENTRY_FINALIZE_6361287847222643044)],
        &[(0b01001, &ENTRY_FINALIZED_12365738080071899916)],
        &[(0b01001, &ENTRY_FINALIZES_10983321682404972812)],
        &[(0b01001, &ENTRY_FINALIZING_10636713064978874210)],
        &[(0b10010, &ENTRY_FINLANDIZATION_17456639156502306653)],
        &[(0b10010, &ENTRY_FINLANDIZATIONS_10327954352032319026)],
        &[(0b01001, &ENTRY_FINLANDIZATION_17456639156502306653)],
        &[(0b01001, &ENTRY_FINLANDIZATIONS_10327954352032319026)],
    ],
    range: 5..=12,
};

static VARS_FIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FIL_CHILDREN),
    value: None,
};

pub static VARS_FIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mise"),
        dictgen::InsensitiveStr::Ascii("mises"),
        dictgen::InsensitiveStr::Ascii("mize"),
        dictgen::InsensitiveStr::Ascii("mizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FILMIZE_7748638805888929688)],
        &[(0b10010, &ENTRY_FILMIZES_8443731642258725255)],
        &[(0b01001, &ENTRY_FILMIZE_7748638805888929688)],
        &[(0b01001, &ENTRY_FILMIZES_8443731642258725255)],
    ],
    range: 4..=5,
};

static VARS_FIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FIG_CHILDREN),
    value: None,
};

pub static VARS_FIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("urise"),
        dictgen::InsensitiveStr::Ascii("urises"),
        dictgen::InsensitiveStr::Ascii("urize"),
        dictgen::InsensitiveStr::Ascii("urizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FIGURIZE_10842730720774474303)],
        &[(0b10010, &ENTRY_FIGURIZES_12804465356162412728)],
        &[(0b01001, &ENTRY_FIGURIZE_10842730720774474303)],
        &[(0b01001, &ENTRY_FIGURIZES_12804465356162412728)],
    ],
    range: 5..=6,
};

static VARS_FIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FIC_CHILDREN),
    value: None,
};

pub static VARS_FIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tionalisation"),
        dictgen::InsensitiveStr::Ascii("tionalisations"),
        dictgen::InsensitiveStr::Ascii("tionalise"),
        dictgen::InsensitiveStr::Ascii("tionalised"),
        dictgen::InsensitiveStr::Ascii("tionalises"),
        dictgen::InsensitiveStr::Ascii("tionalising"),
        dictgen::InsensitiveStr::Ascii("tionalization"),
        dictgen::InsensitiveStr::Ascii("tionalizations"),
        dictgen::InsensitiveStr::Ascii("tionalize"),
        dictgen::InsensitiveStr::Ascii("tionalized"),
        dictgen::InsensitiveStr::Ascii("tionalizes"),
        dictgen::InsensitiveStr::Ascii("tionalizing"),
        dictgen::InsensitiveStr::Ascii("tionisation"),
        dictgen::InsensitiveStr::Ascii("tionisations"),
        dictgen::InsensitiveStr::Ascii("tionise"),
        dictgen::InsensitiveStr::Ascii("tionised"),
        dictgen::InsensitiveStr::Ascii("tionises"),
        dictgen::InsensitiveStr::Ascii("tionising"),
        dictgen::InsensitiveStr::Ascii("tionization"),
        dictgen::InsensitiveStr::Ascii("tionizations"),
        dictgen::InsensitiveStr::Ascii("tionize"),
        dictgen::InsensitiveStr::Ascii("tionized"),
        dictgen::InsensitiveStr::Ascii("tionizes"),
        dictgen::InsensitiveStr::Ascii("tionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FICTIONALIZATION_5522094113122146310)],
        &[(0b10010, &ENTRY_FICTIONALIZATIONS_14516051539943227290)],
        &[(0b10010, &ENTRY_FICTIONALIZE_16577222807187796806)],
        &[(0b10010, &ENTRY_FICTIONALIZED_15741748969425662890)],
        &[(0b10010, &ENTRY_FICTIONALIZES_13772431052894991620)],
        &[(0b10010, &ENTRY_FICTIONALIZING_1062972705175871031)],
        &[(0b01001, &ENTRY_FICTIONALIZATION_5522094113122146310)],
        &[(0b01001, &ENTRY_FICTIONALIZATIONS_14516051539943227290)],
        &[(0b01001, &ENTRY_FICTIONALIZE_16577222807187796806)],
        &[(0b01001, &ENTRY_FICTIONALIZED_15741748969425662890)],
        &[(0b01001, &ENTRY_FICTIONALIZES_13772431052894991620)],
        &[(0b01001, &ENTRY_FICTIONALIZING_1062972705175871031)],
        &[(0b10010, &ENTRY_FICTIONIZATION_14666995530197436361)],
        &[(0b10010, &ENTRY_FICTIONIZATIONS_9671751322318154200)],
        &[(0b10010, &ENTRY_FICTIONIZE_17995007159313813172)],
        &[(0b10010, &ENTRY_FICTIONIZED_6877756002854005504)],
        &[(0b10010, &ENTRY_FICTIONIZES_725473241634804856)],
        &[(0b10010, &ENTRY_FICTIONIZING_7115796450699434396)],
        &[(0b01001, &ENTRY_FICTIONIZATION_14666995530197436361)],
        &[(0b01001, &ENTRY_FICTIONIZATIONS_9671751322318154200)],
        &[(0b01001, &ENTRY_FICTIONIZE_17995007159313813172)],
        &[(0b01001, &ENTRY_FICTIONIZED_6877756002854005504)],
        &[(0b01001, &ENTRY_FICTIONIZES_725473241634804856)],
        &[(0b01001, &ENTRY_FICTIONIZING_7115796450699434396)],
    ],
    range: 7..=14,
};

static VARS_FIB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FIB_CHILDREN),
    value: None,
};

pub static VARS_FIB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("erboard"),
        dictgen::InsensitiveStr::Ascii("erboards"),
        dictgen::InsensitiveStr::Ascii("ered"),
        dictgen::InsensitiveStr::Ascii("erfill"),
        dictgen::InsensitiveStr::Ascii("erfills"),
        dictgen::InsensitiveStr::Ascii("erglass"),
        dictgen::InsensitiveStr::Ascii("erglasses"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizer"),
        dictgen::InsensitiveStr::Ascii("erizers"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("erizing"),
        dictgen::InsensitiveStr::Ascii("erless"),
        dictgen::InsensitiveStr::Ascii("erlesser"),
        dictgen::InsensitiveStr::Ascii("erlesses"),
        dictgen::InsensitiveStr::Ascii("erlessest"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("erscope"),
        dictgen::InsensitiveStr::Ascii("erscopes"),
        dictgen::InsensitiveStr::Ascii("erware"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("reboard"),
        dictgen::InsensitiveStr::Ascii("reboards"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("refill"),
        dictgen::InsensitiveStr::Ascii("refills"),
        dictgen::InsensitiveStr::Ascii("reglass"),
        dictgen::InsensitiveStr::Ascii("reglasses"),
        dictgen::InsensitiveStr::Ascii("reless"),
        dictgen::InsensitiveStr::Ascii("relesser"),
        dictgen::InsensitiveStr::Ascii("relesses"),
        dictgen::InsensitiveStr::Ascii("relessest"),
        dictgen::InsensitiveStr::Ascii("res"),
        dictgen::InsensitiveStr::Ascii("rescope"),
        dictgen::InsensitiveStr::Ascii("rescopes"),
        dictgen::InsensitiveStr::Ascii("reware"),
        dictgen::InsensitiveStr::Ascii("risation"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("riser"),
        dictgen::InsensitiveStr::Ascii("risers"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rization"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizer"),
        dictgen::InsensitiveStr::Ascii("rizers"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FIBER_7952077420634658656)],
        &[(0b00001, &ENTRY_FIBERBOARD_9088608551824916909)],
        &[(0b00001, &ENTRY_FIBERBOARDS_12731975045296410883)],
        &[(0b00001, &ENTRY_FIBERED_3749994473310829181)],
        &[(0b00001, &ENTRY_FIBERFILL_13606310046445718422)],
        &[(0b00001, &ENTRY_FIBERFILLS_6447949254246220216)],
        &[(0b00001, &ENTRY_FIBERGLASS_7810341362649925221)],
        &[(0b00001, &ENTRY_FIBERGLASSES_3971392659490472340)],
        &[(0b00001, &ENTRY_FIBERIZATION_6937225594278445561)],
        &[(0b00001, &ENTRY_FIBERIZE_10547163902572294158)],
        &[(0b00001, &ENTRY_FIBERIZED_3905865692011292572)],
        &[(0b00001, &ENTRY_FIBERIZER_15259065220998459171)],
        &[(0b00001, &ENTRY_FIBERIZERS_11226216140488375203)],
        &[(0b00001, &ENTRY_FIBERIZES_2275756906782580740)],
        &[(0b00001, &ENTRY_FIBERIZING_5446627689124345883)],
        &[(0b00001, &ENTRY_FIBERLESS_12969055159511376893)],
        &[(0b00001, &ENTRY_FIBERLESSER_4551498916657548546)],
        &[(0b00001, &ENTRY_FIBERLESSES_14283109333657558421)],
        &[(0b00001, &ENTRY_FIBERLESSEST_14496238235310789976)],
        &[(0b00001, &ENTRY_FIBERS_1646201480676499010)],
        &[(0b00001, &ENTRY_FIBERSCOPE_1314789335244812695)],
        &[(0b00001, &ENTRY_FIBERSCOPES_17873202834856042126)],
        &[(0b00001, &ENTRY_FIBERWARE_4803374303826557107)],
        &[(0b11010, &ENTRY_FIBER_7952077420634658656)],
        &[(0b11010, &ENTRY_FIBERBOARD_9088608551824916909)],
        &[(0b11010, &ENTRY_FIBERBOARDS_12731975045296410883)],
        &[(0b11010, &ENTRY_FIBERED_3749994473310829181)],
        &[(0b11010, &ENTRY_FIBERFILL_13606310046445718422)],
        &[(0b11010, &ENTRY_FIBERFILLS_6447949254246220216)],
        &[(0b11010, &ENTRY_FIBERGLASS_7810341362649925221)],
        &[(0b11010, &ENTRY_FIBERGLASSES_3971392659490472340)],
        &[(0b11010, &ENTRY_FIBERLESS_12969055159511376893)],
        &[(0b11010, &ENTRY_FIBERLESSER_4551498916657548546)],
        &[(0b11010, &ENTRY_FIBERLESSES_14283109333657558421)],
        &[(0b11010, &ENTRY_FIBERLESSEST_14496238235310789976)],
        &[(0b11010, &ENTRY_FIBERS_1646201480676499010)],
        &[(0b11010, &ENTRY_FIBERSCOPE_1314789335244812695)],
        &[(0b11010, &ENTRY_FIBERSCOPES_17873202834856042126)],
        &[(0b11010, &ENTRY_FIBERWARE_4803374303826557107)],
        &[(0b10010, &ENTRY_FIBERIZATION_6937225594278445561)],
        &[(0b10010, &ENTRY_FIBERIZE_10547163902572294158)],
        &[(0b10010, &ENTRY_FIBERIZED_3905865692011292572)],
        &[(0b10010, &ENTRY_FIBERIZER_15259065220998459171)],
        &[(0b10010, &ENTRY_FIBERIZERS_11226216140488375203)],
        &[(0b10010, &ENTRY_FIBERIZES_2275756906782580740)],
        &[(0b10010, &ENTRY_FIBERIZING_5446627689124345883)],
        &[(0b01000, &ENTRY_FIBERIZATION_6937225594278445561)],
        &[(0b01000, &ENTRY_FIBERIZE_10547163902572294158)],
        &[(0b01000, &ENTRY_FIBERIZED_3905865692011292572)],
        &[(0b01000, &ENTRY_FIBERIZER_15259065220998459171)],
        &[(0b01000, &ENTRY_FIBERIZERS_11226216140488375203)],
        &[(0b01000, &ENTRY_FIBERIZES_2275756906782580740)],
        &[(0b01000, &ENTRY_FIBERIZING_5446627689124345883)],
    ],
    range: 2..=9,
};

static VARS_FE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_FE_11063702362937317781)]),
};

static VARS_FE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_FEC_NODE),
    Some(&VARS_FED_NODE),
    Some(&VARS_FEE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FEM_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_FER_NODE),
    None,
    Some(&VARS_FET_NODE),
    Some(&VARS_FEU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_FEU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FEU_CHILDREN),
    value: None,
};

pub static VARS_FEU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dalisable"),
        dictgen::InsensitiveStr::Ascii("dalisables"),
        dictgen::InsensitiveStr::Ascii("dalisation"),
        dictgen::InsensitiveStr::Ascii("dalisations"),
        dictgen::InsensitiveStr::Ascii("dalise"),
        dictgen::InsensitiveStr::Ascii("dalised"),
        dictgen::InsensitiveStr::Ascii("dalises"),
        dictgen::InsensitiveStr::Ascii("dalising"),
        dictgen::InsensitiveStr::Ascii("dalizable"),
        dictgen::InsensitiveStr::Ascii("dalizables"),
        dictgen::InsensitiveStr::Ascii("dalization"),
        dictgen::InsensitiveStr::Ascii("dalizations"),
        dictgen::InsensitiveStr::Ascii("dalize"),
        dictgen::InsensitiveStr::Ascii("dalized"),
        dictgen::InsensitiveStr::Ascii("dalizes"),
        dictgen::InsensitiveStr::Ascii("dalizing"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FEUDALIZABLE_733725314620977609)],
        &[(0b10010, &ENTRY_FEUDALIZABLES_13435612370533078763)],
        &[(0b10010, &ENTRY_FEUDALIZATION_13206467807460475478)],
        &[(0b10010, &ENTRY_FEUDALIZATIONS_4332973819048848881)],
        &[(0b10010, &ENTRY_FEUDALIZE_8804974376593972508)],
        &[(0b10010, &ENTRY_FEUDALIZED_3960451703311684463)],
        &[(0b10010, &ENTRY_FEUDALIZES_9574302614295101534)],
        &[(0b10010, &ENTRY_FEUDALIZING_15709230783384439087)],
        &[(0b01001, &ENTRY_FEUDALIZABLE_733725314620977609)],
        &[(0b01001, &ENTRY_FEUDALIZABLES_13435612370533078763)],
        &[(0b01001, &ENTRY_FEUDALIZATION_13206467807460475478)],
        &[(0b01001, &ENTRY_FEUDALIZATIONS_4332973819048848881)],
        &[(0b01001, &ENTRY_FEUDALIZE_8804974376593972508)],
        &[(0b01001, &ENTRY_FEUDALIZED_3960451703311684463)],
        &[(0b01001, &ENTRY_FEUDALIZES_9574302614295101534)],
        &[(0b01001, &ENTRY_FEUDALIZING_15709230783384439087)],
        &[(0b00001, &ENTRY_FEUTER_9289342288875733939)],
        &[(0b11010, &ENTRY_FEUTER_9289342288875733939)],
    ],
    range: 3..=11,
};

static VARS_FET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FET_CHILDREN),
    value: None,
};

pub static VARS_FET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ich"),
        dictgen::InsensitiveStr::Ascii("iches"),
        dictgen::InsensitiveStr::Ascii("ichise"),
        dictgen::InsensitiveStr::Ascii("ichised"),
        dictgen::InsensitiveStr::Ascii("ichises"),
        dictgen::InsensitiveStr::Ascii("ichising"),
        dictgen::InsensitiveStr::Ascii("ichize"),
        dictgen::InsensitiveStr::Ascii("ichized"),
        dictgen::InsensitiveStr::Ascii("ichizes"),
        dictgen::InsensitiveStr::Ascii("ichizing"),
        dictgen::InsensitiveStr::Ascii("iferous"),
        dictgen::InsensitiveStr::Ascii("iparous"),
        dictgen::InsensitiveStr::Ascii("ishisation"),
        dictgen::InsensitiveStr::Ascii("ishisations"),
        dictgen::InsensitiveStr::Ascii("ishise"),
        dictgen::InsensitiveStr::Ascii("ishised"),
        dictgen::InsensitiveStr::Ascii("ishises"),
        dictgen::InsensitiveStr::Ascii("ishising"),
        dictgen::InsensitiveStr::Ascii("ishization"),
        dictgen::InsensitiveStr::Ascii("ishizations"),
        dictgen::InsensitiveStr::Ascii("ishize"),
        dictgen::InsensitiveStr::Ascii("ishized"),
        dictgen::InsensitiveStr::Ascii("ishizes"),
        dictgen::InsensitiveStr::Ascii("ishizing"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("oscopies"),
        dictgen::InsensitiveStr::Ascii("oscopy"),
        dictgen::InsensitiveStr::Ascii("ure"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FETISH_14617370190649429983)],
        &[(0b00001, &ENTRY_FETISHES_1240063895948325551)],
        &[(0b10010, &ENTRY_FETICHIZE_6432031967305267018)],
        &[(0b10010, &ENTRY_FETICHIZED_2938251164879304848)],
        &[(0b10010, &ENTRY_FETICHIZES_14431439308759435147)],
        &[(0b10010, &ENTRY_FETICHIZING_18164181749916704128)],
        &[(0b01001, &ENTRY_FETICHIZE_6432031967305267018)],
        &[(0b01001, &ENTRY_FETICHIZED_2938251164879304848)],
        &[(0b01001, &ENTRY_FETICHIZES_14431439308759435147)],
        &[(0b01001, &ENTRY_FETICHIZING_18164181749916704128)],
        &[(0b00001, &ENTRY_FETIFEROUS_13556662435387579595)],
        &[(0b00001, &ENTRY_FETIPAROUS_17812808700113336448)],
        &[(0b10010, &ENTRY_FETISHIZATION_4962686785593207593)],
        &[(0b10010, &ENTRY_FETISHIZATIONS_9301033175433278712)],
        &[(0b10010, &ENTRY_FETISHIZE_6082865116524316715)],
        &[(0b10010, &ENTRY_FETISHIZED_12560577434053979687)],
        &[(0b10010, &ENTRY_FETISHIZES_3112865798662538909)],
        &[(0b10010, &ENTRY_FETISHIZING_3869827553555002799)],
        &[(0b01001, &ENTRY_FETISHIZATION_4962686785593207593)],
        &[(0b01001, &ENTRY_FETISHIZATIONS_9301033175433278712)],
        &[(0b01001, &ENTRY_FETISHIZE_6082865116524316715)],
        &[(0b01001, &ENTRY_FETISHIZED_12560577434053979687)],
        &[(0b01001, &ENTRY_FETISHIZES_3112865798662538909)],
        &[(0b01001, &ENTRY_FETISHIZING_3869827553555002799)],
        &[(0b00001, &ENTRY_FETOR_11492418604517658947)],
        &[(0b00001, &ENTRY_FETORS_9158697288365525100)],
        &[(0b00001, &ENTRY_FETOSCOPIES_11704594850300880722)],
        &[(0b00001, &ENTRY_FETOSCOPY_1200059214877142470)],
        &[(0b00001, &ENTRY_FETURE_5152410073967522436)],
    ],
    range: 2..=11,
};

static VARS_FER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FER_CHILDREN),
    value: None,
};

pub static VARS_FER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("iae"),
        dictgen::InsensitiveStr::Ascii("ie"),
        dictgen::InsensitiveStr::Ascii("ity"),
        dictgen::InsensitiveStr::Ascii("neau"),
        dictgen::InsensitiveStr::Ascii("reled"),
        dictgen::InsensitiveStr::Ascii("reling"),
        dictgen::InsensitiveStr::Ascii("relled"),
        dictgen::InsensitiveStr::Ascii("relling"),
        dictgen::InsensitiveStr::Ascii("ritisation"),
        dictgen::InsensitiveStr::Ascii("ritisations"),
        dictgen::InsensitiveStr::Ascii("ritization"),
        dictgen::InsensitiveStr::Ascii("ritizations"),
        dictgen::InsensitiveStr::Ascii("tilisability"),
        dictgen::InsensitiveStr::Ascii("tilisable"),
        dictgen::InsensitiveStr::Ascii("tilisabler"),
        dictgen::InsensitiveStr::Ascii("tilisables"),
        dictgen::InsensitiveStr::Ascii("tilisablest"),
        dictgen::InsensitiveStr::Ascii("tilisation"),
        dictgen::InsensitiveStr::Ascii("tilisational"),
        dictgen::InsensitiveStr::Ascii("tilisationaler"),
        dictgen::InsensitiveStr::Ascii("tilisationalest"),
        dictgen::InsensitiveStr::Ascii("tilisationals"),
        dictgen::InsensitiveStr::Ascii("tilisations"),
        dictgen::InsensitiveStr::Ascii("tilise"),
        dictgen::InsensitiveStr::Ascii("tilised"),
        dictgen::InsensitiveStr::Ascii("tiliser"),
        dictgen::InsensitiveStr::Ascii("tilisers"),
        dictgen::InsensitiveStr::Ascii("tilises"),
        dictgen::InsensitiveStr::Ascii("tilising"),
        dictgen::InsensitiveStr::Ascii("tilizability"),
        dictgen::InsensitiveStr::Ascii("tilizable"),
        dictgen::InsensitiveStr::Ascii("tilizabler"),
        dictgen::InsensitiveStr::Ascii("tilizables"),
        dictgen::InsensitiveStr::Ascii("tilizablest"),
        dictgen::InsensitiveStr::Ascii("tilization"),
        dictgen::InsensitiveStr::Ascii("tilizational"),
        dictgen::InsensitiveStr::Ascii("tilizationaler"),
        dictgen::InsensitiveStr::Ascii("tilizationalest"),
        dictgen::InsensitiveStr::Ascii("tilizationals"),
        dictgen::InsensitiveStr::Ascii("tilizations"),
        dictgen::InsensitiveStr::Ascii("tilize"),
        dictgen::InsensitiveStr::Ascii("tilized"),
        dictgen::InsensitiveStr::Ascii("tilizer"),
        dictgen::InsensitiveStr::Ascii("tilizers"),
        dictgen::InsensitiveStr::Ascii("tilizes"),
        dictgen::InsensitiveStr::Ascii("tilizing"),
        dictgen::InsensitiveStr::Ascii("vor"),
        dictgen::InsensitiveStr::Ascii("vorless"),
        dictgen::InsensitiveStr::Ascii("vorlesses"),
        dictgen::InsensitiveStr::Ascii("vors"),
        dictgen::InsensitiveStr::Ascii("vour"),
        dictgen::InsensitiveStr::Ascii("vourless"),
        dictgen::InsensitiveStr::Ascii("vourlesses"),
        dictgen::InsensitiveStr::Ascii("vours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FERALIZED_9401556350923512546)],
        &[(0b01001, &ENTRY_FERALIZED_9401556350923512546)],
        &[(0b00001, &ENTRY_FERD_14446691116670344833)],
        &[(0b11010, &ENTRY_FEER_1952217434418698536)],
        &[(0b11010, &ENTRY_FEERS_12963342733000822691)],
        &[(0b11010, &ENTRY_FERIE_17564101729727564682)],
        &[(0b00001, &ENTRY_FERIE_17564101729727564682)],
        &[(0b00001, &ENTRY_FERITY_13311389916744452456)],
        &[(0b00001, &ENTRY_FERNEAU_15772716514172526627)],
        &[(0b00001, &ENTRY_FERRELED_9278515120825907819)],
        &[(0b00001, &ENTRY_FERRELING_13455687359496969723)],
        &[(0b11010, &ENTRY_FERRELED_9278515120825907819)],
        &[(0b11010, &ENTRY_FERRELING_13455687359496969723)],
        &[(0b10010, &ENTRY_FERRITIZATION_14347190689825266865)],
        &[(0b10010, &ENTRY_FERRITIZATIONS_4005953214740177334)],
        &[(0b01001, &ENTRY_FERRITIZATION_14347190689825266865)],
        &[(0b01001, &ENTRY_FERRITIZATIONS_4005953214740177334)],
        &[(0b10010, &ENTRY_FERTILIZABILITY_5571177015810750394)],
        &[(0b10010, &ENTRY_FERTILIZABLE_15315198919851330239)],
        &[(0b10010, &ENTRY_FERTILIZABLER_11059282997226454750)],
        &[(0b10010, &ENTRY_FERTILIZABLES_727447058423532709)],
        &[(0b10010, &ENTRY_FERTILIZABLEST_5310132580923675289)],
        &[(0b10010, &ENTRY_FERTILIZATION_4201619629518396111)],
        &[(0b10010, &ENTRY_FERTILIZATIONAL_16482273944934825327)],
        &[(0b10010, &ENTRY_FERTILIZATIONALER_6618806786515013867)],
        &[(0b10010, &ENTRY_FERTILIZATIONALEST_8345282217735812123)],
        &[(0b10010, &ENTRY_FERTILIZATIONALS_18170848439858779127)],
        &[(0b10010, &ENTRY_FERTILIZATIONS_14053083959867550141)],
        &[(0b10010, &ENTRY_FERTILIZE_16309782255722600032)],
        &[(0b10010, &ENTRY_FERTILIZED_13008162956323771867)],
        &[(0b10010, &ENTRY_FERTILIZER_6815415387209233087)],
        &[(0b10010, &ENTRY_FERTILIZERS_10709867916374165319)],
        &[(0b10010, &ENTRY_FERTILIZES_14381177978733680135)],
        &[(0b10010, &ENTRY_FERTILIZING_11080486546218839023)],
        &[(0b01001, &ENTRY_FERTILIZABILITY_5571177015810750394)],
        &[(0b01001, &ENTRY_FERTILIZABLE_15315198919851330239)],
        &[(0b01001, &ENTRY_FERTILIZABLER_11059282997226454750)],
        &[(0b01001, &ENTRY_FERTILIZABLES_727447058423532709)],
        &[(0b01001, &ENTRY_FERTILIZABLEST_5310132580923675289)],
        &[(0b01001, &ENTRY_FERTILIZATION_4201619629518396111)],
        &[(0b01001, &ENTRY_FERTILIZATIONAL_16482273944934825327)],
        &[(0b01001, &ENTRY_FERTILIZATIONALER_6618806786515013867)],
        &[(0b01001, &ENTRY_FERTILIZATIONALEST_8345282217735812123)],
        &[(0b01001, &ENTRY_FERTILIZATIONALS_18170848439858779127)],
        &[(0b01001, &ENTRY_FERTILIZATIONS_14053083959867550141)],
        &[(0b01001, &ENTRY_FERTILIZE_16309782255722600032)],
        &[(0b01001, &ENTRY_FERTILIZED_13008162956323771867)],
        &[(0b01001, &ENTRY_FERTILIZER_6815415387209233087)],
        &[(0b01001, &ENTRY_FERTILIZERS_10709867916374165319)],
        &[(0b01001, &ENTRY_FERTILIZES_14381177978733680135)],
        &[(0b01001, &ENTRY_FERTILIZING_11080486546218839023)],
        &[(0b11001, &ENTRY_FERVOR_614815645528947396)],
        &[(0b11001, &ENTRY_FERVORLESS_17452353118355031409)],
        &[(0b11001, &ENTRY_FERVORLESSES_3033145698325282698)],
        &[(0b11001, &ENTRY_FERVORS_6323083099093999272)],
        &[(0b11010, &ENTRY_FERVOR_614815645528947396)],
        &[(0b11010, &ENTRY_FERVORLESS_17452353118355031409)],
        &[(0b11010, &ENTRY_FERVORLESSES_3033145698325282698)],
        &[(0b11010, &ENTRY_FERVORS_6323083099093999272)],
    ],
    range: 1..=15,
};

static VARS_FEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FEM_CHILDREN),
    value: None,
};

pub static VARS_FEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("inisation"),
        dictgen::InsensitiveStr::Ascii("inisations"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inised"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inising"),
        dictgen::InsensitiveStr::Ascii("inization"),
        dictgen::InsensitiveStr::Ascii("inizations"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inized"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inizing"),
        dictgen::InsensitiveStr::Ascii("tometer"),
        dictgen::InsensitiveStr::Ascii("tometers"),
        dictgen::InsensitiveStr::Ascii("tometre"),
        dictgen::InsensitiveStr::Ascii("tometres"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FEMALIZE_5076396218269089909)],
        &[(0b10010, &ENTRY_FEMALIZES_5386306269066760275)],
        &[(0b01001, &ENTRY_FEMALIZE_5076396218269089909)],
        &[(0b01001, &ENTRY_FEMALIZES_5386306269066760275)],
        &[(0b10010, &ENTRY_FEMINIZATION_16468029640514579744)],
        &[(0b10010, &ENTRY_FEMINIZATIONS_10686352193044586448)],
        &[(0b10010, &ENTRY_FEMINIZE_14041224965069375071)],
        &[(0b10010, &ENTRY_FEMINIZED_8252992945131834923)],
        &[(0b10010, &ENTRY_FEMINIZES_16698712700755007840)],
        &[(0b10010, &ENTRY_FEMINIZING_15919362523885018840)],
        &[(0b01001, &ENTRY_FEMINIZATION_16468029640514579744)],
        &[(0b01001, &ENTRY_FEMINIZATIONS_10686352193044586448)],
        &[(0b01001, &ENTRY_FEMINIZE_14041224965069375071)],
        &[(0b01001, &ENTRY_FEMINIZED_8252992945131834923)],
        &[(0b01001, &ENTRY_FEMINIZES_16698712700755007840)],
        &[(0b01001, &ENTRY_FEMINIZING_15919362523885018840)],
        &[(0b01001, &ENTRY_FEMTOMETER_2397618503153495289)],
        &[(0b01001, &ENTRY_FEMTOMETERS_10727604929130343624)],
        &[(0b11010, &ENTRY_FEMTOMETER_2397618503153495289)],
        &[(0b11010, &ENTRY_FEMTOMETERS_10727604929130343624)],
    ],
    range: 5..=10,
};

static VARS_FEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FEE_CHILDREN),
    value: None,
};

pub static VARS_FEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rs"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FEER_1952217434418698536)],
        &[(0b00001, &ENTRY_FEERS_12963342733000822691)],
    ],
    range: 1..=2,
};

static VARS_FED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FED_CHILDREN),
    value: None,
};

pub static VARS_FED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arie"),
        dictgen::InsensitiveStr::Ascii("aries"),
        dictgen::InsensitiveStr::Ascii("eralisation"),
        dictgen::InsensitiveStr::Ascii("eralisations"),
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralised"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralising"),
        dictgen::InsensitiveStr::Ascii("eralization"),
        dictgen::InsensitiveStr::Ascii("eralizations"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralized"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("eralizing"),
        dictgen::InsensitiveStr::Ascii("or"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FEDARIE_10275114146235963561)],
        &[(0b00001, &ENTRY_FEDARIES_1925286557832729703)],
        &[(0b10010, &ENTRY_FEDERALIZATION_2930003327175764780)],
        &[(0b10010, &ENTRY_FEDERALIZATIONS_16898914644507613247)],
        &[(0b10010, &ENTRY_FEDERALIZE_2707270304365088999)],
        &[(0b10010, &ENTRY_FEDERALIZED_2097461935187515346)],
        &[(0b10010, &ENTRY_FEDERALIZES_16852170011006866629)],
        &[(0b10010, &ENTRY_FEDERALIZING_13709518621335381978)],
        &[(0b01001, &ENTRY_FEDERALIZATION_2930003327175764780)],
        &[(0b01001, &ENTRY_FEDERALIZATIONS_16898914644507613247)],
        &[(0b01001, &ENTRY_FEDERALIZE_2707270304365088999)],
        &[(0b01001, &ENTRY_FEDERALIZED_2097461935187515346)],
        &[(0b01001, &ENTRY_FEDERALIZES_16852170011006866629)],
        &[(0b01001, &ENTRY_FEDERALIZING_13709518621335381978)],
        &[(0b00001, &ENTRY_FEDOR_9744386020932116298)],
    ],
    range: 2..=12,
};

static VARS_FEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FEC_CHILDREN),
    value: None,
};

pub static VARS_FEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("al"),
        dictgen::InsensitiveStr::Ascii("alith"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("ula"),
        dictgen::InsensitiveStr::Ascii("ulence"),
        dictgen::InsensitiveStr::Ascii("undise"),
        dictgen::InsensitiveStr::Ascii("undises"),
        dictgen::InsensitiveStr::Ascii("unditatis"),
        dictgen::InsensitiveStr::Ascii("undize"),
        dictgen::InsensitiveStr::Ascii("undizes"),
    ],
    values: &[
        &[(0b11001, &ENTRY_FECAL_12589305345141408090)],
        &[(0b11001, &ENTRY_FECALITH_9756122697556381424)],
        &[(0b11001, &ENTRY_FECES_13271217083721614065)],
        &[(0b00001, &ENTRY_FECULA_2736474945675440138)],
        &[(0b00001, &ENTRY_FECULENCE_14580409871443771311)],
        &[(0b10010, &ENTRY_FECUNDIZE_10410164415494311065)],
        &[(0b10010, &ENTRY_FECUNDIZES_819255716151435756)],
        &[(0b00001, &ENTRY_FECUNDITATIS_9429833736788096175)],
        &[(0b01001, &ENTRY_FECUNDIZE_10410164415494311065)],
        &[(0b01001, &ENTRY_FECUNDIZES_819255716151435756)],
    ],
    range: 2..=9,
};

static VARS_FA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FA_CHILDREN),
    value: None,
};

static VARS_FA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_FAB_NODE),
    Some(&VARS_FAC_NODE),
    None,
    Some(&VARS_FAE_NODE),
    None,
    Some(&VARS_FAG_NODE),
    None,
    Some(&VARS_FAI_NODE),
    None,
    None,
    None,
    Some(&VARS_FAM_NODE),
    Some(&VARS_FAN_NODE),
    Some(&VARS_FAO_NODE),
    None,
    None,
    Some(&VARS_FAR_NODE),
    Some(&VARS_FAS_NODE),
    Some(&VARS_FAT_NODE),
    None,
    Some(&VARS_FAV_NODE),
    None,
    None,
    Some(&VARS_FAY_NODE),
    None,
];

static VARS_FAY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAY_CHILDREN),
    value: None,
};

pub static VARS_FAY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FAYER_17774491643443055310)],
        &[(0b11010, &ENTRY_FAYER_17774491643443055310)],
    ],
    range: 2..=2,
};

static VARS_FAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FAV_CHILDREN),
    value: None,
};

static VARS_FAV_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FAVO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_FAVO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FAVO_CHILDREN),
    value: None,
};

static VARS_FAVO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FAVOR_NODE),
    None,
    None,
    Some(&VARS_FAVOU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_FAVOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAVOU_CHILDREN),
    value: None,
};

pub static VARS_FAVOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rable"),
        dictgen::InsensitiveStr::Ascii("rableness"),
        dictgen::InsensitiveStr::Ascii("rablenesses"),
        dictgen::InsensitiveStr::Ascii("rabler"),
        dictgen::InsensitiveStr::Ascii("rables"),
        dictgen::InsensitiveStr::Ascii("rablest"),
        dictgen::InsensitiveStr::Ascii("rablier"),
        dictgen::InsensitiveStr::Ascii("rabliest"),
        dictgen::InsensitiveStr::Ascii("rably"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("redlier"),
        dictgen::InsensitiveStr::Ascii("redliest"),
        dictgen::InsensitiveStr::Ascii("redly"),
        dictgen::InsensitiveStr::Ascii("redness"),
        dictgen::InsensitiveStr::Ascii("rednesses"),
        dictgen::InsensitiveStr::Ascii("reds"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("ress"),
        dictgen::InsensitiveStr::Ascii("ring"),
        dictgen::InsensitiveStr::Ascii("ringlier"),
        dictgen::InsensitiveStr::Ascii("ringliest"),
        dictgen::InsensitiveStr::Ascii("ringly"),
        dictgen::InsensitiveStr::Ascii("rings"),
        dictgen::InsensitiveStr::Ascii("rite"),
        dictgen::InsensitiveStr::Ascii("riter"),
        dictgen::InsensitiveStr::Ascii("rites"),
        dictgen::InsensitiveStr::Ascii("ritest"),
        dictgen::InsensitiveStr::Ascii("ritism"),
        dictgen::InsensitiveStr::Ascii("ritisms"),
        dictgen::InsensitiveStr::Ascii("rless"),
        dictgen::InsensitiveStr::Ascii("rlesser"),
        dictgen::InsensitiveStr::Ascii("rlesses"),
        dictgen::InsensitiveStr::Ascii("rlessest"),
        dictgen::InsensitiveStr::Ascii("rs"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FAVOR_3275216426677362412)],
        &[(0b11010, &ENTRY_FAVORABLE_3232743289071203492)],
        &[(0b11010, &ENTRY_FAVORABLENESS_13318204817688701067)],
        &[(0b11010, &ENTRY_FAVORABLENESSES_11975449432847156038)],
        &[(0b11010, &ENTRY_FAVORABLER_1666504773214810504)],
        &[(0b11010, &ENTRY_FAVORABLES_9226020009295042529)],
        &[(0b11010, &ENTRY_FAVORABLEST_7604212844361785683)],
        &[(0b11010, &ENTRY_FAVORABLIER_9313656689589060087)],
        &[(0b11010, &ENTRY_FAVORABLIEST_14028659737830856566)],
        &[(0b11010, &ENTRY_FAVORABLY_14208254678721843327)],
        &[(0b11010, &ENTRY_FAVORED_10193433870000535406)],
        &[(0b11010, &ENTRY_FAVOREDLIER_18006876556571648819)],
        &[(0b11010, &ENTRY_FAVOREDLIEST_11349830239360797566)],
        &[(0b11010, &ENTRY_FAVOREDLY_16123517779026995677)],
        &[(0b11010, &ENTRY_FAVOREDNESS_683285836749751191)],
        &[(0b11010, &ENTRY_FAVOREDNESSES_15674786591317797795)],
        &[(0b11010, &ENTRY_FAVOREDS_2145643335759443083)],
        &[(0b11010, &ENTRY_FAVORER_1047334691871543829)],
        &[(0b11010, &ENTRY_FAVORERS_1232734746388131459)],
        &[(0b11010, &ENTRY_FAVORESS_15934392179881120848)],
        &[(0b11010, &ENTRY_FAVORING_10319622535862907770)],
        &[(0b11010, &ENTRY_FAVORINGLIER_13209309695763004912)],
        &[(0b11010, &ENTRY_FAVORINGLIEST_17037104130184778054)],
        &[(0b11010, &ENTRY_FAVORINGLY_6876525080994088190)],
        &[(0b11010, &ENTRY_FAVORINGS_11595257563255629951)],
        &[(0b11010, &ENTRY_FAVORITE_17454427683063934544)],
        &[(0b11010, &ENTRY_FAVORITER_13507792634611311500)],
        &[(0b11010, &ENTRY_FAVORITES_16988681338183255120)],
        &[(0b11010, &ENTRY_FAVORITEST_18081892094238130437)],
        &[(0b11010, &ENTRY_FAVORITISM_16206254464455079260)],
        &[(0b11010, &ENTRY_FAVORITISMS_1820158452140245407)],
        &[(0b11010, &ENTRY_FAVORLESS_8919204952537118702)],
        &[(0b11010, &ENTRY_FAVORLESSER_4904370564965283077)],
        &[(0b11010, &ENTRY_FAVORLESSES_16990574289794008026)],
        &[(0b11010, &ENTRY_FAVORLESSEST_6184008116056797645)],
        &[(0b11010, &ENTRY_FAVORS_3051235537214510517)],
    ],
    range: 1..=11,
};

static VARS_FAVOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAVOR_CHILDREN),
    value: Some(&[(0b11001, &ENTRY_FAVOR_3275216426677362412)]),
};

pub static VARS_FAVOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("able"),
        dictgen::InsensitiveStr::Ascii("ableness"),
        dictgen::InsensitiveStr::Ascii("ablenesses"),
        dictgen::InsensitiveStr::Ascii("abler"),
        dictgen::InsensitiveStr::Ascii("ables"),
        dictgen::InsensitiveStr::Ascii("ablest"),
        dictgen::InsensitiveStr::Ascii("ablier"),
        dictgen::InsensitiveStr::Ascii("abliest"),
        dictgen::InsensitiveStr::Ascii("ably"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("edlier"),
        dictgen::InsensitiveStr::Ascii("edliest"),
        dictgen::InsensitiveStr::Ascii("edly"),
        dictgen::InsensitiveStr::Ascii("edness"),
        dictgen::InsensitiveStr::Ascii("ednesses"),
        dictgen::InsensitiveStr::Ascii("eds"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("ess"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("inglier"),
        dictgen::InsensitiveStr::Ascii("ingliest"),
        dictgen::InsensitiveStr::Ascii("ingly"),
        dictgen::InsensitiveStr::Ascii("ings"),
        dictgen::InsensitiveStr::Ascii("ite"),
        dictgen::InsensitiveStr::Ascii("iter"),
        dictgen::InsensitiveStr::Ascii("ites"),
        dictgen::InsensitiveStr::Ascii("itest"),
        dictgen::InsensitiveStr::Ascii("itism"),
        dictgen::InsensitiveStr::Ascii("itisms"),
        dictgen::InsensitiveStr::Ascii("less"),
        dictgen::InsensitiveStr::Ascii("lesser"),
        dictgen::InsensitiveStr::Ascii("lesses"),
        dictgen::InsensitiveStr::Ascii("lessest"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b11001, &ENTRY_FAVORABLE_3232743289071203492)],
        &[(0b11001, &ENTRY_FAVORABLENESS_13318204817688701067)],
        &[(0b11001, &ENTRY_FAVORABLENESSES_11975449432847156038)],
        &[(0b11001, &ENTRY_FAVORABLER_1666504773214810504)],
        &[(0b11001, &ENTRY_FAVORABLES_9226020009295042529)],
        &[(0b11001, &ENTRY_FAVORABLEST_7604212844361785683)],
        &[(0b11001, &ENTRY_FAVORABLIER_9313656689589060087)],
        &[(0b11001, &ENTRY_FAVORABLIEST_14028659737830856566)],
        &[(0b11001, &ENTRY_FAVORABLY_14208254678721843327)],
        &[(0b11001, &ENTRY_FAVORED_10193433870000535406)],
        &[(0b11001, &ENTRY_FAVOREDLIER_18006876556571648819)],
        &[(0b11001, &ENTRY_FAVOREDLIEST_11349830239360797566)],
        &[(0b11001, &ENTRY_FAVOREDLY_16123517779026995677)],
        &[(0b11001, &ENTRY_FAVOREDNESS_683285836749751191)],
        &[(0b11001, &ENTRY_FAVOREDNESSES_15674786591317797795)],
        &[(0b11001, &ENTRY_FAVOREDS_2145643335759443083)],
        &[(0b11001, &ENTRY_FAVORER_1047334691871543829)],
        &[(0b11001, &ENTRY_FAVORERS_1232734746388131459)],
        &[(0b11001, &ENTRY_FAVORESS_15934392179881120848)],
        &[(0b11001, &ENTRY_FAVORING_10319622535862907770)],
        &[(0b11001, &ENTRY_FAVORINGLIER_13209309695763004912)],
        &[(0b11001, &ENTRY_FAVORINGLIEST_17037104130184778054)],
        &[(0b11001, &ENTRY_FAVORINGLY_6876525080994088190)],
        &[(0b11001, &ENTRY_FAVORINGS_11595257563255629951)],
        &[(0b11001, &ENTRY_FAVORITE_17454427683063934544)],
        &[(0b11001, &ENTRY_FAVORITER_13507792634611311500)],
        &[(0b11001, &ENTRY_FAVORITES_16988681338183255120)],
        &[(0b11001, &ENTRY_FAVORITEST_18081892094238130437)],
        &[(0b11001, &ENTRY_FAVORITISM_16206254464455079260)],
        &[(0b11001, &ENTRY_FAVORITISMS_1820158452140245407)],
        &[(0b11001, &ENTRY_FAVORLESS_8919204952537118702)],
        &[(0b11001, &ENTRY_FAVORLESSER_4904370564965283077)],
        &[(0b11001, &ENTRY_FAVORLESSES_16990574289794008026)],
        &[(0b11001, &ENTRY_FAVORLESSEST_6184008116056797645)],
        &[(0b11001, &ENTRY_FAVORS_3051235537214510517)],
    ],
    range: 1..=10,
};

static VARS_FAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAT_CHILDREN),
    value: None,
};

pub static VARS_FAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FATALIZE_8908836302084517669)],
        &[(0b10010, &ENTRY_FATALIZES_14060725425108865277)],
        &[(0b01001, &ENTRY_FATALIZE_8908836302084517669)],
        &[(0b01001, &ENTRY_FATALIZES_14060725425108865277)],
    ],
    range: 5..=6,
};

static VARS_FAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAS_CHILDREN),
    value: None,
};

pub static VARS_FAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ciolae"),
        dictgen::InsensitiveStr::Ascii("ciole"),
        dictgen::InsensitiveStr::Ascii("cisticisation"),
        dictgen::InsensitiveStr::Ascii("cisticisations"),
        dictgen::InsensitiveStr::Ascii("cisticise"),
        dictgen::InsensitiveStr::Ascii("cisticises"),
        dictgen::InsensitiveStr::Ascii("cisticization"),
        dictgen::InsensitiveStr::Ascii("cisticizations"),
        dictgen::InsensitiveStr::Ascii("cisticize"),
        dictgen::InsensitiveStr::Ascii("cisticizes"),
        dictgen::InsensitiveStr::Ascii("cistisation"),
        dictgen::InsensitiveStr::Ascii("cistisations"),
        dictgen::InsensitiveStr::Ascii("cistise"),
        dictgen::InsensitiveStr::Ascii("cistised"),
        dictgen::InsensitiveStr::Ascii("cistises"),
        dictgen::InsensitiveStr::Ascii("cistising"),
        dictgen::InsensitiveStr::Ascii("cistization"),
        dictgen::InsensitiveStr::Ascii("cistizations"),
        dictgen::InsensitiveStr::Ascii("cistize"),
        dictgen::InsensitiveStr::Ascii("cistized"),
        dictgen::InsensitiveStr::Ascii("cistizes"),
        dictgen::InsensitiveStr::Ascii("cistizing"),
        dictgen::InsensitiveStr::Ascii("hionise"),
        dictgen::InsensitiveStr::Ascii("hionises"),
        dictgen::InsensitiveStr::Ascii("hionize"),
        dictgen::InsensitiveStr::Ascii("hionizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FASCIOLE_17263907576806304609)],
        &[(0b00001, &ENTRY_FASCIOLE_17263907576806304609)],
        &[(0b10010, &ENTRY_FASCISTICIZATION_10804431373403126406)],
        &[(0b10010, &ENTRY_FASCISTICIZATIONS_2142515311664578918)],
        &[(0b10010, &ENTRY_FASCISTICIZE_14066142312502290880)],
        &[(0b10010, &ENTRY_FASCISTICIZES_12773262836291186621)],
        &[(0b01001, &ENTRY_FASCISTICIZATION_10804431373403126406)],
        &[(0b01001, &ENTRY_FASCISTICIZATIONS_2142515311664578918)],
        &[(0b01001, &ENTRY_FASCISTICIZE_14066142312502290880)],
        &[(0b01001, &ENTRY_FASCISTICIZES_12773262836291186621)],
        &[(0b10010, &ENTRY_FASCISTIZATION_5837081357565086170)],
        &[(0b10010, &ENTRY_FASCISTIZATIONS_15292377615911280827)],
        &[(0b10010, &ENTRY_FASCISTIZE_11561240909251618082)],
        &[(0b10010, &ENTRY_FASCISTIZED_11585438620059337608)],
        &[(0b10010, &ENTRY_FASCISTIZES_8866762538747399972)],
        &[(0b10010, &ENTRY_FASCISTIZING_8170964443515482096)],
        &[(0b01001, &ENTRY_FASCISTIZATION_5837081357565086170)],
        &[(0b01001, &ENTRY_FASCISTIZATIONS_15292377615911280827)],
        &[(0b01001, &ENTRY_FASCISTIZE_11561240909251618082)],
        &[(0b01001, &ENTRY_FASCISTIZED_11585438620059337608)],
        &[(0b01001, &ENTRY_FASCISTIZES_8866762538747399972)],
        &[(0b01001, &ENTRY_FASCISTIZING_8170964443515482096)],
        &[(0b10010, &ENTRY_FASHIONIZE_165859306339703853)],
        &[(0b10010, &ENTRY_FASHIONIZES_16455688786469638021)],
        &[(0b01001, &ENTRY_FASHIONIZE_165859306339703853)],
        &[(0b01001, &ENTRY_FASHIONIZES_16455688786469638021)],
    ],
    range: 5..=14,
};

static VARS_FAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAR_CHILDREN),
    value: None,
};

pub static VARS_FAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("adisation"),
        dictgen::InsensitiveStr::Ascii("adisations"),
        dictgen::InsensitiveStr::Ascii("adise"),
        dictgen::InsensitiveStr::Ascii("adised"),
        dictgen::InsensitiveStr::Ascii("adiser"),
        dictgen::InsensitiveStr::Ascii("adisers"),
        dictgen::InsensitiveStr::Ascii("adises"),
        dictgen::InsensitiveStr::Ascii("adising"),
        dictgen::InsensitiveStr::Ascii("adization"),
        dictgen::InsensitiveStr::Ascii("adizations"),
        dictgen::InsensitiveStr::Ascii("adize"),
        dictgen::InsensitiveStr::Ascii("adized"),
        dictgen::InsensitiveStr::Ascii("adizer"),
        dictgen::InsensitiveStr::Ascii("adizers"),
        dictgen::InsensitiveStr::Ascii("adizes"),
        dictgen::InsensitiveStr::Ascii("adizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FARADIZATION_205243435660491694)],
        &[(0b10010, &ENTRY_FARADIZATIONS_15687190555969801215)],
        &[(0b10010, &ENTRY_FARADIZE_12209808126934904312)],
        &[(0b10010, &ENTRY_FARADIZED_8966502857650295265)],
        &[(0b10010, &ENTRY_FARADIZER_12338085475428655967)],
        &[(0b10010, &ENTRY_FARADIZERS_16719521658589655925)],
        &[(0b10010, &ENTRY_FARADIZES_15338843475283209863)],
        &[(0b10010, &ENTRY_FARADIZING_4001083035652834283)],
        &[(0b01001, &ENTRY_FARADIZATION_205243435660491694)],
        &[(0b01001, &ENTRY_FARADIZATIONS_15687190555969801215)],
        &[(0b01001, &ENTRY_FARADIZE_12209808126934904312)],
        &[(0b01001, &ENTRY_FARADIZED_8966502857650295265)],
        &[(0b01001, &ENTRY_FARADIZER_12338085475428655967)],
        &[(0b01001, &ENTRY_FARADIZERS_16719521658589655925)],
        &[(0b01001, &ENTRY_FARADIZES_15338843475283209863)],
        &[(0b01001, &ENTRY_FARADIZING_4001083035652834283)],
    ],
    range: 5..=10,
};

static VARS_FAO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAO_CHILDREN),
    value: None,
};

pub static VARS_FAO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ence")],
    values: &[&[(0b11010, &ENTRY_FAENCE_17825379390909859682)]],
    range: 4..=4,
};

static VARS_FAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAN_CHILDREN),
    value: None,
};

pub static VARS_FAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aticise"),
        dictgen::InsensitiveStr::Ascii("aticised"),
        dictgen::InsensitiveStr::Ascii("aticises"),
        dictgen::InsensitiveStr::Ascii("aticising"),
        dictgen::InsensitiveStr::Ascii("aticize"),
        dictgen::InsensitiveStr::Ascii("aticized"),
        dictgen::InsensitiveStr::Ascii("aticizes"),
        dictgen::InsensitiveStr::Ascii("aticizing"),
        dictgen::InsensitiveStr::Ascii("tasise"),
        dictgen::InsensitiveStr::Ascii("tasised"),
        dictgen::InsensitiveStr::Ascii("tasiser"),
        dictgen::InsensitiveStr::Ascii("tasises"),
        dictgen::InsensitiveStr::Ascii("tasising"),
        dictgen::InsensitiveStr::Ascii("tasize"),
        dictgen::InsensitiveStr::Ascii("tasized"),
        dictgen::InsensitiveStr::Ascii("tasizer"),
        dictgen::InsensitiveStr::Ascii("tasizes"),
        dictgen::InsensitiveStr::Ascii("tasizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FANATICIZE_10597130864549893912)],
        &[(0b10010, &ENTRY_FANATICIZED_7803305658591134019)],
        &[(0b10010, &ENTRY_FANATICIZES_15012541655389909830)],
        &[(0b10010, &ENTRY_FANATICIZING_17977710800766343799)],
        &[(0b01001, &ENTRY_FANATICIZE_10597130864549893912)],
        &[(0b01001, &ENTRY_FANATICIZED_7803305658591134019)],
        &[(0b01001, &ENTRY_FANATICIZES_15012541655389909830)],
        &[(0b01001, &ENTRY_FANATICIZING_17977710800766343799)],
        &[(0b10010, &ENTRY_FANTASIZE_14080369588189172386)],
        &[(0b10010, &ENTRY_FANTASIZED_15872386699233756433)],
        &[(0b10010, &ENTRY_FANTASIZER_13718445762964364656)],
        &[(0b10010, &ENTRY_FANTASIZES_4908779596089212975)],
        &[(0b10010, &ENTRY_FANTASIZING_4236358014599476998)],
        &[(0b01001, &ENTRY_FANTASIZE_14080369588189172386)],
        &[(0b01001, &ENTRY_FANTASIZED_15872386699233756433)],
        &[(0b01001, &ENTRY_FANTASIZER_13718445762964364656)],
        &[(0b01001, &ENTRY_FANTASIZES_4908779596089212975)],
        &[(0b01001, &ENTRY_FANTASIZING_4236358014599476998)],
    ],
    range: 6..=9,
};

static VARS_FAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAM_CHILDREN),
    value: None,
};

pub static VARS_FAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iliarisation"),
        dictgen::InsensitiveStr::Ascii("iliarisations"),
        dictgen::InsensitiveStr::Ascii("iliarise"),
        dictgen::InsensitiveStr::Ascii("iliarised"),
        dictgen::InsensitiveStr::Ascii("iliariser"),
        dictgen::InsensitiveStr::Ascii("iliarisers"),
        dictgen::InsensitiveStr::Ascii("iliarises"),
        dictgen::InsensitiveStr::Ascii("iliarising"),
        dictgen::InsensitiveStr::Ascii("iliarisingly"),
        dictgen::InsensitiveStr::Ascii("iliarization"),
        dictgen::InsensitiveStr::Ascii("iliarizations"),
        dictgen::InsensitiveStr::Ascii("iliarize"),
        dictgen::InsensitiveStr::Ascii("iliarized"),
        dictgen::InsensitiveStr::Ascii("iliarizer"),
        dictgen::InsensitiveStr::Ascii("iliarizers"),
        dictgen::InsensitiveStr::Ascii("iliarizes"),
        dictgen::InsensitiveStr::Ascii("iliarizing"),
        dictgen::InsensitiveStr::Ascii("iliarizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FAMILIARIZATION_12082687538774621170)],
        &[(0b10010, &ENTRY_FAMILIARIZATIONS_12640437606890487270)],
        &[(0b10010, &ENTRY_FAMILIARIZE_6242156019669273444)],
        &[(0b10010, &ENTRY_FAMILIARIZED_15024414515945758936)],
        &[(0b10010, &ENTRY_FAMILIARIZER_6464941598388506049)],
        &[(0b10010, &ENTRY_FAMILIARIZERS_3971622733242915623)],
        &[(0b10010, &ENTRY_FAMILIARIZES_17026717100467495383)],
        &[(0b10010, &ENTRY_FAMILIARIZING_8104674979842226150)],
        &[(0b10010, &ENTRY_FAMILIARIZINGLY_5969515453181631796)],
        &[(0b01001, &ENTRY_FAMILIARIZATION_12082687538774621170)],
        &[(0b01001, &ENTRY_FAMILIARIZATIONS_12640437606890487270)],
        &[(0b01001, &ENTRY_FAMILIARIZE_6242156019669273444)],
        &[(0b01001, &ENTRY_FAMILIARIZED_15024414515945758936)],
        &[(0b01001, &ENTRY_FAMILIARIZER_6464941598388506049)],
        &[(0b01001, &ENTRY_FAMILIARIZERS_3971622733242915623)],
        &[(0b01001, &ENTRY_FAMILIARIZES_17026717100467495383)],
        &[(0b01001, &ENTRY_FAMILIARIZING_8104674979842226150)],
        &[(0b01001, &ENTRY_FAMILIARIZINGLY_5969515453181631796)],
    ],
    range: 8..=13,
};

static VARS_FAI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAI_CHILDREN),
    value: None,
};

pub static VARS_FAI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tor"),
        dictgen::InsensitiveStr::Ascii("tors"),
        dictgen::InsensitiveStr::Ascii("tour"),
        dictgen::InsensitiveStr::Ascii("tours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FAITOR_14801362899469576916)],
        &[(0b00001, &ENTRY_FAITORS_14335612044167781406)],
        &[(0b11010, &ENTRY_FAITOR_14801362899469576916)],
        &[(0b11010, &ENTRY_FAITORS_14335612044167781406)],
    ],
    range: 3..=5,
};

static VARS_FAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAG_CHILDREN),
    value: None,
};

pub static VARS_FAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ot"),
        dictgen::InsensitiveStr::Ascii("oted"),
        dictgen::InsensitiveStr::Ascii("oting"),
        dictgen::InsensitiveStr::Ascii("ots"),
    ],
    values: &[
        &[
            (0b01001, &ENTRY_FAGOT_10151298035917845314),
            (0b01001, &ENTRY_FAGOT_7863482917477677576),
        ],
        &[(0b01001, &ENTRY_FAGOTED_6374042289029783427)],
        &[(0b01001, &ENTRY_FAGOTING_5494547696679224898)],
        &[
            (0b01001, &ENTRY_FAGOTS_14417121374438859878),
            (0b01001, &ENTRY_FAGOTS_15779386352352349090),
        ],
    ],
    range: 2..=5,
};

static VARS_FAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_FE_11063702362937317781)]),
};

pub static VARS_FAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cal"),
        dictgen::InsensitiveStr::Ascii("calith"),
        dictgen::InsensitiveStr::Ascii("ces"),
        dictgen::InsensitiveStr::Ascii("cula"),
        dictgen::InsensitiveStr::Ascii("culence"),
        dictgen::InsensitiveStr::Ascii("dor"),
        dictgen::InsensitiveStr::Ascii("nce"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FECAL_12589305345141408090)],
        &[(0b10010, &ENTRY_FECALITH_9756122697556381424)],
        &[(0b11010, &ENTRY_FECES_13271217083721614065)],
        &[(0b11010, &ENTRY_FECULA_2736474945675440138)],
        &[(0b11010, &ENTRY_FECULENCE_14580409871443771311)],
        &[(0b11010, &ENTRY_FEDOR_9744386020932116298)],
        &[(0b00001, &ENTRY_FAENCE_17825379390909859682)],
    ],
    range: 3..=7,
};

static VARS_FAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAC_CHILDREN),
    value: None,
};

pub static VARS_FAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("similise"),
        dictgen::InsensitiveStr::Ascii("similises"),
        dictgen::InsensitiveStr::Ascii("similize"),
        dictgen::InsensitiveStr::Ascii("similizes"),
        dictgen::InsensitiveStr::Ascii("torisation"),
        dictgen::InsensitiveStr::Ascii("torisations"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torised"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torising"),
        dictgen::InsensitiveStr::Ascii("torization"),
        dictgen::InsensitiveStr::Ascii("torizations"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torized"),
        dictgen::InsensitiveStr::Ascii("torizes"),
        dictgen::InsensitiveStr::Ascii("torizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FACSIMILIZE_3990097773408232192)],
        &[(0b10010, &ENTRY_FACSIMILIZES_12559845002197022283)],
        &[(0b01001, &ENTRY_FACSIMILIZE_3990097773408232192)],
        &[(0b01001, &ENTRY_FACSIMILIZES_12559845002197022283)],
        &[(0b10010, &ENTRY_FACTORIZATION_5102971756633526494)],
        &[(0b10010, &ENTRY_FACTORIZATIONS_4638071637630345545)],
        &[(0b10010, &ENTRY_FACTORIZE_6248620742291710594)],
        &[(0b10010, &ENTRY_FACTORIZED_3076385353944751316)],
        &[(0b10010, &ENTRY_FACTORIZES_6368168670047017262)],
        &[(0b10010, &ENTRY_FACTORIZING_10106476068343096154)],
        &[(0b01001, &ENTRY_FACTORIZATION_5102971756633526494)],
        &[(0b01001, &ENTRY_FACTORIZATIONS_4638071637630345545)],
        &[(0b01001, &ENTRY_FACTORIZE_6248620742291710594)],
        &[(0b01001, &ENTRY_FACTORIZED_3076385353944751316)],
        &[(0b01001, &ENTRY_FACTORIZES_6368168670047017262)],
        &[(0b01001, &ENTRY_FACTORIZING_10106476068343096154)],
    ],
    range: 6..=11,
};

static VARS_FAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAB_CHILDREN),
    value: None,
};

pub static VARS_FAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ulise"),
        dictgen::InsensitiveStr::Ascii("ulised"),
        dictgen::InsensitiveStr::Ascii("ulises"),
        dictgen::InsensitiveStr::Ascii("ulising"),
        dictgen::InsensitiveStr::Ascii("ulize"),
        dictgen::InsensitiveStr::Ascii("ulized"),
        dictgen::InsensitiveStr::Ascii("ulizes"),
        dictgen::InsensitiveStr::Ascii("ulizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FABULIZE_14998259506216827665)],
        &[(0b10010, &ENTRY_FABULIZED_17196297800190893705)],
        &[(0b10010, &ENTRY_FABULIZES_6694776625224319041)],
        &[(0b10010, &ENTRY_FABULIZING_1773624844947708020)],
        &[(0b01001, &ENTRY_FABULIZE_14998259506216827665)],
        &[(0b01001, &ENTRY_FABULIZED_17196297800190893705)],
        &[(0b01001, &ENTRY_FABULIZES_6694776625224319041)],
        &[(0b01001, &ENTRY_FABULIZING_1773624844947708020)],
    ],
    range: 5..=7,
};

static VARS_E_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_E_CHILDREN),
    value: None,
};

static VARS_E_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_EA_NODE),
    Some(&VARS_EB_NODE),
    Some(&VARS_EC_NODE),
    Some(&VARS_ED_NODE),
    Some(&VARS_EE_NODE),
    Some(&VARS_EF_NODE),
    Some(&VARS_EG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_EL_NODE),
    Some(&VARS_EM_NODE),
    Some(&VARS_EN_NODE),
    Some(&VARS_EO_NODE),
    Some(&VARS_EP_NODE),
    Some(&VARS_EQ_NODE),
    Some(&VARS_ER_NODE),
    Some(&VARS_ES_NODE),
    Some(&VARS_ET_NODE),
    Some(&VARS_EU_NODE),
    Some(&VARS_EV_NODE),
    None,
    Some(&VARS_EX_NODE),
    Some(&VARS_EY_NODE),
    None,
];

static VARS_EY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EY_CHILDREN),
    value: None,
};

pub static VARS_EY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rie"),
        dictgen::InsensitiveStr::Ascii("ry"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AERIE_17068047033087189954)],
        &[(0b00001, &ENTRY_AERIE_17068047033087189954)],
    ],
    range: 2..=3,
};

static VARS_EX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EX_CHILDREN),
    value: None,
};

static VARS_EX_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_EXA_NODE),
    None,
    Some(&VARS_EXC_NODE),
    None,
    Some(&VARS_EXE_NODE),
    None,
    None,
    Some(&VARS_EXH_NODE),
    Some(&VARS_EXI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_EXO_NODE),
    Some(&VARS_EXP_NODE),
    None,
    None,
    Some(&VARS_EXS_NODE),
    Some(&VARS_EXT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_EXT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXT_CHILDREN),
    value: None,
};

pub static VARS_EXT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emporisation"),
        dictgen::InsensitiveStr::Ascii("emporisations"),
        dictgen::InsensitiveStr::Ascii("emporise"),
        dictgen::InsensitiveStr::Ascii("emporised"),
        dictgen::InsensitiveStr::Ascii("emporiser"),
        dictgen::InsensitiveStr::Ascii("emporisers"),
        dictgen::InsensitiveStr::Ascii("emporises"),
        dictgen::InsensitiveStr::Ascii("emporising"),
        dictgen::InsensitiveStr::Ascii("emporization"),
        dictgen::InsensitiveStr::Ascii("emporizations"),
        dictgen::InsensitiveStr::Ascii("emporize"),
        dictgen::InsensitiveStr::Ascii("emporized"),
        dictgen::InsensitiveStr::Ascii("emporizer"),
        dictgen::InsensitiveStr::Ascii("emporizers"),
        dictgen::InsensitiveStr::Ascii("emporizes"),
        dictgen::InsensitiveStr::Ascii("emporizing"),
        dictgen::InsensitiveStr::Ascii("eriorisation"),
        dictgen::InsensitiveStr::Ascii("eriorisations"),
        dictgen::InsensitiveStr::Ascii("eriorise"),
        dictgen::InsensitiveStr::Ascii("eriorised"),
        dictgen::InsensitiveStr::Ascii("eriorises"),
        dictgen::InsensitiveStr::Ascii("eriorising"),
        dictgen::InsensitiveStr::Ascii("eriorization"),
        dictgen::InsensitiveStr::Ascii("eriorizations"),
        dictgen::InsensitiveStr::Ascii("eriorize"),
        dictgen::InsensitiveStr::Ascii("eriorized"),
        dictgen::InsensitiveStr::Ascii("eriorizes"),
        dictgen::InsensitiveStr::Ascii("eriorizing"),
        dictgen::InsensitiveStr::Ascii("ernalisation"),
        dictgen::InsensitiveStr::Ascii("ernalisations"),
        dictgen::InsensitiveStr::Ascii("ernalise"),
        dictgen::InsensitiveStr::Ascii("ernalised"),
        dictgen::InsensitiveStr::Ascii("ernalises"),
        dictgen::InsensitiveStr::Ascii("ernalising"),
        dictgen::InsensitiveStr::Ascii("ernalization"),
        dictgen::InsensitiveStr::Ascii("ernalizations"),
        dictgen::InsensitiveStr::Ascii("ernalize"),
        dictgen::InsensitiveStr::Ascii("ernalized"),
        dictgen::InsensitiveStr::Ascii("ernalizes"),
        dictgen::InsensitiveStr::Ascii("ernalizing"),
        dictgen::InsensitiveStr::Ascii("oll"),
        dictgen::InsensitiveStr::Ascii("olls"),
        dictgen::InsensitiveStr::Ascii("ravert"),
        dictgen::InsensitiveStr::Ascii("raverted"),
        dictgen::InsensitiveStr::Ascii("raverts"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EXTEMPORIZATION_16495995827408513386)],
        &[(0b10010, &ENTRY_EXTEMPORIZATIONS_484835912937984024)],
        &[(0b10010, &ENTRY_EXTEMPORIZE_18100427440717892297)],
        &[(0b10010, &ENTRY_EXTEMPORIZED_8373892655121344093)],
        &[(0b10010, &ENTRY_EXTEMPORIZER_1000073776414629889)],
        &[(0b10010, &ENTRY_EXTEMPORIZERS_15031267596464401937)],
        &[(0b10010, &ENTRY_EXTEMPORIZES_10237434907700901719)],
        &[(0b10010, &ENTRY_EXTEMPORIZING_3627576447114749026)],
        &[(0b01001, &ENTRY_EXTEMPORIZATION_16495995827408513386)],
        &[(0b01001, &ENTRY_EXTEMPORIZATIONS_484835912937984024)],
        &[(0b01001, &ENTRY_EXTEMPORIZE_18100427440717892297)],
        &[(0b01001, &ENTRY_EXTEMPORIZED_8373892655121344093)],
        &[(0b01001, &ENTRY_EXTEMPORIZER_1000073776414629889)],
        &[(0b01001, &ENTRY_EXTEMPORIZERS_15031267596464401937)],
        &[(0b01001, &ENTRY_EXTEMPORIZES_10237434907700901719)],
        &[(0b01001, &ENTRY_EXTEMPORIZING_3627576447114749026)],
        &[(0b10010, &ENTRY_EXTERIORIZATION_18119077159963528619)],
        &[(0b10010, &ENTRY_EXTERIORIZATIONS_310117758835612277)],
        &[(0b10010, &ENTRY_EXTERIORIZE_44904350820292310)],
        &[(0b10010, &ENTRY_EXTERIORIZED_15754857071634888794)],
        &[(0b10010, &ENTRY_EXTERIORIZES_1503361879818597816)],
        &[(0b10010, &ENTRY_EXTERIORIZING_13843149969846401653)],
        &[(0b01001, &ENTRY_EXTERIORIZATION_18119077159963528619)],
        &[(0b01001, &ENTRY_EXTERIORIZATIONS_310117758835612277)],
        &[(0b01001, &ENTRY_EXTERIORIZE_44904350820292310)],
        &[(0b01001, &ENTRY_EXTERIORIZED_15754857071634888794)],
        &[(0b01001, &ENTRY_EXTERIORIZES_1503361879818597816)],
        &[(0b01001, &ENTRY_EXTERIORIZING_13843149969846401653)],
        &[(0b10010, &ENTRY_EXTERNALIZATION_9246128994925255934)],
        &[(0b10010, &ENTRY_EXTERNALIZATIONS_6813089105022337009)],
        &[(0b10010, &ENTRY_EXTERNALIZE_1755256362900379852)],
        &[(0b10010, &ENTRY_EXTERNALIZED_9673243200936449099)],
        &[(0b10010, &ENTRY_EXTERNALIZES_2963526646467072454)],
        &[(0b10010, &ENTRY_EXTERNALIZING_13585703043209993488)],
        &[(0b01001, &ENTRY_EXTERNALIZATION_9246128994925255934)],
        &[(0b01001, &ENTRY_EXTERNALIZATIONS_6813089105022337009)],
        &[(0b01001, &ENTRY_EXTERNALIZE_1755256362900379852)],
        &[(0b01001, &ENTRY_EXTERNALIZED_9673243200936449099)],
        &[(0b01001, &ENTRY_EXTERNALIZES_2963526646467072454)],
        &[(0b01001, &ENTRY_EXTERNALIZING_13585703043209993488)],
        &[(0b00001, &ENTRY_EXTOL_6530203836420061929)],
        &[(0b00001, &ENTRY_EXTOLS_11917668525245354154)],
        &[(0b10011, &ENTRY_EXTROVERT_14223399491319457241)],
        &[(0b10011, &ENTRY_EXTROVERTED_3349811760540489416)],
        &[(0b10011, &ENTRY_EXTROVERTS_5855938022041084405)],
    ],
    range: 3..=13,
};

static VARS_EXS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXS_CHILDREN),
    value: None,
};

pub static VARS_EXS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iccatae"),
        dictgen::InsensitiveStr::Ascii("iccate"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EXSICCATE_5753093181162139232)],
        &[(0b00001, &ENTRY_EXSICCATE_5753093181162139232)],
    ],
    range: 6..=7,
};

static VARS_EXP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXP_CHILDREN),
    value: None,
};

pub static VARS_EXP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erimentalise"),
        dictgen::InsensitiveStr::Ascii("erimentalised"),
        dictgen::InsensitiveStr::Ascii("erimentalises"),
        dictgen::InsensitiveStr::Ascii("erimentalising"),
        dictgen::InsensitiveStr::Ascii("erimentalize"),
        dictgen::InsensitiveStr::Ascii("erimentalized"),
        dictgen::InsensitiveStr::Ascii("erimentalizes"),
        dictgen::InsensitiveStr::Ascii("erimentalizing"),
        dictgen::InsensitiveStr::Ascii("erimentise"),
        dictgen::InsensitiveStr::Ascii("erimentises"),
        dictgen::InsensitiveStr::Ascii("erimentize"),
        dictgen::InsensitiveStr::Ascii("erimentizes"),
        dictgen::InsensitiveStr::Ascii("ertised"),
        dictgen::InsensitiveStr::Ascii("ertising"),
        dictgen::InsensitiveStr::Ascii("ertized"),
        dictgen::InsensitiveStr::Ascii("ertizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EXPERIMENTALIZE_10878270560966778384)],
        &[(0b10010, &ENTRY_EXPERIMENTALIZED_16319238987251423636)],
        &[(0b10010, &ENTRY_EXPERIMENTALIZES_6488970464603492402)],
        &[(0b10010, &ENTRY_EXPERIMENTALIZING_14626652674328972371)],
        &[(0b01001, &ENTRY_EXPERIMENTALIZE_10878270560966778384)],
        &[(0b01001, &ENTRY_EXPERIMENTALIZED_16319238987251423636)],
        &[(0b01001, &ENTRY_EXPERIMENTALIZES_6488970464603492402)],
        &[(0b01001, &ENTRY_EXPERIMENTALIZING_14626652674328972371)],
        &[(0b10010, &ENTRY_EXPERIMENTIZE_4938698649692716165)],
        &[(0b10010, &ENTRY_EXPERIMENTIZES_7968616202247451636)],
        &[(0b01001, &ENTRY_EXPERIMENTIZE_4938698649692716165)],
        &[(0b01001, &ENTRY_EXPERIMENTIZES_7968616202247451636)],
        &[(0b10010, &ENTRY_EXPERTIZED_14036001593273348525)],
        &[(0b10010, &ENTRY_EXPERTIZING_5977912727854152082)],
        &[(0b01001, &ENTRY_EXPERTIZED_14036001593273348525)],
        &[(0b01001, &ENTRY_EXPERTIZING_5977912727854152082)],
    ],
    range: 7..=14,
};

static VARS_EXO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXO_CHILDREN),
    value: None,
};

pub static VARS_EXO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rcisation"),
        dictgen::InsensitiveStr::Ascii("rcisement"),
        dictgen::InsensitiveStr::Ascii("rciser"),
        dictgen::InsensitiveStr::Ascii("rcisers"),
        dictgen::InsensitiveStr::Ascii("rcization"),
        dictgen::InsensitiveStr::Ascii("rcize"),
        dictgen::InsensitiveStr::Ascii("rcized"),
        dictgen::InsensitiveStr::Ascii("rcizement"),
        dictgen::InsensitiveStr::Ascii("rcizer"),
        dictgen::InsensitiveStr::Ascii("rcizers"),
        dictgen::InsensitiveStr::Ascii("rcizes"),
        dictgen::InsensitiveStr::Ascii("rcizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EXORCIZATION_9973557591494255050)],
        &[(0b10010, &ENTRY_EXORCIZEMENT_4086232982854862407)],
        &[(0b10010, &ENTRY_EXORCIZER_10990791238547945470)],
        &[(0b10010, &ENTRY_EXORCIZERS_4060237431460252715)],
        &[(0b01001, &ENTRY_EXORCIZATION_9973557591494255050)],
        &[(0b01001, &ENTRY_EXORCISE_6519813252766976149)],
        &[(0b01001, &ENTRY_EXORCISED_7923013483761916535)],
        &[(0b01001, &ENTRY_EXORCIZEMENT_4086232982854862407)],
        &[(0b01001, &ENTRY_EXORCIZER_10990791238547945470)],
        &[(0b01001, &ENTRY_EXORCIZERS_4060237431460252715)],
        &[(0b01001, &ENTRY_EXORCISES_13003500046685598280)],
        &[(0b01001, &ENTRY_EXORCISING_7595159943765013984)],
    ],
    range: 5..=9,
};

static VARS_EXI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXI_CHILDREN),
    value: None,
};

pub static VARS_EXI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("stentialise"),
        dictgen::InsensitiveStr::Ascii("stentialises"),
        dictgen::InsensitiveStr::Ascii("stentialize"),
        dictgen::InsensitiveStr::Ascii("stentializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EXISTENTIALIZE_7178947692897315493)],
        &[(0b10010, &ENTRY_EXISTENTIALIZES_12344782442749191950)],
        &[(0b01001, &ENTRY_EXISTENTIALIZE_7178947692897315493)],
        &[(0b01001, &ENTRY_EXISTENTIALIZES_12344782442749191950)],
    ],
    range: 11..=12,
};

static VARS_EXH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXH_CHILDREN),
    value: None,
};

pub static VARS_EXH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ibitionise"),
        dictgen::InsensitiveStr::Ascii("ibitionises"),
        dictgen::InsensitiveStr::Ascii("ibitionize"),
        dictgen::InsensitiveStr::Ascii("ibitionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EXHIBITIONIZE_15056221307874731438)],
        &[(0b10010, &ENTRY_EXHIBITIONIZES_2334877825344301791)],
        &[(0b01001, &ENTRY_EXHIBITIONIZE_15056221307874731438)],
        &[(0b01001, &ENTRY_EXHIBITIONIZES_2334877825344301791)],
    ],
    range: 10..=11,
};

static VARS_EXE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXE_CHILDREN),
    value: None,
};

pub static VARS_EXE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("stuate")],
    values: &[&[(0b00001, &ENTRY_EXESTUATE_10535524922051300239)]],
    range: 6..=6,
};

static VARS_EXC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXC_CHILDREN),
    value: None,
};

pub static VARS_EXC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ursionise"),
        dictgen::InsensitiveStr::Ascii("ursionised"),
        dictgen::InsensitiveStr::Ascii("ursionises"),
        dictgen::InsensitiveStr::Ascii("ursionising"),
        dictgen::InsensitiveStr::Ascii("ursionize"),
        dictgen::InsensitiveStr::Ascii("ursionized"),
        dictgen::InsensitiveStr::Ascii("ursionizes"),
        dictgen::InsensitiveStr::Ascii("ursionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EXCURSIONIZE_9010217601314344660)],
        &[(0b10010, &ENTRY_EXCURSIONIZED_10549978358779313723)],
        &[(0b10010, &ENTRY_EXCURSIONIZES_14003180836324204514)],
        &[(0b10010, &ENTRY_EXCURSIONIZING_3926415541732909964)],
        &[(0b01001, &ENTRY_EXCURSIONIZE_9010217601314344660)],
        &[(0b01001, &ENTRY_EXCURSIONIZED_10549978358779313723)],
        &[(0b01001, &ENTRY_EXCURSIONIZES_14003180836324204514)],
        &[(0b01001, &ENTRY_EXCURSIONIZING_3926415541732909964)],
    ],
    range: 9..=11,
};

static VARS_EXA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXA_CHILDREN),
    value: None,
};

pub static VARS_EXA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("estuate")],
    values: &[&[(0b11010, &ENTRY_EXESTUATE_10535524922051300239)]],
    range: 7..=7,
};

static VARS_EV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EV_CHILDREN),
    value: None,
};

pub static VARS_EV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("angelisation"),
        dictgen::InsensitiveStr::Ascii("angelisations"),
        dictgen::InsensitiveStr::Ascii("angelise"),
        dictgen::InsensitiveStr::Ascii("angelised"),
        dictgen::InsensitiveStr::Ascii("angeliser"),
        dictgen::InsensitiveStr::Ascii("angelisers"),
        dictgen::InsensitiveStr::Ascii("angelises"),
        dictgen::InsensitiveStr::Ascii("angelising"),
        dictgen::InsensitiveStr::Ascii("angelization"),
        dictgen::InsensitiveStr::Ascii("angelizations"),
        dictgen::InsensitiveStr::Ascii("angelize"),
        dictgen::InsensitiveStr::Ascii("angelized"),
        dictgen::InsensitiveStr::Ascii("angelizer"),
        dictgen::InsensitiveStr::Ascii("angelizers"),
        dictgen::InsensitiveStr::Ascii("angelizes"),
        dictgen::InsensitiveStr::Ascii("angelizing"),
        dictgen::InsensitiveStr::Ascii("entualise"),
        dictgen::InsensitiveStr::Ascii("entualised"),
        dictgen::InsensitiveStr::Ascii("entualises"),
        dictgen::InsensitiveStr::Ascii("entualising"),
        dictgen::InsensitiveStr::Ascii("entualize"),
        dictgen::InsensitiveStr::Ascii("entualized"),
        dictgen::InsensitiveStr::Ascii("entualizes"),
        dictgen::InsensitiveStr::Ascii("entualizing"),
        dictgen::InsensitiveStr::Ascii("iler"),
        dictgen::InsensitiveStr::Ascii("ilest"),
        dictgen::InsensitiveStr::Ascii("iller"),
        dictgen::InsensitiveStr::Ascii("illest"),
        dictgen::InsensitiveStr::Ascii("iternal"),
        dictgen::InsensitiveStr::Ascii("olutionise"),
        dictgen::InsensitiveStr::Ascii("olutionises"),
        dictgen::InsensitiveStr::Ascii("olutionize"),
        dictgen::InsensitiveStr::Ascii("olutionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EVANGELIZATION_95918260299241119)],
        &[(0b10010, &ENTRY_EVANGELIZATIONS_13830601721028602369)],
        &[(0b10010, &ENTRY_EVANGELIZE_3816430481934936599)],
        &[(0b10010, &ENTRY_EVANGELIZED_17447599926020044651)],
        &[(0b10010, &ENTRY_EVANGELIZER_15719745451926752893)],
        &[(0b10010, &ENTRY_EVANGELIZERS_13970259288304829321)],
        &[(0b10010, &ENTRY_EVANGELIZES_6848716766820134553)],
        &[(0b10010, &ENTRY_EVANGELIZING_9044162222729137139)],
        &[(0b01001, &ENTRY_EVANGELIZATION_95918260299241119)],
        &[(0b01001, &ENTRY_EVANGELIZATIONS_13830601721028602369)],
        &[(0b01001, &ENTRY_EVANGELIZE_3816430481934936599)],
        &[(0b01001, &ENTRY_EVANGELIZED_17447599926020044651)],
        &[(0b01001, &ENTRY_EVANGELIZER_15719745451926752893)],
        &[(0b01001, &ENTRY_EVANGELIZERS_13970259288304829321)],
        &[(0b01001, &ENTRY_EVANGELIZES_6848716766820134553)],
        &[(0b01001, &ENTRY_EVANGELIZING_9044162222729137139)],
        &[(0b10010, &ENTRY_EVENTUALIZE_16723569842023845082)],
        &[(0b10010, &ENTRY_EVENTUALIZED_16397818441261841688)],
        &[(0b10010, &ENTRY_EVENTUALIZES_9980302890707619422)],
        &[(0b10010, &ENTRY_EVENTUALIZING_16722303449748485140)],
        &[(0b01001, &ENTRY_EVENTUALIZE_16723569842023845082)],
        &[(0b01001, &ENTRY_EVENTUALIZED_16397818441261841688)],
        &[(0b01001, &ENTRY_EVENTUALIZES_9980302890707619422)],
        &[(0b01001, &ENTRY_EVENTUALIZING_16722303449748485140)],
        &[(0b00001, &ENTRY_EVILER_1511493183642407212)],
        &[(0b00001, &ENTRY_EVILEST_13211136907355422438)],
        &[(0b11010, &ENTRY_EVILER_1511493183642407212)],
        &[(0b11010, &ENTRY_EVILEST_13211136907355422438)],
        &[(0b00001, &ENTRY_EVITERNAL_7722180848811514076)],
        &[(0b10010, &ENTRY_EVOLUTIONIZE_8956862466662747203)],
        &[(0b10010, &ENTRY_EVOLUTIONIZES_9296464246749788558)],
        &[(0b01001, &ENTRY_EVOLUTIONIZE_8956862466662747203)],
        &[(0b01001, &ENTRY_EVOLUTIONIZES_9296464246749788558)],
    ],
    range: 4..=13,
};

static VARS_EU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EU_CHILDREN),
    value: None,
};

static VARS_EU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    Some(&VARS_EUD_NODE),
    None,
    None,
    None,
    Some(&VARS_EUH_NODE),
    None,
    None,
    None,
    Some(&VARS_EUL_NODE),
    None,
    Some(&VARS_EUN_NODE),
    None,
    Some(&VARS_EUP_NODE),
    None,
    Some(&VARS_EUR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_EUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EUR_CHILDREN),
    value: None,
};

pub static VARS_EUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("opeanisation"),
        dictgen::InsensitiveStr::Ascii("opeanisations"),
        dictgen::InsensitiveStr::Ascii("opeanise"),
        dictgen::InsensitiveStr::Ascii("opeanised"),
        dictgen::InsensitiveStr::Ascii("opeanises"),
        dictgen::InsensitiveStr::Ascii("opeanising"),
        dictgen::InsensitiveStr::Ascii("opeanization"),
        dictgen::InsensitiveStr::Ascii("opeanizations"),
        dictgen::InsensitiveStr::Ascii("opeanize"),
        dictgen::InsensitiveStr::Ascii("opeanized"),
        dictgen::InsensitiveStr::Ascii("opeanizes"),
        dictgen::InsensitiveStr::Ascii("opeanizing"),
        dictgen::InsensitiveStr::Ascii("yalae"),
        dictgen::InsensitiveStr::Ascii("yale"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EUROPEANIZATION_18182188015643339370)],
        &[(0b10010, &ENTRY_EUROPEANIZATIONS_11732866676783163952)],
        &[(0b10010, &ENTRY_EUROPEANIZE_7877119707137615478)],
        &[(0b10010, &ENTRY_EUROPEANIZED_5069713816195565465)],
        &[(0b10010, &ENTRY_EUROPEANIZES_15551253373119788515)],
        &[(0b10010, &ENTRY_EUROPEANIZING_2151542840584223646)],
        &[(0b01001, &ENTRY_EUROPEANIZATION_18182188015643339370)],
        &[(0b01001, &ENTRY_EUROPEANIZATIONS_11732866676783163952)],
        &[(0b01001, &ENTRY_EUROPEANIZE_7877119707137615478)],
        &[(0b01001, &ENTRY_EUROPEANIZED_5069713816195565465)],
        &[(0b01001, &ENTRY_EUROPEANIZES_15551253373119788515)],
        &[(0b01001, &ENTRY_EUROPEANIZING_2151542840584223646)],
        &[(0b11010, &ENTRY_EURYALE_6543953160332833947)],
        &[(0b00001, &ENTRY_EURYALE_6543953160332833947)],
    ],
    range: 4..=13,
};

static VARS_EUP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EUP_CHILDREN),
    value: None,
};

pub static VARS_EUP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hemisation"),
        dictgen::InsensitiveStr::Ascii("hemise"),
        dictgen::InsensitiveStr::Ascii("hemised"),
        dictgen::InsensitiveStr::Ascii("hemiser"),
        dictgen::InsensitiveStr::Ascii("hemisers"),
        dictgen::InsensitiveStr::Ascii("hemises"),
        dictgen::InsensitiveStr::Ascii("hemising"),
        dictgen::InsensitiveStr::Ascii("hemization"),
        dictgen::InsensitiveStr::Ascii("hemize"),
        dictgen::InsensitiveStr::Ascii("hemized"),
        dictgen::InsensitiveStr::Ascii("hemizer"),
        dictgen::InsensitiveStr::Ascii("hemizers"),
        dictgen::InsensitiveStr::Ascii("hemizes"),
        dictgen::InsensitiveStr::Ascii("hemizing"),
        dictgen::InsensitiveStr::Ascii("honisation"),
        dictgen::InsensitiveStr::Ascii("honise"),
        dictgen::InsensitiveStr::Ascii("honised"),
        dictgen::InsensitiveStr::Ascii("honises"),
        dictgen::InsensitiveStr::Ascii("honising"),
        dictgen::InsensitiveStr::Ascii("honization"),
        dictgen::InsensitiveStr::Ascii("honize"),
        dictgen::InsensitiveStr::Ascii("honized"),
        dictgen::InsensitiveStr::Ascii("honizes"),
        dictgen::InsensitiveStr::Ascii("honizing"),
        dictgen::InsensitiveStr::Ascii("huise"),
        dictgen::InsensitiveStr::Ascii("huised"),
        dictgen::InsensitiveStr::Ascii("huises"),
        dictgen::InsensitiveStr::Ascii("huising"),
        dictgen::InsensitiveStr::Ascii("huize"),
        dictgen::InsensitiveStr::Ascii("huized"),
        dictgen::InsensitiveStr::Ascii("huizes"),
        dictgen::InsensitiveStr::Ascii("huizing"),
        dictgen::InsensitiveStr::Ascii("nea"),
        dictgen::InsensitiveStr::Ascii("neas"),
        dictgen::InsensitiveStr::Ascii("neic"),
        dictgen::InsensitiveStr::Ascii("noea"),
        dictgen::InsensitiveStr::Ascii("noeas"),
        dictgen::InsensitiveStr::Ascii("noeic"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EUPHEMIZATION_4604811513238422771)],
        &[(0b10010, &ENTRY_EUPHEMIZE_6354436200580711971)],
        &[(0b10010, &ENTRY_EUPHEMIZED_384901376621156921)],
        &[(0b10010, &ENTRY_EUPHEMIZER_9802165878126248247)],
        &[(0b10010, &ENTRY_EUPHEMIZERS_3796382537388123060)],
        &[(0b10010, &ENTRY_EUPHEMIZES_17040532734112861700)],
        &[(0b10010, &ENTRY_EUPHEMIZING_12922673468625138298)],
        &[(0b01001, &ENTRY_EUPHEMIZATION_4604811513238422771)],
        &[(0b01001, &ENTRY_EUPHEMIZE_6354436200580711971)],
        &[(0b01001, &ENTRY_EUPHEMIZED_384901376621156921)],
        &[(0b01001, &ENTRY_EUPHEMIZER_9802165878126248247)],
        &[(0b01001, &ENTRY_EUPHEMIZERS_3796382537388123060)],
        &[(0b01001, &ENTRY_EUPHEMIZES_17040532734112861700)],
        &[(0b01001, &ENTRY_EUPHEMIZING_12922673468625138298)],
        &[(0b10010, &ENTRY_EUPHONIZATION_13942576290061210615)],
        &[(0b10010, &ENTRY_EUPHONIZE_14344073934911523788)],
        &[(0b10010, &ENTRY_EUPHONIZED_11998771033982272882)],
        &[(0b10010, &ENTRY_EUPHONIZES_8721809048241461661)],
        &[(0b10010, &ENTRY_EUPHONIZING_7148830146393117295)],
        &[(0b01001, &ENTRY_EUPHONIZATION_13942576290061210615)],
        &[(0b01001, &ENTRY_EUPHONIZE_14344073934911523788)],
        &[(0b01001, &ENTRY_EUPHONIZED_11998771033982272882)],
        &[(0b01001, &ENTRY_EUPHONIZES_8721809048241461661)],
        &[(0b01001, &ENTRY_EUPHONIZING_7148830146393117295)],
        &[(0b10010, &ENTRY_EUPHUIZE_9755428435828216359)],
        &[(0b10010, &ENTRY_EUPHUIZED_12869252973461985164)],
        &[(0b10010, &ENTRY_EUPHUIZES_13621859157470614114)],
        &[(0b10010, &ENTRY_EUPHUIZING_16039790140667819075)],
        &[(0b01001, &ENTRY_EUPHUIZE_9755428435828216359)],
        &[(0b01001, &ENTRY_EUPHUIZED_12869252973461985164)],
        &[(0b01001, &ENTRY_EUPHUIZES_13621859157470614114)],
        &[(0b01001, &ENTRY_EUPHUIZING_16039790140667819075)],
        &[(0b10001, &ENTRY_EUPNEA_17746307000139664788)],
        &[(0b10001, &ENTRY_EUPNEAS_17276821144216069652)],
        &[(0b10001, &ENTRY_EUPNEIC_9681633279055795805)],
        &[(0b11010, &ENTRY_EUPNEA_17746307000139664788)],
        &[(0b11010, &ENTRY_EUPNEAS_17276821144216069652)],
        &[(0b11010, &ENTRY_EUPNEIC_9681633279055795805)],
    ],
    range: 3..=10,
};

static VARS_EUN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EUN_CHILDREN),
    value: None,
};

pub static VARS_EUN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uchise"),
        dictgen::InsensitiveStr::Ascii("uchised"),
        dictgen::InsensitiveStr::Ascii("uchises"),
        dictgen::InsensitiveStr::Ascii("uchising"),
        dictgen::InsensitiveStr::Ascii("uchize"),
        dictgen::InsensitiveStr::Ascii("uchized"),
        dictgen::InsensitiveStr::Ascii("uchizes"),
        dictgen::InsensitiveStr::Ascii("uchizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EUNUCHIZE_10259306639961171201)],
        &[(0b10010, &ENTRY_EUNUCHIZED_14146598531946186034)],
        &[(0b10010, &ENTRY_EUNUCHIZES_4246443737378485094)],
        &[(0b10010, &ENTRY_EUNUCHIZING_2192880783995883311)],
        &[(0b01001, &ENTRY_EUNUCHIZE_10259306639961171201)],
        &[(0b01001, &ENTRY_EUNUCHIZED_14146598531946186034)],
        &[(0b01001, &ENTRY_EUNUCHIZES_4246443737378485094)],
        &[(0b01001, &ENTRY_EUNUCHIZING_2192880783995883311)],
    ],
    range: 6..=8,
};

static VARS_EUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EUL_CHILDREN),
    value: None,
};

pub static VARS_EUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ogisation"),
        dictgen::InsensitiveStr::Ascii("ogisations"),
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogiser"),
        dictgen::InsensitiveStr::Ascii("ogisers"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogization"),
        dictgen::InsensitiveStr::Ascii("ogizations"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizer"),
        dictgen::InsensitiveStr::Ascii("ogizers"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EULOGIZATION_5947448978701222305)],
        &[(0b10010, &ENTRY_EULOGIZATIONS_9338629993379429591)],
        &[(0b10010, &ENTRY_EULOGIZE_5057583596298469791)],
        &[(0b10010, &ENTRY_EULOGIZED_8728323980549981685)],
        &[(0b10010, &ENTRY_EULOGIZER_10010536596440365165)],
        &[(0b10010, &ENTRY_EULOGIZERS_10246860860507041023)],
        &[(0b10010, &ENTRY_EULOGIZES_3835732440821657383)],
        &[(0b10010, &ENTRY_EULOGIZING_13191497739725600277)],
        &[(0b01001, &ENTRY_EULOGIZATION_5947448978701222305)],
        &[(0b01001, &ENTRY_EULOGIZATIONS_9338629993379429591)],
        &[(0b01001, &ENTRY_EULOGIZE_5057583596298469791)],
        &[(0b01001, &ENTRY_EULOGIZED_8728323980549981685)],
        &[(0b01001, &ENTRY_EULOGIZER_10010536596440365165)],
        &[(0b01001, &ENTRY_EULOGIZERS_10246860860507041023)],
        &[(0b01001, &ENTRY_EULOGIZES_3835732440821657383)],
        &[(0b01001, &ENTRY_EULOGIZING_13191497739725600277)],
    ],
    range: 5..=10,
};

static VARS_EUH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EUH_CHILDREN),
    value: None,
};

pub static VARS_EUH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emerise"),
        dictgen::InsensitiveStr::Ascii("emerised"),
        dictgen::InsensitiveStr::Ascii("emerises"),
        dictgen::InsensitiveStr::Ascii("emerising"),
        dictgen::InsensitiveStr::Ascii("emerize"),
        dictgen::InsensitiveStr::Ascii("emerized"),
        dictgen::InsensitiveStr::Ascii("emerizes"),
        dictgen::InsensitiveStr::Ascii("emerizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EUHEMERIZE_1873489264803474104)],
        &[(0b10010, &ENTRY_EUHEMERIZED_1257860755272726832)],
        &[(0b10010, &ENTRY_EUHEMERIZES_12953299966839264414)],
        &[(0b10010, &ENTRY_EUHEMERIZING_10612611578853640855)],
        &[(0b01001, &ENTRY_EUHEMERIZE_1873489264803474104)],
        &[(0b01001, &ENTRY_EUHEMERIZED_1257860755272726832)],
        &[(0b01001, &ENTRY_EUHEMERIZES_12953299966839264414)],
        &[(0b01001, &ENTRY_EUHEMERIZING_10612611578853640855)],
    ],
    range: 7..=9,
};

static VARS_EUD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EUD_CHILDREN),
    value: None,
};

pub static VARS_EUD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemon"),
        dictgen::InsensitiveStr::Ascii("aemonia"),
        dictgen::InsensitiveStr::Ascii("aemonic"),
        dictgen::InsensitiveStr::Ascii("aemonics"),
        dictgen::InsensitiveStr::Ascii("aemonism"),
        dictgen::InsensitiveStr::Ascii("aemonisms"),
        dictgen::InsensitiveStr::Ascii("aemonist"),
        dictgen::InsensitiveStr::Ascii("aemonistic"),
        dictgen::InsensitiveStr::Ascii("aemonistical"),
        dictgen::InsensitiveStr::Ascii("aemonistically"),
        dictgen::InsensitiveStr::Ascii("aemonists"),
        dictgen::InsensitiveStr::Ascii("aemons"),
        dictgen::InsensitiveStr::Ascii("aemony"),
        dictgen::InsensitiveStr::Ascii("emon"),
        dictgen::InsensitiveStr::Ascii("emonia"),
        dictgen::InsensitiveStr::Ascii("emonic"),
        dictgen::InsensitiveStr::Ascii("emonics"),
        dictgen::InsensitiveStr::Ascii("emonism"),
        dictgen::InsensitiveStr::Ascii("emonisms"),
        dictgen::InsensitiveStr::Ascii("emonist"),
        dictgen::InsensitiveStr::Ascii("emonistic"),
        dictgen::InsensitiveStr::Ascii("emonistical"),
        dictgen::InsensitiveStr::Ascii("emonistically"),
        dictgen::InsensitiveStr::Ascii("emonists"),
        dictgen::InsensitiveStr::Ascii("emons"),
        dictgen::InsensitiveStr::Ascii("emony"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EUDEMON_17986635969239112588)],
        &[(0b11010, &ENTRY_EUDEMONIA_18223617891572262880)],
        &[(0b11010, &ENTRY_EUDEMONIC_18143957865317361790)],
        &[(0b11010, &ENTRY_EUDEMONICS_12311044969757068160)],
        &[(0b11010, &ENTRY_EUDEMONISM_3198415778868906023)],
        &[(0b11010, &ENTRY_EUDEMONISMS_17240174868453336510)],
        &[(0b11010, &ENTRY_EUDEMONIST_1610000011487064015)],
        &[(0b11010, &ENTRY_EUDEMONISTIC_1201869317686510728)],
        &[(0b11010, &ENTRY_EUDEMONISTICAL_17188010531930040532)],
        &[(0b11010, &ENTRY_EUDEMONISTICALLY_14824474640377417299)],
        &[(0b11010, &ENTRY_EUDEMONISTS_16625298983105767355)],
        &[(0b11010, &ENTRY_EUDEMONS_11289948523164572570)],
        &[(0b11010, &ENTRY_EUDEMONY_15219598488262475209)],
        &[(0b00001, &ENTRY_EUDEMON_17986635969239112588)],
        &[(0b00001, &ENTRY_EUDEMONIA_18223617891572262880)],
        &[(0b00001, &ENTRY_EUDEMONIC_18143957865317361790)],
        &[(0b00001, &ENTRY_EUDEMONICS_12311044969757068160)],
        &[(0b00001, &ENTRY_EUDEMONISM_3198415778868906023)],
        &[(0b00001, &ENTRY_EUDEMONISMS_17240174868453336510)],
        &[(0b00001, &ENTRY_EUDEMONIST_1610000011487064015)],
        &[(0b00001, &ENTRY_EUDEMONISTIC_1201869317686510728)],
        &[(0b00001, &ENTRY_EUDEMONISTICAL_17188010531930040532)],
        &[(0b00001, &ENTRY_EUDEMONISTICALLY_14824474640377417299)],
        &[(0b00001, &ENTRY_EUDEMONISTS_16625298983105767355)],
        &[(0b00001, &ENTRY_EUDEMONS_11289948523164572570)],
        &[(0b00001, &ENTRY_EUDEMONY_15219598488262475209)],
    ],
    range: 4..=14,
};

static VARS_ET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ET_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_ET_16709700743642230371)]),
};

static VARS_ET_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_ETE_NODE),
    None,
    None,
    Some(&VARS_ETH_NODE),
    Some(&VARS_ETI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ETY_NODE),
    None,
];

static VARS_ETY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ETY_CHILDREN),
    value: None,
};

pub static VARS_ETY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mologisable"),
        dictgen::InsensitiveStr::Ascii("mologisation"),
        dictgen::InsensitiveStr::Ascii("mologise"),
        dictgen::InsensitiveStr::Ascii("mologised"),
        dictgen::InsensitiveStr::Ascii("mologises"),
        dictgen::InsensitiveStr::Ascii("mologising"),
        dictgen::InsensitiveStr::Ascii("mologizable"),
        dictgen::InsensitiveStr::Ascii("mologization"),
        dictgen::InsensitiveStr::Ascii("mologize"),
        dictgen::InsensitiveStr::Ascii("mologized"),
        dictgen::InsensitiveStr::Ascii("mologizes"),
        dictgen::InsensitiveStr::Ascii("mologizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ETYMOLOGIZABLE_1283253131804877951)],
        &[(0b10010, &ENTRY_ETYMOLOGIZATION_15298692810390985104)],
        &[(0b10010, &ENTRY_ETYMOLOGIZE_11288336530403962791)],
        &[(0b10010, &ENTRY_ETYMOLOGIZED_2645595824075873147)],
        &[(0b10010, &ENTRY_ETYMOLOGIZES_13710053144878095709)],
        &[(0b10010, &ENTRY_ETYMOLOGIZING_1743090802525341227)],
        &[(0b01001, &ENTRY_ETYMOLOGIZABLE_1283253131804877951)],
        &[(0b01001, &ENTRY_ETYMOLOGIZATION_15298692810390985104)],
        &[(0b01001, &ENTRY_ETYMOLOGIZE_11288336530403962791)],
        &[(0b01001, &ENTRY_ETYMOLOGIZED_2645595824075873147)],
        &[(0b01001, &ENTRY_ETYMOLOGIZES_13710053144878095709)],
        &[(0b01001, &ENTRY_ETYMOLOGIZING_1743090802525341227)],
    ],
    range: 8..=12,
};

static VARS_ETI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ETI_CHILDREN),
    value: None,
};

pub static VARS_ETI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ogenic"),
        dictgen::InsensitiveStr::Ascii("ologically"),
        dictgen::InsensitiveStr::Ascii("ologist"),
        dictgen::InsensitiveStr::Ascii("ologue"),
        dictgen::InsensitiveStr::Ascii("ology"),
        dictgen::InsensitiveStr::Ascii("ophyllin"),
        dictgen::InsensitiveStr::Ascii("otropic"),
        dictgen::InsensitiveStr::Ascii("otropically"),
    ],
    values: &[
        &[(0b10001, &ENTRY_ETIOGENIC_3830033599800632807)],
        &[(0b11001, &ENTRY_ETIOLOGICALLY_1064612193650452227)],
        &[(0b10001, &ENTRY_ETIOLOGIST_7320826493575703902)],
        &[(0b10001, &ENTRY_ETIOLOGUE_4428360053767153112)],
        &[(0b11001, &ENTRY_ETIOLOGY_4658311861857715324)],
        &[(0b10001, &ENTRY_ETIOPHYLLIN_7707186585402559694)],
        &[(0b10001, &ENTRY_ETIOTROPIC_18055180651114367254)],
        &[(0b10001, &ENTRY_ETIOTROPICALLY_1085913366626989126)],
    ],
    range: 5..=11,
};

static VARS_ETH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ETH_CHILDREN),
    value: None,
};

pub static VARS_ETH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("erealisation"),
        dictgen::InsensitiveStr::Ascii("erealisations"),
        dictgen::InsensitiveStr::Ascii("erealise"),
        dictgen::InsensitiveStr::Ascii("erealised"),
        dictgen::InsensitiveStr::Ascii("erealises"),
        dictgen::InsensitiveStr::Ascii("erealising"),
        dictgen::InsensitiveStr::Ascii("erealization"),
        dictgen::InsensitiveStr::Ascii("erealizations"),
        dictgen::InsensitiveStr::Ascii("erealize"),
        dictgen::InsensitiveStr::Ascii("erealized"),
        dictgen::InsensitiveStr::Ascii("erealizes"),
        dictgen::InsensitiveStr::Ascii("erealizing"),
        dictgen::InsensitiveStr::Ascii("ered"),
        dictgen::InsensitiveStr::Ascii("erialisation"),
        dictgen::InsensitiveStr::Ascii("erialise"),
        dictgen::InsensitiveStr::Ascii("erialised"),
        dictgen::InsensitiveStr::Ascii("erialising"),
        dictgen::InsensitiveStr::Ascii("erialization"),
        dictgen::InsensitiveStr::Ascii("erialize"),
        dictgen::InsensitiveStr::Ascii("erialized"),
        dictgen::InsensitiveStr::Ascii("erializing"),
        dictgen::InsensitiveStr::Ascii("eric"),
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("eriser"),
        dictgen::InsensitiveStr::Ascii("erisers"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erising"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizer"),
        dictgen::InsensitiveStr::Ascii("erizers"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("erizing"),
        dictgen::InsensitiveStr::Ascii("icisation"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icization"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icizing"),
        dictgen::InsensitiveStr::Ascii("nicise"),
        dictgen::InsensitiveStr::Ascii("nicises"),
        dictgen::InsensitiveStr::Ascii("nicize"),
        dictgen::InsensitiveStr::Ascii("nicizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ETHELING_18173115252038941149)],
        &[(0b10010, &ENTRY_ETHEREALIZATION_13082768097000267498)],
        &[(0b10010, &ENTRY_ETHEREALIZATIONS_83785244619387097)],
        &[(0b10010, &ENTRY_ETHEREALIZE_15643873766006860610)],
        &[(0b10010, &ENTRY_ETHEREALIZED_8598724633944495192)],
        &[(0b10010, &ENTRY_ETHEREALIZES_2996813688575204992)],
        &[(0b10010, &ENTRY_ETHEREALIZING_9763005237046272153)],
        &[(0b01001, &ENTRY_ETHEREALIZATION_13082768097000267498)],
        &[(0b01001, &ENTRY_ETHEREALIZATIONS_83785244619387097)],
        &[(0b01001, &ENTRY_ETHEREALIZE_15643873766006860610)],
        &[(0b01001, &ENTRY_ETHEREALIZED_8598724633944495192)],
        &[(0b01001, &ENTRY_ETHEREALIZES_2996813688575204992)],
        &[(0b01001, &ENTRY_ETHEREALIZING_9763005237046272153)],
        &[(0b00001, &ENTRY_ETHERED_14211226607017083705)],
        &[(0b10010, &ENTRY_ETHERIALIZATION_16353693822285712895)],
        &[(0b10010, &ENTRY_ETHERIALIZE_9662916742832206613)],
        &[(0b10010, &ENTRY_ETHERIALIZED_17886169690318510304)],
        &[(0b10010, &ENTRY_ETHERIALIZING_8415609041393721050)],
        &[(0b01001, &ENTRY_ETHERIALIZATION_16353693822285712895)],
        &[(0b01001, &ENTRY_ETHERIALIZE_9662916742832206613)],
        &[(0b01001, &ENTRY_ETHERIALIZED_17886169690318510304)],
        &[(0b01001, &ENTRY_ETHERIALIZING_8415609041393721050)],
        &[(0b00001, &ENTRY_ETHERIC_10479002354969561160)],
        &[(0b10010, &ENTRY_ETHERIZATION_15509189480857162676)],
        &[(0b10010, &ENTRY_ETHERIZATIONS_13335802035112138)],
        &[(0b10010, &ENTRY_ETHERIZE_7063818294001377173)],
        &[(0b10010, &ENTRY_ETHERIZED_12616495300571811734)],
        &[(0b10010, &ENTRY_ETHERIZER_17889160100693239960)],
        &[(0b10010, &ENTRY_ETHERIZERS_6371393300060848641)],
        &[(0b10010, &ENTRY_ETHERIZES_13639595418596582424)],
        &[(0b10010, &ENTRY_ETHERIZING_1369052890079428803)],
        &[(0b01001, &ENTRY_ETHERIZATION_15509189480857162676)],
        &[(0b01001, &ENTRY_ETHERIZATIONS_13335802035112138)],
        &[(0b01001, &ENTRY_ETHERIZE_7063818294001377173)],
        &[(0b01001, &ENTRY_ETHERIZED_12616495300571811734)],
        &[(0b01001, &ENTRY_ETHERIZER_17889160100693239960)],
        &[(0b01001, &ENTRY_ETHERIZERS_6371393300060848641)],
        &[(0b01001, &ENTRY_ETHERIZES_13639595418596582424)],
        &[(0b01001, &ENTRY_ETHERIZING_1369052890079428803)],
        &[(0b10010, &ENTRY_ETHICIZATION_16096230827577668151)],
        &[(0b10010, &ENTRY_ETHICIZE_16707329152141021939)],
        &[(0b10010, &ENTRY_ETHICIZED_3108258699595454839)],
        &[(0b10010, &ENTRY_ETHICIZES_16736624923762826452)],
        &[(0b10010, &ENTRY_ETHICIZING_1886109304857970107)],
        &[(0b01001, &ENTRY_ETHICIZATION_16096230827577668151)],
        &[(0b01001, &ENTRY_ETHICIZE_16707329152141021939)],
        &[(0b01001, &ENTRY_ETHICIZED_3108258699595454839)],
        &[(0b01001, &ENTRY_ETHICIZES_16736624923762826452)],
        &[(0b01001, &ENTRY_ETHICIZING_1886109304857970107)],
        &[(0b10010, &ENTRY_ETHNICIZE_12312081762720332735)],
        &[(0b10010, &ENTRY_ETHNICIZES_960663240708525169)],
        &[(0b01001, &ENTRY_ETHNICIZE_12312081762720332735)],
        &[(0b01001, &ENTRY_ETHNICIZES_960663240708525169)],
    ],
    range: 4..=13,
};

static VARS_ETE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ETE_CHILDREN),
    value: None,
};

pub static VARS_ETE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rnalisation"),
        dictgen::InsensitiveStr::Ascii("rnalisations"),
        dictgen::InsensitiveStr::Ascii("rnalise"),
        dictgen::InsensitiveStr::Ascii("rnalised"),
        dictgen::InsensitiveStr::Ascii("rnalises"),
        dictgen::InsensitiveStr::Ascii("rnalising"),
        dictgen::InsensitiveStr::Ascii("rnalization"),
        dictgen::InsensitiveStr::Ascii("rnalizations"),
        dictgen::InsensitiveStr::Ascii("rnalize"),
        dictgen::InsensitiveStr::Ascii("rnalized"),
        dictgen::InsensitiveStr::Ascii("rnalizes"),
        dictgen::InsensitiveStr::Ascii("rnalizing"),
        dictgen::InsensitiveStr::Ascii("rnisation"),
        dictgen::InsensitiveStr::Ascii("rnisations"),
        dictgen::InsensitiveStr::Ascii("rnise"),
        dictgen::InsensitiveStr::Ascii("rnised"),
        dictgen::InsensitiveStr::Ascii("rnises"),
        dictgen::InsensitiveStr::Ascii("rnising"),
        dictgen::InsensitiveStr::Ascii("rnization"),
        dictgen::InsensitiveStr::Ascii("rnizations"),
        dictgen::InsensitiveStr::Ascii("rnize"),
        dictgen::InsensitiveStr::Ascii("rnized"),
        dictgen::InsensitiveStr::Ascii("rnizes"),
        dictgen::InsensitiveStr::Ascii("rnizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ETERNALIZATION_4110507715995538457)],
        &[(0b10010, &ENTRY_ETERNALIZATIONS_12324801645258560585)],
        &[(0b10010, &ENTRY_ETERNALIZE_16866605418824842181)],
        &[(0b10010, &ENTRY_ETERNALIZED_3895092792354325191)],
        &[(0b10010, &ENTRY_ETERNALIZES_10340106011591437418)],
        &[(0b10010, &ENTRY_ETERNALIZING_3666087619740459810)],
        &[(0b01001, &ENTRY_ETERNALIZATION_4110507715995538457)],
        &[(0b01001, &ENTRY_ETERNALIZATIONS_12324801645258560585)],
        &[(0b01001, &ENTRY_ETERNALIZE_16866605418824842181)],
        &[(0b01001, &ENTRY_ETERNALIZED_3895092792354325191)],
        &[(0b01001, &ENTRY_ETERNALIZES_10340106011591437418)],
        &[(0b01001, &ENTRY_ETERNALIZING_3666087619740459810)],
        &[(0b10010, &ENTRY_ETERNIZATION_14956756864369663492)],
        &[(0b10010, &ENTRY_ETERNIZATIONS_8191041802187544405)],
        &[(0b10010, &ENTRY_ETERNIZE_11185630111475812769)],
        &[(0b10010, &ENTRY_ETERNIZED_13686686999560830605)],
        &[(0b10010, &ENTRY_ETERNIZES_11290183965659731900)],
        &[(0b10010, &ENTRY_ETERNIZING_11205061293945003520)],
        &[(0b01001, &ENTRY_ETERNIZATION_14956756864369663492)],
        &[(0b01001, &ENTRY_ETERNIZATIONS_8191041802187544405)],
        &[(0b01001, &ENTRY_ETERNIZE_11185630111475812769)],
        &[(0b01001, &ENTRY_ETERNIZED_13686686999560830605)],
        &[(0b01001, &ENTRY_ETERNIZES_11290183965659731900)],
        &[(0b01001, &ENTRY_ETERNIZING_11205061293945003520)],
    ],
    range: 5..=12,
};

static VARS_ES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ES_CHILDREN),
    value: None,
};

static VARS_ES_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_ESC_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ESK_NODE),
    None,
    None,
    None,
    Some(&VARS_ESO_NODE),
    None,
    None,
    None,
    Some(&VARS_ESS_NODE),
    Some(&VARS_EST_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_EST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EST_CHILDREN),
    value: None,
};

pub static VARS_EST_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("heses"),
        dictgen::InsensitiveStr::Ascii("hesia"),
        dictgen::InsensitiveStr::Ascii("hesias"),
        dictgen::InsensitiveStr::Ascii("hesiogen"),
        dictgen::InsensitiveStr::Ascii("hesiogenic"),
        dictgen::InsensitiveStr::Ascii("hesiogens"),
        dictgen::InsensitiveStr::Ascii("hesis"),
        dictgen::InsensitiveStr::Ascii("hete"),
        dictgen::InsensitiveStr::Ascii("hetes"),
        dictgen::InsensitiveStr::Ascii("hetic"),
        dictgen::InsensitiveStr::Ascii("hetical"),
        dictgen::InsensitiveStr::Ascii("hetically"),
        dictgen::InsensitiveStr::Ascii("hetician"),
        dictgen::InsensitiveStr::Ascii("heticians"),
        dictgen::InsensitiveStr::Ascii("hetics"),
        dictgen::InsensitiveStr::Ascii("ival"),
        dictgen::InsensitiveStr::Ascii("ivate"),
        dictgen::InsensitiveStr::Ascii("ivated"),
        dictgen::InsensitiveStr::Ascii("ivates"),
        dictgen::InsensitiveStr::Ascii("ivating"),
        dictgen::InsensitiveStr::Ascii("ivation"),
        dictgen::InsensitiveStr::Ascii("ivations"),
        dictgen::InsensitiveStr::Ascii("ivator"),
        dictgen::InsensitiveStr::Ascii("ive"),
        dictgen::InsensitiveStr::Ascii("radiol"),
        dictgen::InsensitiveStr::Ascii("radiols"),
        dictgen::InsensitiveStr::Ascii("ral"),
        dictgen::InsensitiveStr::Ascii("rin"),
        dictgen::InsensitiveStr::Ascii("rins"),
        dictgen::InsensitiveStr::Ascii("riol"),
        dictgen::InsensitiveStr::Ascii("riols"),
        dictgen::InsensitiveStr::Ascii("rogen"),
        dictgen::InsensitiveStr::Ascii("rogenic"),
        dictgen::InsensitiveStr::Ascii("rogens"),
        dictgen::InsensitiveStr::Ascii("rone"),
        dictgen::InsensitiveStr::Ascii("rones"),
        dictgen::InsensitiveStr::Ascii("rous"),
        dictgen::InsensitiveStr::Ascii("rual"),
        dictgen::InsensitiveStr::Ascii("ruate"),
        dictgen::InsensitiveStr::Ascii("ruation"),
        dictgen::InsensitiveStr::Ascii("rum"),
        dictgen::InsensitiveStr::Ascii("rums"),
        dictgen::InsensitiveStr::Ascii("rus"),
        dictgen::InsensitiveStr::Ascii("ruses"),
        dictgen::InsensitiveStr::Ascii("uate"),
        dictgen::InsensitiveStr::Ascii("uous"),
        dictgen::InsensitiveStr::Ascii("ure"),
        dictgen::InsensitiveStr::Ascii("us"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ESTERIZATION_3456588518882788686)],
        &[(0b10010, &ENTRY_ESTERIZATIONS_1619303577440464586)],
        &[(0b10010, &ENTRY_ESTERIZE_12877587379463570837)],
        &[(0b10010, &ENTRY_ESTERIZES_4040354113500129245)],
        &[(0b01001, &ENTRY_ESTERIZATION_3456588518882788686)],
        &[(0b01001, &ENTRY_ESTERIZATIONS_1619303577440464586)],
        &[(0b01001, &ENTRY_ESTERIZE_12877587379463570837)],
        &[(0b01001, &ENTRY_ESTERIZES_4040354113500129245)],
        &[(0b00001, &ENTRY_ESTHESES_5781061020988119088)],
        &[(0b00001, &ENTRY_ESTHESIA_5605519706169745255)],
        &[(0b00001, &ENTRY_ESTHESIAS_18077472499145709356)],
        &[(0b00001, &ENTRY_ESTHESIOGEN_13850970942201599568)],
        &[(0b00001, &ENTRY_ESTHESIOGENIC_8568990898680713091)],
        &[(0b00001, &ENTRY_ESTHESIOGENS_2539942402442311753)],
        &[(0b00001, &ENTRY_ESTHESIS_17178990420713935317)],
        &[(0b00001, &ENTRY_AESTHETE_6475321551135991601)],
        &[(0b00001, &ENTRY_AESTHETES_15012821507993100258)],
        &[(0b11001, &ENTRY_AESTHETIC_5817909166486372441)],
        &[(0b00001, &ENTRY_ESTHETICAL_7594838462752271800)],
        &[(0b00001, &ENTRY_AESTHETICALLY_4393362297255043635)],
        &[(0b01001, &ENTRY_ESTHETICIAN_6690642998636082700)],
        &[(0b01001, &ENTRY_ESTHETICIANS_16857352085837156733)],
        &[(0b11001, &ENTRY_AESTHETICS_3207114874897219410)],
        &[(0b01001, &ENTRY_ESTIVAL_11802673568747360369)],
        &[(0b01001, &ENTRY_ESTIVATE_10836493401844257867)],
        &[(0b01001, &ENTRY_ESTIVATED_5948189904457603376)],
        &[(0b01001, &ENTRY_ESTIVATES_8627334418178723288)],
        &[(0b01001, &ENTRY_ESTIVATING_9498433178617024784)],
        &[(0b01001, &ENTRY_ESTIVATION_6434066985142123064)],
        &[(0b01001, &ENTRY_ESTIVATIONS_15940487245092349305)],
        &[(0b00001, &ENTRY_ESTIVATOR_1664787615112181438)],
        &[(0b00001, &ENTRY_ESTIVE_4965384148538852144)],
        &[(0b00001, &ENTRY_ESTRADIOL_31151792297264606)],
        &[(0b00001, &ENTRY_ESTRADIOLS_6635571464074472879)],
        &[(0b00001, &ENTRY_ESTRAL_4263474669881304636)],
        &[(0b00001, &ENTRY_ESTRIN_17130710844251925900)],
        &[(0b00001, &ENTRY_ESTRINS_17829170952547459464)],
        &[(0b00001, &ENTRY_ESTRIOL_14358431962924162389)],
        &[(0b00001, &ENTRY_ESTRIOLS_1134091154686696143)],
        &[(0b11001, &ENTRY_ESTROGEN_10173348120996063533)],
        &[(0b11001, &ENTRY_ESTROGENIC_3724956938647222280)],
        &[(0b11001, &ENTRY_ESTROGENS_11487970579706669068)],
        &[(0b00001, &ENTRY_ESTRONE_9986540566043863893)],
        &[(0b00001, &ENTRY_ESTRONES_10736858198614463395)],
        &[(0b01001, &ENTRY_ESTROUS_7878210273842809015)],
        &[(0b00001, &ENTRY_ESTRUAL_8880059716302502408)],
        &[(0b00001, &ENTRY_ESTRUATE_16347180830721817630)],
        &[(0b00001, &ENTRY_ESTRUATION_16723443098265001574)],
        &[(0b00001, &ENTRY_ESTRUM_14101011195419605525)],
        &[(0b00001, &ENTRY_ESTRUMS_7268966665464885989)],
        &[(0b01001, &ENTRY_ESTRUS_391811675946213924)],
        &[(0b01001, &ENTRY_ESTRUSES_7947106804154830951)],
        &[(0b00001, &ENTRY_ESTUATE_5365503068852828289)],
        &[(0b00001, &ENTRY_ESTUOUS_10323897909821636581)],
        &[(0b00001, &ENTRY_ESTURE_10845028240222484807)],
        &[(0b00001, &ENTRY_ESTUS_3275119451126332640)],
    ],
    range: 2..=10,
};

static VARS_ESS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ESS_CHILDREN),
    value: None,
};

pub static VARS_ESS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("entialise"),
        dictgen::InsensitiveStr::Ascii("entialises"),
        dictgen::InsensitiveStr::Ascii("entialize"),
        dictgen::InsensitiveStr::Ascii("entializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ESSENIZE_18159451946304315226)],
        &[(0b10010, &ENTRY_ESSENIZES_14419866103970364748)],
        &[(0b01001, &ENTRY_ESSENIZE_18159451946304315226)],
        &[(0b01001, &ENTRY_ESSENIZES_14419866103970364748)],
        &[(0b10010, &ENTRY_ESSENTIALIZE_9743875167123692674)],
        &[(0b10010, &ENTRY_ESSENTIALIZES_7259234954513904851)],
        &[(0b01001, &ENTRY_ESSENTIALIZE_9743875167123692674)],
        &[(0b01001, &ENTRY_ESSENTIALIZES_7259234954513904851)],
    ],
    range: 5..=10,
};

static VARS_ESO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ESO_CHILDREN),
    value: None,
};

pub static VARS_ESO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("p"),
        dictgen::InsensitiveStr::Ascii("phagal"),
        dictgen::InsensitiveStr::Ascii("phagean"),
        dictgen::InsensitiveStr::Ascii("phagi"),
        dictgen::InsensitiveStr::Ascii("phagism"),
        dictgen::InsensitiveStr::Ascii("phagismus"),
        dictgen::InsensitiveStr::Ascii("phagitis"),
        dictgen::InsensitiveStr::Ascii("phagus"),
        dictgen::InsensitiveStr::Ascii("phaguses"),
    ],
    values: &[
        &[(0b10001, &ENTRY_ESOP_12400930167674936381)],
        &[(0b10001, &ENTRY_ESOPHAGAL_11568993434283087514)],
        &[(0b10001, &ENTRY_ESOPHAGEAN_9494840858799849160)],
        &[(0b11001, &ENTRY_ESOPHAGI_11954876978132806506)],
        &[(0b10001, &ENTRY_ESOPHAGISM_13497979405696032460)],
        &[(0b10001, &ENTRY_ESOPHAGISMUS_12116284235422316328)],
        &[(0b10001, &ENTRY_ESOPHAGITIS_13843737924467364508)],
        &[(0b10001, &ENTRY_ESOPHAGUS_17094499599237101062)],
        &[(0b01001, &ENTRY_ESOPHAGI_11954876978132806506)],
    ],
    range: 1..=9,
};

static VARS_ESK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ESK_CHILDREN),
    value: None,
};

pub static VARS_ESK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("imoised"),
        dictgen::InsensitiveStr::Ascii("imoiseds"),
        dictgen::InsensitiveStr::Ascii("imoized"),
        dictgen::InsensitiveStr::Ascii("imoizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ESKIMOIZED_10184376049707311673)],
        &[(0b10010, &ENTRY_ESKIMOIZEDS_2972627145285856881)],
        &[(0b01001, &ENTRY_ESKIMOIZED_10184376049707311673)],
        &[(0b01001, &ENTRY_ESKIMOIZEDS_2972627145285856881)],
    ],
    range: 7..=8,
};

static VARS_ESC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ESC_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_ESC_11648574405051320816)]),
};

pub static VARS_ESC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alades"),
        dictgen::InsensitiveStr::Ascii("aladoes"),
        dictgen::InsensitiveStr::Ascii("hynite"),
        dictgen::InsensitiveStr::Ascii("ulapian"),
        dictgen::InsensitiveStr::Ascii("uletin"),
        dictgen::InsensitiveStr::Ascii("ulin"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ESCALADES_9736873074637956409)],
        &[(0b11010, &ENTRY_ESCALADES_9736873074637956409)],
        &[(0b00001, &ENTRY_ESCHYNITE_2605089747859204015)],
        &[(0b00001, &ENTRY_ESCULAPIAN_13519492358303592154)],
        &[(0b00001, &ENTRY_ESCULETIN_672994155433346330)],
        &[(0b00001, &ENTRY_ESCULIN_12107528280435336696)],
    ],
    range: 4..=7,
};

static VARS_ER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ER_CHILDREN),
    value: None,
};

pub static VARS_ER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bia"),
        dictgen::InsensitiveStr::Ascii("bias"),
        dictgen::InsensitiveStr::Ascii("gotise"),
        dictgen::InsensitiveStr::Ascii("gotised"),
        dictgen::InsensitiveStr::Ascii("gotises"),
        dictgen::InsensitiveStr::Ascii("gotising"),
        dictgen::InsensitiveStr::Ascii("gotize"),
        dictgen::InsensitiveStr::Ascii("gotized"),
        dictgen::InsensitiveStr::Ascii("gotizes"),
        dictgen::InsensitiveStr::Ascii("gotizing"),
        dictgen::InsensitiveStr::Ascii("ic"),
        dictgen::InsensitiveStr::Ascii("ical"),
        dictgen::InsensitiveStr::Ascii("ke"),
        dictgen::InsensitiveStr::Ascii("n"),
        dictgen::InsensitiveStr::Ascii("nes"),
        dictgen::InsensitiveStr::Ascii("nest"),
        dictgen::InsensitiveStr::Ascii("ns"),
        dictgen::InsensitiveStr::Ascii("ogenesis"),
        dictgen::InsensitiveStr::Ascii("ogenic"),
        dictgen::InsensitiveStr::Ascii("os"),
        dictgen::InsensitiveStr::Ascii("ose"),
        dictgen::InsensitiveStr::Ascii("oticisation"),
        dictgen::InsensitiveStr::Ascii("oticise"),
        dictgen::InsensitiveStr::Ascii("oticised"),
        dictgen::InsensitiveStr::Ascii("oticises"),
        dictgen::InsensitiveStr::Ascii("oticising"),
        dictgen::InsensitiveStr::Ascii("oticization"),
        dictgen::InsensitiveStr::Ascii("oticize"),
        dictgen::InsensitiveStr::Ascii("oticized"),
        dictgen::InsensitiveStr::Ascii("oticizes"),
        dictgen::InsensitiveStr::Ascii("oticizing"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("sh"),
        dictgen::InsensitiveStr::Ascii("t"),
        dictgen::InsensitiveStr::Ascii("uginous"),
        dictgen::InsensitiveStr::Ascii("ugo"),
        dictgen::InsensitiveStr::Ascii("ugos"),
        dictgen::InsensitiveStr::Ascii("valenta"),
        dictgen::InsensitiveStr::Ascii("valentas"),
        dictgen::InsensitiveStr::Ascii("ythraean"),
        dictgen::InsensitiveStr::Ascii("ythraemia"),
        dictgen::InsensitiveStr::Ascii("ythrean"),
        dictgen::InsensitiveStr::Ascii("ythremia"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ERBIA_9464736826289357890)],
        &[(0b00001, &ENTRY_ERBIAS_13402989534594842592)],
        &[(0b10010, &ENTRY_ERGOTIZE_574806398622764721)],
        &[(0b10010, &ENTRY_ERGOTIZED_2227326095484778825)],
        &[(0b10010, &ENTRY_ERGOTIZES_8473870319873551180)],
        &[(0b10010, &ENTRY_ERGOTIZING_1812522634071321138)],
        &[(0b01001, &ENTRY_ERGOTIZE_574806398622764721)],
        &[(0b01001, &ENTRY_ERGOTIZED_2227326095484778825)],
        &[(0b01001, &ENTRY_ERGOTIZES_8473870319873551180)],
        &[(0b01001, &ENTRY_ERGOTIZING_1812522634071321138)],
        &[(0b00001, &ENTRY_ERIC_17025031939768003248)],
        &[(0b00001, &ENTRY_ERICAL_8655189856383454932)],
        &[(0b00001, &ENTRY_ERKE_8619846018234689500)],
        &[(0b00001, &ENTRY_ERN_104294260841087582)],
        &[(0b00001, &ENTRY_ERNES_5463728212363901261)],
        &[(0b00001, &ENTRY_ERNEST_15293673726653605695)],
        &[(0b00001, &ENTRY_ERNS_12150371209659416497)],
        &[(0b00001, &ENTRY_EROGENESIS_4160838603281198154)],
        &[(0b00001, &ENTRY_EROGENIC_3471326385946721331)],
        &[(0b00001, &ENTRY_EROS_3972390604755404559)],
        &[(0b00001, &ENTRY_EROSE_3198202279341053863)],
        &[(0b10010, &ENTRY_EROTICIZATION_1842467549610586129)],
        &[(0b10010, &ENTRY_EROTICIZE_12872311394873552692)],
        &[(0b10010, &ENTRY_EROTICIZED_1132548628285760117)],
        &[(0b10010, &ENTRY_EROTICIZES_15223201339169694346)],
        &[(0b10010, &ENTRY_EROTICIZING_14473356132824862336)],
        &[(0b01001, &ENTRY_EROTICIZATION_1842467549610586129)],
        &[(0b01001, &ENTRY_EROTICIZE_12872311394873552692)],
        &[(0b01001, &ENTRY_EROTICIZED_1132548628285760117)],
        &[(0b01001, &ENTRY_EROTICIZES_15223201339169694346)],
        &[(0b01001, &ENTRY_EROTICIZING_14473356132824862336)],
        &[(0b00001, &ENTRY_ERSES_7688907969133909794)],
        &[(0b00001, &ENTRY_ERSH_7419460282608909511)],
        &[(0b00001, &ENTRY_ERT_16435602001912306536)],
        &[(0b00001, &ENTRY_ERUGINOUS_14659575552896773213)],
        &[(0b00001, &ENTRY_ERUGO_5752272360915842141)],
        &[(0b00001, &ENTRY_ERUGOS_8349991962965375484)],
        &[(0b00001, &ENTRY_ERVALENTA_7976991325469128987)],
        &[(0b00001, &ENTRY_ERVALENTAS_767903353833953973)],
        &[(0b11010, &ENTRY_ERYTHREAN_7272728649221707912)],
        &[(0b11010, &ENTRY_ERYTHREMIA_6911299021657199922)],
        &[(0b00001, &ENTRY_ERYTHREAN_7272728649221707912)],
        &[(0b00001, &ENTRY_ERYTHREMIA_6911299021657199922)],
    ],
    range: 1..=11,
};

static VARS_EQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EQ_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_EQ_4118536122320847820)]),
};

pub static VARS_EQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ualed"),
        dictgen::InsensitiveStr::Ascii("ualing"),
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualiser"),
        dictgen::InsensitiveStr::Ascii("ualisers"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualisings"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizer"),
        dictgen::InsensitiveStr::Ascii("ualizers"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
        dictgen::InsensitiveStr::Ascii("ualizings"),
        dictgen::InsensitiveStr::Ascii("ualled"),
        dictgen::InsensitiveStr::Ascii("ualling"),
        dictgen::InsensitiveStr::Ascii("uestrianise"),
        dictgen::InsensitiveStr::Ascii("uestrianises"),
        dictgen::InsensitiveStr::Ascii("uestrianize"),
        dictgen::InsensitiveStr::Ascii("uestrianizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_EQUALED_9280544645272281486)],
        &[(0b00001, &ENTRY_EQUALING_2200698246943537365)],
        &[(0b10010, &ENTRY_EQUALIZATION_15703715989268616381)],
        &[(0b10010, &ENTRY_EQUALIZATIONS_17119813704324078034)],
        &[(0b10010, &ENTRY_EQUALIZE_2295006139195864596)],
        &[(0b10010, &ENTRY_EQUALIZED_13933428330870564759)],
        &[(0b10010, &ENTRY_EQUALIZER_12962637525747924057)],
        &[(0b10010, &ENTRY_EQUALIZERS_55108374391593906)],
        &[(0b10010, &ENTRY_EQUALIZES_11036742568829365058)],
        &[(0b10010, &ENTRY_EQUALIZING_8520313871903824117)],
        &[(0b10010, &ENTRY_EQUALIZINGS_754862697182198741)],
        &[(0b01001, &ENTRY_EQUALIZATION_15703715989268616381)],
        &[(0b01001, &ENTRY_EQUALIZATIONS_17119813704324078034)],
        &[(0b01001, &ENTRY_EQUALIZE_2295006139195864596)],
        &[(0b01001, &ENTRY_EQUALIZED_13933428330870564759)],
        &[(0b01001, &ENTRY_EQUALIZER_12962637525747924057)],
        &[(0b01001, &ENTRY_EQUALIZERS_55108374391593906)],
        &[(0b01001, &ENTRY_EQUALIZES_11036742568829365058)],
        &[(0b01001, &ENTRY_EQUALIZING_8520313871903824117)],
        &[(0b01001, &ENTRY_EQUALIZINGS_754862697182198741)],
        &[(0b11010, &ENTRY_EQUALED_9280544645272281486)],
        &[(0b11010, &ENTRY_EQUALING_2200698246943537365)],
        &[(0b10010, &ENTRY_EQUESTRIANIZE_8079823547575699416)],
        &[(0b10010, &ENTRY_EQUESTRIANIZES_4839701417403750708)],
        &[(0b01001, &ENTRY_EQUESTRIANIZE_8079823547575699416)],
        &[(0b01001, &ENTRY_EQUESTRIANIZES_4839701417403750708)],
    ],
    range: 5..=12,
};

static VARS_EP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EP_CHILDREN),
    value: None,
};

static VARS_EP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_EPA_NODE),
    None,
    None,
    None,
    Some(&VARS_EPE_NODE),
    None,
    None,
    Some(&VARS_EPH_NODE),
    Some(&VARS_EPI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_EPI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EPI_CHILDREN),
    value: None,
};

static VARS_EPI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_EPIC_NODE),
    Some(&VARS_EPID_NODE),
    None,
    None,
    Some(&VARS_EPIG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_EPIL_NODE),
    Some(&VARS_EPIM_NODE),
    None,
    None,
    Some(&VARS_EPIP_NODE),
    None,
    None,
    Some(&VARS_EPIS_NODE),
    Some(&VARS_EPIT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_EPIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIT_CHILDREN),
    value: None,
};

pub static VARS_EPIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aphise"),
        dictgen::InsensitiveStr::Ascii("aphises"),
        dictgen::InsensitiveStr::Ascii("aphize"),
        dictgen::InsensitiveStr::Ascii("aphizes"),
        dictgen::InsensitiveStr::Ascii("hetise"),
        dictgen::InsensitiveStr::Ascii("hetises"),
        dictgen::InsensitiveStr::Ascii("hetize"),
        dictgen::InsensitiveStr::Ascii("hetizes"),
        dictgen::InsensitiveStr::Ascii("omisation"),
        dictgen::InsensitiveStr::Ascii("omisations"),
        dictgen::InsensitiveStr::Ascii("omise"),
        dictgen::InsensitiveStr::Ascii("omised"),
        dictgen::InsensitiveStr::Ascii("omiser"),
        dictgen::InsensitiveStr::Ascii("omisers"),
        dictgen::InsensitiveStr::Ascii("omises"),
        dictgen::InsensitiveStr::Ascii("omising"),
        dictgen::InsensitiveStr::Ascii("omization"),
        dictgen::InsensitiveStr::Ascii("omizations"),
        dictgen::InsensitiveStr::Ascii("omize"),
        dictgen::InsensitiveStr::Ascii("omized"),
        dictgen::InsensitiveStr::Ascii("omizer"),
        dictgen::InsensitiveStr::Ascii("omizers"),
        dictgen::InsensitiveStr::Ascii("omizes"),
        dictgen::InsensitiveStr::Ascii("omizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EPITAPHIZE_18363407027834066446)],
        &[(0b10010, &ENTRY_EPITAPHIZES_14199461099300441433)],
        &[(0b01001, &ENTRY_EPITAPHIZE_18363407027834066446)],
        &[(0b01001, &ENTRY_EPITAPHIZES_14199461099300441433)],
        &[(0b10010, &ENTRY_EPITHETIZE_17660717439429211067)],
        &[(0b10010, &ENTRY_EPITHETIZES_15067064448215298570)],
        &[(0b01001, &ENTRY_EPITHETIZE_17660717439429211067)],
        &[(0b01001, &ENTRY_EPITHETIZES_15067064448215298570)],
        &[(0b10010, &ENTRY_EPITOMIZATION_10587528992127024576)],
        &[(0b10010, &ENTRY_EPITOMIZATIONS_6345699152655468434)],
        &[(0b10010, &ENTRY_EPITOMIZE_798154534644964032)],
        &[(0b10010, &ENTRY_EPITOMIZED_14066301984118681615)],
        &[(0b10010, &ENTRY_EPITOMIZER_11237451189121702511)],
        &[(0b10010, &ENTRY_EPITOMIZERS_16815945095580680385)],
        &[(0b10010, &ENTRY_EPITOMIZES_1913888595081252026)],
        &[(0b10010, &ENTRY_EPITOMIZING_8673529461190796371)],
        &[(0b01001, &ENTRY_EPITOMIZATION_10587528992127024576)],
        &[(0b01001, &ENTRY_EPITOMIZATIONS_6345699152655468434)],
        &[(0b01001, &ENTRY_EPITOMIZE_798154534644964032)],
        &[(0b01001, &ENTRY_EPITOMIZED_14066301984118681615)],
        &[(0b01001, &ENTRY_EPITOMIZER_11237451189121702511)],
        &[(0b01001, &ENTRY_EPITOMIZERS_16815945095580680385)],
        &[(0b01001, &ENTRY_EPITOMIZES_1913888595081252026)],
        &[(0b01001, &ENTRY_EPITOMIZING_8673529461190796371)],
    ],
    range: 5..=10,
};

static VARS_EPIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIS_CHILDREN),
    value: None,
};

pub static VARS_EPIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("copalianise"),
        dictgen::InsensitiveStr::Ascii("copalianises"),
        dictgen::InsensitiveStr::Ascii("copalianize"),
        dictgen::InsensitiveStr::Ascii("copalianizes"),
        dictgen::InsensitiveStr::Ascii("copise"),
        dictgen::InsensitiveStr::Ascii("copised"),
        dictgen::InsensitiveStr::Ascii("copises"),
        dictgen::InsensitiveStr::Ascii("copising"),
        dictgen::InsensitiveStr::Ascii("copize"),
        dictgen::InsensitiveStr::Ascii("copized"),
        dictgen::InsensitiveStr::Ascii("copizes"),
        dictgen::InsensitiveStr::Ascii("copizing"),
        dictgen::InsensitiveStr::Ascii("tolise"),
        dictgen::InsensitiveStr::Ascii("tolised"),
        dictgen::InsensitiveStr::Ascii("tolises"),
        dictgen::InsensitiveStr::Ascii("tolising"),
        dictgen::InsensitiveStr::Ascii("tolize"),
        dictgen::InsensitiveStr::Ascii("tolized"),
        dictgen::InsensitiveStr::Ascii("tolizes"),
        dictgen::InsensitiveStr::Ascii("tolizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EPISCOPALIANIZE_9902792268985434315)],
        &[(0b10010, &ENTRY_EPISCOPALIANIZES_10851922256306811868)],
        &[(0b01001, &ENTRY_EPISCOPALIANIZE_9902792268985434315)],
        &[(0b01001, &ENTRY_EPISCOPALIANIZES_10851922256306811868)],
        &[(0b10010, &ENTRY_EPISCOPIZE_14167118950866758417)],
        &[(0b10010, &ENTRY_EPISCOPIZED_4410075735309180027)],
        &[(0b10010, &ENTRY_EPISCOPIZES_9047505263363914109)],
        &[(0b10010, &ENTRY_EPISCOPIZING_1519487872102985080)],
        &[(0b01001, &ENTRY_EPISCOPIZE_14167118950866758417)],
        &[(0b01001, &ENTRY_EPISCOPIZED_4410075735309180027)],
        &[(0b01001, &ENTRY_EPISCOPIZES_9047505263363914109)],
        &[(0b01001, &ENTRY_EPISCOPIZING_1519487872102985080)],
        &[(0b10010, &ENTRY_EPISTOLIZE_9159157513900675893)],
        &[(0b10010, &ENTRY_EPISTOLIZED_14624347640913463510)],
        &[(0b10010, &ENTRY_EPISTOLIZES_9570789106235050585)],
        &[(0b10010, &ENTRY_EPISTOLIZING_17459192367753910246)],
        &[(0b01001, &ENTRY_EPISTOLIZE_9159157513900675893)],
        &[(0b01001, &ENTRY_EPISTOLIZED_14624347640913463510)],
        &[(0b01001, &ENTRY_EPISTOLIZES_9570789106235050585)],
        &[(0b01001, &ENTRY_EPISTOLIZING_17459192367753910246)],
    ],
    range: 6..=12,
};

static VARS_EPIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIP_CHILDREN),
    value: None,
};

pub static VARS_EPIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hanise"),
        dictgen::InsensitiveStr::Ascii("hanised"),
        dictgen::InsensitiveStr::Ascii("hanising"),
        dictgen::InsensitiveStr::Ascii("hanize"),
        dictgen::InsensitiveStr::Ascii("hanized"),
        dictgen::InsensitiveStr::Ascii("hanizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EPIPHANIZE_3514685295925609873)],
        &[(0b10010, &ENTRY_EPIPHANIZED_15880624717553136731)],
        &[(0b10010, &ENTRY_EPIPHANIZING_15479258772051321334)],
        &[(0b01001, &ENTRY_EPIPHANIZE_3514685295925609873)],
        &[(0b01001, &ENTRY_EPIPHANIZED_15880624717553136731)],
        &[(0b01001, &ENTRY_EPIPHANIZING_15479258772051321334)],
    ],
    range: 6..=8,
};

static VARS_EPIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIM_CHILDREN),
    value: None,
};

pub static VARS_EPIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("erising"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EPIMERIZE_15635504935650611188)],
        &[(0b10010, &ENTRY_EPIMERIZED_13169037228696214197)],
        &[(0b10010, &ENTRY_EPIMERIZING_14470580452174137969)],
        &[(0b01001, &ENTRY_EPIMERIZE_15635504935650611188)],
        &[(0b01001, &ENTRY_EPIMERIZED_13169037228696214197)],
        &[(0b01001, &ENTRY_EPIMERIZING_14470580452174137969)],
    ],
    range: 5..=7,
};

static VARS_EPIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIL_CHILDREN),
    value: None,
};

pub static VARS_EPIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("og"),
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
        dictgen::InsensitiveStr::Ascii("ogs"),
        dictgen::InsensitiveStr::Ascii("oguise"),
        dictgen::InsensitiveStr::Ascii("oguised"),
        dictgen::InsensitiveStr::Ascii("oguises"),
        dictgen::InsensitiveStr::Ascii("oguising"),
        dictgen::InsensitiveStr::Ascii("oguize"),
        dictgen::InsensitiveStr::Ascii("oguized"),
        dictgen::InsensitiveStr::Ascii("oguizes"),
        dictgen::InsensitiveStr::Ascii("oguizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_EPILOGUE_8824676410841380805)],
        &[(0b10010, &ENTRY_EPILOGIZE_13701609820260659621)],
        &[(0b10010, &ENTRY_EPILOGIZED_9239195598114046533)],
        &[(0b10010, &ENTRY_EPILOGIZES_1074466568803602851)],
        &[(0b10010, &ENTRY_EPILOGIZING_13798823667465605797)],
        &[(0b01001, &ENTRY_EPILOGIZE_13701609820260659621)],
        &[(0b01001, &ENTRY_EPILOGIZED_9239195598114046533)],
        &[(0b01001, &ENTRY_EPILOGIZES_1074466568803602851)],
        &[(0b01001, &ENTRY_EPILOGIZING_13798823667465605797)],
        &[(0b00001, &ENTRY_EPILOGUES_9706718333805199018)],
        &[(0b10010, &ENTRY_EPILOGUIZE_2814822517319878967)],
        &[(0b10010, &ENTRY_EPILOGUIZED_17415882164073599805)],
        &[(0b10010, &ENTRY_EPILOGUIZES_12828768269078689177)],
        &[(0b10010, &ENTRY_EPILOGUIZING_4023466930614167148)],
        &[(0b01001, &ENTRY_EPILOGUIZE_2814822517319878967)],
        &[(0b01001, &ENTRY_EPILOGUIZED_17415882164073599805)],
        &[(0b01001, &ENTRY_EPILOGUIZES_12828768269078689177)],
        &[(0b01001, &ENTRY_EPILOGUIZING_4023466930614167148)],
    ],
    range: 2..=8,
};

static VARS_EPIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIG_CHILDREN),
    value: None,
};

pub static VARS_EPIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aeal"),
        dictgen::InsensitiveStr::Ascii("aean"),
        dictgen::InsensitiveStr::Ascii("aeous"),
        dictgen::InsensitiveStr::Ascii("eal"),
        dictgen::InsensitiveStr::Ascii("ean"),
        dictgen::InsensitiveStr::Ascii("eous"),
        dictgen::InsensitiveStr::Ascii("rammatisation"),
        dictgen::InsensitiveStr::Ascii("rammatise"),
        dictgen::InsensitiveStr::Ascii("rammatised"),
        dictgen::InsensitiveStr::Ascii("rammatiser"),
        dictgen::InsensitiveStr::Ascii("rammatises"),
        dictgen::InsensitiveStr::Ascii("rammatising"),
        dictgen::InsensitiveStr::Ascii("rammatization"),
        dictgen::InsensitiveStr::Ascii("rammatize"),
        dictgen::InsensitiveStr::Ascii("rammatized"),
        dictgen::InsensitiveStr::Ascii("rammatizer"),
        dictgen::InsensitiveStr::Ascii("rammatizes"),
        dictgen::InsensitiveStr::Ascii("rammatizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EPIGEAL_8599954853833471823)],
        &[(0b11010, &ENTRY_EPIGEAN_7444574345322565680)],
        &[(0b11010, &ENTRY_EPIGEOUS_1843834689848177694)],
        &[(0b00001, &ENTRY_EPIGEAL_8599954853833471823)],
        &[(0b00001, &ENTRY_EPIGEAN_7444574345322565680)],
        &[(0b00001, &ENTRY_EPIGEOUS_1843834689848177694)],
        &[(0b10010, &ENTRY_EPIGRAMMATIZATION_14888377290593438046)],
        &[(0b10010, &ENTRY_EPIGRAMMATIZE_5360335231973147569)],
        &[(0b10010, &ENTRY_EPIGRAMMATIZED_17832059231855016110)],
        &[(0b10010, &ENTRY_EPIGRAMMATIZER_11151770505267022085)],
        &[(0b10010, &ENTRY_EPIGRAMMATIZES_801021722587007665)],
        &[(0b10010, &ENTRY_EPIGRAMMATIZING_11225062443581711736)],
        &[(0b01001, &ENTRY_EPIGRAMMATIZATION_14888377290593438046)],
        &[(0b01001, &ENTRY_EPIGRAMMATIZE_5360335231973147569)],
        &[(0b01001, &ENTRY_EPIGRAMMATIZED_17832059231855016110)],
        &[(0b01001, &ENTRY_EPIGRAMMATIZER_11151770505267022085)],
        &[(0b01001, &ENTRY_EPIGRAMMATIZES_801021722587007665)],
        &[(0b01001, &ENTRY_EPIGRAMMATIZING_11225062443581711736)],
    ],
    range: 3..=13,
};

static VARS_EPID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPID_CHILDREN),
    value: None,
};

pub static VARS_EPID_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("otisation"),
        dictgen::InsensitiveStr::Ascii("otisations"),
        dictgen::InsensitiveStr::Ascii("otised"),
        dictgen::InsensitiveStr::Ascii("otization"),
        dictgen::InsensitiveStr::Ascii("otizations"),
        dictgen::InsensitiveStr::Ascii("otized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EPIDOTIZATION_14902775533250389672)],
        &[(0b10010, &ENTRY_EPIDOTIZATIONS_5009347331420792794)],
        &[(0b10010, &ENTRY_EPIDOTIZED_12015327785750521988)],
        &[(0b01001, &ENTRY_EPIDOTIZATION_14902775533250389672)],
        &[(0b01001, &ENTRY_EPIDOTIZATIONS_5009347331420792794)],
        &[(0b01001, &ENTRY_EPIDOTIZED_12015327785750521988)],
    ],
    range: 6..=10,
};

static VARS_EPIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIC_CHILDREN),
    value: None,
};

pub static VARS_EPIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ele"),
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("enters"),
        dictgen::InsensitiveStr::Ascii("entre"),
        dictgen::InsensitiveStr::Ascii("entres"),
        dictgen::InsensitiveStr::Ascii("oele"),
        dictgen::InsensitiveStr::Ascii("urise"),
        dictgen::InsensitiveStr::Ascii("urised"),
        dictgen::InsensitiveStr::Ascii("urises"),
        dictgen::InsensitiveStr::Ascii("urising"),
        dictgen::InsensitiveStr::Ascii("urize"),
        dictgen::InsensitiveStr::Ascii("urized"),
        dictgen::InsensitiveStr::Ascii("urizes"),
        dictgen::InsensitiveStr::Ascii("urizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_EPICELE_16748330680925123266)],
        &[(0b00001, &ENTRY_EPICENTER_7128649262146588844)],
        &[(0b00001, &ENTRY_EPICENTERS_6438256216831055083)],
        &[(0b11010, &ENTRY_EPICENTER_7128649262146588844)],
        &[(0b11010, &ENTRY_EPICENTERS_6438256216831055083)],
        &[(0b11010, &ENTRY_EPICELE_16748330680925123266)],
        &[(0b10010, &ENTRY_EPICURIZE_339384262497516913)],
        &[(0b10010, &ENTRY_EPICURIZED_14620920279528356442)],
        &[(0b10010, &ENTRY_EPICURIZES_17067337675366526772)],
        &[(0b10010, &ENTRY_EPICURIZING_7255147326820591762)],
        &[(0b01001, &ENTRY_EPICURIZE_339384262497516913)],
        &[(0b01001, &ENTRY_EPICURIZED_14620920279528356442)],
        &[(0b01001, &ENTRY_EPICURIZES_17067337675366526772)],
        &[(0b01001, &ENTRY_EPICURIZING_7255147326820591762)],
    ],
    range: 3..=7,
};

static VARS_EPH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPH_CHILDREN),
    value: None,
};

pub static VARS_EPH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etae"),
        dictgen::InsensitiveStr::Ascii("ete"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EPHETE_5581169510134543821)],
        &[(0b00001, &ENTRY_EPHETE_5581169510134543821)],
    ],
    range: 3..=4,
};

static VARS_EPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPE_CHILDREN),
    value: None,
};

pub static VARS_EPE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("netic")],
    values: &[&[(0b00001, &ENTRY_EPENETIC_7137716037631214199)]],
    range: 5..=5,
};

static VARS_EPA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPA_CHILDREN),
    value: None,
};

pub static VARS_EPA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enetic"),
        dictgen::InsensitiveStr::Ascii("ulet"),
        dictgen::InsensitiveStr::Ascii("ulets"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EPENETIC_7137716037631214199)],
        &[(0b01001, &ENTRY_EPAULET_3626800389363536157)],
        &[(0b01001, &ENTRY_EPAULETS_15943230211605632990)],
    ],
    range: 4..=6,
};

static VARS_EO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EO_CHILDREN),
    value: None,
};

pub static VARS_EO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lic"),
        dictgen::InsensitiveStr::Ascii("lipile"),
        dictgen::InsensitiveStr::Ascii("lipiles"),
        dictgen::InsensitiveStr::Ascii("lotropic"),
        dictgen::InsensitiveStr::Ascii("nian"),
        dictgen::InsensitiveStr::Ascii("nism"),
        dictgen::InsensitiveStr::Ascii("nisms"),
        dictgen::InsensitiveStr::Ascii("palaeozoic"),
        dictgen::InsensitiveStr::Ascii("paleozoic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_EOLIC_1257979122017004290)],
        &[(0b00001, &ENTRY_EOLIPILE_525577760526182208)],
        &[(0b00001, &ENTRY_EOLIPILES_15636106136610023127)],
        &[(0b00001, &ENTRY_EOLOTROPIC_10112988872948927516)],
        &[(0b00001, &ENTRY_EONIAN_16940933942216477131)],
        &[(0b00001, &ENTRY_EONISM_977800046438629687)],
        &[(0b00001, &ENTRY_EONISMS_13164743036852291403)],
        &[(0b11010, &ENTRY_EOPALEOZOIC_17786993622475697950)],
        &[(0b00001, &ENTRY_EOPALEOZOIC_17786993622475697950)],
    ],
    range: 3..=10,
};

static VARS_EN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EN_CHILDREN),
    value: None,
};

static VARS_EN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ENA_NODE),
    None,
    Some(&VARS_ENC_NODE),
    Some(&VARS_END_NODE),
    Some(&VARS_ENE_NODE),
    None,
    Some(&VARS_ENG_NODE),
    Some(&VARS_ENH_NODE),
    Some(&VARS_ENI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ENO_NODE),
    None,
    Some(&VARS_ENQ_NODE),
    Some(&VARS_ENR_NODE),
    Some(&VARS_ENS_NODE),
    Some(&VARS_ENT_NODE),
    None,
    Some(&VARS_ENV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_ENV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENV_CHILDREN),
    value: None,
};

pub static VARS_ENV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("apor"),
        dictgen::InsensitiveStr::Ascii("apors"),
        dictgen::InsensitiveStr::Ascii("apour"),
        dictgen::InsensitiveStr::Ascii("apours"),
        dictgen::InsensitiveStr::Ascii("enomisation"),
        dictgen::InsensitiveStr::Ascii("enomization"),
    ],
    values: &[
        &[(0b10001, &ENTRY_ENVAPOR_6902516124365331189)],
        &[(0b10001, &ENTRY_ENVAPORS_15378716003112840751)],
        &[(0b11010, &ENTRY_ENVAPOR_6902516124365331189)],
        &[(0b11010, &ENTRY_ENVAPORS_15378716003112840751)],
        &[(0b10010, &ENTRY_ENVENOMIZATION_14570274555559878933)],
        &[(0b01001, &ENTRY_ENVENOMIZATION_14570274555559878933)],
    ],
    range: 4..=11,
};

static VARS_ENT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENT_CHILDREN),
    value: None,
};

pub static VARS_ENT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ameba"),
        dictgen::InsensitiveStr::Ascii("amebae"),
        dictgen::InsensitiveStr::Ascii("amebas"),
        dictgen::InsensitiveStr::Ascii("amebic"),
        dictgen::InsensitiveStr::Ascii("amoeba"),
        dictgen::InsensitiveStr::Ascii("amoebae"),
        dictgen::InsensitiveStr::Ascii("amoebas"),
        dictgen::InsensitiveStr::Ascii("amoebic"),
        dictgen::InsensitiveStr::Ascii("ender"),
        dictgen::InsensitiveStr::Ascii("enders"),
        dictgen::InsensitiveStr::Ascii("endre"),
        dictgen::InsensitiveStr::Ascii("endres"),
        dictgen::InsensitiveStr::Ascii("erocele"),
        dictgen::InsensitiveStr::Ascii("eroceles"),
        dictgen::InsensitiveStr::Ascii("erocoele"),
        dictgen::InsensitiveStr::Ascii("erocoeles"),
        dictgen::InsensitiveStr::Ascii("hral"),
        dictgen::InsensitiveStr::Ascii("hrall"),
        dictgen::InsensitiveStr::Ascii("hrallment"),
        dictgen::InsensitiveStr::Ascii("hrallments"),
        dictgen::InsensitiveStr::Ascii("hralls"),
        dictgen::InsensitiveStr::Ascii("hralment"),
        dictgen::InsensitiveStr::Ascii("hralments"),
        dictgen::InsensitiveStr::Ascii("hrals"),
        dictgen::InsensitiveStr::Ascii("hronisation"),
        dictgen::InsensitiveStr::Ascii("hronisations"),
        dictgen::InsensitiveStr::Ascii("hronise"),
        dictgen::InsensitiveStr::Ascii("hronised"),
        dictgen::InsensitiveStr::Ascii("hronises"),
        dictgen::InsensitiveStr::Ascii("hronising"),
        dictgen::InsensitiveStr::Ascii("hronization"),
        dictgen::InsensitiveStr::Ascii("hronizations"),
        dictgen::InsensitiveStr::Ascii("hronize"),
        dictgen::InsensitiveStr::Ascii("hronized"),
        dictgen::InsensitiveStr::Ascii("hronizes"),
        dictgen::InsensitiveStr::Ascii("hronizing"),
        dictgen::InsensitiveStr::Ascii("ocele"),
        dictgen::InsensitiveStr::Ascii("ocoele"),
        dictgen::InsensitiveStr::Ascii("omologise"),
        dictgen::InsensitiveStr::Ascii("omologised"),
        dictgen::InsensitiveStr::Ascii("omologises"),
        dictgen::InsensitiveStr::Ascii("omologising"),
        dictgen::InsensitiveStr::Ascii("omologize"),
        dictgen::InsensitiveStr::Ascii("omologized"),
        dictgen::InsensitiveStr::Ascii("omologizes"),
        dictgen::InsensitiveStr::Ascii("omologizing"),
        dictgen::InsensitiveStr::Ascii("rae"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ENTAMEBA_515548781888900607)],
        &[(0b00001, &ENTRY_ENTAMEBAE_17080199760776134373)],
        &[(0b00001, &ENTRY_ENTAMEBAS_2614159645596308673)],
        &[(0b00001, &ENTRY_ENTAMEBIC_3962021291130275067)],
        &[(0b11010, &ENTRY_ENTAMEBA_515548781888900607)],
        &[(0b11010, &ENTRY_ENTAMEBAE_17080199760776134373)],
        &[(0b11010, &ENTRY_ENTAMEBAS_2614159645596308673)],
        &[(0b11010, &ENTRY_ENTAMEBIC_3962021291130275067)],
        &[(0b00001, &ENTRY_ENTENDER_9608567180113806684)],
        &[(0b00001, &ENTRY_ENTENDERS_16112813918437445311)],
        &[(0b11010, &ENTRY_ENTENDER_9608567180113806684)],
        &[(0b11010, &ENTRY_ENTENDERS_16112813918437445311)],
        &[(0b00001, &ENTRY_ENTEROCELE_4323995811417375774)],
        &[(0b00001, &ENTRY_ENTEROCELES_3728084489892614221)],
        &[(0b11010, &ENTRY_ENTEROCELE_4323995811417375774)],
        &[(0b11010, &ENTRY_ENTEROCELES_3728084489892614221)],
        &[
            (0b11010, &ENTRY_ENTHRALL_4754864491654938416),
            (0b11010, &ENTRY_ENTHRALL_5942778214277993445),
        ],
        &[
            (0b01001, &ENTRY_ENTHRALL_4754864491654938416),
            (0b01001, &ENTRY_ENTHRALL_5942778214277993445),
        ],
        &[(0b01001, &ENTRY_ENTHRALLMENT_7453407253455951045)],
        &[(0b01001, &ENTRY_ENTHRALLMENTS_3346774299329360123)],
        &[
            (0b01001, &ENTRY_ENTHRALLS_12657636057000965567),
            (0b01001, &ENTRY_ENTHRALLS_4931585169072696150),
        ],
        &[(0b11010, &ENTRY_ENTHRALLMENT_7453407253455951045)],
        &[(0b11010, &ENTRY_ENTHRALLMENTS_3346774299329360123)],
        &[
            (0b11010, &ENTRY_ENTHRALLS_12657636057000965567),
            (0b11010, &ENTRY_ENTHRALLS_4931585169072696150),
        ],
        &[(0b10010, &ENTRY_ENTHRONIZATION_12839918799425697218)],
        &[(0b10010, &ENTRY_ENTHRONIZATIONS_8870953496378498617)],
        &[(0b10010, &ENTRY_ENTHRONIZE_4727702664279282103)],
        &[(0b10010, &ENTRY_ENTHRONIZED_15202186930780507191)],
        &[(0b10010, &ENTRY_ENTHRONIZES_6720645734371175864)],
        &[(0b10010, &ENTRY_ENTHRONIZING_17481510445049896156)],
        &[(0b01001, &ENTRY_ENTHRONIZATION_12839918799425697218)],
        &[(0b01001, &ENTRY_ENTHRONIZATIONS_8870953496378498617)],
        &[(0b01001, &ENTRY_ENTHRONIZE_4727702664279282103)],
        &[(0b01001, &ENTRY_ENTHRONIZED_15202186930780507191)],
        &[(0b01001, &ENTRY_ENTHRONIZES_6720645734371175864)],
        &[(0b01001, &ENTRY_ENTHRONIZING_17481510445049896156)],
        &[(0b00001, &ENTRY_ENTOCELE_6126697644906764247)],
        &[(0b11010, &ENTRY_ENTOCELE_6126697644906764247)],
        &[(0b10010, &ENTRY_ENTOMOLOGIZE_18232561452819589143)],
        &[(0b10010, &ENTRY_ENTOMOLOGIZED_15797986690606619972)],
        &[(0b10010, &ENTRY_ENTOMOLOGIZES_13434995600613447653)],
        &[(0b10010, &ENTRY_ENTOMOLOGIZING_14730252224524443237)],
        &[(0b01001, &ENTRY_ENTOMOLOGIZE_18232561452819589143)],
        &[(0b01001, &ENTRY_ENTOMOLOGIZED_15797986690606619972)],
        &[(0b01001, &ENTRY_ENTOMOLOGIZES_13434995600613447653)],
        &[(0b01001, &ENTRY_ENTOMOLOGIZING_14730252224524443237)],
        &[(0b11010, &ENTRY_ENTRE_17653472184293381292)],
        &[(0b00001, &ENTRY_ENTRE_17653472184293381292)],
    ],
    range: 2..=12,
};

static VARS_ENS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENS_CHILDREN),
    value: None,
};

pub static VARS_ENS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("epulcher"),
        dictgen::InsensitiveStr::Ascii("epulcherred"),
        dictgen::InsensitiveStr::Ascii("epulcherring"),
        dictgen::InsensitiveStr::Ascii("epulchers"),
        dictgen::InsensitiveStr::Ascii("epulchre"),
        dictgen::InsensitiveStr::Ascii("epulchred"),
        dictgen::InsensitiveStr::Ascii("epulchres"),
        dictgen::InsensitiveStr::Ascii("epulchring"),
        dictgen::InsensitiveStr::Ascii("orceled"),
        dictgen::InsensitiveStr::Ascii("orcelled"),
        dictgen::InsensitiveStr::Ascii("orcells"),
        dictgen::InsensitiveStr::Ascii("orcels"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ENSEPULCHER_14205007025959790046)],
        &[(0b00001, &ENTRY_ENSEPULCHERRED_3341755300145508002)],
        &[(0b00001, &ENTRY_ENSEPULCHERRING_14903067822159669845)],
        &[(0b00001, &ENTRY_ENSEPULCHERS_13477964500524967198)],
        &[(0b11010, &ENTRY_ENSEPULCHER_14205007025959790046)],
        &[(0b11010, &ENTRY_ENSEPULCHERRED_3341755300145508002)],
        &[(0b11010, &ENTRY_ENSEPULCHERS_13477964500524967198)],
        &[(0b11010, &ENTRY_ENSEPULCHERRING_14903067822159669845)],
        &[(0b00001, &ENTRY_ENSORCELED_10144591300662625203)],
        &[(0b11010, &ENTRY_ENSORCELED_10144591300662625203)],
        &[(0b11010, &ENTRY_ENSORCELS_18278488126536104634)],
        &[(0b00001, &ENTRY_ENSORCELS_18278488126536104634)],
    ],
    range: 6..=12,
};

static VARS_ENR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENR_CHILDREN),
    value: None,
};

pub static VARS_ENR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ol"),
        dictgen::InsensitiveStr::Ascii("oll"),
        dictgen::InsensitiveStr::Ascii("ollment"),
        dictgen::InsensitiveStr::Ascii("ollments"),
        dictgen::InsensitiveStr::Ascii("olls"),
        dictgen::InsensitiveStr::Ascii("olment"),
        dictgen::InsensitiveStr::Ascii("olments"),
        dictgen::InsensitiveStr::Ascii("ols"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ENROLL_9372041037495900233)],
        &[(0b11001, &ENTRY_ENROLL_9372041037495900233)],
        &[(0b11001, &ENTRY_ENROLLMENT_1944796353205798833)],
        &[(0b11001, &ENTRY_ENROLLMENTS_6330348617051249235)],
        &[(0b11001, &ENTRY_ENROLLS_11547415760061099613)],
        &[(0b11010, &ENTRY_ENROLLMENT_1944796353205798833)],
        &[(0b11010, &ENTRY_ENROLLMENTS_6330348617051249235)],
        &[(0b11010, &ENTRY_ENROLLS_11547415760061099613)],
    ],
    range: 2..=8,
};

static VARS_ENQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENQ_CHILDREN),
    value: None,
};

pub static VARS_ENQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uire"),
        dictgen::InsensitiveStr::Ascii("uired"),
        dictgen::InsensitiveStr::Ascii("uires"),
        dictgen::InsensitiveStr::Ascii("uiries"),
        dictgen::InsensitiveStr::Ascii("uiring"),
        dictgen::InsensitiveStr::Ascii("uiry"),
    ],
    values: &[
        &[(0b11010, &ENTRY_INQUIRE_9931226624157807030)],
        &[(0b11010, &ENTRY_INQUIRED_859881660768366050)],
        &[(0b11010, &ENTRY_INQUIRES_15638770793218138085)],
        &[(0b11010, &ENTRY_INQUIRIES_14785300041968074867)],
        &[(0b11010, &ENTRY_INQUIRING_8930995414308740890)],
        &[(0b11010, &ENTRY_INQUIRY_8834861104825329029)],
    ],
    range: 4..=6,
};

static VARS_ENO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENO_CHILDREN),
    value: None,
};

pub static VARS_ENO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cyte"),
        dictgen::InsensitiveStr::Ascii("lic"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("logical"),
        dictgen::InsensitiveStr::Ascii("logist"),
        dictgen::InsensitiveStr::Ascii("logists"),
        dictgen::InsensitiveStr::Ascii("mania"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ENOCYTE_12666928362851607670)],
        &[(0b00001, &ENTRY_ENOLIC_7934123335578564140)],
        &[(0b10010, &ENTRY_ENOLIZATION_9661716343807765013)],
        &[(0b10010, &ENTRY_ENOLIZATIONS_13082595730021629708)],
        &[(0b10010, &ENTRY_ENOLIZE_14567106179969001314)],
        &[(0b10010, &ENTRY_ENOLIZES_18021851679044538057)],
        &[(0b01001, &ENTRY_ENOLIZATION_9661716343807765013)],
        &[(0b01001, &ENTRY_ENOLIZATIONS_13082595730021629708)],
        &[(0b01001, &ENTRY_ENOLIZE_14567106179969001314)],
        &[(0b01001, &ENTRY_ENOLIZES_18021851679044538057)],
        &[(0b00001, &ENTRY_ENOLOGICAL_11189078660498192658)],
        &[(0b00001, &ENTRY_ENOLOGIST_382673391921246993)],
        &[(0b00001, &ENTRY_ENOLOGISTS_1989647851737964355)],
        &[(0b00001, &ENTRY_ENOMANIA_9115311181322537124)],
    ],
    range: 3..=9,
};

static VARS_ENI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENI_CHILDREN),
    value: None,
};

pub static VARS_ENI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gmatise"),
        dictgen::InsensitiveStr::Ascii("gmatised"),
        dictgen::InsensitiveStr::Ascii("gmatises"),
        dictgen::InsensitiveStr::Ascii("gmatising"),
        dictgen::InsensitiveStr::Ascii("gmatize"),
        dictgen::InsensitiveStr::Ascii("gmatized"),
        dictgen::InsensitiveStr::Ascii("gmatizes"),
        dictgen::InsensitiveStr::Ascii("gmatizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ENIGMATIZE_17621425390583894662)],
        &[(0b10010, &ENTRY_ENIGMATIZED_7309679394180552266)],
        &[(0b10010, &ENTRY_ENIGMATIZES_2459417653809898623)],
        &[(0b10010, &ENTRY_ENIGMATIZING_1060322619558821397)],
        &[(0b01001, &ENTRY_ENIGMATIZE_17621425390583894662)],
        &[(0b01001, &ENTRY_ENIGMATIZED_7309679394180552266)],
        &[(0b01001, &ENTRY_ENIGMATIZES_2459417653809898623)],
        &[(0b01001, &ENTRY_ENIGMATIZING_1060322619558821397)],
    ],
    range: 7..=9,
};

static VARS_ENH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENH_CHILDREN),
    value: None,
};

pub static VARS_ENH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemospore"),
        dictgen::InsensitiveStr::Ascii("arbor"),
        dictgen::InsensitiveStr::Ascii("arbour"),
        dictgen::InsensitiveStr::Ascii("emospore"),
        dictgen::InsensitiveStr::Ascii("ypostatise"),
        dictgen::InsensitiveStr::Ascii("ypostatised"),
        dictgen::InsensitiveStr::Ascii("ypostatises"),
        dictgen::InsensitiveStr::Ascii("ypostatising"),
        dictgen::InsensitiveStr::Ascii("ypostatize"),
        dictgen::InsensitiveStr::Ascii("ypostatized"),
        dictgen::InsensitiveStr::Ascii("ypostatizes"),
        dictgen::InsensitiveStr::Ascii("ypostatizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ENHEMOSPORE_14381240700671698538)],
        &[(0b00001, &ENTRY_ENHARBOR_17888270651607624999)],
        &[(0b11010, &ENTRY_ENHARBOR_17888270651607624999)],
        &[(0b00001, &ENTRY_ENHEMOSPORE_14381240700671698538)],
        &[(0b10010, &ENTRY_ENHYPOSTATIZE_5938376974603134783)],
        &[(0b10010, &ENTRY_ENHYPOSTATIZED_11845916538515240368)],
        &[(0b10010, &ENTRY_ENHYPOSTATIZES_17623173339471208010)],
        &[(0b10010, &ENTRY_ENHYPOSTATIZING_13884097298898705257)],
        &[(0b01001, &ENTRY_ENHYPOSTATIZE_5938376974603134783)],
        &[(0b01001, &ENTRY_ENHYPOSTATIZED_11845916538515240368)],
        &[(0b01001, &ENTRY_ENHYPOSTATIZES_17623173339471208010)],
        &[(0b01001, &ENTRY_ENHYPOSTATIZING_13884097298898705257)],
    ],
    range: 5..=12,
};

static VARS_ENG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENG_CHILDREN),
    value: None,
};

pub static VARS_ENG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lishise"),
        dictgen::InsensitiveStr::Ascii("lishises"),
        dictgen::InsensitiveStr::Ascii("lishize"),
        dictgen::InsensitiveStr::Ascii("lishizes"),
        dictgen::InsensitiveStr::Ascii("randise"),
        dictgen::InsensitiveStr::Ascii("randisement"),
        dictgen::InsensitiveStr::Ascii("randisements"),
        dictgen::InsensitiveStr::Ascii("randises"),
        dictgen::InsensitiveStr::Ascii("randize"),
        dictgen::InsensitiveStr::Ascii("randizement"),
        dictgen::InsensitiveStr::Ascii("randizements"),
        dictgen::InsensitiveStr::Ascii("randizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ENGLISHIZE_6818310543798957094)],
        &[(0b10010, &ENTRY_ENGLISHIZES_10510834442254353928)],
        &[(0b01001, &ENTRY_ENGLISHIZE_6818310543798957094)],
        &[(0b01001, &ENTRY_ENGLISHIZES_10510834442254353928)],
        &[(0b10010, &ENTRY_ENGRANDIZE_12152353911680916734)],
        &[(0b10010, &ENTRY_ENGRANDIZEMENT_17013895899210266240)],
        &[(0b10010, &ENTRY_ENGRANDIZEMENTS_4881165755382957512)],
        &[(0b10010, &ENTRY_ENGRANDIZES_10684955241961233394)],
        &[(0b01001, &ENTRY_ENGRANDIZE_12152353911680916734)],
        &[(0b01001, &ENTRY_ENGRANDIZEMENT_17013895899210266240)],
        &[(0b01001, &ENTRY_ENGRANDIZEMENTS_4881165755382957512)],
        &[(0b01001, &ENTRY_ENGRANDIZES_10684955241961233394)],
    ],
    range: 7..=12,
};

static VARS_ENE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENE_CHILDREN),
    value: None,
};

pub static VARS_ENE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("id"),
        dictgen::InsensitiveStr::Ascii("rgisation"),
        dictgen::InsensitiveStr::Ascii("rgise"),
        dictgen::InsensitiveStr::Ascii("rgised"),
        dictgen::InsensitiveStr::Ascii("rgiser"),
        dictgen::InsensitiveStr::Ascii("rgisers"),
        dictgen::InsensitiveStr::Ascii("rgises"),
        dictgen::InsensitiveStr::Ascii("rgising"),
        dictgen::InsensitiveStr::Ascii("rgization"),
        dictgen::InsensitiveStr::Ascii("rgize"),
        dictgen::InsensitiveStr::Ascii("rgized"),
        dictgen::InsensitiveStr::Ascii("rgizer"),
        dictgen::InsensitiveStr::Ascii("rgizers"),
        dictgen::InsensitiveStr::Ascii("rgizes"),
        dictgen::InsensitiveStr::Ascii("rgizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ENEID_6327528208754564632)],
        &[(0b10010, &ENTRY_ENERGIZATION_5579130930501114053)],
        &[(0b10010, &ENTRY_ENERGIZE_4079145480961428012)],
        &[(0b10010, &ENTRY_ENERGIZED_8110447848594482786)],
        &[(0b10010, &ENTRY_ENERGIZER_12727132395961026060)],
        &[(0b10010, &ENTRY_ENERGIZERS_15921231264985096207)],
        &[(0b10010, &ENTRY_ENERGIZES_15882306341173011479)],
        &[(0b10010, &ENTRY_ENERGIZING_14435058947853843369)],
        &[(0b01001, &ENTRY_ENERGIZATION_5579130930501114053)],
        &[(0b01001, &ENTRY_ENERGIZE_4079145480961428012)],
        &[(0b01001, &ENTRY_ENERGIZED_8110447848594482786)],
        &[(0b01001, &ENTRY_ENERGIZER_12727132395961026060)],
        &[(0b01001, &ENTRY_ENERGIZERS_15921231264985096207)],
        &[(0b01001, &ENTRY_ENERGIZES_15882306341173011479)],
        &[(0b01001, &ENTRY_ENERGIZING_14435058947853843369)],
    ],
    range: 2..=9,
};

static VARS_END_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_END_CHILDREN),
    value: None,
};

pub static VARS_END_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ameba"),
        dictgen::InsensitiveStr::Ascii("amebae"),
        dictgen::InsensitiveStr::Ascii("amebas"),
        dictgen::InsensitiveStr::Ascii("amebiasis"),
        dictgen::InsensitiveStr::Ascii("amebic"),
        dictgen::InsensitiveStr::Ascii("amoeba"),
        dictgen::InsensitiveStr::Ascii("amoebae"),
        dictgen::InsensitiveStr::Ascii("amoebas"),
        dictgen::InsensitiveStr::Ascii("amoebiasis"),
        dictgen::InsensitiveStr::Ascii("amoebic"),
        dictgen::InsensitiveStr::Ascii("eavor"),
        dictgen::InsensitiveStr::Ascii("eavored"),
        dictgen::InsensitiveStr::Ascii("eavorer"),
        dictgen::InsensitiveStr::Ascii("eavorers"),
        dictgen::InsensitiveStr::Ascii("eavoring"),
        dictgen::InsensitiveStr::Ascii("eavors"),
        dictgen::InsensitiveStr::Ascii("eavour"),
        dictgen::InsensitiveStr::Ascii("eavoured"),
        dictgen::InsensitiveStr::Ascii("eavourer"),
        dictgen::InsensitiveStr::Ascii("eavourers"),
        dictgen::InsensitiveStr::Ascii("eavouring"),
        dictgen::InsensitiveStr::Ascii("eavours"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("res"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ENDAMEBA_538229332483664315)],
        &[(0b00001, &ENTRY_ENDAMEBAE_730607999186797325)],
        &[(0b00001, &ENTRY_ENDAMEBAS_3287493942507319830)],
        &[(0b00001, &ENTRY_ENDAMEBIASIS_3671057505608809337)],
        &[(0b00001, &ENTRY_ENDAMEBIC_10948407921673346288)],
        &[(0b11010, &ENTRY_ENDAMEBA_538229332483664315)],
        &[(0b11010, &ENTRY_ENDAMEBAE_730607999186797325)],
        &[(0b11010, &ENTRY_ENDAMEBAS_3287493942507319830)],
        &[(0b11010, &ENTRY_ENDAMEBIASIS_3671057505608809337)],
        &[(0b11010, &ENTRY_ENDAMEBIC_10948407921673346288)],
        &[(0b11001, &ENTRY_ENDEAVOR_16478995020577429674)],
        &[(0b11001, &ENTRY_ENDEAVORED_8875983943474804048)],
        &[(0b11001, &ENTRY_ENDEAVORER_14408798200130866711)],
        &[(0b11001, &ENTRY_ENDEAVORERS_16041450900390640384)],
        &[(0b11001, &ENTRY_ENDEAVORING_13456096223476863134)],
        &[(0b11001, &ENTRY_ENDEAVORS_4206263397240885183)],
        &[(0b11010, &ENTRY_ENDEAVOR_16478995020577429674)],
        &[(0b11010, &ENTRY_ENDEAVORED_8875983943474804048)],
        &[(0b11010, &ENTRY_ENDEAVORER_14408798200130866711)],
        &[(0b11010, &ENTRY_ENDEAVORERS_16041450900390640384)],
        &[(0b11010, &ENTRY_ENDEAVORING_13456096223476863134)],
        &[(0b11010, &ENTRY_ENDEAVORS_4206263397240885183)],
        &[(0b00001, &ENTRY_ENDERS_7291520445086932474)],
        &[(0b11010, &ENTRY_ENDERS_7291520445086932474)],
    ],
    range: 3..=10,
};

static VARS_ENC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENC_CHILDREN),
    value: None,
};

pub static VARS_ENC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arnalisation"),
        dictgen::InsensitiveStr::Ascii("arnalise"),
        dictgen::InsensitiveStr::Ascii("arnalised"),
        dictgen::InsensitiveStr::Ascii("arnalises"),
        dictgen::InsensitiveStr::Ascii("arnalising"),
        dictgen::InsensitiveStr::Ascii("arnalization"),
        dictgen::InsensitiveStr::Ascii("arnalize"),
        dictgen::InsensitiveStr::Ascii("arnalized"),
        dictgen::InsensitiveStr::Ascii("arnalizes"),
        dictgen::InsensitiveStr::Ascii("arnalizing"),
        dictgen::InsensitiveStr::Ascii("ephalocele"),
        dictgen::InsensitiveStr::Ascii("ephalocoele"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("oloring"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olouring"),
        dictgen::InsensitiveStr::Ascii("olours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ENCARNALIZATION_5687752002387237278)],
        &[(0b10010, &ENTRY_ENCARNALIZE_10254990161920998569)],
        &[(0b10010, &ENTRY_ENCARNALIZED_43232854316302843)],
        &[(0b10010, &ENTRY_ENCARNALIZES_9595852378322748330)],
        &[(0b10010, &ENTRY_ENCARNALIZING_7494160605597126310)],
        &[(0b01001, &ENTRY_ENCARNALIZATION_5687752002387237278)],
        &[(0b01001, &ENTRY_ENCARNALIZE_10254990161920998569)],
        &[(0b01001, &ENTRY_ENCARNALIZED_43232854316302843)],
        &[(0b01001, &ENTRY_ENCARNALIZES_9595852378322748330)],
        &[(0b01001, &ENTRY_ENCARNALIZING_7494160605597126310)],
        &[(0b00001, &ENTRY_ENCEPHALOCELE_14437482288349987680)],
        &[(0b11010, &ENTRY_ENCEPHALOCELE_14437482288349987680)],
        &[(0b11001, &ENTRY_ENCOLOR_1643265642387039771)],
        &[(0b11001, &ENTRY_ENCOLORED_17559904051696090004)],
        &[(0b11001, &ENTRY_ENCOLORING_5903264657709891608)],
        &[(0b11001, &ENTRY_ENCOLORS_9671987002199252106)],
        &[(0b11010, &ENTRY_ENCOLOR_1643265642387039771)],
        &[(0b11010, &ENTRY_ENCOLORED_17559904051696090004)],
        &[(0b11010, &ENTRY_ENCOLORING_5903264657709891608)],
        &[(0b11010, &ENTRY_ENCOLORS_9671987002199252106)],
    ],
    range: 4..=12,
};

static VARS_ENA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENA_CHILDREN),
    value: None,
};

pub static VARS_ENA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("meled"),
        dictgen::InsensitiveStr::Ascii("meler"),
        dictgen::InsensitiveStr::Ascii("melers"),
        dictgen::InsensitiveStr::Ascii("meling"),
        dictgen::InsensitiveStr::Ascii("melings"),
        dictgen::InsensitiveStr::Ascii("melist"),
        dictgen::InsensitiveStr::Ascii("melists"),
        dictgen::InsensitiveStr::Ascii("melled"),
        dictgen::InsensitiveStr::Ascii("meller"),
        dictgen::InsensitiveStr::Ascii("mellers"),
        dictgen::InsensitiveStr::Ascii("melling"),
        dictgen::InsensitiveStr::Ascii("mellings"),
        dictgen::InsensitiveStr::Ascii("mellist"),
        dictgen::InsensitiveStr::Ascii("mellists"),
        dictgen::InsensitiveStr::Ascii("mor"),
        dictgen::InsensitiveStr::Ascii("mored"),
        dictgen::InsensitiveStr::Ascii("moredness"),
        dictgen::InsensitiveStr::Ascii("morednesses"),
        dictgen::InsensitiveStr::Ascii("moreds"),
        dictgen::InsensitiveStr::Ascii("moring"),
        dictgen::InsensitiveStr::Ascii("morment"),
        dictgen::InsensitiveStr::Ascii("morments"),
        dictgen::InsensitiveStr::Ascii("mors"),
        dictgen::InsensitiveStr::Ascii("mour"),
        dictgen::InsensitiveStr::Ascii("moured"),
        dictgen::InsensitiveStr::Ascii("mouredness"),
        dictgen::InsensitiveStr::Ascii("mourednesses"),
        dictgen::InsensitiveStr::Ascii("moureds"),
        dictgen::InsensitiveStr::Ascii("mouring"),
        dictgen::InsensitiveStr::Ascii("mourment"),
        dictgen::InsensitiveStr::Ascii("mourments"),
        dictgen::InsensitiveStr::Ascii("mours"),
        dictgen::InsensitiveStr::Ascii("rbor"),
        dictgen::InsensitiveStr::Ascii("rbors"),
        dictgen::InsensitiveStr::Ascii("rbour"),
        dictgen::InsensitiveStr::Ascii("rbours"),
    ],
    values: &[
        &[(0b01001, &ENTRY_ENAMELED_11306849032588231949)],
        &[(0b00001, &ENTRY_ENAMELER_2186265811744360882)],
        &[(0b00001, &ENTRY_ENAMELERS_5158818097595900189)],
        &[(0b01001, &ENTRY_ENAMELING_13986001605744876872)],
        &[(0b01001, &ENTRY_ENAMELINGS_6194997663710852731)],
        &[(0b00001, &ENTRY_ENAMELIST_16185279376392399957)],
        &[(0b00001, &ENTRY_ENAMELISTS_5202782684465152663)],
        &[(0b11010, &ENTRY_ENAMELED_11306849032588231949)],
        &[(0b11010, &ENTRY_ENAMELER_2186265811744360882)],
        &[(0b11010, &ENTRY_ENAMELERS_5158818097595900189)],
        &[(0b11010, &ENTRY_ENAMELING_13986001605744876872)],
        &[(0b11010, &ENTRY_ENAMELINGS_6194997663710852731)],
        &[(0b11010, &ENTRY_ENAMELIST_16185279376392399957)],
        &[(0b11010, &ENTRY_ENAMELISTS_5202782684465152663)],
        &[(0b11001, &ENTRY_ENAMOR_18438712925910130607)],
        &[(0b11001, &ENTRY_ENAMORED_3978396704928569217)],
        &[(0b11001, &ENTRY_ENAMOREDNESS_17627085162072768847)],
        &[(0b11001, &ENTRY_ENAMOREDNESSES_18182856296907046300)],
        &[(0b11001, &ENTRY_ENAMOREDS_1170610777553507807)],
        &[(0b11001, &ENTRY_ENAMORING_873141923636435610)],
        &[(0b11001, &ENTRY_ENAMORMENT_9258481715906385804)],
        &[(0b11001, &ENTRY_ENAMORMENTS_17749223050502368158)],
        &[(0b11001, &ENTRY_ENAMORS_15866647987432832950)],
        &[(0b11010, &ENTRY_ENAMOR_18438712925910130607)],
        &[(0b11010, &ENTRY_ENAMORED_3978396704928569217)],
        &[(0b11010, &ENTRY_ENAMOREDNESS_17627085162072768847)],
        &[(0b11010, &ENTRY_ENAMOREDNESSES_18182856296907046300)],
        &[(0b11010, &ENTRY_ENAMOREDS_1170610777553507807)],
        &[(0b11010, &ENTRY_ENAMORING_873141923636435610)],
        &[(0b11010, &ENTRY_ENAMORMENT_9258481715906385804)],
        &[(0b11010, &ENTRY_ENAMORMENTS_17749223050502368158)],
        &[(0b11010, &ENTRY_ENAMORS_15866647987432832950)],
        &[(0b00001, &ENTRY_ENARBOR_14803042454779304272)],
        &[(0b00001, &ENTRY_ENARBORS_16761278477457337471)],
        &[(0b11010, &ENTRY_ENARBOR_14803042454779304272)],
        &[(0b11010, &ENTRY_ENARBORS_16761278477457337471)],
    ],
    range: 3..=12,
};

static VARS_EM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EM_CHILDREN),
    value: None,
};

static VARS_EM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_EMB_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_EMO_NODE),
    Some(&VARS_EMP_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_EMU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_EMU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EMU_CHILDREN),
    value: None,
};

pub static VARS_EMU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("le"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("les"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lsionise"),
        dictgen::InsensitiveStr::Ascii("lsionised"),
        dictgen::InsensitiveStr::Ascii("lsionises"),
        dictgen::InsensitiveStr::Ascii("lsionising"),
        dictgen::InsensitiveStr::Ascii("lsionize"),
        dictgen::InsensitiveStr::Ascii("lsionized"),
        dictgen::InsensitiveStr::Ascii("lsionizes"),
        dictgen::InsensitiveStr::Ascii("lsionizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_EMULE_16137428121845795673)],
        &[(0b00001, &ENTRY_EMULED_9191420579655492028)],
        &[(0b00001, &ENTRY_EMULES_16077893382767699411)],
        &[(0b00001, &ENTRY_EMULING_10065143813695027214)],
        &[(0b10010, &ENTRY_EMULSIONIZE_3792988642215500768)],
        &[(0b10010, &ENTRY_EMULSIONIZED_15524766724556141082)],
        &[(0b10010, &ENTRY_EMULSIONIZES_276500337258574013)],
        &[(0b10010, &ENTRY_EMULSIONIZING_14852761818650320419)],
        &[(0b01001, &ENTRY_EMULSIONIZE_3792988642215500768)],
        &[(0b01001, &ENTRY_EMULSIONIZED_15524766724556141082)],
        &[(0b01001, &ENTRY_EMULSIONIZES_276500337258574013)],
        &[(0b01001, &ENTRY_EMULSIONIZING_14852761818650320419)],
    ],
    range: 2..=10,
};

static VARS_EMP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EMP_CHILDREN),
    value: None,
};

pub static VARS_EMP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aestic"),
        dictgen::InsensitiveStr::Ascii("aneled"),
        dictgen::InsensitiveStr::Ascii("aneling"),
        dictgen::InsensitiveStr::Ascii("anelled"),
        dictgen::InsensitiveStr::Ascii("anelling"),
        dictgen::InsensitiveStr::Ascii("athise"),
        dictgen::InsensitiveStr::Ascii("athised"),
        dictgen::InsensitiveStr::Ascii("athises"),
        dictgen::InsensitiveStr::Ascii("athising"),
        dictgen::InsensitiveStr::Ascii("athize"),
        dictgen::InsensitiveStr::Ascii("athized"),
        dictgen::InsensitiveStr::Ascii("athizes"),
        dictgen::InsensitiveStr::Ascii("athizing"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erising"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("erizing"),
        dictgen::InsensitiveStr::Ascii("estic"),
        dictgen::InsensitiveStr::Ascii("hasise"),
        dictgen::InsensitiveStr::Ascii("hasised"),
        dictgen::InsensitiveStr::Ascii("hasiser"),
        dictgen::InsensitiveStr::Ascii("hasisers"),
        dictgen::InsensitiveStr::Ascii("hasises"),
        dictgen::InsensitiveStr::Ascii("hasising"),
        dictgen::InsensitiveStr::Ascii("hasize"),
        dictgen::InsensitiveStr::Ascii("hasized"),
        dictgen::InsensitiveStr::Ascii("hasizer"),
        dictgen::InsensitiveStr::Ascii("hasizers"),
        dictgen::InsensitiveStr::Ascii("hasizes"),
        dictgen::InsensitiveStr::Ascii("hasizing"),
        dictgen::InsensitiveStr::Ascii("loye"),
        dictgen::InsensitiveStr::Ascii("loyes"),
        dictgen::InsensitiveStr::Ascii("yreumatise"),
        dictgen::InsensitiveStr::Ascii("yreumatised"),
        dictgen::InsensitiveStr::Ascii("yreumatises"),
        dictgen::InsensitiveStr::Ascii("yreumatising"),
        dictgen::InsensitiveStr::Ascii("yreumatize"),
        dictgen::InsensitiveStr::Ascii("yreumatized"),
        dictgen::InsensitiveStr::Ascii("yreumatizes"),
        dictgen::InsensitiveStr::Ascii("yreumatizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EMPESTIC_3802757668760612665)],
        &[(0b00001, &ENTRY_IMPANELED_5408518347675931541)],
        &[(0b00001, &ENTRY_IMPANELING_2814603235256758547)],
        &[(0b11010, &ENTRY_IMPANELED_5408518347675931541)],
        &[(0b11010, &ENTRY_IMPANELING_2814603235256758547)],
        &[(0b10010, &ENTRY_EMPATHIZE_4851926761652344693)],
        &[(0b10010, &ENTRY_EMPATHIZED_1551573131065246112)],
        &[(0b10010, &ENTRY_EMPATHIZES_14920809075846536428)],
        &[(0b10010, &ENTRY_EMPATHIZING_5521634151158166341)],
        &[(0b01001, &ENTRY_EMPATHIZE_4851926761652344693)],
        &[(0b01001, &ENTRY_EMPATHIZED_1551573131065246112)],
        &[(0b01001, &ENTRY_EMPATHIZES_14920809075846536428)],
        &[(0b01001, &ENTRY_EMPATHIZING_5521634151158166341)],
        &[(0b10010, &ENTRY_EMPERIZE_10489148982923796097)],
        &[(0b10010, &ENTRY_EMPERIZED_13349527569229044403)],
        &[(0b10010, &ENTRY_EMPERIZES_14942780282521384085)],
        &[(0b10010, &ENTRY_EMPERIZING_506176528649772751)],
        &[(0b01001, &ENTRY_EMPERIZE_10489148982923796097)],
        &[(0b01001, &ENTRY_EMPERIZED_13349527569229044403)],
        &[(0b01001, &ENTRY_EMPERIZES_14942780282521384085)],
        &[(0b01001, &ENTRY_EMPERIZING_506176528649772751)],
        &[(0b10001, &ENTRY_EMPESTIC_3802757668760612665)],
        &[(0b10010, &ENTRY_EMPHASIZE_1866717834630982104)],
        &[(0b10010, &ENTRY_EMPHASIZED_11690096218388969918)],
        &[(0b10010, &ENTRY_EMPHASIZER_17617770184095459158)],
        &[(0b10010, &ENTRY_EMPHASIZERS_244529511784884025)],
        &[(0b10010, &ENTRY_EMPHASIZES_12089402216306749832)],
        &[(0b10010, &ENTRY_EMPHASIZING_2120491803588767663)],
        &[(0b01001, &ENTRY_EMPHASIZE_1866717834630982104)],
        &[(0b01001, &ENTRY_EMPHASIZED_11690096218388969918)],
        &[(0b01001, &ENTRY_EMPHASIZER_17617770184095459158)],
        &[(0b01001, &ENTRY_EMPHASIZERS_244529511784884025)],
        &[(0b01001, &ENTRY_EMPHASIZES_12089402216306749832)],
        &[(0b01001, &ENTRY_EMPHASIZING_2120491803588767663)],
        &[(0b00001, &ENTRY_EMPLOYEE_17424105370251049414)],
        &[(0b00001, &ENTRY_EMPLOYEES_17687744840650937952)],
        &[(0b10010, &ENTRY_EMPYREUMATIZE_1873770942588424273)],
        &[(0b10010, &ENTRY_EMPYREUMATIZED_14903751623654391789)],
        &[(0b10010, &ENTRY_EMPYREUMATIZES_18243085845799514916)],
        &[(0b10010, &ENTRY_EMPYREUMATIZING_9596349812094662524)],
        &[(0b01001, &ENTRY_EMPYREUMATIZE_1873770942588424273)],
        &[(0b01001, &ENTRY_EMPYREUMATIZED_14903751623654391789)],
        &[(0b01001, &ENTRY_EMPYREUMATIZES_18243085845799514916)],
        &[(0b01001, &ENTRY_EMPYREUMATIZING_9596349812094662524)],
    ],
    range: 4..=12,
};

static VARS_EMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EMO_CHILDREN),
    value: None,
};

pub static VARS_EMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tionalisation"),
        dictgen::InsensitiveStr::Ascii("tionalisations"),
        dictgen::InsensitiveStr::Ascii("tionalise"),
        dictgen::InsensitiveStr::Ascii("tionalised"),
        dictgen::InsensitiveStr::Ascii("tionalises"),
        dictgen::InsensitiveStr::Ascii("tionalising"),
        dictgen::InsensitiveStr::Ascii("tionalization"),
        dictgen::InsensitiveStr::Ascii("tionalizations"),
        dictgen::InsensitiveStr::Ascii("tionalize"),
        dictgen::InsensitiveStr::Ascii("tionalized"),
        dictgen::InsensitiveStr::Ascii("tionalizes"),
        dictgen::InsensitiveStr::Ascii("tionalizing"),
        dictgen::InsensitiveStr::Ascii("tionise"),
        dictgen::InsensitiveStr::Ascii("tionises"),
        dictgen::InsensitiveStr::Ascii("tionize"),
        dictgen::InsensitiveStr::Ascii("tionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EMOTIONALIZATION_15477138597694532834)],
        &[(0b10010, &ENTRY_EMOTIONALIZATIONS_16883692557939492571)],
        &[(0b10010, &ENTRY_EMOTIONALIZE_11024287246619149998)],
        &[(0b10010, &ENTRY_EMOTIONALIZED_6884440531306026397)],
        &[(0b10010, &ENTRY_EMOTIONALIZES_16647510988271072305)],
        &[(0b10010, &ENTRY_EMOTIONALIZING_8290060333843675227)],
        &[(0b01001, &ENTRY_EMOTIONALIZATION_15477138597694532834)],
        &[(0b01001, &ENTRY_EMOTIONALIZATIONS_16883692557939492571)],
        &[(0b01001, &ENTRY_EMOTIONALIZE_11024287246619149998)],
        &[(0b01001, &ENTRY_EMOTIONALIZED_6884440531306026397)],
        &[(0b01001, &ENTRY_EMOTIONALIZES_16647510988271072305)],
        &[(0b01001, &ENTRY_EMOTIONALIZING_8290060333843675227)],
        &[(0b10010, &ENTRY_EMOTIONIZE_11005352662349605744)],
        &[(0b10010, &ENTRY_EMOTIONIZES_2839160854420329462)],
        &[(0b01001, &ENTRY_EMOTIONIZE_11005352662349605744)],
        &[(0b01001, &ENTRY_EMOTIONIZES_2839160854420329462)],
    ],
    range: 7..=14,
};

static VARS_EMB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EMB_CHILDREN),
    value: None,
};

pub static VARS_EMB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lematicise"),
        dictgen::InsensitiveStr::Ascii("lematicises"),
        dictgen::InsensitiveStr::Ascii("lematicize"),
        dictgen::InsensitiveStr::Ascii("lematicizes"),
        dictgen::InsensitiveStr::Ascii("lematisation"),
        dictgen::InsensitiveStr::Ascii("lematise"),
        dictgen::InsensitiveStr::Ascii("lematised"),
        dictgen::InsensitiveStr::Ascii("lematises"),
        dictgen::InsensitiveStr::Ascii("lematising"),
        dictgen::InsensitiveStr::Ascii("lematization"),
        dictgen::InsensitiveStr::Ascii("lematize"),
        dictgen::InsensitiveStr::Ascii("lematized"),
        dictgen::InsensitiveStr::Ascii("lematizes"),
        dictgen::InsensitiveStr::Ascii("lematizing"),
        dictgen::InsensitiveStr::Ascii("lemise"),
        dictgen::InsensitiveStr::Ascii("lemised"),
        dictgen::InsensitiveStr::Ascii("lemises"),
        dictgen::InsensitiveStr::Ascii("lemising"),
        dictgen::InsensitiveStr::Ascii("lemize"),
        dictgen::InsensitiveStr::Ascii("lemized"),
        dictgen::InsensitiveStr::Ascii("lemizes"),
        dictgen::InsensitiveStr::Ascii("lemizing"),
        dictgen::InsensitiveStr::Ascii("olisation"),
        dictgen::InsensitiveStr::Ascii("olization"),
        dictgen::InsensitiveStr::Ascii("oweled"),
        dictgen::InsensitiveStr::Ascii("oweling"),
        dictgen::InsensitiveStr::Ascii("owelled"),
        dictgen::InsensitiveStr::Ascii("owelling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EMBLEMATICIZE_14235385586885543722)],
        &[(0b10010, &ENTRY_EMBLEMATICIZES_4315173766129339478)],
        &[(0b01001, &ENTRY_EMBLEMATICIZE_14235385586885543722)],
        &[(0b01001, &ENTRY_EMBLEMATICIZES_4315173766129339478)],
        &[(0b10010, &ENTRY_EMBLEMATIZATION_15777403494926706772)],
        &[(0b10010, &ENTRY_EMBLEMATIZE_1598009610505106027)],
        &[(0b10010, &ENTRY_EMBLEMATIZED_13094007365723895528)],
        &[(0b10010, &ENTRY_EMBLEMATIZES_6955351418847090060)],
        &[(0b10010, &ENTRY_EMBLEMATIZING_9369922012211496667)],
        &[(0b01001, &ENTRY_EMBLEMATIZATION_15777403494926706772)],
        &[(0b01001, &ENTRY_EMBLEMATIZE_1598009610505106027)],
        &[(0b01001, &ENTRY_EMBLEMATIZED_13094007365723895528)],
        &[(0b01001, &ENTRY_EMBLEMATIZES_6955351418847090060)],
        &[(0b01001, &ENTRY_EMBLEMATIZING_9369922012211496667)],
        &[(0b10010, &ENTRY_EMBLEMIZE_12554539049583522901)],
        &[(0b10010, &ENTRY_EMBLEMIZED_7258595819534288479)],
        &[(0b10010, &ENTRY_EMBLEMIZES_12663015673488660950)],
        &[(0b10010, &ENTRY_EMBLEMIZING_14792173425346345877)],
        &[(0b01001, &ENTRY_EMBLEMIZE_12554539049583522901)],
        &[(0b01001, &ENTRY_EMBLEMIZED_7258595819534288479)],
        &[(0b01001, &ENTRY_EMBLEMIZES_12663015673488660950)],
        &[(0b01001, &ENTRY_EMBLEMIZING_14792173425346345877)],
        &[(0b10010, &ENTRY_EMBOLIZATION_15457463761636708838)],
        &[(0b01001, &ENTRY_EMBOLIZATION_15457463761636708838)],
        &[(0b00001, &ENTRY_EMBOWELED_9208239197748486767)],
        &[(0b00001, &ENTRY_EMBOWELING_5074912198762807484)],
        &[(0b11010, &ENTRY_EMBOWELED_9208239197748486767)],
        &[(0b11010, &ENTRY_EMBOWELING_5074912198762807484)],
    ],
    range: 6..=12,
};

static VARS_EL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EL_CHILDREN),
    value: None,
};

static VARS_EL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ELA_NODE),
    None,
    None,
    None,
    Some(&VARS_ELE_NODE),
    None,
    None,
    None,
    Some(&VARS_ELI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ELI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ELI_CHILDREN),
    value: None,
};

pub static VARS_ELI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sabethville"),
        dictgen::InsensitiveStr::Ascii("zabethanise"),
        dictgen::InsensitiveStr::Ascii("zabethanises"),
        dictgen::InsensitiveStr::Ascii("zabethanize"),
        dictgen::InsensitiveStr::Ascii("zabethanizes"),
        dictgen::InsensitiveStr::Ascii("zabethville"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ELIZABETHVILLE_4390374012236621457)],
        &[(0b10010, &ENTRY_ELIZABETHANIZE_6611539784579172980)],
        &[(0b10010, &ENTRY_ELIZABETHANIZES_17522723128509514668)],
        &[(0b01001, &ENTRY_ELIZABETHANIZE_6611539784579172980)],
        &[(0b01001, &ENTRY_ELIZABETHANIZES_17522723128509514668)],
        &[(0b01001, &ENTRY_ELIZABETHVILLE_4390374012236621457)],
    ],
    range: 11..=12,
};

static VARS_ELE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ELE_CHILDREN),
    value: None,
};

static VARS_ELE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_ELEC_NODE),
    None,
    None,
    None,
    Some(&VARS_ELEG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ELEM_NODE),
    None,
    Some(&VARS_ELEO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ELEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ELEO_CHILDREN),
    value: None,
};

pub static VARS_ELEO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("blast"),
        dictgen::InsensitiveStr::Ascii("lite"),
        dictgen::InsensitiveStr::Ascii("margaric"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("ptene"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ELEOBLAST_3123904554517439917)],
        &[(0b00001, &ENTRY_ELEOLITE_8948279489308596906)],
        &[(0b00001, &ENTRY_ELEOMARGARIC_378965269236780731)],
        &[(0b00001, &ENTRY_ELEOMETER_1848423254942890620)],
        &[(0b00001, &ENTRY_ELEOPTENE_18118099583187992103)],
    ],
    range: 4..=8,
};

static VARS_ELEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ELEM_CHILDREN),
    value: None,
};

pub static VARS_ELEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entalise"),
        dictgen::InsensitiveStr::Ascii("entalises"),
        dictgen::InsensitiveStr::Ascii("entalize"),
        dictgen::InsensitiveStr::Ascii("entalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ELEMENTALIZE_1297402832087129943)],
        &[(0b10010, &ENTRY_ELEMENTALIZES_16767925982953522971)],
        &[(0b01001, &ENTRY_ELEMENTALIZE_1297402832087129943)],
        &[(0b01001, &ENTRY_ELEMENTALIZES_16767925982953522971)],
    ],
    range: 8..=9,
};

static VARS_ELEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ELEG_CHILDREN),
    value: None,
};

pub static VARS_ELEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ELEGIZE_6148791844217028940)],
        &[(0b10010, &ENTRY_ELEGIZED_16680402250437818257)],
        &[(0b10010, &ENTRY_ELEGIZES_18250546226667841408)],
        &[(0b10010, &ENTRY_ELEGIZING_9684027986507103857)],
        &[(0b01001, &ENTRY_ELEGIZE_6148791844217028940)],
        &[(0b01001, &ENTRY_ELEGIZED_16680402250437818257)],
        &[(0b01001, &ENTRY_ELEGIZES_18250546226667841408)],
        &[(0b01001, &ENTRY_ELEGIZING_9684027986507103857)],
    ],
    range: 3..=5,
};

static VARS_ELEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ELEC_CHILDREN),
    value: None,
};

pub static VARS_ELEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tricalise"),
        dictgen::InsensitiveStr::Ascii("tricalises"),
        dictgen::InsensitiveStr::Ascii("tricalize"),
        dictgen::InsensitiveStr::Ascii("tricalizes"),
        dictgen::InsensitiveStr::Ascii("tricise"),
        dictgen::InsensitiveStr::Ascii("tricises"),
        dictgen::InsensitiveStr::Ascii("tricize"),
        dictgen::InsensitiveStr::Ascii("tricizes"),
        dictgen::InsensitiveStr::Ascii("trisation"),
        dictgen::InsensitiveStr::Ascii("trisations"),
        dictgen::InsensitiveStr::Ascii("trise"),
        dictgen::InsensitiveStr::Ascii("trised"),
        dictgen::InsensitiveStr::Ascii("trises"),
        dictgen::InsensitiveStr::Ascii("trising"),
        dictgen::InsensitiveStr::Ascii("trization"),
        dictgen::InsensitiveStr::Ascii("trizations"),
        dictgen::InsensitiveStr::Ascii("trize"),
        dictgen::InsensitiveStr::Ascii("trized"),
        dictgen::InsensitiveStr::Ascii("trizes"),
        dictgen::InsensitiveStr::Ascii("trizing"),
        dictgen::InsensitiveStr::Ascii("troanaesthesia"),
        dictgen::InsensitiveStr::Ascii("troanaesthesias"),
        dictgen::InsensitiveStr::Ascii("troanesthesia"),
        dictgen::InsensitiveStr::Ascii("troanesthesias"),
        dictgen::InsensitiveStr::Ascii("trocauterisation"),
        dictgen::InsensitiveStr::Ascii("trocauterisations"),
        dictgen::InsensitiveStr::Ascii("trocauterization"),
        dictgen::InsensitiveStr::Ascii("trocauterizations"),
        dictgen::InsensitiveStr::Ascii("trodialyse"),
        dictgen::InsensitiveStr::Ascii("trodialyser"),
        dictgen::InsensitiveStr::Ascii("trodialysers"),
        dictgen::InsensitiveStr::Ascii("trodialyses"),
        dictgen::InsensitiveStr::Ascii("trodialyze"),
        dictgen::InsensitiveStr::Ascii("trodialyzer"),
        dictgen::InsensitiveStr::Ascii("trodialyzers"),
        dictgen::InsensitiveStr::Ascii("trodialyzes"),
        dictgen::InsensitiveStr::Ascii("trogalvanise"),
        dictgen::InsensitiveStr::Ascii("trogalvanises"),
        dictgen::InsensitiveStr::Ascii("trogalvanize"),
        dictgen::InsensitiveStr::Ascii("trogalvanizes"),
        dictgen::InsensitiveStr::Ascii("trohomoeopathies"),
        dictgen::InsensitiveStr::Ascii("trohomoeopathy"),
        dictgen::InsensitiveStr::Ascii("trolysation"),
        dictgen::InsensitiveStr::Ascii("trolyse"),
        dictgen::InsensitiveStr::Ascii("trolysed"),
        dictgen::InsensitiveStr::Ascii("trolyser"),
        dictgen::InsensitiveStr::Ascii("trolysing"),
        dictgen::InsensitiveStr::Ascii("trolyzation"),
        dictgen::InsensitiveStr::Ascii("trolyze"),
        dictgen::InsensitiveStr::Ascii("trolyzed"),
        dictgen::InsensitiveStr::Ascii("trolyzer"),
        dictgen::InsensitiveStr::Ascii("trolyzes"),
        dictgen::InsensitiveStr::Ascii("trolyzing"),
        dictgen::InsensitiveStr::Ascii("tromagnetisable"),
        dictgen::InsensitiveStr::Ascii("tromagnetizable"),
        dictgen::InsensitiveStr::Ascii("trotonise"),
        dictgen::InsensitiveStr::Ascii("trotonises"),
        dictgen::InsensitiveStr::Ascii("trotonize"),
        dictgen::InsensitiveStr::Ascii("trotonizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ELECTRICALIZE_10408403277460728719)],
        &[(0b10010, &ENTRY_ELECTRICALIZES_6359890112921706019)],
        &[(0b01001, &ENTRY_ELECTRICALIZE_10408403277460728719)],
        &[(0b01001, &ENTRY_ELECTRICALIZES_6359890112921706019)],
        &[(0b10010, &ENTRY_ELECTRICIZE_17179687470251507747)],
        &[(0b10010, &ENTRY_ELECTRICIZES_6484922314210733081)],
        &[(0b01001, &ENTRY_ELECTRICIZE_17179687470251507747)],
        &[(0b01001, &ENTRY_ELECTRICIZES_6484922314210733081)],
        &[(0b10010, &ENTRY_ELECTRIZATION_9585656186418990449)],
        &[(0b10010, &ENTRY_ELECTRIZATIONS_10691212371398243727)],
        &[(0b10010, &ENTRY_ELECTRIZE_560401629974373513)],
        &[(0b10010, &ENTRY_ELECTRIZED_6176912453252287333)],
        &[(0b10010, &ENTRY_ELECTRIZES_18179582404392857702)],
        &[(0b10010, &ENTRY_ELECTRIZING_17105866607588659371)],
        &[(0b01001, &ENTRY_ELECTRIZATION_9585656186418990449)],
        &[(0b01001, &ENTRY_ELECTRIZATIONS_10691212371398243727)],
        &[(0b01001, &ENTRY_ELECTRIZE_560401629974373513)],
        &[(0b01001, &ENTRY_ELECTRIZED_6176912453252287333)],
        &[(0b01001, &ENTRY_ELECTRIZES_18179582404392857702)],
        &[(0b01001, &ENTRY_ELECTRIZING_17105866607588659371)],
        &[(0b11010, &ENTRY_ELECTROANESTHESIA_6504800833252803660)],
        &[(0b11010, &ENTRY_ELECTROANESTHESIAS_14756922461417032532)],
        &[(0b00001, &ENTRY_ELECTROANESTHESIA_6504800833252803660)],
        &[(0b00001, &ENTRY_ELECTROANESTHESIAS_14756922461417032532)],
        &[(0b10010, &ENTRY_ELECTROCAUTERIZATION_5127236476860396497)],
        &[(0b10010, &ENTRY_ELECTROCAUTERIZATIONS_11357157871973014701)],
        &[(0b01001, &ENTRY_ELECTROCAUTERIZATION_5127236476860396497)],
        &[(0b01001, &ENTRY_ELECTROCAUTERIZATIONS_11357157871973014701)],
        &[(0b11010, &ENTRY_ELECTRODIALYZE_10875654835912350289)],
        &[(0b11010, &ENTRY_ELECTRODIALYZER_2854817148687643579)],
        &[(0b11010, &ENTRY_ELECTRODIALYZERS_16624393262625707016)],
        &[(0b11010, &ENTRY_ELECTRODIALYZES_16178135564832840236)],
        &[(0b00001, &ENTRY_ELECTRODIALYZE_10875654835912350289)],
        &[(0b00001, &ENTRY_ELECTRODIALYZER_2854817148687643579)],
        &[(0b00001, &ENTRY_ELECTRODIALYZERS_16624393262625707016)],
        &[(0b00001, &ENTRY_ELECTRODIALYZES_16178135564832840236)],
        &[(0b10010, &ENTRY_ELECTROGALVANIZE_11291453603581738430)],
        &[(0b10010, &ENTRY_ELECTROGALVANIZES_187330993183406189)],
        &[(0b01001, &ENTRY_ELECTROGALVANIZE_11291453603581738430)],
        &[(0b01001, &ENTRY_ELECTROGALVANIZES_187330993183406189)],
        &[(0b11010, &ENTRY_ELECTROHOMEOPATHIES_8865376272828187594)],
        &[(0b11010, &ENTRY_ELECTROHOMEOPATHY_12788411585728630698)],
        &[(0b10010, &ENTRY_ELECTROLYZATION_3832545805391829369)],
        &[(0b11010, &ENTRY_ELECTROLYZE_208176436728592713)],
        &[(0b11010, &ENTRY_ELECTROLYZED_17631117637534703380)],
        &[(0b10010, &ENTRY_ELECTROLYZER_1088513950259369032)],
        &[(0b11010, &ENTRY_ELECTROLYZING_9191100302500650799)],
        &[(0b01001, &ENTRY_ELECTROLYZATION_3832545805391829369)],
        &[(0b00001, &ENTRY_ELECTROLYZE_208176436728592713)],
        &[(0b00001, &ENTRY_ELECTROLYZED_17631117637534703380)],
        &[(0b01001, &ENTRY_ELECTROLYZER_1088513950259369032)],
        &[(0b00001, &ENTRY_ELECTROLYZES_552328508973853187)],
        &[(0b00001, &ENTRY_ELECTROLYZING_9191100302500650799)],
        &[(0b10010, &ENTRY_ELECTROMAGNETIZABLE_9977774661858435354)],
        &[(0b01001, &ENTRY_ELECTROMAGNETIZABLE_9977774661858435354)],
        &[(0b10010, &ENTRY_ELECTROTONIZE_4239933396232760980)],
        &[(0b10010, &ENTRY_ELECTROTONIZES_9469818555172774628)],
        &[(0b01001, &ENTRY_ELECTROTONIZE_4239933396232760980)],
        &[(0b01001, &ENTRY_ELECTROTONIZES_9469818555172774628)],
    ],
    range: 5..=17,
};

static VARS_ELA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ELA_CHILDREN),
    value: None,
};

pub static VARS_ELA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eoblast"),
        dictgen::InsensitiveStr::Ascii("eolite"),
        dictgen::InsensitiveStr::Ascii("eomargaric"),
        dictgen::InsensitiveStr::Ascii("eometer"),
        dictgen::InsensitiveStr::Ascii("eoptene"),
        dictgen::InsensitiveStr::Ascii("sticisation"),
        dictgen::InsensitiveStr::Ascii("sticise"),
        dictgen::InsensitiveStr::Ascii("sticised"),
        dictgen::InsensitiveStr::Ascii("sticiser"),
        dictgen::InsensitiveStr::Ascii("sticisers"),
        dictgen::InsensitiveStr::Ascii("sticises"),
        dictgen::InsensitiveStr::Ascii("sticising"),
        dictgen::InsensitiveStr::Ascii("sticization"),
        dictgen::InsensitiveStr::Ascii("sticize"),
        dictgen::InsensitiveStr::Ascii("sticized"),
        dictgen::InsensitiveStr::Ascii("sticizer"),
        dictgen::InsensitiveStr::Ascii("sticizers"),
        dictgen::InsensitiveStr::Ascii("sticizes"),
        dictgen::InsensitiveStr::Ascii("sticizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ELEOBLAST_3123904554517439917)],
        &[(0b11010, &ENTRY_ELEOLITE_8948279489308596906)],
        &[(0b11010, &ENTRY_ELEOMARGARIC_378965269236780731)],
        &[(0b11010, &ENTRY_ELEOMETER_1848423254942890620)],
        &[(0b11010, &ENTRY_ELEOPTENE_18118099583187992103)],
        &[(0b10010, &ENTRY_ELASTICIZATION_160079200382997172)],
        &[(0b10010, &ENTRY_ELASTICIZE_7825987963400402736)],
        &[(0b10010, &ENTRY_ELASTICIZED_16378886949968944812)],
        &[(0b10010, &ENTRY_ELASTICIZER_12748442626833347246)],
        &[(0b10010, &ENTRY_ELASTICIZERS_15895644091982847846)],
        &[(0b10010, &ENTRY_ELASTICIZES_3546799323082756456)],
        &[(0b10010, &ENTRY_ELASTICIZING_16851673773156446389)],
        &[(0b01001, &ENTRY_ELASTICIZATION_160079200382997172)],
        &[(0b01001, &ENTRY_ELASTICIZE_7825987963400402736)],
        &[(0b01001, &ENTRY_ELASTICIZED_16378886949968944812)],
        &[(0b01001, &ENTRY_ELASTICIZER_12748442626833347246)],
        &[(0b01001, &ENTRY_ELASTICIZERS_15895644091982847846)],
        &[(0b01001, &ENTRY_ELASTICIZES_3546799323082756456)],
        &[(0b01001, &ENTRY_ELASTICIZING_16851673773156446389)],
    ],
    range: 6..=11,
};

static VARS_EG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EG_CHILDREN),
    value: None,
};

pub static VARS_EG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ilops"),
        dictgen::InsensitiveStr::Ascii("is"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("logue"),
        dictgen::InsensitiveStr::Ascii("oise"),
        dictgen::InsensitiveStr::Ascii("oiser"),
        dictgen::InsensitiveStr::Ascii("oisers"),
        dictgen::InsensitiveStr::Ascii("oises"),
        dictgen::InsensitiveStr::Ascii("oize"),
        dictgen::InsensitiveStr::Ascii("oizer"),
        dictgen::InsensitiveStr::Ascii("oizers"),
        dictgen::InsensitiveStr::Ascii("oizes"),
        dictgen::InsensitiveStr::Ascii("ophony"),
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otised"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otising"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otized"),
        dictgen::InsensitiveStr::Ascii("otizes"),
        dictgen::InsensitiveStr::Ascii("otizing"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("ritude"),
        dictgen::InsensitiveStr::Ascii("yptianisation"),
        dictgen::InsensitiveStr::Ascii("yptianisations"),
        dictgen::InsensitiveStr::Ascii("yptianise"),
        dictgen::InsensitiveStr::Ascii("yptianised"),
        dictgen::InsensitiveStr::Ascii("yptianises"),
        dictgen::InsensitiveStr::Ascii("yptianising"),
        dictgen::InsensitiveStr::Ascii("yptianization"),
        dictgen::InsensitiveStr::Ascii("yptianizations"),
        dictgen::InsensitiveStr::Ascii("yptianize"),
        dictgen::InsensitiveStr::Ascii("yptianized"),
        dictgen::InsensitiveStr::Ascii("yptianizes"),
        dictgen::InsensitiveStr::Ascii("yptianizing"),
        dictgen::InsensitiveStr::Ascii("yptise"),
        dictgen::InsensitiveStr::Ascii("yptises"),
        dictgen::InsensitiveStr::Ascii("yptize"),
        dictgen::InsensitiveStr::Ascii("yptizes"),
    ],
    values: &[
        &[
            (0b00001, &ENTRY_EGER_15629290598343730410),
            (0b00001, &ENTRY_EGER_16805159729335837493),
        ],
        &[(0b00001, &ENTRY_EGILOPS_2883782480068163532)],
        &[(0b00001, &ENTRY_AEGIS_8763057825902985675)],
        &[(0b00001, &ENTRY_AEGISES_11533648482988821845)],
        &[(0b00001, &ENTRY_EGLOGUE_4915760052338290285)],
        &[(0b10010, &ENTRY_EGOIZE_8499095864183592640)],
        &[(0b10010, &ENTRY_EGOIZER_7689719757825702876)],
        &[(0b10010, &ENTRY_EGOIZERS_3556769201390449943)],
        &[(0b10010, &ENTRY_EGOIZES_6193803137404587336)],
        &[(0b01001, &ENTRY_EGOIZE_8499095864183592640)],
        &[(0b01001, &ENTRY_EGOIZER_7689719757825702876)],
        &[(0b01001, &ENTRY_EGOIZERS_3556769201390449943)],
        &[(0b01001, &ENTRY_EGOIZES_6193803137404587336)],
        &[(0b00001, &ENTRY_EGOPHONY_7733383031638246128)],
        &[(0b10010, &ENTRY_EGOTIZE_14094436066901592528)],
        &[(0b10010, &ENTRY_EGOTIZED_9678276687619622634)],
        &[(0b10010, &ENTRY_EGOTIZES_4049349000890516266)],
        &[(0b10010, &ENTRY_EGOTIZING_4391273872729111861)],
        &[(0b01001, &ENTRY_EGOTIZE_14094436066901592528)],
        &[(0b01001, &ENTRY_EGOTIZED_9678276687619622634)],
        &[(0b01001, &ENTRY_EGOTIZES_4049349000890516266)],
        &[(0b01001, &ENTRY_EGOTIZING_4391273872729111861)],
        &[(0b11010, &ENTRY_EGER_15629290598343730410)],
        &[(0b00001, &ENTRY_EGRITUDE_5267691897554984547)],
        &[(0b10010, &ENTRY_EGYPTIANIZATION_9169883473524518038)],
        &[(0b10010, &ENTRY_EGYPTIANIZATIONS_5796667291802777291)],
        &[(0b10010, &ENTRY_EGYPTIANIZE_10867825058237937480)],
        &[(0b10010, &ENTRY_EGYPTIANIZED_9083945329210201285)],
        &[(0b10010, &ENTRY_EGYPTIANIZES_14853969803249155648)],
        &[(0b10010, &ENTRY_EGYPTIANIZING_7796226165055521595)],
        &[(0b01001, &ENTRY_EGYPTIANIZATION_9169883473524518038)],
        &[(0b01001, &ENTRY_EGYPTIANIZATIONS_5796667291802777291)],
        &[(0b01001, &ENTRY_EGYPTIANIZE_10867825058237937480)],
        &[(0b01001, &ENTRY_EGYPTIANIZED_9083945329210201285)],
        &[(0b01001, &ENTRY_EGYPTIANIZES_14853969803249155648)],
        &[(0b01001, &ENTRY_EGYPTIANIZING_7796226165055521595)],
        &[(0b10010, &ENTRY_EGYPTIZE_16657751372698010888)],
        &[(0b10010, &ENTRY_EGYPTIZES_2702823690355724579)],
        &[(0b01001, &ENTRY_EGYPTIZE_16657751372698010888)],
        &[(0b01001, &ENTRY_EGYPTIZES_2702823690355724579)],
    ],
    range: 2..=14,
};

static VARS_EF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EF_CHILDREN),
    value: None,
};

pub static VARS_EF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fectualise"),
        dictgen::InsensitiveStr::Ascii("fectualises"),
        dictgen::InsensitiveStr::Ascii("fectualize"),
        dictgen::InsensitiveStr::Ascii("fectualizes"),
        dictgen::InsensitiveStr::Ascii("feminatise"),
        dictgen::InsensitiveStr::Ascii("feminatises"),
        dictgen::InsensitiveStr::Ascii("feminatize"),
        dictgen::InsensitiveStr::Ascii("feminatizes"),
        dictgen::InsensitiveStr::Ascii("feminisation"),
        dictgen::InsensitiveStr::Ascii("feminise"),
        dictgen::InsensitiveStr::Ascii("feminised"),
        dictgen::InsensitiveStr::Ascii("feminises"),
        dictgen::InsensitiveStr::Ascii("feminising"),
        dictgen::InsensitiveStr::Ascii("feminization"),
        dictgen::InsensitiveStr::Ascii("feminize"),
        dictgen::InsensitiveStr::Ascii("feminized"),
        dictgen::InsensitiveStr::Ascii("feminizes"),
        dictgen::InsensitiveStr::Ascii("feminizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EFFECTUALIZE_16511416708524415811)],
        &[(0b10010, &ENTRY_EFFECTUALIZES_15433429353568095613)],
        &[(0b01001, &ENTRY_EFFECTUALIZE_16511416708524415811)],
        &[(0b01001, &ENTRY_EFFECTUALIZES_15433429353568095613)],
        &[(0b10010, &ENTRY_EFFEMINATIZE_4375919794746191)],
        &[(0b10010, &ENTRY_EFFEMINATIZES_16307402669566024545)],
        &[(0b01001, &ENTRY_EFFEMINATIZE_4375919794746191)],
        &[(0b01001, &ENTRY_EFFEMINATIZES_16307402669566024545)],
        &[(0b10010, &ENTRY_EFFEMINIZATION_7704851332662455069)],
        &[(0b10010, &ENTRY_EFFEMINIZE_3516173139622441926)],
        &[(0b10010, &ENTRY_EFFEMINIZED_1459056698758933158)],
        &[(0b10010, &ENTRY_EFFEMINIZES_2248031475942155787)],
        &[(0b10010, &ENTRY_EFFEMINIZING_13337240329061769635)],
        &[(0b01001, &ENTRY_EFFEMINIZATION_7704851332662455069)],
        &[(0b01001, &ENTRY_EFFEMINIZE_3516173139622441926)],
        &[(0b01001, &ENTRY_EFFEMINIZED_1459056698758933158)],
        &[(0b01001, &ENTRY_EFFEMINIZES_2248031475942155787)],
        &[(0b01001, &ENTRY_EFFEMINIZING_13337240329061769635)],
    ],
    range: 8..=12,
};

static VARS_EE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EE_CHILDREN),
    value: None,
};

pub static VARS_EE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("tion")],
    values: &[&[(0b00001, &ENTRY_EETION_14909833508202494568)]],
    range: 4..=4,
};

static VARS_ED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ED_CHILDREN),
    value: None,
};

pub static VARS_ED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ema"),
        dictgen::InsensitiveStr::Ascii("emas"),
        dictgen::InsensitiveStr::Ascii("ematose"),
        dictgen::InsensitiveStr::Ascii("ematous"),
        dictgen::InsensitiveStr::Ascii("enisation"),
        dictgen::InsensitiveStr::Ascii("enisations"),
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enization"),
        dictgen::InsensitiveStr::Ascii("enizations"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("icule"),
        dictgen::InsensitiveStr::Ascii("ile"),
        dictgen::InsensitiveStr::Ascii("iles"),
        dictgen::InsensitiveStr::Ascii("ility"),
        dictgen::InsensitiveStr::Ascii("itorialisation"),
        dictgen::InsensitiveStr::Ascii("itorialisations"),
        dictgen::InsensitiveStr::Ascii("itorialise"),
        dictgen::InsensitiveStr::Ascii("itorialised"),
        dictgen::InsensitiveStr::Ascii("itorialiser"),
        dictgen::InsensitiveStr::Ascii("itorialises"),
        dictgen::InsensitiveStr::Ascii("itorialising"),
        dictgen::InsensitiveStr::Ascii("itorialization"),
        dictgen::InsensitiveStr::Ascii("itorializations"),
        dictgen::InsensitiveStr::Ascii("itorialize"),
        dictgen::InsensitiveStr::Ascii("itorialized"),
        dictgen::InsensitiveStr::Ascii("itorializer"),
        dictgen::InsensitiveStr::Ascii("itorializes"),
        dictgen::InsensitiveStr::Ascii("itorializing"),
    ],
    values: &[
        &[(0b11001, &ENTRY_EDEMA_6077775640730618555)],
        &[(0b11001, &ENTRY_EDEMAS_2647107175205211125)],
        &[(0b11001, &ENTRY_EDEMATOSE_8946823576029811633)],
        &[(0b11001, &ENTRY_EDEMATOUS_6296161129737314269)],
        &[(0b10010, &ENTRY_EDENIZATION_4357865095140457300)],
        &[(0b10010, &ENTRY_EDENIZATIONS_1883865383083433566)],
        &[(0b10010, &ENTRY_EDENIZE_15838328178845287775)],
        &[(0b10010, &ENTRY_EDENIZES_668371311599264061)],
        &[(0b01001, &ENTRY_EDENIZATION_4357865095140457300)],
        &[(0b01001, &ENTRY_EDENIZATIONS_1883865383083433566)],
        &[(0b01001, &ENTRY_EDENIZE_15838328178845287775)],
        &[(0b01001, &ENTRY_EDENIZES_668371311599264061)],
        &[(0b00001, &ENTRY_EDICULE_900504125909275639)],
        &[(0b00001, &ENTRY_AEDILE_15038900667105730092)],
        &[(0b00001, &ENTRY_AEDILES_9510493690992644415)],
        &[(0b00001, &ENTRY_EDILITY_15442566410145406587)],
        &[(0b10010, &ENTRY_EDITORIALIZATION_5806097145075247310)],
        &[(0b10010, &ENTRY_EDITORIALIZATIONS_18043149717600446569)],
        &[(0b10010, &ENTRY_EDITORIALIZE_14666089880239131679)],
        &[(0b10010, &ENTRY_EDITORIALIZED_206766284852555978)],
        &[(0b10010, &ENTRY_EDITORIALIZER_13476720904730177780)],
        &[(0b10010, &ENTRY_EDITORIALIZES_7980175984307295032)],
        &[(0b10010, &ENTRY_EDITORIALIZING_6393585257106387800)],
        &[(0b01001, &ENTRY_EDITORIALIZATION_5806097145075247310)],
        &[(0b01001, &ENTRY_EDITORIALIZATIONS_18043149717600446569)],
        &[(0b01001, &ENTRY_EDITORIALIZE_14666089880239131679)],
        &[(0b01001, &ENTRY_EDITORIALIZED_206766284852555978)],
        &[(0b01001, &ENTRY_EDITORIALIZER_13476720904730177780)],
        &[(0b01001, &ENTRY_EDITORIALIZES_7980175984307295032)],
        &[(0b01001, &ENTRY_EDITORIALIZING_6393585257106387800)],
    ],
    range: 3..=15,
};

static VARS_EC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EC_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_EC_8754556227184431879)]),
};

pub static VARS_EC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("clesiasticise"),
        dictgen::InsensitiveStr::Ascii("clesiasticises"),
        dictgen::InsensitiveStr::Ascii("clesiasticize"),
        dictgen::InsensitiveStr::Ascii("clesiasticizes"),
        dictgen::InsensitiveStr::Ascii("hoise"),
        dictgen::InsensitiveStr::Ascii("hoised"),
        dictgen::InsensitiveStr::Ascii("hoises"),
        dictgen::InsensitiveStr::Ascii("hoising"),
        dictgen::InsensitiveStr::Ascii("hoize"),
        dictgen::InsensitiveStr::Ascii("hoized"),
        dictgen::InsensitiveStr::Ascii("hoizes"),
        dictgen::InsensitiveStr::Ascii("hoizing"),
        dictgen::InsensitiveStr::Ascii("lecticise"),
        dictgen::InsensitiveStr::Ascii("lecticises"),
        dictgen::InsensitiveStr::Ascii("lecticize"),
        dictgen::InsensitiveStr::Ascii("lecticizes"),
        dictgen::InsensitiveStr::Ascii("oid"),
        dictgen::InsensitiveStr::Ascii("onomisation"),
        dictgen::InsensitiveStr::Ascii("onomisations"),
        dictgen::InsensitiveStr::Ascii("onomise"),
        dictgen::InsensitiveStr::Ascii("onomised"),
        dictgen::InsensitiveStr::Ascii("onomiser"),
        dictgen::InsensitiveStr::Ascii("onomisers"),
        dictgen::InsensitiveStr::Ascii("onomises"),
        dictgen::InsensitiveStr::Ascii("onomising"),
        dictgen::InsensitiveStr::Ascii("onomization"),
        dictgen::InsensitiveStr::Ascii("onomizations"),
        dictgen::InsensitiveStr::Ascii("onomize"),
        dictgen::InsensitiveStr::Ascii("onomized"),
        dictgen::InsensitiveStr::Ascii("onomizer"),
        dictgen::InsensitiveStr::Ascii("onomizers"),
        dictgen::InsensitiveStr::Ascii("onomizes"),
        dictgen::InsensitiveStr::Ascii("onomizing"),
        dictgen::InsensitiveStr::Ascii("ophobia"),
        dictgen::InsensitiveStr::Ascii("stasise"),
        dictgen::InsensitiveStr::Ascii("stasised"),
        dictgen::InsensitiveStr::Ascii("stasises"),
        dictgen::InsensitiveStr::Ascii("stasising"),
        dictgen::InsensitiveStr::Ascii("stasize"),
        dictgen::InsensitiveStr::Ascii("stasized"),
        dictgen::InsensitiveStr::Ascii("stasizes"),
        dictgen::InsensitiveStr::Ascii("stasizing"),
        dictgen::InsensitiveStr::Ascii("staticise"),
        dictgen::InsensitiveStr::Ascii("staticises"),
        dictgen::InsensitiveStr::Ascii("staticize"),
        dictgen::InsensitiveStr::Ascii("staticizes"),
        dictgen::InsensitiveStr::Ascii("tethmoid"),
        dictgen::InsensitiveStr::Ascii("tocelic"),
        dictgen::InsensitiveStr::Ascii("tocoelic"),
        dictgen::InsensitiveStr::Ascii("toethmoid"),
        dictgen::InsensitiveStr::Ascii("us"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ECCLESIASTICIZE_10347749265631434353)],
        &[(0b10010, &ENTRY_ECCLESIASTICIZES_8360600305321731430)],
        &[(0b01001, &ENTRY_ECCLESIASTICIZE_10347749265631434353)],
        &[(0b01001, &ENTRY_ECCLESIASTICIZES_8360600305321731430)],
        &[(0b10010, &ENTRY_ECHOIZE_5375579523966491386)],
        &[(0b10010, &ENTRY_ECHOIZED_10737085046643450160)],
        &[(0b10010, &ENTRY_ECHOIZES_10397136139664473414)],
        &[(0b10010, &ENTRY_ECHOIZING_288199927771197334)],
        &[(0b01001, &ENTRY_ECHOIZE_5375579523966491386)],
        &[(0b01001, &ENTRY_ECHOIZED_10737085046643450160)],
        &[(0b01001, &ENTRY_ECHOIZES_10397136139664473414)],
        &[(0b01001, &ENTRY_ECHOIZING_288199927771197334)],
        &[(0b10010, &ENTRY_ECLECTICIZE_13502059345443989224)],
        &[(0b10010, &ENTRY_ECLECTICIZES_12673848782293092933)],
        &[(0b01001, &ENTRY_ECLECTICIZE_13502059345443989224)],
        &[(0b01001, &ENTRY_ECLECTICIZES_12673848782293092933)],
        &[(0b00001, &ENTRY_ECOID_15394441758678226221)],
        &[(0b10010, &ENTRY_ECONOMIZATION_10728791833837936702)],
        &[(0b10010, &ENTRY_ECONOMIZATIONS_934146159430176470)],
        &[(0b10010, &ENTRY_ECONOMIZE_12047501793607810301)],
        &[(0b10010, &ENTRY_ECONOMIZED_7472643162983045891)],
        &[(0b10010, &ENTRY_ECONOMIZER_1145608432005541501)],
        &[(0b10010, &ENTRY_ECONOMIZERS_11377293695267374301)],
        &[(0b10010, &ENTRY_ECONOMIZES_15039806622307012464)],
        &[(0b10010, &ENTRY_ECONOMIZING_9258997222217906936)],
        &[(0b01001, &ENTRY_ECONOMIZATION_10728791833837936702)],
        &[(0b01001, &ENTRY_ECONOMIZATIONS_934146159430176470)],
        &[(0b01001, &ENTRY_ECONOMIZE_12047501793607810301)],
        &[(0b01001, &ENTRY_ECONOMIZED_7472643162983045891)],
        &[(0b01001, &ENTRY_ECONOMIZER_1145608432005541501)],
        &[(0b01001, &ENTRY_ECONOMIZERS_11377293695267374301)],
        &[(0b01001, &ENTRY_ECONOMIZES_15039806622307012464)],
        &[(0b01001, &ENTRY_ECONOMIZING_9258997222217906936)],
        &[(0b00001, &ENTRY_ECOPHOBIA_5971973597118487121)],
        &[(0b10010, &ENTRY_ECSTASIZE_14049590323272222892)],
        &[(0b10010, &ENTRY_ECSTASIZED_1854941639407331026)],
        &[(0b10010, &ENTRY_ECSTASIZES_13873477019720774589)],
        &[(0b10010, &ENTRY_ECSTASIZING_6278162153824292928)],
        &[(0b01001, &ENTRY_ECSTASIZE_14049590323272222892)],
        &[(0b01001, &ENTRY_ECSTASIZED_1854941639407331026)],
        &[(0b01001, &ENTRY_ECSTASIZES_13873477019720774589)],
        &[(0b01001, &ENTRY_ECSTASIZING_6278162153824292928)],
        &[(0b10010, &ENTRY_ECSTATICIZE_13705022578144925366)],
        &[(0b10010, &ENTRY_ECSTATICIZES_16065796685331364725)],
        &[(0b01001, &ENTRY_ECSTATICIZE_13705022578144925366)],
        &[(0b01001, &ENTRY_ECSTATICIZES_16065796685331364725)],
        &[(0b00001, &ENTRY_ECTETHMOID_12099837169797274294)],
        &[(0b10001, &ENTRY_ECTOCELIC_6998878818827985507)],
        &[(0b11010, &ENTRY_ECTOCELIC_6998878818827985507)],
        &[(0b11010, &ENTRY_ECTETHMOID_12099837169797274294)],
        &[(0b00001, &ENTRY_ECUS_6730015734116715954)],
    ],
    range: 2..=14,
};

static VARS_EB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EB_CHILDREN),
    value: None,
};

pub static VARS_EB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ionise"),
        dictgen::InsensitiveStr::Ascii("ionised"),
        dictgen::InsensitiveStr::Ascii("ionises"),
        dictgen::InsensitiveStr::Ascii("ionising"),
        dictgen::InsensitiveStr::Ascii("ionize"),
        dictgen::InsensitiveStr::Ascii("ionized"),
        dictgen::InsensitiveStr::Ascii("ionizes"),
        dictgen::InsensitiveStr::Ascii("ionizing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EBIONIZE_13207197767862841625)],
        &[(0b10010, &ENTRY_EBIONIZED_4767603710174780767)],
        &[(0b10010, &ENTRY_EBIONIZES_8688860041619975472)],
        &[(0b10010, &ENTRY_EBIONIZING_8449526340825632312)],
        &[(0b01001, &ENTRY_EBIONIZE_13207197767862841625)],
        &[(0b01001, &ENTRY_EBIONIZED_4767603710174780767)],
        &[(0b01001, &ENTRY_EBIONIZES_8688860041619975472)],
        &[(0b01001, &ENTRY_EBIONIZING_8449526340825632312)],
        &[(0b10010, &ENTRY_EBONIZATION_9459110214216310411)],
        &[(0b10010, &ENTRY_EBONIZE_6555944017551594352)],
        &[(0b10010, &ENTRY_EBONIZED_2700368914274174610)],
        &[(0b10010, &ENTRY_EBONIZES_6460531056601115454)],
        &[(0b10010, &ENTRY_EBONIZING_3132402479188609625)],
        &[(0b01001, &ENTRY_EBONIZATION_9459110214216310411)],
        &[(0b01001, &ENTRY_EBONIZE_6555944017551594352)],
        &[(0b01001, &ENTRY_EBONIZED_2700368914274174610)],
        &[(0b01001, &ENTRY_EBONIZES_6460531056601115454)],
        &[(0b01001, &ENTRY_EBONIZING_3132402479188609625)],
    ],
    range: 5..=9,
};

static VARS_EA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EA_CHILDREN),
    value: None,
};

pub static VARS_EA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etion"),
        dictgen::InsensitiveStr::Ascii("rlierise"),
        dictgen::InsensitiveStr::Ascii("rlierised"),
        dictgen::InsensitiveStr::Ascii("rlierises"),
        dictgen::InsensitiveStr::Ascii("rlierising"),
        dictgen::InsensitiveStr::Ascii("rlierize"),
        dictgen::InsensitiveStr::Ascii("rlierized"),
        dictgen::InsensitiveStr::Ascii("rlierizes"),
        dictgen::InsensitiveStr::Ascii("rlierizing"),
        dictgen::InsensitiveStr::Ascii("sternise"),
        dictgen::InsensitiveStr::Ascii("sternize"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EETION_14909833508202494568)],
        &[(0b10010, &ENTRY_EARLIERIZE_2454029968544836130)],
        &[(0b10010, &ENTRY_EARLIERIZED_8859057113673352489)],
        &[(0b10010, &ENTRY_EARLIERIZES_6097960945758306246)],
        &[(0b10010, &ENTRY_EARLIERIZING_3424145954088036470)],
        &[(0b01001, &ENTRY_EARLIERIZE_2454029968544836130)],
        &[(0b01001, &ENTRY_EARLIERIZED_8859057113673352489)],
        &[(0b01001, &ENTRY_EARLIERIZES_6097960945758306246)],
        &[(0b01001, &ENTRY_EARLIERIZING_3424145954088036470)],
        &[(0b10010, &ENTRY_EASTERNIZE_346663424765039993)],
        &[(0b01001, &ENTRY_EASTERNIZE_346663424765039993)],
    ],
    range: 5..=10,
};

static VARS_D_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_D_CHILDREN),
    value: None,
};

static VARS_D_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DA_NODE),
    None,
    None,
    None,
    Some(&VARS_DE_NODE),
    None,
    None,
    None,
    Some(&VARS_DI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DO_NODE),
    None,
    None,
    Some(&VARS_DR_NODE),
    None,
    None,
    Some(&VARS_DU_NODE),
    None,
    None,
    None,
    Some(&VARS_DY_NODE),
    None,
];

static VARS_DY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DY_CHILDREN),
    value: None,
};

pub static VARS_DY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("namise"),
        dictgen::InsensitiveStr::Ascii("namised"),
        dictgen::InsensitiveStr::Ascii("namises"),
        dictgen::InsensitiveStr::Ascii("namising"),
        dictgen::InsensitiveStr::Ascii("namize"),
        dictgen::InsensitiveStr::Ascii("namized"),
        dictgen::InsensitiveStr::Ascii("namizes"),
        dictgen::InsensitiveStr::Ascii("namizing"),
        dictgen::InsensitiveStr::Ascii("saesthesia"),
        dictgen::InsensitiveStr::Ascii("saesthetic"),
        dictgen::InsensitiveStr::Ascii("sesthesia"),
        dictgen::InsensitiveStr::Ascii("sesthetic"),
        dictgen::InsensitiveStr::Ascii("smenorrhea"),
        dictgen::InsensitiveStr::Ascii("smenorrheal"),
        dictgen::InsensitiveStr::Ascii("smenorrheas"),
        dictgen::InsensitiveStr::Ascii("smenorrheic"),
        dictgen::InsensitiveStr::Ascii("smenorrhoea"),
        dictgen::InsensitiveStr::Ascii("smenorrhoeal"),
        dictgen::InsensitiveStr::Ascii("smenorrhoeas"),
        dictgen::InsensitiveStr::Ascii("smenorrhoeic"),
        dictgen::InsensitiveStr::Ascii("spnea"),
        dictgen::InsensitiveStr::Ascii("spneal"),
        dictgen::InsensitiveStr::Ascii("spneas"),
        dictgen::InsensitiveStr::Ascii("spneic"),
        dictgen::InsensitiveStr::Ascii("spnoea"),
        dictgen::InsensitiveStr::Ascii("spnoeal"),
        dictgen::InsensitiveStr::Ascii("spnoeas"),
        dictgen::InsensitiveStr::Ascii("spnoeic"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DYNAMIZE_974871700799051286)],
        &[(0b10010, &ENTRY_DYNAMIZED_16437663690590760619)],
        &[(0b10010, &ENTRY_DYNAMIZES_4847040906964920430)],
        &[(0b10010, &ENTRY_DYNAMIZING_1200643737276779185)],
        &[(0b01001, &ENTRY_DYNAMIZE_974871700799051286)],
        &[(0b01001, &ENTRY_DYNAMIZED_16437663690590760619)],
        &[(0b01001, &ENTRY_DYNAMIZES_4847040906964920430)],
        &[(0b01001, &ENTRY_DYNAMIZING_1200643737276779185)],
        &[(0b11010, &ENTRY_DYSESTHESIA_9627713140323890333)],
        &[(0b11010, &ENTRY_DYSESTHETIC_7201077519433440244)],
        &[(0b10001, &ENTRY_DYSESTHESIA_9627713140323890333)],
        &[(0b10001, &ENTRY_DYSESTHETIC_7201077519433440244)],
        &[(0b10001, &ENTRY_DYSMENORRHEA_854427638046307166)],
        &[(0b10001, &ENTRY_DYSMENORRHEAL_15355819888146380019)],
        &[(0b10001, &ENTRY_DYSMENORRHEAS_12513373498651023184)],
        &[(0b10001, &ENTRY_DYSMENORRHEIC_11311229779411300652)],
        &[(0b11010, &ENTRY_DYSMENORRHEA_854427638046307166)],
        &[(0b11010, &ENTRY_DYSMENORRHEAL_15355819888146380019)],
        &[(0b11010, &ENTRY_DYSMENORRHEAS_12513373498651023184)],
        &[(0b11010, &ENTRY_DYSMENORRHEIC_11311229779411300652)],
        &[(0b11001, &ENTRY_DYSPNEA_8650571964047698387)],
        &[(0b10001, &ENTRY_DYSPNEAL_904353003353123023)],
        &[(0b11001, &ENTRY_DYSPNEAS_9210940115108150000)],
        &[(0b10001, &ENTRY_DYSPNEIC_5771134243752838640)],
        &[(0b10010, &ENTRY_DYSPNEA_8650571964047698387)],
        &[(0b11010, &ENTRY_DYSPNEAL_904353003353123023)],
        &[(0b10010, &ENTRY_DYSPNEAS_9210940115108150000)],
        &[(0b11010, &ENTRY_DYSPNEIC_5771134243752838640)],
    ],
    range: 5..=12,
};

static VARS_DU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DU_CHILDREN),
    value: None,
};

pub static VARS_DU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("ctilise"),
        dictgen::InsensitiveStr::Ascii("ctilises"),
        dictgen::InsensitiveStr::Ascii("ctilize"),
        dictgen::InsensitiveStr::Ascii("ctilizes"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elist"),
        dictgen::InsensitiveStr::Ascii("elists"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
        dictgen::InsensitiveStr::Ascii("ellist"),
        dictgen::InsensitiveStr::Ascii("ellists"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DUALIZATION_4073509101571037016)],
        &[(0b10010, &ENTRY_DUALIZATIONS_11089519285161275319)],
        &[(0b10010, &ENTRY_DUALIZE_7311697450297146384)],
        &[(0b10010, &ENTRY_DUALIZES_10948073264088116504)],
        &[(0b01001, &ENTRY_DUALIZATION_4073509101571037016)],
        &[(0b01001, &ENTRY_DUALIZATIONS_11089519285161275319)],
        &[(0b01001, &ENTRY_DUALIZE_7311697450297146384)],
        &[(0b01001, &ENTRY_DUALIZES_10948073264088116504)],
        &[(0b10010, &ENTRY_DUCTILIZE_9087726193201443557)],
        &[(0b10010, &ENTRY_DUCTILIZES_13806063438403889486)],
        &[(0b01001, &ENTRY_DUCTILIZE_9087726193201443557)],
        &[(0b01001, &ENTRY_DUCTILIZES_13806063438403889486)],
        &[(0b00001, &ENTRY_DUELED_9329917518038504527)],
        &[(0b00001, &ENTRY_DUELER_1881004460634174849)],
        &[(0b00001, &ENTRY_DUELERS_7359774943746748566)],
        &[(0b00001, &ENTRY_DUELING_517690675461305714)],
        &[(0b00001, &ENTRY_DUELINGS_16266636898439940215)],
        &[(0b00001, &ENTRY_DUELIST_3617834640500550373)],
        &[(0b00001, &ENTRY_DUELISTS_2315213851465914209)],
        &[(0b11010, &ENTRY_DUELED_9329917518038504527)],
        &[(0b11010, &ENTRY_DUELER_1881004460634174849)],
        &[(0b11010, &ENTRY_DUELERS_7359774943746748566)],
        &[(0b11010, &ENTRY_DUELING_517690675461305714)],
        &[(0b11010, &ENTRY_DUELINGS_16266636898439940215)],
        &[(0b11010, &ENTRY_DUELIST_3617834640500550373)],
        &[(0b11010, &ENTRY_DUELISTS_2315213851465914209)],
        &[(0b00001, &ENTRY_DUER_1947794498627426590)],
        &[(0b11010, &ENTRY_DUER_1947794498627426590)],
    ],
    range: 2..=10,
};

static VARS_DR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DR_CHILDREN),
    value: None,
};

static VARS_DR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DRA_NODE),
    None,
    None,
    None,
    Some(&VARS_DRE_NODE),
    None,
    None,
    None,
    Some(&VARS_DRI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_DRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRI_CHILDREN),
    value: None,
};

pub static VARS_DRI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("veled"),
        dictgen::InsensitiveStr::Ascii("veler"),
        dictgen::InsensitiveStr::Ascii("velers"),
        dictgen::InsensitiveStr::Ascii("veling"),
        dictgen::InsensitiveStr::Ascii("velled"),
        dictgen::InsensitiveStr::Ascii("veller"),
        dictgen::InsensitiveStr::Ascii("vellers"),
        dictgen::InsensitiveStr::Ascii("velling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DRIVELED_10369632498060637218)],
        &[(0b00001, &ENTRY_DRIVELER_5677282658106600455)],
        &[(0b00001, &ENTRY_DRIVELERS_292810807634252006)],
        &[(0b00001, &ENTRY_DRIVELING_9276931416261875171)],
        &[(0b11010, &ENTRY_DRIVELED_10369632498060637218)],
        &[(0b11010, &ENTRY_DRIVELER_5677282658106600455)],
        &[(0b11010, &ENTRY_DRIVELERS_292810807634252006)],
        &[(0b11010, &ENTRY_DRIVELING_9276931416261875171)],
    ],
    range: 5..=7,
};

static VARS_DRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRE_CHILDREN),
    value: None,
};

pub static VARS_DRE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("amt"),
        dictgen::InsensitiveStr::Ascii("k"),
        dictgen::InsensitiveStr::Ascii("r"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DREAMED_8816476032248430540)],
        &[(0b11010, &ENTRY_DERK_4188156948801172154)],
        &[(0b11010, &ENTRY_DERR_9116132351167601479)],
    ],
    range: 1..=3,
};

static VARS_DRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DRA_CHILDREN),
    value: None,
};

static VARS_DRA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_DRAC_NODE),
    None,
    None,
    Some(&VARS_DRAF_NODE),
    Some(&VARS_DRAG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DRAM_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DRAU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_DRAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRAU_CHILDREN),
    value: None,
};

pub static VARS_DRAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ghted"),
        dictgen::InsensitiveStr::Ascii("ghtier"),
        dictgen::InsensitiveStr::Ascii("ghtiest"),
        dictgen::InsensitiveStr::Ascii("ghtilier"),
        dictgen::InsensitiveStr::Ascii("ghtiliest"),
        dictgen::InsensitiveStr::Ascii("ghtily"),
        dictgen::InsensitiveStr::Ascii("ghtiness"),
        dictgen::InsensitiveStr::Ascii("ghtinesses"),
        dictgen::InsensitiveStr::Ascii("ghting"),
        dictgen::InsensitiveStr::Ascii("ghtsmanship"),
        dictgen::InsensitiveStr::Ascii("ghtsmanships"),
        dictgen::InsensitiveStr::Ascii("ghtsperson"),
        dictgen::InsensitiveStr::Ascii("ghtswoman"),
        dictgen::InsensitiveStr::Ascii("ghtswomen"),
        dictgen::InsensitiveStr::Ascii("ghty"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DRAFTED_17845159112580457751)],
        &[(0b10010, &ENTRY_DRAFTIER_10315157891310403943)],
        &[(0b10010, &ENTRY_DRAFTIEST_8211720032838927607)],
        &[(0b10010, &ENTRY_DRAFTILIER_7262684480559882840)],
        &[(0b10010, &ENTRY_DRAFTILIEST_9434728745324700875)],
        &[(0b10010, &ENTRY_DRAFTILY_16179502285729030019)],
        &[(0b10010, &ENTRY_DRAFTINESS_17583131269164652522)],
        &[(0b10010, &ENTRY_DRAFTINESSES_2329357781885563418)],
        &[(0b10010, &ENTRY_DRAFTING_9360381139157558092)],
        &[(0b10010, &ENTRY_DRAFTSMANSHIP_15527745914295176647)],
        &[(0b10010, &ENTRY_DRAFTSMANSHIPS_4161880617470266425)],
        &[(0b10010, &ENTRY_DRAFTSPERSON_6409665226600621917)],
        &[(0b10010, &ENTRY_DRAFTSWOMAN_15962715217490874254)],
        &[(0b10010, &ENTRY_DRAFTSWOMEN_1853126005122534712)],
        &[(0b10010, &ENTRY_DRAFTY_1579846262644957016)],
    ],
    range: 4..=12,
};

static VARS_DRAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRAM_CHILDREN),
    value: None,
};

pub static VARS_DRAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atisable"),
        dictgen::InsensitiveStr::Ascii("atisabler"),
        dictgen::InsensitiveStr::Ascii("atisables"),
        dictgen::InsensitiveStr::Ascii("atisablest"),
        dictgen::InsensitiveStr::Ascii("atisation"),
        dictgen::InsensitiveStr::Ascii("atisations"),
        dictgen::InsensitiveStr::Ascii("atise"),
        dictgen::InsensitiveStr::Ascii("atised"),
        dictgen::InsensitiveStr::Ascii("atiser"),
        dictgen::InsensitiveStr::Ascii("atisers"),
        dictgen::InsensitiveStr::Ascii("atises"),
        dictgen::InsensitiveStr::Ascii("atising"),
        dictgen::InsensitiveStr::Ascii("atizable"),
        dictgen::InsensitiveStr::Ascii("atizabler"),
        dictgen::InsensitiveStr::Ascii("atizables"),
        dictgen::InsensitiveStr::Ascii("atizablest"),
        dictgen::InsensitiveStr::Ascii("atization"),
        dictgen::InsensitiveStr::Ascii("atizations"),
        dictgen::InsensitiveStr::Ascii("atize"),
        dictgen::InsensitiveStr::Ascii("atized"),
        dictgen::InsensitiveStr::Ascii("atizer"),
        dictgen::InsensitiveStr::Ascii("atizers"),
        dictgen::InsensitiveStr::Ascii("atizes"),
        dictgen::InsensitiveStr::Ascii("atizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DRAMATIZABLE_2049350738620399063)],
        &[(0b10010, &ENTRY_DRAMATIZABLER_23065206507012041)],
        &[(0b10010, &ENTRY_DRAMATIZABLES_17777717401779818485)],
        &[(0b10010, &ENTRY_DRAMATIZABLEST_1714846433859302074)],
        &[(0b10010, &ENTRY_DRAMATIZATION_7793417852737015856)],
        &[(0b10010, &ENTRY_DRAMATIZATIONS_18020015640645554579)],
        &[(0b10010, &ENTRY_DRAMATIZE_5576714162148854490)],
        &[(0b10010, &ENTRY_DRAMATIZED_1183366410074875762)],
        &[(0b10010, &ENTRY_DRAMATIZER_4338891229356955125)],
        &[(0b10010, &ENTRY_DRAMATIZERS_4849393366081771993)],
        &[(0b10010, &ENTRY_DRAMATIZES_17928119971239910049)],
        &[(0b10010, &ENTRY_DRAMATIZING_17356943686393270091)],
        &[(0b01001, &ENTRY_DRAMATIZABLE_2049350738620399063)],
        &[(0b01001, &ENTRY_DRAMATIZABLER_23065206507012041)],
        &[(0b01001, &ENTRY_DRAMATIZABLES_17777717401779818485)],
        &[(0b01001, &ENTRY_DRAMATIZABLEST_1714846433859302074)],
        &[(0b01001, &ENTRY_DRAMATIZATION_7793417852737015856)],
        &[(0b01001, &ENTRY_DRAMATIZATIONS_18020015640645554579)],
        &[(0b01001, &ENTRY_DRAMATIZE_5576714162148854490)],
        &[(0b01001, &ENTRY_DRAMATIZED_1183366410074875762)],
        &[(0b01001, &ENTRY_DRAMATIZER_4338891229356955125)],
        &[(0b01001, &ENTRY_DRAMATIZERS_4849393366081771993)],
        &[(0b01001, &ENTRY_DRAMATIZES_17928119971239910049)],
        &[(0b01001, &ENTRY_DRAMATIZING_17356943686393270091)],
    ],
    range: 5..=10,
};

static VARS_DRAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRAG_CHILDREN),
    value: None,
};

pub static VARS_DRAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DRAGONIZE_8136430885978842972)],
        &[(0b10010, &ENTRY_DRAGONIZED_17349000651376033189)],
        &[(0b10010, &ENTRY_DRAGONIZES_3000847053490583386)],
        &[(0b10010, &ENTRY_DRAGONIZING_11862836114639182313)],
        &[(0b01001, &ENTRY_DRAGONIZE_8136430885978842972)],
        &[(0b01001, &ENTRY_DRAGONIZED_17349000651376033189)],
        &[(0b01001, &ENTRY_DRAGONIZES_3000847053490583386)],
        &[(0b01001, &ENTRY_DRAGONIZING_11862836114639182313)],
    ],
    range: 5..=7,
};

static VARS_DRAF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRAF_CHILDREN),
    value: None,
};

pub static VARS_DRAF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tboard"),
        dictgen::InsensitiveStr::Ascii("tboards"),
        dictgen::InsensitiveStr::Ascii("tier"),
        dictgen::InsensitiveStr::Ascii("tiest"),
        dictgen::InsensitiveStr::Ascii("tilier"),
        dictgen::InsensitiveStr::Ascii("tiliest"),
        dictgen::InsensitiveStr::Ascii("tily"),
        dictgen::InsensitiveStr::Ascii("tiness"),
        dictgen::InsensitiveStr::Ascii("tinesses"),
        dictgen::InsensitiveStr::Ascii("tsman"),
        dictgen::InsensitiveStr::Ascii("tsmanship"),
        dictgen::InsensitiveStr::Ascii("tsmanships"),
        dictgen::InsensitiveStr::Ascii("tsmen"),
        dictgen::InsensitiveStr::Ascii("tsperson"),
        dictgen::InsensitiveStr::Ascii("tswoman"),
        dictgen::InsensitiveStr::Ascii("tswomen"),
        dictgen::InsensitiveStr::Ascii("ty"),
    ],
    values: &[
        &[(0b01001, &ENTRY_DRAUGHTBOARD_9322151322657814001)],
        &[(0b01001, &ENTRY_DRAUGHTBOARDS_18406148555375655231)],
        &[(0b01001, &ENTRY_DRAFTIER_10315157891310403943)],
        &[(0b01001, &ENTRY_DRAFTIEST_8211720032838927607)],
        &[(0b01001, &ENTRY_DRAFTILIER_7262684480559882840)],
        &[(0b01001, &ENTRY_DRAFTILIEST_9434728745324700875)],
        &[(0b01001, &ENTRY_DRAFTILY_16179502285729030019)],
        &[(0b01001, &ENTRY_DRAFTINESS_17583131269164652522)],
        &[(0b01001, &ENTRY_DRAFTINESSES_2329357781885563418)],
        &[(0b01001, &ENTRY_DRAFTSMAN_6333936616453092304)],
        &[(0b01001, &ENTRY_DRAFTSMANSHIP_15527745914295176647)],
        &[(0b01001, &ENTRY_DRAFTSMANSHIPS_4161880617470266425)],
        &[(0b01001, &ENTRY_DRAFTSMEN_7938842928790039444)],
        &[(0b01001, &ENTRY_DRAFTSPERSON_6409665226600621917)],
        &[(0b01001, &ENTRY_DRAFTSWOMAN_15962715217490874254)],
        &[(0b01001, &ENTRY_DRAFTSWOMEN_1853126005122534712)],
        &[(0b01001, &ENTRY_DRAFTY_1579846262644957016)],
    ],
    range: 2..=10,
};

static VARS_DRAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRAC_CHILDREN),
    value: None,
};

pub static VARS_DRAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aena"),
        dictgen::InsensitiveStr::Ascii("aenaceae"),
        dictgen::InsensitiveStr::Ascii("aenas"),
        dictgen::InsensitiveStr::Ascii("ena"),
        dictgen::InsensitiveStr::Ascii("enaceae"),
        dictgen::InsensitiveStr::Ascii("enas"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DRACENA_13360613075941336461)],
        &[(0b11010, &ENTRY_DRACENACEAE_6277389963808616184)],
        &[(0b11010, &ENTRY_DRACENAS_10822852860992428399)],
        &[(0b00001, &ENTRY_DRACENA_13360613075941336461)],
        &[(0b00001, &ENTRY_DRACENACEAE_6277389963808616184)],
        &[(0b00001, &ENTRY_DRACENAS_10822852860992428399)],
    ],
    range: 3..=8,
};

static VARS_DO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DO_CHILDREN),
    value: None,
};

static VARS_DO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_DOC_NODE),
    Some(&VARS_DOD_NODE),
    None,
    None,
    Some(&VARS_DOG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_DOL_NODE),
    Some(&VARS_DOM_NODE),
    Some(&VARS_DON_NODE),
    None,
    None,
    None,
    Some(&VARS_DOR_NODE),
    None,
    None,
    Some(&VARS_DOU_NODE),
    None,
    Some(&VARS_DOW_NODE),
    None,
    None,
    None,
];

static VARS_DOW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOW_CHILDREN),
    value: None,
};

pub static VARS_DOW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ndraft"),
        dictgen::InsensitiveStr::Ascii("ndraught"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DOWELED_16727405833500660020)],
        &[(0b00001, &ENTRY_DOWELER_2002458985122762767)],
        &[(0b00001, &ENTRY_DOWELING_1873186122978894197)],
        &[(0b11010, &ENTRY_DOWELED_16727405833500660020)],
        &[(0b11010, &ENTRY_DOWELER_2002458985122762767)],
        &[(0b11010, &ENTRY_DOWELING_1873186122978894197)],
        &[(0b01001, &ENTRY_DOWNDRAFT_672818375102871084)],
        &[(0b10010, &ENTRY_DOWNDRAFT_672818375102871084)],
    ],
    range: 4..=8,
};

static VARS_DOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOU_CHILDREN),
    value: None,
};

pub static VARS_DOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ra")],
    values: &[&[(0b11010, &ENTRY_DORA_4500258709959937838)]],
    range: 2..=2,
};

static VARS_DOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOR_CHILDREN),
    value: None,
};

pub static VARS_DOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
        dictgen::InsensitiveStr::Ascii("ylinae"),
        dictgen::InsensitiveStr::Ascii("yline"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DORA_4500258709959937838)],
        &[(0b10010, &ENTRY_DORICIZE_11178351137047196779)],
        &[(0b10010, &ENTRY_DORICIZES_5990614349327139127)],
        &[(0b01001, &ENTRY_DORICIZE_11178351137047196779)],
        &[(0b01001, &ENTRY_DORICIZES_5990614349327139127)],
        &[(0b10010, &ENTRY_DORIZE_3669118827894375489)],
        &[(0b10010, &ENTRY_DORIZED_6250566204141865145)],
        &[(0b10010, &ENTRY_DORIZES_109978163710471541)],
        &[(0b10010, &ENTRY_DORIZING_2573584499976703744)],
        &[(0b01001, &ENTRY_DORIZE_3669118827894375489)],
        &[(0b01001, &ENTRY_DORIZED_6250566204141865145)],
        &[(0b01001, &ENTRY_DORIZES_109978163710471541)],
        &[(0b01001, &ENTRY_DORIZING_2573584499976703744)],
        &[(0b11010, &ENTRY_DORYLINE_5269288463709196415)],
        &[(0b00001, &ENTRY_DORYLINE_5269288463709196415)],
    ],
    range: 1..=6,
};

static VARS_DON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DON_CHILDREN),
    value: None,
};

pub static VARS_DON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ut"),
        dictgen::InsensitiveStr::Ascii("uts"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DOUGHNUT_18126283850351248332)],
        &[(0b00001, &ENTRY_DOUGHNUTS_10463227561131847319)],
    ],
    range: 2..=3,
};

static VARS_DOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOM_CHILDREN),
    value: None,
};

pub static VARS_DOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("esticise"),
        dictgen::InsensitiveStr::Ascii("esticised"),
        dictgen::InsensitiveStr::Ascii("esticises"),
        dictgen::InsensitiveStr::Ascii("esticising"),
        dictgen::InsensitiveStr::Ascii("esticize"),
        dictgen::InsensitiveStr::Ascii("esticized"),
        dictgen::InsensitiveStr::Ascii("esticizes"),
        dictgen::InsensitiveStr::Ascii("esticizing"),
        dictgen::InsensitiveStr::Ascii("inae"),
        dictgen::InsensitiveStr::Ascii("ine"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DOMESTICIZE_16723626797661011386)],
        &[(0b10010, &ENTRY_DOMESTICIZED_17677304649717392604)],
        &[(0b10010, &ENTRY_DOMESTICIZES_16200456902435581821)],
        &[(0b10010, &ENTRY_DOMESTICIZING_4071827736712466122)],
        &[(0b01001, &ENTRY_DOMESTICIZE_16723626797661011386)],
        &[(0b01001, &ENTRY_DOMESTICIZED_17677304649717392604)],
        &[(0b01001, &ENTRY_DOMESTICIZES_16200456902435581821)],
        &[(0b01001, &ENTRY_DOMESTICIZING_4071827736712466122)],
        &[(0b11010, &ENTRY_DOMINE_14388567529452539641)],
        &[(0b00001, &ENTRY_DOMINE_14388567529452539641)],
    ],
    range: 3..=10,
};

static VARS_DOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOL_CHILDREN),
    value: None,
};

pub static VARS_DOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("larisation"),
        dictgen::InsensitiveStr::Ascii("larisations"),
        dictgen::InsensitiveStr::Ascii("larization"),
        dictgen::InsensitiveStr::Ascii("larizations"),
        dictgen::InsensitiveStr::Ascii("omitisation"),
        dictgen::InsensitiveStr::Ascii("omitisations"),
        dictgen::InsensitiveStr::Ascii("omitise"),
        dictgen::InsensitiveStr::Ascii("omitised"),
        dictgen::InsensitiveStr::Ascii("omitises"),
        dictgen::InsensitiveStr::Ascii("omitising"),
        dictgen::InsensitiveStr::Ascii("omitization"),
        dictgen::InsensitiveStr::Ascii("omitizations"),
        dictgen::InsensitiveStr::Ascii("omitize"),
        dictgen::InsensitiveStr::Ascii("omitized"),
        dictgen::InsensitiveStr::Ascii("omitizes"),
        dictgen::InsensitiveStr::Ascii("omitizing"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DOLLARIZATION_5698070921730819245)],
        &[(0b10010, &ENTRY_DOLLARIZATIONS_8202953595796740762)],
        &[(0b01001, &ENTRY_DOLLARIZATION_5698070921730819245)],
        &[(0b01001, &ENTRY_DOLLARIZATIONS_8202953595796740762)],
        &[(0b10010, &ENTRY_DOLOMITIZATION_6461676350416833082)],
        &[(0b10010, &ENTRY_DOLOMITIZATIONS_14007837662999431947)],
        &[(0b10010, &ENTRY_DOLOMITIZE_9046513132302198795)],
        &[(0b10010, &ENTRY_DOLOMITIZED_10868638513884715642)],
        &[(0b10010, &ENTRY_DOLOMITIZES_10827976409192397732)],
        &[(0b10010, &ENTRY_DOLOMITIZING_14905779901521480563)],
        &[(0b01001, &ENTRY_DOLOMITIZATION_6461676350416833082)],
        &[(0b01001, &ENTRY_DOLOMITIZATIONS_14007837662999431947)],
        &[(0b01001, &ENTRY_DOLOMITIZE_9046513132302198795)],
        &[(0b01001, &ENTRY_DOLOMITIZED_10868638513884715642)],
        &[(0b01001, &ENTRY_DOLOMITIZES_10827976409192397732)],
        &[(0b01001, &ENTRY_DOLOMITIZING_14905779901521480563)],
        &[(0b11001, &ENTRY_DOLOR_11069244362262877679)],
        &[(0b11001, &ENTRY_DOLORS_8418108938588101110)],
        &[(0b11010, &ENTRY_DOLOR_11069244362262877679)],
        &[(0b11010, &ENTRY_DOLORS_8418108938588101110)],
    ],
    range: 2..=12,
};

static VARS_DOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOG_CHILDREN),
    value: None,
};

pub static VARS_DOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matisation"),
        dictgen::InsensitiveStr::Ascii("matisations"),
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matiser"),
        dictgen::InsensitiveStr::Ascii("matisers"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matization"),
        dictgen::InsensitiveStr::Ascii("matizations"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizer"),
        dictgen::InsensitiveStr::Ascii("matizers"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
        dictgen::InsensitiveStr::Ascii("naped"),
        dictgen::InsensitiveStr::Ascii("naping"),
        dictgen::InsensitiveStr::Ascii("napped"),
        dictgen::InsensitiveStr::Ascii("napping"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DOGMATIZATION_11122345555081593564)],
        &[(0b10010, &ENTRY_DOGMATIZATIONS_13024880750897076624)],
        &[(0b10010, &ENTRY_DOGMATIZE_4788814445794390818)],
        &[(0b10010, &ENTRY_DOGMATIZED_12823946452811271962)],
        &[(0b10010, &ENTRY_DOGMATIZER_17313290517364467144)],
        &[(0b10010, &ENTRY_DOGMATIZERS_2555429245698465340)],
        &[(0b10010, &ENTRY_DOGMATIZES_15001409429715187150)],
        &[(0b10010, &ENTRY_DOGMATIZING_17332622864075797339)],
        &[(0b01001, &ENTRY_DOGMATIZATION_11122345555081593564)],
        &[(0b01001, &ENTRY_DOGMATIZATIONS_13024880750897076624)],
        &[(0b01001, &ENTRY_DOGMATIZE_4788814445794390818)],
        &[(0b01001, &ENTRY_DOGMATIZED_12823946452811271962)],
        &[(0b01001, &ENTRY_DOGMATIZER_17313290517364467144)],
        &[(0b01001, &ENTRY_DOGMATIZERS_2555429245698465340)],
        &[(0b01001, &ENTRY_DOGMATIZES_15001409429715187150)],
        &[(0b01001, &ENTRY_DOGMATIZING_17332622864075797339)],
        &[(0b00001, &ENTRY_DOGNAPED_1802260907201390168)],
        &[(0b00001, &ENTRY_DOGNAPING_13937433132377991875)],
        &[(0b11010, &ENTRY_DOGNAPED_1802260907201390168)],
        &[(0b11010, &ENTRY_DOGNAPING_13937433132377991875)],
    ],
    range: 5..=11,
};

static VARS_DOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOD_CHILDREN),
    value: None,
};

pub static VARS_DOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onaean"),
        dictgen::InsensitiveStr::Ascii("onean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DODONEAN_2630856114735687957)],
        &[(0b00001, &ENTRY_DODONEAN_2630856114735687957)],
    ],
    range: 5..=6,
};

static VARS_DOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOC_CHILDREN),
    value: None,
};

pub static VARS_DOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etae"),
        dictgen::InsensitiveStr::Ascii("ete"),
        dictgen::InsensitiveStr::Ascii("kisation"),
        dictgen::InsensitiveStr::Ascii("kisations"),
        dictgen::InsensitiveStr::Ascii("kise"),
        dictgen::InsensitiveStr::Ascii("kised"),
        dictgen::InsensitiveStr::Ascii("kises"),
        dictgen::InsensitiveStr::Ascii("kising"),
        dictgen::InsensitiveStr::Ascii("kization"),
        dictgen::InsensitiveStr::Ascii("kizations"),
        dictgen::InsensitiveStr::Ascii("kize"),
        dictgen::InsensitiveStr::Ascii("kized"),
        dictgen::InsensitiveStr::Ascii("kizes"),
        dictgen::InsensitiveStr::Ascii("kizing"),
        dictgen::InsensitiveStr::Ascii("torisation"),
        dictgen::InsensitiveStr::Ascii("torisations"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torization"),
        dictgen::InsensitiveStr::Ascii("torizations"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torizes"),
        dictgen::InsensitiveStr::Ascii("trinisation"),
        dictgen::InsensitiveStr::Ascii("trinisations"),
        dictgen::InsensitiveStr::Ascii("trinise"),
        dictgen::InsensitiveStr::Ascii("trinises"),
        dictgen::InsensitiveStr::Ascii("trinization"),
        dictgen::InsensitiveStr::Ascii("trinizations"),
        dictgen::InsensitiveStr::Ascii("trinize"),
        dictgen::InsensitiveStr::Ascii("trinizes"),
        dictgen::InsensitiveStr::Ascii("umentarisation"),
        dictgen::InsensitiveStr::Ascii("umentarisations"),
        dictgen::InsensitiveStr::Ascii("umentarise"),
        dictgen::InsensitiveStr::Ascii("umentarised"),
        dictgen::InsensitiveStr::Ascii("umentarises"),
        dictgen::InsensitiveStr::Ascii("umentarising"),
        dictgen::InsensitiveStr::Ascii("umentarization"),
        dictgen::InsensitiveStr::Ascii("umentarizations"),
        dictgen::InsensitiveStr::Ascii("umentarize"),
        dictgen::InsensitiveStr::Ascii("umentarized"),
        dictgen::InsensitiveStr::Ascii("umentarizes"),
        dictgen::InsensitiveStr::Ascii("umentarizing"),
        dictgen::InsensitiveStr::Ascii("umentise"),
        dictgen::InsensitiveStr::Ascii("umentises"),
        dictgen::InsensitiveStr::Ascii("umentize"),
        dictgen::InsensitiveStr::Ascii("umentizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DOCETE_18210621150940118199)],
        &[(0b00001, &ENTRY_DOCETE_18210621150940118199)],
        &[(0b10010, &ENTRY_DOCKIZATION_2359063524793332046)],
        &[(0b10010, &ENTRY_DOCKIZATIONS_3062523957842125154)],
        &[(0b10010, &ENTRY_DOCKIZE_3129922305769972728)],
        &[(0b10010, &ENTRY_DOCKIZED_3041614695023781078)],
        &[(0b10010, &ENTRY_DOCKIZES_1001266725508279323)],
        &[(0b10010, &ENTRY_DOCKIZING_16895087588592694901)],
        &[(0b01001, &ENTRY_DOCKIZATION_2359063524793332046)],
        &[(0b01001, &ENTRY_DOCKIZATIONS_3062523957842125154)],
        &[(0b01001, &ENTRY_DOCKIZE_3129922305769972728)],
        &[(0b01001, &ENTRY_DOCKIZED_3041614695023781078)],
        &[(0b01001, &ENTRY_DOCKIZES_1001266725508279323)],
        &[(0b01001, &ENTRY_DOCKIZING_16895087588592694901)],
        &[(0b10010, &ENTRY_DOCTORIZATION_8095587565262451629)],
        &[(0b10010, &ENTRY_DOCTORIZATIONS_17824096614783886488)],
        &[(0b10010, &ENTRY_DOCTORIZE_5270617854561441050)],
        &[(0b10010, &ENTRY_DOCTORIZES_2437264913148867517)],
        &[(0b01001, &ENTRY_DOCTORIZATION_8095587565262451629)],
        &[(0b01001, &ENTRY_DOCTORIZATIONS_17824096614783886488)],
        &[(0b01001, &ENTRY_DOCTORIZE_5270617854561441050)],
        &[(0b01001, &ENTRY_DOCTORIZES_2437264913148867517)],
        &[(0b10010, &ENTRY_DOCTRINIZATION_208993614488737715)],
        &[(0b10010, &ENTRY_DOCTRINIZATIONS_11848559846665795864)],
        &[(0b10010, &ENTRY_DOCTRINIZE_6590461152234221617)],
        &[(0b10010, &ENTRY_DOCTRINIZES_5629972029764985513)],
        &[(0b01001, &ENTRY_DOCTRINIZATION_208993614488737715)],
        &[(0b01001, &ENTRY_DOCTRINIZATIONS_11848559846665795864)],
        &[(0b01001, &ENTRY_DOCTRINIZE_6590461152234221617)],
        &[(0b01001, &ENTRY_DOCTRINIZES_5629972029764985513)],
        &[(0b10010, &ENTRY_DOCUMENTARIZATION_6006296474311575553)],
        &[(0b10010, &ENTRY_DOCUMENTARIZATIONS_18171665198929635251)],
        &[(0b10010, &ENTRY_DOCUMENTARIZE_7464249019029490374)],
        &[(0b10010, &ENTRY_DOCUMENTARIZED_10188551105211855695)],
        &[(0b10010, &ENTRY_DOCUMENTARIZES_5957801404549962940)],
        &[(0b10010, &ENTRY_DOCUMENTARIZING_3990677850725093411)],
        &[(0b01001, &ENTRY_DOCUMENTARIZATION_6006296474311575553)],
        &[(0b01001, &ENTRY_DOCUMENTARIZATIONS_18171665198929635251)],
        &[(0b01001, &ENTRY_DOCUMENTARIZE_7464249019029490374)],
        &[(0b01001, &ENTRY_DOCUMENTARIZED_10188551105211855695)],
        &[(0b01001, &ENTRY_DOCUMENTARIZES_5957801404549962940)],
        &[(0b01001, &ENTRY_DOCUMENTARIZING_3990677850725093411)],
        &[(0b10010, &ENTRY_DOCUMENTIZE_4375971920660462713)],
        &[(0b10010, &ENTRY_DOCUMENTIZES_9883311938822654310)],
        &[(0b01001, &ENTRY_DOCUMENTIZE_4375971920660462713)],
        &[(0b01001, &ENTRY_DOCUMENTIZES_9883311938822654310)],
    ],
    range: 3..=15,
};

static VARS_DI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DI_CHILDREN),
    value: None,
};

static VARS_DI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DIA_NODE),
    None,
    Some(&VARS_DIC_NODE),
    None,
    Some(&VARS_DIE_NODE),
    Some(&VARS_DIF_NODE),
    Some(&VARS_DIG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DIM_NODE),
    None,
    Some(&VARS_DIO_NODE),
    Some(&VARS_DIP_NODE),
    None,
    None,
    Some(&VARS_DIS_NODE),
    None,
    None,
    Some(&VARS_DIV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_DIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIV_CHILDREN),
    value: None,
};

pub static VARS_DIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ersicolored"),
        dictgen::InsensitiveStr::Ascii("ersicoloured"),
        dictgen::InsensitiveStr::Ascii("inisation"),
        dictgen::InsensitiveStr::Ascii("inisations"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inised"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inising"),
        dictgen::InsensitiveStr::Ascii("inister"),
        dictgen::InsensitiveStr::Ascii("inistre"),
        dictgen::InsensitiveStr::Ascii("inization"),
        dictgen::InsensitiveStr::Ascii("inizations"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inized"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inizing"),
        dictgen::InsensitiveStr::Ascii("isionalisation"),
        dictgen::InsensitiveStr::Ascii("isionalisations"),
        dictgen::InsensitiveStr::Ascii("isionalization"),
        dictgen::InsensitiveStr::Ascii("isionalizations"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DIVERSICOLORED_13604237391321254433)],
        &[(0b11010, &ENTRY_DIVERSICOLORED_13604237391321254433)],
        &[(0b10010, &ENTRY_DIVINIZATION_11972340056619369285)],
        &[(0b10010, &ENTRY_DIVINIZATIONS_13538291884563048141)],
        &[(0b10010, &ENTRY_DIVINIZE_8792843604983197190)],
        &[(0b10010, &ENTRY_DIVINIZED_6811293569537741594)],
        &[(0b10010, &ENTRY_DIVINIZES_15547907663135588559)],
        &[(0b10010, &ENTRY_DIVINIZING_10978447348346172564)],
        &[(0b00001, &ENTRY_DIVINISTER_16908631551602499711)],
        &[(0b11010, &ENTRY_DIVINISTER_16908631551602499711)],
        &[(0b01001, &ENTRY_DIVINIZATION_11972340056619369285)],
        &[(0b01001, &ENTRY_DIVINIZATIONS_13538291884563048141)],
        &[(0b01001, &ENTRY_DIVINIZE_8792843604983197190)],
        &[(0b01001, &ENTRY_DIVINIZED_6811293569537741594)],
        &[(0b01001, &ENTRY_DIVINIZES_15547907663135588559)],
        &[(0b01001, &ENTRY_DIVINIZING_10978447348346172564)],
        &[(0b10010, &ENTRY_DIVISIONALIZATION_6004413059534979150)],
        &[(0b10010, &ENTRY_DIVISIONALIZATIONS_15028430852200113799)],
        &[(0b01001, &ENTRY_DIVISIONALIZATION_6004413059534979150)],
        &[(0b01001, &ENTRY_DIVISIONALIZATIONS_15028430852200113799)],
    ],
    range: 5..=15,
};

static VARS_DIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DIS_CHILDREN),
    value: None,
};

static VARS_DIS_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DISA_NODE),
    Some(&VARS_DISB_NODE),
    Some(&VARS_DISC_NODE),
    Some(&VARS_DISD_NODE),
    Some(&VARS_DISE_NODE),
    Some(&VARS_DISF_NODE),
    None,
    Some(&VARS_DISH_NODE),
    Some(&VARS_DISI_NODE),
    None,
    None,
    Some(&VARS_DISL_NODE),
    Some(&VARS_DISM_NODE),
    Some(&VARS_DISN_NODE),
    Some(&VARS_DISO_NODE),
    Some(&VARS_DISP_NODE),
    None,
    Some(&VARS_DISR_NODE),
    Some(&VARS_DISS_NODE),
    Some(&VARS_DIST_NODE),
    Some(&VARS_DISU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_DISU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISU_CHILDREN),
    value: None,
};

pub static VARS_DISU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tilise"),
        dictgen::InsensitiveStr::Ascii("tilises"),
        dictgen::InsensitiveStr::Ascii("tilize"),
        dictgen::InsensitiveStr::Ascii("tilizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISUTILIZE_5491879073193162565)],
        &[(0b10010, &ENTRY_DISUTILIZES_15486108534615553292)],
        &[(0b01001, &ENTRY_DISUTILIZE_5491879073193162565)],
        &[(0b01001, &ENTRY_DISUTILIZES_15486108534615553292)],
    ],
    range: 6..=7,
};

static VARS_DIST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIST_CHILDREN),
    value: None,
};

pub static VARS_DIST_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ill"),
        dictgen::InsensitiveStr::Ascii("ills"),
    ],
    values: &[
        &[(0b01001, &ENTRY_DISTILL_72998375259612317)],
        &[(0b01001, &ENTRY_DISTILLS_6330479058124863728)],
    ],
    range: 3..=4,
};

static VARS_DISS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISS_CHILDREN),
    value: None,
};

pub static VARS_DISS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cepter"),
        dictgen::InsensitiveStr::Ascii("cepters"),
        dictgen::InsensitiveStr::Ascii("ceptre"),
        dictgen::InsensitiveStr::Ascii("ceptres"),
        dictgen::InsensitiveStr::Ascii("eise"),
        dictgen::InsensitiveStr::Ascii("eised"),
        dictgen::InsensitiveStr::Ascii("eisee"),
        dictgen::InsensitiveStr::Ascii("eises"),
        dictgen::InsensitiveStr::Ascii("eisin"),
        dictgen::InsensitiveStr::Ascii("eising"),
        dictgen::InsensitiveStr::Ascii("eisins"),
        dictgen::InsensitiveStr::Ascii("eisor"),
        dictgen::InsensitiveStr::Ascii("eisors"),
        dictgen::InsensitiveStr::Ascii("eize"),
        dictgen::InsensitiveStr::Ascii("eized"),
        dictgen::InsensitiveStr::Ascii("eizee"),
        dictgen::InsensitiveStr::Ascii("eizes"),
        dictgen::InsensitiveStr::Ascii("eizin"),
        dictgen::InsensitiveStr::Ascii("eizing"),
        dictgen::InsensitiveStr::Ascii("eizins"),
        dictgen::InsensitiveStr::Ascii("eizor"),
        dictgen::InsensitiveStr::Ascii("eizors"),
        dictgen::InsensitiveStr::Ascii("ensualise"),
        dictgen::InsensitiveStr::Ascii("ensualises"),
        dictgen::InsensitiveStr::Ascii("ensualize"),
        dictgen::InsensitiveStr::Ascii("ensualizes"),
        dictgen::InsensitiveStr::Ascii("ocialise"),
        dictgen::InsensitiveStr::Ascii("ocialised"),
        dictgen::InsensitiveStr::Ascii("ocialises"),
        dictgen::InsensitiveStr::Ascii("ocialising"),
        dictgen::InsensitiveStr::Ascii("ocialize"),
        dictgen::InsensitiveStr::Ascii("ocialized"),
        dictgen::InsensitiveStr::Ascii("ocializes"),
        dictgen::InsensitiveStr::Ascii("ocializing"),
        dictgen::InsensitiveStr::Ascii("yllabise"),
        dictgen::InsensitiveStr::Ascii("yllabised"),
        dictgen::InsensitiveStr::Ascii("yllabising"),
        dictgen::InsensitiveStr::Ascii("yllabize"),
        dictgen::InsensitiveStr::Ascii("yllabized"),
        dictgen::InsensitiveStr::Ascii("yllabizing"),
        dictgen::InsensitiveStr::Ascii("ympathise"),
        dictgen::InsensitiveStr::Ascii("ympathises"),
        dictgen::InsensitiveStr::Ascii("ympathize"),
        dictgen::InsensitiveStr::Ascii("ympathizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DISSCEPTER_15059488157685275579)],
        &[(0b00001, &ENTRY_DISSCEPTERS_4311122668006835706)],
        &[(0b11010, &ENTRY_DISSCEPTER_15059488157685275579)],
        &[(0b11010, &ENTRY_DISSCEPTERS_4311122668006835706)],
        &[(0b10010, &ENTRY_DISSEIZE_11569356311223512234)],
        &[(0b10010, &ENTRY_DISSEIZED_2079387468009637513)],
        &[(0b10010, &ENTRY_DISSEIZEE_6124208357466227860)],
        &[(0b10010, &ENTRY_DISSEIZES_14929980355877382152)],
        &[(0b11010, &ENTRY_DISSEIZIN_7901052414713980761)],
        &[(0b10010, &ENTRY_DISSEIZING_14239857670092493992)],
        &[(0b11010, &ENTRY_DISSEIZINS_2569940430990116237)],
        &[(0b11010, &ENTRY_DISSEIZOR_14475077887631074628)],
        &[(0b11010, &ENTRY_DISSEIZORS_2869738690076803680)],
        &[(0b01001, &ENTRY_DISSEIZE_11569356311223512234)],
        &[(0b01001, &ENTRY_DISSEIZED_2079387468009637513)],
        &[(0b01001, &ENTRY_DISSEIZEE_6124208357466227860)],
        &[(0b01001, &ENTRY_DISSEIZES_14929980355877382152)],
        &[(0b00001, &ENTRY_DISSEIZIN_7901052414713980761)],
        &[(0b01001, &ENTRY_DISSEIZING_14239857670092493992)],
        &[(0b00001, &ENTRY_DISSEIZINS_2569940430990116237)],
        &[(0b00001, &ENTRY_DISSEIZOR_14475077887631074628)],
        &[(0b00001, &ENTRY_DISSEIZORS_2869738690076803680)],
        &[(0b10010, &ENTRY_DISSENSUALIZE_7244829030534674841)],
        &[(0b10010, &ENTRY_DISSENSUALIZES_16186087831493933183)],
        &[(0b01001, &ENTRY_DISSENSUALIZE_7244829030534674841)],
        &[(0b01001, &ENTRY_DISSENSUALIZES_16186087831493933183)],
        &[(0b10010, &ENTRY_DISSOCIALIZE_3098839401536604100)],
        &[(0b10010, &ENTRY_DISSOCIALIZED_7817550467475017912)],
        &[(0b10010, &ENTRY_DISSOCIALIZES_3807225651535481442)],
        &[(0b10010, &ENTRY_DISSOCIALIZING_18099761030916777061)],
        &[(0b01001, &ENTRY_DISSOCIALIZE_3098839401536604100)],
        &[(0b01001, &ENTRY_DISSOCIALIZED_7817550467475017912)],
        &[(0b01001, &ENTRY_DISSOCIALIZES_3807225651535481442)],
        &[(0b01001, &ENTRY_DISSOCIALIZING_18099761030916777061)],
        &[(0b10010, &ENTRY_DISSYLLABIZE_5360857095905079197)],
        &[(0b10010, &ENTRY_DISSYLLABIZED_13261189064508331736)],
        &[(0b10010, &ENTRY_DISSYLLABIZING_6445596796049180767)],
        &[(0b01001, &ENTRY_DISSYLLABIZE_5360857095905079197)],
        &[(0b01001, &ENTRY_DISSYLLABIZED_13261189064508331736)],
        &[(0b01001, &ENTRY_DISSYLLABIZING_6445596796049180767)],
        &[(0b10010, &ENTRY_DISSYMPATHIZE_16935057061240923894)],
        &[(0b10010, &ENTRY_DISSYMPATHIZES_14278393868885673403)],
        &[(0b01001, &ENTRY_DISSYMPATHIZE_16935057061240923894)],
        &[(0b01001, &ENTRY_DISSYMPATHIZES_14278393868885673403)],
    ],
    range: 4..=10,
};

static VARS_DISR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISR_CHILDREN),
    value: None,
};

pub static VARS_DISR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ealise"),
        dictgen::InsensitiveStr::Ascii("ealises"),
        dictgen::InsensitiveStr::Ascii("ealize"),
        dictgen::InsensitiveStr::Ascii("ealizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISREALIZE_10968259045804893585)],
        &[(0b10010, &ENTRY_DISREALIZES_15666216050063868100)],
        &[(0b01001, &ENTRY_DISREALIZE_10968259045804893585)],
        &[(0b01001, &ENTRY_DISREALIZES_15666216050063868100)],
    ],
    range: 6..=7,
};

static VARS_DISP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISP_CHILDREN),
    value: None,
};

pub static VARS_DISP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("apalise"),
        dictgen::InsensitiveStr::Ascii("apalises"),
        dictgen::InsensitiveStr::Ascii("apalize"),
        dictgen::InsensitiveStr::Ascii("apalizes"),
        dictgen::InsensitiveStr::Ascii("auperise"),
        dictgen::InsensitiveStr::Ascii("auperised"),
        dictgen::InsensitiveStr::Ascii("auperises"),
        dictgen::InsensitiveStr::Ascii("auperising"),
        dictgen::InsensitiveStr::Ascii("auperize"),
        dictgen::InsensitiveStr::Ascii("auperized"),
        dictgen::InsensitiveStr::Ascii("auperizes"),
        dictgen::InsensitiveStr::Ascii("auperizing"),
        dictgen::InsensitiveStr::Ascii("ersonalise"),
        dictgen::InsensitiveStr::Ascii("ersonalises"),
        dictgen::InsensitiveStr::Ascii("ersonalize"),
        dictgen::InsensitiveStr::Ascii("ersonalizes"),
        dictgen::InsensitiveStr::Ascii("opularise"),
        dictgen::InsensitiveStr::Ascii("opularises"),
        dictgen::InsensitiveStr::Ascii("opularize"),
        dictgen::InsensitiveStr::Ascii("opularizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISPAPALIZE_12503394153284261888)],
        &[(0b10010, &ENTRY_DISPAPALIZES_7854705630224972621)],
        &[(0b01001, &ENTRY_DISPAPALIZE_12503394153284261888)],
        &[(0b01001, &ENTRY_DISPAPALIZES_7854705630224972621)],
        &[(0b10010, &ENTRY_DISPAUPERIZE_16571750003331073373)],
        &[(0b10010, &ENTRY_DISPAUPERIZED_5072817155402454298)],
        &[(0b10010, &ENTRY_DISPAUPERIZES_4159908714944585355)],
        &[(0b10010, &ENTRY_DISPAUPERIZING_9914663279704655258)],
        &[(0b01001, &ENTRY_DISPAUPERIZE_16571750003331073373)],
        &[(0b01001, &ENTRY_DISPAUPERIZED_5072817155402454298)],
        &[(0b01001, &ENTRY_DISPAUPERIZES_4159908714944585355)],
        &[(0b01001, &ENTRY_DISPAUPERIZING_9914663279704655258)],
        &[(0b10010, &ENTRY_DISPERSONALIZE_4939920470701961719)],
        &[(0b10010, &ENTRY_DISPERSONALIZES_17310403051207524564)],
        &[(0b01001, &ENTRY_DISPERSONALIZE_4939920470701961719)],
        &[(0b01001, &ENTRY_DISPERSONALIZES_17310403051207524564)],
        &[(0b10010, &ENTRY_DISPOPULARIZE_13320474917175875266)],
        &[(0b10010, &ENTRY_DISPOPULARIZES_4469702792863907437)],
        &[(0b01001, &ENTRY_DISPOPULARIZE_13320474917175875266)],
        &[(0b01001, &ENTRY_DISPOPULARIZES_4469702792863907437)],
    ],
    range: 7..=11,
};

static VARS_DISO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISO_CHILDREN),
    value: None,
};

pub static VARS_DISO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganise"),
        dictgen::InsensitiveStr::Ascii("rganised"),
        dictgen::InsensitiveStr::Ascii("rganiser"),
        dictgen::InsensitiveStr::Ascii("rganisers"),
        dictgen::InsensitiveStr::Ascii("rganises"),
        dictgen::InsensitiveStr::Ascii("rganising"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("rganize"),
        dictgen::InsensitiveStr::Ascii("rganized"),
        dictgen::InsensitiveStr::Ascii("rganizer"),
        dictgen::InsensitiveStr::Ascii("rganizers"),
        dictgen::InsensitiveStr::Ascii("rganizes"),
        dictgen::InsensitiveStr::Ascii("rganizing"),
        dictgen::InsensitiveStr::Ascii("zonise"),
        dictgen::InsensitiveStr::Ascii("zonises"),
        dictgen::InsensitiveStr::Ascii("zonize"),
        dictgen::InsensitiveStr::Ascii("zonizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISORGANIZATION_16996811069576322696)],
        &[(0b10010, &ENTRY_DISORGANIZATIONS_5594690456228431300)],
        &[(0b10010, &ENTRY_DISORGANIZE_8532063637419651098)],
        &[(0b10010, &ENTRY_DISORGANIZED_8174306046630470447)],
        &[(0b10010, &ENTRY_DISORGANIZER_14173806118703512335)],
        &[(0b10010, &ENTRY_DISORGANIZERS_14983162437093206464)],
        &[(0b10010, &ENTRY_DISORGANIZES_2153949974040488529)],
        &[(0b10010, &ENTRY_DISORGANIZING_9571942280468279076)],
        &[(0b01001, &ENTRY_DISORGANIZATION_16996811069576322696)],
        &[(0b01001, &ENTRY_DISORGANIZATIONS_5594690456228431300)],
        &[(0b01001, &ENTRY_DISORGANIZE_8532063637419651098)],
        &[(0b01001, &ENTRY_DISORGANIZED_8174306046630470447)],
        &[(0b01001, &ENTRY_DISORGANIZER_14173806118703512335)],
        &[(0b01001, &ENTRY_DISORGANIZERS_14983162437093206464)],
        &[(0b01001, &ENTRY_DISORGANIZES_2153949974040488529)],
        &[(0b01001, &ENTRY_DISORGANIZING_9571942280468279076)],
        &[(0b10010, &ENTRY_DISOZONIZE_16113533175672098111)],
        &[(0b10010, &ENTRY_DISOZONIZES_9388111209265427380)],
        &[(0b01001, &ENTRY_DISOZONIZE_16113533175672098111)],
        &[(0b01001, &ENTRY_DISOZONIZES_9388111209265427380)],
    ],
    range: 6..=12,
};

static VARS_DISN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISN_CHILDREN),
    value: None,
};

pub static VARS_DISN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aturalisation"),
        dictgen::InsensitiveStr::Ascii("aturalisations"),
        dictgen::InsensitiveStr::Ascii("aturalise"),
        dictgen::InsensitiveStr::Ascii("aturalised"),
        dictgen::InsensitiveStr::Ascii("aturalises"),
        dictgen::InsensitiveStr::Ascii("aturalising"),
        dictgen::InsensitiveStr::Ascii("aturalization"),
        dictgen::InsensitiveStr::Ascii("aturalizations"),
        dictgen::InsensitiveStr::Ascii("aturalize"),
        dictgen::InsensitiveStr::Ascii("aturalized"),
        dictgen::InsensitiveStr::Ascii("aturalizes"),
        dictgen::InsensitiveStr::Ascii("aturalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISNATURALIZATION_13759062101456967136)],
        &[(0b10010, &ENTRY_DISNATURALIZATIONS_9144315549620421227)],
        &[(0b10010, &ENTRY_DISNATURALIZE_4631885449577103514)],
        &[(0b10010, &ENTRY_DISNATURALIZED_5139712538919037153)],
        &[(0b10010, &ENTRY_DISNATURALIZES_5656357318797234866)],
        &[(0b10010, &ENTRY_DISNATURALIZING_9697668056281067306)],
        &[(0b01001, &ENTRY_DISNATURALIZATION_13759062101456967136)],
        &[(0b01001, &ENTRY_DISNATURALIZATIONS_9144315549620421227)],
        &[(0b01001, &ENTRY_DISNATURALIZE_4631885449577103514)],
        &[(0b01001, &ENTRY_DISNATURALIZED_5139712538919037153)],
        &[(0b01001, &ENTRY_DISNATURALIZES_5656357318797234866)],
        &[(0b01001, &ENTRY_DISNATURALIZING_9697668056281067306)],
    ],
    range: 9..=14,
};

static VARS_DISM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISM_CHILDREN),
    value: None,
};

pub static VARS_DISM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISMALIZE_7994271907630309515)],
        &[(0b10010, &ENTRY_DISMALIZES_2605097482883819029)],
        &[(0b01001, &ENTRY_DISMALIZE_7994271907630309515)],
        &[(0b01001, &ENTRY_DISMALIZES_2605097482883819029)],
    ],
    range: 5..=6,
};

static VARS_DISL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISL_CHILDREN),
    value: None,
};

pub static VARS_DISL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uster"),
        dictgen::InsensitiveStr::Ascii("ustre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DISLUSTER_13358247352773333676)],
        &[(0b11010, &ENTRY_DISLUSTER_13358247352773333676)],
    ],
    range: 5..=5,
};

static VARS_DISI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISI_CHILDREN),
    value: None,
};

pub static VARS_DISI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("llusionise"),
        dictgen::InsensitiveStr::Ascii("llusionised"),
        dictgen::InsensitiveStr::Ascii("llusioniser"),
        dictgen::InsensitiveStr::Ascii("llusionisers"),
        dictgen::InsensitiveStr::Ascii("llusionises"),
        dictgen::InsensitiveStr::Ascii("llusionising"),
        dictgen::InsensitiveStr::Ascii("llusionize"),
        dictgen::InsensitiveStr::Ascii("llusionized"),
        dictgen::InsensitiveStr::Ascii("llusionizer"),
        dictgen::InsensitiveStr::Ascii("llusionizers"),
        dictgen::InsensitiveStr::Ascii("llusionizes"),
        dictgen::InsensitiveStr::Ascii("llusionizing"),
        dictgen::InsensitiveStr::Ascii("ndividualise"),
        dictgen::InsensitiveStr::Ascii("ndividualised"),
        dictgen::InsensitiveStr::Ascii("ndividualises"),
        dictgen::InsensitiveStr::Ascii("ndividualising"),
        dictgen::InsensitiveStr::Ascii("ndividualize"),
        dictgen::InsensitiveStr::Ascii("ndividualized"),
        dictgen::InsensitiveStr::Ascii("ndividualizes"),
        dictgen::InsensitiveStr::Ascii("ndividualizing"),
        dictgen::InsensitiveStr::Ascii("ndustrialisation"),
        dictgen::InsensitiveStr::Ascii("ndustrialisations"),
        dictgen::InsensitiveStr::Ascii("ndustrialise"),
        dictgen::InsensitiveStr::Ascii("ndustrialised"),
        dictgen::InsensitiveStr::Ascii("ndustrialises"),
        dictgen::InsensitiveStr::Ascii("ndustrialising"),
        dictgen::InsensitiveStr::Ascii("ndustrialization"),
        dictgen::InsensitiveStr::Ascii("ndustrializations"),
        dictgen::InsensitiveStr::Ascii("ndustrialize"),
        dictgen::InsensitiveStr::Ascii("ndustrialized"),
        dictgen::InsensitiveStr::Ascii("ndustrializes"),
        dictgen::InsensitiveStr::Ascii("ndustrializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISILLUSIONIZE_544284270568577104)],
        &[(0b10010, &ENTRY_DISILLUSIONIZED_2046602644783149604)],
        &[(0b10010, &ENTRY_DISILLUSIONIZER_3198853356088724502)],
        &[(0b10010, &ENTRY_DISILLUSIONIZERS_16679379308545646053)],
        &[(0b10010, &ENTRY_DISILLUSIONIZES_9587219142518614686)],
        &[(0b10010, &ENTRY_DISILLUSIONIZING_2867093168312197564)],
        &[(0b01001, &ENTRY_DISILLUSIONIZE_544284270568577104)],
        &[(0b01001, &ENTRY_DISILLUSIONIZED_2046602644783149604)],
        &[(0b01001, &ENTRY_DISILLUSIONIZER_3198853356088724502)],
        &[(0b01001, &ENTRY_DISILLUSIONIZERS_16679379308545646053)],
        &[(0b01001, &ENTRY_DISILLUSIONIZES_9587219142518614686)],
        &[(0b01001, &ENTRY_DISILLUSIONIZING_2867093168312197564)],
        &[(0b10010, &ENTRY_DISINDIVIDUALIZE_3474275877211684124)],
        &[(0b10010, &ENTRY_DISINDIVIDUALIZED_8419880667851776580)],
        &[(0b10010, &ENTRY_DISINDIVIDUALIZES_4702939998891004702)],
        &[(0b10010, &ENTRY_DISINDIVIDUALIZING_17455766326632665129)],
        &[(0b01001, &ENTRY_DISINDIVIDUALIZE_3474275877211684124)],
        &[(0b01001, &ENTRY_DISINDIVIDUALIZED_8419880667851776580)],
        &[(0b01001, &ENTRY_DISINDIVIDUALIZES_4702939998891004702)],
        &[(0b01001, &ENTRY_DISINDIVIDUALIZING_17455766326632665129)],
        &[(0b10010, &ENTRY_DISINDUSTRIALIZATION_17135590793569724945)],
        &[(0b10010, &ENTRY_DISINDUSTRIALIZATIONS_6170260318117555283)],
        &[(0b10010, &ENTRY_DISINDUSTRIALIZE_3656465979526508744)],
        &[(0b10010, &ENTRY_DISINDUSTRIALIZED_5965260381139710218)],
        &[(0b10010, &ENTRY_DISINDUSTRIALIZES_15047921186004255745)],
        &[(0b10010, &ENTRY_DISINDUSTRIALIZING_14648192815944839417)],
        &[(0b01001, &ENTRY_DISINDUSTRIALIZATION_17135590793569724945)],
        &[(0b01001, &ENTRY_DISINDUSTRIALIZATIONS_6170260318117555283)],
        &[(0b01001, &ENTRY_DISINDUSTRIALIZE_3656465979526508744)],
        &[(0b01001, &ENTRY_DISINDUSTRIALIZED_5965260381139710218)],
        &[(0b01001, &ENTRY_DISINDUSTRIALIZES_15047921186004255745)],
        &[(0b01001, &ENTRY_DISINDUSTRIALIZING_14648192815944839417)],
    ],
    range: 10..=17,
};

static VARS_DISH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISH_CHILDREN),
    value: None,
};

pub static VARS_DISH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("armonise"),
        dictgen::InsensitiveStr::Ascii("armonised"),
        dictgen::InsensitiveStr::Ascii("armonises"),
        dictgen::InsensitiveStr::Ascii("armonising"),
        dictgen::InsensitiveStr::Ascii("armonize"),
        dictgen::InsensitiveStr::Ascii("armonized"),
        dictgen::InsensitiveStr::Ascii("armonizes"),
        dictgen::InsensitiveStr::Ascii("armonizing"),
        dictgen::InsensitiveStr::Ascii("eveled"),
        dictgen::InsensitiveStr::Ascii("eveler"),
        dictgen::InsensitiveStr::Ascii("eveling"),
        dictgen::InsensitiveStr::Ascii("evelled"),
        dictgen::InsensitiveStr::Ascii("eveller"),
        dictgen::InsensitiveStr::Ascii("evelling"),
        dictgen::InsensitiveStr::Ascii("onor"),
        dictgen::InsensitiveStr::Ascii("onorable"),
        dictgen::InsensitiveStr::Ascii("onorableness"),
        dictgen::InsensitiveStr::Ascii("onorablenesses"),
        dictgen::InsensitiveStr::Ascii("onorabler"),
        dictgen::InsensitiveStr::Ascii("onorables"),
        dictgen::InsensitiveStr::Ascii("onorablest"),
        dictgen::InsensitiveStr::Ascii("onorablier"),
        dictgen::InsensitiveStr::Ascii("onorablies"),
        dictgen::InsensitiveStr::Ascii("onorabliest"),
        dictgen::InsensitiveStr::Ascii("onorably"),
        dictgen::InsensitiveStr::Ascii("onorary"),
        dictgen::InsensitiveStr::Ascii("onored"),
        dictgen::InsensitiveStr::Ascii("onorer"),
        dictgen::InsensitiveStr::Ascii("onorers"),
        dictgen::InsensitiveStr::Ascii("onoring"),
        dictgen::InsensitiveStr::Ascii("onors"),
        dictgen::InsensitiveStr::Ascii("onour"),
        dictgen::InsensitiveStr::Ascii("onourable"),
        dictgen::InsensitiveStr::Ascii("onourableness"),
        dictgen::InsensitiveStr::Ascii("onourablenesses"),
        dictgen::InsensitiveStr::Ascii("onourabler"),
        dictgen::InsensitiveStr::Ascii("onourables"),
        dictgen::InsensitiveStr::Ascii("onourablest"),
        dictgen::InsensitiveStr::Ascii("onourablier"),
        dictgen::InsensitiveStr::Ascii("onourablies"),
        dictgen::InsensitiveStr::Ascii("onourabliest"),
        dictgen::InsensitiveStr::Ascii("onourably"),
        dictgen::InsensitiveStr::Ascii("onourary"),
        dictgen::InsensitiveStr::Ascii("onoured"),
        dictgen::InsensitiveStr::Ascii("onourer"),
        dictgen::InsensitiveStr::Ascii("onourers"),
        dictgen::InsensitiveStr::Ascii("onouring"),
        dictgen::InsensitiveStr::Ascii("onours"),
        dictgen::InsensitiveStr::Ascii("umanise"),
        dictgen::InsensitiveStr::Ascii("umanises"),
        dictgen::InsensitiveStr::Ascii("umanize"),
        dictgen::InsensitiveStr::Ascii("umanizes"),
        dictgen::InsensitiveStr::Ascii("umor"),
        dictgen::InsensitiveStr::Ascii("umored"),
        dictgen::InsensitiveStr::Ascii("umors"),
        dictgen::InsensitiveStr::Ascii("umour"),
        dictgen::InsensitiveStr::Ascii("umoured"),
        dictgen::InsensitiveStr::Ascii("umours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISHARMONIZE_15635806502203971041)],
        &[(0b10010, &ENTRY_DISHARMONIZED_12718766168972067120)],
        &[(0b10010, &ENTRY_DISHARMONIZES_2153201734651956091)],
        &[(0b10010, &ENTRY_DISHARMONIZING_13293257979178794218)],
        &[(0b01001, &ENTRY_DISHARMONIZE_15635806502203971041)],
        &[(0b01001, &ENTRY_DISHARMONIZED_12718766168972067120)],
        &[(0b01001, &ENTRY_DISHARMONIZES_2153201734651956091)],
        &[(0b01001, &ENTRY_DISHARMONIZING_13293257979178794218)],
        &[(0b00001, &ENTRY_DISHEVELED_870550093566288707)],
        &[(0b00001, &ENTRY_DISHEVELER_2159675347135854964)],
        &[(0b00001, &ENTRY_DISHEVELING_6322833404479205492)],
        &[(0b11010, &ENTRY_DISHEVELED_870550093566288707)],
        &[(0b11010, &ENTRY_DISHEVELER_2159675347135854964)],
        &[(0b11010, &ENTRY_DISHEVELING_6322833404479205492)],
        &[(0b11001, &ENTRY_DISHONOR_11620713121077259513)],
        &[(0b11001, &ENTRY_DISHONORABLE_38080454965404032)],
        &[(0b11001, &ENTRY_DISHONORABLENESS_10657592516833463167)],
        &[(0b11001, &ENTRY_DISHONORABLENESSES_17639524963688776538)],
        &[(0b11001, &ENTRY_DISHONORABLER_13799504522206021743)],
        &[(0b11001, &ENTRY_DISHONORABLES_16248754702342750197)],
        &[(0b11001, &ENTRY_DISHONORABLEST_15156355191001228972)],
        &[(0b11001, &ENTRY_DISHONORABLIER_1654116585736260216)],
        &[(0b11001, &ENTRY_DISHONORABLIES_15514876857964789392)],
        &[(0b11001, &ENTRY_DISHONORABLIEST_16101869312549419261)],
        &[(0b11001, &ENTRY_DISHONORABLY_7020648298729028040)],
        &[(0b00001, &ENTRY_DISHONORARY_3156010712966438359)],
        &[(0b11001, &ENTRY_DISHONORED_2157274559673536220)],
        &[(0b11001, &ENTRY_DISHONORER_10838124284388158631)],
        &[(0b11001, &ENTRY_DISHONORERS_18354990936256424099)],
        &[(0b11001, &ENTRY_DISHONORING_2399726273028722915)],
        &[(0b11001, &ENTRY_DISHONORS_1597149550458150983)],
        &[(0b11010, &ENTRY_DISHONOR_11620713121077259513)],
        &[(0b11010, &ENTRY_DISHONORABLE_38080454965404032)],
        &[(0b11010, &ENTRY_DISHONORABLENESS_10657592516833463167)],
        &[(0b11010, &ENTRY_DISHONORABLENESSES_17639524963688776538)],
        &[(0b11010, &ENTRY_DISHONORABLER_13799504522206021743)],
        &[(0b11010, &ENTRY_DISHONORABLES_16248754702342750197)],
        &[(0b11010, &ENTRY_DISHONORABLEST_15156355191001228972)],
        &[(0b11010, &ENTRY_DISHONORABLIER_1654116585736260216)],
        &[(0b11010, &ENTRY_DISHONORABLIES_15514876857964789392)],
        &[(0b11010, &ENTRY_DISHONORABLIEST_16101869312549419261)],
        &[(0b11010, &ENTRY_DISHONORABLY_7020648298729028040)],
        &[(0b11010, &ENTRY_DISHONORARY_3156010712966438359)],
        &[(0b11010, &ENTRY_DISHONORED_2157274559673536220)],
        &[(0b11010, &ENTRY_DISHONORER_10838124284388158631)],
        &[(0b11010, &ENTRY_DISHONORERS_18354990936256424099)],
        &[(0b11010, &ENTRY_DISHONORING_2399726273028722915)],
        &[(0b11010, &ENTRY_DISHONORS_1597149550458150983)],
        &[(0b10010, &ENTRY_DISHUMANIZE_3651625213094865968)],
        &[(0b10010, &ENTRY_DISHUMANIZES_492537464677045904)],
        &[(0b01001, &ENTRY_DISHUMANIZE_3651625213094865968)],
        &[(0b01001, &ENTRY_DISHUMANIZES_492537464677045904)],
        &[(0b11001, &ENTRY_DISHUMOR_8582767360144693186)],
        &[(0b11001, &ENTRY_DISHUMORED_10529422865830482415)],
        &[(0b11001, &ENTRY_DISHUMORS_12570733308231929375)],
        &[(0b11010, &ENTRY_DISHUMOR_8582767360144693186)],
        &[(0b11010, &ENTRY_DISHUMORED_10529422865830482415)],
        &[(0b11010, &ENTRY_DISHUMORS_12570733308231929375)],
    ],
    range: 4..=15,
};

static VARS_DISF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISF_CHILDREN),
    value: None,
};

pub static VARS_DISF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avor"),
        dictgen::InsensitiveStr::Ascii("avored"),
        dictgen::InsensitiveStr::Ascii("avorer"),
        dictgen::InsensitiveStr::Ascii("avorers"),
        dictgen::InsensitiveStr::Ascii("avoring"),
        dictgen::InsensitiveStr::Ascii("avors"),
        dictgen::InsensitiveStr::Ascii("avour"),
        dictgen::InsensitiveStr::Ascii("avoured"),
        dictgen::InsensitiveStr::Ascii("avourer"),
        dictgen::InsensitiveStr::Ascii("avourers"),
        dictgen::InsensitiveStr::Ascii("avouring"),
        dictgen::InsensitiveStr::Ascii("avours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_DISFAVOR_11771334909061188611)],
        &[(0b11001, &ENTRY_DISFAVORED_6170594285770625316)],
        &[(0b11001, &ENTRY_DISFAVORER_16985801654708795790)],
        &[(0b11001, &ENTRY_DISFAVORERS_17879567110832075503)],
        &[(0b11001, &ENTRY_DISFAVORING_8029210556789284619)],
        &[(0b11001, &ENTRY_DISFAVORS_7649343434045517378)],
        &[(0b11010, &ENTRY_DISFAVOR_11771334909061188611)],
        &[(0b11010, &ENTRY_DISFAVORED_6170594285770625316)],
        &[(0b11010, &ENTRY_DISFAVORER_16985801654708795790)],
        &[(0b11010, &ENTRY_DISFAVORERS_17879567110832075503)],
        &[(0b11010, &ENTRY_DISFAVORING_8029210556789284619)],
        &[(0b11010, &ENTRY_DISFAVORS_7649343434045517378)],
    ],
    range: 4..=8,
};

static VARS_DISE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISE_CHILDREN),
    value: None,
};

pub static VARS_DISE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mboweled"),
        dictgen::InsensitiveStr::Ascii("mboweling"),
        dictgen::InsensitiveStr::Ascii("mbowelled"),
        dictgen::InsensitiveStr::Ascii("mbowelling"),
        dictgen::InsensitiveStr::Ascii("qualise"),
        dictgen::InsensitiveStr::Ascii("qualiser"),
        dictgen::InsensitiveStr::Ascii("qualisers"),
        dictgen::InsensitiveStr::Ascii("qualises"),
        dictgen::InsensitiveStr::Ascii("qualize"),
        dictgen::InsensitiveStr::Ascii("qualizer"),
        dictgen::InsensitiveStr::Ascii("qualizers"),
        dictgen::InsensitiveStr::Ascii("qualizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DISEMBOWELED_4919626984837066547)],
        &[(0b00001, &ENTRY_DISEMBOWELING_17785417677818928746)],
        &[(0b11010, &ENTRY_DISEMBOWELED_4919626984837066547)],
        &[(0b11010, &ENTRY_DISEMBOWELING_17785417677818928746)],
        &[(0b10010, &ENTRY_DISEQUALIZE_11476330084724633640)],
        &[(0b10010, &ENTRY_DISEQUALIZER_1587016333056628979)],
        &[(0b10010, &ENTRY_DISEQUALIZERS_5646916474154465014)],
        &[(0b10010, &ENTRY_DISEQUALIZES_11310592020717848131)],
        &[(0b01001, &ENTRY_DISEQUALIZE_11476330084724633640)],
        &[(0b01001, &ENTRY_DISEQUALIZER_1587016333056628979)],
        &[(0b01001, &ENTRY_DISEQUALIZERS_5646916474154465014)],
        &[(0b01001, &ENTRY_DISEQUALIZES_11310592020717848131)],
    ],
    range: 7..=10,
};

static VARS_DISD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISD_CHILDREN),
    value: None,
};

pub static VARS_DISD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enominationalise"),
        dictgen::InsensitiveStr::Ascii("enominationalises"),
        dictgen::InsensitiveStr::Ascii("enominationalize"),
        dictgen::InsensitiveStr::Ascii("enominationalizes"),
        dictgen::InsensitiveStr::Ascii("iplomatise"),
        dictgen::InsensitiveStr::Ascii("iplomatises"),
        dictgen::InsensitiveStr::Ascii("iplomatize"),
        dictgen::InsensitiveStr::Ascii("iplomatizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISDENOMINATIONALIZE_1834435332509515205)],
        &[(0b10010, &ENTRY_DISDENOMINATIONALIZES_5072175193852948543)],
        &[(0b01001, &ENTRY_DISDENOMINATIONALIZE_1834435332509515205)],
        &[(0b01001, &ENTRY_DISDENOMINATIONALIZES_5072175193852948543)],
        &[(0b10010, &ENTRY_DISDIPLOMATIZE_17465884571858136970)],
        &[(0b10010, &ENTRY_DISDIPLOMATIZES_3981084271285196916)],
        &[(0b01001, &ENTRY_DISDIPLOMATIZE_17465884571858136970)],
        &[(0b01001, &ENTRY_DISDIPLOMATIZES_3981084271285196916)],
    ],
    range: 10..=17,
};

static VARS_DISC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISC_CHILDREN),
    value: None,
};

pub static VARS_DISC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anonisation"),
        dictgen::InsensitiveStr::Ascii("anonisations"),
        dictgen::InsensitiveStr::Ascii("anonise"),
        dictgen::InsensitiveStr::Ascii("anonises"),
        dictgen::InsensitiveStr::Ascii("anonization"),
        dictgen::InsensitiveStr::Ascii("anonizations"),
        dictgen::InsensitiveStr::Ascii("anonize"),
        dictgen::InsensitiveStr::Ascii("anonizes"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olorate"),
        dictgen::InsensitiveStr::Ascii("olorated"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("oloredness"),
        dictgen::InsensitiveStr::Ascii("oloreds"),
        dictgen::InsensitiveStr::Ascii("oloring"),
        dictgen::InsensitiveStr::Ascii("olorization"),
        dictgen::InsensitiveStr::Ascii("olorizations"),
        dictgen::InsensitiveStr::Ascii("olorment"),
        dictgen::InsensitiveStr::Ascii("olorments"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("olourate"),
        dictgen::InsensitiveStr::Ascii("olourated"),
        dictgen::InsensitiveStr::Ascii("olouration"),
        dictgen::InsensitiveStr::Ascii("olourations"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olouredness"),
        dictgen::InsensitiveStr::Ascii("oloureds"),
        dictgen::InsensitiveStr::Ascii("olouring"),
        dictgen::InsensitiveStr::Ascii("olourisation"),
        dictgen::InsensitiveStr::Ascii("olourisations"),
        dictgen::InsensitiveStr::Ascii("olourization"),
        dictgen::InsensitiveStr::Ascii("olourizations"),
        dictgen::InsensitiveStr::Ascii("olourment"),
        dictgen::InsensitiveStr::Ascii("olourments"),
        dictgen::InsensitiveStr::Ascii("olours"),
        dictgen::InsensitiveStr::Ascii("retisation"),
        dictgen::InsensitiveStr::Ascii("retise"),
        dictgen::InsensitiveStr::Ascii("retization"),
        dictgen::InsensitiveStr::Ascii("retize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISCANONIZATION_15089376592937545269)],
        &[(0b10010, &ENTRY_DISCANONIZATIONS_17543892402167599721)],
        &[(0b10010, &ENTRY_DISCANONIZE_13454483455213180202)],
        &[(0b10010, &ENTRY_DISCANONIZES_15186719030368110625)],
        &[(0b01001, &ENTRY_DISCANONIZATION_15089376592937545269)],
        &[(0b01001, &ENTRY_DISCANONIZATIONS_17543892402167599721)],
        &[(0b01001, &ENTRY_DISCANONIZE_13454483455213180202)],
        &[(0b01001, &ENTRY_DISCANONIZES_15186719030368110625)],
        &[(0b01001, &ENTRY_DISCOLOR_2037841141685560590)],
        &[(0b00001, &ENTRY_DISCOLORATE_15722048022558836335)],
        &[(0b00001, &ENTRY_DISCOLORATED_8704987430623829107)],
        &[(0b01001, &ENTRY_DISCOLORED_16908798995974595866)],
        &[(0b00001, &ENTRY_DISCOLOREDNESS_2230982585028818030)],
        &[(0b01001, &ENTRY_DISCOLOREDS_7473250501334264517)],
        &[(0b01001, &ENTRY_DISCOLORING_8629722440902022000)],
        &[(0b00001, &ENTRY_DISCOLORIZATION_15335471267644592508)],
        &[(0b00001, &ENTRY_DISCOLORIZATIONS_3768143524495401586)],
        &[(0b00001, &ENTRY_DISCOLORMENT_6345690574258770117)],
        &[(0b00001, &ENTRY_DISCOLORMENTS_8676018080341439978)],
        &[(0b01001, &ENTRY_DISCOLORS_3188891474327267925)],
        &[(0b11010, &ENTRY_DISCOLOR_2037841141685560590)],
        &[(0b11010, &ENTRY_DISCOLORATE_15722048022558836335)],
        &[(0b11010, &ENTRY_DISCOLORATED_8704987430623829107)],
        &[(0b11010, &ENTRY_DISCOLORATION_1217061862280012422)],
        &[(0b11010, &ENTRY_DISCOLORATIONS_1674651272709360573)],
        &[(0b11010, &ENTRY_DISCOLORED_16908798995974595866)],
        &[(0b11010, &ENTRY_DISCOLOREDNESS_2230982585028818030)],
        &[(0b11010, &ENTRY_DISCOLOREDS_7473250501334264517)],
        &[(0b11010, &ENTRY_DISCOLORING_8629722440902022000)],
        &[(0b10010, &ENTRY_DISCOLORIZATION_15335471267644592508)],
        &[(0b10010, &ENTRY_DISCOLORIZATIONS_3768143524495401586)],
        &[(0b01000, &ENTRY_DISCOLORIZATION_15335471267644592508)],
        &[(0b01000, &ENTRY_DISCOLORIZATIONS_3768143524495401586)],
        &[(0b11010, &ENTRY_DISCOLORMENT_6345690574258770117)],
        &[(0b11010, &ENTRY_DISCOLORMENTS_8676018080341439978)],
        &[(0b11010, &ENTRY_DISCOLORS_3188891474327267925)],
        &[(0b10010, &ENTRY_DISCRETIZATION_11452971369238653426)],
        &[(0b10010, &ENTRY_DISCRETIZE_6297624588140855627)],
        &[(0b01001, &ENTRY_DISCRETIZATION_11452971369238653426)],
        &[(0b01001, &ENTRY_DISCRETIZE_6297624588140855627)],
    ],
    range: 4..=13,
};

static VARS_DISB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISB_CHILDREN),
    value: None,
};

pub static VARS_DISB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oweled"),
        dictgen::InsensitiveStr::Ascii("oweling"),
        dictgen::InsensitiveStr::Ascii("owelled"),
        dictgen::InsensitiveStr::Ascii("owelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DISBOWELED_6495042604775859773)],
        &[(0b00001, &ENTRY_DISBOWELING_4226524984238944204)],
        &[(0b11010, &ENTRY_DISBOWELED_6495042604775859773)],
        &[(0b11010, &ENTRY_DISBOWELING_4226524984238944204)],
    ],
    range: 6..=8,
};

static VARS_DISA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISA_CHILDREN),
    value: None,
};

pub static VARS_DISA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ngularise"),
        dictgen::InsensitiveStr::Ascii("ngularises"),
        dictgen::InsensitiveStr::Ascii("ngularize"),
        dictgen::InsensitiveStr::Ascii("ngularizes"),
        dictgen::InsensitiveStr::Ascii("uthorise"),
        dictgen::InsensitiveStr::Ascii("uthorised"),
        dictgen::InsensitiveStr::Ascii("uthorises"),
        dictgen::InsensitiveStr::Ascii("uthorising"),
        dictgen::InsensitiveStr::Ascii("uthorize"),
        dictgen::InsensitiveStr::Ascii("uthorized"),
        dictgen::InsensitiveStr::Ascii("uthorizes"),
        dictgen::InsensitiveStr::Ascii("uthorizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISANGULARIZE_13323240909851231875)],
        &[(0b10010, &ENTRY_DISANGULARIZES_8869019649269602071)],
        &[(0b01001, &ENTRY_DISANGULARIZE_13323240909851231875)],
        &[(0b01001, &ENTRY_DISANGULARIZES_8869019649269602071)],
        &[(0b10010, &ENTRY_DISAUTHORIZE_6190072065866456291)],
        &[(0b10010, &ENTRY_DISAUTHORIZED_6840896542619235950)],
        &[(0b10010, &ENTRY_DISAUTHORIZES_12659924006813750384)],
        &[(0b10010, &ENTRY_DISAUTHORIZING_17808569511505045100)],
        &[(0b01001, &ENTRY_DISAUTHORIZE_6190072065866456291)],
        &[(0b01001, &ENTRY_DISAUTHORIZED_6840896542619235950)],
        &[(0b01001, &ENTRY_DISAUTHORIZES_12659924006813750384)],
        &[(0b01001, &ENTRY_DISAUTHORIZING_17808569511505045100)],
    ],
    range: 8..=10,
};

static VARS_DIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIP_CHILDREN),
    value: None,
};

pub static VARS_DIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hthongisation"),
        dictgen::InsensitiveStr::Ascii("hthongisations"),
        dictgen::InsensitiveStr::Ascii("hthongise"),
        dictgen::InsensitiveStr::Ascii("hthongised"),
        dictgen::InsensitiveStr::Ascii("hthongises"),
        dictgen::InsensitiveStr::Ascii("hthongising"),
        dictgen::InsensitiveStr::Ascii("hthongization"),
        dictgen::InsensitiveStr::Ascii("hthongizations"),
        dictgen::InsensitiveStr::Ascii("hthongize"),
        dictgen::InsensitiveStr::Ascii("hthongized"),
        dictgen::InsensitiveStr::Ascii("hthongizes"),
        dictgen::InsensitiveStr::Ascii("hthongizing"),
        dictgen::InsensitiveStr::Ascii("le"),
        dictgen::InsensitiveStr::Ascii("loae"),
        dictgen::InsensitiveStr::Ascii("loe"),
        dictgen::InsensitiveStr::Ascii("lomatise"),
        dictgen::InsensitiveStr::Ascii("lomatised"),
        dictgen::InsensitiveStr::Ascii("lomatises"),
        dictgen::InsensitiveStr::Ascii("lomatising"),
        dictgen::InsensitiveStr::Ascii("lomatize"),
        dictgen::InsensitiveStr::Ascii("lomatized"),
        dictgen::InsensitiveStr::Ascii("lomatizes"),
        dictgen::InsensitiveStr::Ascii("lomatizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIPHTHONGIZATION_17407501498744325663)],
        &[(0b10010, &ENTRY_DIPHTHONGIZATIONS_2030371554784749334)],
        &[(0b10010, &ENTRY_DIPHTHONGIZE_10084557415323022414)],
        &[(0b10010, &ENTRY_DIPHTHONGIZED_13148843710594941732)],
        &[(0b10010, &ENTRY_DIPHTHONGIZES_13677092120190203653)],
        &[(0b10010, &ENTRY_DIPHTHONGIZING_11085495889059563585)],
        &[(0b01001, &ENTRY_DIPHTHONGIZATION_17407501498744325663)],
        &[(0b01001, &ENTRY_DIPHTHONGIZATIONS_2030371554784749334)],
        &[(0b01001, &ENTRY_DIPHTHONGIZE_10084557415323022414)],
        &[(0b01001, &ENTRY_DIPHTHONGIZED_13148843710594941732)],
        &[(0b01001, &ENTRY_DIPHTHONGIZES_13677092120190203653)],
        &[(0b01001, &ENTRY_DIPHTHONGIZING_11085495889059563585)],
        &[(0b00001, &ENTRY_DIPLE_7428584638928928919)],
        &[(0b11010, &ENTRY_DIPLOE_10703949518050648588)],
        &[
            (0b11010, &ENTRY_DIPLE_7428584638928928919),
            (0b00001, &ENTRY_DIPLOE_10703949518050648588),
        ],
        &[(0b10010, &ENTRY_DIPLOMATIZE_9472455919380322088)],
        &[(0b10010, &ENTRY_DIPLOMATIZED_11523795488471592556)],
        &[(0b10010, &ENTRY_DIPLOMATIZES_14629626523715323067)],
        &[(0b10010, &ENTRY_DIPLOMATIZING_2076281714855929811)],
        &[(0b01001, &ENTRY_DIPLOMATIZE_9472455919380322088)],
        &[(0b01001, &ENTRY_DIPLOMATIZED_11523795488471592556)],
        &[(0b01001, &ENTRY_DIPLOMATIZES_14629626523715323067)],
        &[(0b01001, &ENTRY_DIPLOMATIZING_2076281714855929811)],
    ],
    range: 2..=14,
};

static VARS_DIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIO_CHILDREN),
    value: None,
};

pub static VARS_DIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("estrous"),
        dictgen::InsensitiveStr::Ascii("estrual"),
        dictgen::InsensitiveStr::Ascii("estrum"),
        dictgen::InsensitiveStr::Ascii("estrus"),
        dictgen::InsensitiveStr::Ascii("estruses"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("pter"),
        dictgen::InsensitiveStr::Ascii("pters"),
        dictgen::InsensitiveStr::Ascii("ptre"),
        dictgen::InsensitiveStr::Ascii("ptres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DIESTROUS_5675936637008060315)],
        &[(0b11010, &ENTRY_DIESTRUAL_3082735349669486152)],
        &[(0b11010, &ENTRY_DIESTRUM_2386801088895051709)],
        &[(0b11010, &ENTRY_DIESTRUS_16455941497852839497)],
        &[(0b11010, &ENTRY_DIESTRUSES_13285806073259462800)],
        &[(0b10010, &ENTRY_DIONIZE_13243585000792606440)],
        &[(0b01001, &ENTRY_DIONIZE_13243585000792606440)],
        &[(0b01001, &ENTRY_DIOPTER_16953349812175946912)],
        &[(0b01001, &ENTRY_DIOPTERS_11469688744147601313)],
        &[(0b11010, &ENTRY_DIOPTER_16953349812175946912)],
        &[(0b11010, &ENTRY_DIOPTERS_11469688744147601313)],
    ],
    range: 4..=8,
};

static VARS_DIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIM_CHILDREN),
    value: None,
};

pub static VARS_DIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ensionalisation"),
        dictgen::InsensitiveStr::Ascii("ensionalise"),
        dictgen::InsensitiveStr::Ascii("ensionalised"),
        dictgen::InsensitiveStr::Ascii("ensionalises"),
        dictgen::InsensitiveStr::Ascii("ensionalising"),
        dictgen::InsensitiveStr::Ascii("ensionalization"),
        dictgen::InsensitiveStr::Ascii("ensionalize"),
        dictgen::InsensitiveStr::Ascii("ensionalized"),
        dictgen::InsensitiveStr::Ascii("ensionalizes"),
        dictgen::InsensitiveStr::Ascii("ensionalizing"),
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erising"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("erizing"),
        dictgen::InsensitiveStr::Ascii("inutivise"),
        dictgen::InsensitiveStr::Ascii("inutivises"),
        dictgen::InsensitiveStr::Ascii("inutivize"),
        dictgen::InsensitiveStr::Ascii("inutivizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIMENSIONALIZATION_4356536298220232988)],
        &[(0b10010, &ENTRY_DIMENSIONALIZE_10901055311777106222)],
        &[(0b10010, &ENTRY_DIMENSIONALIZED_3184637022176586212)],
        &[(0b10010, &ENTRY_DIMENSIONALIZES_9848355598654843982)],
        &[(0b10010, &ENTRY_DIMENSIONALIZING_1752907837018030213)],
        &[(0b01001, &ENTRY_DIMENSIONALIZATION_4356536298220232988)],
        &[(0b01001, &ENTRY_DIMENSIONALIZE_10901055311777106222)],
        &[(0b01001, &ENTRY_DIMENSIONALIZED_3184637022176586212)],
        &[(0b01001, &ENTRY_DIMENSIONALIZES_9848355598654843982)],
        &[(0b01001, &ENTRY_DIMENSIONALIZING_1752907837018030213)],
        &[(0b10010, &ENTRY_DIMERIZATION_9938594401087459901)],
        &[(0b10010, &ENTRY_DIMERIZATIONS_17395979002092992362)],
        &[(0b10010, &ENTRY_DIMERIZE_4390974169720571059)],
        &[(0b10010, &ENTRY_DIMERIZED_13111304572987660792)],
        &[(0b10010, &ENTRY_DIMERIZES_9744071354280045741)],
        &[(0b10010, &ENTRY_DIMERIZING_13012922488510597897)],
        &[(0b01001, &ENTRY_DIMERIZATION_9938594401087459901)],
        &[(0b01001, &ENTRY_DIMERIZATIONS_17395979002092992362)],
        &[(0b01001, &ENTRY_DIMERIZE_4390974169720571059)],
        &[(0b01001, &ENTRY_DIMERIZED_13111304572987660792)],
        &[(0b01001, &ENTRY_DIMERIZES_9744071354280045741)],
        &[(0b01001, &ENTRY_DIMERIZING_13012922488510597897)],
        &[(0b10010, &ENTRY_DIMINUTIVIZE_2645195698550337493)],
        &[(0b10010, &ENTRY_DIMINUTIVIZES_10068123782291339418)],
        &[(0b01001, &ENTRY_DIMINUTIVIZE_2645195698550337493)],
        &[(0b01001, &ENTRY_DIMINUTIVIZES_10068123782291339418)],
    ],
    range: 5..=15,
};

static VARS_DIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIG_CHILDREN),
    value: None,
};

pub static VARS_DIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("italisation"),
        dictgen::InsensitiveStr::Ascii("italisations"),
        dictgen::InsensitiveStr::Ascii("italise"),
        dictgen::InsensitiveStr::Ascii("italised"),
        dictgen::InsensitiveStr::Ascii("italising"),
        dictgen::InsensitiveStr::Ascii("italization"),
        dictgen::InsensitiveStr::Ascii("italizations"),
        dictgen::InsensitiveStr::Ascii("italize"),
        dictgen::InsensitiveStr::Ascii("italized"),
        dictgen::InsensitiveStr::Ascii("italizes"),
        dictgen::InsensitiveStr::Ascii("italizing"),
        dictgen::InsensitiveStr::Ascii("itisation"),
        dictgen::InsensitiveStr::Ascii("itisations"),
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itiser"),
        dictgen::InsensitiveStr::Ascii("itisers"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itization"),
        dictgen::InsensitiveStr::Ascii("itizations"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizer"),
        dictgen::InsensitiveStr::Ascii("itizers"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIGITALIZATION_1880066254948558272)],
        &[(0b10010, &ENTRY_DIGITALIZATIONS_569505163832283300)],
        &[(0b10010, &ENTRY_DIGITALIZE_641397969368171855)],
        &[(0b10010, &ENTRY_DIGITALIZED_10523465632142129010)],
        &[(0b10010, &ENTRY_DIGITALIZING_5222161273491894931)],
        &[(0b01001, &ENTRY_DIGITALIZATION_1880066254948558272)],
        &[(0b01001, &ENTRY_DIGITALIZATIONS_569505163832283300)],
        &[(0b01001, &ENTRY_DIGITALIZE_641397969368171855)],
        &[(0b01001, &ENTRY_DIGITALIZED_10523465632142129010)],
        &[(0b01001, &ENTRY_DIGITALIZES_16738992677023261947)],
        &[(0b01001, &ENTRY_DIGITALIZING_5222161273491894931)],
        &[(0b10010, &ENTRY_DIGITIZATION_16526021465569627029)],
        &[(0b10010, &ENTRY_DIGITIZATIONS_16075534772362552339)],
        &[(0b10010, &ENTRY_DIGITIZE_2409600049499220627)],
        &[(0b10010, &ENTRY_DIGITIZED_9086015022851622383)],
        &[(0b10010, &ENTRY_DIGITIZER_17878398947103509512)],
        &[(0b10010, &ENTRY_DIGITIZERS_13765203491581800269)],
        &[(0b10010, &ENTRY_DIGITIZES_8019423972202149279)],
        &[(0b10010, &ENTRY_DIGITIZING_18195991368262756258)],
        &[(0b01001, &ENTRY_DIGITIZATION_16526021465569627029)],
        &[(0b01001, &ENTRY_DIGITIZATIONS_16075534772362552339)],
        &[(0b01001, &ENTRY_DIGITIZE_2409600049499220627)],
        &[(0b01001, &ENTRY_DIGITIZED_9086015022851622383)],
        &[(0b01001, &ENTRY_DIGITIZER_17878398947103509512)],
        &[(0b01001, &ENTRY_DIGITIZERS_13765203491581800269)],
        &[(0b01001, &ENTRY_DIGITIZES_8019423972202149279)],
        &[(0b01001, &ENTRY_DIGITIZING_18195991368262756258)],
    ],
    range: 5..=12,
};

static VARS_DIF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIF_CHILDREN),
    value: None,
};

pub static VARS_DIF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ferentialise"),
        dictgen::InsensitiveStr::Ascii("ferentialises"),
        dictgen::InsensitiveStr::Ascii("ferentialize"),
        dictgen::InsensitiveStr::Ascii("ferentializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIFFERENTIALIZE_12999555494326012749)],
        &[(0b10010, &ENTRY_DIFFERENTIALIZES_10101899794646797010)],
        &[(0b01001, &ENTRY_DIFFERENTIALIZE_12999555494326012749)],
        &[(0b01001, &ENTRY_DIFFERENTIALIZES_10101899794646797010)],
    ],
    range: 12..=13,
};

static VARS_DIE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIE_CHILDREN),
    value: None,
};

pub static VARS_DIE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cious"),
        dictgen::InsensitiveStr::Ascii("ciously"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("retic"),
        dictgen::InsensitiveStr::Ascii("selisation"),
        dictgen::InsensitiveStr::Ascii("selisations"),
        dictgen::InsensitiveStr::Ascii("selise"),
        dictgen::InsensitiveStr::Ascii("selised"),
        dictgen::InsensitiveStr::Ascii("selises"),
        dictgen::InsensitiveStr::Ascii("selising"),
        dictgen::InsensitiveStr::Ascii("selization"),
        dictgen::InsensitiveStr::Ascii("selizations"),
        dictgen::InsensitiveStr::Ascii("selize"),
        dictgen::InsensitiveStr::Ascii("selized"),
        dictgen::InsensitiveStr::Ascii("selizes"),
        dictgen::InsensitiveStr::Ascii("selizing"),
        dictgen::InsensitiveStr::Ascii("strous"),
        dictgen::InsensitiveStr::Ascii("strual"),
        dictgen::InsensitiveStr::Ascii("strum"),
        dictgen::InsensitiveStr::Ascii("strus"),
        dictgen::InsensitiveStr::Ascii("struses"),
        dictgen::InsensitiveStr::Ascii("thylstilbestrol"),
        dictgen::InsensitiveStr::Ascii("thylstilboestrol"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DIOECIOUS_755179665025369568)],
        &[(0b00001, &ENTRY_DIOECIOUSLY_6346210130110835649)],
        &[(0b00001, &ENTRY_DIENE_5289363052349288627)],
        &[(0b00001, &ENTRY_DIERETIC_12527602600898981533)],
        &[(0b10010, &ENTRY_DIESELIZATION_12398344399064585609)],
        &[(0b10010, &ENTRY_DIESELIZATIONS_14033775324353063673)],
        &[(0b10010, &ENTRY_DIESELIZE_11999686462945584292)],
        &[(0b10010, &ENTRY_DIESELIZED_964526993351555906)],
        &[(0b10010, &ENTRY_DIESELIZES_14049322191860606720)],
        &[(0b10010, &ENTRY_DIESELIZING_11362563188776269281)],
        &[(0b01001, &ENTRY_DIESELIZATION_12398344399064585609)],
        &[(0b01001, &ENTRY_DIESELIZATIONS_14033775324353063673)],
        &[(0b01001, &ENTRY_DIESELIZE_11999686462945584292)],
        &[(0b01001, &ENTRY_DIESELIZED_964526993351555906)],
        &[(0b01001, &ENTRY_DIESELIZES_14049322191860606720)],
        &[(0b01001, &ENTRY_DIESELIZING_11362563188776269281)],
        &[(0b10001, &ENTRY_DIESTROUS_5675936637008060315)],
        &[(0b10001, &ENTRY_DIESTRUAL_3082735349669486152)],
        &[(0b10001, &ENTRY_DIESTRUM_2386801088895051709)],
        &[(0b10001, &ENTRY_DIESTRUS_16455941497852839497)],
        &[(0b10001, &ENTRY_DIESTRUSES_13285806073259462800)],
        &[(0b00001, &ENTRY_DIETHYLSTILBESTROL_7507155956542803846)],
        &[(0b11010, &ENTRY_DIETHYLSTILBESTROL_7507155956542803846)],
    ],
    range: 2..=16,
};

static VARS_DIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIC_CHILDREN),
    value: None,
};

pub static VARS_DIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hotomisation"),
        dictgen::InsensitiveStr::Ascii("hotomisations"),
        dictgen::InsensitiveStr::Ascii("hotomise"),
        dictgen::InsensitiveStr::Ascii("hotomised"),
        dictgen::InsensitiveStr::Ascii("hotomises"),
        dictgen::InsensitiveStr::Ascii("hotomising"),
        dictgen::InsensitiveStr::Ascii("hotomization"),
        dictgen::InsensitiveStr::Ascii("hotomizations"),
        dictgen::InsensitiveStr::Ascii("hotomize"),
        dictgen::InsensitiveStr::Ascii("hotomized"),
        dictgen::InsensitiveStr::Ascii("hotomizes"),
        dictgen::InsensitiveStr::Ascii("hotomizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DICHOTOMIZATION_14122718939310504058)],
        &[(0b10010, &ENTRY_DICHOTOMIZATIONS_115773806968765381)],
        &[(0b10010, &ENTRY_DICHOTOMIZE_10272954486831643030)],
        &[(0b10010, &ENTRY_DICHOTOMIZED_6365894040247689611)],
        &[(0b10010, &ENTRY_DICHOTOMIZES_6036836042986433362)],
        &[(0b10010, &ENTRY_DICHOTOMIZING_12141393071288009958)],
        &[(0b01001, &ENTRY_DICHOTOMIZATION_14122718939310504058)],
        &[(0b01001, &ENTRY_DICHOTOMIZATIONS_115773806968765381)],
        &[(0b01001, &ENTRY_DICHOTOMIZE_10272954486831643030)],
        &[(0b01001, &ENTRY_DICHOTOMIZED_6365894040247689611)],
        &[(0b01001, &ENTRY_DICHOTOMIZES_6036836042986433362)],
        &[(0b01001, &ENTRY_DICHOTOMIZING_12141393071288009958)],
    ],
    range: 8..=13,
};

static VARS_DIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DIA_CHILDREN),
    value: None,
};

static VARS_DIA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_DIAB_NODE),
    None,
    None,
    Some(&VARS_DIAE_NODE),
    None,
    Some(&VARS_DIAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_DIAL_NODE),
    Some(&VARS_DIAM_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_DIAR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_DIAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIAR_CHILDREN),
    value: None,
};

pub static VARS_DIAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
        dictgen::InsensitiveStr::Ascii("rhea"),
        dictgen::InsensitiveStr::Ascii("rheal"),
        dictgen::InsensitiveStr::Ascii("rhealer"),
        dictgen::InsensitiveStr::Ascii("rhealest"),
        dictgen::InsensitiveStr::Ascii("rheas"),
        dictgen::InsensitiveStr::Ascii("rheic"),
        dictgen::InsensitiveStr::Ascii("rheicer"),
        dictgen::InsensitiveStr::Ascii("rheicest"),
        dictgen::InsensitiveStr::Ascii("rhetic"),
        dictgen::InsensitiveStr::Ascii("rheticer"),
        dictgen::InsensitiveStr::Ascii("rheticest"),
        dictgen::InsensitiveStr::Ascii("rhoea"),
        dictgen::InsensitiveStr::Ascii("rhoeal"),
        dictgen::InsensitiveStr::Ascii("rhoealer"),
        dictgen::InsensitiveStr::Ascii("rhoealest"),
        dictgen::InsensitiveStr::Ascii("rhoeas"),
        dictgen::InsensitiveStr::Ascii("rhoeic"),
        dictgen::InsensitiveStr::Ascii("rhoeicer"),
        dictgen::InsensitiveStr::Ascii("rhoeicest"),
        dictgen::InsensitiveStr::Ascii("rhoetic"),
        dictgen::InsensitiveStr::Ascii("rhoeticer"),
        dictgen::InsensitiveStr::Ascii("rhoeticest"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIARIZE_2138954015204333925)],
        &[(0b10010, &ENTRY_DIARIZED_14821458016432673364)],
        &[(0b10010, &ENTRY_DIARIZES_4127995912600199105)],
        &[(0b10010, &ENTRY_DIARIZING_12061227027012575105)],
        &[(0b01001, &ENTRY_DIARIZE_2138954015204333925)],
        &[(0b01001, &ENTRY_DIARIZED_14821458016432673364)],
        &[(0b01001, &ENTRY_DIARIZES_4127995912600199105)],
        &[(0b01001, &ENTRY_DIARIZING_12061227027012575105)],
        &[(0b11001, &ENTRY_DIARRHEA_3911277028508716960)],
        &[(0b11001, &ENTRY_DIARRHEAL_13632347487774327311)],
        &[(0b11001, &ENTRY_DIARRHEALER_3006325160958144376)],
        &[(0b11001, &ENTRY_DIARRHEALEST_17262839018541832325)],
        &[(0b11001, &ENTRY_DIARRHEAS_15185377414757726510)],
        &[(0b10001, &ENTRY_DIARRHEIC_12128447998005479433)],
        &[(0b10001, &ENTRY_DIARRHEICER_8223047862418714828)],
        &[(0b10001, &ENTRY_DIARRHEICEST_13997700102628135772)],
        &[(0b10001, &ENTRY_DIARRHETIC_7536154240592572346)],
        &[(0b10001, &ENTRY_DIARRHETICER_10689775787335384886)],
        &[(0b10001, &ENTRY_DIARRHETICEST_5068896754833432010)],
        &[(0b10010, &ENTRY_DIARRHEA_3911277028508716960)],
        &[(0b10010, &ENTRY_DIARRHEAL_13632347487774327311)],
        &[(0b10010, &ENTRY_DIARRHEALER_3006325160958144376)],
        &[(0b10010, &ENTRY_DIARRHEALEST_17262839018541832325)],
        &[(0b10010, &ENTRY_DIARRHEAS_15185377414757726510)],
        &[(0b11010, &ENTRY_DIARRHEIC_12128447998005479433)],
        &[(0b11010, &ENTRY_DIARRHEICER_8223047862418714828)],
        &[(0b11010, &ENTRY_DIARRHEICEST_13997700102628135772)],
        &[(0b11010, &ENTRY_DIARRHETIC_7536154240592572346)],
        &[(0b11010, &ENTRY_DIARRHETICER_10689775787335384886)],
        &[(0b11010, &ENTRY_DIARRHETICEST_5068896754833432010)],
    ],
    range: 3..=10,
};

static VARS_DIAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIAM_CHILDREN),
    value: None,
};

pub static VARS_DIAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ondise"),
        dictgen::InsensitiveStr::Ascii("ondises"),
        dictgen::InsensitiveStr::Ascii("ondize"),
        dictgen::InsensitiveStr::Ascii("ondizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIAMONDIZE_6182158864087976989)],
        &[(0b10010, &ENTRY_DIAMONDIZES_14251466086938482305)],
        &[(0b01001, &ENTRY_DIAMONDIZE_6182158864087976989)],
        &[(0b01001, &ENTRY_DIAMONDIZES_14251466086938482305)],
    ],
    range: 6..=7,
};

static VARS_DIAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIAL_CHILDREN),
    value: None,
};

pub static VARS_DIAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecticise"),
        dictgen::InsensitiveStr::Ascii("ecticises"),
        dictgen::InsensitiveStr::Ascii("ecticize"),
        dictgen::InsensitiveStr::Ascii("ecticizes"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("ings"),
        dictgen::InsensitiveStr::Ascii("ist"),
        dictgen::InsensitiveStr::Ascii("ists"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lings"),
        dictgen::InsensitiveStr::Ascii("list"),
        dictgen::InsensitiveStr::Ascii("lists"),
        dictgen::InsensitiveStr::Ascii("ogged"),
        dictgen::InsensitiveStr::Ascii("ogging"),
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
        dictgen::InsensitiveStr::Ascii("ogs"),
        dictgen::InsensitiveStr::Ascii("ysabilities"),
        dictgen::InsensitiveStr::Ascii("ysability"),
        dictgen::InsensitiveStr::Ascii("ysable"),
        dictgen::InsensitiveStr::Ascii("ysabler"),
        dictgen::InsensitiveStr::Ascii("ysables"),
        dictgen::InsensitiveStr::Ascii("ysablest"),
        dictgen::InsensitiveStr::Ascii("ysate"),
        dictgen::InsensitiveStr::Ascii("ysates"),
        dictgen::InsensitiveStr::Ascii("ysation"),
        dictgen::InsensitiveStr::Ascii("yse"),
        dictgen::InsensitiveStr::Ascii("ysed"),
        dictgen::InsensitiveStr::Ascii("yser"),
        dictgen::InsensitiveStr::Ascii("ysers"),
        dictgen::InsensitiveStr::Ascii("ysing"),
        dictgen::InsensitiveStr::Ascii("yzabilities"),
        dictgen::InsensitiveStr::Ascii("yzability"),
        dictgen::InsensitiveStr::Ascii("yzable"),
        dictgen::InsensitiveStr::Ascii("yzabler"),
        dictgen::InsensitiveStr::Ascii("yzables"),
        dictgen::InsensitiveStr::Ascii("yzablest"),
        dictgen::InsensitiveStr::Ascii("yzate"),
        dictgen::InsensitiveStr::Ascii("yzates"),
        dictgen::InsensitiveStr::Ascii("yzation"),
        dictgen::InsensitiveStr::Ascii("yze"),
        dictgen::InsensitiveStr::Ascii("yzed"),
        dictgen::InsensitiveStr::Ascii("yzer"),
        dictgen::InsensitiveStr::Ascii("yzers"),
        dictgen::InsensitiveStr::Ascii("yzes"),
        dictgen::InsensitiveStr::Ascii("yzing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIALECTICIZE_12501453537726971128)],
        &[(0b10010, &ENTRY_DIALECTICIZES_6038135739665968964)],
        &[(0b01001, &ENTRY_DIALECTICIZE_12501453537726971128)],
        &[(0b01001, &ENTRY_DIALECTICIZES_6038135739665968964)],
        &[(0b01001, &ENTRY_DIALED_8624721026195652691)],
        &[(0b00001, &ENTRY_DIALER_12144421429152334948)],
        &[(0b00001, &ENTRY_DIALERS_106036826415288726)],
        &[(0b01001, &ENTRY_DIALING_14894824825058184021)],
        &[(0b01001, &ENTRY_DIALINGS_16812342776213308353)],
        &[(0b00001, &ENTRY_DIALIST_4516170084506307202)],
        &[(0b00001, &ENTRY_DIALISTS_11507803815872945664)],
        &[(0b11010, &ENTRY_DIALED_8624721026195652691)],
        &[(0b11010, &ENTRY_DIALER_12144421429152334948)],
        &[(0b11010, &ENTRY_DIALERS_106036826415288726)],
        &[(0b11010, &ENTRY_DIALING_14894824825058184021)],
        &[(0b11010, &ENTRY_DIALINGS_16812342776213308353)],
        &[(0b11010, &ENTRY_DIALIST_4516170084506307202)],
        &[(0b11010, &ENTRY_DIALISTS_11507803815872945664)],
        &[(0b00001, &ENTRY_DIALOGUED_6096361692015426802)],
        &[(0b00001, &ENTRY_DIALOGUING_11388291889533762516)],
        &[(0b10010, &ENTRY_DIALOGIZE_12108565015252354953)],
        &[(0b10010, &ENTRY_DIALOGIZED_2130998845263727006)],
        &[(0b10010, &ENTRY_DIALOGIZES_15128492515715378027)],
        &[(0b10010, &ENTRY_DIALOGIZING_16954032865785818920)],
        &[(0b01001, &ENTRY_DIALOGIZE_12108565015252354953)],
        &[(0b01001, &ENTRY_DIALOGIZED_2130998845263727006)],
        &[(0b01001, &ENTRY_DIALOGIZES_15128492515715378027)],
        &[(0b01001, &ENTRY_DIALOGIZING_16954032865785818920)],
        &[(0b00001, &ENTRY_DIALOGUES_11293834938019836177)],
        &[(0b11010, &ENTRY_DIALYZABILITIES_7999248871142067536)],
        &[(0b11010, &ENTRY_DIALYZABILITY_6815030337453867720)],
        &[(0b11010, &ENTRY_DIALYZABLE_17385568374012534569)],
        &[(0b11010, &ENTRY_DIALYZABLER_15208921974675203583)],
        &[(0b11010, &ENTRY_DIALYZABLES_6376554827966008616)],
        &[(0b11010, &ENTRY_DIALYZABLEST_11000318458472685986)],
        &[(0b10010, &ENTRY_DIALYZATE_2109777769298374812)],
        &[(0b10010, &ENTRY_DIALYZATES_13362126314458712842)],
        &[(0b10010, &ENTRY_DIALYZATION_7430305913509943439)],
        &[(0b10010, &ENTRY_DIALYZE_1688147137734168562)],
        &[(0b10010, &ENTRY_DIALYZED_14166787736891210495)],
        &[(0b10010, &ENTRY_DIALYZER_17215496811652992094)],
        &[(0b10010, &ENTRY_DIALYZERS_11015093780016815012)],
        &[(0b10010, &ENTRY_DIALYZING_14844209232520540927)],
        &[(0b00001, &ENTRY_DIALYZABILITIES_7999248871142067536)],
        &[(0b00001, &ENTRY_DIALYZABILITY_6815030337453867720)],
        &[(0b00001, &ENTRY_DIALYZABLE_17385568374012534569)],
        &[(0b00001, &ENTRY_DIALYZABLER_15208921974675203583)],
        &[(0b00001, &ENTRY_DIALYZABLES_6376554827966008616)],
        &[(0b00001, &ENTRY_DIALYZABLEST_11000318458472685986)],
        &[(0b01001, &ENTRY_DIALYZATE_2109777769298374812)],
        &[(0b01001, &ENTRY_DIALYZATES_13362126314458712842)],
        &[(0b01001, &ENTRY_DIALYZATION_7430305913509943439)],
        &[(0b01001, &ENTRY_DIALYZE_1688147137734168562)],
        &[(0b01001, &ENTRY_DIALYZED_14166787736891210495)],
        &[(0b01001, &ENTRY_DIALYZER_17215496811652992094)],
        &[(0b01001, &ENTRY_DIALYZERS_11015093780016815012)],
        &[(0b01001, &ENTRY_DIALYZES_7300597766358786533)],
        &[(0b01001, &ENTRY_DIALYZING_14844209232520540927)],
    ],
    range: 2..=11,
};

static VARS_DIAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIAG_CHILDREN),
    value: None,
};

pub static VARS_DIAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onalisable"),
        dictgen::InsensitiveStr::Ascii("onalisation"),
        dictgen::InsensitiveStr::Ascii("onalise"),
        dictgen::InsensitiveStr::Ascii("onalised"),
        dictgen::InsensitiveStr::Ascii("onalises"),
        dictgen::InsensitiveStr::Ascii("onalising"),
        dictgen::InsensitiveStr::Ascii("onalizable"),
        dictgen::InsensitiveStr::Ascii("onalization"),
        dictgen::InsensitiveStr::Ascii("onalize"),
        dictgen::InsensitiveStr::Ascii("onalized"),
        dictgen::InsensitiveStr::Ascii("onalizes"),
        dictgen::InsensitiveStr::Ascii("onalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIAGONALIZABLE_2762017719834849456)],
        &[(0b10010, &ENTRY_DIAGONALIZATION_6595403545220372020)],
        &[(0b10010, &ENTRY_DIAGONALIZE_17904977846869341160)],
        &[(0b10010, &ENTRY_DIAGONALIZED_17579955084907080650)],
        &[(0b10010, &ENTRY_DIAGONALIZES_15254037472689690498)],
        &[(0b10010, &ENTRY_DIAGONALIZING_13586424289506988897)],
        &[(0b01001, &ENTRY_DIAGONALIZABLE_2762017719834849456)],
        &[(0b01001, &ENTRY_DIAGONALIZATION_6595403545220372020)],
        &[(0b01001, &ENTRY_DIAGONALIZE_17904977846869341160)],
        &[(0b01001, &ENTRY_DIAGONALIZED_17579955084907080650)],
        &[(0b01001, &ENTRY_DIAGONALIZES_15254037472689690498)],
        &[(0b01001, &ENTRY_DIAGONALIZING_13586424289506988897)],
    ],
    range: 7..=11,
};

static VARS_DIAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIAE_CHILDREN),
    value: None,
};

pub static VARS_DIAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("retic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DIENE_5289363052349288627)],
        &[(0b11010, &ENTRY_DIERETIC_12527602600898981533)],
    ],
    range: 2..=5,
};

static VARS_DIAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIAB_CHILDREN),
    value: None,
};

pub static VARS_DIAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olisation"),
        dictgen::InsensitiveStr::Ascii("olisations"),
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olization"),
        dictgen::InsensitiveStr::Ascii("olizations"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIABOLIZATION_1363887125114685904)],
        &[(0b10010, &ENTRY_DIABOLIZATIONS_16583315643649032340)],
        &[(0b10010, &ENTRY_DIABOLIZE_7558206233001066545)],
        &[(0b10010, &ENTRY_DIABOLIZED_11064715463315482252)],
        &[(0b10010, &ENTRY_DIABOLIZES_1852822825341821570)],
        &[(0b10010, &ENTRY_DIABOLIZING_15636021241322694053)],
        &[(0b01001, &ENTRY_DIABOLIZATION_1363887125114685904)],
        &[(0b01001, &ENTRY_DIABOLIZATIONS_16583315643649032340)],
        &[(0b01001, &ENTRY_DIABOLIZE_7558206233001066545)],
        &[(0b01001, &ENTRY_DIABOLIZED_11064715463315482252)],
        &[(0b01001, &ENTRY_DIABOLIZES_1852822825341821570)],
        &[(0b01001, &ENTRY_DIABOLIZING_15636021241322694053)],
    ],
    range: 5..=10,
};

static VARS_DE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DE_CHILDREN),
    value: None,
};

static VARS_DE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DEA_NODE),
    None,
    Some(&VARS_DEC_NODE),
    Some(&VARS_DED_NODE),
    Some(&VARS_DEE_NODE),
    Some(&VARS_DEF_NODE),
    Some(&VARS_DEG_NODE),
    Some(&VARS_DEH_NODE),
    Some(&VARS_DEI_NODE),
    None,
    Some(&VARS_DEK_NODE),
    Some(&VARS_DEL_NODE),
    Some(&VARS_DEM_NODE),
    Some(&VARS_DEN_NODE),
    Some(&VARS_DEO_NODE),
    Some(&VARS_DEP_NODE),
    None,
    Some(&VARS_DER_NODE),
    Some(&VARS_DES_NODE),
    Some(&VARS_DET_NODE),
    None,
    Some(&VARS_DEV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_DEV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEV_CHILDREN),
    value: None,
};

pub static VARS_DEV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("alorisation"),
        dictgen::InsensitiveStr::Ascii("alorisations"),
        dictgen::InsensitiveStr::Ascii("alorise"),
        dictgen::InsensitiveStr::Ascii("alorised"),
        dictgen::InsensitiveStr::Ascii("alorises"),
        dictgen::InsensitiveStr::Ascii("alorising"),
        dictgen::InsensitiveStr::Ascii("alorization"),
        dictgen::InsensitiveStr::Ascii("alorizations"),
        dictgen::InsensitiveStr::Ascii("alorize"),
        dictgen::InsensitiveStr::Ascii("alorized"),
        dictgen::InsensitiveStr::Ascii("alorizes"),
        dictgen::InsensitiveStr::Ascii("alorizing"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("iled"),
        dictgen::InsensitiveStr::Ascii("iling"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("illed"),
        dictgen::InsensitiveStr::Ascii("illing"),
        dictgen::InsensitiveStr::Ascii("italisation"),
        dictgen::InsensitiveStr::Ascii("italisations"),
        dictgen::InsensitiveStr::Ascii("italise"),
        dictgen::InsensitiveStr::Ascii("italised"),
        dictgen::InsensitiveStr::Ascii("italises"),
        dictgen::InsensitiveStr::Ascii("italising"),
        dictgen::InsensitiveStr::Ascii("italization"),
        dictgen::InsensitiveStr::Ascii("italizations"),
        dictgen::InsensitiveStr::Ascii("italize"),
        dictgen::InsensitiveStr::Ascii("italized"),
        dictgen::InsensitiveStr::Ascii("italizes"),
        dictgen::InsensitiveStr::Ascii("italizing"),
        dictgen::InsensitiveStr::Ascii("ocalisation"),
        dictgen::InsensitiveStr::Ascii("ocalise"),
        dictgen::InsensitiveStr::Ascii("ocalised"),
        dictgen::InsensitiveStr::Ascii("ocalises"),
        dictgen::InsensitiveStr::Ascii("ocalising"),
        dictgen::InsensitiveStr::Ascii("ocalization"),
        dictgen::InsensitiveStr::Ascii("ocalize"),
        dictgen::InsensitiveStr::Ascii("ocalized"),
        dictgen::InsensitiveStr::Ascii("ocalizes"),
        dictgen::InsensitiveStr::Ascii("ocalizing"),
        dictgen::InsensitiveStr::Ascii("olatilisation"),
        dictgen::InsensitiveStr::Ascii("olatilisations"),
        dictgen::InsensitiveStr::Ascii("olatilise"),
        dictgen::InsensitiveStr::Ascii("olatilised"),
        dictgen::InsensitiveStr::Ascii("olatilises"),
        dictgen::InsensitiveStr::Ascii("olatilising"),
        dictgen::InsensitiveStr::Ascii("olatilization"),
        dictgen::InsensitiveStr::Ascii("olatilizations"),
        dictgen::InsensitiveStr::Ascii("olatilize"),
        dictgen::InsensitiveStr::Ascii("olatilized"),
        dictgen::InsensitiveStr::Ascii("olatilizes"),
        dictgen::InsensitiveStr::Ascii("olatilizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DEVA_17913294961213511390)],
        &[(0b10010, &ENTRY_DEVALORIZATION_263183622783279423)],
        &[(0b10010, &ENTRY_DEVALORIZATIONS_3733441228994839656)],
        &[(0b10010, &ENTRY_DEVALORIZE_3441956694235575978)],
        &[(0b10010, &ENTRY_DEVALORIZED_3035715402231659393)],
        &[(0b10010, &ENTRY_DEVALORIZES_11252089261618256450)],
        &[(0b10010, &ENTRY_DEVALORIZING_576941735937016987)],
        &[(0b01001, &ENTRY_DEVALORIZATION_263183622783279423)],
        &[(0b01001, &ENTRY_DEVALORIZATIONS_3733441228994839656)],
        &[(0b01001, &ENTRY_DEVALORIZE_3441956694235575978)],
        &[(0b01001, &ENTRY_DEVALORIZED_3035715402231659393)],
        &[(0b01001, &ENTRY_DEVALORIZES_11252089261618256450)],
        &[(0b01001, &ENTRY_DEVALORIZING_576941735937016987)],
        &[(0b00001, &ENTRY_DEVELED_2772420296503800249)],
        &[(0b00001, &ENTRY_DEVELING_5035027030513600653)],
        &[(0b11010, &ENTRY_DEVELED_2772420296503800249)],
        &[(0b11010, &ENTRY_DEVELING_5035027030513600653)],
        &[(0b00001, &ENTRY_DEVILED_3048829577081044907)],
        &[(0b00001, &ENTRY_DEVILING_2852485461150693530)],
        &[(0b10010, &ENTRY_DEVILIZE_1860871339294390376)],
        &[(0b10010, &ENTRY_DEVILIZES_2252795004975721973)],
        &[(0b01001, &ENTRY_DEVILIZE_1860871339294390376)],
        &[(0b01001, &ENTRY_DEVILIZES_2252795004975721973)],
        &[(0b11010, &ENTRY_DEVILED_3048829577081044907)],
        &[(0b11010, &ENTRY_DEVILING_2852485461150693530)],
        &[(0b10010, &ENTRY_DEVITALIZATION_15852094530751489673)],
        &[(0b10010, &ENTRY_DEVITALIZATIONS_1168911391057981701)],
        &[(0b10010, &ENTRY_DEVITALIZE_5134304117244312868)],
        &[(0b10010, &ENTRY_DEVITALIZED_2614953819800812061)],
        &[(0b10010, &ENTRY_DEVITALIZES_8740304697698136600)],
        &[(0b10010, &ENTRY_DEVITALIZING_432513802469216184)],
        &[(0b01001, &ENTRY_DEVITALIZATION_15852094530751489673)],
        &[(0b01001, &ENTRY_DEVITALIZATIONS_1168911391057981701)],
        &[(0b01001, &ENTRY_DEVITALIZE_5134304117244312868)],
        &[(0b01001, &ENTRY_DEVITALIZED_2614953819800812061)],
        &[(0b01001, &ENTRY_DEVITALIZES_8740304697698136600)],
        &[(0b01001, &ENTRY_DEVITALIZING_432513802469216184)],
        &[(0b10010, &ENTRY_DEVOCALIZATION_1702123344804371213)],
        &[(0b10010, &ENTRY_DEVOCALIZE_2685272297865524074)],
        &[(0b10010, &ENTRY_DEVOCALIZED_1211021425952943044)],
        &[(0b10010, &ENTRY_DEVOCALIZES_17642417100083990068)],
        &[(0b10010, &ENTRY_DEVOCALIZING_10482039920211385501)],
        &[(0b01001, &ENTRY_DEVOCALIZATION_1702123344804371213)],
        &[(0b01001, &ENTRY_DEVOCALIZE_2685272297865524074)],
        &[(0b01001, &ENTRY_DEVOCALIZED_1211021425952943044)],
        &[(0b01001, &ENTRY_DEVOCALIZES_17642417100083990068)],
        &[(0b01001, &ENTRY_DEVOCALIZING_10482039920211385501)],
        &[(0b10010, &ENTRY_DEVOLATILIZATION_15274887322161140461)],
        &[(0b10010, &ENTRY_DEVOLATILIZATIONS_1986930233175031782)],
        &[(0b10010, &ENTRY_DEVOLATILIZE_6367186675206777835)],
        &[(0b10010, &ENTRY_DEVOLATILIZED_13031211289203336444)],
        &[(0b10010, &ENTRY_DEVOLATILIZES_1833448326954504353)],
        &[(0b10010, &ENTRY_DEVOLATILIZING_16426756662834727247)],
        &[(0b01001, &ENTRY_DEVOLATILIZATION_15274887322161140461)],
        &[(0b01001, &ENTRY_DEVOLATILIZATIONS_1986930233175031782)],
        &[(0b01001, &ENTRY_DEVOLATILIZE_6367186675206777835)],
        &[(0b01001, &ENTRY_DEVOLATILIZED_13031211289203336444)],
        &[(0b01001, &ENTRY_DEVOLATILIZES_1833448326954504353)],
        &[(0b01001, &ENTRY_DEVOLATILIZING_16426756662834727247)],
    ],
    range: 1..=14,
};

static VARS_DET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DET_CHILDREN),
    value: None,
};

pub static VARS_DET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ribalisation"),
        dictgen::InsensitiveStr::Ascii("ribalisations"),
        dictgen::InsensitiveStr::Ascii("ribalise"),
        dictgen::InsensitiveStr::Ascii("ribalised"),
        dictgen::InsensitiveStr::Ascii("ribalises"),
        dictgen::InsensitiveStr::Ascii("ribalising"),
        dictgen::InsensitiveStr::Ascii("ribalization"),
        dictgen::InsensitiveStr::Ascii("ribalizations"),
        dictgen::InsensitiveStr::Ascii("ribalize"),
        dictgen::InsensitiveStr::Ascii("ribalized"),
        dictgen::InsensitiveStr::Ascii("ribalizes"),
        dictgen::InsensitiveStr::Ascii("ribalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DETRIBALIZATION_1652215190238627536)],
        &[(0b10010, &ENTRY_DETRIBALIZATIONS_10197716064139754204)],
        &[(0b10010, &ENTRY_DETRIBALIZE_1614085836292794906)],
        &[(0b10010, &ENTRY_DETRIBALIZED_8262386414888942658)],
        &[(0b10010, &ENTRY_DETRIBALIZES_10964606572749162711)],
        &[(0b10010, &ENTRY_DETRIBALIZING_4078840495989197779)],
        &[(0b01001, &ENTRY_DETRIBALIZATION_1652215190238627536)],
        &[(0b01001, &ENTRY_DETRIBALIZATIONS_10197716064139754204)],
        &[(0b01001, &ENTRY_DETRIBALIZE_1614085836292794906)],
        &[(0b01001, &ENTRY_DETRIBALIZED_8262386414888942658)],
        &[(0b01001, &ENTRY_DETRIBALIZES_10964606572749162711)],
        &[(0b01001, &ENTRY_DETRIBALIZING_4078840495989197779)],
    ],
    range: 8..=13,
};

static VARS_DES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DES_CHILDREN),
    value: None,
};

static VARS_DES_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DESA_NODE),
    None,
    Some(&VARS_DESC_NODE),
    None,
    Some(&VARS_DESE_NODE),
    None,
    None,
    None,
    Some(&VARS_DESI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DESP_NODE),
    None,
    None,
    None,
    Some(&VARS_DEST_NODE),
    Some(&VARS_DESU_NODE),
    None,
    None,
    None,
    Some(&VARS_DESY_NODE),
    None,
];

static VARS_DESY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESY_CHILDREN),
    value: None,
};

pub static VARS_DESY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nchronisation"),
        dictgen::InsensitiveStr::Ascii("nchronisations"),
        dictgen::InsensitiveStr::Ascii("nchronise"),
        dictgen::InsensitiveStr::Ascii("nchronised"),
        dictgen::InsensitiveStr::Ascii("nchronises"),
        dictgen::InsensitiveStr::Ascii("nchronising"),
        dictgen::InsensitiveStr::Ascii("nchronization"),
        dictgen::InsensitiveStr::Ascii("nchronizations"),
        dictgen::InsensitiveStr::Ascii("nchronize"),
        dictgen::InsensitiveStr::Ascii("nchronized"),
        dictgen::InsensitiveStr::Ascii("nchronizes"),
        dictgen::InsensitiveStr::Ascii("nchronizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DESYNCHRONIZATION_7571142988844086339)],
        &[(0b10010, &ENTRY_DESYNCHRONIZATIONS_16916238148674253682)],
        &[(0b10010, &ENTRY_DESYNCHRONIZE_11372885649599375047)],
        &[(0b10010, &ENTRY_DESYNCHRONIZED_10677701267884215526)],
        &[(0b10010, &ENTRY_DESYNCHRONIZES_6662843521917179779)],
        &[(0b10010, &ENTRY_DESYNCHRONIZING_17223398467673868688)],
        &[(0b01001, &ENTRY_DESYNCHRONIZATION_7571142988844086339)],
        &[(0b01001, &ENTRY_DESYNCHRONIZATIONS_16916238148674253682)],
        &[(0b01001, &ENTRY_DESYNCHRONIZE_11372885649599375047)],
        &[(0b01001, &ENTRY_DESYNCHRONIZED_10677701267884215526)],
        &[(0b01001, &ENTRY_DESYNCHRONIZES_6662843521917179779)],
        &[(0b01001, &ENTRY_DESYNCHRONIZING_17223398467673868688)],
    ],
    range: 9..=14,
};

static VARS_DESU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESU_CHILDREN),
    value: None,
};

pub static VARS_DESU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lfuriser"),
        dictgen::InsensitiveStr::Ascii("lfurization"),
        dictgen::InsensitiveStr::Ascii("lfurizations"),
        dictgen::InsensitiveStr::Ascii("lfurize"),
        dictgen::InsensitiveStr::Ascii("lfurized"),
        dictgen::InsensitiveStr::Ascii("lfurizer"),
        dictgen::InsensitiveStr::Ascii("lfurizes"),
        dictgen::InsensitiveStr::Ascii("lfurizing"),
        dictgen::InsensitiveStr::Ascii("lphurisation"),
        dictgen::InsensitiveStr::Ascii("lphurisations"),
        dictgen::InsensitiveStr::Ascii("lphurise"),
        dictgen::InsensitiveStr::Ascii("lphurised"),
        dictgen::InsensitiveStr::Ascii("lphuriser"),
        dictgen::InsensitiveStr::Ascii("lphurisers"),
        dictgen::InsensitiveStr::Ascii("lphurises"),
        dictgen::InsensitiveStr::Ascii("lphurising"),
        dictgen::InsensitiveStr::Ascii("lphurization"),
        dictgen::InsensitiveStr::Ascii("lphurizations"),
        dictgen::InsensitiveStr::Ascii("lphurize"),
        dictgen::InsensitiveStr::Ascii("lphurized"),
        dictgen::InsensitiveStr::Ascii("lphurizer"),
        dictgen::InsensitiveStr::Ascii("lphurizers"),
        dictgen::InsensitiveStr::Ascii("lphurizes"),
        dictgen::InsensitiveStr::Ascii("lphurizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DESULFURIZER_6811111747434101705)],
        &[(0b00001, &ENTRY_DESULFURIZATION_7274801890477561400)],
        &[(0b00001, &ENTRY_DESULFURIZATIONS_2177003244823249071)],
        &[(0b00001, &ENTRY_DESULFURIZE_13186827014999009464)],
        &[(0b00001, &ENTRY_DESULFURIZED_2406386063012452485)],
        &[(0b01001, &ENTRY_DESULFURIZER_6811111747434101705)],
        &[(0b00001, &ENTRY_DESULFURIZES_35072370079092901)],
        &[(0b00001, &ENTRY_DESULFURIZING_15868123655289821047)],
        &[(0b10010, &ENTRY_DESULFURIZATION_7274801890477561400)],
        &[(0b10010, &ENTRY_DESULFURIZATIONS_2177003244823249071)],
        &[(0b10010, &ENTRY_DESULFURIZE_13186827014999009464)],
        &[(0b10010, &ENTRY_DESULFURIZED_2406386063012452485)],
        &[(0b10010, &ENTRY_DESULPHURIZER_16216980596436245396)],
        &[(0b10010, &ENTRY_DESULPHURIZERS_11557780828704734590)],
        &[(0b10010, &ENTRY_DESULFURIZES_35072370079092901)],
        &[(0b10010, &ENTRY_DESULFURIZING_15868123655289821047)],
        &[(0b01000, &ENTRY_DESULFURIZATION_7274801890477561400)],
        &[(0b01000, &ENTRY_DESULFURIZATIONS_2177003244823249071)],
        &[(0b01000, &ENTRY_DESULFURIZE_13186827014999009464)],
        &[(0b01000, &ENTRY_DESULFURIZED_2406386063012452485)],
        &[(0b01001, &ENTRY_DESULPHURIZER_16216980596436245396)],
        &[(0b01001, &ENTRY_DESULPHURIZERS_11557780828704734590)],
        &[(0b01000, &ENTRY_DESULFURIZES_35072370079092901)],
        &[(0b01000, &ENTRY_DESULFURIZING_15868123655289821047)],
    ],
    range: 7..=13,
};

static VARS_DEST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEST_CHILDREN),
    value: None,
};

pub static VARS_DEST_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abilisation"),
        dictgen::InsensitiveStr::Ascii("abilise"),
        dictgen::InsensitiveStr::Ascii("abilised"),
        dictgen::InsensitiveStr::Ascii("abiliser"),
        dictgen::InsensitiveStr::Ascii("abilisers"),
        dictgen::InsensitiveStr::Ascii("abilises"),
        dictgen::InsensitiveStr::Ascii("abilising"),
        dictgen::InsensitiveStr::Ascii("abilization"),
        dictgen::InsensitiveStr::Ascii("abilize"),
        dictgen::InsensitiveStr::Ascii("abilized"),
        dictgen::InsensitiveStr::Ascii("abilizer"),
        dictgen::InsensitiveStr::Ascii("abilizers"),
        dictgen::InsensitiveStr::Ascii("abilizes"),
        dictgen::InsensitiveStr::Ascii("abilizing"),
        dictgen::InsensitiveStr::Ascii("alinise"),
        dictgen::InsensitiveStr::Ascii("alinised"),
        dictgen::InsensitiveStr::Ascii("alinises"),
        dictgen::InsensitiveStr::Ascii("alinising"),
        dictgen::InsensitiveStr::Ascii("alinize"),
        dictgen::InsensitiveStr::Ascii("alinized"),
        dictgen::InsensitiveStr::Ascii("alinizes"),
        dictgen::InsensitiveStr::Ascii("alinizing"),
        dictgen::InsensitiveStr::Ascii("erilise"),
        dictgen::InsensitiveStr::Ascii("erilize"),
        dictgen::InsensitiveStr::Ascii("igmatisation"),
        dictgen::InsensitiveStr::Ascii("igmatization"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DESTABILIZATION_13317005930133883698)],
        &[(0b10010, &ENTRY_DESTABILIZE_6658582433887926026)],
        &[(0b10010, &ENTRY_DESTABILIZED_798803001524481006)],
        &[(0b10010, &ENTRY_DESTABILIZER_10948885335030959608)],
        &[(0b10010, &ENTRY_DESTABILIZERS_8507105907416838284)],
        &[(0b10010, &ENTRY_DESTABILIZES_9175954977739946204)],
        &[(0b10010, &ENTRY_DESTABILIZING_11313904175788895920)],
        &[(0b01001, &ENTRY_DESTABILIZATION_13317005930133883698)],
        &[(0b01001, &ENTRY_DESTABILIZE_6658582433887926026)],
        &[(0b01001, &ENTRY_DESTABILIZED_798803001524481006)],
        &[(0b01001, &ENTRY_DESTABILIZER_10948885335030959608)],
        &[(0b01001, &ENTRY_DESTABILIZERS_8507105907416838284)],
        &[(0b01001, &ENTRY_DESTABILIZES_9175954977739946204)],
        &[(0b01001, &ENTRY_DESTABILIZING_11313904175788895920)],
        &[(0b10010, &ENTRY_DESTALINIZE_12064490249878771919)],
        &[(0b10010, &ENTRY_DESTALINIZED_17070618679462501180)],
        &[(0b10010, &ENTRY_DESTALINIZES_18175065567954168080)],
        &[(0b10010, &ENTRY_DESTALINIZING_13590427920165160122)],
        &[(0b01001, &ENTRY_DESTALINIZE_12064490249878771919)],
        &[(0b01001, &ENTRY_DESTALINIZED_17070618679462501180)],
        &[(0b01001, &ENTRY_DESTALINIZES_18175065567954168080)],
        &[(0b01001, &ENTRY_DESTALINIZING_13590427920165160122)],
        &[(0b10010, &ENTRY_DESTERILIZE_11764632884497568500)],
        &[(0b01001, &ENTRY_DESTERILIZE_11764632884497568500)],
        &[(0b10010, &ENTRY_DESTIGMATIZATION_7571753247806883930)],
        &[(0b01001, &ENTRY_DESTIGMATIZATION_7571753247806883930)],
    ],
    range: 7..=12,
};

static VARS_DESP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESP_CHILDREN),
    value: None,
};

pub static VARS_DESP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atch"),
        dictgen::InsensitiveStr::Ascii("atched"),
        dictgen::InsensitiveStr::Ascii("atches"),
        dictgen::InsensitiveStr::Ascii("atching"),
        dictgen::InsensitiveStr::Ascii("iritualisation"),
        dictgen::InsensitiveStr::Ascii("iritualise"),
        dictgen::InsensitiveStr::Ascii("iritualization"),
        dictgen::InsensitiveStr::Ascii("iritualize"),
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otizes"),
    ],
    values: &[
        &[(0b10011, &ENTRY_DISPATCH_1411749765220275516)],
        &[(0b10011, &ENTRY_DISPATCHED_15237234107206890876)],
        &[(0b10011, &ENTRY_DISPATCHES_6888853082053231509)],
        &[(0b10011, &ENTRY_DISPATCHING_14791196208532843181)],
        &[(0b10010, &ENTRY_DESPIRITUALIZATION_9166826348834973753)],
        &[(0b10010, &ENTRY_DESPIRITUALIZE_9957134782134537672)],
        &[(0b01001, &ENTRY_DESPIRITUALIZATION_9166826348834973753)],
        &[(0b01001, &ENTRY_DESPIRITUALIZE_9957134782134537672)],
        &[(0b10010, &ENTRY_DESPOTIZE_7723518336373467594)],
        &[(0b10010, &ENTRY_DESPOTIZES_11713728788148916724)],
        &[(0b01001, &ENTRY_DESPOTIZE_7723518336373467594)],
        &[(0b01001, &ENTRY_DESPOTIZES_11713728788148916724)],
    ],
    range: 4..=14,
};

static VARS_DESI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESI_CHILDREN),
    value: None,
};

pub static VARS_DESI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lverisation"),
        dictgen::InsensitiveStr::Ascii("lverisations"),
        dictgen::InsensitiveStr::Ascii("lverise"),
        dictgen::InsensitiveStr::Ascii("lverised"),
        dictgen::InsensitiveStr::Ascii("lverises"),
        dictgen::InsensitiveStr::Ascii("lverising"),
        dictgen::InsensitiveStr::Ascii("lverization"),
        dictgen::InsensitiveStr::Ascii("lverizations"),
        dictgen::InsensitiveStr::Ascii("lverize"),
        dictgen::InsensitiveStr::Ascii("lverized"),
        dictgen::InsensitiveStr::Ascii("lverizes"),
        dictgen::InsensitiveStr::Ascii("lverizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DESILVERIZATION_9101345412818934981)],
        &[(0b10010, &ENTRY_DESILVERIZATIONS_3676328424316872989)],
        &[(0b10010, &ENTRY_DESILVERIZE_2584970706129191216)],
        &[(0b10010, &ENTRY_DESILVERIZED_13381393077624925641)],
        &[(0b10010, &ENTRY_DESILVERIZES_12540224859423235308)],
        &[(0b10010, &ENTRY_DESILVERIZING_17410306605308363953)],
        &[(0b01001, &ENTRY_DESILVERIZATION_9101345412818934981)],
        &[(0b01001, &ENTRY_DESILVERIZATIONS_3676328424316872989)],
        &[(0b01001, &ENTRY_DESILVERIZE_2584970706129191216)],
        &[(0b01001, &ENTRY_DESILVERIZED_13381393077624925641)],
        &[(0b01001, &ENTRY_DESILVERIZES_12540224859423235308)],
        &[(0b01001, &ENTRY_DESILVERIZING_17410306605308363953)],
    ],
    range: 7..=12,
};

static VARS_DESE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESE_CHILDREN),
    value: None,
};

pub static VARS_DESE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nsitisation"),
        dictgen::InsensitiveStr::Ascii("nsitisations"),
        dictgen::InsensitiveStr::Ascii("nsitise"),
        dictgen::InsensitiveStr::Ascii("nsitised"),
        dictgen::InsensitiveStr::Ascii("nsitiser"),
        dictgen::InsensitiveStr::Ascii("nsitisers"),
        dictgen::InsensitiveStr::Ascii("nsitises"),
        dictgen::InsensitiveStr::Ascii("nsitising"),
        dictgen::InsensitiveStr::Ascii("nsitization"),
        dictgen::InsensitiveStr::Ascii("nsitizations"),
        dictgen::InsensitiveStr::Ascii("nsitize"),
        dictgen::InsensitiveStr::Ascii("nsitized"),
        dictgen::InsensitiveStr::Ascii("nsitizer"),
        dictgen::InsensitiveStr::Ascii("nsitizers"),
        dictgen::InsensitiveStr::Ascii("nsitizes"),
        dictgen::InsensitiveStr::Ascii("nsitizing"),
        dictgen::InsensitiveStr::Ascii("rtisation"),
        dictgen::InsensitiveStr::Ascii("rtisations"),
        dictgen::InsensitiveStr::Ascii("rtization"),
        dictgen::InsensitiveStr::Ascii("rtizations"),
        dictgen::InsensitiveStr::Ascii("xualisation"),
        dictgen::InsensitiveStr::Ascii("xualisations"),
        dictgen::InsensitiveStr::Ascii("xualise"),
        dictgen::InsensitiveStr::Ascii("xualised"),
        dictgen::InsensitiveStr::Ascii("xualises"),
        dictgen::InsensitiveStr::Ascii("xualising"),
        dictgen::InsensitiveStr::Ascii("xualization"),
        dictgen::InsensitiveStr::Ascii("xualizations"),
        dictgen::InsensitiveStr::Ascii("xualize"),
        dictgen::InsensitiveStr::Ascii("xualized"),
        dictgen::InsensitiveStr::Ascii("xualizes"),
        dictgen::InsensitiveStr::Ascii("xualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DESENSITIZATION_6477425684013695224)],
        &[(0b10010, &ENTRY_DESENSITIZATIONS_2653162068724592823)],
        &[(0b10010, &ENTRY_DESENSITIZE_7076278913280010375)],
        &[(0b10010, &ENTRY_DESENSITIZED_18060076779967037190)],
        &[(0b10010, &ENTRY_DESENSITIZER_17295084989835588516)],
        &[(0b10010, &ENTRY_DESENSITIZERS_4492855637688265508)],
        &[(0b10010, &ENTRY_DESENSITIZES_14085116376101022093)],
        &[(0b10010, &ENTRY_DESENSITIZING_1861532716047418795)],
        &[(0b01001, &ENTRY_DESENSITIZATION_6477425684013695224)],
        &[(0b01001, &ENTRY_DESENSITIZATIONS_2653162068724592823)],
        &[(0b01001, &ENTRY_DESENSITIZE_7076278913280010375)],
        &[(0b01001, &ENTRY_DESENSITIZED_18060076779967037190)],
        &[(0b01001, &ENTRY_DESENSITIZER_17295084989835588516)],
        &[(0b01001, &ENTRY_DESENSITIZERS_4492855637688265508)],
        &[(0b01001, &ENTRY_DESENSITIZES_14085116376101022093)],
        &[(0b01001, &ENTRY_DESENSITIZING_1861532716047418795)],
        &[(0b10010, &ENTRY_DESERTIZATION_8322146084862234585)],
        &[(0b10010, &ENTRY_DESERTIZATIONS_13686869646615221507)],
        &[(0b01001, &ENTRY_DESERTIZATION_8322146084862234585)],
        &[(0b01001, &ENTRY_DESERTIZATIONS_13686869646615221507)],
        &[(0b10010, &ENTRY_DESEXUALIZATION_3533631506018024460)],
        &[(0b10010, &ENTRY_DESEXUALIZATIONS_13808942213186512101)],
        &[(0b10010, &ENTRY_DESEXUALIZE_1452349021755288588)],
        &[(0b10010, &ENTRY_DESEXUALIZED_14697196652232596540)],
        &[(0b10010, &ENTRY_DESEXUALIZES_310153221369007273)],
        &[(0b10010, &ENTRY_DESEXUALIZING_12199543455593087481)],
        &[(0b01001, &ENTRY_DESEXUALIZATION_3533631506018024460)],
        &[(0b01001, &ENTRY_DESEXUALIZATIONS_13808942213186512101)],
        &[(0b01001, &ENTRY_DESEXUALIZE_1452349021755288588)],
        &[(0b01001, &ENTRY_DESEXUALIZED_14697196652232596540)],
        &[(0b01001, &ENTRY_DESEXUALIZES_310153221369007273)],
        &[(0b01001, &ENTRY_DESEXUALIZING_12199543455593087481)],
    ],
    range: 7..=12,
};

static VARS_DESC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESC_CHILDREN),
    value: None,
};

pub static VARS_DESC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("endents")],
    values: &[&[(0b00001, &ENTRY_DESCENDANTS_15651999902366879600)]],
    range: 7..=7,
};

static VARS_DESA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESA_CHILDREN),
    value: None,
};

pub static VARS_DESA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cralisation"),
        dictgen::InsensitiveStr::Ascii("cralisations"),
        dictgen::InsensitiveStr::Ascii("cralise"),
        dictgen::InsensitiveStr::Ascii("cralised"),
        dictgen::InsensitiveStr::Ascii("cralises"),
        dictgen::InsensitiveStr::Ascii("cralising"),
        dictgen::InsensitiveStr::Ascii("cralization"),
        dictgen::InsensitiveStr::Ascii("cralizations"),
        dictgen::InsensitiveStr::Ascii("cralize"),
        dictgen::InsensitiveStr::Ascii("cralized"),
        dictgen::InsensitiveStr::Ascii("cralizes"),
        dictgen::InsensitiveStr::Ascii("cralizing"),
        dictgen::InsensitiveStr::Ascii("linisation"),
        dictgen::InsensitiveStr::Ascii("linisations"),
        dictgen::InsensitiveStr::Ascii("linise"),
        dictgen::InsensitiveStr::Ascii("linised"),
        dictgen::InsensitiveStr::Ascii("linises"),
        dictgen::InsensitiveStr::Ascii("linising"),
        dictgen::InsensitiveStr::Ascii("linization"),
        dictgen::InsensitiveStr::Ascii("linizations"),
        dictgen::InsensitiveStr::Ascii("linize"),
        dictgen::InsensitiveStr::Ascii("linized"),
        dictgen::InsensitiveStr::Ascii("linizes"),
        dictgen::InsensitiveStr::Ascii("linizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DESACRALIZATION_6663446605605284221)],
        &[(0b10010, &ENTRY_DESACRALIZATIONS_12761956333453162715)],
        &[(0b10010, &ENTRY_DESACRALIZE_17692095792097093691)],
        &[(0b10010, &ENTRY_DESACRALIZED_3102194836021935643)],
        &[(0b10010, &ENTRY_DESACRALIZES_17016027804952998366)],
        &[(0b10010, &ENTRY_DESACRALIZING_8095563156338258250)],
        &[(0b01001, &ENTRY_DESACRALIZATION_6663446605605284221)],
        &[(0b01001, &ENTRY_DESACRALIZATIONS_12761956333453162715)],
        &[(0b01001, &ENTRY_DESACRALIZE_17692095792097093691)],
        &[(0b01001, &ENTRY_DESACRALIZED_3102194836021935643)],
        &[(0b01001, &ENTRY_DESACRALIZES_17016027804952998366)],
        &[(0b01001, &ENTRY_DESACRALIZING_8095563156338258250)],
        &[(0b10010, &ENTRY_DESALINIZATION_18136851436548406134)],
        &[(0b10010, &ENTRY_DESALINIZATIONS_1947156449217935933)],
        &[(0b10010, &ENTRY_DESALINIZE_15580269981634714244)],
        &[(0b10010, &ENTRY_DESALINIZED_787514518667266596)],
        &[(0b10010, &ENTRY_DESALINIZES_3392036422321879852)],
        &[(0b10010, &ENTRY_DESALINIZING_7600583977642503954)],
        &[(0b01001, &ENTRY_DESALINIZATION_18136851436548406134)],
        &[(0b01001, &ENTRY_DESALINIZATIONS_1947156449217935933)],
        &[(0b01001, &ENTRY_DESALINIZE_15580269981634714244)],
        &[(0b01001, &ENTRY_DESALINIZED_787514518667266596)],
        &[(0b01001, &ENTRY_DESALINIZES_3392036422321879852)],
        &[(0b01001, &ENTRY_DESALINIZING_7600583977642503954)],
    ],
    range: 6..=12,
};

static VARS_DER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DER_CHILDREN),
    value: None,
};

pub static VARS_DER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("acialise"),
        dictgen::InsensitiveStr::Ascii("acialised"),
        dictgen::InsensitiveStr::Ascii("acialises"),
        dictgen::InsensitiveStr::Ascii("acialising"),
        dictgen::InsensitiveStr::Ascii("acialize"),
        dictgen::InsensitiveStr::Ascii("acialized"),
        dictgen::InsensitiveStr::Ascii("acializes"),
        dictgen::InsensitiveStr::Ascii("acializing"),
        dictgen::InsensitiveStr::Ascii("ationalisation"),
        dictgen::InsensitiveStr::Ascii("ationalisations"),
        dictgen::InsensitiveStr::Ascii("ationalise"),
        dictgen::InsensitiveStr::Ascii("ationalises"),
        dictgen::InsensitiveStr::Ascii("ationalization"),
        dictgen::InsensitiveStr::Ascii("ationalizations"),
        dictgen::InsensitiveStr::Ascii("ationalize"),
        dictgen::InsensitiveStr::Ascii("ationalizes"),
        dictgen::InsensitiveStr::Ascii("atisation"),
        dictgen::InsensitiveStr::Ascii("atisations"),
        dictgen::InsensitiveStr::Ascii("atization"),
        dictgen::InsensitiveStr::Ascii("atizations"),
        dictgen::InsensitiveStr::Ascii("ealisation"),
        dictgen::InsensitiveStr::Ascii("ealization"),
        dictgen::InsensitiveStr::Ascii("ecognise"),
        dictgen::InsensitiveStr::Ascii("ecognised"),
        dictgen::InsensitiveStr::Ascii("ecognises"),
        dictgen::InsensitiveStr::Ascii("ecognising"),
        dictgen::InsensitiveStr::Ascii("ecognize"),
        dictgen::InsensitiveStr::Ascii("ecognized"),
        dictgen::InsensitiveStr::Ascii("ecognizes"),
        dictgen::InsensitiveStr::Ascii("ecognizing"),
        dictgen::InsensitiveStr::Ascii("egulationise"),
        dictgen::InsensitiveStr::Ascii("egulationises"),
        dictgen::InsensitiveStr::Ascii("egulationize"),
        dictgen::InsensitiveStr::Ascii("egulationizes"),
        dictgen::InsensitiveStr::Ascii("eligionise"),
        dictgen::InsensitiveStr::Ascii("eligionised"),
        dictgen::InsensitiveStr::Ascii("eligionises"),
        dictgen::InsensitiveStr::Ascii("eligionising"),
        dictgen::InsensitiveStr::Ascii("eligionize"),
        dictgen::InsensitiveStr::Ascii("eligionized"),
        dictgen::InsensitiveStr::Ascii("eligionizes"),
        dictgen::InsensitiveStr::Ascii("eligionizing"),
        dictgen::InsensitiveStr::Ascii("k"),
        dictgen::InsensitiveStr::Ascii("matorrhea"),
        dictgen::InsensitiveStr::Ascii("matorrhoea"),
        dictgen::InsensitiveStr::Ascii("r"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DERACIALIZE_9783084937607989481)],
        &[(0b10010, &ENTRY_DERACIALIZED_4376882873641183994)],
        &[(0b10010, &ENTRY_DERACIALIZES_13294967594818824381)],
        &[(0b10010, &ENTRY_DERACIALIZING_317834154241325652)],
        &[(0b01001, &ENTRY_DERACIALIZE_9783084937607989481)],
        &[(0b01001, &ENTRY_DERACIALIZED_4376882873641183994)],
        &[(0b01001, &ENTRY_DERACIALIZES_13294967594818824381)],
        &[(0b01001, &ENTRY_DERACIALIZING_317834154241325652)],
        &[(0b10010, &ENTRY_DERATIONALIZATION_3932130518301875356)],
        &[(0b10010, &ENTRY_DERATIONALIZATIONS_4307467050402784753)],
        &[(0b10010, &ENTRY_DERATIONALIZE_15378847943662042149)],
        &[(0b10010, &ENTRY_DERATIONALIZES_11244440347288615996)],
        &[(0b01001, &ENTRY_DERATIONALIZATION_3932130518301875356)],
        &[(0b01001, &ENTRY_DERATIONALIZATIONS_4307467050402784753)],
        &[(0b01001, &ENTRY_DERATIONALIZE_15378847943662042149)],
        &[(0b01001, &ENTRY_DERATIONALIZES_11244440347288615996)],
        &[(0b10010, &ENTRY_DERATIZATION_13362911385856325847)],
        &[(0b10010, &ENTRY_DERATIZATIONS_2572923369998003352)],
        &[(0b01001, &ENTRY_DERATIZATION_13362911385856325847)],
        &[(0b01001, &ENTRY_DERATIZATIONS_2572923369998003352)],
        &[(0b10010, &ENTRY_DEREALIZATION_9432370619252273879)],
        &[(0b01001, &ENTRY_DEREALIZATION_9432370619252273879)],
        &[(0b10010, &ENTRY_DERECOGNIZE_2343806536593988088)],
        &[(0b10010, &ENTRY_DERECOGNIZED_960138435617857980)],
        &[(0b10010, &ENTRY_DERECOGNIZES_11433993209056588186)],
        &[(0b10010, &ENTRY_DERECOGNIZING_8878118177062532050)],
        &[(0b01001, &ENTRY_DERECOGNIZE_2343806536593988088)],
        &[(0b01001, &ENTRY_DERECOGNIZED_960138435617857980)],
        &[(0b01001, &ENTRY_DERECOGNIZES_11433993209056588186)],
        &[(0b01001, &ENTRY_DERECOGNIZING_8878118177062532050)],
        &[(0b10010, &ENTRY_DEREGULATIONIZE_17362959656302764932)],
        &[(0b10010, &ENTRY_DEREGULATIONIZES_6565341939253019114)],
        &[(0b01001, &ENTRY_DEREGULATIONIZE_17362959656302764932)],
        &[(0b01001, &ENTRY_DEREGULATIONIZES_6565341939253019114)],
        &[(0b10010, &ENTRY_DERELIGIONIZE_2435879930867823358)],
        &[(0b10010, &ENTRY_DERELIGIONIZED_17203995608182086867)],
        &[(0b10010, &ENTRY_DERELIGIONIZES_4132296307299375253)],
        &[(0b10010, &ENTRY_DERELIGIONIZING_284672108011662731)],
        &[(0b01001, &ENTRY_DERELIGIONIZE_2435879930867823358)],
        &[(0b01001, &ENTRY_DERELIGIONIZED_17203995608182086867)],
        &[(0b01001, &ENTRY_DERELIGIONIZES_4132296307299375253)],
        &[(0b01001, &ENTRY_DERELIGIONIZING_284672108011662731)],
        &[(0b00001, &ENTRY_DERK_4188156948801172154)],
        &[(0b10001, &ENTRY_DERMATORRHEA_13737380613591936019)],
        &[(0b11010, &ENTRY_DERMATORRHEA_13737380613591936019)],
        &[(0b00001, &ENTRY_DERR_9116132351167601479)],
    ],
    range: 1..=15,
};

static VARS_DEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DEP_CHILDREN),
    value: None,
};

static VARS_DEP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DEPA_NODE),
    None,
    None,
    None,
    Some(&VARS_DEPE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DEPO_NODE),
    None,
    None,
    Some(&VARS_DEPR_NODE),
    None,
    None,
    Some(&VARS_DEPU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_DEPU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEPU_CHILDREN),
    value: None,
};

pub static VARS_DEPU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tationise"),
        dictgen::InsensitiveStr::Ascii("tationises"),
        dictgen::InsensitiveStr::Ascii("tationize"),
        dictgen::InsensitiveStr::Ascii("tationizes"),
        dictgen::InsensitiveStr::Ascii("tisation"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tization"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEPUTATIONIZE_11714259026529794497)],
        &[(0b10010, &ENTRY_DEPUTATIONIZES_18170818538991682534)],
        &[(0b01001, &ENTRY_DEPUTATIONIZE_11714259026529794497)],
        &[(0b01001, &ENTRY_DEPUTATIONIZES_18170818538991682534)],
        &[(0b10010, &ENTRY_DEPUTIZATION_11869337893120725807)],
        &[(0b10010, &ENTRY_DEPUTIZE_14708452402802592517)],
        &[(0b10010, &ENTRY_DEPUTIZED_15591871669346119917)],
        &[(0b10010, &ENTRY_DEPUTIZES_16885595381873833095)],
        &[(0b10010, &ENTRY_DEPUTIZING_11731565191775615613)],
        &[(0b01001, &ENTRY_DEPUTIZATION_11869337893120725807)],
        &[(0b01001, &ENTRY_DEPUTIZE_14708452402802592517)],
        &[(0b01001, &ENTRY_DEPUTIZED_15591871669346119917)],
        &[(0b01001, &ENTRY_DEPUTIZES_16885595381873833095)],
        &[(0b01001, &ENTRY_DEPUTIZING_11731565191775615613)],
    ],
    range: 4..=10,
};

static VARS_DEPR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEPR_CHILDREN),
    value: None,
};

pub static VARS_DEPR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("essurisation"),
        dictgen::InsensitiveStr::Ascii("essurisations"),
        dictgen::InsensitiveStr::Ascii("essurise"),
        dictgen::InsensitiveStr::Ascii("essurised"),
        dictgen::InsensitiveStr::Ascii("essurises"),
        dictgen::InsensitiveStr::Ascii("essurising"),
        dictgen::InsensitiveStr::Ascii("essurization"),
        dictgen::InsensitiveStr::Ascii("essurizations"),
        dictgen::InsensitiveStr::Ascii("essurize"),
        dictgen::InsensitiveStr::Ascii("essurized"),
        dictgen::InsensitiveStr::Ascii("essurizes"),
        dictgen::InsensitiveStr::Ascii("essurizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEPRESSURIZATION_10217952263080064818)],
        &[(0b10010, &ENTRY_DEPRESSURIZATIONS_3229591287232610524)],
        &[(0b10010, &ENTRY_DEPRESSURIZE_4006202201627920697)],
        &[(0b10010, &ENTRY_DEPRESSURIZED_4661479933134951890)],
        &[(0b10010, &ENTRY_DEPRESSURIZES_6344315569910956899)],
        &[(0b10010, &ENTRY_DEPRESSURIZING_309386769136380221)],
        &[(0b01001, &ENTRY_DEPRESSURIZATION_10217952263080064818)],
        &[(0b01001, &ENTRY_DEPRESSURIZATIONS_3229591287232610524)],
        &[(0b01001, &ENTRY_DEPRESSURIZE_4006202201627920697)],
        &[(0b01001, &ENTRY_DEPRESSURIZED_4661479933134951890)],
        &[(0b01001, &ENTRY_DEPRESSURIZES_6344315569910956899)],
        &[(0b01001, &ENTRY_DEPRESSURIZING_309386769136380221)],
    ],
    range: 8..=13,
};

static VARS_DEPO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEPO_CHILDREN),
    value: None,
};

pub static VARS_DEPO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("larisation"),
        dictgen::InsensitiveStr::Ascii("larisations"),
        dictgen::InsensitiveStr::Ascii("larise"),
        dictgen::InsensitiveStr::Ascii("larised"),
        dictgen::InsensitiveStr::Ascii("lariser"),
        dictgen::InsensitiveStr::Ascii("larisers"),
        dictgen::InsensitiveStr::Ascii("larises"),
        dictgen::InsensitiveStr::Ascii("larising"),
        dictgen::InsensitiveStr::Ascii("larization"),
        dictgen::InsensitiveStr::Ascii("larizations"),
        dictgen::InsensitiveStr::Ascii("larize"),
        dictgen::InsensitiveStr::Ascii("larized"),
        dictgen::InsensitiveStr::Ascii("larizer"),
        dictgen::InsensitiveStr::Ascii("larizers"),
        dictgen::InsensitiveStr::Ascii("larizes"),
        dictgen::InsensitiveStr::Ascii("larizing"),
        dictgen::InsensitiveStr::Ascii("liticisation"),
        dictgen::InsensitiveStr::Ascii("liticise"),
        dictgen::InsensitiveStr::Ascii("liticised"),
        dictgen::InsensitiveStr::Ascii("liticises"),
        dictgen::InsensitiveStr::Ascii("liticising"),
        dictgen::InsensitiveStr::Ascii("liticization"),
        dictgen::InsensitiveStr::Ascii("liticize"),
        dictgen::InsensitiveStr::Ascii("liticized"),
        dictgen::InsensitiveStr::Ascii("liticizes"),
        dictgen::InsensitiveStr::Ascii("liticizing"),
        dictgen::InsensitiveStr::Ascii("lymerisation"),
        dictgen::InsensitiveStr::Ascii("lymerisations"),
        dictgen::InsensitiveStr::Ascii("lymerise"),
        dictgen::InsensitiveStr::Ascii("lymerised"),
        dictgen::InsensitiveStr::Ascii("lymerises"),
        dictgen::InsensitiveStr::Ascii("lymerising"),
        dictgen::InsensitiveStr::Ascii("lymerization"),
        dictgen::InsensitiveStr::Ascii("lymerizations"),
        dictgen::InsensitiveStr::Ascii("lymerize"),
        dictgen::InsensitiveStr::Ascii("lymerized"),
        dictgen::InsensitiveStr::Ascii("lymerizes"),
        dictgen::InsensitiveStr::Ascii("lymerizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEPOLARIZATION_15774978100153361770)],
        &[(0b10010, &ENTRY_DEPOLARIZATIONS_16752636127743385337)],
        &[(0b10010, &ENTRY_DEPOLARIZE_14265169874625051800)],
        &[(0b10010, &ENTRY_DEPOLARIZED_377191566140430593)],
        &[(0b10010, &ENTRY_DEPOLARIZER_2090825138581959491)],
        &[(0b10010, &ENTRY_DEPOLARIZERS_13304033375550399462)],
        &[(0b10010, &ENTRY_DEPOLARIZES_3226445999634432202)],
        &[(0b10010, &ENTRY_DEPOLARIZING_5347205347171321160)],
        &[(0b01001, &ENTRY_DEPOLARIZATION_15774978100153361770)],
        &[(0b01001, &ENTRY_DEPOLARIZATIONS_16752636127743385337)],
        &[(0b01001, &ENTRY_DEPOLARIZE_14265169874625051800)],
        &[(0b01001, &ENTRY_DEPOLARIZED_377191566140430593)],
        &[(0b01001, &ENTRY_DEPOLARIZER_2090825138581959491)],
        &[(0b01001, &ENTRY_DEPOLARIZERS_13304033375550399462)],
        &[(0b01001, &ENTRY_DEPOLARIZES_3226445999634432202)],
        &[(0b01001, &ENTRY_DEPOLARIZING_5347205347171321160)],
        &[(0b10010, &ENTRY_DEPOLITICIZATION_15265110179231465481)],
        &[(0b10010, &ENTRY_DEPOLITICIZE_7370960578004693927)],
        &[(0b10010, &ENTRY_DEPOLITICIZED_17235888679911223431)],
        &[(0b10010, &ENTRY_DEPOLITICIZES_13700298543339019300)],
        &[(0b10010, &ENTRY_DEPOLITICIZING_2647277921869165326)],
        &[(0b01001, &ENTRY_DEPOLITICIZATION_15265110179231465481)],
        &[(0b01001, &ENTRY_DEPOLITICIZE_7370960578004693927)],
        &[(0b01001, &ENTRY_DEPOLITICIZED_17235888679911223431)],
        &[(0b01001, &ENTRY_DEPOLITICIZES_13700298543339019300)],
        &[(0b01001, &ENTRY_DEPOLITICIZING_2647277921869165326)],
        &[(0b10010, &ENTRY_DEPOLYMERIZATION_3633275984619877932)],
        &[(0b10010, &ENTRY_DEPOLYMERIZATIONS_11969399143532196145)],
        &[(0b10010, &ENTRY_DEPOLYMERIZE_17116091341951567184)],
        &[(0b10010, &ENTRY_DEPOLYMERIZED_3571703505928412135)],
        &[(0b10010, &ENTRY_DEPOLYMERIZES_18366430796592539914)],
        &[(0b10010, &ENTRY_DEPOLYMERIZING_4657392775383874483)],
        &[(0b01001, &ENTRY_DEPOLYMERIZATION_3633275984619877932)],
        &[(0b01001, &ENTRY_DEPOLYMERIZATIONS_11969399143532196145)],
        &[(0b01001, &ENTRY_DEPOLYMERIZE_17116091341951567184)],
        &[(0b01001, &ENTRY_DEPOLYMERIZED_3571703505928412135)],
        &[(0b01001, &ENTRY_DEPOLYMERIZES_18366430796592539914)],
        &[(0b01001, &ENTRY_DEPOLYMERIZING_4657392775383874483)],
    ],
    range: 6..=13,
};

static VARS_DEPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEPE_CHILDREN),
    value: None,
};

pub static VARS_DEPE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ndance"),
        dictgen::InsensitiveStr::Ascii("ndances"),
        dictgen::InsensitiveStr::Ascii("ndant"),
        dictgen::InsensitiveStr::Ascii("ndants"),
        dictgen::InsensitiveStr::Ascii("rsonalisation"),
        dictgen::InsensitiveStr::Ascii("rsonalisations"),
        dictgen::InsensitiveStr::Ascii("rsonalise"),
        dictgen::InsensitiveStr::Ascii("rsonalised"),
        dictgen::InsensitiveStr::Ascii("rsonalises"),
        dictgen::InsensitiveStr::Ascii("rsonalising"),
        dictgen::InsensitiveStr::Ascii("rsonalization"),
        dictgen::InsensitiveStr::Ascii("rsonalizations"),
        dictgen::InsensitiveStr::Ascii("rsonalize"),
        dictgen::InsensitiveStr::Ascii("rsonalized"),
        dictgen::InsensitiveStr::Ascii("rsonalizes"),
        dictgen::InsensitiveStr::Ascii("rsonalizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DEPENDENCE_2975032857660330940)],
        &[(0b00001, &ENTRY_DEPENDENCES_4898857694362268650)],
        &[(0b11010, &ENTRY_DEPENDENT_15548837712937438814)],
        &[(0b11010, &ENTRY_DEPENDENTS_6484680412761939586)],
        &[(0b10010, &ENTRY_DEPERSONALIZATION_3798571196825324317)],
        &[(0b10010, &ENTRY_DEPERSONALIZATIONS_13800546258710189283)],
        &[(0b10010, &ENTRY_DEPERSONALIZE_6577935583661707932)],
        &[(0b10010, &ENTRY_DEPERSONALIZED_4395700992531987338)],
        &[(0b10010, &ENTRY_DEPERSONALIZES_2561116931316488871)],
        &[(0b10010, &ENTRY_DEPERSONALIZING_12778802923540312835)],
        &[(0b01001, &ENTRY_DEPERSONALIZATION_3798571196825324317)],
        &[(0b01001, &ENTRY_DEPERSONALIZATIONS_13800546258710189283)],
        &[(0b01001, &ENTRY_DEPERSONALIZE_6577935583661707932)],
        &[(0b01001, &ENTRY_DEPERSONALIZED_4395700992531987338)],
        &[(0b01001, &ENTRY_DEPERSONALIZES_2561116931316488871)],
        &[(0b01001, &ENTRY_DEPERSONALIZING_12778802923540312835)],
    ],
    range: 5..=14,
};

static VARS_DEPA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEPA_CHILDREN),
    value: None,
};

pub static VARS_DEPA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rtmentalisation"),
        dictgen::InsensitiveStr::Ascii("rtmentalisations"),
        dictgen::InsensitiveStr::Ascii("rtmentalise"),
        dictgen::InsensitiveStr::Ascii("rtmentalised"),
        dictgen::InsensitiveStr::Ascii("rtmentalises"),
        dictgen::InsensitiveStr::Ascii("rtmentalising"),
        dictgen::InsensitiveStr::Ascii("rtmentalization"),
        dictgen::InsensitiveStr::Ascii("rtmentalizations"),
        dictgen::InsensitiveStr::Ascii("rtmentalize"),
        dictgen::InsensitiveStr::Ascii("rtmentalized"),
        dictgen::InsensitiveStr::Ascii("rtmentalizes"),
        dictgen::InsensitiveStr::Ascii("rtmentalizing"),
        dictgen::InsensitiveStr::Ascii("rtmentisation"),
        dictgen::InsensitiveStr::Ascii("rtmentisations"),
        dictgen::InsensitiveStr::Ascii("rtmentise"),
        dictgen::InsensitiveStr::Ascii("rtmentises"),
        dictgen::InsensitiveStr::Ascii("rtmentization"),
        dictgen::InsensitiveStr::Ascii("rtmentizations"),
        dictgen::InsensitiveStr::Ascii("rtmentize"),
        dictgen::InsensitiveStr::Ascii("rtmentizes"),
        dictgen::InsensitiveStr::Ascii("uperisation"),
        dictgen::InsensitiveStr::Ascii("uperise"),
        dictgen::InsensitiveStr::Ascii("uperised"),
        dictgen::InsensitiveStr::Ascii("uperises"),
        dictgen::InsensitiveStr::Ascii("uperising"),
        dictgen::InsensitiveStr::Ascii("uperization"),
        dictgen::InsensitiveStr::Ascii("uperize"),
        dictgen::InsensitiveStr::Ascii("uperized"),
        dictgen::InsensitiveStr::Ascii("uperizes"),
        dictgen::InsensitiveStr::Ascii("uperizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEPARTMENTALIZATION_16732736631808006231)],
        &[(0b10010, &ENTRY_DEPARTMENTALIZATIONS_12433036246957322206)],
        &[(0b10010, &ENTRY_DEPARTMENTALIZE_12544989001599465845)],
        &[(0b10010, &ENTRY_DEPARTMENTALIZED_6440346371168938642)],
        &[(0b10010, &ENTRY_DEPARTMENTALIZES_5200360728452577607)],
        &[(0b10010, &ENTRY_DEPARTMENTALIZING_14933842151249052929)],
        &[(0b01001, &ENTRY_DEPARTMENTALIZATION_16732736631808006231)],
        &[(0b01001, &ENTRY_DEPARTMENTALIZATIONS_12433036246957322206)],
        &[(0b01001, &ENTRY_DEPARTMENTALIZE_12544989001599465845)],
        &[(0b01001, &ENTRY_DEPARTMENTALIZED_6440346371168938642)],
        &[(0b01001, &ENTRY_DEPARTMENTALIZES_5200360728452577607)],
        &[(0b01001, &ENTRY_DEPARTMENTALIZING_14933842151249052929)],
        &[(0b10010, &ENTRY_DEPARTMENTIZATION_9861192684661133651)],
        &[(0b10010, &ENTRY_DEPARTMENTIZATIONS_17612652463821022551)],
        &[(0b10010, &ENTRY_DEPARTMENTIZE_5108687202401260993)],
        &[(0b10010, &ENTRY_DEPARTMENTIZES_12817610265677063578)],
        &[(0b01001, &ENTRY_DEPARTMENTIZATION_9861192684661133651)],
        &[(0b01001, &ENTRY_DEPARTMENTIZATIONS_17612652463821022551)],
        &[(0b01001, &ENTRY_DEPARTMENTIZE_5108687202401260993)],
        &[(0b01001, &ENTRY_DEPARTMENTIZES_12817610265677063578)],
        &[(0b10010, &ENTRY_DEPAUPERIZATION_5277909277167873828)],
        &[(0b10010, &ENTRY_DEPAUPERIZE_12233319978058773389)],
        &[(0b10010, &ENTRY_DEPAUPERIZED_10522496344063518401)],
        &[(0b10010, &ENTRY_DEPAUPERIZES_7048735608776554840)],
        &[(0b10010, &ENTRY_DEPAUPERIZING_1140611640524607577)],
        &[(0b01001, &ENTRY_DEPAUPERIZATION_5277909277167873828)],
        &[(0b01001, &ENTRY_DEPAUPERIZE_12233319978058773389)],
        &[(0b01001, &ENTRY_DEPAUPERIZED_10522496344063518401)],
        &[(0b01001, &ENTRY_DEPAUPERIZES_7048735608776554840)],
        &[(0b01001, &ENTRY_DEPAUPERIZING_1140611640524607577)],
    ],
    range: 7..=16,
};

static VARS_DEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEO_CHILDREN),
    value: None,
};

pub static VARS_DEO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dorisation"),
        dictgen::InsensitiveStr::Ascii("dorisations"),
        dictgen::InsensitiveStr::Ascii("dorise"),
        dictgen::InsensitiveStr::Ascii("dorised"),
        dictgen::InsensitiveStr::Ascii("doriser"),
        dictgen::InsensitiveStr::Ascii("dorisers"),
        dictgen::InsensitiveStr::Ascii("dorises"),
        dictgen::InsensitiveStr::Ascii("dorising"),
        dictgen::InsensitiveStr::Ascii("dorization"),
        dictgen::InsensitiveStr::Ascii("dorizations"),
        dictgen::InsensitiveStr::Ascii("dorize"),
        dictgen::InsensitiveStr::Ascii("dorized"),
        dictgen::InsensitiveStr::Ascii("dorizer"),
        dictgen::InsensitiveStr::Ascii("dorizers"),
        dictgen::InsensitiveStr::Ascii("dorizes"),
        dictgen::InsensitiveStr::Ascii("dorizing"),
        dictgen::InsensitiveStr::Ascii("xidisation"),
        dictgen::InsensitiveStr::Ascii("xidisations"),
        dictgen::InsensitiveStr::Ascii("xidise"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidiser"),
        dictgen::InsensitiveStr::Ascii("xidisers"),
        dictgen::InsensitiveStr::Ascii("xidises"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidization"),
        dictgen::InsensitiveStr::Ascii("xidizations"),
        dictgen::InsensitiveStr::Ascii("xidize"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizer"),
        dictgen::InsensitiveStr::Ascii("xidizers"),
        dictgen::InsensitiveStr::Ascii("xidizes"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
        dictgen::InsensitiveStr::Ascii("xygenise"),
        dictgen::InsensitiveStr::Ascii("xygenised"),
        dictgen::InsensitiveStr::Ascii("xygenises"),
        dictgen::InsensitiveStr::Ascii("xygenising"),
        dictgen::InsensitiveStr::Ascii("xygenize"),
        dictgen::InsensitiveStr::Ascii("xygenized"),
        dictgen::InsensitiveStr::Ascii("xygenizes"),
        dictgen::InsensitiveStr::Ascii("xygenizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEODORIZATION_15742635316130478344)],
        &[(0b10010, &ENTRY_DEODORIZATIONS_1611791796101503754)],
        &[(0b10010, &ENTRY_DEODORIZE_11113930164721287704)],
        &[(0b10010, &ENTRY_DEODORIZED_18267764171132816135)],
        &[(0b10010, &ENTRY_DEODORIZER_10856939399522550712)],
        &[(0b10010, &ENTRY_DEODORIZERS_14070131912570234977)],
        &[(0b10010, &ENTRY_DEODORIZES_9011430423896385984)],
        &[(0b10010, &ENTRY_DEODORIZING_13167718500093382611)],
        &[(0b01001, &ENTRY_DEODORIZATION_15742635316130478344)],
        &[(0b01001, &ENTRY_DEODORIZATIONS_1611791796101503754)],
        &[(0b01001, &ENTRY_DEODORIZE_11113930164721287704)],
        &[(0b01001, &ENTRY_DEODORIZED_18267764171132816135)],
        &[(0b01001, &ENTRY_DEODORIZER_10856939399522550712)],
        &[(0b01001, &ENTRY_DEODORIZERS_14070131912570234977)],
        &[(0b01001, &ENTRY_DEODORIZES_9011430423896385984)],
        &[(0b01001, &ENTRY_DEODORIZING_13167718500093382611)],
        &[(0b10010, &ENTRY_DEOXIDIZATION_2952381442471631896)],
        &[(0b10010, &ENTRY_DEOXIDIZATIONS_1374490184286343040)],
        &[(0b10010, &ENTRY_DEOXIDIZE_2568727168916119326)],
        &[(0b10010, &ENTRY_DEOXIDIZED_1342275632500355504)],
        &[(0b10010, &ENTRY_DEOXIDIZER_553955836648748373)],
        &[(0b10010, &ENTRY_DEOXIDIZERS_2906487448450757563)],
        &[(0b10010, &ENTRY_DEOXIDIZES_17882486098773443848)],
        &[(0b10010, &ENTRY_DEOXIDIZING_7425951821093112332)],
        &[(0b01001, &ENTRY_DEOXIDIZATION_2952381442471631896)],
        &[(0b01001, &ENTRY_DEOXIDIZATIONS_1374490184286343040)],
        &[(0b01001, &ENTRY_DEOXIDIZE_2568727168916119326)],
        &[(0b01001, &ENTRY_DEOXIDIZED_1342275632500355504)],
        &[(0b01001, &ENTRY_DEOXIDIZER_553955836648748373)],
        &[(0b01001, &ENTRY_DEOXIDIZERS_2906487448450757563)],
        &[(0b01001, &ENTRY_DEOXIDIZES_17882486098773443848)],
        &[(0b01001, &ENTRY_DEOXIDIZING_7425951821093112332)],
        &[(0b10010, &ENTRY_DEOXYGENIZE_615158521240619189)],
        &[(0b10010, &ENTRY_DEOXYGENIZED_9843329803418032730)],
        &[(0b10010, &ENTRY_DEOXYGENIZES_11294607905996274671)],
        &[(0b10010, &ENTRY_DEOXYGENIZING_13700570458079855816)],
        &[(0b01001, &ENTRY_DEOXYGENIZE_615158521240619189)],
        &[(0b01001, &ENTRY_DEOXYGENIZED_9843329803418032730)],
        &[(0b01001, &ENTRY_DEOXYGENIZES_11294607905996274671)],
        &[(0b01001, &ENTRY_DEOXYGENIZING_13700570458079855816)],
    ],
    range: 6..=11,
};

static VARS_DEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DEN_CHILDREN),
    value: None,
};

static VARS_DEN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DENA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DENI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DENO_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_DENT_NODE),
    Some(&VARS_DENU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_DENU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DENU_CHILDREN),
    value: None,
};

pub static VARS_DENU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("clearisation"),
        dictgen::InsensitiveStr::Ascii("clearisations"),
        dictgen::InsensitiveStr::Ascii("clearise"),
        dictgen::InsensitiveStr::Ascii("clearised"),
        dictgen::InsensitiveStr::Ascii("clearises"),
        dictgen::InsensitiveStr::Ascii("clearising"),
        dictgen::InsensitiveStr::Ascii("clearization"),
        dictgen::InsensitiveStr::Ascii("clearizations"),
        dictgen::InsensitiveStr::Ascii("clearize"),
        dictgen::InsensitiveStr::Ascii("clearized"),
        dictgen::InsensitiveStr::Ascii("clearizes"),
        dictgen::InsensitiveStr::Ascii("clearizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DENUCLEARIZATION_3316678403334950773)],
        &[(0b10010, &ENTRY_DENUCLEARIZATIONS_14853943063749587480)],
        &[(0b10010, &ENTRY_DENUCLEARIZE_7087853246260766822)],
        &[(0b10010, &ENTRY_DENUCLEARIZED_6796248104359598000)],
        &[(0b10010, &ENTRY_DENUCLEARIZES_18168803656441460141)],
        &[(0b10010, &ENTRY_DENUCLEARIZING_12070807204335448918)],
        &[(0b01001, &ENTRY_DENUCLEARIZATION_3316678403334950773)],
        &[(0b01001, &ENTRY_DENUCLEARIZATIONS_14853943063749587480)],
        &[(0b01001, &ENTRY_DENUCLEARIZE_7087853246260766822)],
        &[(0b01001, &ENTRY_DENUCLEARIZED_6796248104359598000)],
        &[(0b01001, &ENTRY_DENUCLEARIZES_18168803656441460141)],
        &[(0b01001, &ENTRY_DENUCLEARIZING_12070807204335448918)],
    ],
    range: 8..=13,
};

static VARS_DENT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DENT_CHILDREN),
    value: None,
};

pub static VARS_DENT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("in"),
        dictgen::InsensitiveStr::Ascii("ins"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DENTALIZATION_7950101487769456236)],
        &[(0b10010, &ENTRY_DENTALIZATIONS_14739673468733397726)],
        &[(0b10010, &ENTRY_DENTALIZE_7399494862597532732)],
        &[(0b10010, &ENTRY_DENTALIZED_4287706936239846846)],
        &[(0b10010, &ENTRY_DENTALIZES_1046373883492057791)],
        &[(0b10010, &ENTRY_DENTALIZING_9457659412983759427)],
        &[(0b01001, &ENTRY_DENTALIZATION_7950101487769456236)],
        &[(0b01001, &ENTRY_DENTALIZATIONS_14739673468733397726)],
        &[(0b01001, &ENTRY_DENTALIZE_7399494862597532732)],
        &[(0b01001, &ENTRY_DENTALIZED_4287706936239846846)],
        &[(0b01001, &ENTRY_DENTALIZES_1046373883492057791)],
        &[(0b01001, &ENTRY_DENTALIZING_9457659412983759427)],
        &[(0b00001, &ENTRY_DENTIN_357200140665913924)],
        &[(0b00001, &ENTRY_DENTINS_16363943754880560753)],
    ],
    range: 2..=10,
};

static VARS_DENO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DENO_CHILDREN),
    value: None,
};

pub static VARS_DENO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("minationalise"),
        dictgen::InsensitiveStr::Ascii("minationalises"),
        dictgen::InsensitiveStr::Ascii("minationalize"),
        dictgen::InsensitiveStr::Ascii("minationalizes"),
        dictgen::InsensitiveStr::Ascii("rmalise"),
        dictgen::InsensitiveStr::Ascii("rmalize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DENOMINATIONALIZE_10227188452058754943)],
        &[(0b10010, &ENTRY_DENOMINATIONALIZES_6379243336804749861)],
        &[(0b01001, &ENTRY_DENOMINATIONALIZE_10227188452058754943)],
        &[(0b01001, &ENTRY_DENOMINATIONALIZES_6379243336804749861)],
        &[(0b10010, &ENTRY_DENORMALIZE_10985021775483702575)],
        &[(0b01001, &ENTRY_DENORMALIZE_10985021775483702575)],
    ],
    range: 7..=14,
};

static VARS_DENI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DENI_CHILDREN),
    value: None,
};

pub static VARS_DENI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cotinise"),
        dictgen::InsensitiveStr::Ascii("cotinize"),
        dictgen::InsensitiveStr::Ascii("zenise"),
        dictgen::InsensitiveStr::Ascii("zenises"),
        dictgen::InsensitiveStr::Ascii("zenize"),
        dictgen::InsensitiveStr::Ascii("zenizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DENICOTINIZE_8579575775799953548)],
        &[(0b01001, &ENTRY_DENICOTINIZE_8579575775799953548)],
        &[(0b10010, &ENTRY_DENIZENIZE_17817911669092719598)],
        &[(0b10010, &ENTRY_DENIZENIZES_14830211105150512617)],
        &[(0b01001, &ENTRY_DENIZENIZE_17817911669092719598)],
        &[(0b01001, &ENTRY_DENIZENIZES_14830211105150512617)],
    ],
    range: 6..=8,
};

static VARS_DENA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DENA_CHILDREN),
    value: None,
};

pub static VARS_DENA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tionalisation"),
        dictgen::InsensitiveStr::Ascii("tionalisations"),
        dictgen::InsensitiveStr::Ascii("tionalise"),
        dictgen::InsensitiveStr::Ascii("tionalised"),
        dictgen::InsensitiveStr::Ascii("tionalises"),
        dictgen::InsensitiveStr::Ascii("tionalising"),
        dictgen::InsensitiveStr::Ascii("tionalization"),
        dictgen::InsensitiveStr::Ascii("tionalizations"),
        dictgen::InsensitiveStr::Ascii("tionalize"),
        dictgen::InsensitiveStr::Ascii("tionalized"),
        dictgen::InsensitiveStr::Ascii("tionalizes"),
        dictgen::InsensitiveStr::Ascii("tionalizing"),
        dictgen::InsensitiveStr::Ascii("turalisation"),
        dictgen::InsensitiveStr::Ascii("turalisations"),
        dictgen::InsensitiveStr::Ascii("turalise"),
        dictgen::InsensitiveStr::Ascii("turalised"),
        dictgen::InsensitiveStr::Ascii("turalises"),
        dictgen::InsensitiveStr::Ascii("turalising"),
        dictgen::InsensitiveStr::Ascii("turalization"),
        dictgen::InsensitiveStr::Ascii("turalizations"),
        dictgen::InsensitiveStr::Ascii("turalize"),
        dictgen::InsensitiveStr::Ascii("turalized"),
        dictgen::InsensitiveStr::Ascii("turalizes"),
        dictgen::InsensitiveStr::Ascii("turalizing"),
        dictgen::InsensitiveStr::Ascii("turisation"),
        dictgen::InsensitiveStr::Ascii("turisations"),
        dictgen::InsensitiveStr::Ascii("turise"),
        dictgen::InsensitiveStr::Ascii("turised"),
        dictgen::InsensitiveStr::Ascii("turiser"),
        dictgen::InsensitiveStr::Ascii("turisers"),
        dictgen::InsensitiveStr::Ascii("turises"),
        dictgen::InsensitiveStr::Ascii("turising"),
        dictgen::InsensitiveStr::Ascii("turization"),
        dictgen::InsensitiveStr::Ascii("turizations"),
        dictgen::InsensitiveStr::Ascii("turize"),
        dictgen::InsensitiveStr::Ascii("turized"),
        dictgen::InsensitiveStr::Ascii("turizer"),
        dictgen::InsensitiveStr::Ascii("turizers"),
        dictgen::InsensitiveStr::Ascii("turizes"),
        dictgen::InsensitiveStr::Ascii("turizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DENATIONALIZATION_7729401217206590693)],
        &[(0b10010, &ENTRY_DENATIONALIZATIONS_15722416399546323549)],
        &[(0b10010, &ENTRY_DENATIONALIZE_6717709717538962281)],
        &[(0b10010, &ENTRY_DENATIONALIZED_743884727286515814)],
        &[(0b10010, &ENTRY_DENATIONALIZES_810829978748210734)],
        &[(0b10010, &ENTRY_DENATIONALIZING_700744151576877592)],
        &[(0b01001, &ENTRY_DENATIONALIZATION_7729401217206590693)],
        &[(0b01001, &ENTRY_DENATIONALIZATIONS_15722416399546323549)],
        &[(0b01001, &ENTRY_DENATIONALIZE_6717709717538962281)],
        &[(0b01001, &ENTRY_DENATIONALIZED_743884727286515814)],
        &[(0b01001, &ENTRY_DENATIONALIZES_810829978748210734)],
        &[(0b01001, &ENTRY_DENATIONALIZING_700744151576877592)],
        &[(0b10010, &ENTRY_DENATURALIZATION_971871507540742642)],
        &[(0b10010, &ENTRY_DENATURALIZATIONS_8163203679079106549)],
        &[(0b10010, &ENTRY_DENATURALIZE_13324203980568159303)],
        &[(0b10010, &ENTRY_DENATURALIZED_12577789701438825587)],
        &[(0b10010, &ENTRY_DENATURALIZES_1101122283585879857)],
        &[(0b10010, &ENTRY_DENATURALIZING_10692265626612469207)],
        &[(0b01001, &ENTRY_DENATURALIZATION_971871507540742642)],
        &[(0b01001, &ENTRY_DENATURALIZATIONS_8163203679079106549)],
        &[(0b01001, &ENTRY_DENATURALIZE_13324203980568159303)],
        &[(0b01001, &ENTRY_DENATURALIZED_12577789701438825587)],
        &[(0b01001, &ENTRY_DENATURALIZES_1101122283585879857)],
        &[(0b01001, &ENTRY_DENATURALIZING_10692265626612469207)],
        &[(0b10010, &ENTRY_DENATURIZATION_16327711323005388330)],
        &[(0b10010, &ENTRY_DENATURIZATIONS_6130073867652899556)],
        &[(0b10010, &ENTRY_DENATURIZE_8790862263166536662)],
        &[(0b10010, &ENTRY_DENATURIZED_7728796726923631023)],
        &[(0b10010, &ENTRY_DENATURIZER_5742972324535303084)],
        &[(0b10010, &ENTRY_DENATURIZERS_8124812684792240271)],
        &[(0b10010, &ENTRY_DENATURIZES_8891761127410674874)],
        &[(0b10010, &ENTRY_DENATURIZING_10703544832870467506)],
        &[(0b01001, &ENTRY_DENATURIZATION_16327711323005388330)],
        &[(0b01001, &ENTRY_DENATURIZATIONS_6130073867652899556)],
        &[(0b01001, &ENTRY_DENATURIZE_8790862263166536662)],
        &[(0b01001, &ENTRY_DENATURIZED_7728796726923631023)],
        &[(0b01001, &ENTRY_DENATURIZER_5742972324535303084)],
        &[(0b01001, &ENTRY_DENATURIZERS_8124812684792240271)],
        &[(0b01001, &ENTRY_DENATURIZES_8891761127410674874)],
        &[(0b01001, &ENTRY_DENATURIZING_10703544832870467506)],
    ],
    range: 6..=14,
};

static VARS_DEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DEM_CHILDREN),
    value: None,
};

static VARS_DEM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DEMA_NODE),
    None,
    None,
    None,
    Some(&VARS_DEME_NODE),
    None,
    None,
    None,
    Some(&VARS_DEMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DEMO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DEMU_NODE),
    None,
    None,
    None,
    Some(&VARS_DEMY_NODE),
    None,
];

static VARS_DEMY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMY_CHILDREN),
    value: None,
};

pub static VARS_DEMY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thologisation"),
        dictgen::InsensitiveStr::Ascii("thologisations"),
        dictgen::InsensitiveStr::Ascii("thologise"),
        dictgen::InsensitiveStr::Ascii("thologised"),
        dictgen::InsensitiveStr::Ascii("thologiser"),
        dictgen::InsensitiveStr::Ascii("thologises"),
        dictgen::InsensitiveStr::Ascii("thologising"),
        dictgen::InsensitiveStr::Ascii("thologization"),
        dictgen::InsensitiveStr::Ascii("thologizations"),
        dictgen::InsensitiveStr::Ascii("thologize"),
        dictgen::InsensitiveStr::Ascii("thologized"),
        dictgen::InsensitiveStr::Ascii("thologizer"),
        dictgen::InsensitiveStr::Ascii("thologizes"),
        dictgen::InsensitiveStr::Ascii("thologizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMYTHOLOGIZATION_9448051342581796983)],
        &[(0b10010, &ENTRY_DEMYTHOLOGIZATIONS_11694452494871264603)],
        &[(0b10010, &ENTRY_DEMYTHOLOGIZE_16256850336374180662)],
        &[(0b10010, &ENTRY_DEMYTHOLOGIZED_1548902620938435190)],
        &[(0b10010, &ENTRY_DEMYTHOLOGIZER_2012883936376160479)],
        &[(0b10010, &ENTRY_DEMYTHOLOGIZES_9084348299549456287)],
        &[(0b10010, &ENTRY_DEMYTHOLOGIZING_16424025398156147764)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZATION_9448051342581796983)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZATIONS_11694452494871264603)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZE_16256850336374180662)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZED_1548902620938435190)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZER_2012883936376160479)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZES_9084348299549456287)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZING_16424025398156147764)],
    ],
    range: 9..=14,
};

static VARS_DEMU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMU_CHILDREN),
    value: None,
};

pub static VARS_DEMU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tualisation"),
        dictgen::InsensitiveStr::Ascii("tualisations"),
        dictgen::InsensitiveStr::Ascii("tualise"),
        dictgen::InsensitiveStr::Ascii("tualised"),
        dictgen::InsensitiveStr::Ascii("tualises"),
        dictgen::InsensitiveStr::Ascii("tualising"),
        dictgen::InsensitiveStr::Ascii("tualization"),
        dictgen::InsensitiveStr::Ascii("tualizations"),
        dictgen::InsensitiveStr::Ascii("tualize"),
        dictgen::InsensitiveStr::Ascii("tualized"),
        dictgen::InsensitiveStr::Ascii("tualizes"),
        dictgen::InsensitiveStr::Ascii("tualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMUTUALIZATION_18431681853700545646)],
        &[(0b10010, &ENTRY_DEMUTUALIZATIONS_6102922690573062369)],
        &[(0b10010, &ENTRY_DEMUTUALIZE_14231937422114961245)],
        &[(0b10010, &ENTRY_DEMUTUALIZED_17042353852397685351)],
        &[(0b10010, &ENTRY_DEMUTUALIZES_15236673083951911035)],
        &[(0b10010, &ENTRY_DEMUTUALIZING_13109066682270155313)],
        &[(0b01001, &ENTRY_DEMUTUALIZATION_18431681853700545646)],
        &[(0b01001, &ENTRY_DEMUTUALIZATIONS_6102922690573062369)],
        &[(0b01001, &ENTRY_DEMUTUALIZE_14231937422114961245)],
        &[(0b01001, &ENTRY_DEMUTUALIZED_17042353852397685351)],
        &[(0b01001, &ENTRY_DEMUTUALIZES_15236673083951911035)],
        &[(0b01001, &ENTRY_DEMUTUALIZING_13109066682270155313)],
    ],
    range: 7..=12,
};

static VARS_DEMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DEMO_CHILDREN),
    value: None,
};

static VARS_DEMO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_DEMOB_NODE),
    Some(&VARS_DEMOC_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DEMON_NODE),
    None,
    None,
    None,
    Some(&VARS_DEMOR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_DEMOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMOR_CHILDREN),
    value: None,
};

pub static VARS_DEMOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alisingly"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("alizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMORALIZATION_5556421705683237030)],
        &[(0b10010, &ENTRY_DEMORALIZATIONS_9043499224356783699)],
        &[(0b10010, &ENTRY_DEMORALIZE_6209215674833141288)],
        &[(0b10010, &ENTRY_DEMORALIZED_11896518767543535927)],
        &[(0b10010, &ENTRY_DEMORALIZER_6308024706547373880)],
        &[(0b10010, &ENTRY_DEMORALIZERS_9101020457936316129)],
        &[(0b10010, &ENTRY_DEMORALIZES_17922317839176266819)],
        &[(0b10010, &ENTRY_DEMORALIZING_7879881258206607673)],
        &[(0b10010, &ENTRY_DEMORALIZINGLY_11418463351635146120)],
        &[(0b01001, &ENTRY_DEMORALIZATION_5556421705683237030)],
        &[(0b01001, &ENTRY_DEMORALIZATIONS_9043499224356783699)],
        &[(0b01001, &ENTRY_DEMORALIZE_6209215674833141288)],
        &[(0b01001, &ENTRY_DEMORALIZED_11896518767543535927)],
        &[(0b01001, &ENTRY_DEMORALIZER_6308024706547373880)],
        &[(0b01001, &ENTRY_DEMORALIZERS_9101020457936316129)],
        &[(0b01001, &ENTRY_DEMORALIZES_17922317839176266819)],
        &[(0b01001, &ENTRY_DEMORALIZING_7879881258206607673)],
        &[(0b01001, &ENTRY_DEMORALIZINGLY_11418463351635146120)],
    ],
    range: 5..=10,
};

static VARS_DEMON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMON_CHILDREN),
    value: None,
};

pub static VARS_DEMON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etisation"),
        dictgen::InsensitiveStr::Ascii("etisations"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etising"),
        dictgen::InsensitiveStr::Ascii("etization"),
        dictgen::InsensitiveStr::Ascii("etizations"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("etizing"),
        dictgen::InsensitiveStr::Ascii("ian"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMONETIZATION_4518090358111490492)],
        &[(0b10010, &ENTRY_DEMONETIZATIONS_5789055765366818676)],
        &[(0b10010, &ENTRY_DEMONETIZE_13078441376893081927)],
        &[(0b10010, &ENTRY_DEMONETIZED_9558772114869845360)],
        &[(0b10010, &ENTRY_DEMONETIZES_11169810391799810472)],
        &[(0b10010, &ENTRY_DEMONETIZING_17201412552660846011)],
        &[(0b01001, &ENTRY_DEMONETIZATION_4518090358111490492)],
        &[(0b01001, &ENTRY_DEMONETIZATIONS_5789055765366818676)],
        &[(0b01001, &ENTRY_DEMONETIZE_13078441376893081927)],
        &[(0b01001, &ENTRY_DEMONETIZED_9558772114869845360)],
        &[(0b01001, &ENTRY_DEMONETIZES_11169810391799810472)],
        &[(0b01001, &ENTRY_DEMONETIZING_17201412552660846011)],
        &[(0b10001, &ENTRY_DEMONIAN_1193667978555747859)],
        &[(0b10010, &ENTRY_DEMONIZATION_435935988767727254)],
        &[(0b10010, &ENTRY_DEMONIZE_13260611226384752739)],
        &[(0b10010, &ENTRY_DEMONIZED_7711881396852229241)],
        &[(0b10010, &ENTRY_DEMONIZES_6258438652449642743)],
        &[(0b10010, &ENTRY_DEMONIZING_8343923659206792410)],
        &[(0b01001, &ENTRY_DEMONIZATION_435935988767727254)],
        &[(0b01001, &ENTRY_DEMONIZE_13260611226384752739)],
        &[(0b01001, &ENTRY_DEMONIZED_7711881396852229241)],
        &[(0b01001, &ENTRY_DEMONIZES_6258438652449642743)],
        &[(0b01001, &ENTRY_DEMONIZING_8343923659206792410)],
    ],
    range: 3..=10,
};

static VARS_DEMOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMOC_CHILDREN),
    value: None,
};

pub static VARS_DEMOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ratisation"),
        dictgen::InsensitiveStr::Ascii("ratisations"),
        dictgen::InsensitiveStr::Ascii("ratise"),
        dictgen::InsensitiveStr::Ascii("ratised"),
        dictgen::InsensitiveStr::Ascii("ratiser"),
        dictgen::InsensitiveStr::Ascii("ratises"),
        dictgen::InsensitiveStr::Ascii("ratising"),
        dictgen::InsensitiveStr::Ascii("ratization"),
        dictgen::InsensitiveStr::Ascii("ratizations"),
        dictgen::InsensitiveStr::Ascii("ratize"),
        dictgen::InsensitiveStr::Ascii("ratized"),
        dictgen::InsensitiveStr::Ascii("ratizer"),
        dictgen::InsensitiveStr::Ascii("ratizes"),
        dictgen::InsensitiveStr::Ascii("ratizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMOCRATIZATION_14834678678990587615)],
        &[(0b10010, &ENTRY_DEMOCRATIZATIONS_3121981811677706660)],
        &[(0b10010, &ENTRY_DEMOCRATIZE_14651228604547676688)],
        &[(0b10010, &ENTRY_DEMOCRATIZED_12561497189609834727)],
        &[(0b10010, &ENTRY_DEMOCRATIZER_7068896316951512081)],
        &[(0b10010, &ENTRY_DEMOCRATIZES_9683541385378161525)],
        &[(0b10010, &ENTRY_DEMOCRATIZING_17328231163322967219)],
        &[(0b01001, &ENTRY_DEMOCRATIZATION_14834678678990587615)],
        &[(0b01001, &ENTRY_DEMOCRATIZATIONS_3121981811677706660)],
        &[(0b01001, &ENTRY_DEMOCRATIZE_14651228604547676688)],
        &[(0b01001, &ENTRY_DEMOCRATIZED_12561497189609834727)],
        &[(0b01001, &ENTRY_DEMOCRATIZER_7068896316951512081)],
        &[(0b01001, &ENTRY_DEMOCRATIZES_9683541385378161525)],
        &[(0b01001, &ENTRY_DEMOCRATIZING_17328231163322967219)],
    ],
    range: 6..=11,
};

static VARS_DEMOB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMOB_CHILDREN),
    value: None,
};

pub static VARS_DEMOB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMOBILIZATION_1049482128993581914)],
        &[(0b10010, &ENTRY_DEMOBILIZATIONS_13060676951440773109)],
        &[(0b10010, &ENTRY_DEMOBILIZE_14631658221062411664)],
        &[(0b10010, &ENTRY_DEMOBILIZED_17675606354573049345)],
        &[(0b10010, &ENTRY_DEMOBILIZES_10953083886563254885)],
        &[(0b10010, &ENTRY_DEMOBILIZING_12570129016674680770)],
        &[(0b01001, &ENTRY_DEMOBILIZATION_1049482128993581914)],
        &[(0b01001, &ENTRY_DEMOBILIZATIONS_13060676951440773109)],
        &[(0b01001, &ENTRY_DEMOBILIZE_14631658221062411664)],
        &[(0b01001, &ENTRY_DEMOBILIZED_17675606354573049345)],
        &[(0b01001, &ENTRY_DEMOBILIZES_10953083886563254885)],
        &[(0b01001, &ENTRY_DEMOBILIZING_12570129016674680770)],
    ],
    range: 5..=10,
};

static VARS_DEMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMI_CHILDREN),
    value: None,
};

pub static VARS_DEMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("litarisation"),
        dictgen::InsensitiveStr::Ascii("litarisations"),
        dictgen::InsensitiveStr::Ascii("litarise"),
        dictgen::InsensitiveStr::Ascii("litarised"),
        dictgen::InsensitiveStr::Ascii("litarises"),
        dictgen::InsensitiveStr::Ascii("litarising"),
        dictgen::InsensitiveStr::Ascii("litarization"),
        dictgen::InsensitiveStr::Ascii("litarizations"),
        dictgen::InsensitiveStr::Ascii("litarize"),
        dictgen::InsensitiveStr::Ascii("litarized"),
        dictgen::InsensitiveStr::Ascii("litarizes"),
        dictgen::InsensitiveStr::Ascii("litarizing"),
        dictgen::InsensitiveStr::Ascii("luster"),
        dictgen::InsensitiveStr::Ascii("lustre"),
        dictgen::InsensitiveStr::Ascii("neralisation"),
        dictgen::InsensitiveStr::Ascii("neralisations"),
        dictgen::InsensitiveStr::Ascii("neralise"),
        dictgen::InsensitiveStr::Ascii("neralised"),
        dictgen::InsensitiveStr::Ascii("neraliser"),
        dictgen::InsensitiveStr::Ascii("neralises"),
        dictgen::InsensitiveStr::Ascii("neralising"),
        dictgen::InsensitiveStr::Ascii("neralization"),
        dictgen::InsensitiveStr::Ascii("neralizations"),
        dictgen::InsensitiveStr::Ascii("neralize"),
        dictgen::InsensitiveStr::Ascii("neralized"),
        dictgen::InsensitiveStr::Ascii("neralizer"),
        dictgen::InsensitiveStr::Ascii("neralizes"),
        dictgen::InsensitiveStr::Ascii("neralizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMILITARIZATION_8640733064988757472)],
        &[(0b10010, &ENTRY_DEMILITARIZATIONS_13863377781587784313)],
        &[(0b10010, &ENTRY_DEMILITARIZE_5838068700068012783)],
        &[(0b10010, &ENTRY_DEMILITARIZED_4980413846043795380)],
        &[(0b10010, &ENTRY_DEMILITARIZES_1164840116130396010)],
        &[(0b10010, &ENTRY_DEMILITARIZING_994064454433057567)],
        &[(0b01001, &ENTRY_DEMILITARIZATION_8640733064988757472)],
        &[(0b01001, &ENTRY_DEMILITARIZATIONS_13863377781587784313)],
        &[(0b01001, &ENTRY_DEMILITARIZE_5838068700068012783)],
        &[(0b01001, &ENTRY_DEMILITARIZED_4980413846043795380)],
        &[(0b01001, &ENTRY_DEMILITARIZES_1164840116130396010)],
        &[(0b01001, &ENTRY_DEMILITARIZING_994064454433057567)],
        &[(0b00001, &ENTRY_DEMILUSTER_18132679498143227517)],
        &[(0b11010, &ENTRY_DEMILUSTER_18132679498143227517)],
        &[(0b10010, &ENTRY_DEMINERALIZATION_3724123166587453242)],
        &[(0b10010, &ENTRY_DEMINERALIZATIONS_3572117260520975819)],
        &[(0b10010, &ENTRY_DEMINERALIZE_11805613081665284275)],
        &[(0b10010, &ENTRY_DEMINERALIZED_5889760188783683563)],
        &[(0b10010, &ENTRY_DEMINERALIZER_5594003650129551989)],
        &[(0b10010, &ENTRY_DEMINERALIZES_7031323467048546237)],
        &[(0b10010, &ENTRY_DEMINERALIZING_17818456458860291247)],
        &[(0b01001, &ENTRY_DEMINERALIZATION_3724123166587453242)],
        &[(0b01001, &ENTRY_DEMINERALIZATIONS_3572117260520975819)],
        &[(0b01001, &ENTRY_DEMINERALIZE_11805613081665284275)],
        &[(0b01001, &ENTRY_DEMINERALIZED_5889760188783683563)],
        &[(0b01001, &ENTRY_DEMINERALIZER_5594003650129551989)],
        &[(0b01001, &ENTRY_DEMINERALIZES_7031323467048546237)],
        &[(0b01001, &ENTRY_DEMINERALIZING_17818456458860291247)],
    ],
    range: 6..=13,
};

static VARS_DEME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEME_CHILDREN),
    value: None,
};

pub static VARS_DEME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anor"),
        dictgen::InsensitiveStr::Ascii("anors"),
        dictgen::InsensitiveStr::Ascii("anour"),
        dictgen::InsensitiveStr::Ascii("anours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_DEMEANOR_16422703697064073325)],
        &[(0b11001, &ENTRY_DEMEANORS_7209163777589536912)],
        &[(0b11010, &ENTRY_DEMEANOR_16422703697064073325)],
        &[(0b11010, &ENTRY_DEMEANORS_7209163777589536912)],
    ],
    range: 4..=6,
};

static VARS_DEMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMA_CHILDREN),
    value: None,
};

pub static VARS_DEMA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gnetisable"),
        dictgen::InsensitiveStr::Ascii("gnetisabler"),
        dictgen::InsensitiveStr::Ascii("gnetisables"),
        dictgen::InsensitiveStr::Ascii("gnetisablest"),
        dictgen::InsensitiveStr::Ascii("gnetisation"),
        dictgen::InsensitiveStr::Ascii("gnetisations"),
        dictgen::InsensitiveStr::Ascii("gnetise"),
        dictgen::InsensitiveStr::Ascii("gnetised"),
        dictgen::InsensitiveStr::Ascii("gnetiser"),
        dictgen::InsensitiveStr::Ascii("gnetisers"),
        dictgen::InsensitiveStr::Ascii("gnetises"),
        dictgen::InsensitiveStr::Ascii("gnetising"),
        dictgen::InsensitiveStr::Ascii("gnetizable"),
        dictgen::InsensitiveStr::Ascii("gnetizabler"),
        dictgen::InsensitiveStr::Ascii("gnetizables"),
        dictgen::InsensitiveStr::Ascii("gnetizablest"),
        dictgen::InsensitiveStr::Ascii("gnetization"),
        dictgen::InsensitiveStr::Ascii("gnetizations"),
        dictgen::InsensitiveStr::Ascii("gnetize"),
        dictgen::InsensitiveStr::Ascii("gnetized"),
        dictgen::InsensitiveStr::Ascii("gnetizer"),
        dictgen::InsensitiveStr::Ascii("gnetizers"),
        dictgen::InsensitiveStr::Ascii("gnetizes"),
        dictgen::InsensitiveStr::Ascii("gnetizing"),
        dictgen::InsensitiveStr::Ascii("gog"),
        dictgen::InsensitiveStr::Ascii("goged"),
        dictgen::InsensitiveStr::Ascii("goging"),
        dictgen::InsensitiveStr::Ascii("gogry"),
        dictgen::InsensitiveStr::Ascii("gogs"),
        dictgen::InsensitiveStr::Ascii("sculinisation"),
        dictgen::InsensitiveStr::Ascii("sculinise"),
        dictgen::InsensitiveStr::Ascii("sculinised"),
        dictgen::InsensitiveStr::Ascii("sculinising"),
        dictgen::InsensitiveStr::Ascii("sculinization"),
        dictgen::InsensitiveStr::Ascii("sculinize"),
        dictgen::InsensitiveStr::Ascii("sculinized"),
        dictgen::InsensitiveStr::Ascii("sculinizing"),
        dictgen::InsensitiveStr::Ascii("terialisation"),
        dictgen::InsensitiveStr::Ascii("terialisations"),
        dictgen::InsensitiveStr::Ascii("terialise"),
        dictgen::InsensitiveStr::Ascii("terialised"),
        dictgen::InsensitiveStr::Ascii("terialises"),
        dictgen::InsensitiveStr::Ascii("terialising"),
        dictgen::InsensitiveStr::Ascii("terialization"),
        dictgen::InsensitiveStr::Ascii("terializations"),
        dictgen::InsensitiveStr::Ascii("terialize"),
        dictgen::InsensitiveStr::Ascii("terialized"),
        dictgen::InsensitiveStr::Ascii("terializes"),
        dictgen::InsensitiveStr::Ascii("terializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMAGNETIZABLE_18071482520159508890)],
        &[(0b10010, &ENTRY_DEMAGNETIZABLER_5023249495266689114)],
        &[(0b10010, &ENTRY_DEMAGNETIZABLES_12807792172235133470)],
        &[(0b10010, &ENTRY_DEMAGNETIZABLEST_12541438993123223292)],
        &[(0b10010, &ENTRY_DEMAGNETIZATION_8660626408268068192)],
        &[(0b10010, &ENTRY_DEMAGNETIZATIONS_6017739735415397589)],
        &[(0b10010, &ENTRY_DEMAGNETIZE_14716676657435015384)],
        &[(0b10010, &ENTRY_DEMAGNETIZED_16278014960965990808)],
        &[(0b10010, &ENTRY_DEMAGNETIZER_4728434350800689036)],
        &[(0b10010, &ENTRY_DEMAGNETIZERS_931034885365981384)],
        &[(0b10010, &ENTRY_DEMAGNETIZES_677533597345689814)],
        &[(0b10010, &ENTRY_DEMAGNETIZING_11214913343744584233)],
        &[(0b01001, &ENTRY_DEMAGNETIZABLE_18071482520159508890)],
        &[(0b01001, &ENTRY_DEMAGNETIZABLER_5023249495266689114)],
        &[(0b01001, &ENTRY_DEMAGNETIZABLES_12807792172235133470)],
        &[(0b01001, &ENTRY_DEMAGNETIZABLEST_12541438993123223292)],
        &[(0b01001, &ENTRY_DEMAGNETIZATION_8660626408268068192)],
        &[(0b01001, &ENTRY_DEMAGNETIZATIONS_6017739735415397589)],
        &[(0b01001, &ENTRY_DEMAGNETIZE_14716676657435015384)],
        &[(0b01001, &ENTRY_DEMAGNETIZED_16278014960965990808)],
        &[(0b01001, &ENTRY_DEMAGNETIZER_4728434350800689036)],
        &[(0b01001, &ENTRY_DEMAGNETIZERS_931034885365981384)],
        &[(0b01001, &ENTRY_DEMAGNETIZES_677533597345689814)],
        &[(0b01001, &ENTRY_DEMAGNETIZING_11214913343744584233)],
        &[(0b00001, &ENTRY_DEMAGOGUE_8651813563125313987)],
        &[(0b00001, &ENTRY_DEMAGOGUED_3536597591189504210)],
        &[(0b00001, &ENTRY_DEMAGOGUING_15979024284168235826)],
        &[(0b00001, &ENTRY_DEMAGOGUERY_1494206203290122461)],
        &[(0b00001, &ENTRY_DEMAGOGUES_15335780932382092242)],
        &[(0b10010, &ENTRY_DEMASCULINIZATION_213789906363297959)],
        &[(0b10010, &ENTRY_DEMASCULINIZE_1597494522680282305)],
        &[(0b10010, &ENTRY_DEMASCULINIZED_12911696497389015826)],
        &[(0b10010, &ENTRY_DEMASCULINIZING_1729668073021130975)],
        &[(0b01001, &ENTRY_DEMASCULINIZATION_213789906363297959)],
        &[(0b01001, &ENTRY_DEMASCULINIZE_1597494522680282305)],
        &[(0b01001, &ENTRY_DEMASCULINIZED_12911696497389015826)],
        &[(0b01001, &ENTRY_DEMASCULINIZING_1729668073021130975)],
        &[(0b10010, &ENTRY_DEMATERIALIZATION_6643468176116888919)],
        &[(0b10010, &ENTRY_DEMATERIALIZATIONS_9448622588126109210)],
        &[(0b10010, &ENTRY_DEMATERIALIZE_5188464319891499632)],
        &[(0b10010, &ENTRY_DEMATERIALIZED_13253413423231441157)],
        &[(0b10010, &ENTRY_DEMATERIALIZES_5270284454646712513)],
        &[(0b10010, &ENTRY_DEMATERIALIZING_4105956654256703819)],
        &[(0b01001, &ENTRY_DEMATERIALIZATION_6643468176116888919)],
        &[(0b01001, &ENTRY_DEMATERIALIZATIONS_9448622588126109210)],
        &[(0b01001, &ENTRY_DEMATERIALIZE_5188464319891499632)],
        &[(0b01001, &ENTRY_DEMATERIALIZED_13253413423231441157)],
        &[(0b01001, &ENTRY_DEMATERIALIZES_5270284454646712513)],
        &[(0b01001, &ENTRY_DEMATERIALIZING_4105956654256703819)],
    ],
    range: 3..=14,
};

static VARS_DEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEL_CHILDREN),
    value: None,
};

pub static VARS_DEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("imitise"),
        dictgen::InsensitiveStr::Ascii("imitises"),
        dictgen::InsensitiveStr::Ascii("imitize"),
        dictgen::InsensitiveStr::Ascii("imitizes"),
        dictgen::InsensitiveStr::Ascii("ocalisation"),
        dictgen::InsensitiveStr::Ascii("ocalisations"),
        dictgen::InsensitiveStr::Ascii("ocalise"),
        dictgen::InsensitiveStr::Ascii("ocalised"),
        dictgen::InsensitiveStr::Ascii("ocalises"),
        dictgen::InsensitiveStr::Ascii("ocalising"),
        dictgen::InsensitiveStr::Ascii("ocalization"),
        dictgen::InsensitiveStr::Ascii("ocalizations"),
        dictgen::InsensitiveStr::Ascii("ocalize"),
        dictgen::InsensitiveStr::Ascii("ocalized"),
        dictgen::InsensitiveStr::Ascii("ocalizes"),
        dictgen::InsensitiveStr::Ascii("ocalizing"),
        dictgen::InsensitiveStr::Ascii("uster"),
        dictgen::InsensitiveStr::Ascii("ustre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DELIMITIZE_6280786742056797343)],
        &[(0b10010, &ENTRY_DELIMITIZES_5856258726008705246)],
        &[(0b01001, &ENTRY_DELIMITIZE_6280786742056797343)],
        &[(0b01001, &ENTRY_DELIMITIZES_5856258726008705246)],
        &[(0b10010, &ENTRY_DELOCALIZATION_3872128840219390827)],
        &[(0b10010, &ENTRY_DELOCALIZATIONS_11207793221550956501)],
        &[(0b10010, &ENTRY_DELOCALIZE_2924961970509538366)],
        &[(0b10010, &ENTRY_DELOCALIZED_17487743123281665827)],
        &[(0b10010, &ENTRY_DELOCALIZES_1352875521634188136)],
        &[(0b10010, &ENTRY_DELOCALIZING_18066483905901400466)],
        &[(0b01001, &ENTRY_DELOCALIZATION_3872128840219390827)],
        &[(0b01001, &ENTRY_DELOCALIZATIONS_11207793221550956501)],
        &[(0b01001, &ENTRY_DELOCALIZE_2924961970509538366)],
        &[(0b01001, &ENTRY_DELOCALIZED_17487743123281665827)],
        &[(0b01001, &ENTRY_DELOCALIZES_1352875521634188136)],
        &[(0b01001, &ENTRY_DELOCALIZING_18066483905901400466)],
        &[(0b00001, &ENTRY_DELUSTER_5748786244898572324)],
        &[(0b11010, &ENTRY_DELUSTER_5748786244898572324)],
    ],
    range: 5..=12,
};

static VARS_DEK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEK_CHILDREN),
    value: None,
};

pub static VARS_DEK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aliter"),
        dictgen::InsensitiveStr::Ascii("aliters"),
        dictgen::InsensitiveStr::Ascii("ameter"),
        dictgen::InsensitiveStr::Ascii("ameters"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DEKALITER_11207981744248149263)],
        &[(0b00001, &ENTRY_DEKALITERS_740321635385073637)],
        &[(0b00001, &ENTRY_DEKAMETER_1569515849500939883)],
        &[(0b00001, &ENTRY_DEKAMETERS_10451263896199436858)],
    ],
    range: 6..=7,
};

static VARS_DEI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEI_CHILDREN),
    value: None,
};

pub static VARS_DEI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ndustrialisation"),
        dictgen::InsensitiveStr::Ascii("ndustrialisations"),
        dictgen::InsensitiveStr::Ascii("ndustrialise"),
        dictgen::InsensitiveStr::Ascii("ndustrialised"),
        dictgen::InsensitiveStr::Ascii("ndustrialises"),
        dictgen::InsensitiveStr::Ascii("ndustrialising"),
        dictgen::InsensitiveStr::Ascii("ndustrialization"),
        dictgen::InsensitiveStr::Ascii("ndustrializations"),
        dictgen::InsensitiveStr::Ascii("ndustrialize"),
        dictgen::InsensitiveStr::Ascii("ndustrialized"),
        dictgen::InsensitiveStr::Ascii("ndustrializes"),
        dictgen::InsensitiveStr::Ascii("ndustrializing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEINDUSTRIALIZATION_6387275550903659107)],
        &[(0b10010, &ENTRY_DEINDUSTRIALIZATIONS_2772884714504552706)],
        &[(0b10010, &ENTRY_DEINDUSTRIALIZE_1319190901834187810)],
        &[(0b10010, &ENTRY_DEINDUSTRIALIZED_16089090941805878059)],
        &[(0b10010, &ENTRY_DEINDUSTRIALIZES_4178419714956693675)],
        &[(0b10010, &ENTRY_DEINDUSTRIALIZING_499895641188650261)],
        &[(0b01001, &ENTRY_DEINDUSTRIALIZATION_6387275550903659107)],
        &[(0b01001, &ENTRY_DEINDUSTRIALIZATIONS_2772884714504552706)],
        &[(0b01001, &ENTRY_DEINDUSTRIALIZE_1319190901834187810)],
        &[(0b01001, &ENTRY_DEINDUSTRIALIZED_16089090941805878059)],
        &[(0b01001, &ENTRY_DEINDUSTRIALIZES_4178419714956693675)],
        &[(0b01001, &ENTRY_DEINDUSTRIALIZING_499895641188650261)],
        &[(0b10010, &ENTRY_DEIONIZATION_8915428723312142234)],
        &[(0b10010, &ENTRY_DEIONIZE_338398712613893588)],
        &[(0b10010, &ENTRY_DEIONIZED_10491202019791607626)],
        &[(0b10010, &ENTRY_DEIONIZES_10200275155305727895)],
        &[(0b10010, &ENTRY_DEIONIZING_16611163248873983172)],
        &[(0b01001, &ENTRY_DEIONIZATION_8915428723312142234)],
        &[(0b01001, &ENTRY_DEIONIZE_338398712613893588)],
        &[(0b01001, &ENTRY_DEIONIZED_10491202019791607626)],
        &[(0b01001, &ENTRY_DEIONIZES_10200275155305727895)],
        &[(0b01001, &ENTRY_DEIONIZING_16611163248873983172)],
    ],
    range: 5..=17,
};

static VARS_DEH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEH_CHILDREN),
    value: None,
};

pub static VARS_DEH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("umanisation"),
        dictgen::InsensitiveStr::Ascii("umanisations"),
        dictgen::InsensitiveStr::Ascii("umanise"),
        dictgen::InsensitiveStr::Ascii("umanised"),
        dictgen::InsensitiveStr::Ascii("umanises"),
        dictgen::InsensitiveStr::Ascii("umanising"),
        dictgen::InsensitiveStr::Ascii("umanization"),
        dictgen::InsensitiveStr::Ascii("umanizations"),
        dictgen::InsensitiveStr::Ascii("umanize"),
        dictgen::InsensitiveStr::Ascii("umanized"),
        dictgen::InsensitiveStr::Ascii("umanizes"),
        dictgen::InsensitiveStr::Ascii("umanizing"),
        dictgen::InsensitiveStr::Ascii("ydrogenisation"),
        dictgen::InsensitiveStr::Ascii("ydrogenise"),
        dictgen::InsensitiveStr::Ascii("ydrogenised"),
        dictgen::InsensitiveStr::Ascii("ydrogeniser"),
        dictgen::InsensitiveStr::Ascii("ydrogenising"),
        dictgen::InsensitiveStr::Ascii("ydrogenization"),
        dictgen::InsensitiveStr::Ascii("ydrogenize"),
        dictgen::InsensitiveStr::Ascii("ydrogenized"),
        dictgen::InsensitiveStr::Ascii("ydrogenizer"),
        dictgen::InsensitiveStr::Ascii("ydrogenizing"),
        dictgen::InsensitiveStr::Ascii("ypnotisation"),
        dictgen::InsensitiveStr::Ascii("ypnotisations"),
        dictgen::InsensitiveStr::Ascii("ypnotise"),
        dictgen::InsensitiveStr::Ascii("ypnotised"),
        dictgen::InsensitiveStr::Ascii("ypnotises"),
        dictgen::InsensitiveStr::Ascii("ypnotising"),
        dictgen::InsensitiveStr::Ascii("ypnotization"),
        dictgen::InsensitiveStr::Ascii("ypnotizations"),
        dictgen::InsensitiveStr::Ascii("ypnotize"),
        dictgen::InsensitiveStr::Ascii("ypnotized"),
        dictgen::InsensitiveStr::Ascii("ypnotizes"),
        dictgen::InsensitiveStr::Ascii("ypnotizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEHUMANIZATION_8203365336341231524)],
        &[(0b10010, &ENTRY_DEHUMANIZATIONS_12753893729327325578)],
        &[(0b10010, &ENTRY_DEHUMANIZE_18142286574789231038)],
        &[(0b10010, &ENTRY_DEHUMANIZED_6478369645453909211)],
        &[(0b10010, &ENTRY_DEHUMANIZES_7224437139012646110)],
        &[(0b10010, &ENTRY_DEHUMANIZING_9897055991255710061)],
        &[(0b01001, &ENTRY_DEHUMANIZATION_8203365336341231524)],
        &[(0b01001, &ENTRY_DEHUMANIZATIONS_12753893729327325578)],
        &[(0b01001, &ENTRY_DEHUMANIZE_18142286574789231038)],
        &[(0b01001, &ENTRY_DEHUMANIZED_6478369645453909211)],
        &[(0b01001, &ENTRY_DEHUMANIZES_7224437139012646110)],
        &[(0b01001, &ENTRY_DEHUMANIZING_9897055991255710061)],
        &[(0b10010, &ENTRY_DEHYDROGENIZATION_7598177451677061196)],
        &[(0b10010, &ENTRY_DEHYDROGENIZE_15631606377798495147)],
        &[(0b10010, &ENTRY_DEHYDROGENIZED_13134561750473254133)],
        &[(0b10010, &ENTRY_DEHYDROGENIZER_8350907719907519200)],
        &[(0b10010, &ENTRY_DEHYDROGENIZING_9609271904194973996)],
        &[(0b01001, &ENTRY_DEHYDROGENIZATION_7598177451677061196)],
        &[(0b01001, &ENTRY_DEHYDROGENIZE_15631606377798495147)],
        &[(0b01001, &ENTRY_DEHYDROGENIZED_13134561750473254133)],
        &[(0b01001, &ENTRY_DEHYDROGENIZER_8350907719907519200)],
        &[(0b01001, &ENTRY_DEHYDROGENIZING_9609271904194973996)],
        &[(0b10010, &ENTRY_DEHYPNOTIZATION_11425386795669592923)],
        &[(0b10010, &ENTRY_DEHYPNOTIZATIONS_1374277010264346868)],
        &[(0b10010, &ENTRY_DEHYPNOTIZE_3485990394993698329)],
        &[(0b10010, &ENTRY_DEHYPNOTIZED_4122447499004441152)],
        &[(0b10010, &ENTRY_DEHYPNOTIZES_4660291758322276947)],
        &[(0b10010, &ENTRY_DEHYPNOTIZING_9093004215936393024)],
        &[(0b01001, &ENTRY_DEHYPNOTIZATION_11425386795669592923)],
        &[(0b01001, &ENTRY_DEHYPNOTIZATIONS_1374277010264346868)],
        &[(0b01001, &ENTRY_DEHYPNOTIZE_3485990394993698329)],
        &[(0b01001, &ENTRY_DEHYPNOTIZED_4122447499004441152)],
        &[(0b01001, &ENTRY_DEHYPNOTIZES_4660291758322276947)],
        &[(0b01001, &ENTRY_DEHYPNOTIZING_9093004215936393024)],
    ],
    range: 7..=14,
};

static VARS_DEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEG_CHILDREN),
    value: None,
};

pub static VARS_DEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lycerolised"),
        dictgen::InsensitiveStr::Ascii("lycerolized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEGLYCEROLIZED_17745076794910422475)],
        &[(0b01001, &ENTRY_DEGLYCEROLIZED_17745076794910422475)],
    ],
    range: 11..=11,
};

static VARS_DEF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DEF_CHILDREN),
    value: None,
};

static VARS_DEF_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_DEFE_NODE),
    None,
    None,
    None,
    Some(&VARS_DEFI_NODE),
    None,
    None,
    Some(&VARS_DEFL_NODE),
    None,
    None,
    Some(&VARS_DEFO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DEFU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_DEFU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEFU_CHILDREN),
    value: None,
};

pub static VARS_DEFU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nctionalisation"),
        dictgen::InsensitiveStr::Ascii("nctionalisations"),
        dictgen::InsensitiveStr::Ascii("nctionalise"),
        dictgen::InsensitiveStr::Ascii("nctionalises"),
        dictgen::InsensitiveStr::Ascii("nctionalization"),
        dictgen::InsensitiveStr::Ascii("nctionalizations"),
        dictgen::InsensitiveStr::Ascii("nctionalize"),
        dictgen::InsensitiveStr::Ascii("nctionalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEFUNCTIONALIZATION_6513191605029783649)],
        &[(0b10010, &ENTRY_DEFUNCTIONALIZATIONS_2498662966774747713)],
        &[(0b10010, &ENTRY_DEFUNCTIONALIZE_10852668215621257147)],
        &[(0b10010, &ENTRY_DEFUNCTIONALIZES_8234850659392060612)],
        &[(0b01001, &ENTRY_DEFUNCTIONALIZATION_6513191605029783649)],
        &[(0b01001, &ENTRY_DEFUNCTIONALIZATIONS_2498662966774747713)],
        &[(0b01001, &ENTRY_DEFUNCTIONALIZE_10852668215621257147)],
        &[(0b01001, &ENTRY_DEFUNCTIONALIZES_8234850659392060612)],
    ],
    range: 11..=16,
};

static VARS_DEFO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEFO_CHILDREN),
    value: None,
};

pub static VARS_DEFO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edation"),
        dictgen::InsensitiveStr::Ascii("rmalise"),
        dictgen::InsensitiveStr::Ascii("rmalize"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DEFEDATION_7684726192530482845)],
        &[(0b10010, &ENTRY_DEFORMALIZE_729735874124230446)],
        &[(0b01001, &ENTRY_DEFORMALIZE_729735874124230446)],
    ],
    range: 7..=7,
};

static VARS_DEFL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEFL_CHILDREN),
    value: None,
};

pub static VARS_DEFL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectionisation"),
        dictgen::InsensitiveStr::Ascii("ectionisations"),
        dictgen::InsensitiveStr::Ascii("ectionise"),
        dictgen::InsensitiveStr::Ascii("ectionises"),
        dictgen::InsensitiveStr::Ascii("ectionization"),
        dictgen::InsensitiveStr::Ascii("ectionizations"),
        dictgen::InsensitiveStr::Ascii("ectionize"),
        dictgen::InsensitiveStr::Ascii("ectionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEFLECTIONIZATION_5301497873748261232)],
        &[(0b10010, &ENTRY_DEFLECTIONIZATIONS_17596193550921436107)],
        &[(0b10010, &ENTRY_DEFLECTIONIZE_14639492675276732860)],
        &[(0b10010, &ENTRY_DEFLECTIONIZES_304679022130280223)],
        &[(0b01001, &ENTRY_DEFLECTIONIZATION_5301497873748261232)],
        &[(0b01001, &ENTRY_DEFLECTIONIZATIONS_17596193550921436107)],
        &[(0b01001, &ENTRY_DEFLECTIONIZE_14639492675276732860)],
        &[(0b01001, &ENTRY_DEFLECTIONIZES_304679022130280223)],
    ],
    range: 9..=14,
};

static VARS_DEFI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEFI_CHILDREN),
    value: None,
};

pub static VARS_DEFI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("brinise"),
        dictgen::InsensitiveStr::Ascii("brinised"),
        dictgen::InsensitiveStr::Ascii("brinises"),
        dictgen::InsensitiveStr::Ascii("brinising"),
        dictgen::InsensitiveStr::Ascii("brinize"),
        dictgen::InsensitiveStr::Ascii("brinized"),
        dictgen::InsensitiveStr::Ascii("brinizes"),
        dictgen::InsensitiveStr::Ascii("brinizing"),
        dictgen::InsensitiveStr::Ascii("nitisation"),
        dictgen::InsensitiveStr::Ascii("nitisations"),
        dictgen::InsensitiveStr::Ascii("nitise"),
        dictgen::InsensitiveStr::Ascii("nitised"),
        dictgen::InsensitiveStr::Ascii("nitises"),
        dictgen::InsensitiveStr::Ascii("nitising"),
        dictgen::InsensitiveStr::Ascii("nitization"),
        dictgen::InsensitiveStr::Ascii("nitizations"),
        dictgen::InsensitiveStr::Ascii("nitize"),
        dictgen::InsensitiveStr::Ascii("nitized"),
        dictgen::InsensitiveStr::Ascii("nitizes"),
        dictgen::InsensitiveStr::Ascii("nitizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEFIBRINIZE_14420334367184791100)],
        &[(0b10010, &ENTRY_DEFIBRINIZED_1290929009543001059)],
        &[(0b10010, &ENTRY_DEFIBRINIZES_2604624886224030465)],
        &[(0b10010, &ENTRY_DEFIBRINIZING_14003929221742906824)],
        &[(0b01001, &ENTRY_DEFIBRINIZE_14420334367184791100)],
        &[(0b01001, &ENTRY_DEFIBRINIZED_1290929009543001059)],
        &[(0b01001, &ENTRY_DEFIBRINIZES_2604624886224030465)],
        &[(0b01001, &ENTRY_DEFIBRINIZING_14003929221742906824)],
        &[(0b10010, &ENTRY_DEFINITIZATION_16248589342393728527)],
        &[(0b10010, &ENTRY_DEFINITIZATIONS_5870566431659215392)],
        &[(0b10010, &ENTRY_DEFINITIZE_7690090636180942716)],
        &[(0b10010, &ENTRY_DEFINITIZED_17126163171519985460)],
        &[(0b10010, &ENTRY_DEFINITIZES_1694150075299923326)],
        &[(0b10010, &ENTRY_DEFINITIZING_9576972500061726353)],
        &[(0b01001, &ENTRY_DEFINITIZATION_16248589342393728527)],
        &[(0b01001, &ENTRY_DEFINITIZATIONS_5870566431659215392)],
        &[(0b01001, &ENTRY_DEFINITIZE_7690090636180942716)],
        &[(0b01001, &ENTRY_DEFINITIZED_17126163171519985460)],
        &[(0b01001, &ENTRY_DEFINITIZES_1694150075299923326)],
        &[(0b01001, &ENTRY_DEFINITIZING_9576972500061726353)],
    ],
    range: 6..=11,
};

static VARS_DEFE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEFE_CHILDREN),
    value: None,
};

pub static VARS_DEFE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dation"),
        dictgen::InsensitiveStr::Ascii("minisation"),
        dictgen::InsensitiveStr::Ascii("minise"),
        dictgen::InsensitiveStr::Ascii("minised"),
        dictgen::InsensitiveStr::Ascii("minises"),
        dictgen::InsensitiveStr::Ascii("minising"),
        dictgen::InsensitiveStr::Ascii("minization"),
        dictgen::InsensitiveStr::Ascii("minize"),
        dictgen::InsensitiveStr::Ascii("minized"),
        dictgen::InsensitiveStr::Ascii("minizes"),
        dictgen::InsensitiveStr::Ascii("minizing"),
        dictgen::InsensitiveStr::Ascii("nce"),
        dictgen::InsensitiveStr::Ascii("nced"),
        dictgen::InsensitiveStr::Ascii("nceless"),
        dictgen::InsensitiveStr::Ascii("ncelesser"),
        dictgen::InsensitiveStr::Ascii("ncelessest"),
        dictgen::InsensitiveStr::Ascii("ncelesslier"),
        dictgen::InsensitiveStr::Ascii("ncelessliest"),
        dictgen::InsensitiveStr::Ascii("ncelessly"),
        dictgen::InsensitiveStr::Ascii("ncelessness"),
        dictgen::InsensitiveStr::Ascii("ncelessnesses"),
        dictgen::InsensitiveStr::Ascii("nceman"),
        dictgen::InsensitiveStr::Ascii("ncemen"),
        dictgen::InsensitiveStr::Ascii("nces"),
        dictgen::InsensitiveStr::Ascii("ncing"),
        dictgen::InsensitiveStr::Ascii("nse"),
        dictgen::InsensitiveStr::Ascii("nsed"),
        dictgen::InsensitiveStr::Ascii("nseless"),
        dictgen::InsensitiveStr::Ascii("nselesser"),
        dictgen::InsensitiveStr::Ascii("nselessest"),
        dictgen::InsensitiveStr::Ascii("nselesslier"),
        dictgen::InsensitiveStr::Ascii("nselessliest"),
        dictgen::InsensitiveStr::Ascii("nselessly"),
        dictgen::InsensitiveStr::Ascii("nselessness"),
        dictgen::InsensitiveStr::Ascii("nselessnesses"),
        dictgen::InsensitiveStr::Ascii("nseman"),
        dictgen::InsensitiveStr::Ascii("nsemen"),
        dictgen::InsensitiveStr::Ascii("nses"),
        dictgen::InsensitiveStr::Ascii("nsing"),
        dictgen::InsensitiveStr::Ascii("udalise"),
        dictgen::InsensitiveStr::Ascii("udalised"),
        dictgen::InsensitiveStr::Ascii("udalises"),
        dictgen::InsensitiveStr::Ascii("udalising"),
        dictgen::InsensitiveStr::Ascii("udalize"),
        dictgen::InsensitiveStr::Ascii("udalized"),
        dictgen::InsensitiveStr::Ascii("udalizes"),
        dictgen::InsensitiveStr::Ascii("udalizing"),
    ],
    values: &[
        &[(0b10001, &ENTRY_DEFEDATION_7684726192530482845)],
        &[(0b10010, &ENTRY_DEFEMINIZATION_17125497262735349522)],
        &[(0b10010, &ENTRY_DEFEMINIZE_1452385300989253047)],
        &[(0b10010, &ENTRY_DEFEMINIZED_14147872800166298820)],
        &[(0b10010, &ENTRY_DEFEMINIZES_12654300795426353647)],
        &[(0b10010, &ENTRY_DEFEMINIZING_13788943719949840623)],
        &[(0b01001, &ENTRY_DEFEMINIZATION_17125497262735349522)],
        &[(0b01001, &ENTRY_DEFEMINIZE_1452385300989253047)],
        &[(0b01001, &ENTRY_DEFEMINIZED_14147872800166298820)],
        &[(0b01001, &ENTRY_DEFEMINIZES_12654300795426353647)],
        &[(0b01001, &ENTRY_DEFEMINIZING_13788943719949840623)],
        &[(0b11010, &ENTRY_DEFENSE_6661070793019776368)],
        &[(0b11010, &ENTRY_DEFENSED_10450678450925087448)],
        &[(0b11010, &ENTRY_DEFENSELESS_18055933219220277884)],
        &[(0b11010, &ENTRY_DEFENSELESSER_11231098921374350935)],
        &[(0b11010, &ENTRY_DEFENSELESSEST_11877359825751139498)],
        &[(0b11010, &ENTRY_DEFENSELESSLIER_9226167285723882730)],
        &[(0b11010, &ENTRY_DEFENSELESSLIEST_9146397922775201714)],
        &[(0b11010, &ENTRY_DEFENSELESSLY_11336139755398142135)],
        &[(0b11010, &ENTRY_DEFENSELESSNESS_2531659609001850832)],
        &[(0b11010, &ENTRY_DEFENSELESSNESSES_5028704575903983200)],
        &[(0b11010, &ENTRY_DEFENSEMAN_8101448990231531201)],
        &[(0b11010, &ENTRY_DEFENSEMEN_14899097357539129070)],
        &[(0b11010, &ENTRY_DEFENSES_10286318404274050577)],
        &[(0b11010, &ENTRY_DEFENSING_10107917169615339119)],
        &[(0b01001, &ENTRY_DEFENSE_6661070793019776368)],
        &[(0b01001, &ENTRY_DEFENSED_10450678450925087448)],
        &[(0b00001, &ENTRY_DEFENSELESS_18055933219220277884)],
        &[(0b00001, &ENTRY_DEFENSELESSER_11231098921374350935)],
        &[(0b00001, &ENTRY_DEFENSELESSEST_11877359825751139498)],
        &[(0b00001, &ENTRY_DEFENSELESSLIER_9226167285723882730)],
        &[(0b00001, &ENTRY_DEFENSELESSLIEST_9146397922775201714)],
        &[(0b00001, &ENTRY_DEFENSELESSLY_11336139755398142135)],
        &[(0b00001, &ENTRY_DEFENSELESSNESS_2531659609001850832)],
        &[(0b00001, &ENTRY_DEFENSELESSNESSES_5028704575903983200)],
        &[(0b00001, &ENTRY_DEFENSEMAN_8101448990231531201)],
        &[(0b00001, &ENTRY_DEFENSEMEN_14899097357539129070)],
        &[(0b01001, &ENTRY_DEFENSES_10286318404274050577)],
        &[(0b01001, &ENTRY_DEFENSING_10107917169615339119)],
        &[(0b10010, &ENTRY_DEFEUDALIZE_3615319173936225913)],
        &[(0b10010, &ENTRY_DEFEUDALIZED_9788529944065992059)],
        &[(0b10010, &ENTRY_DEFEUDALIZES_8395303255870377128)],
        &[(0b10010, &ENTRY_DEFEUDALIZING_16034778366842959566)],
        &[(0b01001, &ENTRY_DEFEUDALIZE_3615319173936225913)],
        &[(0b01001, &ENTRY_DEFEUDALIZED_9788529944065992059)],
        &[(0b01001, &ENTRY_DEFEUDALIZES_8395303255870377128)],
        &[(0b01001, &ENTRY_DEFEUDALIZING_16034778366842959566)],
    ],
    range: 3..=13,
};

static VARS_DEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEE_CHILDREN),
    value: None,
};

pub static VARS_DEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mphasisation"),
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasised"),
        dictgen::InsensitiveStr::Ascii("mphasiser"),
        dictgen::InsensitiveStr::Ascii("mphasisers"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasising"),
        dictgen::InsensitiveStr::Ascii("mphasization"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasized"),
        dictgen::InsensitiveStr::Ascii("mphasizer"),
        dictgen::InsensitiveStr::Ascii("mphasizers"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
        dictgen::InsensitiveStr::Ascii("mphasizing"),
        dictgen::InsensitiveStr::Ascii("nergise"),
        dictgen::InsensitiveStr::Ascii("nergised"),
        dictgen::InsensitiveStr::Ascii("nergiser"),
        dictgen::InsensitiveStr::Ascii("nergises"),
        dictgen::InsensitiveStr::Ascii("nergising"),
        dictgen::InsensitiveStr::Ascii("nergize"),
        dictgen::InsensitiveStr::Ascii("nergized"),
        dictgen::InsensitiveStr::Ascii("nergizer"),
        dictgen::InsensitiveStr::Ascii("nergizes"),
        dictgen::InsensitiveStr::Ascii("nergizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEEMPHASIZATION_6353956261442847002)],
        &[(0b10010, &ENTRY_DEEMPHASIZE_2081897672675351950)],
        &[(0b10010, &ENTRY_DEEMPHASIZED_12142584568291460608)],
        &[(0b10010, &ENTRY_DEEMPHASIZER_6108957853290475121)],
        &[(0b10010, &ENTRY_DEEMPHASIZERS_7007912895593682783)],
        &[(0b10010, &ENTRY_DEEMPHASIZES_13409957615967153812)],
        &[(0b10010, &ENTRY_DEEMPHASIZING_1840968374820826426)],
        &[(0b01001, &ENTRY_DEEMPHASIZATION_6353956261442847002)],
        &[(0b01001, &ENTRY_DEEMPHASIZE_2081897672675351950)],
        &[(0b01001, &ENTRY_DEEMPHASIZED_12142584568291460608)],
        &[(0b01001, &ENTRY_DEEMPHASIZER_6108957853290475121)],
        &[(0b01001, &ENTRY_DEEMPHASIZERS_7007912895593682783)],
        &[(0b01001, &ENTRY_DEEMPHASIZES_13409957615967153812)],
        &[(0b01001, &ENTRY_DEEMPHASIZING_1840968374820826426)],
        &[(0b10010, &ENTRY_DEENERGIZE_8887834988706607224)],
        &[(0b10010, &ENTRY_DEENERGIZED_5896164931005823934)],
        &[(0b10010, &ENTRY_DEENERGIZER_16176360588388947490)],
        &[(0b10010, &ENTRY_DEENERGIZES_15613252110879695341)],
        &[(0b10010, &ENTRY_DEENERGIZING_4306770013369809072)],
        &[(0b01001, &ENTRY_DEENERGIZE_8887834988706607224)],
        &[(0b01001, &ENTRY_DEENERGIZED_5896164931005823934)],
        &[(0b01001, &ENTRY_DEENERGIZER_16176360588388947490)],
        &[(0b01001, &ENTRY_DEENERGIZES_15613252110879695341)],
        &[(0b01001, &ENTRY_DEENERGIZING_4306770013369809072)],
    ],
    range: 7..=12,
};

static VARS_DED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DED_CHILDREN),
    value: None,
};

pub static VARS_DED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("al"),
        dictgen::InsensitiveStr::Ascii("alian"),
        dictgen::InsensitiveStr::Ascii("ramatise"),
        dictgen::InsensitiveStr::Ascii("ramatised"),
        dictgen::InsensitiveStr::Ascii("ramatises"),
        dictgen::InsensitiveStr::Ascii("ramatising"),
        dictgen::InsensitiveStr::Ascii("ramatize"),
        dictgen::InsensitiveStr::Ascii("ramatized"),
        dictgen::InsensitiveStr::Ascii("ramatizes"),
        dictgen::InsensitiveStr::Ascii("ramatizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DEDAL_5521769065882955150)],
        &[(0b00001, &ENTRY_DEDALIAN_8486751251745352405)],
        &[(0b10010, &ENTRY_DEDRAMATIZE_17445126165727154559)],
        &[(0b10010, &ENTRY_DEDRAMATIZED_12118161118064784971)],
        &[(0b10010, &ENTRY_DEDRAMATIZES_10320190471768337081)],
        &[(0b10010, &ENTRY_DEDRAMATIZING_6204364643863458996)],
        &[(0b01001, &ENTRY_DEDRAMATIZE_17445126165727154559)],
        &[(0b01001, &ENTRY_DEDRAMATIZED_12118161118064784971)],
        &[(0b01001, &ENTRY_DEDRAMATIZES_10320190471768337081)],
        &[(0b01001, &ENTRY_DEDRAMATIZING_6204364643863458996)],
    ],
    range: 2..=10,
};

static VARS_DEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DEC_CHILDREN),
    value: None,
};

static VARS_DEC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DECA_NODE),
    None,
    None,
    None,
    Some(&VARS_DECE_NODE),
    None,
    None,
    Some(&VARS_DECH_NODE),
    Some(&VARS_DECI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DECO_NODE),
    None,
    None,
    Some(&VARS_DECR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_DECR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DECR_CHILDREN),
    value: None,
};

pub static VARS_DECR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iminalisation"),
        dictgen::InsensitiveStr::Ascii("iminalisations"),
        dictgen::InsensitiveStr::Ascii("iminalise"),
        dictgen::InsensitiveStr::Ascii("iminalised"),
        dictgen::InsensitiveStr::Ascii("iminalises"),
        dictgen::InsensitiveStr::Ascii("iminalising"),
        dictgen::InsensitiveStr::Ascii("iminalization"),
        dictgen::InsensitiveStr::Ascii("iminalizations"),
        dictgen::InsensitiveStr::Ascii("iminalize"),
        dictgen::InsensitiveStr::Ascii("iminalized"),
        dictgen::InsensitiveStr::Ascii("iminalizes"),
        dictgen::InsensitiveStr::Ascii("iminalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DECRIMINALIZATION_10972189705541961663)],
        &[(0b10010, &ENTRY_DECRIMINALIZATIONS_12268289228613201569)],
        &[(0b10010, &ENTRY_DECRIMINALIZE_6677799413626987625)],
        &[(0b10010, &ENTRY_DECRIMINALIZED_5536378597888996415)],
        &[(0b10010, &ENTRY_DECRIMINALIZES_6555315341160373102)],
        &[(0b10010, &ENTRY_DECRIMINALIZING_6483531696781808568)],
        &[(0b01001, &ENTRY_DECRIMINALIZATION_10972189705541961663)],
        &[(0b01001, &ENTRY_DECRIMINALIZATIONS_12268289228613201569)],
        &[(0b01001, &ENTRY_DECRIMINALIZE_6677799413626987625)],
        &[(0b01001, &ENTRY_DECRIMINALIZED_5536378597888996415)],
        &[(0b01001, &ENTRY_DECRIMINALIZES_6555315341160373102)],
        &[(0b01001, &ENTRY_DECRIMINALIZING_6483531696781808568)],
    ],
    range: 9..=14,
};

static VARS_DECO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DECO_CHILDREN),
    value: None,
};

pub static VARS_DECO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lonisation"),
        dictgen::InsensitiveStr::Ascii("lonisations"),
        dictgen::InsensitiveStr::Ascii("lonise"),
        dictgen::InsensitiveStr::Ascii("lonised"),
        dictgen::InsensitiveStr::Ascii("lonises"),
        dictgen::InsensitiveStr::Ascii("lonising"),
        dictgen::InsensitiveStr::Ascii("lonization"),
        dictgen::InsensitiveStr::Ascii("lonizations"),
        dictgen::InsensitiveStr::Ascii("lonize"),
        dictgen::InsensitiveStr::Ascii("lonized"),
        dictgen::InsensitiveStr::Ascii("lonizes"),
        dictgen::InsensitiveStr::Ascii("lonizing"),
        dictgen::InsensitiveStr::Ascii("lor"),
        dictgen::InsensitiveStr::Ascii("lorant"),
        dictgen::InsensitiveStr::Ascii("lorants"),
        dictgen::InsensitiveStr::Ascii("lorate"),
        dictgen::InsensitiveStr::Ascii("lorated"),
        dictgen::InsensitiveStr::Ascii("lorates"),
        dictgen::InsensitiveStr::Ascii("loration"),
        dictgen::InsensitiveStr::Ascii("lorations"),
        dictgen::InsensitiveStr::Ascii("lored"),
        dictgen::InsensitiveStr::Ascii("lorimeter"),
        dictgen::InsensitiveStr::Ascii("loring"),
        dictgen::InsensitiveStr::Ascii("lorization"),
        dictgen::InsensitiveStr::Ascii("lorizations"),
        dictgen::InsensitiveStr::Ascii("lorize"),
        dictgen::InsensitiveStr::Ascii("lorized"),
        dictgen::InsensitiveStr::Ascii("lorizer"),
        dictgen::InsensitiveStr::Ascii("lorizers"),
        dictgen::InsensitiveStr::Ascii("lorizes"),
        dictgen::InsensitiveStr::Ascii("lorizing"),
        dictgen::InsensitiveStr::Ascii("lors"),
        dictgen::InsensitiveStr::Ascii("lour"),
        dictgen::InsensitiveStr::Ascii("lourant"),
        dictgen::InsensitiveStr::Ascii("lourants"),
        dictgen::InsensitiveStr::Ascii("lourate"),
        dictgen::InsensitiveStr::Ascii("lourated"),
        dictgen::InsensitiveStr::Ascii("lourates"),
        dictgen::InsensitiveStr::Ascii("louration"),
        dictgen::InsensitiveStr::Ascii("lourations"),
        dictgen::InsensitiveStr::Ascii("loured"),
        dictgen::InsensitiveStr::Ascii("lourimeter"),
        dictgen::InsensitiveStr::Ascii("louring"),
        dictgen::InsensitiveStr::Ascii("lourisation"),
        dictgen::InsensitiveStr::Ascii("lourisations"),
        dictgen::InsensitiveStr::Ascii("lourise"),
        dictgen::InsensitiveStr::Ascii("lourised"),
        dictgen::InsensitiveStr::Ascii("louriser"),
        dictgen::InsensitiveStr::Ascii("lourisers"),
        dictgen::InsensitiveStr::Ascii("lourises"),
        dictgen::InsensitiveStr::Ascii("lourising"),
        dictgen::InsensitiveStr::Ascii("lourization"),
        dictgen::InsensitiveStr::Ascii("lourizations"),
        dictgen::InsensitiveStr::Ascii("lourize"),
        dictgen::InsensitiveStr::Ascii("lourized"),
        dictgen::InsensitiveStr::Ascii("lourizer"),
        dictgen::InsensitiveStr::Ascii("lourizers"),
        dictgen::InsensitiveStr::Ascii("lourizes"),
        dictgen::InsensitiveStr::Ascii("lourizing"),
        dictgen::InsensitiveStr::Ascii("lours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DECOLONIZATION_1486129639809542135)],
        &[(0b10010, &ENTRY_DECOLONIZATIONS_15958442548094153342)],
        &[(0b10010, &ENTRY_DECOLONIZE_8186463036478425034)],
        &[(0b10010, &ENTRY_DECOLONIZED_4107643671609353888)],
        &[(0b10010, &ENTRY_DECOLONIZES_2371774017479885060)],
        &[(0b10010, &ENTRY_DECOLONIZING_9800590501891725470)],
        &[(0b01001, &ENTRY_DECOLONIZATION_1486129639809542135)],
        &[(0b01001, &ENTRY_DECOLONIZATIONS_15958442548094153342)],
        &[(0b01001, &ENTRY_DECOLONIZE_8186463036478425034)],
        &[(0b01001, &ENTRY_DECOLONIZED_4107643671609353888)],
        &[(0b01001, &ENTRY_DECOLONIZES_2371774017479885060)],
        &[(0b01001, &ENTRY_DECOLONIZING_9800590501891725470)],
        &[(0b11001, &ENTRY_DECOLOR_6014626123338999290)],
        &[(0b11001, &ENTRY_DECOLORANT_3559353327617165243)],
        &[(0b11001, &ENTRY_DECOLORANTS_8581787138873386831)],
        &[(0b00001, &ENTRY_DECOLORATE_7324915820614623145)],
        &[(0b00001, &ENTRY_DECOLORATED_15668109642110621999)],
        &[(0b00001, &ENTRY_DECOLORATES_16816468260998969475)],
        &[(0b00001, &ENTRY_DECOLORATION_11009565715119639809)],
        &[(0b00001, &ENTRY_DECOLORATIONS_1487931213239331011)],
        &[(0b11001, &ENTRY_DECOLORED_4538268430939537427)],
        &[(0b00001, &ENTRY_DECOLORIMETER_3508867565377467518)],
        &[(0b11001, &ENTRY_DECOLORING_1116088952225601804)],
        &[(0b00001, &ENTRY_DECOLORIZATION_16733480511994092682)],
        &[(0b00001, &ENTRY_DECOLORIZATIONS_3802618399074055478)],
        &[(0b00001, &ENTRY_DECOLORIZE_15634240403993874308)],
        &[(0b00001, &ENTRY_DECOLORIZED_4114104346884333601)],
        &[(0b00001, &ENTRY_DECOLORIZER_16745583175877494200)],
        &[(0b00001, &ENTRY_DECOLORIZERS_3539821653969419352)],
        &[(0b00001, &ENTRY_DECOLORIZES_2799250970864932246)],
        &[(0b00001, &ENTRY_DECOLORIZING_11469437894799461132)],
        &[(0b11001, &ENTRY_DECOLORS_11780774510706184579)],
        &[(0b11010, &ENTRY_DECOLOR_6014626123338999290)],
        &[(0b11010, &ENTRY_DECOLORANT_3559353327617165243)],
        &[(0b11010, &ENTRY_DECOLORANTS_8581787138873386831)],
        &[(0b11010, &ENTRY_DECOLORATE_7324915820614623145)],
        &[(0b11010, &ENTRY_DECOLORATED_15668109642110621999)],
        &[(0b11010, &ENTRY_DECOLORATES_16816468260998969475)],
        &[(0b11010, &ENTRY_DECOLORATION_11009565715119639809)],
        &[(0b11010, &ENTRY_DECOLORATIONS_1487931213239331011)],
        &[(0b11010, &ENTRY_DECOLORED_4538268430939537427)],
        &[(0b11010, &ENTRY_DECOLORIMETER_3508867565377467518)],
        &[(0b11010, &ENTRY_DECOLORING_1116088952225601804)],
        &[(0b10010, &ENTRY_DECOLORIZATION_16733480511994092682)],
        &[(0b10010, &ENTRY_DECOLORIZATIONS_3802618399074055478)],
        &[(0b10010, &ENTRY_DECOLORIZE_15634240403993874308)],
        &[(0b10010, &ENTRY_DECOLORIZED_4114104346884333601)],
        &[(0b10010, &ENTRY_DECOLORIZER_16745583175877494200)],
        &[(0b10010, &ENTRY_DECOLORIZERS_3539821653969419352)],
        &[(0b10010, &ENTRY_DECOLORIZES_2799250970864932246)],
        &[(0b10010, &ENTRY_DECOLORIZING_11469437894799461132)],
        &[(0b01000, &ENTRY_DECOLORIZATION_16733480511994092682)],
        &[(0b01000, &ENTRY_DECOLORIZATIONS_3802618399074055478)],
        &[(0b01000, &ENTRY_DECOLORIZE_15634240403993874308)],
        &[(0b01000, &ENTRY_DECOLORIZED_4114104346884333601)],
        &[(0b01000, &ENTRY_DECOLORIZER_16745583175877494200)],
        &[(0b01000, &ENTRY_DECOLORIZERS_3539821653969419352)],
        &[(0b01000, &ENTRY_DECOLORIZES_2799250970864932246)],
        &[(0b01000, &ENTRY_DECOLORIZING_11469437894799461132)],
        &[(0b11010, &ENTRY_DECOLORS_11780774510706184579)],
    ],
    range: 3..=12,
};

static VARS_DECI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DECI_CHILDREN),
    value: None,
};

pub static VARS_DECI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gramme"),
        dictgen::InsensitiveStr::Ascii("grammes"),
        dictgen::InsensitiveStr::Ascii("liter"),
        dictgen::InsensitiveStr::Ascii("liters"),
        dictgen::InsensitiveStr::Ascii("litre"),
        dictgen::InsensitiveStr::Ascii("litres"),
        dictgen::InsensitiveStr::Ascii("malisation"),
        dictgen::InsensitiveStr::Ascii("malisations"),
        dictgen::InsensitiveStr::Ascii("malise"),
        dictgen::InsensitiveStr::Ascii("malised"),
        dictgen::InsensitiveStr::Ascii("malises"),
        dictgen::InsensitiveStr::Ascii("malising"),
        dictgen::InsensitiveStr::Ascii("malization"),
        dictgen::InsensitiveStr::Ascii("malizations"),
        dictgen::InsensitiveStr::Ascii("malize"),
        dictgen::InsensitiveStr::Ascii("malized"),
        dictgen::InsensitiveStr::Ascii("malizes"),
        dictgen::InsensitiveStr::Ascii("malizing"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("meters"),
        dictgen::InsensitiveStr::Ascii("metre"),
        dictgen::InsensitiveStr::Ascii("metres"),
        dictgen::InsensitiveStr::Ascii("vilise"),
        dictgen::InsensitiveStr::Ascii("vilised"),
        dictgen::InsensitiveStr::Ascii("vilises"),
        dictgen::InsensitiveStr::Ascii("vilising"),
        dictgen::InsensitiveStr::Ascii("vilize"),
        dictgen::InsensitiveStr::Ascii("vilized"),
        dictgen::InsensitiveStr::Ascii("vilizes"),
        dictgen::InsensitiveStr::Ascii("vilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DECIGRAM_1038669198251789426)],
        &[(0b10010, &ENTRY_DECIGRAMS_6387241613823447779)],
        &[(0b00001, &ENTRY_DECILITER_16596592820215375084)],
        &[(0b00001, &ENTRY_DECILITERS_151708397377325111)],
        &[(0b11010, &ENTRY_DECILITER_16596592820215375084)],
        &[(0b11010, &ENTRY_DECILITERS_151708397377325111)],
        &[(0b10010, &ENTRY_DECIMALIZATION_6585979287053082594)],
        &[(0b10010, &ENTRY_DECIMALIZATIONS_14219964716573449259)],
        &[(0b10010, &ENTRY_DECIMALIZE_6260219389368908768)],
        &[(0b10010, &ENTRY_DECIMALIZED_8364548564908015686)],
        &[(0b10010, &ENTRY_DECIMALIZES_15979587779699755101)],
        &[(0b10010, &ENTRY_DECIMALIZING_17193949793978263746)],
        &[(0b01001, &ENTRY_DECIMALIZATION_6585979287053082594)],
        &[(0b01001, &ENTRY_DECIMALIZATIONS_14219964716573449259)],
        &[(0b01001, &ENTRY_DECIMALIZE_6260219389368908768)],
        &[(0b01001, &ENTRY_DECIMALIZED_8364548564908015686)],
        &[(0b01001, &ENTRY_DECIMALIZES_15979587779699755101)],
        &[(0b01001, &ENTRY_DECIMALIZING_17193949793978263746)],
        &[(0b01001, &ENTRY_DECIMETER_5877956144268963607)],
        &[(0b01001, &ENTRY_DECIMETERS_10623100407909187264)],
        &[(0b11010, &ENTRY_DECIMETER_5877956144268963607)],
        &[(0b11010, &ENTRY_DECIMETERS_10623100407909187264)],
        &[(0b10010, &ENTRY_DECIVILIZE_1843830017556346024)],
        &[(0b10010, &ENTRY_DECIVILIZED_5549046655328836217)],
        &[(0b10010, &ENTRY_DECIVILIZES_13869478196538743509)],
        &[(0b10010, &ENTRY_DECIVILIZING_11884011725903167539)],
        &[(0b01001, &ENTRY_DECIVILIZE_1843830017556346024)],
        &[(0b01001, &ENTRY_DECIVILIZED_5549046655328836217)],
        &[(0b01001, &ENTRY_DECIVILIZES_13869478196538743509)],
        &[(0b01001, &ENTRY_DECIVILIZING_11884011725903167539)],
    ],
    range: 5..=11,
};

static VARS_DECH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DECH_CHILDREN),
    value: None,
};

pub static VARS_DECH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ristianisation"),
        dictgen::InsensitiveStr::Ascii("ristianisations"),
        dictgen::InsensitiveStr::Ascii("ristianise"),
        dictgen::InsensitiveStr::Ascii("ristianised"),
        dictgen::InsensitiveStr::Ascii("ristianises"),
        dictgen::InsensitiveStr::Ascii("ristianising"),
        dictgen::InsensitiveStr::Ascii("ristianization"),
        dictgen::InsensitiveStr::Ascii("ristianizations"),
        dictgen::InsensitiveStr::Ascii("ristianize"),
        dictgen::InsensitiveStr::Ascii("ristianized"),
        dictgen::InsensitiveStr::Ascii("ristianizes"),
        dictgen::InsensitiveStr::Ascii("ristianizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DECHRISTIANIZATION_9661661223970321419)],
        &[(0b10010, &ENTRY_DECHRISTIANIZATIONS_9362852101358454817)],
        &[(0b10010, &ENTRY_DECHRISTIANIZE_18071236489381249425)],
        &[(0b10010, &ENTRY_DECHRISTIANIZED_6053330827461756799)],
        &[(0b10010, &ENTRY_DECHRISTIANIZES_881703834826854403)],
        &[(0b10010, &ENTRY_DECHRISTIANIZING_5393715445133549748)],
        &[(0b01001, &ENTRY_DECHRISTIANIZATION_9661661223970321419)],
        &[(0b01001, &ENTRY_DECHRISTIANIZATIONS_9362852101358454817)],
        &[(0b01001, &ENTRY_DECHRISTIANIZE_18071236489381249425)],
        &[(0b01001, &ENTRY_DECHRISTIANIZED_6053330827461756799)],
        &[(0b01001, &ENTRY_DECHRISTIANIZES_881703834826854403)],
        &[(0b01001, &ENTRY_DECHRISTIANIZING_5393715445133549748)],
    ],
    range: 10..=15,
};

static VARS_DECE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DECE_CHILDREN),
    value: None,
};

pub static VARS_DECE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nters"),
        dictgen::InsensitiveStr::Ascii("ntralisation"),
        dictgen::InsensitiveStr::Ascii("ntralisationist"),
        dictgen::InsensitiveStr::Ascii("ntralisations"),
        dictgen::InsensitiveStr::Ascii("ntralise"),
        dictgen::InsensitiveStr::Ascii("ntralised"),
        dictgen::InsensitiveStr::Ascii("ntralises"),
        dictgen::InsensitiveStr::Ascii("ntralising"),
        dictgen::InsensitiveStr::Ascii("ntralization"),
        dictgen::InsensitiveStr::Ascii("ntralizationist"),
        dictgen::InsensitiveStr::Ascii("ntralizations"),
        dictgen::InsensitiveStr::Ascii("ntralize"),
        dictgen::InsensitiveStr::Ascii("ntralized"),
        dictgen::InsensitiveStr::Ascii("ntralizes"),
        dictgen::InsensitiveStr::Ascii("ntralizing"),
        dictgen::InsensitiveStr::Ascii("ntres"),
        dictgen::InsensitiveStr::Ascii("rebrise"),
        dictgen::InsensitiveStr::Ascii("rebrised"),
        dictgen::InsensitiveStr::Ascii("rebrises"),
        dictgen::InsensitiveStr::Ascii("rebrising"),
        dictgen::InsensitiveStr::Ascii("rebrize"),
        dictgen::InsensitiveStr::Ascii("rebrized"),
        dictgen::InsensitiveStr::Ascii("rebrizes"),
        dictgen::InsensitiveStr::Ascii("rebrizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DECENTERS_1428026027855636170)],
        &[(0b10010, &ENTRY_DECENTRALIZATION_14989034485163734668)],
        &[(0b10010, &ENTRY_DECENTRALIZATIONIST_7530718361872221052)],
        &[(0b10010, &ENTRY_DECENTRALIZATIONS_15028307675843910435)],
        &[(0b10010, &ENTRY_DECENTRALIZE_17306384894132674147)],
        &[(0b10010, &ENTRY_DECENTRALIZED_15938901073912000317)],
        &[(0b10010, &ENTRY_DECENTRALIZES_8990159632087872438)],
        &[(0b10010, &ENTRY_DECENTRALIZING_11771308820494191656)],
        &[(0b01001, &ENTRY_DECENTRALIZATION_14989034485163734668)],
        &[(0b01001, &ENTRY_DECENTRALIZATIONIST_7530718361872221052)],
        &[(0b01001, &ENTRY_DECENTRALIZATIONS_15028307675843910435)],
        &[(0b01001, &ENTRY_DECENTRALIZE_17306384894132674147)],
        &[(0b01001, &ENTRY_DECENTRALIZED_15938901073912000317)],
        &[(0b01001, &ENTRY_DECENTRALIZES_8990159632087872438)],
        &[(0b01001, &ENTRY_DECENTRALIZING_11771308820494191656)],
        &[(0b11010, &ENTRY_DECENTERS_1428026027855636170)],
        &[(0b10010, &ENTRY_DECEREBRIZE_3339748175537557282)],
        &[(0b10010, &ENTRY_DECEREBRIZED_9540346435806066143)],
        &[(0b10010, &ENTRY_DECEREBRIZES_4566139257381137550)],
        &[(0b10010, &ENTRY_DECEREBRIZING_9951042741513666052)],
        &[(0b01001, &ENTRY_DECEREBRIZE_3339748175537557282)],
        &[(0b01001, &ENTRY_DECEREBRIZED_9540346435806066143)],
        &[(0b01001, &ENTRY_DECEREBRIZES_4566139257381137550)],
        &[(0b01001, &ENTRY_DECEREBRIZING_9951042741513666052)],
    ],
    range: 5..=15,
};

static VARS_DECA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DECA_CHILDREN),
    value: None,
};

pub static VARS_DECA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("liter"),
        dictgen::InsensitiveStr::Ascii("litre"),
        dictgen::InsensitiveStr::Ascii("litres"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("metre"),
        dictgen::InsensitiveStr::Ascii("metres"),
        dictgen::InsensitiveStr::Ascii("pitalisation"),
        dictgen::InsensitiveStr::Ascii("pitalisations"),
        dictgen::InsensitiveStr::Ascii("pitalise"),
        dictgen::InsensitiveStr::Ascii("pitalised"),
        dictgen::InsensitiveStr::Ascii("pitalises"),
        dictgen::InsensitiveStr::Ascii("pitalising"),
        dictgen::InsensitiveStr::Ascii("pitalization"),
        dictgen::InsensitiveStr::Ascii("pitalizations"),
        dictgen::InsensitiveStr::Ascii("pitalize"),
        dictgen::InsensitiveStr::Ascii("pitalized"),
        dictgen::InsensitiveStr::Ascii("pitalizes"),
        dictgen::InsensitiveStr::Ascii("pitalizing"),
        dictgen::InsensitiveStr::Ascii("rbonisation"),
        dictgen::InsensitiveStr::Ascii("rbonisations"),
        dictgen::InsensitiveStr::Ascii("rbonise"),
        dictgen::InsensitiveStr::Ascii("rbonised"),
        dictgen::InsensitiveStr::Ascii("rboniser"),
        dictgen::InsensitiveStr::Ascii("rbonisers"),
        dictgen::InsensitiveStr::Ascii("rbonises"),
        dictgen::InsensitiveStr::Ascii("rbonising"),
        dictgen::InsensitiveStr::Ascii("rbonization"),
        dictgen::InsensitiveStr::Ascii("rbonizations"),
        dictgen::InsensitiveStr::Ascii("rbonize"),
        dictgen::InsensitiveStr::Ascii("rbonized"),
        dictgen::InsensitiveStr::Ascii("rbonizer"),
        dictgen::InsensitiveStr::Ascii("rbonizers"),
        dictgen::InsensitiveStr::Ascii("rbonizes"),
        dictgen::InsensitiveStr::Ascii("rbonizing"),
        dictgen::InsensitiveStr::Ascii("rburisation"),
        dictgen::InsensitiveStr::Ascii("rburisations"),
        dictgen::InsensitiveStr::Ascii("rburise"),
        dictgen::InsensitiveStr::Ascii("rburised"),
        dictgen::InsensitiveStr::Ascii("rburises"),
        dictgen::InsensitiveStr::Ascii("rburising"),
        dictgen::InsensitiveStr::Ascii("rburization"),
        dictgen::InsensitiveStr::Ascii("rburizations"),
        dictgen::InsensitiveStr::Ascii("rburize"),
        dictgen::InsensitiveStr::Ascii("rburized"),
        dictgen::InsensitiveStr::Ascii("rburizes"),
        dictgen::InsensitiveStr::Ascii("rburizing"),
        dictgen::InsensitiveStr::Ascii("sualisation"),
        dictgen::InsensitiveStr::Ascii("sualisations"),
        dictgen::InsensitiveStr::Ascii("sualise"),
        dictgen::InsensitiveStr::Ascii("sualised"),
        dictgen::InsensitiveStr::Ascii("sualising"),
        dictgen::InsensitiveStr::Ascii("sualization"),
        dictgen::InsensitiveStr::Ascii("sualizations"),
        dictgen::InsensitiveStr::Ascii("sualize"),
        dictgen::InsensitiveStr::Ascii("sualized"),
        dictgen::InsensitiveStr::Ascii("sualizing"),
    ],
    values: &[
        &[
            (0b00001, &ENTRY_DEKALITERS_740321635385073637),
            (0b00001, &ENTRY_DEKALITER_11207981744248149263),
        ],
        &[(0b11010, &ENTRY_DEKALITER_11207981744248149263)],
        &[(0b11010, &ENTRY_DEKALITERS_740321635385073637)],
        &[
            (0b01001, &ENTRY_DEKAMETERS_10451263896199436858),
            (0b01001, &ENTRY_DEKAMETER_1569515849500939883),
        ],
        &[(0b11010, &ENTRY_DEKAMETER_1569515849500939883)],
        &[(0b11010, &ENTRY_DEKAMETERS_10451263896199436858)],
        &[(0b10010, &ENTRY_DECAPITALIZATION_1901543172013658650)],
        &[(0b10010, &ENTRY_DECAPITALIZATIONS_10231502913320043128)],
        &[(0b10010, &ENTRY_DECAPITALIZE_4356343600200271051)],
        &[(0b10010, &ENTRY_DECAPITALIZED_4301222274905658857)],
        &[(0b10010, &ENTRY_DECAPITALIZES_13874569898481582362)],
        &[(0b10010, &ENTRY_DECAPITALIZING_1775343748326764728)],
        &[(0b01001, &ENTRY_DECAPITALIZATION_1901543172013658650)],
        &[(0b01001, &ENTRY_DECAPITALIZATIONS_10231502913320043128)],
        &[(0b01001, &ENTRY_DECAPITALIZE_4356343600200271051)],
        &[(0b01001, &ENTRY_DECAPITALIZED_4301222274905658857)],
        &[(0b01001, &ENTRY_DECAPITALIZES_13874569898481582362)],
        &[(0b01001, &ENTRY_DECAPITALIZING_1775343748326764728)],
        &[(0b10010, &ENTRY_DECARBONIZATION_11478706021702952565)],
        &[(0b10010, &ENTRY_DECARBONIZATIONS_16017243127754390829)],
        &[(0b10010, &ENTRY_DECARBONIZE_17211928749740566614)],
        &[(0b10010, &ENTRY_DECARBONIZED_10394178489330721396)],
        &[(0b10010, &ENTRY_DECARBONIZER_6312932521576530142)],
        &[(0b10010, &ENTRY_DECARBONIZERS_17342232878961752295)],
        &[(0b10010, &ENTRY_DECARBONIZES_11122308997566756604)],
        &[(0b10010, &ENTRY_DECARBONIZING_5775070557566850865)],
        &[(0b01001, &ENTRY_DECARBONIZATION_11478706021702952565)],
        &[(0b01001, &ENTRY_DECARBONIZATIONS_16017243127754390829)],
        &[(0b01001, &ENTRY_DECARBONIZE_17211928749740566614)],
        &[(0b01001, &ENTRY_DECARBONIZED_10394178489330721396)],
        &[(0b01001, &ENTRY_DECARBONIZER_6312932521576530142)],
        &[(0b01001, &ENTRY_DECARBONIZERS_17342232878961752295)],
        &[(0b01001, &ENTRY_DECARBONIZES_11122308997566756604)],
        &[(0b01001, &ENTRY_DECARBONIZING_5775070557566850865)],
        &[(0b10010, &ENTRY_DECARBURIZATION_8009088083185706945)],
        &[(0b10010, &ENTRY_DECARBURIZATIONS_707144490166188138)],
        &[(0b10010, &ENTRY_DECARBURIZE_4982039598579376654)],
        &[(0b10010, &ENTRY_DECARBURIZED_1086979997678475265)],
        &[(0b10010, &ENTRY_DECARBURIZES_1172943395595033147)],
        &[(0b10010, &ENTRY_DECARBURIZING_15557851551596582391)],
        &[(0b01001, &ENTRY_DECARBURIZATION_8009088083185706945)],
        &[(0b01001, &ENTRY_DECARBURIZATIONS_707144490166188138)],
        &[(0b01001, &ENTRY_DECARBURIZE_4982039598579376654)],
        &[(0b01001, &ENTRY_DECARBURIZED_1086979997678475265)],
        &[(0b01001, &ENTRY_DECARBURIZES_1172943395595033147)],
        &[(0b01001, &ENTRY_DECARBURIZING_15557851551596582391)],
        &[(0b10010, &ENTRY_DECASUALIZATION_6341396589709137255)],
        &[(0b10010, &ENTRY_DECASUALIZATIONS_16861279937161161131)],
        &[(0b10010, &ENTRY_DECASUALIZE_2974632681155668648)],
        &[(0b10010, &ENTRY_DECASUALIZED_15267631738259466587)],
        &[(0b10010, &ENTRY_DECASUALIZING_12949252096566039416)],
        &[(0b01001, &ENTRY_DECASUALIZATION_6341396589709137255)],
        &[(0b01001, &ENTRY_DECASUALIZATIONS_16861279937161161131)],
        &[(0b01001, &ENTRY_DECASUALIZE_2974632681155668648)],
        &[(0b01001, &ENTRY_DECASUALIZED_15267631738259466587)],
        &[(0b01001, &ENTRY_DECASUALIZING_12949252096566039416)],
    ],
    range: 5..=13,
};

static VARS_DEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEA_CHILDREN),
    value: None,
};

pub static VARS_DEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("conise"),
        dictgen::InsensitiveStr::Ascii("conises"),
        dictgen::InsensitiveStr::Ascii("conize"),
        dictgen::InsensitiveStr::Ascii("conizes"),
        dictgen::InsensitiveStr::Ascii("drise"),
        dictgen::InsensitiveStr::Ascii("drize"),
        dictgen::InsensitiveStr::Ascii("lcoholise"),
        dictgen::InsensitiveStr::Ascii("lcoholised"),
        dictgen::InsensitiveStr::Ascii("lcoholises"),
        dictgen::InsensitiveStr::Ascii("lcoholising"),
        dictgen::InsensitiveStr::Ascii("lcoholize"),
        dictgen::InsensitiveStr::Ascii("lcoholized"),
        dictgen::InsensitiveStr::Ascii("lcoholizes"),
        dictgen::InsensitiveStr::Ascii("lcoholizing"),
        dictgen::InsensitiveStr::Ascii("minise"),
        dictgen::InsensitiveStr::Ascii("minize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEACONIZE_239384026809512957)],
        &[(0b10010, &ENTRY_DEACONIZES_2282161273560974649)],
        &[(0b01001, &ENTRY_DEACONIZE_239384026809512957)],
        &[(0b01001, &ENTRY_DEACONIZES_2282161273560974649)],
        &[(0b10010, &ENTRY_DEADRIZE_13632024912068492778)],
        &[(0b01001, &ENTRY_DEADRIZE_13632024912068492778)],
        &[(0b10010, &ENTRY_DEALCOHOLIZE_434858633952871464)],
        &[(0b10010, &ENTRY_DEALCOHOLIZED_5860794855975302138)],
        &[(0b10010, &ENTRY_DEALCOHOLIZES_3132733363085655905)],
        &[(0b10010, &ENTRY_DEALCOHOLIZING_4070885849740585749)],
        &[(0b01001, &ENTRY_DEALCOHOLIZE_434858633952871464)],
        &[(0b01001, &ENTRY_DEALCOHOLIZED_5860794855975302138)],
        &[(0b01001, &ENTRY_DEALCOHOLIZES_3132733363085655905)],
        &[(0b01001, &ENTRY_DEALCOHOLIZING_4070885849740585749)],
        &[(0b10010, &ENTRY_DEAMINIZE_1967701233443135959)],
        &[(0b01001, &ENTRY_DEAMINIZE_1967701233443135959)],
    ],
    range: 5..=11,
};

static VARS_DA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DA_CHILDREN),
    value: None,
};

pub static VARS_DA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edal"),
        dictgen::InsensitiveStr::Ascii("edalian"),
        dictgen::InsensitiveStr::Ascii("emonian"),
        dictgen::InsensitiveStr::Ascii("eva"),
        dictgen::InsensitiveStr::Ascii("nae"),
        dictgen::InsensitiveStr::Ascii("naidae"),
        dictgen::InsensitiveStr::Ascii("naide"),
        dictgen::InsensitiveStr::Ascii("ndisette"),
        dictgen::InsensitiveStr::Ascii("ndizette"),
        dictgen::InsensitiveStr::Ascii("ndyise"),
        dictgen::InsensitiveStr::Ascii("ndyises"),
        dictgen::InsensitiveStr::Ascii("ndyize"),
        dictgen::InsensitiveStr::Ascii("ndyizes"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("rwinise"),
        dictgen::InsensitiveStr::Ascii("rwinises"),
        dictgen::InsensitiveStr::Ascii("rwinize"),
        dictgen::InsensitiveStr::Ascii("rwinizes"),
        dictgen::InsensitiveStr::Ascii("stardise"),
        dictgen::InsensitiveStr::Ascii("stardises"),
        dictgen::InsensitiveStr::Ascii("stardize"),
        dictgen::InsensitiveStr::Ascii("stardizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DEDAL_5521769065882955150)],
        &[(0b11010, &ENTRY_DEDALIAN_8486751251745352405)],
        &[(0b11010, &ENTRY_DEMONIAN_1193667978555747859)],
        &[(0b11010, &ENTRY_DEVA_17913294961213511390)],
        &[(0b11010, &ENTRY_DANE_9169321821790361286)],
        &[(0b11010, &ENTRY_DANAIDE_15818498892253686536)],
        &[(0b00001, &ENTRY_DANAIDE_15818498892253686536)],
        &[(0b10010, &ENTRY_DANDIZETTE_5936439417225702170)],
        &[(0b01001, &ENTRY_DANDIZETTE_5936439417225702170)],
        &[(0b10010, &ENTRY_DANDYIZE_17840706303249111284)],
        &[(0b10010, &ENTRY_DANDYIZES_8481185232790854326)],
        &[(0b01001, &ENTRY_DANDYIZE_17840706303249111284)],
        &[(0b01001, &ENTRY_DANDYIZES_8481185232790854326)],
        &[(0b00001, &ENTRY_DANE_9169321821790361286)],
        &[(0b10010, &ENTRY_DANIZATION_8107686361857058644)],
        &[(0b10010, &ENTRY_DANIZATIONS_7756796548817532718)],
        &[(0b10010, &ENTRY_DANIZE_5515013359300588165)],
        &[(0b10010, &ENTRY_DANIZES_12632956829925791843)],
        &[(0b01001, &ENTRY_DANIZATION_8107686361857058644)],
        &[(0b01001, &ENTRY_DANIZATIONS_7756796548817532718)],
        &[(0b01001, &ENTRY_DANIZE_5515013359300588165)],
        &[(0b01001, &ENTRY_DANIZES_12632956829925791843)],
        &[(0b10010, &ENTRY_DARWINIZE_12330149218554050438)],
        &[(0b10010, &ENTRY_DARWINIZES_8098473267747389683)],
        &[(0b01001, &ENTRY_DARWINIZE_12330149218554050438)],
        &[(0b01001, &ENTRY_DARWINIZES_8098473267747389683)],
        &[(0b10010, &ENTRY_DASTARDIZE_17208857305345984482)],
        &[(0b10010, &ENTRY_DASTARDIZES_5293835990122312524)],
        &[(0b01001, &ENTRY_DASTARDIZE_17208857305345984482)],
        &[(0b01001, &ENTRY_DASTARDIZES_5293835990122312524)],
    ],
    range: 2..=9,
};

static VARS_C_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_C_CHILDREN),
    value: None,
};

static VARS_C_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CA_NODE),
    None,
    None,
    None,
    Some(&VARS_CE_NODE),
    None,
    None,
    Some(&VARS_CH_NODE),
    Some(&VARS_CI_NODE),
    None,
    None,
    Some(&VARS_CL_NODE),
    None,
    None,
    Some(&VARS_CO_NODE),
    None,
    None,
    Some(&VARS_CR_NODE),
    None,
    None,
    Some(&VARS_CU_NODE),
    None,
    None,
    None,
    Some(&VARS_CY_NODE),
    Some(&VARS_CZ_NODE),
];

static VARS_CZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CZ_CHILDREN),
    value: None,
};

pub static VARS_CZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("echisation"),
        dictgen::InsensitiveStr::Ascii("echisations"),
        dictgen::InsensitiveStr::Ascii("echization"),
        dictgen::InsensitiveStr::Ascii("echizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CZECHIZATION_5873051794680913883)],
        &[(0b10010, &ENTRY_CZECHIZATIONS_1280147882515365800)],
        &[(0b01001, &ENTRY_CZECHIZATION_5873051794680913883)],
        &[(0b01001, &ENTRY_CZECHIZATIONS_1280147882515365800)],
    ],
    range: 10..=11,
};

static VARS_CY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CY_CHILDREN),
    value: None,
};

pub static VARS_CY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aneae"),
        dictgen::InsensitiveStr::Ascii("anee"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("anomethaemoglobin"),
        dictgen::InsensitiveStr::Ascii("anomethemoglobin"),
        dictgen::InsensitiveStr::Ascii("clisation"),
        dictgen::InsensitiveStr::Ascii("clisations"),
        dictgen::InsensitiveStr::Ascii("clise"),
        dictgen::InsensitiveStr::Ascii("clised"),
        dictgen::InsensitiveStr::Ascii("clises"),
        dictgen::InsensitiveStr::Ascii("clising"),
        dictgen::InsensitiveStr::Ascii("clization"),
        dictgen::InsensitiveStr::Ascii("clizations"),
        dictgen::InsensitiveStr::Ascii("clize"),
        dictgen::InsensitiveStr::Ascii("clized"),
        dictgen::InsensitiveStr::Ascii("clizes"),
        dictgen::InsensitiveStr::Ascii("clizing"),
        dictgen::InsensitiveStr::Ascii("mae"),
        dictgen::InsensitiveStr::Ascii("me"),
        dictgen::InsensitiveStr::Ascii("pher"),
        dictgen::InsensitiveStr::Ascii("phered"),
        dictgen::InsensitiveStr::Ascii("phering"),
        dictgen::InsensitiveStr::Ascii("phers"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CYANEE_8351179455076677468)],
        &[(0b00001, &ENTRY_CYANEE_8351179455076677468)],
        &[(0b10010, &ENTRY_CYANIZE_18317689038562952818)],
        &[(0b10010, &ENTRY_CYANIZED_4456713039660344440)],
        &[(0b10010, &ENTRY_CYANIZES_2442374963273240913)],
        &[(0b10010, &ENTRY_CYANIZING_20662407404582315)],
        &[(0b01001, &ENTRY_CYANIZE_18317689038562952818)],
        &[(0b01001, &ENTRY_CYANIZED_4456713039660344440)],
        &[(0b01001, &ENTRY_CYANIZES_2442374963273240913)],
        &[(0b01001, &ENTRY_CYANIZING_20662407404582315)],
        &[(0b11010, &ENTRY_CYANOMETHEMOGLOBIN_12769153246273536208)],
        &[(0b10001, &ENTRY_CYANOMETHEMOGLOBIN_12769153246273536208)],
        &[(0b10010, &ENTRY_CYCLIZATION_15526264059961831355)],
        &[(0b10010, &ENTRY_CYCLIZATIONS_846436386408180033)],
        &[(0b10010, &ENTRY_CYCLIZE_6968162168191291774)],
        &[(0b10010, &ENTRY_CYCLIZED_15172658726383026502)],
        &[(0b10010, &ENTRY_CYCLIZES_10110148238244620541)],
        &[(0b10010, &ENTRY_CYCLIZING_10944596226901344600)],
        &[(0b01001, &ENTRY_CYCLIZATION_15526264059961831355)],
        &[(0b01001, &ENTRY_CYCLIZATIONS_846436386408180033)],
        &[(0b01001, &ENTRY_CYCLIZE_6968162168191291774)],
        &[(0b01001, &ENTRY_CYCLIZED_15172658726383026502)],
        &[(0b01001, &ENTRY_CYCLIZES_10110148238244620541)],
        &[(0b01001, &ENTRY_CYCLIZING_10944596226901344600)],
        &[(0b11010, &ENTRY_CYME_893707718890012153)],
        &[(0b00001, &ENTRY_CYME_893707718890012153)],
        &[(0b11010, &ENTRY_CIPHER_16521802570229937628)],
        &[(0b11010, &ENTRY_CIPHERED_15203892274342132278)],
        &[(0b11010, &ENTRY_CIPHERING_14057839138660888428)],
        &[(0b11010, &ENTRY_CIPHERS_4808512383208465724)],
    ],
    range: 2..=17,
};

static VARS_CU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CU_CHILDREN),
    value: None,
};

static VARS_CU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_CUB_NODE),
    Some(&VARS_CUC_NODE),
    Some(&VARS_CUD_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CUL_NODE),
    None,
    None,
    None,
    Some(&VARS_CUP_NODE),
    None,
    Some(&VARS_CUR_NODE),
    Some(&VARS_CUS_NODE),
    Some(&VARS_CUT_NODE),
    None,
    Some(&VARS_CUV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_CUV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUV_CHILDREN),
    value: None,
};

pub static VARS_CUV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CUVE_2708295972808503112)],
        &[(0b00001, &ENTRY_CUVE_2708295972808503112)],
    ],
    range: 1..=2,
};

static VARS_CUT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUT_CHILDREN),
    value: None,
};

pub static VARS_CUT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icolor"),
        dictgen::InsensitiveStr::Ascii("icolour"),
        dictgen::InsensitiveStr::Ascii("inisation"),
        dictgen::InsensitiveStr::Ascii("inisations"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inised"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inising"),
        dictgen::InsensitiveStr::Ascii("inization"),
        dictgen::InsensitiveStr::Ascii("inizations"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inized"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inizing"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CUTICOLOR_749118681891659729)],
        &[(0b11010, &ENTRY_CUTICOLOR_749118681891659729)],
        &[(0b10010, &ENTRY_CUTINIZATION_3225990792951117269)],
        &[(0b10010, &ENTRY_CUTINIZATIONS_15507232556236784571)],
        &[(0b10010, &ENTRY_CUTINIZE_15723941317771284250)],
        &[(0b10010, &ENTRY_CUTINIZED_13245491328214081401)],
        &[(0b10010, &ENTRY_CUTINIZES_15457760425980991257)],
        &[(0b10010, &ENTRY_CUTINIZING_3424452919945485048)],
        &[(0b01001, &ENTRY_CUTINIZATION_3225990792951117269)],
        &[(0b01001, &ENTRY_CUTINIZATIONS_15507232556236784571)],
        &[(0b01001, &ENTRY_CUTINIZE_15723941317771284250)],
        &[(0b01001, &ENTRY_CUTINIZED_13245491328214081401)],
        &[(0b01001, &ENTRY_CUTINIZES_15457760425980991257)],
        &[(0b01001, &ENTRY_CUTINIZING_3424452919945485048)],
        &[(0b10010, &ENTRY_CUTIZATION_16266962016865617854)],
        &[(0b10010, &ENTRY_CUTIZATIONS_17957033495950051125)],
        &[(0b01001, &ENTRY_CUTIZATION_16266962016865617854)],
        &[(0b01001, &ENTRY_CUTIZATIONS_17957033495950051125)],
    ],
    range: 5..=10,
};

static VARS_CUS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUS_CHILDREN),
    value: None,
};

pub static VARS_CUS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tomisable"),
        dictgen::InsensitiveStr::Ascii("tomisation"),
        dictgen::InsensitiveStr::Ascii("tomisations"),
        dictgen::InsensitiveStr::Ascii("tomise"),
        dictgen::InsensitiveStr::Ascii("tomised"),
        dictgen::InsensitiveStr::Ascii("tomiser"),
        dictgen::InsensitiveStr::Ascii("tomisers"),
        dictgen::InsensitiveStr::Ascii("tomises"),
        dictgen::InsensitiveStr::Ascii("tomising"),
        dictgen::InsensitiveStr::Ascii("tomizable"),
        dictgen::InsensitiveStr::Ascii("tomization"),
        dictgen::InsensitiveStr::Ascii("tomizations"),
        dictgen::InsensitiveStr::Ascii("tomize"),
        dictgen::InsensitiveStr::Ascii("tomized"),
        dictgen::InsensitiveStr::Ascii("tomizer"),
        dictgen::InsensitiveStr::Ascii("tomizers"),
        dictgen::InsensitiveStr::Ascii("tomizes"),
        dictgen::InsensitiveStr::Ascii("tomizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CUSTOMIZABLE_13082591789323327431)],
        &[(0b10010, &ENTRY_CUSTOMIZATION_6533324325688675249)],
        &[(0b10010, &ENTRY_CUSTOMIZATIONS_4094977061478290809)],
        &[(0b10010, &ENTRY_CUSTOMIZE_8330776599249555820)],
        &[(0b10010, &ENTRY_CUSTOMIZED_18152983780958356874)],
        &[(0b10010, &ENTRY_CUSTOMIZER_11779086965135396229)],
        &[(0b10010, &ENTRY_CUSTOMIZERS_12285041107419930743)],
        &[(0b10010, &ENTRY_CUSTOMIZES_5070925338090106827)],
        &[(0b10010, &ENTRY_CUSTOMIZING_2510425683526861127)],
        &[(0b01001, &ENTRY_CUSTOMIZABLE_13082591789323327431)],
        &[(0b01001, &ENTRY_CUSTOMIZATION_6533324325688675249)],
        &[(0b01001, &ENTRY_CUSTOMIZATIONS_4094977061478290809)],
        &[(0b01001, &ENTRY_CUSTOMIZE_8330776599249555820)],
        &[(0b01001, &ENTRY_CUSTOMIZED_18152983780958356874)],
        &[(0b01001, &ENTRY_CUSTOMIZER_11779086965135396229)],
        &[(0b01001, &ENTRY_CUSTOMIZERS_12285041107419930743)],
        &[(0b01001, &ENTRY_CUSTOMIZES_5070925338090106827)],
        &[(0b01001, &ENTRY_CUSTOMIZING_2510425683526861127)],
    ],
    range: 6..=11,
};

static VARS_CUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUR_CHILDREN),
    value: None,
};

pub static VARS_CUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arised"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arising"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arized"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("arizing"),
        dictgen::InsensitiveStr::Ascii("atise"),
        dictgen::InsensitiveStr::Ascii("atises"),
        dictgen::InsensitiveStr::Ascii("atize"),
        dictgen::InsensitiveStr::Ascii("atizes"),
        dictgen::InsensitiveStr::Ascii("ricularisation"),
        dictgen::InsensitiveStr::Ascii("ricularisations"),
        dictgen::InsensitiveStr::Ascii("ricularise"),
        dictgen::InsensitiveStr::Ascii("ricularises"),
        dictgen::InsensitiveStr::Ascii("ricularization"),
        dictgen::InsensitiveStr::Ascii("ricularizations"),
        dictgen::InsensitiveStr::Ascii("ricularize"),
        dictgen::InsensitiveStr::Ascii("ricularizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CURARIZE_14052932738253349451)],
        &[(0b10010, &ENTRY_CURARIZED_11693769575589653647)],
        &[(0b10010, &ENTRY_CURARIZES_17992342785692504556)],
        &[(0b10010, &ENTRY_CURARIZING_8798739795306767891)],
        &[(0b01001, &ENTRY_CURARIZE_14052932738253349451)],
        &[(0b01001, &ENTRY_CURARIZED_11693769575589653647)],
        &[(0b01001, &ENTRY_CURARIZES_17992342785692504556)],
        &[(0b01001, &ENTRY_CURARIZING_8798739795306767891)],
        &[(0b10010, &ENTRY_CURATIZE_6140878767375219419)],
        &[(0b10010, &ENTRY_CURATIZES_3945298158977001204)],
        &[(0b01001, &ENTRY_CURATIZE_6140878767375219419)],
        &[(0b01001, &ENTRY_CURATIZES_3945298158977001204)],
        &[(0b10010, &ENTRY_CURRICULARIZATION_434350820790147885)],
        &[(0b10010, &ENTRY_CURRICULARIZATIONS_6183818344426773100)],
        &[(0b10010, &ENTRY_CURRICULARIZE_4667478241371657714)],
        &[(0b10010, &ENTRY_CURRICULARIZES_13267456067224993371)],
        &[(0b01001, &ENTRY_CURRICULARIZATION_434350820790147885)],
        &[(0b01001, &ENTRY_CURRICULARIZATIONS_6183818344426773100)],
        &[(0b01001, &ENTRY_CURRICULARIZE_4667478241371657714)],
        &[(0b01001, &ENTRY_CURRICULARIZES_13267456067224993371)],
    ],
    range: 5..=15,
};

static VARS_CUP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUP_CHILDREN),
    value: None,
};

pub static VARS_CUP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elation"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("ellation"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CUPELATION_6970002014185731346)],
        &[(0b00001, &ENTRY_CUPELED_10239795116537207270)],
        &[(0b00001, &ENTRY_CUPELER_9495986041110761502)],
        &[(0b00001, &ENTRY_CUPELERS_12036428482700876979)],
        &[(0b00001, &ENTRY_CUPELING_1424135100214219307)],
        &[(0b11010, &ENTRY_CUPELATION_6970002014185731346)],
        &[(0b11010, &ENTRY_CUPELED_10239795116537207270)],
        &[(0b11010, &ENTRY_CUPELER_9495986041110761502)],
        &[(0b11010, &ENTRY_CUPELERS_12036428482700876979)],
        &[(0b11010, &ENTRY_CUPELING_1424135100214219307)],
        &[(0b11010, &ENTRY_CUPULE_12537732425607401603)],
        &[(0b00001, &ENTRY_CUPULE_12537732425607401603)],
    ],
    range: 3..=8,
};

static VARS_CUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUL_CHILDREN),
    value: None,
};

pub static VARS_CUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icidae"),
        dictgen::InsensitiveStr::Ascii("icide"),
        dictgen::InsensitiveStr::Ascii("turisation"),
        dictgen::InsensitiveStr::Ascii("turisations"),
        dictgen::InsensitiveStr::Ascii("turise"),
        dictgen::InsensitiveStr::Ascii("turises"),
        dictgen::InsensitiveStr::Ascii("turization"),
        dictgen::InsensitiveStr::Ascii("turizations"),
        dictgen::InsensitiveStr::Ascii("turize"),
        dictgen::InsensitiveStr::Ascii("turizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CULICIDE_16583607724694171506)],
        &[(0b00001, &ENTRY_CULICIDE_16583607724694171506)],
        &[(0b10010, &ENTRY_CULTURIZATION_8543494668590567803)],
        &[(0b10010, &ENTRY_CULTURIZATIONS_10014747967141783123)],
        &[(0b10010, &ENTRY_CULTURIZE_574509036799042170)],
        &[(0b10010, &ENTRY_CULTURIZES_5511084100185314818)],
        &[(0b01001, &ENTRY_CULTURIZATION_8543494668590567803)],
        &[(0b01001, &ENTRY_CULTURIZATIONS_10014747967141783123)],
        &[(0b01001, &ENTRY_CULTURIZE_574509036799042170)],
        &[(0b01001, &ENTRY_CULTURIZES_5511084100185314818)],
    ],
    range: 5..=11,
};

static VARS_CUD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUD_CHILDREN),
    value: None,
};

pub static VARS_CUD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("geled"),
        dictgen::InsensitiveStr::Ascii("geler"),
        dictgen::InsensitiveStr::Ascii("gelers"),
        dictgen::InsensitiveStr::Ascii("geling"),
        dictgen::InsensitiveStr::Ascii("gelings"),
        dictgen::InsensitiveStr::Ascii("gelled"),
        dictgen::InsensitiveStr::Ascii("geller"),
        dictgen::InsensitiveStr::Ascii("gellers"),
        dictgen::InsensitiveStr::Ascii("gelling"),
        dictgen::InsensitiveStr::Ascii("gellings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CUDGELED_9692005941001882555)],
        &[(0b00001, &ENTRY_CUDGELER_8422885901453267960)],
        &[(0b00001, &ENTRY_CUDGELERS_9715477768767548981)],
        &[(0b00001, &ENTRY_CUDGELING_8911435466137772919)],
        &[(0b00001, &ENTRY_CUDGELINGS_15615614002141274961)],
        &[(0b11010, &ENTRY_CUDGELED_9692005941001882555)],
        &[(0b11010, &ENTRY_CUDGELER_8422885901453267960)],
        &[(0b11010, &ENTRY_CUDGELERS_9715477768767548981)],
        &[(0b11010, &ENTRY_CUDGELING_8911435466137772919)],
        &[(0b11010, &ENTRY_CUDGELINGS_15615614002141274961)],
    ],
    range: 5..=8,
};

static VARS_CUC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUC_CHILDREN),
    value: None,
};

pub static VARS_CUC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("koldise"),
        dictgen::InsensitiveStr::Ascii("koldised"),
        dictgen::InsensitiveStr::Ascii("koldises"),
        dictgen::InsensitiveStr::Ascii("koldising"),
        dictgen::InsensitiveStr::Ascii("koldize"),
        dictgen::InsensitiveStr::Ascii("koldized"),
        dictgen::InsensitiveStr::Ascii("koldizes"),
        dictgen::InsensitiveStr::Ascii("koldizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CUCKOLDIZE_16118722183687227180)],
        &[(0b10010, &ENTRY_CUCKOLDIZED_14528006487293492545)],
        &[(0b10010, &ENTRY_CUCKOLDIZES_2342079244115513031)],
        &[(0b10010, &ENTRY_CUCKOLDIZING_5733984869361635766)],
        &[(0b01001, &ENTRY_CUCKOLDIZE_16118722183687227180)],
        &[(0b01001, &ENTRY_CUCKOLDIZED_14528006487293492545)],
        &[(0b01001, &ENTRY_CUCKOLDIZES_2342079244115513031)],
        &[(0b01001, &ENTRY_CUCKOLDIZING_5733984869361635766)],
    ],
    range: 7..=9,
};

static VARS_CUB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUB_CHILDREN),
    value: None,
};

pub static VARS_CUB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CUBANIZE_2187405951985618166)],
        &[(0b10010, &ENTRY_CUBANIZES_451693161566111602)],
        &[(0b01001, &ENTRY_CUBANIZE_2187405951985618166)],
        &[(0b01001, &ENTRY_CUBANIZES_451693161566111602)],
    ],
    range: 5..=6,
};

static VARS_CR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CR_CHILDREN),
    value: None,
};

static VARS_CR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CRA_NODE),
    None,
    None,
    None,
    Some(&VARS_CRE_NODE),
    None,
    None,
    None,
    Some(&VARS_CRI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CRO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CRU_NODE),
    None,
    None,
    None,
    Some(&VARS_CRY_NODE),
    None,
];

static VARS_CRY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CRY_CHILDREN),
    value: None,
};

pub static VARS_CRY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("oanaesthesia"),
        dictgen::InsensitiveStr::Ascii("oanesthesia"),
        dictgen::InsensitiveStr::Ascii("ptaesthesia"),
        dictgen::InsensitiveStr::Ascii("ptaesthesias"),
        dictgen::InsensitiveStr::Ascii("ptaesthetic"),
        dictgen::InsensitiveStr::Ascii("ptanalyses"),
        dictgen::InsensitiveStr::Ascii("ptanalyzes"),
        dictgen::InsensitiveStr::Ascii("ptesthesia"),
        dictgen::InsensitiveStr::Ascii("ptesthesias"),
        dictgen::InsensitiveStr::Ascii("ptesthetic"),
        dictgen::InsensitiveStr::Ascii("stalize"),
        dictgen::InsensitiveStr::Ascii("stalized"),
        dictgen::InsensitiveStr::Ascii("stalizes"),
        dictgen::InsensitiveStr::Ascii("stalizing"),
        dictgen::InsensitiveStr::Ascii("stallisabilities"),
        dictgen::InsensitiveStr::Ascii("stallisability"),
        dictgen::InsensitiveStr::Ascii("stallisable"),
        dictgen::InsensitiveStr::Ascii("stallisabler"),
        dictgen::InsensitiveStr::Ascii("stallisables"),
        dictgen::InsensitiveStr::Ascii("stallisablest"),
        dictgen::InsensitiveStr::Ascii("stallisation"),
        dictgen::InsensitiveStr::Ascii("stallisations"),
        dictgen::InsensitiveStr::Ascii("stallise"),
        dictgen::InsensitiveStr::Ascii("stallised"),
        dictgen::InsensitiveStr::Ascii("stalliser"),
        dictgen::InsensitiveStr::Ascii("stallisers"),
        dictgen::InsensitiveStr::Ascii("stallises"),
        dictgen::InsensitiveStr::Ascii("stallising"),
        dictgen::InsensitiveStr::Ascii("stallizabilities"),
        dictgen::InsensitiveStr::Ascii("stallizability"),
        dictgen::InsensitiveStr::Ascii("stallizable"),
        dictgen::InsensitiveStr::Ascii("stallizabler"),
        dictgen::InsensitiveStr::Ascii("stallizables"),
        dictgen::InsensitiveStr::Ascii("stallizablest"),
        dictgen::InsensitiveStr::Ascii("stallization"),
        dictgen::InsensitiveStr::Ascii("stallizations"),
        dictgen::InsensitiveStr::Ascii("stallize"),
        dictgen::InsensitiveStr::Ascii("stallized"),
        dictgen::InsensitiveStr::Ascii("stallizer"),
        dictgen::InsensitiveStr::Ascii("stallizers"),
        dictgen::InsensitiveStr::Ascii("stallizes"),
        dictgen::InsensitiveStr::Ascii("stallizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CRYESTHESIA_7209068238753136776)],
        &[(0b10001, &ENTRY_CRYESTHESIA_7209068238753136776)],
        &[(0b11010, &ENTRY_CRYOANESTHESIA_9229830264131529463)],
        &[(0b10001, &ENTRY_CRYOANESTHESIA_9229830264131529463)],
        &[(0b11010, &ENTRY_CRYPTESTHESIA_4340108141979706017)],
        &[(0b11010, &ENTRY_CRYPTESTHESIAS_15435745145193473110)],
        &[(0b11010, &ENTRY_CRYPTESTHETIC_2683184143393101964)],
        &[(0b10010, &ENTRY_CRYPTANALYZES_15535208005224777574)],
        &[(0b01001, &ENTRY_CRYPTANALYZES_15535208005224777574)],
        &[(0b10001, &ENTRY_CRYPTESTHESIA_4340108141979706017)],
        &[(0b10001, &ENTRY_CRYPTESTHESIAS_15435745145193473110)],
        &[(0b10001, &ENTRY_CRYPTESTHETIC_2683184143393101964)],
        &[(0b00001, &ENTRY_CRYSTALLIZE_3680960475075584665)],
        &[(0b00001, &ENTRY_CRYSTALLIZED_248195502747238890)],
        &[(0b00001, &ENTRY_CRYSTALLIZES_10883222514964571084)],
        &[(0b00001, &ENTRY_CRYSTALLIZING_16188565388667490505)],
        &[(0b10010, &ENTRY_CRYSTALLIZABILITIES_78809746787495534)],
        &[(0b10010, &ENTRY_CRYSTALLIZABILITY_8925485498433699838)],
        &[(0b10010, &ENTRY_CRYSTALLIZABLE_16889159866170496088)],
        &[(0b10010, &ENTRY_CRYSTALLIZABLER_10028068295407018641)],
        &[(0b10010, &ENTRY_CRYSTALLIZABLES_5177371679598980802)],
        &[(0b10010, &ENTRY_CRYSTALLIZABLEST_15524726073324327188)],
        &[(0b10010, &ENTRY_CRYSTALLIZATION_8976951361725962128)],
        &[(0b10010, &ENTRY_CRYSTALLIZATIONS_18023920101940919054)],
        &[(0b10010, &ENTRY_CRYSTALLIZE_3680960475075584665)],
        &[(0b10010, &ENTRY_CRYSTALLIZED_248195502747238890)],
        &[(0b10010, &ENTRY_CRYSTALLIZER_17740031004687030742)],
        &[(0b10010, &ENTRY_CRYSTALLIZERS_11409497017545724908)],
        &[(0b10010, &ENTRY_CRYSTALLIZES_10883222514964571084)],
        &[(0b10010, &ENTRY_CRYSTALLIZING_16188565388667490505)],
        &[(0b01001, &ENTRY_CRYSTALLIZABILITIES_78809746787495534)],
        &[(0b01001, &ENTRY_CRYSTALLIZABILITY_8925485498433699838)],
        &[(0b01001, &ENTRY_CRYSTALLIZABLE_16889159866170496088)],
        &[(0b01001, &ENTRY_CRYSTALLIZABLER_10028068295407018641)],
        &[(0b01001, &ENTRY_CRYSTALLIZABLES_5177371679598980802)],
        &[(0b01001, &ENTRY_CRYSTALLIZABLEST_15524726073324327188)],
        &[(0b01001, &ENTRY_CRYSTALLIZATION_8976951361725962128)],
        &[(0b01001, &ENTRY_CRYSTALLIZATIONS_18023920101940919054)],
        &[(0b01001, &ENTRY_CRYSTALLIZE_3680960475075584665)],
        &[(0b01001, &ENTRY_CRYSTALLIZED_248195502747238890)],
        &[(0b01001, &ENTRY_CRYSTALLIZER_17740031004687030742)],
        &[(0b01001, &ENTRY_CRYSTALLIZERS_11409497017545724908)],
        &[(0b01001, &ENTRY_CRYSTALLIZES_10883222514964571084)],
        &[(0b01001, &ENTRY_CRYSTALLIZING_16188565388667490505)],
    ],
    range: 7..=16,
};

static VARS_CRU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CRU_CHILDREN),
    value: None,
};

pub static VARS_CRU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elest"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellest"),
    ],
    values: &[
        &[(0b01001, &ENTRY_CRUELER_965105578349190970)],
        &[(0b01001, &ENTRY_CRUELEST_13236978233703918484)],
        &[(0b10010, &ENTRY_CRUELIZE_15407828798782205437)],
        &[(0b10010, &ENTRY_CRUELIZES_4558925592934439514)],
        &[(0b01001, &ENTRY_CRUELIZE_15407828798782205437)],
        &[(0b01001, &ENTRY_CRUELIZES_4558925592934439514)],
        &[(0b11010, &ENTRY_CRUELER_965105578349190970)],
        &[(0b11010, &ENTRY_CRUELEST_13236978233703918484)],
    ],
    range: 4..=6,
};

static VARS_CRO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CRO_CHILDREN),
    value: None,
};

pub static VARS_CRO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fterisation"),
        dictgen::InsensitiveStr::Ascii("fterisations"),
        dictgen::InsensitiveStr::Ascii("fterise"),
        dictgen::InsensitiveStr::Ascii("fterises"),
        dictgen::InsensitiveStr::Ascii("fterization"),
        dictgen::InsensitiveStr::Ascii("fterizations"),
        dictgen::InsensitiveStr::Ascii("fterize"),
        dictgen::InsensitiveStr::Ascii("fterizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CROFTERIZATION_4057900818249510176)],
        &[(0b10010, &ENTRY_CROFTERIZATIONS_15656785732855226560)],
        &[(0b10010, &ENTRY_CROFTERIZE_15285078638244483958)],
        &[(0b10010, &ENTRY_CROFTERIZES_8832761325441693011)],
        &[(0b01001, &ENTRY_CROFTERIZATION_4057900818249510176)],
        &[(0b01001, &ENTRY_CROFTERIZATIONS_15656785732855226560)],
        &[(0b01001, &ENTRY_CROFTERIZE_15285078638244483958)],
        &[(0b01001, &ENTRY_CROFTERIZES_8832761325441693011)],
    ],
    range: 7..=12,
};

static VARS_CRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CRI_CHILDREN),
    value: None,
};

pub static VARS_CRI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("minalisation"),
        dictgen::InsensitiveStr::Ascii("minalisations"),
        dictgen::InsensitiveStr::Ascii("minalise"),
        dictgen::InsensitiveStr::Ascii("minalised"),
        dictgen::InsensitiveStr::Ascii("minalises"),
        dictgen::InsensitiveStr::Ascii("minalising"),
        dictgen::InsensitiveStr::Ascii("minalization"),
        dictgen::InsensitiveStr::Ascii("minalizations"),
        dictgen::InsensitiveStr::Ascii("minalize"),
        dictgen::InsensitiveStr::Ascii("minalized"),
        dictgen::InsensitiveStr::Ascii("minalizes"),
        dictgen::InsensitiveStr::Ascii("minalizing"),
        dictgen::InsensitiveStr::Ascii("ticisable"),
        dictgen::InsensitiveStr::Ascii("ticisabler"),
        dictgen::InsensitiveStr::Ascii("ticisables"),
        dictgen::InsensitiveStr::Ascii("ticisablest"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticised"),
        dictgen::InsensitiveStr::Ascii("ticiser"),
        dictgen::InsensitiveStr::Ascii("ticisers"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticising"),
        dictgen::InsensitiveStr::Ascii("ticisinglier"),
        dictgen::InsensitiveStr::Ascii("ticisinglies"),
        dictgen::InsensitiveStr::Ascii("ticisingliest"),
        dictgen::InsensitiveStr::Ascii("ticisingly"),
        dictgen::InsensitiveStr::Ascii("ticizable"),
        dictgen::InsensitiveStr::Ascii("ticizabler"),
        dictgen::InsensitiveStr::Ascii("ticizables"),
        dictgen::InsensitiveStr::Ascii("ticizablest"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticized"),
        dictgen::InsensitiveStr::Ascii("ticizer"),
        dictgen::InsensitiveStr::Ascii("ticizers"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
        dictgen::InsensitiveStr::Ascii("ticizing"),
        dictgen::InsensitiveStr::Ascii("ticizinglier"),
        dictgen::InsensitiveStr::Ascii("ticizinglies"),
        dictgen::InsensitiveStr::Ascii("ticizingliest"),
        dictgen::InsensitiveStr::Ascii("ticizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CRIMINALIZATION_12203512332897805584)],
        &[(0b10010, &ENTRY_CRIMINALIZATIONS_9877401047859565771)],
        &[(0b10010, &ENTRY_CRIMINALIZE_9971594675545300062)],
        &[(0b10010, &ENTRY_CRIMINALIZED_3582649755795597508)],
        &[(0b10010, &ENTRY_CRIMINALIZES_7223829830621296974)],
        &[(0b10010, &ENTRY_CRIMINALIZING_12354761681927219659)],
        &[(0b01001, &ENTRY_CRIMINALIZATION_12203512332897805584)],
        &[(0b01001, &ENTRY_CRIMINALIZATIONS_9877401047859565771)],
        &[(0b01001, &ENTRY_CRIMINALIZE_9971594675545300062)],
        &[(0b01001, &ENTRY_CRIMINALIZED_3582649755795597508)],
        &[(0b01001, &ENTRY_CRIMINALIZES_7223829830621296974)],
        &[(0b01001, &ENTRY_CRIMINALIZING_12354761681927219659)],
        &[(0b10010, &ENTRY_CRITICIZABLE_12337979955682572299)],
        &[(0b10010, &ENTRY_CRITICIZABLER_16750540382481946795)],
        &[(0b10010, &ENTRY_CRITICIZABLES_14668868341788863043)],
        &[(0b10010, &ENTRY_CRITICIZABLEST_444603967053446436)],
        &[(0b10010, &ENTRY_CRITICIZE_13517498827728588589)],
        &[(0b10010, &ENTRY_CRITICIZED_10569362492506305842)],
        &[(0b10010, &ENTRY_CRITICIZER_8603387376111275284)],
        &[(0b10010, &ENTRY_CRITICIZERS_17493845359467775710)],
        &[(0b10010, &ENTRY_CRITICIZES_11166250956805349653)],
        &[(0b10010, &ENTRY_CRITICIZING_14274101564029962026)],
        &[(0b10010, &ENTRY_CRITICIZINGLIER_14296714278669892281)],
        &[(0b10010, &ENTRY_CRITICIZINGLIES_15160186189638892532)],
        &[(0b10010, &ENTRY_CRITICIZINGLIEST_13633098824583378573)],
        &[(0b10010, &ENTRY_CRITICIZINGLY_11847434186733349799)],
        &[(0b01001, &ENTRY_CRITICIZABLE_12337979955682572299)],
        &[(0b01001, &ENTRY_CRITICIZABLER_16750540382481946795)],
        &[(0b01001, &ENTRY_CRITICIZABLES_14668868341788863043)],
        &[(0b01001, &ENTRY_CRITICIZABLEST_444603967053446436)],
        &[(0b01001, &ENTRY_CRITICIZE_13517498827728588589)],
        &[(0b01001, &ENTRY_CRITICIZED_10569362492506305842)],
        &[(0b01001, &ENTRY_CRITICIZER_8603387376111275284)],
        &[(0b01001, &ENTRY_CRITICIZERS_17493845359467775710)],
        &[(0b01001, &ENTRY_CRITICIZES_11166250956805349653)],
        &[(0b01001, &ENTRY_CRITICIZING_14274101564029962026)],
        &[(0b01001, &ENTRY_CRITICIZINGLIER_14296714278669892281)],
        &[(0b01001, &ENTRY_CRITICIZINGLIES_15160186189638892532)],
        &[(0b01001, &ENTRY_CRITICIZINGLIEST_13633098824583378573)],
        &[(0b01001, &ENTRY_CRITICIZINGLY_11847434186733349799)],
    ],
    range: 6..=13,
};

static VARS_CRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CRE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_CER_7391662671400680429)]),
};

pub static VARS_CRE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("at"),
        dictgen::InsensitiveStr::Ascii("atin"),
        dictgen::InsensitiveStr::Ascii("atins"),
        dictgen::InsensitiveStr::Ascii("aturise"),
        dictgen::InsensitiveStr::Ascii("aturises"),
        dictgen::InsensitiveStr::Ascii("aturize"),
        dictgen::InsensitiveStr::Ascii("aturizes"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("nellate"),
        dictgen::InsensitiveStr::Ascii("nellated"),
        dictgen::InsensitiveStr::Ascii("nellater"),
        dictgen::InsensitiveStr::Ascii("nellates"),
        dictgen::InsensitiveStr::Ascii("nellatest"),
        dictgen::InsensitiveStr::Ascii("nellating"),
        dictgen::InsensitiveStr::Ascii("nellation"),
        dictgen::InsensitiveStr::Ascii("nellations"),
        dictgen::InsensitiveStr::Ascii("nelled"),
        dictgen::InsensitiveStr::Ascii("nelling"),
        dictgen::InsensitiveStr::Ascii("olisation"),
        dictgen::InsensitiveStr::Ascii("olisations"),
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olite"),
        dictgen::InsensitiveStr::Ascii("olization"),
        dictgen::InsensitiveStr::Ascii("olizations"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
        dictgen::InsensitiveStr::Ascii("tinisation"),
        dictgen::InsensitiveStr::Ascii("tinisations"),
        dictgen::InsensitiveStr::Ascii("tinise"),
        dictgen::InsensitiveStr::Ascii("tinised"),
        dictgen::InsensitiveStr::Ascii("tinises"),
        dictgen::InsensitiveStr::Ascii("tinising"),
        dictgen::InsensitiveStr::Ascii("tinization"),
        dictgen::InsensitiveStr::Ascii("tinizations"),
        dictgen::InsensitiveStr::Ascii("tinize"),
        dictgen::InsensitiveStr::Ascii("tinized"),
        dictgen::InsensitiveStr::Ascii("tinizes"),
        dictgen::InsensitiveStr::Ascii("tinizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CERA_4010763817295674400)],
        &[(0b11010, &ENTRY_CERAT_952631974668920340)],
        &[(0b11010, &ENTRY_CERATIN_12655188086840180608)],
        &[(0b11010, &ENTRY_CERATINS_11807307117212505372)],
        &[(0b10010, &ENTRY_CREATURIZE_7728183535168976997)],
        &[(0b10010, &ENTRY_CREATURIZES_1248731206347691357)],
        &[(0b01001, &ENTRY_CREATURIZE_7728183535168976997)],
        &[(0b01001, &ENTRY_CREATURIZES_1248731206347691357)],
        &[(0b11010, &ENTRY_CERE_7492486766027596747)],
        &[(0b11010, &ENTRY_CERES_13909916927122501672)],
        &[(0b11010, &ENTRY_CRENELATE_16654827051033938768)],
        &[(0b11010, &ENTRY_CRENELATED_14791658803956712009)],
        &[(0b11010, &ENTRY_CRENELATER_11388015695766004333)],
        &[(0b11010, &ENTRY_CRENELATES_10245337469566174666)],
        &[(0b11010, &ENTRY_CRENELATEST_14183406657979002478)],
        &[(0b11010, &ENTRY_CRENELATING_17583663146982717987)],
        &[(0b11010, &ENTRY_CRENELATION_11524933049185072103)],
        &[(0b11010, &ENTRY_CRENELATIONS_15328070542518467567)],
        &[(0b11010, &ENTRY_CRENELED_16014586123533609952)],
        &[(0b11010, &ENTRY_CRENELING_5311342342273872232)],
        &[(0b10010, &ENTRY_CREOLIZATION_18113727530889902093)],
        &[(0b10010, &ENTRY_CREOLIZATIONS_17009489055568961562)],
        &[(0b10010, &ENTRY_CREOLIZE_146003202220590288)],
        &[(0b10010, &ENTRY_CREOLIZED_11852473936521640088)],
        &[(0b10010, &ENTRY_CREOLIZES_17960363375761238839)],
        &[(0b10010, &ENTRY_CREOLIZING_13664113412449994869)],
        &[(0b11010, &ENTRY_CEROLITE_13936865573619235917)],
        &[(0b01001, &ENTRY_CREOLIZATION_18113727530889902093)],
        &[(0b01001, &ENTRY_CREOLIZATIONS_17009489055568961562)],
        &[(0b01001, &ENTRY_CREOLIZE_146003202220590288)],
        &[(0b01001, &ENTRY_CREOLIZED_11852473936521640088)],
        &[(0b01001, &ENTRY_CREOLIZES_17960363375761238839)],
        &[(0b01001, &ENTRY_CREOLIZING_13664113412449994869)],
        &[(0b10010, &ENTRY_CRETINIZATION_12141340075954838361)],
        &[(0b10010, &ENTRY_CRETINIZATIONS_8151443991713584435)],
        &[(0b10010, &ENTRY_CRETINIZE_13005767874816748250)],
        &[(0b10010, &ENTRY_CRETINIZED_558201944204822698)],
        &[(0b10010, &ENTRY_CRETINIZES_7179221825296926291)],
        &[(0b10010, &ENTRY_CRETINIZING_6901184386136281414)],
        &[(0b01001, &ENTRY_CRETINIZATION_12141340075954838361)],
        &[(0b01001, &ENTRY_CRETINIZATIONS_8151443991713584435)],
        &[(0b01001, &ENTRY_CRETINIZE_13005767874816748250)],
        &[(0b01001, &ENTRY_CRETINIZED_558201944204822698)],
        &[(0b01001, &ENTRY_CRETINIZES_7179221825296926291)],
        &[(0b01001, &ENTRY_CRETINIZING_6901184386136281414)],
    ],
    range: 1..=11,
};

static VARS_CRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CRA_CHILDREN),
    value: None,
};

pub static VARS_CRA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isey"),
        dictgen::InsensitiveStr::Ascii("izey"),
        dictgen::InsensitiveStr::Ascii("mbes"),
        dictgen::InsensitiveStr::Ascii("mboes"),
        dictgen::InsensitiveStr::Ascii("wlerise"),
        dictgen::InsensitiveStr::Ascii("wlerises"),
        dictgen::InsensitiveStr::Ascii("wlerize"),
        dictgen::InsensitiveStr::Ascii("wlerizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CRAIZEY_4366032612918169570)],
        &[(0b01001, &ENTRY_CRAIZEY_4366032612918169570)],
        &[(0b00001, &ENTRY_CRAMBES_13590842356025353019)],
        &[(0b11010, &ENTRY_CRAMBES_13590842356025353019)],
        &[(0b10010, &ENTRY_CRAWLERIZE_16511383301840652370)],
        &[(0b10010, &ENTRY_CRAWLERIZES_6301045917084390617)],
        &[(0b01001, &ENTRY_CRAWLERIZE_16511383301840652370)],
        &[(0b01001, &ENTRY_CRAWLERIZES_6301045917084390617)],
    ],
    range: 4..=8,
};

static VARS_CO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CO_CHILDREN),
    value: None,
};

static VARS_CO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_COA_NODE),
    None,
    Some(&VARS_COC_NODE),
    None,
    Some(&VARS_COE_NODE),
    None,
    Some(&VARS_COG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_COL_NODE),
    Some(&VARS_COM_NODE),
    Some(&VARS_CON_NODE),
    Some(&VARS_COO_NODE),
    Some(&VARS_COP_NODE),
    None,
    Some(&VARS_COR_NODE),
    Some(&VARS_COS_NODE),
    Some(&VARS_COT_NODE),
    Some(&VARS_COU_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_COZ_NODE),
];

static VARS_COZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COZ_CHILDREN),
    value: None,
};

pub static VARS_COZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ied"),
        dictgen::InsensitiveStr::Ascii("ier"),
        dictgen::InsensitiveStr::Ascii("ies"),
        dictgen::InsensitiveStr::Ascii("iest"),
        dictgen::InsensitiveStr::Ascii("ily"),
        dictgen::InsensitiveStr::Ascii("iness"),
        dictgen::InsensitiveStr::Ascii("y"),
        dictgen::InsensitiveStr::Ascii("ying"),
    ],
    values: &[
        &[(0b01001, &ENTRY_COZIED_6562646973128567884)],
        &[(0b01001, &ENTRY_COZIER_9366197992019890355)],
        &[(0b01001, &ENTRY_COZIES_1955518053712297702)],
        &[(0b01001, &ENTRY_COZIEST_10595392179485625103)],
        &[(0b01001, &ENTRY_COZILY_9030881398920983543)],
        &[(0b01001, &ENTRY_COZINESS_3678850341916343717)],
        &[(0b01001, &ENTRY_COZY_7236665209258571742)],
        &[(0b01001, &ENTRY_COZYING_15155247936314647373)],
    ],
    range: 1..=5,
};

static VARS_COU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COU_CHILDREN),
    value: None,
};

pub static VARS_COU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ncillor"),
        dictgen::InsensitiveStr::Ascii("ncillors"),
        dictgen::InsensitiveStr::Ascii("ncillorship"),
        dictgen::InsensitiveStr::Ascii("ncillorships"),
        dictgen::InsensitiveStr::Ascii("ncilor"),
        dictgen::InsensitiveStr::Ascii("ncilors"),
        dictgen::InsensitiveStr::Ascii("ncilorship"),
        dictgen::InsensitiveStr::Ascii("ncilorships"),
        dictgen::InsensitiveStr::Ascii("nseled"),
        dictgen::InsensitiveStr::Ascii("nselee"),
        dictgen::InsensitiveStr::Ascii("nseling"),
        dictgen::InsensitiveStr::Ascii("nselled"),
        dictgen::InsensitiveStr::Ascii("nsellee"),
        dictgen::InsensitiveStr::Ascii("nselling"),
        dictgen::InsensitiveStr::Ascii("nsellor"),
        dictgen::InsensitiveStr::Ascii("nsellors"),
        dictgen::InsensitiveStr::Ascii("nsellorship"),
        dictgen::InsensitiveStr::Ascii("nsellorships"),
        dictgen::InsensitiveStr::Ascii("nselor"),
        dictgen::InsensitiveStr::Ascii("nselors"),
        dictgen::InsensitiveStr::Ascii("nselorship"),
        dictgen::InsensitiveStr::Ascii("nselorships"),
        dictgen::InsensitiveStr::Ascii("ntercolored"),
        dictgen::InsensitiveStr::Ascii("ntercoloured"),
        dictgen::InsensitiveStr::Ascii("ntor"),
        dictgen::InsensitiveStr::Ascii("ntour"),
        dictgen::InsensitiveStr::Ascii("ranto"),
        dictgen::InsensitiveStr::Ascii("rantoes"),
        dictgen::InsensitiveStr::Ascii("rantos"),
        dictgen::InsensitiveStr::Ascii("rbe"),
        dictgen::InsensitiveStr::Ascii("rbed"),
        dictgen::InsensitiveStr::Ascii("rge"),
        dictgen::InsensitiveStr::Ascii("rsy"),
        dictgen::InsensitiveStr::Ascii("rtage"),
        dictgen::InsensitiveStr::Ascii("rtin"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COUNCILOR_15580609476721559009)],
        &[(0b11010, &ENTRY_COUNCILORS_8086440655852289978)],
        &[(0b11010, &ENTRY_COUNCILORSHIP_16998032340551826478)],
        &[(0b11010, &ENTRY_COUNCILORSHIPS_3525523011873776596)],
        &[(0b00001, &ENTRY_COUNCILOR_15580609476721559009)],
        &[(0b00001, &ENTRY_COUNCILORS_8086440655852289978)],
        &[(0b00001, &ENTRY_COUNCILORSHIP_16998032340551826478)],
        &[(0b00001, &ENTRY_COUNCILORSHIPS_3525523011873776596)],
        &[(0b00001, &ENTRY_COUNSELED_10079969979774535185)],
        &[(0b00001, &ENTRY_COUNSELEE_2663336403792418618)],
        &[(0b00001, &ENTRY_COUNSELING_3362710659606651238)],
        &[(0b11010, &ENTRY_COUNSELED_10079969979774535185)],
        &[(0b11010, &ENTRY_COUNSELEE_2663336403792418618)],
        &[(0b11010, &ENTRY_COUNSELING_3362710659606651238)],
        &[(0b11010, &ENTRY_COUNSELOR_13404070207747695814)],
        &[(0b11010, &ENTRY_COUNSELORS_1887733060441859158)],
        &[(0b11010, &ENTRY_COUNSELORSHIP_184117096334597007)],
        &[(0b11010, &ENTRY_COUNSELORSHIPS_3885641614196374389)],
        &[(0b01001, &ENTRY_COUNSELOR_13404070207747695814)],
        &[(0b01001, &ENTRY_COUNSELORS_1887733060441859158)],
        &[(0b00001, &ENTRY_COUNSELORSHIP_184117096334597007)],
        &[(0b00001, &ENTRY_COUNSELORSHIPS_3885641614196374389)],
        &[(0b10001, &ENTRY_COUNTERCOLORED_14141979223186124542)],
        &[(0b11010, &ENTRY_COUNTERCOLORED_14141979223186124542)],
        &[(0b00001, &ENTRY_COUNTOR_3607924860727110166)],
        &[(0b11010, &ENTRY_COUNTOR_3607924860727110166)],
        &[(0b11010, &ENTRY_CORANTO_449281456667886469)],
        &[(0b11010, &ENTRY_CORANTOES_10805751077677468198)],
        &[(0b11010, &ENTRY_CORANTOS_10727231399317582642)],
        &[(0b11010, &ENTRY_CORBE_9500946030049509925)],
        &[(0b11010, &ENTRY_CORBED_6613581470338211217)],
        &[(0b11010, &ENTRY_CORGE_17485843320272456103)],
        &[(0b11010, &ENTRY_CORSY_2581357179624818778)],
        &[(0b11010, &ENTRY_CORTAGE_240810678292962993)],
        &[(0b11010, &ENTRY_CORTIN_15506462001994757631)],
    ],
    range: 3..=12,
};

static VARS_COT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COT_CHILDREN),
    value: None,
};

pub static VARS_COT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("tonisation"),
        dictgen::InsensitiveStr::Ascii("tonisations"),
        dictgen::InsensitiveStr::Ascii("tonise"),
        dictgen::InsensitiveStr::Ascii("tonises"),
        dictgen::InsensitiveStr::Ascii("tonization"),
        dictgen::InsensitiveStr::Ascii("tonizations"),
        dictgen::InsensitiveStr::Ascii("tonize"),
        dictgen::InsensitiveStr::Ascii("tonizes"),
        dictgen::InsensitiveStr::Ascii("ylae"),
        dictgen::InsensitiveStr::Ascii("yle"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COTTE_5426452040563003837)],
        &[(0b00001, &ENTRY_COTTE_5426452040563003837)],
        &[(0b10010, &ENTRY_COTTONIZATION_9129202047860498194)],
        &[(0b10010, &ENTRY_COTTONIZATIONS_659824657489867728)],
        &[(0b10010, &ENTRY_COTTONIZE_7266294437242654895)],
        &[(0b10010, &ENTRY_COTTONIZES_16537091607400846202)],
        &[(0b01001, &ENTRY_COTTONIZATION_9129202047860498194)],
        &[(0b01001, &ENTRY_COTTONIZATIONS_659824657489867728)],
        &[(0b01001, &ENTRY_COTTONIZE_7266294437242654895)],
        &[(0b01001, &ENTRY_COTTONIZES_16537091607400846202)],
        &[(0b11010, &ENTRY_COTYLE_6691433492815997580)],
        &[(0b00001, &ENTRY_COTYLE_6691433492815997580)],
    ],
    range: 2..=11,
};

static VARS_COS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COS_CHILDREN),
    value: None,
};

pub static VARS_COS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ied"),
        dictgen::InsensitiveStr::Ascii("ier"),
        dictgen::InsensitiveStr::Ascii("ies"),
        dictgen::InsensitiveStr::Ascii("iest"),
        dictgen::InsensitiveStr::Ascii("ily"),
        dictgen::InsensitiveStr::Ascii("iness"),
        dictgen::InsensitiveStr::Ascii("meticise"),
        dictgen::InsensitiveStr::Ascii("meticised"),
        dictgen::InsensitiveStr::Ascii("meticises"),
        dictgen::InsensitiveStr::Ascii("meticising"),
        dictgen::InsensitiveStr::Ascii("meticize"),
        dictgen::InsensitiveStr::Ascii("meticized"),
        dictgen::InsensitiveStr::Ascii("meticizes"),
        dictgen::InsensitiveStr::Ascii("meticizing"),
        dictgen::InsensitiveStr::Ascii("mopolitanisation"),
        dictgen::InsensitiveStr::Ascii("mopolitanisations"),
        dictgen::InsensitiveStr::Ascii("mopolitanise"),
        dictgen::InsensitiveStr::Ascii("mopolitanised"),
        dictgen::InsensitiveStr::Ascii("mopolitanises"),
        dictgen::InsensitiveStr::Ascii("mopolitanising"),
        dictgen::InsensitiveStr::Ascii("mopolitanization"),
        dictgen::InsensitiveStr::Ascii("mopolitanizations"),
        dictgen::InsensitiveStr::Ascii("mopolitanize"),
        dictgen::InsensitiveStr::Ascii("mopolitanized"),
        dictgen::InsensitiveStr::Ascii("mopolitanizes"),
        dictgen::InsensitiveStr::Ascii("mopolitanizing"),
        dictgen::InsensitiveStr::Ascii("plendor"),
        dictgen::InsensitiveStr::Ascii("plendour"),
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("tumier"),
        dictgen::InsensitiveStr::Ascii("tumire"),
        dictgen::InsensitiveStr::Ascii("y"),
        dictgen::InsensitiveStr::Ascii("ying"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COZIED_6562646973128567884)],
        &[(0b11010, &ENTRY_COZIER_9366197992019890355)],
        &[(0b11010, &ENTRY_COZIES_1955518053712297702)],
        &[(0b11010, &ENTRY_COZIEST_10595392179485625103)],
        &[(0b10010, &ENTRY_COZILY_9030881398920983543)],
        &[(0b10010, &ENTRY_COZINESS_3678850341916343717)],
        &[(0b10010, &ENTRY_COSMETICIZE_7229806576940444951)],
        &[(0b10010, &ENTRY_COSMETICIZED_13587523395309881775)],
        &[(0b10010, &ENTRY_COSMETICIZES_14677656770429071116)],
        &[(0b10010, &ENTRY_COSMETICIZING_14659907444405436840)],
        &[(0b01001, &ENTRY_COSMETICIZE_7229806576940444951)],
        &[(0b01001, &ENTRY_COSMETICIZED_13587523395309881775)],
        &[(0b01001, &ENTRY_COSMETICIZES_14677656770429071116)],
        &[(0b01001, &ENTRY_COSMETICIZING_14659907444405436840)],
        &[(0b10010, &ENTRY_COSMOPOLITANIZATION_5720036499017135205)],
        &[(0b10010, &ENTRY_COSMOPOLITANIZATIONS_8321319186324517850)],
        &[(0b10010, &ENTRY_COSMOPOLITANIZE_2274947466234383776)],
        &[(0b10010, &ENTRY_COSMOPOLITANIZED_7733201348304626234)],
        &[(0b10010, &ENTRY_COSMOPOLITANIZES_10510882645788399153)],
        &[(0b10010, &ENTRY_COSMOPOLITANIZING_8986323684241042113)],
        &[(0b01001, &ENTRY_COSMOPOLITANIZATION_5720036499017135205)],
        &[(0b01001, &ENTRY_COSMOPOLITANIZATIONS_8321319186324517850)],
        &[(0b01001, &ENTRY_COSMOPOLITANIZE_2274947466234383776)],
        &[(0b01001, &ENTRY_COSMOPOLITANIZED_7733201348304626234)],
        &[(0b01001, &ENTRY_COSMOPOLITANIZES_10510882645788399153)],
        &[(0b01001, &ENTRY_COSMOPOLITANIZING_8986323684241042113)],
        &[(0b10001, &ENTRY_COSPLENDOR_2580856102842719661)],
        &[(0b11010, &ENTRY_COSPLENDOR_2580856102842719661)],
        &[(0b11010, &ENTRY_COSTE_2504691656191425333)],
        &[(0b00001, &ENTRY_COSTE_2504691656191425333)],
        &[(0b00001, &ENTRY_COSTUMIER_9518731460874060467)],
        &[(0b11010, &ENTRY_COSTUMIER_9518731460874060467)],
        &[(0b11010, &ENTRY_COZY_7236665209258571742)],
        &[(0b11010, &ENTRY_COZYING_15155247936314647373)],
    ],
    range: 1..=17,
};

static VARS_COR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COR_CHILDREN),
    value: None,
};

pub static VARS_COR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aled"),
        dictgen::InsensitiveStr::Ascii("alled"),
        dictgen::InsensitiveStr::Ascii("anto"),
        dictgen::InsensitiveStr::Ascii("antoes"),
        dictgen::InsensitiveStr::Ascii("antos"),
        dictgen::InsensitiveStr::Ascii("be"),
        dictgen::InsensitiveStr::Ascii("bed"),
        dictgen::InsensitiveStr::Ascii("beled"),
        dictgen::InsensitiveStr::Ascii("beling"),
        dictgen::InsensitiveStr::Ascii("belings"),
        dictgen::InsensitiveStr::Ascii("belled"),
        dictgen::InsensitiveStr::Ascii("belling"),
        dictgen::InsensitiveStr::Ascii("bellings"),
        dictgen::InsensitiveStr::Ascii("dialise"),
        dictgen::InsensitiveStr::Ascii("dialised"),
        dictgen::InsensitiveStr::Ascii("dialises"),
        dictgen::InsensitiveStr::Ascii("dialising"),
        dictgen::InsensitiveStr::Ascii("dialize"),
        dictgen::InsensitiveStr::Ascii("dialized"),
        dictgen::InsensitiveStr::Ascii("dializes"),
        dictgen::InsensitiveStr::Ascii("dializing"),
        dictgen::InsensitiveStr::Ascii("ge"),
        dictgen::InsensitiveStr::Ascii("inthianise"),
        dictgen::InsensitiveStr::Ascii("inthianised"),
        dictgen::InsensitiveStr::Ascii("inthianises"),
        dictgen::InsensitiveStr::Ascii("inthianising"),
        dictgen::InsensitiveStr::Ascii("inthianize"),
        dictgen::InsensitiveStr::Ascii("inthianized"),
        dictgen::InsensitiveStr::Ascii("inthianizes"),
        dictgen::InsensitiveStr::Ascii("inthianizing"),
        dictgen::InsensitiveStr::Ascii("porealisation"),
        dictgen::InsensitiveStr::Ascii("porealisations"),
        dictgen::InsensitiveStr::Ascii("porealise"),
        dictgen::InsensitiveStr::Ascii("porealised"),
        dictgen::InsensitiveStr::Ascii("porealises"),
        dictgen::InsensitiveStr::Ascii("porealising"),
        dictgen::InsensitiveStr::Ascii("porealization"),
        dictgen::InsensitiveStr::Ascii("porealizations"),
        dictgen::InsensitiveStr::Ascii("porealize"),
        dictgen::InsensitiveStr::Ascii("porealized"),
        dictgen::InsensitiveStr::Ascii("porealizes"),
        dictgen::InsensitiveStr::Ascii("porealizing"),
        dictgen::InsensitiveStr::Ascii("sy"),
        dictgen::InsensitiveStr::Ascii("tage"),
        dictgen::InsensitiveStr::Ascii("tin"),
        dictgen::InsensitiveStr::Ascii("tinae"),
        dictgen::InsensitiveStr::Ascii("tine"),
        dictgen::InsensitiveStr::Ascii("vae"),
        dictgen::InsensitiveStr::Ascii("ve"),
        dictgen::InsensitiveStr::Ascii("yphae"),
        dictgen::InsensitiveStr::Ascii("yphaes"),
        dictgen::InsensitiveStr::Ascii("yphe"),
        dictgen::InsensitiveStr::Ascii("yphes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CORALED_14441209538548736417)],
        &[(0b11010, &ENTRY_CORALED_14441209538548736417)],
        &[(0b00001, &ENTRY_CORANTO_449281456667886469)],
        &[(0b00001, &ENTRY_CORANTOES_10805751077677468198)],
        &[(0b00001, &ENTRY_CORANTOS_10727231399317582642)],
        &[(0b00001, &ENTRY_CORBE_9500946030049509925)],
        &[(0b00001, &ENTRY_CORBED_6613581470338211217)],
        &[(0b00001, &ENTRY_CORBELED_6696681783303093325)],
        &[(0b00001, &ENTRY_CORBELING_14073722108296010081)],
        &[(0b00001, &ENTRY_CORBELINGS_3333039851766534882)],
        &[(0b11010, &ENTRY_CORBELED_6696681783303093325)],
        &[(0b11010, &ENTRY_CORBELING_14073722108296010081)],
        &[(0b11010, &ENTRY_CORBELINGS_3333039851766534882)],
        &[(0b10010, &ENTRY_CORDIALIZE_14444478676753919887)],
        &[(0b10010, &ENTRY_CORDIALIZED_4522684783827889079)],
        &[(0b10010, &ENTRY_CORDIALIZES_5004163444219892172)],
        &[(0b10010, &ENTRY_CORDIALIZING_4461609946720434424)],
        &[(0b01001, &ENTRY_CORDIALIZE_14444478676753919887)],
        &[(0b01001, &ENTRY_CORDIALIZED_4522684783827889079)],
        &[(0b01001, &ENTRY_CORDIALIZES_5004163444219892172)],
        &[(0b01001, &ENTRY_CORDIALIZING_4461609946720434424)],
        &[(0b00001, &ENTRY_CORGE_17485843320272456103)],
        &[(0b10010, &ENTRY_CORINTHIANIZE_14380160817703322777)],
        &[(0b10010, &ENTRY_CORINTHIANIZED_14231677469452975998)],
        &[(0b10010, &ENTRY_CORINTHIANIZES_4980508561030799726)],
        &[(0b10010, &ENTRY_CORINTHIANIZING_3286736123626060904)],
        &[(0b01001, &ENTRY_CORINTHIANIZE_14380160817703322777)],
        &[(0b01001, &ENTRY_CORINTHIANIZED_14231677469452975998)],
        &[(0b01001, &ENTRY_CORINTHIANIZES_4980508561030799726)],
        &[(0b01001, &ENTRY_CORINTHIANIZING_3286736123626060904)],
        &[(0b10010, &ENTRY_CORPOREALIZATION_7151572681191131638)],
        &[(0b10010, &ENTRY_CORPOREALIZATIONS_4194611580429909973)],
        &[(0b10010, &ENTRY_CORPOREALIZE_176880298140876486)],
        &[(0b10010, &ENTRY_CORPOREALIZED_4844383411397455314)],
        &[(0b10010, &ENTRY_CORPOREALIZES_12122791156138928858)],
        &[(0b10010, &ENTRY_CORPOREALIZING_13300853358390651516)],
        &[(0b01001, &ENTRY_CORPOREALIZATION_7151572681191131638)],
        &[(0b01001, &ENTRY_CORPOREALIZATIONS_4194611580429909973)],
        &[(0b01001, &ENTRY_CORPOREALIZE_176880298140876486)],
        &[(0b01001, &ENTRY_CORPOREALIZED_4844383411397455314)],
        &[(0b01001, &ENTRY_CORPOREALIZES_12122791156138928858)],
        &[(0b01001, &ENTRY_CORPOREALIZING_13300853358390651516)],
        &[(0b00001, &ENTRY_CORSY_2581357179624818778)],
        &[(0b00001, &ENTRY_CORTAGE_240810678292962993)],
        &[(0b00001, &ENTRY_CORTIN_15506462001994757631)],
        &[(0b11010, &ENTRY_CORTINE_7414842809696171862)],
        &[(0b00001, &ENTRY_CORTINE_7414842809696171862)],
        &[(0b11010, &ENTRY_CORVE_469980777380433756)],
        &[(0b00001, &ENTRY_CORVE_469980777380433756)],
        &[(0b11010, &ENTRY_CORYPHE_12873350252360823738)],
        &[(0b11010, &ENTRY_CORYPHES_2551099835554491861)],
        &[(0b00001, &ENTRY_CORYPHE_12873350252360823738)],
        &[(0b00001, &ENTRY_CORYPHES_2551099835554491861)],
    ],
    range: 2..=14,
};

static VARS_COP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COP_CHILDREN),
    value: None,
};

pub static VARS_COP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olymerisation"),
        dictgen::InsensitiveStr::Ascii("olymerisations"),
        dictgen::InsensitiveStr::Ascii("olymerise"),
        dictgen::InsensitiveStr::Ascii("olymerised"),
        dictgen::InsensitiveStr::Ascii("olymerises"),
        dictgen::InsensitiveStr::Ascii("olymerising"),
        dictgen::InsensitiveStr::Ascii("olymerization"),
        dictgen::InsensitiveStr::Ascii("olymerizations"),
        dictgen::InsensitiveStr::Ascii("olymerize"),
        dictgen::InsensitiveStr::Ascii("olymerized"),
        dictgen::InsensitiveStr::Ascii("olymerizes"),
        dictgen::InsensitiveStr::Ascii("olymerizing"),
        dictgen::InsensitiveStr::Ascii("perisation"),
        dictgen::InsensitiveStr::Ascii("perisations"),
        dictgen::InsensitiveStr::Ascii("perise"),
        dictgen::InsensitiveStr::Ascii("perises"),
        dictgen::InsensitiveStr::Ascii("perization"),
        dictgen::InsensitiveStr::Ascii("perizations"),
        dictgen::InsensitiveStr::Ascii("perize"),
        dictgen::InsensitiveStr::Ascii("perizes"),
        dictgen::InsensitiveStr::Ascii("raemia"),
        dictgen::InsensitiveStr::Ascii("raemic"),
        dictgen::InsensitiveStr::Ascii("remia"),
        dictgen::InsensitiveStr::Ascii("remic"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COPOLYMERIZATION_9906853656154549423)],
        &[(0b10010, &ENTRY_COPOLYMERIZATIONS_1735711282043986975)],
        &[(0b10010, &ENTRY_COPOLYMERIZE_2974760063313637629)],
        &[(0b10010, &ENTRY_COPOLYMERIZED_4836344646706287325)],
        &[(0b10010, &ENTRY_COPOLYMERIZES_3215794498833268659)],
        &[(0b10010, &ENTRY_COPOLYMERIZING_343564958295258899)],
        &[(0b01001, &ENTRY_COPOLYMERIZATION_9906853656154549423)],
        &[(0b01001, &ENTRY_COPOLYMERIZATIONS_1735711282043986975)],
        &[(0b01001, &ENTRY_COPOLYMERIZE_2974760063313637629)],
        &[(0b01001, &ENTRY_COPOLYMERIZED_4836344646706287325)],
        &[(0b01001, &ENTRY_COPOLYMERIZES_3215794498833268659)],
        &[(0b01001, &ENTRY_COPOLYMERIZING_343564958295258899)],
        &[(0b10010, &ENTRY_COPPERIZATION_2232365228358153481)],
        &[(0b10010, &ENTRY_COPPERIZATIONS_3873804989120766921)],
        &[(0b10010, &ENTRY_COPPERIZE_11487691990144705431)],
        &[(0b10010, &ENTRY_COPPERIZES_10154527404496674895)],
        &[(0b01001, &ENTRY_COPPERIZATION_2232365228358153481)],
        &[(0b01001, &ENTRY_COPPERIZATIONS_3873804989120766921)],
        &[(0b01001, &ENTRY_COPPERIZE_11487691990144705431)],
        &[(0b01001, &ENTRY_COPPERIZES_10154527404496674895)],
        &[(0b11010, &ENTRY_COPREMIA_979590469354878339)],
        &[(0b11010, &ENTRY_COPREMIC_2536455939195658636)],
        &[(0b10001, &ENTRY_COPREMIA_979590469354878339)],
        &[(0b10001, &ENTRY_COPREMIC_2536455939195658636)],
    ],
    range: 5..=14,
};

static VARS_COO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COO_CHILDREN),
    value: None,
};

pub static VARS_COO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ky"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COE_15056580635786997263)],
        &[(0b00001, &ENTRY_COOKIE_9287663065088073450)],
    ],
    range: 1..=2,
};

static VARS_CON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CON_CHILDREN),
    value: None,
};

static VARS_CON_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_CONC_NODE),
    Some(&VARS_COND_NODE),
    None,
    Some(&VARS_CONF_NODE),
    Some(&VARS_CONG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CONN_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_CONS_NODE),
    Some(&VARS_CONT_NODE),
    Some(&VARS_CONU_NODE),
    Some(&VARS_CONV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_CONV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONV_CHILDREN),
    value: None,
};

pub static VARS_CONV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entionalisation"),
        dictgen::InsensitiveStr::Ascii("entionalisations"),
        dictgen::InsensitiveStr::Ascii("entionalise"),
        dictgen::InsensitiveStr::Ascii("entionalised"),
        dictgen::InsensitiveStr::Ascii("entionalises"),
        dictgen::InsensitiveStr::Ascii("entionalising"),
        dictgen::InsensitiveStr::Ascii("entionalization"),
        dictgen::InsensitiveStr::Ascii("entionalizations"),
        dictgen::InsensitiveStr::Ascii("entionalize"),
        dictgen::InsensitiveStr::Ascii("entionalized"),
        dictgen::InsensitiveStr::Ascii("entionalizes"),
        dictgen::InsensitiveStr::Ascii("entionalizing"),
        dictgen::InsensitiveStr::Ascii("entionise"),
        dictgen::InsensitiveStr::Ascii("entionises"),
        dictgen::InsensitiveStr::Ascii("entionize"),
        dictgen::InsensitiveStr::Ascii("entionizes"),
        dictgen::InsensitiveStr::Ascii("ersationise"),
        dictgen::InsensitiveStr::Ascii("ersationises"),
        dictgen::InsensitiveStr::Ascii("ersationize"),
        dictgen::InsensitiveStr::Ascii("ersationizes"),
        dictgen::InsensitiveStr::Ascii("ertor"),
        dictgen::InsensitiveStr::Ascii("ertors"),
        dictgen::InsensitiveStr::Ascii("eyorise"),
        dictgen::InsensitiveStr::Ascii("eyorised"),
        dictgen::InsensitiveStr::Ascii("eyorises"),
        dictgen::InsensitiveStr::Ascii("eyorising"),
        dictgen::InsensitiveStr::Ascii("eyorize"),
        dictgen::InsensitiveStr::Ascii("eyorized"),
        dictgen::InsensitiveStr::Ascii("eyorizes"),
        dictgen::InsensitiveStr::Ascii("eyorizing"),
        dictgen::InsensitiveStr::Ascii("ivialise"),
        dictgen::InsensitiveStr::Ascii("ivialises"),
        dictgen::InsensitiveStr::Ascii("ivialize"),
        dictgen::InsensitiveStr::Ascii("ivializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONVENTIONALIZATION_9500763137802119350)],
        &[(0b10010, &ENTRY_CONVENTIONALIZATIONS_17887109827005802547)],
        &[(0b10010, &ENTRY_CONVENTIONALIZE_8965825227981389572)],
        &[(0b10010, &ENTRY_CONVENTIONALIZED_2515352950983299261)],
        &[(0b10010, &ENTRY_CONVENTIONALIZES_9956067957387320740)],
        &[(0b10010, &ENTRY_CONVENTIONALIZING_1207910973175187527)],
        &[(0b01001, &ENTRY_CONVENTIONALIZATION_9500763137802119350)],
        &[(0b01001, &ENTRY_CONVENTIONALIZATIONS_17887109827005802547)],
        &[(0b01001, &ENTRY_CONVENTIONALIZE_8965825227981389572)],
        &[(0b01001, &ENTRY_CONVENTIONALIZED_2515352950983299261)],
        &[(0b01001, &ENTRY_CONVENTIONALIZES_9956067957387320740)],
        &[(0b01001, &ENTRY_CONVENTIONALIZING_1207910973175187527)],
        &[(0b10010, &ENTRY_CONVENTIONIZE_7190828471187981506)],
        &[(0b10010, &ENTRY_CONVENTIONIZES_8607084348592237232)],
        &[(0b01001, &ENTRY_CONVENTIONIZE_7190828471187981506)],
        &[(0b01001, &ENTRY_CONVENTIONIZES_8607084348592237232)],
        &[(0b10010, &ENTRY_CONVERSATIONIZE_10644563930821457875)],
        &[(0b10010, &ENTRY_CONVERSATIONIZES_18287566729258936019)],
        &[(0b01001, &ENTRY_CONVERSATIONIZE_10644563930821457875)],
        &[(0b01001, &ENTRY_CONVERSATIONIZES_18287566729258936019)],
        &[
            (0b10011, &ENTRY_CONVERTER_11042638331866408272),
            (0b10010, &ENTRY_CONVERTER_9597145040682608749),
        ],
        &[
            (0b10011, &ENTRY_CONVERTERS_18202666178479349443),
            (0b10010, &ENTRY_CONVERTERS_2794867188871344776),
        ],
        &[(0b10010, &ENTRY_CONVEYORIZE_7183391646528291733)],
        &[(0b10010, &ENTRY_CONVEYORIZED_4580194486713878999)],
        &[(0b10010, &ENTRY_CONVEYORIZES_8443332349483946519)],
        &[(0b10010, &ENTRY_CONVEYORIZING_193492211454742065)],
        &[(0b01001, &ENTRY_CONVEYORIZE_7183391646528291733)],
        &[(0b01001, &ENTRY_CONVEYORIZED_4580194486713878999)],
        &[(0b01001, &ENTRY_CONVEYORIZES_8443332349483946519)],
        &[(0b01001, &ENTRY_CONVEYORIZING_193492211454742065)],
        &[(0b10010, &ENTRY_CONVIVIALIZE_10958239774543390437)],
        &[(0b10010, &ENTRY_CONVIVIALIZES_10501313390440810552)],
        &[(0b01001, &ENTRY_CONVIVIALIZE_10958239774543390437)],
        &[(0b01001, &ENTRY_CONVIVIALIZES_10501313390440810552)],
    ],
    range: 5..=16,
};

static VARS_CONU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONU_CHILDREN),
    value: None,
};

pub static VARS_CONU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ndrumise"),
        dictgen::InsensitiveStr::Ascii("ndrumises"),
        dictgen::InsensitiveStr::Ascii("ndrumize"),
        dictgen::InsensitiveStr::Ascii("ndrumizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONUNDRUMIZE_12445914040901915336)],
        &[(0b10010, &ENTRY_CONUNDRUMIZES_5697079552794062501)],
        &[(0b01001, &ENTRY_CONUNDRUMIZE_12445914040901915336)],
        &[(0b01001, &ENTRY_CONUNDRUMIZES_5697079552794062501)],
    ],
    range: 8..=9,
};

static VARS_CONT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONT_CHILDREN),
    value: None,
};

pub static VARS_CONT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ainerisation"),
        dictgen::InsensitiveStr::Ascii("ainerisations"),
        dictgen::InsensitiveStr::Ascii("ainerise"),
        dictgen::InsensitiveStr::Ascii("ainerised"),
        dictgen::InsensitiveStr::Ascii("ainerises"),
        dictgen::InsensitiveStr::Ascii("ainerising"),
        dictgen::InsensitiveStr::Ascii("ainerization"),
        dictgen::InsensitiveStr::Ascii("ainerizations"),
        dictgen::InsensitiveStr::Ascii("ainerize"),
        dictgen::InsensitiveStr::Ascii("ainerized"),
        dictgen::InsensitiveStr::Ascii("ainerizes"),
        dictgen::InsensitiveStr::Ascii("ainerizing"),
        dictgen::InsensitiveStr::Ascii("emporisation"),
        dictgen::InsensitiveStr::Ascii("emporise"),
        dictgen::InsensitiveStr::Ascii("emporised"),
        dictgen::InsensitiveStr::Ascii("emporises"),
        dictgen::InsensitiveStr::Ascii("emporising"),
        dictgen::InsensitiveStr::Ascii("emporization"),
        dictgen::InsensitiveStr::Ascii("emporize"),
        dictgen::InsensitiveStr::Ascii("emporized"),
        dictgen::InsensitiveStr::Ascii("emporizes"),
        dictgen::InsensitiveStr::Ascii("emporizing"),
        dictgen::InsensitiveStr::Ascii("extualisation"),
        dictgen::InsensitiveStr::Ascii("extualisations"),
        dictgen::InsensitiveStr::Ascii("extualise"),
        dictgen::InsensitiveStr::Ascii("extualised"),
        dictgen::InsensitiveStr::Ascii("extualises"),
        dictgen::InsensitiveStr::Ascii("extualising"),
        dictgen::InsensitiveStr::Ascii("extualization"),
        dictgen::InsensitiveStr::Ascii("extualizations"),
        dictgen::InsensitiveStr::Ascii("extualize"),
        dictgen::InsensitiveStr::Ascii("extualized"),
        dictgen::InsensitiveStr::Ascii("extualizes"),
        dictgen::InsensitiveStr::Ascii("extualizing"),
        dictgen::InsensitiveStr::Ascii("inentalise"),
        dictgen::InsensitiveStr::Ascii("inentalises"),
        dictgen::InsensitiveStr::Ascii("inentalize"),
        dictgen::InsensitiveStr::Ascii("inentalizes"),
        dictgen::InsensitiveStr::Ascii("roversialise"),
        dictgen::InsensitiveStr::Ascii("roversialises"),
        dictgen::InsensitiveStr::Ascii("roversialize"),
        dictgen::InsensitiveStr::Ascii("roversializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONTAINERIZATION_357714449239345018)],
        &[(0b10010, &ENTRY_CONTAINERIZATIONS_1825293490197224406)],
        &[(0b10010, &ENTRY_CONTAINERIZE_16524442428649009741)],
        &[(0b10010, &ENTRY_CONTAINERIZED_11191961675041311832)],
        &[(0b10010, &ENTRY_CONTAINERIZES_128119427989538890)],
        &[(0b10010, &ENTRY_CONTAINERIZING_13615379785688951746)],
        &[(0b01001, &ENTRY_CONTAINERIZATION_357714449239345018)],
        &[(0b01001, &ENTRY_CONTAINERIZATIONS_1825293490197224406)],
        &[(0b01001, &ENTRY_CONTAINERIZE_16524442428649009741)],
        &[(0b01001, &ENTRY_CONTAINERIZED_11191961675041311832)],
        &[(0b01001, &ENTRY_CONTAINERIZES_128119427989538890)],
        &[(0b01001, &ENTRY_CONTAINERIZING_13615379785688951746)],
        &[(0b10010, &ENTRY_CONTEMPORIZATION_7973281613236719624)],
        &[(0b10010, &ENTRY_CONTEMPORIZE_18324583852979424629)],
        &[(0b10010, &ENTRY_CONTEMPORIZED_17912597175826461474)],
        &[(0b10010, &ENTRY_CONTEMPORIZES_15323099493170636003)],
        &[(0b10010, &ENTRY_CONTEMPORIZING_12751018645468916685)],
        &[(0b01001, &ENTRY_CONTEMPORIZATION_7973281613236719624)],
        &[(0b01001, &ENTRY_CONTEMPORIZE_18324583852979424629)],
        &[(0b01001, &ENTRY_CONTEMPORIZED_17912597175826461474)],
        &[(0b01001, &ENTRY_CONTEMPORIZES_15323099493170636003)],
        &[(0b01001, &ENTRY_CONTEMPORIZING_12751018645468916685)],
        &[(0b10010, &ENTRY_CONTEXTUALIZATION_15725305900345696430)],
        &[(0b10010, &ENTRY_CONTEXTUALIZATIONS_17844118780680419482)],
        &[(0b10010, &ENTRY_CONTEXTUALIZE_1732229238408526525)],
        &[(0b10010, &ENTRY_CONTEXTUALIZED_13151283679008083721)],
        &[(0b10010, &ENTRY_CONTEXTUALIZES_9989549820338407239)],
        &[(0b10010, &ENTRY_CONTEXTUALIZING_15565025679692944311)],
        &[(0b01001, &ENTRY_CONTEXTUALIZATION_15725305900345696430)],
        &[(0b01001, &ENTRY_CONTEXTUALIZATIONS_17844118780680419482)],
        &[(0b01001, &ENTRY_CONTEXTUALIZE_1732229238408526525)],
        &[(0b01001, &ENTRY_CONTEXTUALIZED_13151283679008083721)],
        &[(0b01001, &ENTRY_CONTEXTUALIZES_9989549820338407239)],
        &[(0b01001, &ENTRY_CONTEXTUALIZING_15565025679692944311)],
        &[(0b10010, &ENTRY_CONTINENTALIZE_4849218751129058653)],
        &[(0b10010, &ENTRY_CONTINENTALIZES_7922821302652628557)],
        &[(0b01001, &ENTRY_CONTINENTALIZE_4849218751129058653)],
        &[(0b01001, &ENTRY_CONTINENTALIZES_7922821302652628557)],
        &[(0b10010, &ENTRY_CONTROVERSIALIZE_7578510810226772147)],
        &[(0b10010, &ENTRY_CONTROVERSIALIZES_10595020217935359413)],
        &[(0b01001, &ENTRY_CONTROVERSIALIZE_7578510810226772147)],
        &[(0b01001, &ENTRY_CONTROVERSIALIZES_10595020217935359413)],
    ],
    range: 8..=14,
};

static VARS_CONS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONS_CHILDREN),
    value: None,
};

pub static VARS_CONS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ervatise"),
        dictgen::InsensitiveStr::Ascii("ervatised"),
        dictgen::InsensitiveStr::Ascii("ervatises"),
        dictgen::InsensitiveStr::Ascii("ervatising"),
        dictgen::InsensitiveStr::Ascii("ervatize"),
        dictgen::InsensitiveStr::Ascii("ervatized"),
        dictgen::InsensitiveStr::Ascii("ervatizes"),
        dictgen::InsensitiveStr::Ascii("ervatizing"),
        dictgen::InsensitiveStr::Ascii("onantise"),
        dictgen::InsensitiveStr::Ascii("onantised"),
        dictgen::InsensitiveStr::Ascii("onantises"),
        dictgen::InsensitiveStr::Ascii("onantising"),
        dictgen::InsensitiveStr::Ascii("onantize"),
        dictgen::InsensitiveStr::Ascii("onantized"),
        dictgen::InsensitiveStr::Ascii("onantizes"),
        dictgen::InsensitiveStr::Ascii("onantizing"),
        dictgen::InsensitiveStr::Ascii("titutionalisation"),
        dictgen::InsensitiveStr::Ascii("titutionalisations"),
        dictgen::InsensitiveStr::Ascii("titutionalise"),
        dictgen::InsensitiveStr::Ascii("titutionalised"),
        dictgen::InsensitiveStr::Ascii("titutionalises"),
        dictgen::InsensitiveStr::Ascii("titutionalising"),
        dictgen::InsensitiveStr::Ascii("titutionalization"),
        dictgen::InsensitiveStr::Ascii("titutionalizations"),
        dictgen::InsensitiveStr::Ascii("titutionalize"),
        dictgen::InsensitiveStr::Ascii("titutionalized"),
        dictgen::InsensitiveStr::Ascii("titutionalizes"),
        dictgen::InsensitiveStr::Ascii("titutionalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONSERVATIZE_3646372571466696766)],
        &[(0b10010, &ENTRY_CONSERVATIZED_16667414097441419360)],
        &[(0b10010, &ENTRY_CONSERVATIZES_12340270739151171364)],
        &[(0b10010, &ENTRY_CONSERVATIZING_11488144501185235678)],
        &[(0b01001, &ENTRY_CONSERVATIZE_3646372571466696766)],
        &[(0b01001, &ENTRY_CONSERVATIZED_16667414097441419360)],
        &[(0b01001, &ENTRY_CONSERVATIZES_12340270739151171364)],
        &[(0b01001, &ENTRY_CONSERVATIZING_11488144501185235678)],
        &[(0b10010, &ENTRY_CONSONANTIZE_15868785799560721590)],
        &[(0b10010, &ENTRY_CONSONANTIZED_1739085823699319625)],
        &[(0b10010, &ENTRY_CONSONANTIZES_6704700096758384175)],
        &[(0b10010, &ENTRY_CONSONANTIZING_14994297411492896579)],
        &[(0b01001, &ENTRY_CONSONANTIZE_15868785799560721590)],
        &[(0b01001, &ENTRY_CONSONANTIZED_1739085823699319625)],
        &[(0b01001, &ENTRY_CONSONANTIZES_6704700096758384175)],
        &[(0b01001, &ENTRY_CONSONANTIZING_14994297411492896579)],
        &[(0b10010, &ENTRY_CONSTITUTIONALIZATION_2780065667348017791)],
        &[(0b10010, &ENTRY_CONSTITUTIONALIZATIONS_12583158008471493273)],
        &[(0b10010, &ENTRY_CONSTITUTIONALIZE_10610919002840977320)],
        &[(0b10010, &ENTRY_CONSTITUTIONALIZED_43545588069914801)],
        &[(0b10010, &ENTRY_CONSTITUTIONALIZES_10615302449483893069)],
        &[(0b10010, &ENTRY_CONSTITUTIONALIZING_68455832474437967)],
        &[(0b01001, &ENTRY_CONSTITUTIONALIZATION_2780065667348017791)],
        &[(0b01001, &ENTRY_CONSTITUTIONALIZATIONS_12583158008471493273)],
        &[(0b01001, &ENTRY_CONSTITUTIONALIZE_10610919002840977320)],
        &[(0b01001, &ENTRY_CONSTITUTIONALIZED_43545588069914801)],
        &[(0b01001, &ENTRY_CONSTITUTIONALIZES_10615302449483893069)],
        &[(0b01001, &ENTRY_CONSTITUTIONALIZING_68455832474437967)],
    ],
    range: 8..=18,
};

static VARS_CONN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONN_CHILDREN),
    value: None,
};

pub static VARS_CONN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecter"),
        dictgen::InsensitiveStr::Ascii("ecters"),
        dictgen::InsensitiveStr::Ascii("ectible"),
        dictgen::InsensitiveStr::Ascii("exion"),
        dictgen::InsensitiveStr::Ascii("exions"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CONNECTOR_13923636240148187800)],
        &[(0b00001, &ENTRY_CONNECTORS_2449191281557186850)],
        &[(0b00001, &ENTRY_CONNECTABLE_7524650066461359012)],
        &[(0b10010, &ENTRY_CONNECTION_16157944294383303345)],
        &[(0b10010, &ENTRY_CONNECTIONS_13854358641231956725)],
    ],
    range: 5..=7,
};

static VARS_CONG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONG_CHILDREN),
    value: None,
};

pub static VARS_CONG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enialise"),
        dictgen::InsensitiveStr::Ascii("enialises"),
        dictgen::InsensitiveStr::Ascii("enialize"),
        dictgen::InsensitiveStr::Ascii("enializes"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("oes"),
        dictgen::InsensitiveStr::Ascii("regationalise"),
        dictgen::InsensitiveStr::Ascii("regationalises"),
        dictgen::InsensitiveStr::Ascii("regationalize"),
        dictgen::InsensitiveStr::Ascii("regationalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONGENIALIZE_10692985883053956904)],
        &[(0b10010, &ENTRY_CONGENIALIZES_16044870707549003069)],
        &[(0b01001, &ENTRY_CONGENIALIZE_10692985883053956904)],
        &[(0b01001, &ENTRY_CONGENIALIZES_16044870707549003069)],
        &[(0b00001, &ENTRY_CONGES_7410724732817107806)],
        &[(0b11010, &ENTRY_CONGES_7410724732817107806)],
        &[(0b10010, &ENTRY_CONGREGATIONALIZE_11421943368574877519)],
        &[(0b10010, &ENTRY_CONGREGATIONALIZES_320017757737745163)],
        &[(0b01001, &ENTRY_CONGREGATIONALIZE_11421943368574877519)],
        &[(0b01001, &ENTRY_CONGREGATIONALIZES_320017757737745163)],
    ],
    range: 2..=14,
};

static VARS_CONF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONF_CHILDREN),
    value: None,
};

pub static VARS_CONF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ederatise"),
        dictgen::InsensitiveStr::Ascii("ederatises"),
        dictgen::InsensitiveStr::Ascii("ederatize"),
        dictgen::InsensitiveStr::Ascii("ederatizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONFEDERATIZE_2482426421068477118)],
        &[(0b10010, &ENTRY_CONFEDERATIZES_11332452239971933051)],
        &[(0b01001, &ENTRY_CONFEDERATIZE_2482426421068477118)],
        &[(0b01001, &ENTRY_CONFEDERATIZES_11332452239971933051)],
    ],
    range: 9..=10,
};

static VARS_COND_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COND_CHILDREN),
    value: None,
};

pub static VARS_COND_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itionalise"),
        dictgen::InsensitiveStr::Ascii("itionalises"),
        dictgen::InsensitiveStr::Ascii("itionalize"),
        dictgen::InsensitiveStr::Ascii("itionalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONDITIONALIZE_17715539903517618589)],
        &[(0b10010, &ENTRY_CONDITIONALIZES_12954903983960396279)],
        &[(0b01001, &ENTRY_CONDITIONALIZE_17715539903517618589)],
        &[(0b01001, &ENTRY_CONDITIONALIZES_12954903983960396279)],
    ],
    range: 10..=11,
};

static VARS_CONC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONC_CHILDREN),
    value: None,
};

pub static VARS_CONC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("entered"),
        dictgen::InsensitiveStr::Ascii("entering"),
        dictgen::InsensitiveStr::Ascii("enters"),
        dictgen::InsensitiveStr::Ascii("entre"),
        dictgen::InsensitiveStr::Ascii("entred"),
        dictgen::InsensitiveStr::Ascii("entres"),
        dictgen::InsensitiveStr::Ascii("entring"),
        dictgen::InsensitiveStr::Ascii("eptualisation"),
        dictgen::InsensitiveStr::Ascii("eptualisations"),
        dictgen::InsensitiveStr::Ascii("eptualise"),
        dictgen::InsensitiveStr::Ascii("eptualised"),
        dictgen::InsensitiveStr::Ascii("eptualiser"),
        dictgen::InsensitiveStr::Ascii("eptualises"),
        dictgen::InsensitiveStr::Ascii("eptualising"),
        dictgen::InsensitiveStr::Ascii("eptualization"),
        dictgen::InsensitiveStr::Ascii("eptualizations"),
        dictgen::InsensitiveStr::Ascii("eptualize"),
        dictgen::InsensitiveStr::Ascii("eptualized"),
        dictgen::InsensitiveStr::Ascii("eptualizer"),
        dictgen::InsensitiveStr::Ascii("eptualizes"),
        dictgen::InsensitiveStr::Ascii("eptualizing"),
        dictgen::InsensitiveStr::Ascii("ertise"),
        dictgen::InsensitiveStr::Ascii("ertised"),
        dictgen::InsensitiveStr::Ascii("ertiser"),
        dictgen::InsensitiveStr::Ascii("ertisers"),
        dictgen::InsensitiveStr::Ascii("ertises"),
        dictgen::InsensitiveStr::Ascii("ertising"),
        dictgen::InsensitiveStr::Ascii("ertist"),
        dictgen::InsensitiveStr::Ascii("ertize"),
        dictgen::InsensitiveStr::Ascii("ertized"),
        dictgen::InsensitiveStr::Ascii("ertizer"),
        dictgen::InsensitiveStr::Ascii("ertizers"),
        dictgen::InsensitiveStr::Ascii("ertizes"),
        dictgen::InsensitiveStr::Ascii("ertizing"),
        dictgen::InsensitiveStr::Ascii("hae"),
        dictgen::InsensitiveStr::Ascii("he"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olorous"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("olourous"),
        dictgen::InsensitiveStr::Ascii("retisation"),
        dictgen::InsensitiveStr::Ascii("retisations"),
        dictgen::InsensitiveStr::Ascii("retise"),
        dictgen::InsensitiveStr::Ascii("retised"),
        dictgen::InsensitiveStr::Ascii("retises"),
        dictgen::InsensitiveStr::Ascii("retising"),
        dictgen::InsensitiveStr::Ascii("retist"),
        dictgen::InsensitiveStr::Ascii("retization"),
        dictgen::InsensitiveStr::Ascii("retizations"),
        dictgen::InsensitiveStr::Ascii("retize"),
        dictgen::InsensitiveStr::Ascii("retized"),
        dictgen::InsensitiveStr::Ascii("retizes"),
        dictgen::InsensitiveStr::Ascii("retizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CONCENTER_14635484834787157155)],
        &[(0b00001, &ENTRY_CONCENTERED_10443891162354344149)],
        &[(0b00001, &ENTRY_CONCENTERING_12833772605844930946)],
        &[(0b00001, &ENTRY_CONCENTERS_7325901945687233731)],
        &[(0b11010, &ENTRY_CONCENTER_14635484834787157155)],
        &[(0b11010, &ENTRY_CONCENTERED_10443891162354344149)],
        &[(0b11010, &ENTRY_CONCENTERS_7325901945687233731)],
        &[(0b11010, &ENTRY_CONCENTERING_12833772605844930946)],
        &[(0b10010, &ENTRY_CONCEPTUALIZATION_1957977035290831317)],
        &[(0b10010, &ENTRY_CONCEPTUALIZATIONS_1431558151182672246)],
        &[(0b10010, &ENTRY_CONCEPTUALIZE_14569429550467897306)],
        &[(0b10010, &ENTRY_CONCEPTUALIZED_16855689032804433939)],
        &[(0b10010, &ENTRY_CONCEPTUALIZER_14985502701134901202)],
        &[(0b10010, &ENTRY_CONCEPTUALIZES_3109330931899076925)],
        &[(0b10010, &ENTRY_CONCEPTUALIZING_3830098906802741483)],
        &[(0b01001, &ENTRY_CONCEPTUALIZATION_1957977035290831317)],
        &[(0b01001, &ENTRY_CONCEPTUALIZATIONS_1431558151182672246)],
        &[(0b01001, &ENTRY_CONCEPTUALIZE_14569429550467897306)],
        &[(0b01001, &ENTRY_CONCEPTUALIZED_16855689032804433939)],
        &[(0b01001, &ENTRY_CONCEPTUALIZER_14985502701134901202)],
        &[(0b01001, &ENTRY_CONCEPTUALIZES_3109330931899076925)],
        &[(0b01001, &ENTRY_CONCEPTUALIZING_3830098906802741483)],
        &[(0b10010, &ENTRY_CONCERTIZE_6315390562327616511)],
        &[(0b10010, &ENTRY_CONCERTIZED_8186570394307997010)],
        &[(0b10010, &ENTRY_CONCERTIZER_8023331987711270226)],
        &[(0b10010, &ENTRY_CONCERTIZERS_16324384319575570385)],
        &[(0b10010, &ENTRY_CONCERTIZES_16396741238386452819)],
        &[(0b10010, &ENTRY_CONCERTIZING_8848777050159359780)],
        &[(0b00001, &ENTRY_CONCERTIST_12843597612273738002)],
        &[(0b01001, &ENTRY_CONCERTIZE_6315390562327616511)],
        &[(0b01001, &ENTRY_CONCERTIZED_8186570394307997010)],
        &[(0b01001, &ENTRY_CONCERTIZER_8023331987711270226)],
        &[(0b01001, &ENTRY_CONCERTIZERS_16324384319575570385)],
        &[(0b01001, &ENTRY_CONCERTIZES_16396741238386452819)],
        &[(0b01001, &ENTRY_CONCERTIZING_8848777050159359780)],
        &[(0b11010, &ENTRY_CONCHE_5133084355374835635)],
        &[(0b00001, &ENTRY_CONCHE_5133084355374835635)],
        &[(0b00001, &ENTRY_CONCOLOR_1624705544613646046)],
        &[(0b00001, &ENTRY_CONCOLOROUS_17104772201009728838)],
        &[(0b11010, &ENTRY_CONCOLOR_1624705544613646046)],
        &[(0b11010, &ENTRY_CONCOLOROUS_17104772201009728838)],
        &[(0b10010, &ENTRY_CONCRETIZATION_16748795997403623068)],
        &[(0b10010, &ENTRY_CONCRETIZATIONS_16577819847117636011)],
        &[(0b10010, &ENTRY_CONCRETIZE_2393131352307099452)],
        &[(0b10010, &ENTRY_CONCRETIZED_11886059222443029705)],
        &[(0b10010, &ENTRY_CONCRETIZES_14708644144755990132)],
        &[(0b10010, &ENTRY_CONCRETIZING_6612279978454068181)],
        &[(0b11010, &ENTRY_CONCERTIST_12843597612273738002)],
        &[(0b01001, &ENTRY_CONCRETIZATION_16748795997403623068)],
        &[(0b01001, &ENTRY_CONCRETIZATIONS_16577819847117636011)],
        &[(0b01001, &ENTRY_CONCRETIZE_2393131352307099452)],
        &[(0b01001, &ENTRY_CONCRETIZED_11886059222443029705)],
        &[(0b01001, &ENTRY_CONCRETIZES_14708644144755990132)],
        &[(0b01001, &ENTRY_CONCRETIZING_6612279978454068181)],
    ],
    range: 2..=14,
};

static VARS_COM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_COM_CHILDREN),
    value: None,
};

static VARS_COM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_COME_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_COMM_NODE),
    None,
    Some(&VARS_COMO_NODE),
    Some(&VARS_COMP_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_COMP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COMP_CHILDREN),
    value: None,
};

pub static VARS_COMP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anionise"),
        dictgen::InsensitiveStr::Ascii("anionises"),
        dictgen::InsensitiveStr::Ascii("anionize"),
        dictgen::InsensitiveStr::Ascii("anionizes"),
        dictgen::InsensitiveStr::Ascii("artmentalisation"),
        dictgen::InsensitiveStr::Ascii("artmentalisations"),
        dictgen::InsensitiveStr::Ascii("artmentalise"),
        dictgen::InsensitiveStr::Ascii("artmentalised"),
        dictgen::InsensitiveStr::Ascii("artmentalises"),
        dictgen::InsensitiveStr::Ascii("artmentalising"),
        dictgen::InsensitiveStr::Ascii("artmentalization"),
        dictgen::InsensitiveStr::Ascii("artmentalizations"),
        dictgen::InsensitiveStr::Ascii("artmentalize"),
        dictgen::InsensitiveStr::Ascii("artmentalized"),
        dictgen::InsensitiveStr::Ascii("artmentalizes"),
        dictgen::InsensitiveStr::Ascii("artmentalizing"),
        dictgen::InsensitiveStr::Ascii("artmentise"),
        dictgen::InsensitiveStr::Ascii("artmentises"),
        dictgen::InsensitiveStr::Ascii("artmentize"),
        dictgen::InsensitiveStr::Ascii("artmentizes"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("lementiser"),
        dictgen::InsensitiveStr::Ascii("lementizer"),
        dictgen::InsensitiveStr::Ascii("oer"),
        dictgen::InsensitiveStr::Ascii("ositae"),
        dictgen::InsensitiveStr::Ascii("osite"),
        dictgen::InsensitiveStr::Ascii("rehensivisation"),
        dictgen::InsensitiveStr::Ascii("rehensivisations"),
        dictgen::InsensitiveStr::Ascii("rehensivise"),
        dictgen::InsensitiveStr::Ascii("rehensivised"),
        dictgen::InsensitiveStr::Ascii("rehensivises"),
        dictgen::InsensitiveStr::Ascii("rehensivising"),
        dictgen::InsensitiveStr::Ascii("rehensivization"),
        dictgen::InsensitiveStr::Ascii("rehensivizations"),
        dictgen::InsensitiveStr::Ascii("rehensivize"),
        dictgen::InsensitiveStr::Ascii("rehensivized"),
        dictgen::InsensitiveStr::Ascii("rehensivizes"),
        dictgen::InsensitiveStr::Ascii("rehensivizing"),
        dictgen::InsensitiveStr::Ascii("risable"),
        dictgen::InsensitiveStr::Ascii("risal"),
        dictgen::InsensitiveStr::Ascii("rizable"),
        dictgen::InsensitiveStr::Ascii("rizal"),
        dictgen::InsensitiveStr::Ascii("uterisable"),
        dictgen::InsensitiveStr::Ascii("uterisation"),
        dictgen::InsensitiveStr::Ascii("uterisations"),
        dictgen::InsensitiveStr::Ascii("uterise"),
        dictgen::InsensitiveStr::Ascii("uterised"),
        dictgen::InsensitiveStr::Ascii("uterises"),
        dictgen::InsensitiveStr::Ascii("uterising"),
        dictgen::InsensitiveStr::Ascii("uterizable"),
        dictgen::InsensitiveStr::Ascii("uterization"),
        dictgen::InsensitiveStr::Ascii("uterizations"),
        dictgen::InsensitiveStr::Ascii("uterize"),
        dictgen::InsensitiveStr::Ascii("uterized"),
        dictgen::InsensitiveStr::Ascii("uterizes"),
        dictgen::InsensitiveStr::Ascii("uterizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COMPANIONIZE_14698523764786642117)],
        &[(0b10010, &ENTRY_COMPANIONIZES_17140744362563906153)],
        &[(0b01001, &ENTRY_COMPANIONIZE_14698523764786642117)],
        &[(0b01001, &ENTRY_COMPANIONIZES_17140744362563906153)],
        &[(0b10010, &ENTRY_COMPARTMENTALIZATION_8817670805873858578)],
        &[(0b10010, &ENTRY_COMPARTMENTALIZATIONS_7803350045421233416)],
        &[(0b10010, &ENTRY_COMPARTMENTALIZE_8466180960814001454)],
        &[(0b10010, &ENTRY_COMPARTMENTALIZED_5318284676300892382)],
        &[(0b10010, &ENTRY_COMPARTMENTALIZES_295558042693607522)],
        &[(0b10010, &ENTRY_COMPARTMENTALIZING_180997580421371176)],
        &[(0b01001, &ENTRY_COMPARTMENTALIZATION_8817670805873858578)],
        &[(0b01001, &ENTRY_COMPARTMENTALIZATIONS_7803350045421233416)],
        &[(0b01001, &ENTRY_COMPARTMENTALIZE_8466180960814001454)],
        &[(0b01001, &ENTRY_COMPARTMENTALIZED_5318284676300892382)],
        &[(0b01001, &ENTRY_COMPARTMENTALIZES_295558042693607522)],
        &[(0b01001, &ENTRY_COMPARTMENTALIZING_180997580421371176)],
        &[(0b10010, &ENTRY_COMPARTMENTIZE_17471420907240441116)],
        &[(0b10010, &ENTRY_COMPARTMENTIZES_10064645464410787449)],
        &[(0b01001, &ENTRY_COMPARTMENTIZE_17471420907240441116)],
        &[(0b01001, &ENTRY_COMPARTMENTIZES_10064645464410787449)],
        &[(0b00001, &ENTRY_COMPER_16144834334055019782)],
        &[(0b10010, &ENTRY_COMPLEMENTIZER_937168745129410584)],
        &[(0b01001, &ENTRY_COMPLEMENTIZER_937168745129410584)],
        &[(0b11010, &ENTRY_COMPER_16144834334055019782)],
        &[(0b11010, &ENTRY_COMPOSITE_12658187924614050642)],
        &[(0b00001, &ENTRY_COMPOSITE_12658187924614050642)],
        &[(0b10010, &ENTRY_COMPREHENSIVIZATION_3208133082700888116)],
        &[(0b10010, &ENTRY_COMPREHENSIVIZATIONS_88315432366576424)],
        &[(0b10010, &ENTRY_COMPREHENSIVIZE_15456592777056386140)],
        &[(0b10010, &ENTRY_COMPREHENSIVIZED_17416398274270240432)],
        &[(0b10010, &ENTRY_COMPREHENSIVIZES_2364696171145838288)],
        &[(0b10010, &ENTRY_COMPREHENSIVIZING_9798923127976660537)],
        &[(0b01001, &ENTRY_COMPREHENSIVIZATION_3208133082700888116)],
        &[(0b01001, &ENTRY_COMPREHENSIVIZATIONS_88315432366576424)],
        &[(0b01001, &ENTRY_COMPREHENSIVIZE_15456592777056386140)],
        &[(0b01001, &ENTRY_COMPREHENSIVIZED_17416398274270240432)],
        &[(0b01001, &ENTRY_COMPREHENSIVIZES_2364696171145838288)],
        &[(0b01001, &ENTRY_COMPREHENSIVIZING_9798923127976660537)],
        &[(0b10010, &ENTRY_COMPRIZABLE_7612510701093420227)],
        &[(0b10010, &ENTRY_COMPRIZAL_7506253949548704435)],
        &[(0b01001, &ENTRY_COMPRIZABLE_7612510701093420227)],
        &[(0b01001, &ENTRY_COMPRIZAL_7506253949548704435)],
        &[(0b10010, &ENTRY_COMPUTERIZABLE_7194148740250173181)],
        &[(0b10010, &ENTRY_COMPUTERIZATION_8388242133507632203)],
        &[(0b10010, &ENTRY_COMPUTERIZATIONS_14988232009287248263)],
        &[(0b10010, &ENTRY_COMPUTERIZE_540581710185506773)],
        &[(0b10010, &ENTRY_COMPUTERIZED_17906439342563202559)],
        &[(0b10010, &ENTRY_COMPUTERIZES_5839612827384030489)],
        &[(0b10010, &ENTRY_COMPUTERIZING_9293272863931059588)],
        &[(0b01001, &ENTRY_COMPUTERIZABLE_7194148740250173181)],
        &[(0b01001, &ENTRY_COMPUTERIZATION_8388242133507632203)],
        &[(0b01001, &ENTRY_COMPUTERIZATIONS_14988232009287248263)],
        &[(0b01001, &ENTRY_COMPUTERIZE_540581710185506773)],
        &[(0b01001, &ENTRY_COMPUTERIZED_17906439342563202559)],
        &[(0b01001, &ENTRY_COMPUTERIZES_5839612827384030489)],
        &[(0b01001, &ENTRY_COMPUTERIZING_9293272863931059588)],
    ],
    range: 2..=17,
};

static VARS_COMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COMO_CHILDREN),
    value: None,
};

pub static VARS_COMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("edia")],
    values: &[&[(0b11010, &ENTRY_COMEDIA_1600668820158737311)]],
    range: 4..=4,
};

static VARS_COMM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COMM_CHILDREN),
    value: None,
};

pub static VARS_COMM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ercialisation"),
        dictgen::InsensitiveStr::Ascii("ercialisations"),
        dictgen::InsensitiveStr::Ascii("ercialise"),
        dictgen::InsensitiveStr::Ascii("ercialised"),
        dictgen::InsensitiveStr::Ascii("ercialises"),
        dictgen::InsensitiveStr::Ascii("ercialising"),
        dictgen::InsensitiveStr::Ascii("ercialization"),
        dictgen::InsensitiveStr::Ascii("ercializations"),
        dictgen::InsensitiveStr::Ascii("ercialize"),
        dictgen::InsensitiveStr::Ascii("ercialized"),
        dictgen::InsensitiveStr::Ascii("ercializes"),
        dictgen::InsensitiveStr::Ascii("ercializing"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("unalisation"),
        dictgen::InsensitiveStr::Ascii("unalisations"),
        dictgen::InsensitiveStr::Ascii("unalise"),
        dictgen::InsensitiveStr::Ascii("unalised"),
        dictgen::InsensitiveStr::Ascii("unaliser"),
        dictgen::InsensitiveStr::Ascii("unalisers"),
        dictgen::InsensitiveStr::Ascii("unalises"),
        dictgen::InsensitiveStr::Ascii("unalising"),
        dictgen::InsensitiveStr::Ascii("unalization"),
        dictgen::InsensitiveStr::Ascii("unalizations"),
        dictgen::InsensitiveStr::Ascii("unalize"),
        dictgen::InsensitiveStr::Ascii("unalized"),
        dictgen::InsensitiveStr::Ascii("unalizer"),
        dictgen::InsensitiveStr::Ascii("unalizers"),
        dictgen::InsensitiveStr::Ascii("unalizes"),
        dictgen::InsensitiveStr::Ascii("unalizing"),
        dictgen::InsensitiveStr::Ascii("unisation"),
        dictgen::InsensitiveStr::Ascii("unisations"),
        dictgen::InsensitiveStr::Ascii("unise"),
        dictgen::InsensitiveStr::Ascii("unised"),
        dictgen::InsensitiveStr::Ascii("unises"),
        dictgen::InsensitiveStr::Ascii("unising"),
        dictgen::InsensitiveStr::Ascii("unization"),
        dictgen::InsensitiveStr::Ascii("unizations"),
        dictgen::InsensitiveStr::Ascii("unize"),
        dictgen::InsensitiveStr::Ascii("unized"),
        dictgen::InsensitiveStr::Ascii("unizes"),
        dictgen::InsensitiveStr::Ascii("unizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COMMERCIALIZATION_11469816268140890812)],
        &[(0b10010, &ENTRY_COMMERCIALIZATIONS_1148877062636686126)],
        &[(0b10010, &ENTRY_COMMERCIALIZE_1137904747608279477)],
        &[(0b10010, &ENTRY_COMMERCIALIZED_2494708843919137706)],
        &[(0b10010, &ENTRY_COMMERCIALIZES_14762377282271056556)],
        &[(0b10010, &ENTRY_COMMERCIALIZING_11104285966117995808)],
        &[(0b01001, &ENTRY_COMMERCIALIZATION_11469816268140890812)],
        &[(0b01001, &ENTRY_COMMERCIALIZATIONS_1148877062636686126)],
        &[(0b01001, &ENTRY_COMMERCIALIZE_1137904747608279477)],
        &[(0b01001, &ENTRY_COMMERCIALIZED_2494708843919137706)],
        &[(0b01001, &ENTRY_COMMERCIALIZES_14762377282271056556)],
        &[(0b01001, &ENTRY_COMMERCIALIZING_11104285966117995808)],
        &[(0b10010, &ENTRY_COMMONIZE_13451392529140004615)],
        &[(0b10010, &ENTRY_COMMONIZES_5349922175331423897)],
        &[(0b01001, &ENTRY_COMMONIZE_13451392529140004615)],
        &[(0b01001, &ENTRY_COMMONIZES_5349922175331423897)],
        &[(0b10010, &ENTRY_COMMUNALIZATION_6966761097767900834)],
        &[(0b10010, &ENTRY_COMMUNALIZATIONS_9017291405367751157)],
        &[(0b10010, &ENTRY_COMMUNALIZE_11496551884840027380)],
        &[(0b10010, &ENTRY_COMMUNALIZED_10899726674894063394)],
        &[(0b10010, &ENTRY_COMMUNALIZER_8227245558039401681)],
        &[(0b10010, &ENTRY_COMMUNALIZERS_15123475272425091783)],
        &[(0b10010, &ENTRY_COMMUNALIZES_10018478960559246487)],
        &[(0b10010, &ENTRY_COMMUNALIZING_10440823094828579805)],
        &[(0b01001, &ENTRY_COMMUNALIZATION_6966761097767900834)],
        &[(0b01001, &ENTRY_COMMUNALIZATIONS_9017291405367751157)],
        &[(0b01001, &ENTRY_COMMUNALIZE_11496551884840027380)],
        &[(0b01001, &ENTRY_COMMUNALIZED_10899726674894063394)],
        &[(0b01001, &ENTRY_COMMUNALIZER_8227245558039401681)],
        &[(0b01001, &ENTRY_COMMUNALIZERS_15123475272425091783)],
        &[(0b01001, &ENTRY_COMMUNALIZES_10018478960559246487)],
        &[(0b01001, &ENTRY_COMMUNALIZING_10440823094828579805)],
        &[(0b10010, &ENTRY_COMMUNIZATION_4610686521220792898)],
        &[(0b10010, &ENTRY_COMMUNIZATIONS_5313326036601660607)],
        &[(0b10010, &ENTRY_COMMUNIZE_14906500406546755200)],
        &[(0b10010, &ENTRY_COMMUNIZED_3470806738778989383)],
        &[(0b10010, &ENTRY_COMMUNIZES_1087544272453039357)],
        &[(0b10010, &ENTRY_COMMUNIZING_7736146114310476831)],
        &[(0b01001, &ENTRY_COMMUNIZATION_4610686521220792898)],
        &[(0b01001, &ENTRY_COMMUNIZATIONS_5313326036601660607)],
        &[(0b01001, &ENTRY_COMMUNIZE_14906500406546755200)],
        &[(0b01001, &ENTRY_COMMUNIZED_3470806738778989383)],
        &[(0b01001, &ENTRY_COMMUNIZES_1087544272453039357)],
        &[(0b01001, &ENTRY_COMMUNIZING_7736146114310476831)],
    ],
    range: 5..=14,
};

static VARS_COME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COME_CHILDREN),
    value: None,
};

pub static VARS_COME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("dia")],
    values: &[&[(0b00001, &ENTRY_COMEDIA_1600668820158737311)]],
    range: 3..=3,
};

static VARS_COL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_COL_CHILDREN),
    value: None,
};

static VARS_COL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_COLL_NODE),
    None,
    None,
    Some(&VARS_COLO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_COLU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_COLU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLU_CHILDREN),
    value: None,
};

pub static VARS_COLU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mnisation"),
        dictgen::InsensitiveStr::Ascii("mnisations"),
        dictgen::InsensitiveStr::Ascii("mnise"),
        dictgen::InsensitiveStr::Ascii("mnised"),
        dictgen::InsensitiveStr::Ascii("mnises"),
        dictgen::InsensitiveStr::Ascii("mnising"),
        dictgen::InsensitiveStr::Ascii("mnization"),
        dictgen::InsensitiveStr::Ascii("mnizations"),
        dictgen::InsensitiveStr::Ascii("mnize"),
        dictgen::InsensitiveStr::Ascii("mnized"),
        dictgen::InsensitiveStr::Ascii("mnizes"),
        dictgen::InsensitiveStr::Ascii("mnizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COLUMNIZATION_5232248272406510285)],
        &[(0b10010, &ENTRY_COLUMNIZATIONS_4008802043920010207)],
        &[(0b10010, &ENTRY_COLUMNIZE_14711333916026596986)],
        &[(0b10010, &ENTRY_COLUMNIZED_1732014965343684845)],
        &[(0b10010, &ENTRY_COLUMNIZES_4402893970233063575)],
        &[(0b10010, &ENTRY_COLUMNIZING_2889638109077339111)],
        &[(0b01001, &ENTRY_COLUMNIZATION_5232248272406510285)],
        &[(0b01001, &ENTRY_COLUMNIZATIONS_4008802043920010207)],
        &[(0b01001, &ENTRY_COLUMNIZE_14711333916026596986)],
        &[(0b01001, &ENTRY_COLUMNIZED_1732014965343684845)],
        &[(0b01001, &ENTRY_COLUMNIZES_4402893970233063575)],
        &[(0b01001, &ENTRY_COLUMNIZING_2889638109077339111)],
    ],
    range: 5..=10,
};

static VARS_COLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_COLO_CHILDREN),
    value: None,
};

static VARS_COLO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_COLON_NODE),
    None,
    None,
    None,
    Some(&VARS_COLOR_NODE),
    None,
    None,
    Some(&VARS_COLOU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_COLOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_COLOU_CHILDREN),
    value: None,
};

static VARS_COLOU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_COLOUR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_COLOUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_COLOUR_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_COLOR_4390088940109675041)]),
};

static VARS_COLOUR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_COLOURA_NODE),
    Some(&VARS_COLOURB_NODE),
    Some(&VARS_COLOURC_NODE),
    None,
    Some(&VARS_COLOURE_NODE),
    Some(&VARS_COLOURF_NODE),
    None,
    None,
    Some(&VARS_COLOURI_NODE),
    None,
    None,
    Some(&VARS_COLOURL_NODE),
    Some(&VARS_COLOURM_NODE),
    None,
    Some(&VARS_COLOURO_NODE),
    Some(&VARS_COLOURP_NODE),
    None,
    Some(&VARS_COLOURR_NODE),
    Some(&VARS_COLOURS_NODE),
    Some(&VARS_COLOURT_NODE),
    None,
    None,
    Some(&VARS_COLOURW_NODE),
    None,
    Some(&VARS_COLOURY_NODE),
    None,
];

static VARS_COLOURY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURY_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_COLORY_692735169960595413)]),
};

pub static VARS_COLOURY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_COLOURW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURW_CHILDREN),
    value: None,
};

pub static VARS_COLOURW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ay"),
        dictgen::InsensitiveStr::Ascii("ays"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORWAY_17470413378276487899)],
        &[(0b11010, &ENTRY_COLORWAYS_4628145222031734139)],
    ],
    range: 2..=3,
};

static VARS_COLOURT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURT_CHILDREN),
    value: None,
};

pub static VARS_COLOURT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ype")],
    values: &[&[(0b11010, &ENTRY_COLORTYPE_8791391695518930895)]],
    range: 3..=3,
};

static VARS_COLOURS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURS_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_COLORS_11482118763257927768)]),
};

pub static VARS_COLOURS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_COLOURR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURR_CHILDREN),
    value: None,
};

pub static VARS_COLOURR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("haphy")],
    values: &[&[(0b11010, &ENTRY_COLORRHAPHY_9426928456383049814)]],
    range: 5..=5,
};

static VARS_COLOURP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURP_CHILDREN),
    value: None,
};

pub static VARS_COLOURP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oint"),
        dictgen::InsensitiveStr::Ascii("oints"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORPOINT_1488326999809355845)],
        &[(0b11010, &ENTRY_COLORPOINTS_5692566788742856472)],
    ],
    range: 4..=5,
};

static VARS_COLOURO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURO_CHILDREN),
    value: None,
};

pub static VARS_COLOURO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("to")],
    values: &[&[(0b11010, &ENTRY_COLOROTO_10920719126014730348)]],
    range: 2..=2,
};

static VARS_COLOURM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURM_CHILDREN),
    value: None,
};

pub static VARS_COLOURM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aker"),
        dictgen::InsensitiveStr::Ascii("aking"),
        dictgen::InsensitiveStr::Ascii("an"),
        dictgen::InsensitiveStr::Ascii("ap"),
        dictgen::InsensitiveStr::Ascii("aps"),
        dictgen::InsensitiveStr::Ascii("en"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORMAKER_18240822022788344542)],
        &[(0b11010, &ENTRY_COLORMAKING_5754969022058419268)],
        &[(0b11010, &ENTRY_COLORMAN_14198957698124507708)],
        &[(0b11010, &ENTRY_COLORMAP_17016045057031205698)],
        &[(0b11010, &ENTRY_COLORMAPS_11344428357452815640)],
        &[(0b11010, &ENTRY_COLORMEN_14804279233130680016)],
    ],
    range: 2..=5,
};

static VARS_COLOURL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURL_CHILDREN),
    value: None,
};

pub static VARS_COLOURL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ess"),
        dictgen::InsensitiveStr::Ascii("esser"),
        dictgen::InsensitiveStr::Ascii("essest"),
        dictgen::InsensitiveStr::Ascii("esslier"),
        dictgen::InsensitiveStr::Ascii("essliest"),
        dictgen::InsensitiveStr::Ascii("essly"),
        dictgen::InsensitiveStr::Ascii("essness"),
        dictgen::InsensitiveStr::Ascii("essnesses"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORLESS_79666121160281791)],
        &[(0b11010, &ENTRY_COLORLESSER_14130375164463853792)],
        &[(0b11010, &ENTRY_COLORLESSEST_14480954022966990260)],
        &[(0b11010, &ENTRY_COLORLESSLIER_4162646048805483531)],
        &[(0b11010, &ENTRY_COLORLESSLIEST_12869681984000132288)],
        &[(0b11010, &ENTRY_COLORLESSLY_13297396459356641001)],
        &[(0b11010, &ENTRY_COLORLESSNESS_9336682862246396379)],
        &[(0b11010, &ENTRY_COLORLESSNESSES_6266382497440905953)],
    ],
    range: 3..=9,
};

static VARS_COLOURI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURI_CHILDREN),
    value: None,
};

pub static VARS_COLOURI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fic"),
        dictgen::InsensitiveStr::Ascii("fics"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("meters"),
        dictgen::InsensitiveStr::Ascii("metric"),
        dictgen::InsensitiveStr::Ascii("metrical"),
        dictgen::InsensitiveStr::Ascii("metrically"),
        dictgen::InsensitiveStr::Ascii("metrics"),
        dictgen::InsensitiveStr::Ascii("metries"),
        dictgen::InsensitiveStr::Ascii("metrist"),
        dictgen::InsensitiveStr::Ascii("metry"),
        dictgen::InsensitiveStr::Ascii("ng"),
        dictgen::InsensitiveStr::Ascii("ngs"),
        dictgen::InsensitiveStr::Ascii("sation"),
        dictgen::InsensitiveStr::Ascii("sations"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("sed"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("sing"),
        dictgen::InsensitiveStr::Ascii("sm"),
        dictgen::InsensitiveStr::Ascii("sms"),
        dictgen::InsensitiveStr::Ascii("st"),
        dictgen::InsensitiveStr::Ascii("stic"),
        dictgen::InsensitiveStr::Ascii("stically"),
        dictgen::InsensitiveStr::Ascii("sticer"),
        dictgen::InsensitiveStr::Ascii("sticest"),
        dictgen::InsensitiveStr::Ascii("stics"),
        dictgen::InsensitiveStr::Ascii("sts"),
        dictgen::InsensitiveStr::Ascii("zation"),
        dictgen::InsensitiveStr::Ascii("zations"),
        dictgen::InsensitiveStr::Ascii("ze"),
        dictgen::InsensitiveStr::Ascii("zed"),
        dictgen::InsensitiveStr::Ascii("zes"),
        dictgen::InsensitiveStr::Ascii("zing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORIFIC_18224680928850475846)],
        &[(0b11010, &ENTRY_COLORIFICS_14988984988237436693)],
        &[(0b11010, &ENTRY_COLORIMETER_7886930247663758657)],
        &[(0b11010, &ENTRY_COLORIMETERS_11304231755461980338)],
        &[(0b11010, &ENTRY_COLORIMETRIC_7191450808866389504)],
        &[(0b11010, &ENTRY_COLORIMETRICAL_5893759513244621607)],
        &[(0b11010, &ENTRY_COLORIMETRICALLY_17982031766432667637)],
        &[(0b11010, &ENTRY_COLORIMETRICS_7899060896503658636)],
        &[(0b11010, &ENTRY_COLORIMETRIES_4002895138139503597)],
        &[(0b11010, &ENTRY_COLORIMETRIST_9206995085391335333)],
        &[(0b11010, &ENTRY_COLORIMETRY_17653132236103689829)],
        &[(0b11010, &ENTRY_COLORING_1146707622868481032)],
        &[(0b11010, &ENTRY_COLORINGS_7915048393125592470)],
        &[(0b10010, &ENTRY_COLORIZATION_14308932529511399348)],
        &[(0b10010, &ENTRY_COLORIZATIONS_18157034030783136605)],
        &[(0b10010, &ENTRY_COLORIZE_18354734970370761815)],
        &[(0b10010, &ENTRY_COLORIZED_960777906946234161)],
        &[(0b10010, &ENTRY_COLORIZES_12131917003294390385)],
        &[(0b10010, &ENTRY_COLORIZING_2471786832873381659)],
        &[(0b11010, &ENTRY_COLORISM_16137276040089598557)],
        &[(0b11010, &ENTRY_COLORISMS_18256708391175621780)],
        &[(0b11010, &ENTRY_COLORIST_17294665081422796979)],
        &[(0b11010, &ENTRY_COLORISTIC_399320276255558866)],
        &[(0b11010, &ENTRY_COLORISTICALLY_5424161462341646669)],
        &[(0b11010, &ENTRY_COLORISTICER_7005818059703147231)],
        &[(0b11010, &ENTRY_COLORISTICEST_2156436723060189793)],
        &[(0b11010, &ENTRY_COLORISTICS_13996615122580621680)],
        &[(0b11010, &ENTRY_COLORISTS_12579547357893269970)],
        &[(0b01000, &ENTRY_COLORIZATION_14308932529511399348)],
        &[(0b01000, &ENTRY_COLORIZATIONS_18157034030783136605)],
        &[(0b01000, &ENTRY_COLORIZE_18354734970370761815)],
        &[(0b01000, &ENTRY_COLORIZED_960777906946234161)],
        &[(0b01000, &ENTRY_COLORIZES_12131917003294390385)],
        &[(0b01000, &ENTRY_COLORIZING_2471786832873381659)],
    ],
    range: 2..=10,
};

static VARS_COLOURF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURF_CHILDREN),
    value: None,
};

pub static VARS_COLOURF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ast"),
        dictgen::InsensitiveStr::Ascii("astness"),
        dictgen::InsensitiveStr::Ascii("astnesses"),
        dictgen::InsensitiveStr::Ascii("ul"),
        dictgen::InsensitiveStr::Ascii("uler"),
        dictgen::InsensitiveStr::Ascii("ulest"),
        dictgen::InsensitiveStr::Ascii("ullier"),
        dictgen::InsensitiveStr::Ascii("ulliest"),
        dictgen::InsensitiveStr::Ascii("ully"),
        dictgen::InsensitiveStr::Ascii("ulness"),
        dictgen::InsensitiveStr::Ascii("ulnesses"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORFAST_6749057993199514856)],
        &[(0b11010, &ENTRY_COLORFASTNESS_17325104284808699862)],
        &[(0b11010, &ENTRY_COLORFASTNESSES_10917750449768357558)],
        &[(0b11010, &ENTRY_COLORFUL_4806683583475489506)],
        &[(0b11010, &ENTRY_COLORFULER_4366882207953732907)],
        &[(0b11010, &ENTRY_COLORFULEST_15151264088558637473)],
        &[(0b11010, &ENTRY_COLORFULLIER_12948386305746310089)],
        &[(0b11010, &ENTRY_COLORFULLIEST_14305289677627923994)],
        &[(0b11010, &ENTRY_COLORFULLY_12792342106302406309)],
        &[(0b11010, &ENTRY_COLORFULNESS_15839726768009061296)],
        &[(0b11010, &ENTRY_COLORFULNESSES_12191353247710978564)],
    ],
    range: 2..=9,
};

static VARS_COLOURE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURE_CHILDREN),
    value: None,
};

pub static VARS_COLOURE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ctal"),
        dictgen::InsensitiveStr::Ascii("ctitis"),
        dictgen::InsensitiveStr::Ascii("ctostomy"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("ds"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("st"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORECTAL_11824441472361931850)],
        &[(0b11010, &ENTRY_COLORECTITIS_18158962813924379828)],
        &[(0b11010, &ENTRY_COLORECTOSTOMY_15787993662663226229)],
        &[(0b11010, &ENTRY_COLORED_16993799574214757686)],
        &[(0b11010, &ENTRY_COLOREDS_3930825355719143828)],
        &[(0b11010, &ENTRY_COLORER_14593090349752845026)],
        &[(0b11010, &ENTRY_COLORERS_13681356278503403951)],
        &[(0b11010, &ENTRY_COLORREST_13441910764710538786)],
    ],
    range: 1..=8,
};

static VARS_COLOURC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURC_CHILDREN),
    value: None,
};

pub static VARS_COLOURC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ast"),
        dictgen::InsensitiveStr::Ascii("asted"),
        dictgen::InsensitiveStr::Ascii("aster"),
        dictgen::InsensitiveStr::Ascii("asters"),
        dictgen::InsensitiveStr::Ascii("asting"),
        dictgen::InsensitiveStr::Ascii("asts"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORCAST_2201027249760625617)],
        &[(0b11010, &ENTRY_COLORCASTED_15703965836749186308)],
        &[(0b11010, &ENTRY_COLORCASTER_3993571528628164298)],
        &[(0b11010, &ENTRY_COLORCASTERS_6200168122277172332)],
        &[(0b11010, &ENTRY_COLORCASTING_18326831152918404831)],
        &[(0b11010, &ENTRY_COLORCASTS_15491829989405229642)],
    ],
    range: 3..=6,
};

static VARS_COLOURB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURB_CHILDREN),
    value: None,
};

pub static VARS_COLOURB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("earer"),
        dictgen::InsensitiveStr::Ascii("lind"),
        dictgen::InsensitiveStr::Ascii("lindness"),
        dictgen::InsensitiveStr::Ascii("lindnesses"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("reed"),
        dictgen::InsensitiveStr::Ascii("reeding"),
        dictgen::InsensitiveStr::Ascii("reeds"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORBEARER_16302991417022897520)],
        &[(0b11010, &ENTRY_COLORBLIND_16694090854179664434)],
        &[(0b11010, &ENTRY_COLORBLINDNESS_18174910962271343344)],
        &[(0b11010, &ENTRY_COLORBLINDNESSES_14269141498431512170)],
        &[(0b11010, &ENTRY_COLORBRED_5216310496600520453)],
        &[(0b11010, &ENTRY_COLORBREED_5358779689549478848)],
        &[(0b11010, &ENTRY_COLORBREEDING_14340643893363063008)],
        &[(0b11010, &ENTRY_COLORBREEDS_11113473641764637830)],
    ],
    range: 3..=10,
};

static VARS_COLOURA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURA_CHILDREN),
    value: None,
};

pub static VARS_COLOURA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilities"),
        dictgen::InsensitiveStr::Ascii("bility"),
        dictgen::InsensitiveStr::Ascii("ble"),
        dictgen::InsensitiveStr::Ascii("bleness"),
        dictgen::InsensitiveStr::Ascii("blenesses"),
        dictgen::InsensitiveStr::Ascii("bler"),
        dictgen::InsensitiveStr::Ascii("bles"),
        dictgen::InsensitiveStr::Ascii("blest"),
        dictgen::InsensitiveStr::Ascii("blier"),
        dictgen::InsensitiveStr::Ascii("blies"),
        dictgen::InsensitiveStr::Ascii("bliest"),
        dictgen::InsensitiveStr::Ascii("bly"),
        dictgen::InsensitiveStr::Ascii("doite"),
        dictgen::InsensitiveStr::Ascii("ma"),
        dictgen::InsensitiveStr::Ascii("nt"),
        dictgen::InsensitiveStr::Ascii("nts"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("tion"),
        dictgen::InsensitiveStr::Ascii("tional"),
        dictgen::InsensitiveStr::Ascii("tionaler"),
        dictgen::InsensitiveStr::Ascii("tionalest"),
        dictgen::InsensitiveStr::Ascii("tionallier"),
        dictgen::InsensitiveStr::Ascii("tionalliest"),
        dictgen::InsensitiveStr::Ascii("tionally"),
        dictgen::InsensitiveStr::Ascii("tions"),
        dictgen::InsensitiveStr::Ascii("tive"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORABILITIES_9958964032688729898)],
        &[(0b11010, &ENTRY_COLORABILITY_4981844209136751100)],
        &[(0b11010, &ENTRY_COLORABLE_7050710397577980432)],
        &[(0b11010, &ENTRY_COLORABLENESS_2481325297280462095)],
        &[(0b11010, &ENTRY_COLORABLENESSES_3851955312082062820)],
        &[(0b11010, &ENTRY_COLORABLER_9668141786678165672)],
        &[(0b11010, &ENTRY_COLORABLES_9835654246095695799)],
        &[(0b11010, &ENTRY_COLORABLEST_7942972157513237380)],
        &[(0b11010, &ENTRY_COLORABLIER_6977421189014021102)],
        &[(0b11010, &ENTRY_COLORABLIES_12294270181831783929)],
        &[(0b11010, &ENTRY_COLORABLIEST_11146624897447970828)],
        &[(0b11010, &ENTRY_COLORABLY_9468463993023925722)],
        &[(0b11010, &ENTRY_COLORADOITE_8833920578577260105)],
        &[(0b11010, &ENTRY_COLORAMA_1846226585848796493)],
        &[(0b11010, &ENTRY_COLORANT_8508078357677443619)],
        &[(0b11010, &ENTRY_COLORANTS_5504580436166605292)],
        &[(0b11010, &ENTRY_COLORATE_1487899690349145487)],
        &[(0b11010, &ENTRY_COLORATION_16722034247789816535)],
        &[(0b11010, &ENTRY_COLORATIONAL_16753288079293957487)],
        &[(0b11010, &ENTRY_COLORATIONALER_2315908441786659774)],
        &[(0b11010, &ENTRY_COLORATIONALEST_18397653125866719085)],
        &[(0b11010, &ENTRY_COLORATIONALLIER_11478779488477057274)],
        &[(0b11010, &ENTRY_COLORATIONALLIEST_10706588560840167842)],
        &[(0b11010, &ENTRY_COLORATIONALLY_858328911743147657)],
        &[(0b11010, &ENTRY_COLORATIONS_10032620475490215127)],
        &[(0b11010, &ENTRY_COLORATIVE_10364780649786282163)],
    ],
    range: 2..=11,
};

static VARS_COLOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_COLOR_CHILDREN),
    value: Some(&[(0b11001, &ENTRY_COLOR_4390088940109675041)]),
};

static VARS_COLOR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_COLORA_NODE),
    Some(&VARS_COLORB_NODE),
    Some(&VARS_COLORC_NODE),
    None,
    Some(&VARS_COLORE_NODE),
    Some(&VARS_COLORF_NODE),
    None,
    None,
    Some(&VARS_COLORI_NODE),
    None,
    None,
    Some(&VARS_COLORL_NODE),
    Some(&VARS_COLORM_NODE),
    None,
    Some(&VARS_COLORO_NODE),
    Some(&VARS_COLORP_NODE),
    None,
    Some(&VARS_COLORR_NODE),
    Some(&VARS_COLORS_NODE),
    Some(&VARS_COLORT_NODE),
    None,
    None,
    Some(&VARS_COLORW_NODE),
    None,
    Some(&VARS_COLORY_NODE),
    None,
];

static VARS_COLORY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORY_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_COLORY_692735169960595413)]),
};

pub static VARS_COLORY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_COLORW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORW_CHILDREN),
    value: None,
};

pub static VARS_COLORW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ay"),
        dictgen::InsensitiveStr::Ascii("ays"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORWAY_17470413378276487899)],
        &[(0b11001, &ENTRY_COLORWAYS_4628145222031734139)],
    ],
    range: 2..=3,
};

static VARS_COLORT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORT_CHILDREN),
    value: None,
};

pub static VARS_COLORT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ype")],
    values: &[&[(0b11001, &ENTRY_COLORTYPE_8791391695518930895)]],
    range: 3..=3,
};

static VARS_COLORS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORS_CHILDREN),
    value: Some(&[(0b11001, &ENTRY_COLORS_11482118763257927768)]),
};

pub static VARS_COLORS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_COLORR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORR_CHILDREN),
    value: None,
};

pub static VARS_COLORR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("est"),
        dictgen::InsensitiveStr::Ascii("haphy"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORREST_13441910764710538786)],
        &[(0b00001, &ENTRY_COLORRHAPHY_9426928456383049814)],
    ],
    range: 3..=5,
};

static VARS_COLORP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORP_CHILDREN),
    value: None,
};

pub static VARS_COLORP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oint"),
        dictgen::InsensitiveStr::Ascii("oints"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORPOINT_1488326999809355845)],
        &[(0b11001, &ENTRY_COLORPOINTS_5692566788742856472)],
    ],
    range: 4..=5,
};

static VARS_COLORO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORO_CHILDREN),
    value: None,
};

pub static VARS_COLORO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("to")],
    values: &[&[(0b00001, &ENTRY_COLOROTO_10920719126014730348)]],
    range: 2..=2,
};

static VARS_COLORM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORM_CHILDREN),
    value: None,
};

pub static VARS_COLORM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aker"),
        dictgen::InsensitiveStr::Ascii("aking"),
        dictgen::InsensitiveStr::Ascii("an"),
        dictgen::InsensitiveStr::Ascii("ap"),
        dictgen::InsensitiveStr::Ascii("aps"),
        dictgen::InsensitiveStr::Ascii("en"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORMAKER_18240822022788344542)],
        &[(0b11001, &ENTRY_COLORMAKING_5754969022058419268)],
        &[(0b11001, &ENTRY_COLORMAN_14198957698124507708)],
        &[(0b11001, &ENTRY_COLORMAP_17016045057031205698)],
        &[(0b11001, &ENTRY_COLORMAPS_11344428357452815640)],
        &[(0b11001, &ENTRY_COLORMEN_14804279233130680016)],
    ],
    range: 2..=5,
};

static VARS_COLORL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORL_CHILDREN),
    value: None,
};

pub static VARS_COLORL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ess"),
        dictgen::InsensitiveStr::Ascii("esser"),
        dictgen::InsensitiveStr::Ascii("essest"),
        dictgen::InsensitiveStr::Ascii("esslier"),
        dictgen::InsensitiveStr::Ascii("essliest"),
        dictgen::InsensitiveStr::Ascii("essly"),
        dictgen::InsensitiveStr::Ascii("essness"),
        dictgen::InsensitiveStr::Ascii("essnesses"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORLESS_79666121160281791)],
        &[(0b11001, &ENTRY_COLORLESSER_14130375164463853792)],
        &[(0b11001, &ENTRY_COLORLESSEST_14480954022966990260)],
        &[(0b11001, &ENTRY_COLORLESSLIER_4162646048805483531)],
        &[(0b11001, &ENTRY_COLORLESSLIEST_12869681984000132288)],
        &[(0b11001, &ENTRY_COLORLESSLY_13297396459356641001)],
        &[(0b11001, &ENTRY_COLORLESSNESS_9336682862246396379)],
        &[(0b11001, &ENTRY_COLORLESSNESSES_6266382497440905953)],
    ],
    range: 3..=9,
};

static VARS_COLORI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORI_CHILDREN),
    value: None,
};

pub static VARS_COLORI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fic"),
        dictgen::InsensitiveStr::Ascii("fics"),
        dictgen::InsensitiveStr::Ascii("metrical"),
        dictgen::InsensitiveStr::Ascii("metrically"),
        dictgen::InsensitiveStr::Ascii("metrist"),
        dictgen::InsensitiveStr::Ascii("ng"),
        dictgen::InsensitiveStr::Ascii("ngs"),
        dictgen::InsensitiveStr::Ascii("sm"),
        dictgen::InsensitiveStr::Ascii("sms"),
        dictgen::InsensitiveStr::Ascii("st"),
        dictgen::InsensitiveStr::Ascii("stic"),
        dictgen::InsensitiveStr::Ascii("stically"),
        dictgen::InsensitiveStr::Ascii("sticer"),
        dictgen::InsensitiveStr::Ascii("sticest"),
        dictgen::InsensitiveStr::Ascii("stics"),
        dictgen::InsensitiveStr::Ascii("sts"),
        dictgen::InsensitiveStr::Ascii("zation"),
        dictgen::InsensitiveStr::Ascii("zations"),
        dictgen::InsensitiveStr::Ascii("ze"),
        dictgen::InsensitiveStr::Ascii("zed"),
        dictgen::InsensitiveStr::Ascii("zes"),
        dictgen::InsensitiveStr::Ascii("zing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_COLORIFIC_18224680928850475846)],
        &[(0b00001, &ENTRY_COLORIFICS_14988984988237436693)],
        &[(0b00001, &ENTRY_COLORIMETRICAL_5893759513244621607)],
        &[(0b00001, &ENTRY_COLORIMETRICALLY_17982031766432667637)],
        &[(0b00001, &ENTRY_COLORIMETRIST_9206995085391335333)],
        &[(0b11001, &ENTRY_COLORING_1146707622868481032)],
        &[(0b11001, &ENTRY_COLORINGS_7915048393125592470)],
        &[(0b00001, &ENTRY_COLORISM_16137276040089598557)],
        &[(0b00001, &ENTRY_COLORISMS_18256708391175621780)],
        &[(0b01001, &ENTRY_COLORIST_17294665081422796979)],
        &[(0b00001, &ENTRY_COLORISTIC_399320276255558866)],
        &[(0b00001, &ENTRY_COLORISTICALLY_5424161462341646669)],
        &[(0b00001, &ENTRY_COLORISTICER_7005818059703147231)],
        &[(0b00001, &ENTRY_COLORISTICEST_2156436723060189793)],
        &[(0b00001, &ENTRY_COLORISTICS_13996615122580621680)],
        &[(0b01001, &ENTRY_COLORISTS_12579547357893269970)],
        &[(0b00001, &ENTRY_COLORIZATION_14308932529511399348)],
        &[(0b00001, &ENTRY_COLORIZATIONS_18157034030783136605)],
        &[(0b00001, &ENTRY_COLORIZE_18354734970370761815)],
        &[(0b00001, &ENTRY_COLORIZED_960777906946234161)],
        &[(0b00001, &ENTRY_COLORIZES_12131917003294390385)],
        &[(0b00001, &ENTRY_COLORIZING_2471786832873381659)],
    ],
    range: 2..=10,
};

static VARS_COLORF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORF_CHILDREN),
    value: None,
};

pub static VARS_COLORF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ast"),
        dictgen::InsensitiveStr::Ascii("astness"),
        dictgen::InsensitiveStr::Ascii("astnesses"),
        dictgen::InsensitiveStr::Ascii("ul"),
        dictgen::InsensitiveStr::Ascii("uler"),
        dictgen::InsensitiveStr::Ascii("ulest"),
        dictgen::InsensitiveStr::Ascii("ullier"),
        dictgen::InsensitiveStr::Ascii("ulliest"),
        dictgen::InsensitiveStr::Ascii("ully"),
        dictgen::InsensitiveStr::Ascii("ulness"),
        dictgen::InsensitiveStr::Ascii("ulnesses"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORFAST_6749057993199514856)],
        &[(0b11001, &ENTRY_COLORFASTNESS_17325104284808699862)],
        &[(0b11001, &ENTRY_COLORFASTNESSES_10917750449768357558)],
        &[(0b11001, &ENTRY_COLORFUL_4806683583475489506)],
        &[(0b11001, &ENTRY_COLORFULER_4366882207953732907)],
        &[(0b11001, &ENTRY_COLORFULEST_15151264088558637473)],
        &[(0b11001, &ENTRY_COLORFULLIER_12948386305746310089)],
        &[(0b11001, &ENTRY_COLORFULLIEST_14305289677627923994)],
        &[(0b11001, &ENTRY_COLORFULLY_12792342106302406309)],
        &[(0b11001, &ENTRY_COLORFULNESS_15839726768009061296)],
        &[(0b11001, &ENTRY_COLORFULNESSES_12191353247710978564)],
    ],
    range: 2..=9,
};

static VARS_COLORE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORE_CHILDREN),
    value: None,
};

pub static VARS_COLORE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ctal"),
        dictgen::InsensitiveStr::Ascii("ctitis"),
        dictgen::InsensitiveStr::Ascii("ctostomy"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("ds"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rs"),
    ],
    values: &[
        &[(0b00001, &ENTRY_COLORECTAL_11824441472361931850)],
        &[(0b00001, &ENTRY_COLORECTITIS_18158962813924379828)],
        &[(0b00001, &ENTRY_COLORECTOSTOMY_15787993662663226229)],
        &[(0b11001, &ENTRY_COLORED_16993799574214757686)],
        &[(0b11001, &ENTRY_COLOREDS_3930825355719143828)],
        &[(0b11001, &ENTRY_COLORER_14593090349752845026)],
        &[(0b11001, &ENTRY_COLORERS_13681356278503403951)],
    ],
    range: 1..=8,
};

static VARS_COLORC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORC_CHILDREN),
    value: None,
};

pub static VARS_COLORC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ast"),
        dictgen::InsensitiveStr::Ascii("asted"),
        dictgen::InsensitiveStr::Ascii("aster"),
        dictgen::InsensitiveStr::Ascii("asters"),
        dictgen::InsensitiveStr::Ascii("asting"),
        dictgen::InsensitiveStr::Ascii("asts"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORCAST_2201027249760625617)],
        &[(0b11001, &ENTRY_COLORCASTED_15703965836749186308)],
        &[(0b11001, &ENTRY_COLORCASTER_3993571528628164298)],
        &[(0b11001, &ENTRY_COLORCASTERS_6200168122277172332)],
        &[(0b11001, &ENTRY_COLORCASTING_18326831152918404831)],
        &[(0b11001, &ENTRY_COLORCASTS_15491829989405229642)],
    ],
    range: 3..=6,
};

static VARS_COLORB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORB_CHILDREN),
    value: None,
};

pub static VARS_COLORB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("earer"),
        dictgen::InsensitiveStr::Ascii("lind"),
        dictgen::InsensitiveStr::Ascii("lindness"),
        dictgen::InsensitiveStr::Ascii("lindnesses"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("reed"),
        dictgen::InsensitiveStr::Ascii("reeding"),
        dictgen::InsensitiveStr::Ascii("reeds"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORBEARER_16302991417022897520)],
        &[(0b11001, &ENTRY_COLORBLIND_16694090854179664434)],
        &[(0b11001, &ENTRY_COLORBLINDNESS_18174910962271343344)],
        &[(0b11001, &ENTRY_COLORBLINDNESSES_14269141498431512170)],
        &[(0b11001, &ENTRY_COLORBRED_5216310496600520453)],
        &[(0b11001, &ENTRY_COLORBREED_5358779689549478848)],
        &[(0b11001, &ENTRY_COLORBREEDING_14340643893363063008)],
        &[(0b11001, &ENTRY_COLORBREEDS_11113473641764637830)],
    ],
    range: 3..=10,
};

static VARS_COLORA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORA_CHILDREN),
    value: None,
};

pub static VARS_COLORA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilities"),
        dictgen::InsensitiveStr::Ascii("bility"),
        dictgen::InsensitiveStr::Ascii("ble"),
        dictgen::InsensitiveStr::Ascii("bleness"),
        dictgen::InsensitiveStr::Ascii("blenesses"),
        dictgen::InsensitiveStr::Ascii("bler"),
        dictgen::InsensitiveStr::Ascii("bles"),
        dictgen::InsensitiveStr::Ascii("blest"),
        dictgen::InsensitiveStr::Ascii("blier"),
        dictgen::InsensitiveStr::Ascii("blies"),
        dictgen::InsensitiveStr::Ascii("bliest"),
        dictgen::InsensitiveStr::Ascii("bly"),
        dictgen::InsensitiveStr::Ascii("doite"),
        dictgen::InsensitiveStr::Ascii("ma"),
        dictgen::InsensitiveStr::Ascii("nt"),
        dictgen::InsensitiveStr::Ascii("nts"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("tive"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORABILITIES_9958964032688729898)],
        &[(0b11001, &ENTRY_COLORABILITY_4981844209136751100)],
        &[(0b11001, &ENTRY_COLORABLE_7050710397577980432)],
        &[(0b11001, &ENTRY_COLORABLENESS_2481325297280462095)],
        &[(0b11001, &ENTRY_COLORABLENESSES_3851955312082062820)],
        &[(0b11001, &ENTRY_COLORABLER_9668141786678165672)],
        &[(0b11001, &ENTRY_COLORABLES_9835654246095695799)],
        &[(0b11001, &ENTRY_COLORABLEST_7942972157513237380)],
        &[(0b11001, &ENTRY_COLORABLIER_6977421189014021102)],
        &[(0b11001, &ENTRY_COLORABLIES_12294270181831783929)],
        &[(0b11001, &ENTRY_COLORABLIEST_11146624897447970828)],
        &[(0b11001, &ENTRY_COLORABLY_9468463993023925722)],
        &[(0b00001, &ENTRY_COLORADOITE_8833920578577260105)],
        &[(0b00001, &ENTRY_COLORAMA_1846226585848796493)],
        &[(0b11001, &ENTRY_COLORANT_8508078357677443619)],
        &[(0b11001, &ENTRY_COLORANTS_5504580436166605292)],
        &[(0b00001, &ENTRY_COLORATE_1487899690349145487)],
        &[(0b00001, &ENTRY_COLORATIVE_10364780649786282163)],
    ],
    range: 2..=9,
};

static VARS_COLON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLON_CHILDREN),
    value: None,
};

pub static VARS_COLON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialised"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialising"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ialized"),
        dictgen::InsensitiveStr::Ascii("ializes"),
        dictgen::InsensitiveStr::Ascii("ializing"),
        dictgen::InsensitiveStr::Ascii("isabilities"),
        dictgen::InsensitiveStr::Ascii("isability"),
        dictgen::InsensitiveStr::Ascii("isable"),
        dictgen::InsensitiveStr::Ascii("isabler"),
        dictgen::InsensitiveStr::Ascii("isables"),
        dictgen::InsensitiveStr::Ascii("isablest"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isationist"),
        dictgen::InsensitiveStr::Ascii("isationists"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("iser"),
        dictgen::InsensitiveStr::Ascii("isers"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("izabilities"),
        dictgen::InsensitiveStr::Ascii("izability"),
        dictgen::InsensitiveStr::Ascii("izable"),
        dictgen::InsensitiveStr::Ascii("izabler"),
        dictgen::InsensitiveStr::Ascii("izables"),
        dictgen::InsensitiveStr::Ascii("izablest"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izationist"),
        dictgen::InsensitiveStr::Ascii("izationists"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izer"),
        dictgen::InsensitiveStr::Ascii("izers"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COLONIALIZE_2476668941415938404)],
        &[(0b10010, &ENTRY_COLONIALIZED_9330153878225199389)],
        &[(0b10010, &ENTRY_COLONIALIZES_960436986919349894)],
        &[(0b10010, &ENTRY_COLONIALIZING_17918492670165907096)],
        &[(0b01001, &ENTRY_COLONIALIZE_2476668941415938404)],
        &[(0b01001, &ENTRY_COLONIALIZED_9330153878225199389)],
        &[(0b01001, &ENTRY_COLONIALIZES_960436986919349894)],
        &[(0b01001, &ENTRY_COLONIALIZING_17918492670165907096)],
        &[(0b10010, &ENTRY_COLONIZABILITIES_11409323284499327132)],
        &[(0b10010, &ENTRY_COLONIZABILITY_15907592922758162551)],
        &[(0b10010, &ENTRY_COLONIZABLE_13323742069868648887)],
        &[(0b10010, &ENTRY_COLONIZABLER_8047959087063068506)],
        &[(0b10010, &ENTRY_COLONIZABLES_3770494241206552717)],
        &[(0b10010, &ENTRY_COLONIZABLEST_13440662900309087302)],
        &[(0b10010, &ENTRY_COLONIZATION_5170205300413493772)],
        &[(0b10010, &ENTRY_COLONIZATIONIST_4791984041393920785)],
        &[(0b10010, &ENTRY_COLONIZATIONISTS_15686995795564411609)],
        &[(0b10010, &ENTRY_COLONIZATIONS_5914393406246107629)],
        &[(0b10010, &ENTRY_COLONIZE_15736921118583985460)],
        &[(0b10010, &ENTRY_COLONIZED_1613678129917812032)],
        &[(0b10010, &ENTRY_COLONIZER_12757929901281569170)],
        &[(0b10010, &ENTRY_COLONIZERS_8168468522547534282)],
        &[(0b10010, &ENTRY_COLONIZES_12944167433051970340)],
        &[(0b10010, &ENTRY_COLONIZING_10333921368822957164)],
        &[(0b01001, &ENTRY_COLONIZABILITIES_11409323284499327132)],
        &[(0b01001, &ENTRY_COLONIZABILITY_15907592922758162551)],
        &[(0b01001, &ENTRY_COLONIZABLE_13323742069868648887)],
        &[(0b01001, &ENTRY_COLONIZABLER_8047959087063068506)],
        &[(0b01001, &ENTRY_COLONIZABLES_3770494241206552717)],
        &[(0b01001, &ENTRY_COLONIZABLEST_13440662900309087302)],
        &[(0b01001, &ENTRY_COLONIZATION_5170205300413493772)],
        &[(0b01001, &ENTRY_COLONIZATIONIST_4791984041393920785)],
        &[(0b01001, &ENTRY_COLONIZATIONISTS_15686995795564411609)],
        &[(0b01001, &ENTRY_COLONIZATIONS_5914393406246107629)],
        &[(0b01001, &ENTRY_COLONIZE_15736921118583985460)],
        &[(0b01001, &ENTRY_COLONIZED_1613678129917812032)],
        &[(0b01001, &ENTRY_COLONIZER_12757929901281569170)],
        &[(0b01001, &ENTRY_COLONIZERS_8168468522547534282)],
        &[(0b01001, &ENTRY_COLONIZES_12944167433051970340)],
        &[(0b01001, &ENTRY_COLONIZING_10333921368822957164)],
    ],
    range: 3..=11,
};

static VARS_COLL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLL_CHILDREN),
    value: None,
};

pub static VARS_COLL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ateralise"),
        dictgen::InsensitiveStr::Ascii("ateralize"),
        dictgen::InsensitiveStr::Ascii("ectable"),
        dictgen::InsensitiveStr::Ascii("ectables"),
        dictgen::InsensitiveStr::Ascii("ectivisation"),
        dictgen::InsensitiveStr::Ascii("ectivisations"),
        dictgen::InsensitiveStr::Ascii("ectivise"),
        dictgen::InsensitiveStr::Ascii("ectivised"),
        dictgen::InsensitiveStr::Ascii("ectivises"),
        dictgen::InsensitiveStr::Ascii("ectivising"),
        dictgen::InsensitiveStr::Ascii("ectivization"),
        dictgen::InsensitiveStr::Ascii("ectivizations"),
        dictgen::InsensitiveStr::Ascii("ectivize"),
        dictgen::InsensitiveStr::Ascii("ectivized"),
        dictgen::InsensitiveStr::Ascii("ectivizes"),
        dictgen::InsensitiveStr::Ascii("ectivizing"),
        dictgen::InsensitiveStr::Ascii("oquialise"),
        dictgen::InsensitiveStr::Ascii("oquialises"),
        dictgen::InsensitiveStr::Ascii("oquialize"),
        dictgen::InsensitiveStr::Ascii("oquializes"),
        dictgen::InsensitiveStr::Ascii("oquise"),
        dictgen::InsensitiveStr::Ascii("oquised"),
        dictgen::InsensitiveStr::Ascii("oquises"),
        dictgen::InsensitiveStr::Ascii("oquising"),
        dictgen::InsensitiveStr::Ascii("oquize"),
        dictgen::InsensitiveStr::Ascii("oquized"),
        dictgen::InsensitiveStr::Ascii("oquizes"),
        dictgen::InsensitiveStr::Ascii("oquizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COLLATERALIZE_8441122820061036167)],
        &[(0b01001, &ENTRY_COLLATERALIZE_8441122820061036167)],
        &[(0b10011, &ENTRY_COLLECTIBLE_1730285011498072035)],
        &[(0b10011, &ENTRY_COLLECTIBLES_7358720680663200346)],
        &[(0b10010, &ENTRY_COLLECTIVIZATION_1362380877833359975)],
        &[(0b10010, &ENTRY_COLLECTIVIZATIONS_6195427118788754823)],
        &[(0b10010, &ENTRY_COLLECTIVIZE_12809074466084828054)],
        &[(0b10010, &ENTRY_COLLECTIVIZED_6132833186626165249)],
        &[(0b10010, &ENTRY_COLLECTIVIZES_10627545540156031817)],
        &[(0b10010, &ENTRY_COLLECTIVIZING_7798244009757756216)],
        &[(0b01001, &ENTRY_COLLECTIVIZATION_1362380877833359975)],
        &[(0b01001, &ENTRY_COLLECTIVIZATIONS_6195427118788754823)],
        &[(0b01001, &ENTRY_COLLECTIVIZE_12809074466084828054)],
        &[(0b01001, &ENTRY_COLLECTIVIZED_6132833186626165249)],
        &[(0b01001, &ENTRY_COLLECTIVIZES_10627545540156031817)],
        &[(0b01001, &ENTRY_COLLECTIVIZING_7798244009757756216)],
        &[(0b10010, &ENTRY_COLLOQUIALIZE_6461602182250284611)],
        &[(0b10010, &ENTRY_COLLOQUIALIZES_4056117948065720431)],
        &[(0b01001, &ENTRY_COLLOQUIALIZE_6461602182250284611)],
        &[(0b01001, &ENTRY_COLLOQUIALIZES_4056117948065720431)],
        &[(0b10010, &ENTRY_COLLOQUIZE_15542701926724482347)],
        &[(0b10010, &ENTRY_COLLOQUIZED_13559947537098336546)],
        &[(0b10010, &ENTRY_COLLOQUIZES_6598013176193983362)],
        &[(0b10010, &ENTRY_COLLOQUIZING_18394182203016272897)],
        &[(0b01001, &ENTRY_COLLOQUIZE_15542701926724482347)],
        &[(0b01001, &ENTRY_COLLOQUIZED_13559947537098336546)],
        &[(0b01001, &ENTRY_COLLOQUIZES_6598013176193983362)],
        &[(0b01001, &ENTRY_COLLOQUIZING_18394182203016272897)],
    ],
    range: 6..=13,
};

static VARS_COG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COG_CHILDREN),
    value: None,
};

pub static VARS_COG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisability"),
        dictgen::InsensitiveStr::Ascii("nisable"),
        dictgen::InsensitiveStr::Ascii("nisableness"),
        dictgen::InsensitiveStr::Ascii("nisabler"),
        dictgen::InsensitiveStr::Ascii("nisablest"),
        dictgen::InsensitiveStr::Ascii("nisablier"),
        dictgen::InsensitiveStr::Ascii("nisabliest"),
        dictgen::InsensitiveStr::Ascii("nisably"),
        dictgen::InsensitiveStr::Ascii("nisance"),
        dictgen::InsensitiveStr::Ascii("nisances"),
        dictgen::InsensitiveStr::Ascii("nisant"),
        dictgen::InsensitiveStr::Ascii("nisanter"),
        dictgen::InsensitiveStr::Ascii("nisantest"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nizability"),
        dictgen::InsensitiveStr::Ascii("nizable"),
        dictgen::InsensitiveStr::Ascii("nizableness"),
        dictgen::InsensitiveStr::Ascii("nizabler"),
        dictgen::InsensitiveStr::Ascii("nizablest"),
        dictgen::InsensitiveStr::Ascii("nizablier"),
        dictgen::InsensitiveStr::Ascii("nizabliest"),
        dictgen::InsensitiveStr::Ascii("nizably"),
        dictgen::InsensitiveStr::Ascii("nizance"),
        dictgen::InsensitiveStr::Ascii("nizances"),
        dictgen::InsensitiveStr::Ascii("nizant"),
        dictgen::InsensitiveStr::Ascii("nizanter"),
        dictgen::InsensitiveStr::Ascii("nizantest"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COGNIZABILITY_3446315876410265322)],
        &[(0b10010, &ENTRY_COGNIZABLE_17452455676169531153)],
        &[(0b10010, &ENTRY_COGNIZABLENESS_8915902797245580552)],
        &[(0b10010, &ENTRY_COGNIZABLER_15866973125677355856)],
        &[(0b10010, &ENTRY_COGNIZABLEST_2508940668012161280)],
        &[(0b10010, &ENTRY_COGNIZABLIER_12566683806712864297)],
        &[(0b10010, &ENTRY_COGNIZABLIEST_10273112470027332981)],
        &[(0b10010, &ENTRY_COGNIZABLY_7985411479326092139)],
        &[(0b10010, &ENTRY_COGNIZANCE_16406744570348652654)],
        &[(0b10010, &ENTRY_COGNIZANCES_278004122060158781)],
        &[(0b10010, &ENTRY_COGNIZANT_8482318087824381990)],
        &[(0b10010, &ENTRY_COGNIZANTER_1642202493657548366)],
        &[(0b10010, &ENTRY_COGNIZANTEST_2041114456387040574)],
        &[(0b10010, &ENTRY_COGNIZE_2805454015471605031)],
        &[(0b10010, &ENTRY_COGNIZED_6020528868489883774)],
        &[(0b10010, &ENTRY_COGNIZER_16090594603569153260)],
        &[(0b10010, &ENTRY_COGNIZERS_3699936194698127720)],
        &[(0b10010, &ENTRY_COGNIZES_10693547746110885948)],
        &[(0b10010, &ENTRY_COGNIZING_4439407777143073908)],
        &[(0b01001, &ENTRY_COGNIZABILITY_3446315876410265322)],
        &[(0b01001, &ENTRY_COGNIZABLE_17452455676169531153)],
        &[(0b01001, &ENTRY_COGNIZABLENESS_8915902797245580552)],
        &[(0b01001, &ENTRY_COGNIZABLER_15866973125677355856)],
        &[(0b01001, &ENTRY_COGNIZABLEST_2508940668012161280)],
        &[(0b01001, &ENTRY_COGNIZABLIER_12566683806712864297)],
        &[(0b01001, &ENTRY_COGNIZABLIEST_10273112470027332981)],
        &[(0b01001, &ENTRY_COGNIZABLY_7985411479326092139)],
        &[(0b01001, &ENTRY_COGNIZANCE_16406744570348652654)],
        &[(0b01001, &ENTRY_COGNIZANCES_278004122060158781)],
        &[(0b01001, &ENTRY_COGNIZANT_8482318087824381990)],
        &[(0b01001, &ENTRY_COGNIZANTER_1642202493657548366)],
        &[(0b01001, &ENTRY_COGNIZANTEST_2041114456387040574)],
        &[(0b01001, &ENTRY_COGNIZE_2805454015471605031)],
        &[(0b01001, &ENTRY_COGNIZED_6020528868489883774)],
        &[(0b01001, &ENTRY_COGNIZER_16090594603569153260)],
        &[(0b01001, &ENTRY_COGNIZERS_3699936194698127720)],
        &[(0b01001, &ENTRY_COGNIZES_10693547746110885948)],
        &[(0b01001, &ENTRY_COGNIZING_4439407777143073908)],
    ],
    range: 4..=11,
};

static VARS_COE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COE_CHILDREN),
    value: Some(&[
        (0b11010, &ENTRY_CE_17001278784018973857),
        (0b00001, &ENTRY_COE_15056580635786997263),
    ]),
};

pub static VARS_COE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ducationalise"),
        dictgen::InsensitiveStr::Ascii("ducationalises"),
        dictgen::InsensitiveStr::Ascii("ducationalize"),
        dictgen::InsensitiveStr::Ascii("ducationalizes"),
        dictgen::InsensitiveStr::Ascii("lastraceae"),
        dictgen::InsensitiveStr::Ascii("lastraceous"),
        dictgen::InsensitiveStr::Ascii("lestine"),
        dictgen::InsensitiveStr::Ascii("liac"),
        dictgen::InsensitiveStr::Ascii("liacs"),
        dictgen::InsensitiveStr::Ascii("lialgia"),
        dictgen::InsensitiveStr::Ascii("liomyalgia"),
        dictgen::InsensitiveStr::Ascii("liorrhea"),
        dictgen::InsensitiveStr::Ascii("lioscopy"),
        dictgen::InsensitiveStr::Ascii("liotomy"),
        dictgen::InsensitiveStr::Ascii("lom"),
        dictgen::InsensitiveStr::Ascii("loma"),
        dictgen::InsensitiveStr::Ascii("lomata"),
        dictgen::InsensitiveStr::Ascii("loms"),
        dictgen::InsensitiveStr::Ascii("loscope"),
        dictgen::InsensitiveStr::Ascii("nacle"),
        dictgen::InsensitiveStr::Ascii("naculum"),
        dictgen::InsensitiveStr::Ascii("namor"),
        dictgen::InsensitiveStr::Ascii("namored"),
        dictgen::InsensitiveStr::Ascii("namoring"),
        dictgen::InsensitiveStr::Ascii("namorment"),
        dictgen::InsensitiveStr::Ascii("namors"),
        dictgen::InsensitiveStr::Ascii("namour"),
        dictgen::InsensitiveStr::Ascii("namoured"),
        dictgen::InsensitiveStr::Ascii("namouring"),
        dictgen::InsensitiveStr::Ascii("namourment"),
        dictgen::InsensitiveStr::Ascii("namours"),
        dictgen::InsensitiveStr::Ascii("nesthesia"),
        dictgen::InsensitiveStr::Ascii("nesthesias"),
        dictgen::InsensitiveStr::Ascii("nesthesis"),
        dictgen::InsensitiveStr::Ascii("nobe"),
        dictgen::InsensitiveStr::Ascii("nobite"),
        dictgen::InsensitiveStr::Ascii("nobites"),
        dictgen::InsensitiveStr::Ascii("nobitic"),
        dictgen::InsensitiveStr::Ascii("nobitical"),
        dictgen::InsensitiveStr::Ascii("nobitism"),
        dictgen::InsensitiveStr::Ascii("nobium"),
        dictgen::InsensitiveStr::Ascii("noby"),
        dictgen::InsensitiveStr::Ascii("nogenetic"),
        dictgen::InsensitiveStr::Ascii("nosite"),
        dictgen::InsensitiveStr::Ascii("nospecies"),
        dictgen::InsensitiveStr::Ascii("nospecific"),
        dictgen::InsensitiveStr::Ascii("nospecifically"),
        dictgen::InsensitiveStr::Ascii("qualise"),
        dictgen::InsensitiveStr::Ascii("qualises"),
        dictgen::InsensitiveStr::Ascii("qualize"),
        dictgen::InsensitiveStr::Ascii("qualizes"),
        dictgen::InsensitiveStr::Ascii("ruleolactite"),
        dictgen::InsensitiveStr::Ascii("tus"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COEDUCATIONALIZE_3086000341959483566)],
        &[(0b10010, &ENTRY_COEDUCATIONALIZES_9568142082441537090)],
        &[(0b01001, &ENTRY_COEDUCATIONALIZE_3086000341959483566)],
        &[(0b01001, &ENTRY_COEDUCATIONALIZES_9568142082441537090)],
        &[(0b11010, &ENTRY_CELASTRACEAE_248052160521437337)],
        &[(0b11010, &ENTRY_CELASTRACEOUS_13139092700507364792)],
        &[(0b11010, &ENTRY_CELESTINE_6574095563191113248)],
        &[(0b11010, &ENTRY_CELIAC_18102856828663564552)],
        &[(0b11010, &ENTRY_CELIACS_7167873050372594104)],
        &[(0b11010, &ENTRY_CELIALGIA_4390117124611657564)],
        &[(0b11010, &ENTRY_CELIOMYALGIA_11280554360719408547)],
        &[(0b11010, &ENTRY_CELIORRHEA_6798475442650879420)],
        &[(0b11010, &ENTRY_CELIOSCOPY_10064554083059800495)],
        &[(0b11010, &ENTRY_CELIOTOMY_7002375967235750854)],
        &[(0b11010, &ENTRY_CELOM_6954296651788090066)],
        &[(0b11010, &ENTRY_CELOMA_16635368470102536323)],
        &[
            (0b11010, &ENTRY_CELOMATA_9462689710315550329),
            (0b00010, &ENTRY_CELOMS_4896390401945145201),
        ],
        &[(0b11010, &ENTRY_CELOMS_4896390401945145201)],
        &[(0b11010, &ENTRY_CELOSCOPE_4883213512077398928)],
        &[(0b11010, &ENTRY_CENACLE_11560322831244580416)],
        &[(0b11010, &ENTRY_CENACULUM_9966061997534531582)],
        &[(0b10001, &ENTRY_COENAMOR_12585202648195371106)],
        &[(0b10001, &ENTRY_COENAMORED_14206991445267202710)],
        &[(0b10001, &ENTRY_COENAMORING_8672063553065406305)],
        &[(0b10001, &ENTRY_COENAMORMENT_5585745797135358489)],
        &[(0b10001, &ENTRY_COENAMORS_14785645811529661699)],
        &[(0b11010, &ENTRY_COENAMOR_12585202648195371106)],
        &[(0b11010, &ENTRY_COENAMORED_14206991445267202710)],
        &[(0b11010, &ENTRY_COENAMORING_8672063553065406305)],
        &[(0b11010, &ENTRY_COENAMORMENT_5585745797135358489)],
        &[(0b11010, &ENTRY_COENAMORS_14785645811529661699)],
        &[(0b11010, &ENTRY_CENESTHESIA_4011067798171287989)],
        &[(0b11010, &ENTRY_CENESTHESIAS_16287981603481963061)],
        &[(0b11010, &ENTRY_CENESTHESIS_9192577966958417138)],
        &[(0b11010, &ENTRY_CENOBE_15621742511041336445)],
        &[(0b11010, &ENTRY_CENOBITE_3238719954758957076)],
        &[(0b11010, &ENTRY_CENOBITES_13837713854551690629)],
        &[(0b11010, &ENTRY_CENOBITIC_14473057480801204596)],
        &[(0b11010, &ENTRY_CENOBITICAL_6881474597185636655)],
        &[(0b11010, &ENTRY_CENOBITISM_10552992890229559594)],
        &[(0b11010, &ENTRY_CENOBIUM_9531258636879765081)],
        &[(0b11010, &ENTRY_CENOBY_12287306148631547483)],
        &[(0b11010, &ENTRY_CENOGENETIC_5287833837469101531)],
        &[(0b11010, &ENTRY_CENOSITE_14996204277047943901)],
        &[(0b11010, &ENTRY_CENOSPECIES_1304456854215858015)],
        &[(0b11010, &ENTRY_CENOSPECIFIC_200658439075912747)],
        &[(0b11010, &ENTRY_CENOSPECIFICALLY_14746841820461979584)],
        &[(0b10010, &ENTRY_COEQUALIZE_8933102284206871912)],
        &[(0b10010, &ENTRY_COEQUALIZES_452700607554473573)],
        &[(0b01001, &ENTRY_COEQUALIZE_8933102284206871912)],
        &[(0b01001, &ENTRY_COEQUALIZES_452700607554473573)],
        &[(0b11010, &ENTRY_CERULEOLACTITE_14138382859124709242)],
        &[(0b11010, &ENTRY_CETUS_5843508028170188409)],
    ],
    range: 3..=14,
};

static VARS_COC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COC_CHILDREN),
    value: None,
};

pub static VARS_COC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ainisation"),
        dictgen::InsensitiveStr::Ascii("ainisations"),
        dictgen::InsensitiveStr::Ascii("ainise"),
        dictgen::InsensitiveStr::Ascii("ainised"),
        dictgen::InsensitiveStr::Ascii("ainises"),
        dictgen::InsensitiveStr::Ascii("ainising"),
        dictgen::InsensitiveStr::Ascii("ainization"),
        dictgen::InsensitiveStr::Ascii("ainizations"),
        dictgen::InsensitiveStr::Ascii("ainize"),
        dictgen::InsensitiveStr::Ascii("ainized"),
        dictgen::InsensitiveStr::Ascii("ainizes"),
        dictgen::InsensitiveStr::Ascii("ainizing"),
        dictgen::InsensitiveStr::Ascii("uisa"),
        dictgen::InsensitiveStr::Ascii("uiza"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COCAINIZATION_1565985876637474561)],
        &[(0b10010, &ENTRY_COCAINIZATIONS_17964048038138593445)],
        &[(0b10010, &ENTRY_COCAINIZE_3674396344816602030)],
        &[(0b10010, &ENTRY_COCAINIZED_14547823316205743882)],
        &[(0b10010, &ENTRY_COCAINIZES_15635621286592311027)],
        &[(0b10010, &ENTRY_COCAINIZING_4136645123820639818)],
        &[(0b01001, &ENTRY_COCAINIZATION_1565985876637474561)],
        &[(0b01001, &ENTRY_COCAINIZATIONS_17964048038138593445)],
        &[(0b01001, &ENTRY_COCAINIZE_3674396344816602030)],
        &[(0b01001, &ENTRY_COCAINIZED_14547823316205743882)],
        &[(0b01001, &ENTRY_COCAINIZES_15635621286592311027)],
        &[(0b01001, &ENTRY_COCAINIZING_4136645123820639818)],
        &[(0b10010, &ENTRY_COCUIZA_14986726333358901234)],
        &[(0b01001, &ENTRY_COCUIZA_14986726333358901234)],
    ],
    range: 4..=11,
};

static VARS_COA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COA_CHILDREN),
    value: None,
};

pub static VARS_COA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("liser"),
        dictgen::InsensitiveStr::Ascii("lisers"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizer"),
        dictgen::InsensitiveStr::Ascii("lizers"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COALIZE_11558724977177179550)],
        &[(0b10010, &ENTRY_COALIZED_3645830777684850035)],
        &[(0b10010, &ENTRY_COALIZER_5925785296167946025)],
        &[(0b10010, &ENTRY_COALIZERS_12486481008714536417)],
        &[(0b10010, &ENTRY_COALIZES_580286287171430443)],
        &[(0b10010, &ENTRY_COALIZING_694156750091536205)],
        &[(0b01001, &ENTRY_COALIZE_11558724977177179550)],
        &[(0b01001, &ENTRY_COALIZED_3645830777684850035)],
        &[(0b01001, &ENTRY_COALIZER_5925785296167946025)],
        &[(0b01001, &ENTRY_COALIZERS_12486481008714536417)],
        &[(0b01001, &ENTRY_COALIZES_580286287171430443)],
        &[(0b01001, &ENTRY_COALIZING_694156750091536205)],
    ],
    range: 4..=6,
};

static VARS_CL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CL_CHILDREN),
    value: None,
};

static VARS_CL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CLA_NODE),
    None,
    None,
    None,
    Some(&VARS_CLE_NODE),
    None,
    None,
    None,
    Some(&VARS_CLI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CLO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CLY_NODE),
    None,
];

static VARS_CLY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CLY_CHILDREN),
    value: None,
};

pub static VARS_CLY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tiae"),
        dictgen::InsensitiveStr::Ascii("tie"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CLYTIE_15430707852737482986)],
        &[(0b00001, &ENTRY_CLYTIE_15430707852737482986)],
    ],
    range: 3..=4,
};

static VARS_CLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CLO_CHILDREN),
    value: None,
};

pub static VARS_CLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ete"),
        dictgen::InsensitiveStr::Ascii("wer"),
        dictgen::InsensitiveStr::Ascii("wre"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CLETE_9114346982470440863)],
        &[(0b00001, &ENTRY_CLOWER_14920406222871692430)],
        &[(0b11010, &ENTRY_CLOWER_14920406222871692430)],
    ],
    range: 3..=3,
};

static VARS_CLI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CLI_CHILDREN),
    value: None,
};

pub static VARS_CLI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CLIMATIZE_17719324526044936011)],
        &[(0b10010, &ENTRY_CLIMATIZED_8642688561481903657)],
        &[(0b10010, &ENTRY_CLIMATIZES_10325703256837622121)],
        &[(0b10010, &ENTRY_CLIMATIZING_12047667901968744541)],
        &[(0b01001, &ENTRY_CLIMATIZE_17719324526044936011)],
        &[(0b01001, &ENTRY_CLIMATIZED_8642688561481903657)],
        &[(0b01001, &ENTRY_CLIMATIZES_10325703256837622121)],
        &[(0b01001, &ENTRY_CLIMATIZING_12047667901968744541)],
    ],
    range: 6..=8,
};

static VARS_CLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CLE_CHILDREN),
    value: None,
};

pub static VARS_CLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ricalise"),
        dictgen::InsensitiveStr::Ascii("ricalises"),
        dictgen::InsensitiveStr::Ascii("ricalize"),
        dictgen::InsensitiveStr::Ascii("ricalizes"),
        dictgen::InsensitiveStr::Ascii("te"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CLERICALIZE_8419668540187724800)],
        &[(0b10010, &ENTRY_CLERICALIZES_9868541024178822970)],
        &[(0b01001, &ENTRY_CLERICALIZE_8419668540187724800)],
        &[(0b01001, &ENTRY_CLERICALIZES_9868541024178822970)],
        &[(0b00001, &ENTRY_CLETE_9114346982470440863)],
    ],
    range: 2..=9,
};

static VARS_CLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CLA_CHILDREN),
    value: None,
};

pub static VARS_CLA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mor"),
        dictgen::InsensitiveStr::Ascii("mored"),
        dictgen::InsensitiveStr::Ascii("morer"),
        dictgen::InsensitiveStr::Ascii("morers"),
        dictgen::InsensitiveStr::Ascii("moring"),
        dictgen::InsensitiveStr::Ascii("morist"),
        dictgen::InsensitiveStr::Ascii("mors"),
        dictgen::InsensitiveStr::Ascii("morsome"),
        dictgen::InsensitiveStr::Ascii("mour"),
        dictgen::InsensitiveStr::Ascii("moured"),
        dictgen::InsensitiveStr::Ascii("mourer"),
        dictgen::InsensitiveStr::Ascii("mourers"),
        dictgen::InsensitiveStr::Ascii("mouring"),
        dictgen::InsensitiveStr::Ascii("mourist"),
        dictgen::InsensitiveStr::Ascii("mours"),
        dictgen::InsensitiveStr::Ascii("moursome"),
        dictgen::InsensitiveStr::Ascii("ngor"),
        dictgen::InsensitiveStr::Ascii("ngored"),
        dictgen::InsensitiveStr::Ascii("ngoring"),
        dictgen::InsensitiveStr::Ascii("ngors"),
        dictgen::InsensitiveStr::Ascii("ngour"),
        dictgen::InsensitiveStr::Ascii("ngoured"),
        dictgen::InsensitiveStr::Ascii("ngouring"),
        dictgen::InsensitiveStr::Ascii("ngours"),
        dictgen::InsensitiveStr::Ascii("res"),
        dictgen::InsensitiveStr::Ascii("rinetist"),
        dictgen::InsensitiveStr::Ascii("rinetists"),
        dictgen::InsensitiveStr::Ascii("rinettist"),
        dictgen::InsensitiveStr::Ascii("rinettists"),
        dictgen::InsensitiveStr::Ascii("roes"),
        dictgen::InsensitiveStr::Ascii("ssicalise"),
        dictgen::InsensitiveStr::Ascii("ssicalises"),
        dictgen::InsensitiveStr::Ascii("ssicalize"),
        dictgen::InsensitiveStr::Ascii("ssicalizes"),
        dictgen::InsensitiveStr::Ascii("ssicisation"),
        dictgen::InsensitiveStr::Ascii("ssicise"),
        dictgen::InsensitiveStr::Ascii("ssicised"),
        dictgen::InsensitiveStr::Ascii("ssicises"),
        dictgen::InsensitiveStr::Ascii("ssicising"),
        dictgen::InsensitiveStr::Ascii("ssicization"),
        dictgen::InsensitiveStr::Ascii("ssicize"),
        dictgen::InsensitiveStr::Ascii("ssicized"),
        dictgen::InsensitiveStr::Ascii("ssicizes"),
        dictgen::InsensitiveStr::Ascii("ssicizing"),
        dictgen::InsensitiveStr::Ascii("usulae"),
        dictgen::InsensitiveStr::Ascii("usule"),
    ],
    values: &[
        &[(0b11001, &ENTRY_CLAMOR_5158185862304229945)],
        &[(0b11001, &ENTRY_CLAMORED_2092729859202254484)],
        &[(0b11001, &ENTRY_CLAMORER_2016537190882321769)],
        &[(0b11001, &ENTRY_CLAMORERS_11938498029963459379)],
        &[(0b11001, &ENTRY_CLAMORING_17170493137896914728)],
        &[(0b00001, &ENTRY_CLAMORIST_1995860053434361541)],
        &[(0b11001, &ENTRY_CLAMORS_12585789829012154512)],
        &[(0b11001, &ENTRY_CLAMORSOME_330894112921712012)],
        &[(0b11010, &ENTRY_CLAMOR_5158185862304229945)],
        &[(0b11010, &ENTRY_CLAMORED_2092729859202254484)],
        &[(0b11010, &ENTRY_CLAMORER_2016537190882321769)],
        &[(0b11010, &ENTRY_CLAMORERS_11938498029963459379)],
        &[(0b11010, &ENTRY_CLAMORING_17170493137896914728)],
        &[(0b11010, &ENTRY_CLAMORIST_1995860053434361541)],
        &[(0b11010, &ENTRY_CLAMORS_12585789829012154512)],
        &[(0b11010, &ENTRY_CLAMORSOME_330894112921712012)],
        &[(0b11001, &ENTRY_CLANGOR_11068622204017638397)],
        &[(0b11001, &ENTRY_CLANGORED_4896068625903464560)],
        &[(0b11001, &ENTRY_CLANGORING_2067393512241593148)],
        &[(0b11001, &ENTRY_CLANGORS_9815521559387015927)],
        &[(0b11010, &ENTRY_CLANGOR_11068622204017638397)],
        &[(0b11010, &ENTRY_CLANGORED_4896068625903464560)],
        &[(0b11010, &ENTRY_CLANGORING_2067393512241593148)],
        &[(0b11010, &ENTRY_CLANGORS_9815521559387015927)],
        &[(0b00001, &ENTRY_CLARES_5409815003752679904)],
        &[(0b01001, &ENTRY_CLARINETIST_10300531156065359462)],
        &[(0b01001, &ENTRY_CLARINETISTS_6735422107420159102)],
        &[(0b10011, &ENTRY_CLARINETIST_10300531156065359462)],
        &[(0b10011, &ENTRY_CLARINETISTS_6735422107420159102)],
        &[(0b11010, &ENTRY_CLARES_5409815003752679904)],
        &[(0b10010, &ENTRY_CLASSICALIZE_14979442572681110295)],
        &[(0b10010, &ENTRY_CLASSICALIZES_2327042308575389083)],
        &[(0b01001, &ENTRY_CLASSICALIZE_14979442572681110295)],
        &[(0b01001, &ENTRY_CLASSICALIZES_2327042308575389083)],
        &[(0b10010, &ENTRY_CLASSICIZATION_16187684362412692047)],
        &[(0b10010, &ENTRY_CLASSICIZE_6173596440580862000)],
        &[(0b10010, &ENTRY_CLASSICIZED_1424459898101384526)],
        &[(0b10010, &ENTRY_CLASSICIZES_5416184573508461528)],
        &[(0b10010, &ENTRY_CLASSICIZING_7645297896587290775)],
        &[(0b01001, &ENTRY_CLASSICIZATION_16187684362412692047)],
        &[(0b01001, &ENTRY_CLASSICIZE_6173596440580862000)],
        &[(0b01001, &ENTRY_CLASSICIZED_1424459898101384526)],
        &[(0b01001, &ENTRY_CLASSICIZES_5416184573508461528)],
        &[(0b01001, &ENTRY_CLASSICIZING_7645297896587290775)],
        &[(0b11010, &ENTRY_CLAUSULE_13784658851539783980)],
        &[(0b00001, &ENTRY_CLAUSULE_13784658851539783980)],
    ],
    range: 3..=11,
};

static VARS_CI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CI_CHILDREN),
    value: None,
};

static VARS_CI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_CIC_NODE),
    None,
    None,
    None,
    Some(&VARS_CIG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CIM_NODE),
    Some(&VARS_CIN_NODE),
    None,
    None,
    None,
    Some(&VARS_CIR_NODE),
    Some(&VARS_CIS_NODE),
    Some(&VARS_CIT_NODE),
    None,
    Some(&VARS_CIV_NODE),
    None,
    None,
    None,
    Some(&VARS_CIZ_NODE),
];

static VARS_CIZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIZ_CHILDREN),
    value: None,
};

pub static VARS_CIZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b01001, &ENTRY_CIZE_17978395450979456583)]],
    range: 1..=1,
};

static VARS_CIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIV_CHILDREN),
    value: None,
};

pub static VARS_CIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilianisation"),
        dictgen::InsensitiveStr::Ascii("ilianisations"),
        dictgen::InsensitiveStr::Ascii("ilianise"),
        dictgen::InsensitiveStr::Ascii("ilianised"),
        dictgen::InsensitiveStr::Ascii("ilianises"),
        dictgen::InsensitiveStr::Ascii("ilianising"),
        dictgen::InsensitiveStr::Ascii("ilianization"),
        dictgen::InsensitiveStr::Ascii("ilianizations"),
        dictgen::InsensitiveStr::Ascii("ilianize"),
        dictgen::InsensitiveStr::Ascii("ilianized"),
        dictgen::InsensitiveStr::Ascii("ilianizes"),
        dictgen::InsensitiveStr::Ascii("ilianizing"),
        dictgen::InsensitiveStr::Ascii("ilisable"),
        dictgen::InsensitiveStr::Ascii("ilisabler"),
        dictgen::InsensitiveStr::Ascii("ilisables"),
        dictgen::InsensitiveStr::Ascii("ilisablest"),
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisational"),
        dictgen::InsensitiveStr::Ascii("ilisationaler"),
        dictgen::InsensitiveStr::Ascii("ilisationalest"),
        dictgen::InsensitiveStr::Ascii("ilisationals"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilisatory"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("ilisedness"),
        dictgen::InsensitiveStr::Ascii("ilisednesses"),
        dictgen::InsensitiveStr::Ascii("iliser"),
        dictgen::InsensitiveStr::Ascii("ilisers"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilizable"),
        dictgen::InsensitiveStr::Ascii("ilizabler"),
        dictgen::InsensitiveStr::Ascii("ilizables"),
        dictgen::InsensitiveStr::Ascii("ilizablest"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizational"),
        dictgen::InsensitiveStr::Ascii("ilizationaler"),
        dictgen::InsensitiveStr::Ascii("ilizationalest"),
        dictgen::InsensitiveStr::Ascii("ilizationals"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilizatory"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizedness"),
        dictgen::InsensitiveStr::Ascii("ilizednesses"),
        dictgen::InsensitiveStr::Ascii("ilizer"),
        dictgen::InsensitiveStr::Ascii("ilizers"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CIVILIANIZATION_7286943312580518737)],
        &[(0b10010, &ENTRY_CIVILIANIZATIONS_1184580639044287766)],
        &[(0b10010, &ENTRY_CIVILIANIZE_9200206390563342469)],
        &[(0b10010, &ENTRY_CIVILIANIZED_15858039446683412237)],
        &[(0b10010, &ENTRY_CIVILIANIZES_7876834226685948201)],
        &[(0b10010, &ENTRY_CIVILIANIZING_13031723867600209433)],
        &[(0b01001, &ENTRY_CIVILIANIZATION_7286943312580518737)],
        &[(0b01001, &ENTRY_CIVILIANIZATIONS_1184580639044287766)],
        &[(0b01001, &ENTRY_CIVILIANIZE_9200206390563342469)],
        &[(0b01001, &ENTRY_CIVILIANIZED_15858039446683412237)],
        &[(0b01001, &ENTRY_CIVILIANIZES_7876834226685948201)],
        &[(0b01001, &ENTRY_CIVILIANIZING_13031723867600209433)],
        &[(0b10010, &ENTRY_CIVILIZABLE_9989179314754294521)],
        &[(0b10010, &ENTRY_CIVILIZABLER_1074825683746490989)],
        &[(0b10010, &ENTRY_CIVILIZABLES_4607646917173663003)],
        &[(0b10010, &ENTRY_CIVILIZABLEST_12041786786344794314)],
        &[(0b10010, &ENTRY_CIVILIZATION_15411020791056209676)],
        &[(0b10010, &ENTRY_CIVILIZATIONAL_13278373598904289511)],
        &[(0b10010, &ENTRY_CIVILIZATIONALER_5751340816103939865)],
        &[(0b10010, &ENTRY_CIVILIZATIONALEST_9429491474830355260)],
        &[(0b10010, &ENTRY_CIVILIZATIONALS_7189230314901517664)],
        &[(0b10010, &ENTRY_CIVILIZATIONS_8013365541301592457)],
        &[(0b10010, &ENTRY_CIVILIZATORY_8170984304313567948)],
        &[(0b10010, &ENTRY_CIVILIZE_16590332670644302211)],
        &[(0b10010, &ENTRY_CIVILIZED_8223404244720114957)],
        &[(0b10010, &ENTRY_CIVILIZEDNESS_2902568270319878801)],
        &[(0b10010, &ENTRY_CIVILIZEDNESSES_3387643148858025856)],
        &[(0b10010, &ENTRY_CIVILIZER_8024073242072515118)],
        &[(0b10010, &ENTRY_CIVILIZERS_3015830727153297093)],
        &[(0b10010, &ENTRY_CIVILIZES_9333851959553393399)],
        &[(0b10010, &ENTRY_CIVILIZING_17372507961283340052)],
        &[(0b01001, &ENTRY_CIVILIZABLE_9989179314754294521)],
        &[(0b01001, &ENTRY_CIVILIZABLER_1074825683746490989)],
        &[(0b01001, &ENTRY_CIVILIZABLES_4607646917173663003)],
        &[(0b01001, &ENTRY_CIVILIZABLEST_12041786786344794314)],
        &[(0b01001, &ENTRY_CIVILIZATION_15411020791056209676)],
        &[(0b01001, &ENTRY_CIVILIZATIONAL_13278373598904289511)],
        &[(0b01001, &ENTRY_CIVILIZATIONALER_5751340816103939865)],
        &[(0b01001, &ENTRY_CIVILIZATIONALEST_9429491474830355260)],
        &[(0b01001, &ENTRY_CIVILIZATIONALS_7189230314901517664)],
        &[(0b01001, &ENTRY_CIVILIZATIONS_8013365541301592457)],
        &[(0b01001, &ENTRY_CIVILIZATORY_8170984304313567948)],
        &[(0b01001, &ENTRY_CIVILIZE_16590332670644302211)],
        &[(0b01001, &ENTRY_CIVILIZED_8223404244720114957)],
        &[(0b01001, &ENTRY_CIVILIZEDNESS_2902568270319878801)],
        &[(0b01001, &ENTRY_CIVILIZEDNESSES_3387643148858025856)],
        &[(0b01001, &ENTRY_CIVILIZER_8024073242072515118)],
        &[(0b01001, &ENTRY_CIVILIZERS_3015830727153297093)],
        &[(0b01001, &ENTRY_CIVILIZES_9333851959553393399)],
        &[(0b01001, &ENTRY_CIVILIZING_17372507961283340052)],
    ],
    range: 5..=14,
};

static VARS_CIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIT_CHILDREN),
    value: None,
};

pub static VARS_CIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hern"),
        dictgen::InsensitiveStr::Ascii("herns"),
        dictgen::InsensitiveStr::Ascii("hren"),
        dictgen::InsensitiveStr::Ascii("hrens"),
        dictgen::InsensitiveStr::Ascii("izenise"),
        dictgen::InsensitiveStr::Ascii("izenised"),
        dictgen::InsensitiveStr::Ascii("izenises"),
        dictgen::InsensitiveStr::Ascii("izenising"),
        dictgen::InsensitiveStr::Ascii("izenize"),
        dictgen::InsensitiveStr::Ascii("izenized"),
        dictgen::InsensitiveStr::Ascii("izenizes"),
        dictgen::InsensitiveStr::Ascii("izenizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CITHERN_7019582320411452194)],
        &[(0b00001, &ENTRY_CITHERNS_3103642542221543646)],
        &[(0b11010, &ENTRY_CITHERN_7019582320411452194)],
        &[(0b11010, &ENTRY_CITHERNS_3103642542221543646)],
        &[(0b10010, &ENTRY_CITIZENIZE_8500004873095245347)],
        &[(0b10010, &ENTRY_CITIZENIZED_9568727046657390022)],
        &[(0b10010, &ENTRY_CITIZENIZES_16757027513992676737)],
        &[(0b10010, &ENTRY_CITIZENIZING_3145059359855704610)],
        &[(0b01001, &ENTRY_CITIZENIZE_8500004873095245347)],
        &[(0b01001, &ENTRY_CITIZENIZED_9568727046657390022)],
        &[(0b01001, &ENTRY_CITIZENIZES_16757027513992676737)],
        &[(0b01001, &ENTRY_CITIZENIZING_3145059359855704610)],
    ],
    range: 4..=9,
};

static VARS_CIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIS_CHILDREN),
    value: None,
};

pub static VARS_CIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b10010, &ENTRY_CIZE_17978395450979456583)]],
    range: 1..=1,
};

static VARS_CIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIR_CHILDREN),
    value: None,
};

pub static VARS_CIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("caean"),
        dictgen::InsensitiveStr::Ascii("cean"),
        dictgen::InsensitiveStr::Ascii("cularisation"),
        dictgen::InsensitiveStr::Ascii("cularisations"),
        dictgen::InsensitiveStr::Ascii("cularise"),
        dictgen::InsensitiveStr::Ascii("cularised"),
        dictgen::InsensitiveStr::Ascii("culariser"),
        dictgen::InsensitiveStr::Ascii("cularisers"),
        dictgen::InsensitiveStr::Ascii("cularises"),
        dictgen::InsensitiveStr::Ascii("cularising"),
        dictgen::InsensitiveStr::Ascii("cularization"),
        dictgen::InsensitiveStr::Ascii("cularizations"),
        dictgen::InsensitiveStr::Ascii("cularize"),
        dictgen::InsensitiveStr::Ascii("cularized"),
        dictgen::InsensitiveStr::Ascii("cularizer"),
        dictgen::InsensitiveStr::Ascii("cularizers"),
        dictgen::InsensitiveStr::Ascii("cularizes"),
        dictgen::InsensitiveStr::Ascii("cularizing"),
        dictgen::InsensitiveStr::Ascii("cumcenter"),
        dictgen::InsensitiveStr::Ascii("cumcenters"),
        dictgen::InsensitiveStr::Ascii("cumcentre"),
        dictgen::InsensitiveStr::Ascii("cumcentres"),
        dictgen::InsensitiveStr::Ascii("cumesophagal"),
        dictgen::InsensitiveStr::Ascii("cumoesophagal"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CIRCEAN_13914378621232486516)],
        &[(0b00001, &ENTRY_CIRCEAN_13914378621232486516)],
        &[(0b10010, &ENTRY_CIRCULARIZATION_13446228978184474783)],
        &[(0b10010, &ENTRY_CIRCULARIZATIONS_15969413902903833833)],
        &[(0b10010, &ENTRY_CIRCULARIZE_17976452635575197775)],
        &[(0b10010, &ENTRY_CIRCULARIZED_10196681630788896392)],
        &[(0b10010, &ENTRY_CIRCULARIZER_5474163430499344980)],
        &[(0b10010, &ENTRY_CIRCULARIZERS_9385945421646713627)],
        &[(0b10010, &ENTRY_CIRCULARIZES_2687194339579068787)],
        &[(0b10010, &ENTRY_CIRCULARIZING_5021096955296996517)],
        &[(0b01001, &ENTRY_CIRCULARIZATION_13446228978184474783)],
        &[(0b01001, &ENTRY_CIRCULARIZATIONS_15969413902903833833)],
        &[(0b01001, &ENTRY_CIRCULARIZE_17976452635575197775)],
        &[(0b01001, &ENTRY_CIRCULARIZED_10196681630788896392)],
        &[(0b01001, &ENTRY_CIRCULARIZER_5474163430499344980)],
        &[(0b01001, &ENTRY_CIRCULARIZERS_9385945421646713627)],
        &[(0b01001, &ENTRY_CIRCULARIZES_2687194339579068787)],
        &[(0b01001, &ENTRY_CIRCULARIZING_5021096955296996517)],
        &[(0b00001, &ENTRY_CIRCUMCENTER_13368725237225377813)],
        &[(0b00001, &ENTRY_CIRCUMCENTERS_12086402493856101663)],
        &[(0b11010, &ENTRY_CIRCUMCENTER_13368725237225377813)],
        &[(0b11010, &ENTRY_CIRCUMCENTERS_12086402493856101663)],
        &[(0b00001, &ENTRY_CIRCUMESOPHAGAL_15080034942492674876)],
        &[(0b11010, &ENTRY_CIRCUMESOPHAGAL_15080034942492674876)],
    ],
    range: 4..=13,
};

static VARS_CIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIN_CHILDREN),
    value: None,
};

pub static VARS_CIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chonisation"),
        dictgen::InsensitiveStr::Ascii("chonisations"),
        dictgen::InsensitiveStr::Ascii("chonise"),
        dictgen::InsensitiveStr::Ascii("chonised"),
        dictgen::InsensitiveStr::Ascii("chonises"),
        dictgen::InsensitiveStr::Ascii("chonising"),
        dictgen::InsensitiveStr::Ascii("chonization"),
        dictgen::InsensitiveStr::Ascii("chonizations"),
        dictgen::InsensitiveStr::Ascii("chonize"),
        dictgen::InsensitiveStr::Ascii("chonized"),
        dictgen::InsensitiveStr::Ascii("chonizes"),
        dictgen::InsensitiveStr::Ascii("chonizing"),
        dictgen::InsensitiveStr::Ascii("ematise"),
        dictgen::InsensitiveStr::Ascii("ematize"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CINCHONIZATION_8898418899758893781)],
        &[(0b10010, &ENTRY_CINCHONIZATIONS_11466854488565689917)],
        &[(0b10010, &ENTRY_CINCHONIZE_7002464384875628561)],
        &[(0b10010, &ENTRY_CINCHONIZED_10320384586732033099)],
        &[(0b10010, &ENTRY_CINCHONIZES_13630850583605907955)],
        &[(0b10010, &ENTRY_CINCHONIZING_1127474968700444323)],
        &[(0b01001, &ENTRY_CINCHONIZATION_8898418899758893781)],
        &[(0b01001, &ENTRY_CINCHONIZATIONS_11466854488565689917)],
        &[(0b01001, &ENTRY_CINCHONIZE_7002464384875628561)],
        &[(0b01001, &ENTRY_CINCHONIZED_10320384586732033099)],
        &[(0b01001, &ENTRY_CINCHONIZES_13630850583605907955)],
        &[(0b01001, &ENTRY_CINCHONIZING_1127474968700444323)],
        &[(0b10010, &ENTRY_CINEMATIZE_887503370904956303)],
        &[(0b01001, &ENTRY_CINEMATIZE_887503370904956303)],
        &[(0b00001, &ENTRY_CINTER_12423048040489747966)],
        &[(0b11010, &ENTRY_CINTER_12423048040489747966)],
    ],
    range: 3..=12,
};

static VARS_CIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIM_CHILDREN),
    value: None,
};

pub static VARS_CIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icidae"),
        dictgen::InsensitiveStr::Ascii("icide"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CIMICIDE_16199859638855147432)],
        &[(0b00001, &ENTRY_CIMICIDE_16199859638855147432)],
    ],
    range: 5..=6,
};

static VARS_CIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIG_CHILDREN),
    value: None,
};

pub static VARS_CIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aret"),
        dictgen::InsensitiveStr::Ascii("arets"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CIGARETTE_5420991040189256779)],
        &[(0b00001, &ENTRY_CIGARETTES_16419249441518698267)],
    ],
    range: 4..=5,
};

static VARS_CIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIC_CHILDREN),
    value: None,
};

pub static VARS_CIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atriculae"),
        dictgen::InsensitiveStr::Ascii("atricule"),
        dictgen::InsensitiveStr::Ascii("atrisant"),
        dictgen::InsensitiveStr::Ascii("atrisate"),
        dictgen::InsensitiveStr::Ascii("atrisation"),
        dictgen::InsensitiveStr::Ascii("atrisations"),
        dictgen::InsensitiveStr::Ascii("atrise"),
        dictgen::InsensitiveStr::Ascii("atrised"),
        dictgen::InsensitiveStr::Ascii("atriser"),
        dictgen::InsensitiveStr::Ascii("atrises"),
        dictgen::InsensitiveStr::Ascii("atrising"),
        dictgen::InsensitiveStr::Ascii("atrixes"),
        dictgen::InsensitiveStr::Ascii("atrizant"),
        dictgen::InsensitiveStr::Ascii("atrizate"),
        dictgen::InsensitiveStr::Ascii("atrization"),
        dictgen::InsensitiveStr::Ascii("atrizations"),
        dictgen::InsensitiveStr::Ascii("atrize"),
        dictgen::InsensitiveStr::Ascii("atrized"),
        dictgen::InsensitiveStr::Ascii("atrizer"),
        dictgen::InsensitiveStr::Ascii("atrizes"),
        dictgen::InsensitiveStr::Ascii("atrizing"),
        dictgen::InsensitiveStr::Ascii("eronianise"),
        dictgen::InsensitiveStr::Ascii("eronianises"),
        dictgen::InsensitiveStr::Ascii("eronianize"),
        dictgen::InsensitiveStr::Ascii("eronianizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CICATRICULE_3423950138630950565)],
        &[(0b00001, &ENTRY_CICATRICULE_3423950138630950565)],
        &[(0b10010, &ENTRY_CICATRIZANT_14580030762509411820)],
        &[(0b10010, &ENTRY_CICATRIZATE_13034404440200633128)],
        &[(0b10010, &ENTRY_CICATRIZATION_9264802001449770315)],
        &[(0b10010, &ENTRY_CICATRIZATIONS_6401479390305959155)],
        &[(0b10010, &ENTRY_CICATRIZE_10818694238612969910)],
        &[(0b10010, &ENTRY_CICATRIZED_1828890261939464598)],
        &[(0b10010, &ENTRY_CICATRIZER_7968728130764832311)],
        &[(0b10010, &ENTRY_CICATRIZES_10804914940535295994)],
        &[(0b10010, &ENTRY_CICATRIZING_2146572731064124559)],
        &[(0b00001, &ENTRY_CICATRICES_17574423838445240061)],
        &[(0b01001, &ENTRY_CICATRIZANT_14580030762509411820)],
        &[(0b01001, &ENTRY_CICATRIZATE_13034404440200633128)],
        &[(0b01001, &ENTRY_CICATRIZATION_9264802001449770315)],
        &[(0b01001, &ENTRY_CICATRIZATIONS_6401479390305959155)],
        &[(0b01001, &ENTRY_CICATRIZE_10818694238612969910)],
        &[(0b01001, &ENTRY_CICATRIZED_1828890261939464598)],
        &[(0b01001, &ENTRY_CICATRIZER_7968728130764832311)],
        &[(0b01001, &ENTRY_CICATRIZES_10804914940535295994)],
        &[(0b01001, &ENTRY_CICATRIZING_2146572731064124559)],
        &[(0b10010, &ENTRY_CICERONIANIZE_954039864252417924)],
        &[(0b10010, &ENTRY_CICERONIANIZES_8272191235039896374)],
        &[(0b01001, &ENTRY_CICERONIANIZE_954039864252417924)],
        &[(0b01001, &ENTRY_CICERONIANIZES_8272191235039896374)],
    ],
    range: 6..=11,
};

static VARS_CH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CH_CHILDREN),
    value: None,
};

static VARS_CH_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CHA_NODE),
    None,
    None,
    None,
    Some(&VARS_CHE_NODE),
    None,
    None,
    None,
    Some(&VARS_CHI_NODE),
    None,
    None,
    Some(&VARS_CHL_NODE),
    None,
    None,
    Some(&VARS_CHO_NODE),
    None,
    None,
    Some(&VARS_CHR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CHR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHR_CHILDREN),
    value: None,
};

pub static VARS_CHR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("istianisation"),
        dictgen::InsensitiveStr::Ascii("istianisations"),
        dictgen::InsensitiveStr::Ascii("istianise"),
        dictgen::InsensitiveStr::Ascii("istianised"),
        dictgen::InsensitiveStr::Ascii("istianiser"),
        dictgen::InsensitiveStr::Ascii("istianisers"),
        dictgen::InsensitiveStr::Ascii("istianises"),
        dictgen::InsensitiveStr::Ascii("istianising"),
        dictgen::InsensitiveStr::Ascii("istianization"),
        dictgen::InsensitiveStr::Ascii("istianizations"),
        dictgen::InsensitiveStr::Ascii("istianize"),
        dictgen::InsensitiveStr::Ascii("istianized"),
        dictgen::InsensitiveStr::Ascii("istianizer"),
        dictgen::InsensitiveStr::Ascii("istianizers"),
        dictgen::InsensitiveStr::Ascii("istianizes"),
        dictgen::InsensitiveStr::Ascii("istianizing"),
        dictgen::InsensitiveStr::Ascii("omaesthesia"),
        dictgen::InsensitiveStr::Ascii("omatise"),
        dictgen::InsensitiveStr::Ascii("omatises"),
        dictgen::InsensitiveStr::Ascii("omatize"),
        dictgen::InsensitiveStr::Ascii("omatizes"),
        dictgen::InsensitiveStr::Ascii("omesthesia"),
        dictgen::InsensitiveStr::Ascii("omicise"),
        dictgen::InsensitiveStr::Ascii("omicises"),
        dictgen::InsensitiveStr::Ascii("omicize"),
        dictgen::InsensitiveStr::Ascii("omicizes"),
        dictgen::InsensitiveStr::Ascii("omise"),
        dictgen::InsensitiveStr::Ascii("omised"),
        dictgen::InsensitiveStr::Ascii("omises"),
        dictgen::InsensitiveStr::Ascii("omising"),
        dictgen::InsensitiveStr::Ascii("omize"),
        dictgen::InsensitiveStr::Ascii("omized"),
        dictgen::InsensitiveStr::Ascii("omizes"),
        dictgen::InsensitiveStr::Ascii("omizing"),
        dictgen::InsensitiveStr::Ascii("onologise"),
        dictgen::InsensitiveStr::Ascii("onologised"),
        dictgen::InsensitiveStr::Ascii("onologises"),
        dictgen::InsensitiveStr::Ascii("onologising"),
        dictgen::InsensitiveStr::Ascii("onologize"),
        dictgen::InsensitiveStr::Ascii("onologized"),
        dictgen::InsensitiveStr::Ascii("onologizes"),
        dictgen::InsensitiveStr::Ascii("onologizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CHRISTIANIZATION_11631799398993571501)],
        &[(0b10010, &ENTRY_CHRISTIANIZATIONS_16703091698980017207)],
        &[(0b10010, &ENTRY_CHRISTIANIZE_15479599846963049140)],
        &[(0b10010, &ENTRY_CHRISTIANIZED_14623745351432413209)],
        &[(0b10010, &ENTRY_CHRISTIANIZER_2479285670414112843)],
        &[(0b10010, &ENTRY_CHRISTIANIZERS_548699853676213111)],
        &[(0b10010, &ENTRY_CHRISTIANIZES_5529854457085699383)],
        &[(0b10010, &ENTRY_CHRISTIANIZING_18179844943674675649)],
        &[(0b01001, &ENTRY_CHRISTIANIZATION_11631799398993571501)],
        &[(0b01001, &ENTRY_CHRISTIANIZATIONS_16703091698980017207)],
        &[(0b01001, &ENTRY_CHRISTIANIZE_15479599846963049140)],
        &[(0b01001, &ENTRY_CHRISTIANIZED_14623745351432413209)],
        &[(0b01001, &ENTRY_CHRISTIANIZER_2479285670414112843)],
        &[(0b01001, &ENTRY_CHRISTIANIZERS_548699853676213111)],
        &[(0b01001, &ENTRY_CHRISTIANIZES_5529854457085699383)],
        &[(0b01001, &ENTRY_CHRISTIANIZING_18179844943674675649)],
        &[(0b11010, &ENTRY_CHROMESTHESIA_13054371463552987700)],
        &[(0b10010, &ENTRY_CHROMATIZE_2668025850337683157)],
        &[(0b10010, &ENTRY_CHROMATIZES_13288811852915667150)],
        &[(0b01001, &ENTRY_CHROMATIZE_2668025850337683157)],
        &[(0b01001, &ENTRY_CHROMATIZES_13288811852915667150)],
        &[(0b00001, &ENTRY_CHROMESTHESIA_13054371463552987700)],
        &[(0b10010, &ENTRY_CHROMICIZE_12696401195528858571)],
        &[(0b10010, &ENTRY_CHROMICIZES_13307038207206351843)],
        &[(0b01001, &ENTRY_CHROMICIZE_12696401195528858571)],
        &[(0b01001, &ENTRY_CHROMICIZES_13307038207206351843)],
        &[(0b10010, &ENTRY_CHROMIZE_12632752465699049760)],
        &[(0b10010, &ENTRY_CHROMIZED_12919396713518006471)],
        &[(0b10010, &ENTRY_CHROMIZES_5753213299896220168)],
        &[(0b10010, &ENTRY_CHROMIZING_5933298884828048845)],
        &[(0b01001, &ENTRY_CHROMIZE_12632752465699049760)],
        &[(0b01001, &ENTRY_CHROMIZED_12919396713518006471)],
        &[(0b01001, &ENTRY_CHROMIZES_5753213299896220168)],
        &[(0b01001, &ENTRY_CHROMIZING_5933298884828048845)],
        &[(0b10010, &ENTRY_CHRONOLOGIZE_3452679310375560624)],
        &[(0b10010, &ENTRY_CHRONOLOGIZED_15542262960559957529)],
        &[(0b10010, &ENTRY_CHRONOLOGIZES_13298230809874096677)],
        &[(0b10010, &ENTRY_CHRONOLOGIZING_12511502139252569918)],
        &[(0b01001, &ENTRY_CHRONOLOGIZE_3452679310375560624)],
        &[(0b01001, &ENTRY_CHRONOLOGIZED_15542262960559957529)],
        &[(0b01001, &ENTRY_CHRONOLOGIZES_13298230809874096677)],
        &[(0b01001, &ENTRY_CHRONOLOGIZING_12511502139252569918)],
    ],
    range: 5..=14,
};

static VARS_CHO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHO_CHILDREN),
    value: None,
};

pub static VARS_CHO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aephori"),
        dictgen::InsensitiveStr::Ascii("enix"),
        dictgen::InsensitiveStr::Ascii("enixes"),
        dictgen::InsensitiveStr::Ascii("ephori"),
        dictgen::InsensitiveStr::Ascii("laemia"),
        dictgen::InsensitiveStr::Ascii("laemias"),
        dictgen::InsensitiveStr::Ascii("lemia"),
        dictgen::InsensitiveStr::Ascii("lemias"),
        dictgen::InsensitiveStr::Ascii("lophaein"),
        dictgen::InsensitiveStr::Ascii("lophein"),
        dictgen::InsensitiveStr::Ascii("risation"),
        dictgen::InsensitiveStr::Ascii("risations"),
        dictgen::InsensitiveStr::Ascii("rization"),
        dictgen::InsensitiveStr::Ascii("rizations"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CHOEPHORI_10552773655980362861)],
        &[(0b11010, &ENTRY_CHENIX_9436665074503213945)],
        &[(0b11010, &ENTRY_CHENIXES_12373276886429414482)],
        &[(0b00001, &ENTRY_CHOEPHORI_10552773655980362861)],
        &[(0b11010, &ENTRY_CHOLEMIA_6834066919164531101)],
        &[(0b11010, &ENTRY_CHOLEMIAS_2456580251486109547)],
        &[(0b00001, &ENTRY_CHOLEMIA_6834066919164531101)],
        &[(0b00001, &ENTRY_CHOLEMIAS_2456580251486109547)],
        &[(0b11010, &ENTRY_CHOLOPHEIN_5429784934275487908)],
        &[(0b00001, &ENTRY_CHOLOPHEIN_5429784934275487908)],
        &[(0b10010, &ENTRY_CHORIZATION_11714300496685916511)],
        &[(0b10010, &ENTRY_CHORIZATIONS_13097819281236468089)],
        &[(0b01001, &ENTRY_CHORIZATION_11714300496685916511)],
        &[(0b01001, &ENTRY_CHORIZATIONS_13097819281236468089)],
    ],
    range: 4..=9,
};

static VARS_CHL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHL_CHILDREN),
    value: None,
};

pub static VARS_CHL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oraemia"),
        dictgen::InsensitiveStr::Ascii("oranaemia"),
        dictgen::InsensitiveStr::Ascii("oranemia"),
        dictgen::InsensitiveStr::Ascii("oremia"),
        dictgen::InsensitiveStr::Ascii("oridise"),
        dictgen::InsensitiveStr::Ascii("oridised"),
        dictgen::InsensitiveStr::Ascii("oridises"),
        dictgen::InsensitiveStr::Ascii("oridising"),
        dictgen::InsensitiveStr::Ascii("oridize"),
        dictgen::InsensitiveStr::Ascii("oridized"),
        dictgen::InsensitiveStr::Ascii("oridizes"),
        dictgen::InsensitiveStr::Ascii("oridizing"),
        dictgen::InsensitiveStr::Ascii("orinise"),
        dictgen::InsensitiveStr::Ascii("orinised"),
        dictgen::InsensitiveStr::Ascii("orinises"),
        dictgen::InsensitiveStr::Ascii("orinising"),
        dictgen::InsensitiveStr::Ascii("orinize"),
        dictgen::InsensitiveStr::Ascii("orinized"),
        dictgen::InsensitiveStr::Ascii("orinizes"),
        dictgen::InsensitiveStr::Ascii("orinizing"),
        dictgen::InsensitiveStr::Ascii("oritisation"),
        dictgen::InsensitiveStr::Ascii("oritisations"),
        dictgen::InsensitiveStr::Ascii("oritization"),
        dictgen::InsensitiveStr::Ascii("oritizations"),
        dictgen::InsensitiveStr::Ascii("oroanaemia"),
        dictgen::InsensitiveStr::Ascii("oroanemia"),
        dictgen::InsensitiveStr::Ascii("oroformisation"),
        dictgen::InsensitiveStr::Ascii("oroformisations"),
        dictgen::InsensitiveStr::Ascii("oroformise"),
        dictgen::InsensitiveStr::Ascii("oroformises"),
        dictgen::InsensitiveStr::Ascii("oroformization"),
        dictgen::InsensitiveStr::Ascii("oroformizations"),
        dictgen::InsensitiveStr::Ascii("oroformize"),
        dictgen::InsensitiveStr::Ascii("oroformizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CHLOREMIA_7420263500114563596)],
        &[(0b11010, &ENTRY_CHLORANEMIA_11270485874157916083)],
        &[(0b10001, &ENTRY_CHLORANEMIA_11270485874157916083)],
        &[(0b10001, &ENTRY_CHLOREMIA_7420263500114563596)],
        &[(0b10010, &ENTRY_CHLORIDIZE_9409684253444584379)],
        &[(0b10010, &ENTRY_CHLORIDIZED_13964319076359404488)],
        &[(0b10010, &ENTRY_CHLORIDIZES_9839694069117617871)],
        &[(0b10010, &ENTRY_CHLORIDIZING_6720106718363520715)],
        &[(0b01001, &ENTRY_CHLORIDIZE_9409684253444584379)],
        &[(0b01001, &ENTRY_CHLORIDIZED_13964319076359404488)],
        &[(0b01001, &ENTRY_CHLORIDIZES_9839694069117617871)],
        &[(0b01001, &ENTRY_CHLORIDIZING_6720106718363520715)],
        &[(0b10010, &ENTRY_CHLORINIZE_12524672883670643023)],
        &[(0b10010, &ENTRY_CHLORINIZED_15553237296393813828)],
        &[(0b10010, &ENTRY_CHLORINIZES_11665336668178598109)],
        &[(0b10010, &ENTRY_CHLORINIZING_14635019816160510486)],
        &[(0b01001, &ENTRY_CHLORINIZE_12524672883670643023)],
        &[(0b01001, &ENTRY_CHLORINIZED_15553237296393813828)],
        &[(0b01001, &ENTRY_CHLORINIZES_11665336668178598109)],
        &[(0b01001, &ENTRY_CHLORINIZING_14635019816160510486)],
        &[(0b10010, &ENTRY_CHLORITIZATION_6737319641916521224)],
        &[(0b10010, &ENTRY_CHLORITIZATIONS_10355800894312961778)],
        &[(0b01001, &ENTRY_CHLORITIZATION_6737319641916521224)],
        &[(0b01001, &ENTRY_CHLORITIZATIONS_10355800894312961778)],
        &[(0b11010, &ENTRY_CHLOROANEMIA_13191336111224105809)],
        &[(0b10001, &ENTRY_CHLOROANEMIA_13191336111224105809)],
        &[(0b10010, &ENTRY_CHLOROFORMIZATION_8020987499143049943)],
        &[(0b10010, &ENTRY_CHLOROFORMIZATIONS_4190940435587315261)],
        &[(0b10010, &ENTRY_CHLOROFORMIZE_9691972914840499500)],
        &[(0b10010, &ENTRY_CHLOROFORMIZES_17289598219370180905)],
        &[(0b01001, &ENTRY_CHLOROFORMIZATION_8020987499143049943)],
        &[(0b01001, &ENTRY_CHLOROFORMIZATIONS_4190940435587315261)],
        &[(0b01001, &ENTRY_CHLOROFORMIZE_9691972914840499500)],
        &[(0b01001, &ENTRY_CHLOROFORMIZES_17289598219370180905)],
    ],
    range: 6..=15,
};

static VARS_CHI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHI_CHILDREN),
    value: None,
};

pub static VARS_CHI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ffer"),
        dictgen::InsensitiveStr::Ascii("ffre"),
        dictgen::InsensitiveStr::Ascii("lder"),
        dictgen::InsensitiveStr::Ascii("ldre"),
        dictgen::InsensitiveStr::Ascii("le"),
        dictgen::InsensitiveStr::Ascii("les"),
        dictgen::InsensitiveStr::Ascii("li"),
        dictgen::InsensitiveStr::Ascii("lies"),
        dictgen::InsensitiveStr::Ascii("lis"),
        dictgen::InsensitiveStr::Ascii("lli"),
        dictgen::InsensitiveStr::Ascii("llies"),
        dictgen::InsensitiveStr::Ascii("maerid"),
        dictgen::InsensitiveStr::Ascii("maerids"),
        dictgen::InsensitiveStr::Ascii("maerism"),
        dictgen::InsensitiveStr::Ascii("maerisms"),
        dictgen::InsensitiveStr::Ascii("merid"),
        dictgen::InsensitiveStr::Ascii("merids"),
        dictgen::InsensitiveStr::Ascii("merism"),
        dictgen::InsensitiveStr::Ascii("merisms"),
        dictgen::InsensitiveStr::Ascii("seled"),
        dictgen::InsensitiveStr::Ascii("seler"),
        dictgen::InsensitiveStr::Ascii("selers"),
        dictgen::InsensitiveStr::Ascii("seling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CHIFFER_14039870972729192317)],
        &[(0b11010, &ENTRY_CHIFFER_14039870972729192317)],
        &[(0b00001, &ENTRY_CHILDER_1783990015359332295)],
        &[(0b11010, &ENTRY_CHILDER_1783990015359332295)],
        &[(0b01001, &ENTRY_CHILI_8746464747530279303)],
        &[(0b01001, &ENTRY_CHILIES_17046197863582163056)],
        &[(0b01001, &ENTRY_CHILI_8746464747530279303)],
        &[(0b01001, &ENTRY_CHILIES_17046197863582163056)],
        &[(0b00001, &ENTRY_CHILIES_17046197863582163056)],
        &[(0b10011, &ENTRY_CHILI_8746464747530279303)],
        &[(0b10011, &ENTRY_CHILIES_17046197863582163056)],
        &[(0b11010, &ENTRY_CHIMERID_12009697971234596857)],
        &[(0b11010, &ENTRY_CHIMERIDS_13323620337760204404)],
        &[(0b11010, &ENTRY_CHIMERISM_4161896008783758509)],
        &[(0b11010, &ENTRY_CHIMERISMS_14057193106240919198)],
        &[(0b00001, &ENTRY_CHIMERID_12009697971234596857)],
        &[(0b00001, &ENTRY_CHIMERIDS_13323620337760204404)],
        &[(0b00001, &ENTRY_CHIMERISM_4161896008783758509)],
        &[(0b00001, &ENTRY_CHIMERISMS_14057193106240919198)],
        &[(0b00001, &ENTRY_CHISELED_15546949667254573790)],
        &[(0b00001, &ENTRY_CHISELER_1587603412683173146)],
        &[(0b00001, &ENTRY_CHISELERS_13598630043321083893)],
        &[(0b00001, &ENTRY_CHISELING_4623966446629021871)],
    ],
    range: 2..=8,
};

static VARS_CHE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHE_CHILDREN),
    value: None,
};

pub static VARS_CHE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ckbook"),
        dictgen::InsensitiveStr::Ascii("ckbooks"),
        dictgen::InsensitiveStr::Ascii("ckerboard"),
        dictgen::InsensitiveStr::Ascii("ckerboards"),
        dictgen::InsensitiveStr::Ascii("ckered"),
        dictgen::InsensitiveStr::Ascii("ckering"),
        dictgen::InsensitiveStr::Ascii("erfulise"),
        dictgen::InsensitiveStr::Ascii("erfulises"),
        dictgen::InsensitiveStr::Ascii("erfulize"),
        dictgen::InsensitiveStr::Ascii("erfulizes"),
        dictgen::InsensitiveStr::Ascii("erly"),
        dictgen::InsensitiveStr::Ascii("licerae"),
        dictgen::InsensitiveStr::Ascii("licere"),
        dictgen::InsensitiveStr::Ascii("micalisation"),
        dictgen::InsensitiveStr::Ascii("micalisations"),
        dictgen::InsensitiveStr::Ascii("micalise"),
        dictgen::InsensitiveStr::Ascii("micalises"),
        dictgen::InsensitiveStr::Ascii("micalization"),
        dictgen::InsensitiveStr::Ascii("micalizations"),
        dictgen::InsensitiveStr::Ascii("micalize"),
        dictgen::InsensitiveStr::Ascii("micalizes"),
        dictgen::InsensitiveStr::Ascii("nix"),
        dictgen::InsensitiveStr::Ascii("nixes"),
        dictgen::InsensitiveStr::Ascii("que"),
        dictgen::InsensitiveStr::Ascii("quebook"),
        dictgen::InsensitiveStr::Ascii("quebooks"),
        dictgen::InsensitiveStr::Ascii("qued"),
        dictgen::InsensitiveStr::Ascii("quer"),
        dictgen::InsensitiveStr::Ascii("querboard"),
        dictgen::InsensitiveStr::Ascii("querboards"),
        dictgen::InsensitiveStr::Ascii("quered"),
        dictgen::InsensitiveStr::Ascii("quering"),
        dictgen::InsensitiveStr::Ascii("quers"),
        dictgen::InsensitiveStr::Ascii("ques"),
        dictgen::InsensitiveStr::Ascii("quing"),
        dictgen::InsensitiveStr::Ascii("rely"),
        dictgen::InsensitiveStr::Ascii("topod"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CHECKBOOK_1836353332372798027)],
        &[(0b00001, &ENTRY_CHECKBOOKS_17373327628350162625)],
        &[(0b00001, &ENTRY_CHECKERBOARD_16789724192435672675)],
        &[(0b00001, &ENTRY_CHECKERBOARDS_4609233615704287762)],
        &[(0b01001, &ENTRY_CHECKERED_9945873716414107297)],
        &[(0b01001, &ENTRY_CHECKERING_4080085454000431870)],
        &[(0b10010, &ENTRY_CHEERFULIZE_10570276368652022687)],
        &[(0b10010, &ENTRY_CHEERFULIZES_5741050836564918219)],
        &[(0b01001, &ENTRY_CHEERFULIZE_10570276368652022687)],
        &[(0b01001, &ENTRY_CHEERFULIZES_5741050836564918219)],
        &[(0b00001, &ENTRY_CHEERLY_9201421946306221416)],
        &[(0b11010, &ENTRY_CHELICERE_7180330785369795833)],
        &[(0b00001, &ENTRY_CHELICERE_7180330785369795833)],
        &[(0b10010, &ENTRY_CHEMICALIZATION_1118964376798303878)],
        &[(0b10010, &ENTRY_CHEMICALIZATIONS_3842257322989197933)],
        &[(0b10010, &ENTRY_CHEMICALIZE_10557765234290972373)],
        &[(0b10010, &ENTRY_CHEMICALIZES_1636425057650084951)],
        &[(0b01001, &ENTRY_CHEMICALIZATION_1118964376798303878)],
        &[(0b01001, &ENTRY_CHEMICALIZATIONS_3842257322989197933)],
        &[(0b01001, &ENTRY_CHEMICALIZE_10557765234290972373)],
        &[(0b01001, &ENTRY_CHEMICALIZES_1636425057650084951)],
        &[(0b10001, &ENTRY_CHENIX_9436665074503213945)],
        &[(0b10001, &ENTRY_CHENIXES_12373276886429414482)],
        &[(0b11010, &ENTRY_CHECK_9710872025351452895)],
        &[(0b11010, &ENTRY_CHECKBOOK_1836353332372798027)],
        &[(0b11010, &ENTRY_CHECKBOOKS_17373327628350162625)],
        &[(0b11010, &ENTRY_CHECKED_9204677386650577893)],
        &[(0b11010, &ENTRY_CHECKER_15996220430790986329)],
        &[(0b11010, &ENTRY_CHECKERBOARD_16789724192435672675)],
        &[(0b11010, &ENTRY_CHECKERBOARDS_4609233615704287762)],
        &[(0b11010, &ENTRY_CHECKERED_9945873716414107297)],
        &[(0b11010, &ENTRY_CHECKERING_4080085454000431870)],
        &[(0b11010, &ENTRY_CHECKERS_10330904262647298958)],
        &[(0b11010, &ENTRY_CHECKS_2013661607139878581)],
        &[(0b11010, &ENTRY_CHECKING_12809623155680137187)],
        &[(0b11010, &ENTRY_CHEERLY_9201421946306221416)],
        &[(0b00001, &ENTRY_CHETOPOD_189649762509045765)],
    ],
    range: 3..=13,
};

static VARS_CHA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CHA_CHILDREN),
    value: None,
};

static VARS_CHA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_CHAC_NODE),
    None,
    Some(&VARS_CHAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CHAL_NODE),
    Some(&VARS_CHAM_NODE),
    Some(&VARS_CHAN_NODE),
    None,
    Some(&VARS_CHAP_NODE),
    None,
    Some(&VARS_CHAR_NODE),
    None,
    Some(&VARS_CHAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CHAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAT_CHILDREN),
    value: None,
};

pub static VARS_CHAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("telisation"),
        dictgen::InsensitiveStr::Ascii("telisations"),
        dictgen::InsensitiveStr::Ascii("telise"),
        dictgen::InsensitiveStr::Ascii("telises"),
        dictgen::InsensitiveStr::Ascii("telization"),
        dictgen::InsensitiveStr::Ascii("telizations"),
        dictgen::InsensitiveStr::Ascii("telize"),
        dictgen::InsensitiveStr::Ascii("telizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CHATTELIZATION_2351241488930486091)],
        &[(0b10010, &ENTRY_CHATTELIZATIONS_2797949953247855051)],
        &[(0b10010, &ENTRY_CHATTELIZE_10573267935784980008)],
        &[(0b10010, &ENTRY_CHATTELIZES_10654226472445860357)],
        &[(0b01001, &ENTRY_CHATTELIZATION_2351241488930486091)],
        &[(0b01001, &ENTRY_CHATTELIZATIONS_2797949953247855051)],
        &[(0b01001, &ENTRY_CHATTELIZE_10573267935784980008)],
        &[(0b01001, &ENTRY_CHATTELIZES_10654226472445860357)],
    ],
    range: 6..=11,
};

static VARS_CHAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAR_CHILDREN),
    value: None,
};

pub static VARS_CHAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("acterisable"),
        dictgen::InsensitiveStr::Ascii("acterisabler"),
        dictgen::InsensitiveStr::Ascii("acterisables"),
        dictgen::InsensitiveStr::Ascii("acterisablest"),
        dictgen::InsensitiveStr::Ascii("acterisation"),
        dictgen::InsensitiveStr::Ascii("acterisations"),
        dictgen::InsensitiveStr::Ascii("acterise"),
        dictgen::InsensitiveStr::Ascii("acterised"),
        dictgen::InsensitiveStr::Ascii("acteriser"),
        dictgen::InsensitiveStr::Ascii("acterisers"),
        dictgen::InsensitiveStr::Ascii("acterises"),
        dictgen::InsensitiveStr::Ascii("acterising"),
        dictgen::InsensitiveStr::Ascii("acterizable"),
        dictgen::InsensitiveStr::Ascii("acterizabler"),
        dictgen::InsensitiveStr::Ascii("acterizables"),
        dictgen::InsensitiveStr::Ascii("acterizablest"),
        dictgen::InsensitiveStr::Ascii("acterization"),
        dictgen::InsensitiveStr::Ascii("acterizations"),
        dictgen::InsensitiveStr::Ascii("acterize"),
        dictgen::InsensitiveStr::Ascii("acterized"),
        dictgen::InsensitiveStr::Ascii("acterizer"),
        dictgen::InsensitiveStr::Ascii("acterizers"),
        dictgen::InsensitiveStr::Ascii("acterizes"),
        dictgen::InsensitiveStr::Ascii("acterizing"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CHARACTERIZABLE_6565431935227576065)],
        &[(0b10010, &ENTRY_CHARACTERIZABLER_14184251246782572062)],
        &[(0b10010, &ENTRY_CHARACTERIZABLES_5781065015666250414)],
        &[(0b10010, &ENTRY_CHARACTERIZABLEST_4747819617396262494)],
        &[(0b10010, &ENTRY_CHARACTERIZATION_11550110625481177338)],
        &[(0b10010, &ENTRY_CHARACTERIZATIONS_13277352132965580301)],
        &[(0b10010, &ENTRY_CHARACTERIZE_14637565961485771135)],
        &[(0b10010, &ENTRY_CHARACTERIZED_17817519055123408875)],
        &[(0b10010, &ENTRY_CHARACTERIZER_2691742990866193884)],
        &[(0b10010, &ENTRY_CHARACTERIZERS_1378131457915956997)],
        &[(0b10010, &ENTRY_CHARACTERIZES_14017907572178871492)],
        &[(0b10010, &ENTRY_CHARACTERIZING_15152517398466769326)],
        &[(0b01001, &ENTRY_CHARACTERIZABLE_6565431935227576065)],
        &[(0b01001, &ENTRY_CHARACTERIZABLER_14184251246782572062)],
        &[(0b01001, &ENTRY_CHARACTERIZABLES_5781065015666250414)],
        &[(0b01001, &ENTRY_CHARACTERIZABLEST_4747819617396262494)],
        &[(0b01001, &ENTRY_CHARACTERIZATION_11550110625481177338)],
        &[(0b01001, &ENTRY_CHARACTERIZATIONS_13277352132965580301)],
        &[(0b01001, &ENTRY_CHARACTERIZE_14637565961485771135)],
        &[(0b01001, &ENTRY_CHARACTERIZED_17817519055123408875)],
        &[(0b01001, &ENTRY_CHARACTERIZER_2691742990866193884)],
        &[(0b01001, &ENTRY_CHARACTERIZERS_1378131457915956997)],
        &[(0b01001, &ENTRY_CHARACTERIZES_14017907572178871492)],
        &[(0b01001, &ENTRY_CHARACTERIZING_15152517398466769326)],
        &[(0b00001, &ENTRY_CHARER_1702867236913115290)],
        &[(0b11010, &ENTRY_CHARER_1702867236913115290)],
    ],
    range: 2..=13,
};

static VARS_CHAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAP_CHILDREN),
    value: None,
};

pub static VARS_CHAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("talisation"),
        dictgen::InsensitiveStr::Ascii("talisations"),
        dictgen::InsensitiveStr::Ascii("talise"),
        dictgen::InsensitiveStr::Ascii("talised"),
        dictgen::InsensitiveStr::Ascii("talises"),
        dictgen::InsensitiveStr::Ascii("talising"),
        dictgen::InsensitiveStr::Ascii("talization"),
        dictgen::InsensitiveStr::Ascii("talizations"),
        dictgen::InsensitiveStr::Ascii("talize"),
        dictgen::InsensitiveStr::Ascii("talized"),
        dictgen::InsensitiveStr::Ascii("talizes"),
        dictgen::InsensitiveStr::Ascii("talizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CHAPTALIZATION_6504001854346497205)],
        &[(0b10010, &ENTRY_CHAPTALIZATIONS_7700818675877073771)],
        &[(0b10010, &ENTRY_CHAPTALIZE_14248650062578755426)],
        &[(0b10010, &ENTRY_CHAPTALIZED_4461125988509678051)],
        &[(0b10010, &ENTRY_CHAPTALIZES_7896297337499803290)],
        &[(0b10010, &ENTRY_CHAPTALIZING_17220948961295716354)],
        &[(0b01001, &ENTRY_CHAPTALIZATION_6504001854346497205)],
        &[(0b01001, &ENTRY_CHAPTALIZATIONS_7700818675877073771)],
        &[(0b01001, &ENTRY_CHAPTALIZE_14248650062578755426)],
        &[(0b01001, &ENTRY_CHAPTALIZED_4461125988509678051)],
        &[(0b01001, &ENTRY_CHAPTALIZES_7896297337499803290)],
        &[(0b01001, &ENTRY_CHAPTALIZING_17220948961295716354)],
    ],
    range: 6..=11,
};

static VARS_CHAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAN_CHILDREN),
    value: None,
};

pub static VARS_CHAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("neled"),
        dictgen::InsensitiveStr::Ascii("neler"),
        dictgen::InsensitiveStr::Ascii("nelers"),
        dictgen::InsensitiveStr::Ascii("neling"),
        dictgen::InsensitiveStr::Ascii("nelisation"),
        dictgen::InsensitiveStr::Ascii("nelisations"),
        dictgen::InsensitiveStr::Ascii("nelise"),
        dictgen::InsensitiveStr::Ascii("nelised"),
        dictgen::InsensitiveStr::Ascii("nelises"),
        dictgen::InsensitiveStr::Ascii("nelising"),
        dictgen::InsensitiveStr::Ascii("nelization"),
        dictgen::InsensitiveStr::Ascii("nelizations"),
        dictgen::InsensitiveStr::Ascii("nelize"),
        dictgen::InsensitiveStr::Ascii("nelized"),
        dictgen::InsensitiveStr::Ascii("nelizes"),
        dictgen::InsensitiveStr::Ascii("nelizing"),
        dictgen::InsensitiveStr::Ascii("nelled"),
        dictgen::InsensitiveStr::Ascii("neller"),
        dictgen::InsensitiveStr::Ascii("nellers"),
        dictgen::InsensitiveStr::Ascii("nelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CHANNELED_3884192849125819469)],
        &[(0b00001, &ENTRY_CHANNELER_7136881456277511173)],
        &[(0b00001, &ENTRY_CHANNELERS_16612593297039553035)],
        &[(0b00001, &ENTRY_CHANNELING_4768505129233237962)],
        &[(0b10010, &ENTRY_CHANNELIZATION_7847892923196708836)],
        &[(0b10010, &ENTRY_CHANNELIZATIONS_2195360393747957501)],
        &[(0b10010, &ENTRY_CHANNELIZE_9103946204000221039)],
        &[(0b10010, &ENTRY_CHANNELIZED_5449663681030349216)],
        &[(0b10010, &ENTRY_CHANNELIZES_8130546736139303129)],
        &[(0b10010, &ENTRY_CHANNELIZING_6754708663381850003)],
        &[(0b01001, &ENTRY_CHANNELIZATION_7847892923196708836)],
        &[(0b01001, &ENTRY_CHANNELIZATIONS_2195360393747957501)],
        &[(0b01001, &ENTRY_CHANNELIZE_9103946204000221039)],
        &[(0b01001, &ENTRY_CHANNELIZED_5449663681030349216)],
        &[(0b01001, &ENTRY_CHANNELIZES_8130546736139303129)],
        &[(0b01001, &ENTRY_CHANNELIZING_6754708663381850003)],
        &[(0b11010, &ENTRY_CHANNELED_3884192849125819469)],
        &[(0b11010, &ENTRY_CHANNELER_7136881456277511173)],
        &[(0b11010, &ENTRY_CHANNELERS_16612593297039553035)],
        &[(0b11010, &ENTRY_CHANNELING_4768505129233237962)],
    ],
    range: 5..=11,
};

static VARS_CHAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAM_CHILDREN),
    value: None,
};

pub static VARS_CHAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eleonise"),
        dictgen::InsensitiveStr::Ascii("eleonises"),
        dictgen::InsensitiveStr::Ascii("eleonize"),
        dictgen::InsensitiveStr::Ascii("eleonizes"),
        dictgen::InsensitiveStr::Ascii("isal"),
        dictgen::InsensitiveStr::Ascii("izal"),
        dictgen::InsensitiveStr::Ascii("pionise"),
        dictgen::InsensitiveStr::Ascii("pionises"),
        dictgen::InsensitiveStr::Ascii("pionize"),
        dictgen::InsensitiveStr::Ascii("pionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CHAMELEONIZE_6643805712111426796)],
        &[(0b10010, &ENTRY_CHAMELEONIZES_18219192353443797519)],
        &[(0b01001, &ENTRY_CHAMELEONIZE_6643805712111426796)],
        &[(0b01001, &ENTRY_CHAMELEONIZES_18219192353443797519)],
        &[(0b10010, &ENTRY_CHAMIZAL_16232076464897458404)],
        &[(0b01001, &ENTRY_CHAMIZAL_16232076464897458404)],
        &[(0b10010, &ENTRY_CHAMPIONIZE_8022492695135570679)],
        &[(0b10010, &ENTRY_CHAMPIONIZES_10731216498351955029)],
        &[(0b01001, &ENTRY_CHAMPIONIZE_8022492695135570679)],
        &[(0b01001, &ENTRY_CHAMPIONIZES_10731216498351955029)],
    ],
    range: 4..=9,
};

static VARS_CHAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAL_CHILDREN),
    value: None,
};

pub static VARS_CHAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("azae"),
        dictgen::InsensitiveStr::Ascii("aze"),
        dictgen::InsensitiveStr::Ascii("daeans"),
        dictgen::InsensitiveStr::Ascii("deans"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CHALAZE_12687207023115659676)],
        &[(0b00001, &ENTRY_CHALAZE_12687207023115659676)],
        &[(0b11010, &ENTRY_CHALDEANS_12673514258939936489)],
        &[(0b00001, &ENTRY_CHALDEANS_12673514258939936489)],
    ],
    range: 3..=6,
};

static VARS_CHAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAE_CHILDREN),
    value: None,
};

pub static VARS_CHAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("topod")],
    values: &[&[(0b11010, &ENTRY_CHETOPOD_189649762509045765)]],
    range: 5..=5,
};

static VARS_CHAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAC_CHILDREN),
    value: None,
};

pub static VARS_CHAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("oes"),
    ],
    values: &[
        &[(0b10001, &ENTRY_CHACES_12737065532724784535)],
        &[(0b11010, &ENTRY_CHACES_12737065532724784535)],
    ],
    range: 2..=3,
};

static VARS_CE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_CE_17001278784018973857)]),
};

static VARS_CE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_CEC_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CEL_NODE),
    None,
    Some(&VARS_CEN_NODE),
    None,
    Some(&VARS_CEP_NODE),
    None,
    Some(&VARS_CER_NODE),
    Some(&VARS_CES_NODE),
    Some(&VARS_CET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CET_CHILDREN),
    value: None,
};

pub static VARS_CET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("us")],
    values: &[&[(0b10001, &ENTRY_CETUS_5843508028170188409)]],
    range: 2..=2,
};

static VARS_CES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CES_CHILDREN),
    value: None,
};

pub static VARS_CES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ar"),
        dictgen::InsensitiveStr::Ascii("aria"),
        dictgen::InsensitiveStr::Ascii("ious"),
        dictgen::InsensitiveStr::Ascii("ium"),
        dictgen::InsensitiveStr::Ascii("iums"),
        dictgen::InsensitiveStr::Ascii("pitose"),
        dictgen::InsensitiveStr::Ascii("pitosely"),
        dictgen::InsensitiveStr::Ascii("tus"),
        dictgen::InsensitiveStr::Ascii("tuses"),
        dictgen::InsensitiveStr::Ascii("ural"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CESAR_17704325165906141578)],
        &[(0b00001, &ENTRY_CESARIA_13260737813085944916)],
        &[(0b00001, &ENTRY_CESIOUS_11410150702051630927)],
        &[(0b11001, &ENTRY_CESIUM_14697098024822079251)],
        &[(0b11001, &ENTRY_CESIUMS_6672725677512073080)],
        &[(0b10001, &ENTRY_CESPITOSE_6409378686720351127)],
        &[(0b10001, &ENTRY_CESPITOSELY_3931130846381787690)],
        &[(0b10001, &ENTRY_CESTUS_4030396889026927959)],
        &[(0b10001, &ENTRY_CESTUSES_307704550846354852)],
        &[(0b10001, &ENTRY_CESURAL_6753528217264809955)],
    ],
    range: 2..=8,
};

static VARS_CER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CER_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_CER_7391662671400680429)]),
};

pub static VARS_CER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("at"),
        dictgen::InsensitiveStr::Ascii("atin"),
        dictgen::InsensitiveStr::Ascii("atins"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ebralisation"),
        dictgen::InsensitiveStr::Ascii("ebralisations"),
        dictgen::InsensitiveStr::Ascii("ebralise"),
        dictgen::InsensitiveStr::Ascii("ebralises"),
        dictgen::InsensitiveStr::Ascii("ebralization"),
        dictgen::InsensitiveStr::Ascii("ebralizations"),
        dictgen::InsensitiveStr::Ascii("ebralize"),
        dictgen::InsensitiveStr::Ascii("ebralizes"),
        dictgen::InsensitiveStr::Ascii("emonialise"),
        dictgen::InsensitiveStr::Ascii("emonialises"),
        dictgen::InsensitiveStr::Ascii("emonialize"),
        dictgen::InsensitiveStr::Ascii("emonializes"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("olite"),
        dictgen::InsensitiveStr::Ascii("ule"),
        dictgen::InsensitiveStr::Ascii("uleolactite"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CERA_4010763817295674400)],
        &[(0b00001, &ENTRY_CERAT_952631974668920340)],
        &[(0b00001, &ENTRY_CERATIN_12655188086840180608)],
        &[(0b00001, &ENTRY_CERATINS_11807307117212505372)],
        &[(0b00001, &ENTRY_CERE_7492486766027596747)],
        &[(0b10010, &ENTRY_CEREBRALIZATION_16112629056325862157)],
        &[(0b10010, &ENTRY_CEREBRALIZATIONS_6843095609202501892)],
        &[(0b10010, &ENTRY_CEREBRALIZE_10176941368321775199)],
        &[(0b10010, &ENTRY_CEREBRALIZES_3809932987263287223)],
        &[(0b01001, &ENTRY_CEREBRALIZATION_16112629056325862157)],
        &[(0b01001, &ENTRY_CEREBRALIZATIONS_6843095609202501892)],
        &[(0b01001, &ENTRY_CEREBRALIZE_10176941368321775199)],
        &[(0b01001, &ENTRY_CEREBRALIZES_3809932987263287223)],
        &[(0b10010, &ENTRY_CEREMONIALIZE_16487784841115936970)],
        &[(0b10010, &ENTRY_CEREMONIALIZES_10200837703193624027)],
        &[(0b01001, &ENTRY_CEREMONIALIZE_16487784841115936970)],
        &[(0b01001, &ENTRY_CEREMONIALIZES_10200837703193624027)],
        &[(0b00001, &ENTRY_CERES_13909916927122501672)],
        &[(0b00001, &ENTRY_CEROLITE_13936865573619235917)],
        &[(0b00001, &ENTRY_CERULE_13807908748488324309)],
        &[(0b00001, &ENTRY_CERULEOLACTITE_14138382859124709242)],
    ],
    range: 1..=13,
};

static VARS_CEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CEP_CHILDREN),
    value: None,
};

pub static VARS_CEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("halisation"),
        dictgen::InsensitiveStr::Ascii("halisations"),
        dictgen::InsensitiveStr::Ascii("halization"),
        dictgen::InsensitiveStr::Ascii("halizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CEPHALIZATION_9633792686486937214)],
        &[(0b10010, &ENTRY_CEPHALIZATIONS_4196229478743299448)],
        &[(0b01001, &ENTRY_CEPHALIZATION_9633792686486937214)],
        &[(0b01001, &ENTRY_CEPHALIZATIONS_4196229478743299448)],
    ],
    range: 10..=11,
};

static VARS_CEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CEN_CHILDREN),
    value: None,
};

static VARS_CEN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CENA_NODE),
    None,
    None,
    None,
    Some(&VARS_CENE_NODE),
    None,
    None,
    None,
    Some(&VARS_CENI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CENO_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_CENT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CENT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CENT_CHILDREN),
    value: None,
};

static VARS_CENT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_CENTE_NODE),
    None,
    None,
    None,
    Some(&VARS_CENTI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CENTR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CENTR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENTR_CHILDREN),
    value: None,
};

pub static VARS_CENTR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("eable"),
        dictgen::InsensitiveStr::Ascii("eables"),
        dictgen::InsensitiveStr::Ascii("eboard"),
        dictgen::InsensitiveStr::Ascii("eboards"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("efold"),
        dictgen::InsensitiveStr::Ascii("efolds"),
        dictgen::InsensitiveStr::Ascii("eless"),
        dictgen::InsensitiveStr::Ascii("elesser"),
        dictgen::InsensitiveStr::Ascii("elessest"),
        dictgen::InsensitiveStr::Ascii("eline"),
        dictgen::InsensitiveStr::Ascii("elines"),
        dictgen::InsensitiveStr::Ascii("emost"),
        dictgen::InsensitiveStr::Ascii("epiece"),
        dictgen::InsensitiveStr::Ascii("epieces"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("eville"),
        dictgen::InsensitiveStr::Ascii("ifugalisation"),
        dictgen::InsensitiveStr::Ascii("ifugalisations"),
        dictgen::InsensitiveStr::Ascii("ifugalise"),
        dictgen::InsensitiveStr::Ascii("ifugalised"),
        dictgen::InsensitiveStr::Ascii("ifugalises"),
        dictgen::InsensitiveStr::Ascii("ifugalising"),
        dictgen::InsensitiveStr::Ascii("ifugalization"),
        dictgen::InsensitiveStr::Ascii("ifugalizations"),
        dictgen::InsensitiveStr::Ascii("ifugalize"),
        dictgen::InsensitiveStr::Ascii("ifugalized"),
        dictgen::InsensitiveStr::Ascii("ifugalizes"),
        dictgen::InsensitiveStr::Ascii("ifugalizing"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("ings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CENTRALIZATION_14489606925183485682)],
        &[(0b10010, &ENTRY_CENTRALIZATIONS_14077284492075609276)],
        &[(0b10010, &ENTRY_CENTRALIZE_3598052449531879733)],
        &[(0b10010, &ENTRY_CENTRALIZED_11571044202801829690)],
        &[(0b10010, &ENTRY_CENTRALIZER_6120657287536400694)],
        &[(0b10010, &ENTRY_CENTRALIZERS_17147959706080239831)],
        &[(0b10010, &ENTRY_CENTRALIZES_13364036337997133322)],
        &[(0b10010, &ENTRY_CENTRALIZING_16563092158705447235)],
        &[(0b01001, &ENTRY_CENTRALIZATION_14489606925183485682)],
        &[(0b01001, &ENTRY_CENTRALIZATIONS_14077284492075609276)],
        &[(0b01001, &ENTRY_CENTRALIZE_3598052449531879733)],
        &[(0b01001, &ENTRY_CENTRALIZED_11571044202801829690)],
        &[(0b01001, &ENTRY_CENTRALIZER_6120657287536400694)],
        &[(0b01001, &ENTRY_CENTRALIZERS_17147959706080239831)],
        &[(0b01001, &ENTRY_CENTRALIZES_13364036337997133322)],
        &[(0b01001, &ENTRY_CENTRALIZING_16563092158705447235)],
        &[(0b11010, &ENTRY_CENTER_2062827205925125611)],
        &[(0b11010, &ENTRY_CENTERABLE_1736442923708139393)],
        &[(0b11010, &ENTRY_CENTERABLES_15482936396077523679)],
        &[(0b11010, &ENTRY_CENTERBOARD_12936059728076156984)],
        &[(0b11010, &ENTRY_CENTERBOARDS_8162665466509661850)],
        &[(0b11010, &ENTRY_CENTERED_15927189749167280073)],
        &[(0b11010, &ENTRY_CENTERFOLD_13964837998835453817)],
        &[(0b11010, &ENTRY_CENTERFOLDS_6987098084704804029)],
        &[(0b11010, &ENTRY_CENTERLESS_9593765835963687698)],
        &[(0b11010, &ENTRY_CENTERLESSER_11642941641041736956)],
        &[(0b11010, &ENTRY_CENTERLESSEST_13108645794898456200)],
        &[(0b11010, &ENTRY_CENTERLINE_8193954350816983103)],
        &[(0b11010, &ENTRY_CENTERLINES_5503867658086621883)],
        &[(0b11010, &ENTRY_CENTERMOST_17931621876330932092)],
        &[(0b11010, &ENTRY_CENTERPIECE_8959571131813824904)],
        &[(0b11010, &ENTRY_CENTERPIECES_9003602563873687762)],
        &[(0b11010, &ENTRY_CENTERER_2663515071115995852)],
        &[(0b11010, &ENTRY_CENTERERS_12660813565427012077)],
        &[(0b11010, &ENTRY_CENTERS_3653356479744194617)],
        &[(0b11010, &ENTRY_CENTERVILLE_1463746369386483595)],
        &[(0b10010, &ENTRY_CENTRIFUGALIZATION_9870283591412029358)],
        &[(0b10010, &ENTRY_CENTRIFUGALIZATIONS_10177560764588170199)],
        &[(0b10010, &ENTRY_CENTRIFUGALIZE_16234395767957633471)],
        &[(0b10010, &ENTRY_CENTRIFUGALIZED_10606420628931925286)],
        &[(0b10010, &ENTRY_CENTRIFUGALIZES_2357194867049429611)],
        &[(0b10010, &ENTRY_CENTRIFUGALIZING_3551395843046197608)],
        &[(0b01001, &ENTRY_CENTRIFUGALIZATION_9870283591412029358)],
        &[(0b01001, &ENTRY_CENTRIFUGALIZATIONS_10177560764588170199)],
        &[(0b01001, &ENTRY_CENTRIFUGALIZE_16234395767957633471)],
        &[(0b01001, &ENTRY_CENTRIFUGALIZED_10606420628931925286)],
        &[(0b01001, &ENTRY_CENTRIFUGALIZES_2357194867049429611)],
        &[(0b01001, &ENTRY_CENTRIFUGALIZING_3551395843046197608)],
        &[(0b11010, &ENTRY_CENTERING_12678821431832397053)],
        &[(0b11010, &ENTRY_CENTERINGS_14821164417176031250)],
    ],
    range: 1..=14,
};

static VARS_CENTI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENTI_CHILDREN),
    value: None,
};

pub static VARS_CENTI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gramme"),
        dictgen::InsensitiveStr::Ascii("grammes"),
        dictgen::InsensitiveStr::Ascii("liter"),
        dictgen::InsensitiveStr::Ascii("liters"),
        dictgen::InsensitiveStr::Ascii("litre"),
        dictgen::InsensitiveStr::Ascii("litres"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("meters"),
        dictgen::InsensitiveStr::Ascii("metre"),
        dictgen::InsensitiveStr::Ascii("metres"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CENTIGRAM_16369133942610299137)],
        &[(0b10010, &ENTRY_CENTIGRAMS_4446712383280702017)],
        &[(0b00001, &ENTRY_CENTILITER_5486758117872326030)],
        &[(0b00001, &ENTRY_CENTILITERS_1152239446012655040)],
        &[(0b11010, &ENTRY_CENTILITER_5486758117872326030)],
        &[(0b11010, &ENTRY_CENTILITERS_1152239446012655040)],
        &[(0b01001, &ENTRY_CENTIMETER_16919893077343778486)],
        &[(0b01001, &ENTRY_CENTIMETERS_2488768602472487806)],
        &[(0b11010, &ENTRY_CENTIMETER_16919893077343778486)],
        &[(0b11010, &ENTRY_CENTIMETERS_2488768602472487806)],
    ],
    range: 5..=7,
};

static VARS_CENTE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENTE_CHILDREN),
    value: None,
};

pub static VARS_CENTE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rable"),
        dictgen::InsensitiveStr::Ascii("rables"),
        dictgen::InsensitiveStr::Ascii("rboard"),
        dictgen::InsensitiveStr::Ascii("rboards"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("rfold"),
        dictgen::InsensitiveStr::Ascii("rfolds"),
        dictgen::InsensitiveStr::Ascii("ring"),
        dictgen::InsensitiveStr::Ascii("rings"),
        dictgen::InsensitiveStr::Ascii("rless"),
        dictgen::InsensitiveStr::Ascii("rlesser"),
        dictgen::InsensitiveStr::Ascii("rlessest"),
        dictgen::InsensitiveStr::Ascii("rline"),
        dictgen::InsensitiveStr::Ascii("rlines"),
        dictgen::InsensitiveStr::Ascii("rmost"),
        dictgen::InsensitiveStr::Ascii("rpiece"),
        dictgen::InsensitiveStr::Ascii("rpieces"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("rville"),
    ],
    values: &[
        &[(0b01001, &ENTRY_CENTER_2062827205925125611)],
        &[(0b00001, &ENTRY_CENTERABLE_1736442923708139393)],
        &[(0b00001, &ENTRY_CENTERABLES_15482936396077523679)],
        &[(0b00001, &ENTRY_CENTERBOARD_12936059728076156984)],
        &[(0b00001, &ENTRY_CENTERBOARDS_8162665466509661850)],
        &[(0b01001, &ENTRY_CENTERED_15927189749167280073)],
        &[(0b00001, &ENTRY_CENTERER_2663515071115995852)],
        &[(0b00001, &ENTRY_CENTERERS_12660813565427012077)],
        &[(0b00001, &ENTRY_CENTERFOLD_13964837998835453817)],
        &[(0b00001, &ENTRY_CENTERFOLDS_6987098084704804029)],
        &[(0b01001, &ENTRY_CENTERING_12678821431832397053)],
        &[(0b01001, &ENTRY_CENTERINGS_14821164417176031250)],
        &[(0b00001, &ENTRY_CENTERLESS_9593765835963687698)],
        &[(0b00001, &ENTRY_CENTERLESSER_11642941641041736956)],
        &[(0b00001, &ENTRY_CENTERLESSEST_13108645794898456200)],
        &[(0b00001, &ENTRY_CENTERLINE_8193954350816983103)],
        &[(0b00001, &ENTRY_CENTERLINES_5503867658086621883)],
        &[(0b00001, &ENTRY_CENTERMOST_17931621876330932092)],
        &[(0b00001, &ENTRY_CENTERPIECE_8959571131813824904)],
        &[(0b00001, &ENTRY_CENTERPIECES_9003602563873687762)],
        &[(0b01001, &ENTRY_CENTERS_3653356479744194617)],
        &[(0b00001, &ENTRY_CENTERVILLE_1463746369386483595)],
    ],
    range: 1..=8,
};

static VARS_CENO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENO_CHILDREN),
    value: None,
};

pub static VARS_CENO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("be"),
        dictgen::InsensitiveStr::Ascii("bitism"),
        dictgen::InsensitiveStr::Ascii("bium"),
        dictgen::InsensitiveStr::Ascii("by"),
        dictgen::InsensitiveStr::Ascii("genetic"),
        dictgen::InsensitiveStr::Ascii("genetically"),
        dictgen::InsensitiveStr::Ascii("site"),
        dictgen::InsensitiveStr::Ascii("species"),
        dictgen::InsensitiveStr::Ascii("specific"),
        dictgen::InsensitiveStr::Ascii("specifically"),
        dictgen::InsensitiveStr::Ascii("zoic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_CENOBE_15621742511041336445)],
        &[(0b10001, &ENTRY_CENOBITISM_10552992890229559594)],
        &[(0b10001, &ENTRY_CENOBIUM_9531258636879765081)],
        &[(0b10001, &ENTRY_CENOBY_12287306148631547483)],
        &[
            (0b10001, &ENTRY_CENOGENETIC_3476451464373390522),
            (0b10001, &ENTRY_CENOGENETIC_5287833837469101531),
        ],
        &[(0b10001, &ENTRY_CENOGENETICALLY_1887927515979187697)],
        &[(0b10001, &ENTRY_CENOSITE_14996204277047943901)],
        &[(0b10001, &ENTRY_CENOSPECIES_1304456854215858015)],
        &[(0b10001, &ENTRY_CENOSPECIFIC_200658439075912747)],
        &[(0b10001, &ENTRY_CENOSPECIFICALLY_14746841820461979584)],
        &[(0b10001, &ENTRY_CENOZOIC_15012859896037847714)],
    ],
    range: 2..=12,
};

static VARS_CENI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENI_CHILDREN),
    value: None,
};

pub static VARS_CENI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("s")],
    values: &[&[(0b10001, &ENTRY_CENIS_12176224815013604688)]],
    range: 1..=1,
};

static VARS_CENE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENE_CHILDREN),
    value: None,
};

pub static VARS_CENE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthesis"),
    ],
    values: &[
        &[(0b10001, &ENTRY_CENESTHESIA_4011067798171287989)],
        &[(0b10001, &ENTRY_CENESTHESIAS_16287981603481963061)],
        &[(0b10001, &ENTRY_CENESTHESIS_9192577966958417138)],
    ],
    range: 7..=8,
};

static VARS_CENA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENA_CHILDREN),
    value: None,
};

pub static VARS_CENA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cle"),
        dictgen::InsensitiveStr::Ascii("culum"),
    ],
    values: &[
        &[(0b10001, &ENTRY_CENACLE_11560322831244580416)],
        &[(0b10001, &ENTRY_CENACULUM_9966061997534531582)],
    ],
    range: 3..=5,
};

static VARS_CEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CEL_CHILDREN),
    value: None,
};

pub static VARS_CEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("astraceae"),
        dictgen::InsensitiveStr::Ascii("astraceous"),
        dictgen::InsensitiveStr::Ascii("estialise"),
        dictgen::InsensitiveStr::Ascii("estialises"),
        dictgen::InsensitiveStr::Ascii("estialize"),
        dictgen::InsensitiveStr::Ascii("estializes"),
        dictgen::InsensitiveStr::Ascii("estine"),
        dictgen::InsensitiveStr::Ascii("iac"),
        dictgen::InsensitiveStr::Ascii("iacs"),
        dictgen::InsensitiveStr::Ascii("ialgia"),
        dictgen::InsensitiveStr::Ascii("iomyalgia"),
        dictgen::InsensitiveStr::Ascii("iorrhea"),
        dictgen::InsensitiveStr::Ascii("ioscopy"),
        dictgen::InsensitiveStr::Ascii("iotomy"),
        dictgen::InsensitiveStr::Ascii("om"),
        dictgen::InsensitiveStr::Ascii("oma"),
        dictgen::InsensitiveStr::Ascii("omata"),
        dictgen::InsensitiveStr::Ascii("oms"),
        dictgen::InsensitiveStr::Ascii("oscope"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CELASTRACEAE_248052160521437337)],
        &[(0b00001, &ENTRY_CELASTRACEOUS_13139092700507364792)],
        &[(0b10010, &ENTRY_CELESTIALIZE_538727862299269646)],
        &[(0b10010, &ENTRY_CELESTIALIZES_9179277409781355070)],
        &[(0b01001, &ENTRY_CELESTIALIZE_538727862299269646)],
        &[(0b01001, &ENTRY_CELESTIALIZES_9179277409781355070)],
        &[(0b00001, &ENTRY_CELESTINE_6574095563191113248)],
        &[(0b10001, &ENTRY_CELIAC_18102856828663564552)],
        &[(0b10001, &ENTRY_CELIACS_7167873050372594104)],
        &[(0b10001, &ENTRY_CELIALGIA_4390117124611657564)],
        &[(0b10001, &ENTRY_CELIOMYALGIA_11280554360719408547)],
        &[(0b10001, &ENTRY_CELIORRHEA_6798475442650879420)],
        &[(0b10001, &ENTRY_CELIOSCOPY_10064554083059800495)],
        &[(0b10001, &ENTRY_CELIOTOMY_7002375967235750854)],
        &[(0b11001, &ENTRY_CELOM_6954296651788090066)],
        &[(0b10001, &ENTRY_CELOMA_16635368470102536323)],
        &[(0b10001, &ENTRY_CELOMATA_9462689710315550329)],
        &[(0b11001, &ENTRY_CELOMS_4896390401945145201)],
        &[(0b10001, &ENTRY_CELOSCOPE_4883213512077398928)],
        &[(0b10010, &ENTRY_CELTICIZE_7118296023797408335)],
        &[(0b10010, &ENTRY_CELTICIZES_1129237498010014182)],
        &[(0b01001, &ENTRY_CELTICIZE_7118296023797408335)],
        &[(0b01001, &ENTRY_CELTICIZES_1129237498010014182)],
    ],
    range: 2..=10,
};

static VARS_CEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CEC_CHILDREN),
    value: None,
};

pub static VARS_CEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ally"),
        dictgen::InsensitiveStr::Ascii("itis"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("ity"),
        dictgen::InsensitiveStr::Ascii("ostomy"),
        dictgen::InsensitiveStr::Ascii("otomy"),
    ],
    values: &[
        &[(0b10001, &ENTRY_CECALLY_9670506280479282690)],
        &[(0b10001, &ENTRY_CECITIS_3074214842392316094)],
        &[(0b10001, &ENTRY_CECITISES_8125550960993244895)],
        &[(0b10001, &ENTRY_CECITY_109164963209594686)],
        &[(0b10001, &ENTRY_CECOSTOMY_14076938077100733913)],
        &[(0b10001, &ENTRY_CECOTOMY_6391026121304575885)],
    ],
    range: 3..=6,
};

static VARS_CA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CA_CHILDREN),
    value: None,
};

static VARS_CA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_CAC_NODE),
    Some(&VARS_CAD_NODE),
    Some(&VARS_CAE_NODE),
    Some(&VARS_CAF_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CAL_NODE),
    Some(&VARS_CAM_NODE),
    Some(&VARS_CAN_NODE),
    None,
    Some(&VARS_CAP_NODE),
    None,
    Some(&VARS_CAR_NODE),
    Some(&VARS_CAS_NODE),
    Some(&VARS_CAT_NODE),
    Some(&VARS_CAU_NODE),
    Some(&VARS_CAV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_CAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAV_CHILDREN),
    value: None,
};

pub static VARS_CAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iare"),
        dictgen::InsensitiveStr::Ascii("iares"),
        dictgen::InsensitiveStr::Ascii("ilation"),
        dictgen::InsensitiveStr::Ascii("iled"),
        dictgen::InsensitiveStr::Ascii("iler"),
        dictgen::InsensitiveStr::Ascii("ilers"),
        dictgen::InsensitiveStr::Ascii("iling"),
        dictgen::InsensitiveStr::Ascii("ilings"),
        dictgen::InsensitiveStr::Ascii("illation"),
        dictgen::InsensitiveStr::Ascii("illed"),
        dictgen::InsensitiveStr::Ascii("iller"),
        dictgen::InsensitiveStr::Ascii("illers"),
        dictgen::InsensitiveStr::Ascii("illing"),
        dictgen::InsensitiveStr::Ascii("illings"),
    ],
    values: &[
        &[(0b10011, &ENTRY_CAVIAR_13293796828806890873)],
        &[(0b10011, &ENTRY_CAVIARS_11505002019485473608)],
        &[(0b00001, &ENTRY_CAVILATION_6190881958167857313)],
        &[(0b01001, &ENTRY_CAVILED_11192889244066147526)],
        &[(0b00001, &ENTRY_CAVILER_9496917240731757934)],
        &[(0b00001, &ENTRY_CAVILERS_12077868647577851396)],
        &[(0b01001, &ENTRY_CAVILING_17734305391918802240)],
        &[(0b01001, &ENTRY_CAVILINGS_2004720957308004113)],
        &[(0b11010, &ENTRY_CAVILATION_6190881958167857313)],
        &[(0b11010, &ENTRY_CAVILED_11192889244066147526)],
        &[(0b11010, &ENTRY_CAVILER_9496917240731757934)],
        &[(0b11010, &ENTRY_CAVILERS_12077868647577851396)],
        &[(0b11010, &ENTRY_CAVILING_17734305391918802240)],
        &[(0b11010, &ENTRY_CAVILINGS_2004720957308004113)],
    ],
    range: 4..=8,
};

static VARS_CAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAU_CHILDREN),
    value: None,
};

pub static VARS_CAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sticisation"),
        dictgen::InsensitiveStr::Ascii("sticisations"),
        dictgen::InsensitiveStr::Ascii("sticise"),
        dictgen::InsensitiveStr::Ascii("sticiser"),
        dictgen::InsensitiveStr::Ascii("sticisers"),
        dictgen::InsensitiveStr::Ascii("sticises"),
        dictgen::InsensitiveStr::Ascii("sticization"),
        dictgen::InsensitiveStr::Ascii("sticizations"),
        dictgen::InsensitiveStr::Ascii("sticize"),
        dictgen::InsensitiveStr::Ascii("sticizer"),
        dictgen::InsensitiveStr::Ascii("sticizers"),
        dictgen::InsensitiveStr::Ascii("sticizes"),
        dictgen::InsensitiveStr::Ascii("terisation"),
        dictgen::InsensitiveStr::Ascii("terisations"),
        dictgen::InsensitiveStr::Ascii("terise"),
        dictgen::InsensitiveStr::Ascii("terised"),
        dictgen::InsensitiveStr::Ascii("terises"),
        dictgen::InsensitiveStr::Ascii("terising"),
        dictgen::InsensitiveStr::Ascii("terization"),
        dictgen::InsensitiveStr::Ascii("terizations"),
        dictgen::InsensitiveStr::Ascii("terize"),
        dictgen::InsensitiveStr::Ascii("terized"),
        dictgen::InsensitiveStr::Ascii("terizes"),
        dictgen::InsensitiveStr::Ascii("terizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CAUSTICIZATION_783439317842741879)],
        &[(0b10010, &ENTRY_CAUSTICIZATIONS_8334657249022891576)],
        &[(0b10010, &ENTRY_CAUSTICIZE_4584551572444823336)],
        &[(0b10010, &ENTRY_CAUSTICIZER_6841395610651928471)],
        &[(0b10010, &ENTRY_CAUSTICIZERS_5473710480358282522)],
        &[(0b10010, &ENTRY_CAUSTICIZES_6084094714495938613)],
        &[(0b01001, &ENTRY_CAUSTICIZATION_783439317842741879)],
        &[(0b01001, &ENTRY_CAUSTICIZATIONS_8334657249022891576)],
        &[(0b01001, &ENTRY_CAUSTICIZE_4584551572444823336)],
        &[(0b01001, &ENTRY_CAUSTICIZER_6841395610651928471)],
        &[(0b01001, &ENTRY_CAUSTICIZERS_5473710480358282522)],
        &[(0b01001, &ENTRY_CAUSTICIZES_6084094714495938613)],
        &[(0b10010, &ENTRY_CAUTERIZATION_11314889126154078843)],
        &[(0b10010, &ENTRY_CAUTERIZATIONS_4890341307628816522)],
        &[(0b10010, &ENTRY_CAUTERIZE_11145047639262148996)],
        &[(0b10010, &ENTRY_CAUTERIZED_12118160833980913736)],
        &[(0b10010, &ENTRY_CAUTERIZES_17337688368809469148)],
        &[(0b10010, &ENTRY_CAUTERIZING_14426485505826676009)],
        &[(0b01001, &ENTRY_CAUTERIZATION_11314889126154078843)],
        &[(0b01001, &ENTRY_CAUTERIZATIONS_4890341307628816522)],
        &[(0b01001, &ENTRY_CAUTERIZE_11145047639262148996)],
        &[(0b01001, &ENTRY_CAUTERIZED_12118160833980913736)],
        &[(0b01001, &ENTRY_CAUTERIZES_17337688368809469148)],
        &[(0b01001, &ENTRY_CAUTERIZING_14426485505826676009)],
    ],
    range: 6..=12,
};

static VARS_CAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CAT_CHILDREN),
    value: None,
};

static VARS_CAT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CATA_NODE),
    None,
    None,
    None,
    Some(&VARS_CATE_NODE),
    None,
    None,
    Some(&VARS_CATH_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CATH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CATH_CHILDREN),
    value: None,
};

pub static VARS_CATH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arised"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arising"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arized"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("arizing"),
        dictgen::InsensitiveStr::Ascii("eterisation"),
        dictgen::InsensitiveStr::Ascii("eterisations"),
        dictgen::InsensitiveStr::Ascii("eterise"),
        dictgen::InsensitiveStr::Ascii("eterised"),
        dictgen::InsensitiveStr::Ascii("eterises"),
        dictgen::InsensitiveStr::Ascii("eterising"),
        dictgen::InsensitiveStr::Ascii("eterization"),
        dictgen::InsensitiveStr::Ascii("eterizations"),
        dictgen::InsensitiveStr::Ascii("eterize"),
        dictgen::InsensitiveStr::Ascii("eterized"),
        dictgen::InsensitiveStr::Ascii("eterizes"),
        dictgen::InsensitiveStr::Ascii("eterizing"),
        dictgen::InsensitiveStr::Ascii("olicisation"),
        dictgen::InsensitiveStr::Ascii("olicisations"),
        dictgen::InsensitiveStr::Ascii("olicise"),
        dictgen::InsensitiveStr::Ascii("olicised"),
        dictgen::InsensitiveStr::Ascii("oliciser"),
        dictgen::InsensitiveStr::Ascii("olicisers"),
        dictgen::InsensitiveStr::Ascii("olicises"),
        dictgen::InsensitiveStr::Ascii("olicising"),
        dictgen::InsensitiveStr::Ascii("olicization"),
        dictgen::InsensitiveStr::Ascii("olicizations"),
        dictgen::InsensitiveStr::Ascii("olicize"),
        dictgen::InsensitiveStr::Ascii("olicized"),
        dictgen::InsensitiveStr::Ascii("olicizer"),
        dictgen::InsensitiveStr::Ascii("olicizers"),
        dictgen::InsensitiveStr::Ascii("olicizes"),
        dictgen::InsensitiveStr::Ascii("olicizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CATHARIZE_1274769098491691139)],
        &[(0b10010, &ENTRY_CATHARIZED_7243939307071691808)],
        &[(0b10010, &ENTRY_CATHARIZES_5237565431552696013)],
        &[(0b10010, &ENTRY_CATHARIZING_7925028932359317897)],
        &[(0b01001, &ENTRY_CATHARIZE_1274769098491691139)],
        &[(0b01001, &ENTRY_CATHARIZED_7243939307071691808)],
        &[(0b01001, &ENTRY_CATHARIZES_5237565431552696013)],
        &[(0b01001, &ENTRY_CATHARIZING_7925028932359317897)],
        &[(0b10010, &ENTRY_CATHETERIZATION_3744811591478338437)],
        &[(0b10010, &ENTRY_CATHETERIZATIONS_5962217885260693783)],
        &[(0b10010, &ENTRY_CATHETERIZE_6223868023340323760)],
        &[(0b10010, &ENTRY_CATHETERIZED_2068677963449945916)],
        &[(0b10010, &ENTRY_CATHETERIZES_8282905890220338225)],
        &[(0b10010, &ENTRY_CATHETERIZING_9242723783135014192)],
        &[(0b01001, &ENTRY_CATHETERIZATION_3744811591478338437)],
        &[(0b01001, &ENTRY_CATHETERIZATIONS_5962217885260693783)],
        &[(0b01001, &ENTRY_CATHETERIZE_6223868023340323760)],
        &[(0b01001, &ENTRY_CATHETERIZED_2068677963449945916)],
        &[(0b01001, &ENTRY_CATHETERIZES_8282905890220338225)],
        &[(0b01001, &ENTRY_CATHETERIZING_9242723783135014192)],
        &[(0b10010, &ENTRY_CATHOLICIZATION_12300499468594157854)],
        &[(0b10010, &ENTRY_CATHOLICIZATIONS_16523318186466117967)],
        &[(0b10010, &ENTRY_CATHOLICIZE_10498710367246830234)],
        &[(0b10010, &ENTRY_CATHOLICIZED_10053746865059391537)],
        &[(0b10010, &ENTRY_CATHOLICIZER_3986145398863481078)],
        &[(0b10010, &ENTRY_CATHOLICIZERS_3541962920626482853)],
        &[(0b10010, &ENTRY_CATHOLICIZES_10974246470223113109)],
        &[(0b10010, &ENTRY_CATHOLICIZING_16243083594073649559)],
        &[(0b01001, &ENTRY_CATHOLICIZATION_12300499468594157854)],
        &[(0b01001, &ENTRY_CATHOLICIZATIONS_16523318186466117967)],
        &[(0b01001, &ENTRY_CATHOLICIZE_10498710367246830234)],
        &[(0b01001, &ENTRY_CATHOLICIZED_10053746865059391537)],
        &[(0b01001, &ENTRY_CATHOLICIZER_3986145398863481078)],
        &[(0b01001, &ENTRY_CATHOLICIZERS_3541962920626482853)],
        &[(0b01001, &ENTRY_CATHOLICIZES_10974246470223113109)],
        &[(0b01001, &ENTRY_CATHOLICIZING_16243083594073649559)],
    ],
    range: 5..=12,
};

static VARS_CATE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CATE_CHILDREN),
    value: None,
};

pub static VARS_CATE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chisable"),
        dictgen::InsensitiveStr::Ascii("chisabler"),
        dictgen::InsensitiveStr::Ascii("chisables"),
        dictgen::InsensitiveStr::Ascii("chisablest"),
        dictgen::InsensitiveStr::Ascii("chisation"),
        dictgen::InsensitiveStr::Ascii("chisations"),
        dictgen::InsensitiveStr::Ascii("chise"),
        dictgen::InsensitiveStr::Ascii("chised"),
        dictgen::InsensitiveStr::Ascii("chiser"),
        dictgen::InsensitiveStr::Ascii("chisers"),
        dictgen::InsensitiveStr::Ascii("chises"),
        dictgen::InsensitiveStr::Ascii("chising"),
        dictgen::InsensitiveStr::Ascii("chisings"),
        dictgen::InsensitiveStr::Ascii("chizable"),
        dictgen::InsensitiveStr::Ascii("chizabler"),
        dictgen::InsensitiveStr::Ascii("chizables"),
        dictgen::InsensitiveStr::Ascii("chizablest"),
        dictgen::InsensitiveStr::Ascii("chization"),
        dictgen::InsensitiveStr::Ascii("chizations"),
        dictgen::InsensitiveStr::Ascii("chize"),
        dictgen::InsensitiveStr::Ascii("chized"),
        dictgen::InsensitiveStr::Ascii("chizer"),
        dictgen::InsensitiveStr::Ascii("chizers"),
        dictgen::InsensitiveStr::Ascii("chizes"),
        dictgen::InsensitiveStr::Ascii("chizing"),
        dictgen::InsensitiveStr::Ascii("chizings"),
        dictgen::InsensitiveStr::Ascii("gorisation"),
        dictgen::InsensitiveStr::Ascii("gorisations"),
        dictgen::InsensitiveStr::Ascii("gorise"),
        dictgen::InsensitiveStr::Ascii("gorised"),
        dictgen::InsensitiveStr::Ascii("goriser"),
        dictgen::InsensitiveStr::Ascii("gorisers"),
        dictgen::InsensitiveStr::Ascii("gorises"),
        dictgen::InsensitiveStr::Ascii("gorising"),
        dictgen::InsensitiveStr::Ascii("gorization"),
        dictgen::InsensitiveStr::Ascii("gorizations"),
        dictgen::InsensitiveStr::Ascii("gorize"),
        dictgen::InsensitiveStr::Ascii("gorized"),
        dictgen::InsensitiveStr::Ascii("gorizer"),
        dictgen::InsensitiveStr::Ascii("gorizers"),
        dictgen::InsensitiveStr::Ascii("gorizes"),
        dictgen::InsensitiveStr::Ascii("gorizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CATECHIZABLE_8148927032591971850)],
        &[(0b10010, &ENTRY_CATECHIZABLER_16489482911634337625)],
        &[(0b10010, &ENTRY_CATECHIZABLES_16080446590160289539)],
        &[(0b10010, &ENTRY_CATECHIZABLEST_15304433722914372605)],
        &[(0b10010, &ENTRY_CATECHIZATION_10980745592282334992)],
        &[(0b10010, &ENTRY_CATECHIZATIONS_1066006272641891178)],
        &[(0b10010, &ENTRY_CATECHIZE_5115052394209545163)],
        &[(0b10010, &ENTRY_CATECHIZED_12525365667138826112)],
        &[(0b10010, &ENTRY_CATECHIZER_7607670417085575365)],
        &[(0b10010, &ENTRY_CATECHIZERS_7954123406223722552)],
        &[(0b10010, &ENTRY_CATECHIZES_15782633201911980832)],
        &[(0b10010, &ENTRY_CATECHIZING_3256072816982004976)],
        &[(0b10010, &ENTRY_CATECHIZINGS_8339955228064173770)],
        &[(0b01001, &ENTRY_CATECHIZABLE_8148927032591971850)],
        &[(0b01001, &ENTRY_CATECHIZABLER_16489482911634337625)],
        &[(0b01001, &ENTRY_CATECHIZABLES_16080446590160289539)],
        &[(0b01001, &ENTRY_CATECHIZABLEST_15304433722914372605)],
        &[(0b01001, &ENTRY_CATECHIZATION_10980745592282334992)],
        &[(0b01001, &ENTRY_CATECHIZATIONS_1066006272641891178)],
        &[(0b01001, &ENTRY_CATECHIZE_5115052394209545163)],
        &[(0b01001, &ENTRY_CATECHIZED_12525365667138826112)],
        &[(0b01001, &ENTRY_CATECHIZER_7607670417085575365)],
        &[(0b01001, &ENTRY_CATECHIZERS_7954123406223722552)],
        &[(0b01001, &ENTRY_CATECHIZES_15782633201911980832)],
        &[(0b01001, &ENTRY_CATECHIZING_3256072816982004976)],
        &[(0b01001, &ENTRY_CATECHIZINGS_8339955228064173770)],
        &[(0b10010, &ENTRY_CATEGORIZATION_18434363169100289749)],
        &[(0b10010, &ENTRY_CATEGORIZATIONS_16946076754480761936)],
        &[(0b10010, &ENTRY_CATEGORIZE_8200356101421109194)],
        &[(0b10010, &ENTRY_CATEGORIZED_3860898201662042852)],
        &[(0b10010, &ENTRY_CATEGORIZER_9728655756054218872)],
        &[(0b10010, &ENTRY_CATEGORIZERS_15733945145429406975)],
        &[(0b10010, &ENTRY_CATEGORIZES_5429500333056172375)],
        &[(0b10010, &ENTRY_CATEGORIZING_3255461076933906932)],
        &[(0b01001, &ENTRY_CATEGORIZATION_18434363169100289749)],
        &[(0b01001, &ENTRY_CATEGORIZATIONS_16946076754480761936)],
        &[(0b01001, &ENTRY_CATEGORIZE_8200356101421109194)],
        &[(0b01001, &ENTRY_CATEGORIZED_3860898201662042852)],
        &[(0b01001, &ENTRY_CATEGORIZER_9728655756054218872)],
        &[(0b01001, &ENTRY_CATEGORIZERS_15733945145429406975)],
        &[(0b01001, &ENTRY_CATEGORIZES_5429500333056172375)],
        &[(0b01001, &ENTRY_CATEGORIZING_3255461076933906932)],
    ],
    range: 5..=11,
};

static VARS_CATA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CATA_CHILDREN),
    value: None,
};

pub static VARS_CATA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bolise"),
        dictgen::InsensitiveStr::Ascii("bolize"),
        dictgen::InsensitiveStr::Ascii("log"),
        dictgen::InsensitiveStr::Ascii("loged"),
        dictgen::InsensitiveStr::Ascii("loger"),
        dictgen::InsensitiveStr::Ascii("logers"),
        dictgen::InsensitiveStr::Ascii("loging"),
        dictgen::InsensitiveStr::Ascii("logs"),
        dictgen::InsensitiveStr::Ascii("loguer"),
        dictgen::InsensitiveStr::Ascii("loguers"),
        dictgen::InsensitiveStr::Ascii("loguise"),
        dictgen::InsensitiveStr::Ascii("loguised"),
        dictgen::InsensitiveStr::Ascii("loguises"),
        dictgen::InsensitiveStr::Ascii("loguising"),
        dictgen::InsensitiveStr::Ascii("loguize"),
        dictgen::InsensitiveStr::Ascii("loguized"),
        dictgen::InsensitiveStr::Ascii("loguizes"),
        dictgen::InsensitiveStr::Ascii("loguizing"),
        dictgen::InsensitiveStr::Ascii("lyse"),
        dictgen::InsensitiveStr::Ascii("lysed"),
        dictgen::InsensitiveStr::Ascii("lyser"),
        dictgen::InsensitiveStr::Ascii("lysers"),
        dictgen::InsensitiveStr::Ascii("lysing"),
        dictgen::InsensitiveStr::Ascii("lyze"),
        dictgen::InsensitiveStr::Ascii("lyzed"),
        dictgen::InsensitiveStr::Ascii("lyzer"),
        dictgen::InsensitiveStr::Ascii("lyzers"),
        dictgen::InsensitiveStr::Ascii("lyzes"),
        dictgen::InsensitiveStr::Ascii("lyzing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CATABOLIZE_11816197913174352635)],
        &[(0b01001, &ENTRY_CATABOLIZE_11816197913174352635)],
        &[(0b00001, &ENTRY_CATALOG_565730177416789533)],
        &[(0b00001, &ENTRY_CATALOGED_13847517650261824048)],
        &[(0b00001, &ENTRY_CATALOGER_17511688898877974998)],
        &[(0b00001, &ENTRY_CATALOGERS_4685828953878934730)],
        &[(0b00001, &ENTRY_CATALOGING_9488455222365923997)],
        &[(0b00001, &ENTRY_CATALOGS_5196696314182792455)],
        &[(0b11010, &ENTRY_CATALOGER_17511688898877974998)],
        &[(0b11010, &ENTRY_CATALOGERS_4685828953878934730)],
        &[(0b10010, &ENTRY_CATALOGUIZE_14984251796182303314)],
        &[(0b10010, &ENTRY_CATALOGUIZED_8601558565793987799)],
        &[(0b10010, &ENTRY_CATALOGUIZES_3670496253316543674)],
        &[(0b10010, &ENTRY_CATALOGUIZING_6606816050812238917)],
        &[(0b01001, &ENTRY_CATALOGUIZE_14984251796182303314)],
        &[(0b01001, &ENTRY_CATALOGUIZED_8601558565793987799)],
        &[(0b01001, &ENTRY_CATALOGUIZES_3670496253316543674)],
        &[(0b01001, &ENTRY_CATALOGUIZING_6606816050812238917)],
        &[(0b11010, &ENTRY_CATALYZE_5340148730721059753)],
        &[(0b11010, &ENTRY_CATALYZED_18179839917863952435)],
        &[(0b11010, &ENTRY_CATALYZER_11797586490562423657)],
        &[(0b11010, &ENTRY_CATALYZERS_7508097445503599240)],
        &[(0b11010, &ENTRY_CATALYZING_13540847378063734907)],
        &[(0b01001, &ENTRY_CATALYZE_5340148730721059753)],
        &[(0b01001, &ENTRY_CATALYZED_18179839917863952435)],
        &[(0b00001, &ENTRY_CATALYZER_11797586490562423657)],
        &[(0b00001, &ENTRY_CATALYZERS_7508097445503599240)],
        &[(0b01001, &ENTRY_CATALYZES_11042547222296624347)],
        &[(0b01001, &ENTRY_CATALYZING_13540847378063734907)],
    ],
    range: 3..=9,
};

static VARS_CAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAS_CHILDREN),
    value: None,
};

pub static VARS_CAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("torised"),
        dictgen::InsensitiveStr::Ascii("toriseds"),
        dictgen::InsensitiveStr::Ascii("torized"),
        dictgen::InsensitiveStr::Ascii("torizeds"),
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CASTORIZED_10151818395862381641)],
        &[(0b10010, &ENTRY_CASTORIZEDS_6148490693168594327)],
        &[(0b01001, &ENTRY_CASTORIZED_10151818395862381641)],
        &[(0b01001, &ENTRY_CASTORIZEDS_6148490693168594327)],
        &[(0b10010, &ENTRY_CASUALIZATION_17265270261689405024)],
        &[(0b10010, &ENTRY_CASUALIZATIONS_1177089607693079865)],
        &[(0b10010, &ENTRY_CASUALIZE_17972861847589378190)],
        &[(0b10010, &ENTRY_CASUALIZED_4864891523978676413)],
        &[(0b10010, &ENTRY_CASUALIZES_4478609648430497928)],
        &[(0b10010, &ENTRY_CASUALIZING_16059580509092791196)],
        &[(0b01001, &ENTRY_CASUALIZATION_17265270261689405024)],
        &[(0b01001, &ENTRY_CASUALIZATIONS_1177089607693079865)],
        &[(0b01001, &ENTRY_CASUALIZE_17972861847589378190)],
        &[(0b01001, &ENTRY_CASUALIZED_4864891523978676413)],
        &[(0b01001, &ENTRY_CASUALIZES_4478609648430497928)],
        &[(0b01001, &ENTRY_CASUALIZING_16059580509092791196)],
    ],
    range: 6..=11,
};

static VARS_CAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CAR_CHILDREN),
    value: None,
};

static VARS_CAR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CARA_NODE),
    Some(&VARS_CARB_NODE),
    None,
    Some(&VARS_CARD_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CARN_NODE),
    Some(&VARS_CARO_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_CART_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CART_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CART_CHILDREN),
    value: None,
};

pub static VARS_CART_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elisation"),
        dictgen::InsensitiveStr::Ascii("elisations"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elising"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elizations"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("elizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CARTELIZATION_16312929833092298961)],
        &[(0b10010, &ENTRY_CARTELIZATIONS_9619770345243460310)],
        &[(0b10010, &ENTRY_CARTELIZE_2833428251960695439)],
        &[(0b10010, &ENTRY_CARTELIZED_12213627611344387963)],
        &[(0b10010, &ENTRY_CARTELIZES_7591657395331891195)],
        &[(0b10010, &ENTRY_CARTELIZING_11143164166226551666)],
        &[(0b01001, &ENTRY_CARTELIZATION_16312929833092298961)],
        &[(0b01001, &ENTRY_CARTELIZATIONS_9619770345243460310)],
        &[(0b01001, &ENTRY_CARTELIZE_2833428251960695439)],
        &[(0b01001, &ENTRY_CARTELIZED_12213627611344387963)],
        &[(0b01001, &ENTRY_CARTELIZES_7591657395331891195)],
        &[(0b01001, &ENTRY_CARTELIZING_11143164166226551666)],
    ],
    range: 5..=10,
};

static VARS_CARO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CARO_CHILDREN),
    value: None,
};

pub static VARS_CARO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("ller"),
        dictgen::InsensitiveStr::Ascii("llers"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("tinaemia"),
        dictgen::InsensitiveStr::Ascii("tinemia"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CAROLED_4418735863611872467)],
        &[(0b00001, &ENTRY_CAROLER_4713116399310207395)],
        &[(0b00001, &ENTRY_CAROLERS_5398425405494964276)],
        &[(0b00001, &ENTRY_CAROLING_6802531412817349154)],
        &[(0b11010, &ENTRY_CAROLED_4418735863611872467)],
        &[(0b11010, &ENTRY_CAROLER_4713116399310207395)],
        &[(0b11010, &ENTRY_CAROLERS_5398425405494964276)],
        &[(0b11010, &ENTRY_CAROLING_6802531412817349154)],
        &[(0b11010, &ENTRY_CAROTINEMIA_3890327621498954431)],
        &[(0b10001, &ENTRY_CAROTINEMIA_3890327621498954431)],
    ],
    range: 3..=8,
};

static VARS_CARN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CARN_CHILDREN),
    value: None,
};

pub static VARS_CARN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CARNALIZE_888189908487025980)],
        &[(0b10010, &ENTRY_CARNALIZED_12290977097104986519)],
        &[(0b10010, &ENTRY_CARNALIZES_10340856607662046936)],
        &[(0b10010, &ENTRY_CARNALIZING_11439495256258951221)],
        &[(0b01001, &ENTRY_CARNALIZE_888189908487025980)],
        &[(0b01001, &ENTRY_CARNALIZED_12290977097104986519)],
        &[(0b01001, &ENTRY_CARNALIZES_10340856607662046936)],
        &[(0b01001, &ENTRY_CARNALIZING_11439495256258951221)],
    ],
    range: 5..=7,
};

static VARS_CARD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CARD_CHILDREN),
    value: None,
};

pub static VARS_CARD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iae"),
        dictgen::InsensitiveStr::Ascii("ie"),
        dictgen::InsensitiveStr::Ascii("uelinae"),
        dictgen::InsensitiveStr::Ascii("ueline"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CARDIE_5254053559491595290)],
        &[(0b00001, &ENTRY_CARDIE_5254053559491595290)],
        &[(0b11010, &ENTRY_CARDUELINE_12160806795445300820)],
        &[(0b00001, &ENTRY_CARDUELINE_12160806795445300820)],
    ],
    range: 2..=7,
};

static VARS_CARB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CARB_CHILDREN),
    value: None,
};

pub static VARS_CARB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olisation"),
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olization"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
        dictgen::InsensitiveStr::Ascii("onades"),
        dictgen::InsensitiveStr::Ascii("onadoes"),
        dictgen::InsensitiveStr::Ascii("onatisation"),
        dictgen::InsensitiveStr::Ascii("onatisations"),
        dictgen::InsensitiveStr::Ascii("onatization"),
        dictgen::InsensitiveStr::Ascii("onatizations"),
        dictgen::InsensitiveStr::Ascii("onisable"),
        dictgen::InsensitiveStr::Ascii("onisabler"),
        dictgen::InsensitiveStr::Ascii("onisables"),
        dictgen::InsensitiveStr::Ascii("onisablest"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniser"),
        dictgen::InsensitiveStr::Ascii("onisers"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onizable"),
        dictgen::InsensitiveStr::Ascii("onizabler"),
        dictgen::InsensitiveStr::Ascii("onizables"),
        dictgen::InsensitiveStr::Ascii("onizablest"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizer"),
        dictgen::InsensitiveStr::Ascii("onizers"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("uretor"),
        dictgen::InsensitiveStr::Ascii("uretors"),
        dictgen::InsensitiveStr::Ascii("uretter"),
        dictgen::InsensitiveStr::Ascii("uretters"),
        dictgen::InsensitiveStr::Ascii("urettor"),
        dictgen::InsensitiveStr::Ascii("urettors"),
        dictgen::InsensitiveStr::Ascii("urisation"),
        dictgen::InsensitiveStr::Ascii("urisations"),
        dictgen::InsensitiveStr::Ascii("urise"),
        dictgen::InsensitiveStr::Ascii("urised"),
        dictgen::InsensitiveStr::Ascii("uriser"),
        dictgen::InsensitiveStr::Ascii("urises"),
        dictgen::InsensitiveStr::Ascii("urising"),
        dictgen::InsensitiveStr::Ascii("urization"),
        dictgen::InsensitiveStr::Ascii("urizations"),
        dictgen::InsensitiveStr::Ascii("urize"),
        dictgen::InsensitiveStr::Ascii("urized"),
        dictgen::InsensitiveStr::Ascii("urizer"),
        dictgen::InsensitiveStr::Ascii("urizes"),
        dictgen::InsensitiveStr::Ascii("urizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CARBOLIZATION_1668321139010867766)],
        &[(0b10010, &ENTRY_CARBOLIZE_18199301992433580177)],
        &[(0b10010, &ENTRY_CARBOLIZED_1304647434125401295)],
        &[(0b10010, &ENTRY_CARBOLIZES_18256554089605613959)],
        &[(0b10010, &ENTRY_CARBOLIZING_15468275393703968978)],
        &[(0b01001, &ENTRY_CARBOLIZATION_1668321139010867766)],
        &[(0b01001, &ENTRY_CARBOLIZE_18199301992433580177)],
        &[(0b01001, &ENTRY_CARBOLIZED_1304647434125401295)],
        &[(0b01001, &ENTRY_CARBOLIZES_18256554089605613959)],
        &[(0b01001, &ENTRY_CARBOLIZING_15468275393703968978)],
        &[(0b00001, &ENTRY_CARBONADES_2718956912399980360)],
        &[(0b11010, &ENTRY_CARBONADES_2718956912399980360)],
        &[(0b10010, &ENTRY_CARBONATIZATION_8679961555762969779)],
        &[(0b10010, &ENTRY_CARBONATIZATIONS_16224281628260636804)],
        &[(0b01001, &ENTRY_CARBONATIZATION_8679961555762969779)],
        &[(0b01001, &ENTRY_CARBONATIZATIONS_16224281628260636804)],
        &[(0b10010, &ENTRY_CARBONIZABLE_9770507971838358591)],
        &[(0b10010, &ENTRY_CARBONIZABLER_5983353872794548574)],
        &[(0b10010, &ENTRY_CARBONIZABLES_15010240797533617511)],
        &[(0b10010, &ENTRY_CARBONIZABLEST_8906777685042270793)],
        &[(0b10010, &ENTRY_CARBONIZATION_16165847968956959109)],
        &[(0b10010, &ENTRY_CARBONIZATIONS_13100027598773896835)],
        &[(0b10010, &ENTRY_CARBONIZE_1296979562221113559)],
        &[(0b10010, &ENTRY_CARBONIZED_14007117269969730084)],
        &[(0b10010, &ENTRY_CARBONIZER_13548993741300401082)],
        &[(0b10010, &ENTRY_CARBONIZERS_6321314892804174768)],
        &[(0b10010, &ENTRY_CARBONIZES_4601016301417314989)],
        &[(0b10010, &ENTRY_CARBONIZING_9584599099267202250)],
        &[(0b01001, &ENTRY_CARBONIZABLE_9770507971838358591)],
        &[(0b01001, &ENTRY_CARBONIZABLER_5983353872794548574)],
        &[(0b01001, &ENTRY_CARBONIZABLES_15010240797533617511)],
        &[(0b01001, &ENTRY_CARBONIZABLEST_8906777685042270793)],
        &[(0b01001, &ENTRY_CARBONIZATION_16165847968956959109)],
        &[(0b01001, &ENTRY_CARBONIZATIONS_13100027598773896835)],
        &[(0b01001, &ENTRY_CARBONIZE_1296979562221113559)],
        &[(0b01001, &ENTRY_CARBONIZED_14007117269969730084)],
        &[(0b01001, &ENTRY_CARBONIZER_13548993741300401082)],
        &[(0b01001, &ENTRY_CARBONIZERS_6321314892804174768)],
        &[(0b01001, &ENTRY_CARBONIZES_4601016301417314989)],
        &[(0b01001, &ENTRY_CARBONIZING_9584599099267202250)],
        &[(0b00001, &ENTRY_CARBURETOR_796458217902184728)],
        &[(0b00001, &ENTRY_CARBURETORS_17976622243676266477)],
        &[(0b11010, &ENTRY_CARBURETOR_796458217902184728)],
        &[(0b11010, &ENTRY_CARBURETORS_17976622243676266477)],
        &[(0b11010, &ENTRY_CARBURETOR_796458217902184728)],
        &[(0b11010, &ENTRY_CARBURETORS_17976622243676266477)],
        &[(0b10010, &ENTRY_CARBURIZATION_3111751723008963789)],
        &[(0b10010, &ENTRY_CARBURIZATIONS_9387786085754507277)],
        &[(0b10010, &ENTRY_CARBURIZE_3007037993552406791)],
        &[(0b10010, &ENTRY_CARBURIZED_11327808482383627961)],
        &[(0b10010, &ENTRY_CARBURIZER_1208889746894515605)],
        &[(0b10010, &ENTRY_CARBURIZES_1569393480555670518)],
        &[(0b10010, &ENTRY_CARBURIZING_2531220195880162003)],
        &[(0b01001, &ENTRY_CARBURIZATION_3111751723008963789)],
        &[(0b01001, &ENTRY_CARBURIZATIONS_9387786085754507277)],
        &[(0b01001, &ENTRY_CARBURIZE_3007037993552406791)],
        &[(0b01001, &ENTRY_CARBURIZED_11327808482383627961)],
        &[(0b01001, &ENTRY_CARBURIZER_1208889746894515605)],
        &[(0b01001, &ENTRY_CARBURIZES_1569393480555670518)],
        &[(0b01001, &ENTRY_CARBURIZING_2531220195880162003)],
    ],
    range: 5..=12,
};

static VARS_CARA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CARA_CHILDREN),
    value: None,
};

pub static VARS_CARA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("coled"),
        dictgen::InsensitiveStr::Ascii("coling"),
        dictgen::InsensitiveStr::Ascii("colled"),
        dictgen::InsensitiveStr::Ascii("colling"),
        dictgen::InsensitiveStr::Ascii("melisation"),
        dictgen::InsensitiveStr::Ascii("melisations"),
        dictgen::InsensitiveStr::Ascii("melise"),
        dictgen::InsensitiveStr::Ascii("melised"),
        dictgen::InsensitiveStr::Ascii("melises"),
        dictgen::InsensitiveStr::Ascii("melising"),
        dictgen::InsensitiveStr::Ascii("melization"),
        dictgen::InsensitiveStr::Ascii("melizations"),
        dictgen::InsensitiveStr::Ascii("melize"),
        dictgen::InsensitiveStr::Ascii("melized"),
        dictgen::InsensitiveStr::Ascii("melizes"),
        dictgen::InsensitiveStr::Ascii("melizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CARACOLED_17261812764511727457)],
        &[(0b00001, &ENTRY_CARACOLING_3661744636660380050)],
        &[(0b11010, &ENTRY_CARACOLED_17261812764511727457)],
        &[(0b11010, &ENTRY_CARACOLING_3661744636660380050)],
        &[(0b10010, &ENTRY_CARAMELIZATION_12515762504964341677)],
        &[(0b10010, &ENTRY_CARAMELIZATIONS_2385837672145447407)],
        &[(0b10010, &ENTRY_CARAMELIZE_1110104959262710985)],
        &[(0b10010, &ENTRY_CARAMELIZED_7793381247604239400)],
        &[(0b10010, &ENTRY_CARAMELIZES_6059982956966755570)],
        &[(0b10010, &ENTRY_CARAMELIZING_2936515763713237491)],
        &[(0b01001, &ENTRY_CARAMELIZATION_12515762504964341677)],
        &[(0b01001, &ENTRY_CARAMELIZATIONS_2385837672145447407)],
        &[(0b01001, &ENTRY_CARAMELIZE_1110104959262710985)],
        &[(0b01001, &ENTRY_CARAMELIZED_7793381247604239400)],
        &[(0b01001, &ENTRY_CARAMELIZES_6059982956966755570)],
        &[(0b01001, &ENTRY_CARAMELIZING_2936515763713237491)],
    ],
    range: 5..=11,
};

static VARS_CAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAP_CHILDREN),
    value: None,
};

pub static VARS_CAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("italisable"),
        dictgen::InsensitiveStr::Ascii("italisabler"),
        dictgen::InsensitiveStr::Ascii("italisables"),
        dictgen::InsensitiveStr::Ascii("italisablest"),
        dictgen::InsensitiveStr::Ascii("italisation"),
        dictgen::InsensitiveStr::Ascii("italisations"),
        dictgen::InsensitiveStr::Ascii("italise"),
        dictgen::InsensitiveStr::Ascii("italised"),
        dictgen::InsensitiveStr::Ascii("italiser"),
        dictgen::InsensitiveStr::Ascii("italisers"),
        dictgen::InsensitiveStr::Ascii("italises"),
        dictgen::InsensitiveStr::Ascii("italising"),
        dictgen::InsensitiveStr::Ascii("italizable"),
        dictgen::InsensitiveStr::Ascii("italizabler"),
        dictgen::InsensitiveStr::Ascii("italizables"),
        dictgen::InsensitiveStr::Ascii("italizablest"),
        dictgen::InsensitiveStr::Ascii("italization"),
        dictgen::InsensitiveStr::Ascii("italizations"),
        dictgen::InsensitiveStr::Ascii("italize"),
        dictgen::InsensitiveStr::Ascii("italized"),
        dictgen::InsensitiveStr::Ascii("italizer"),
        dictgen::InsensitiveStr::Ascii("italizers"),
        dictgen::InsensitiveStr::Ascii("italizes"),
        dictgen::InsensitiveStr::Ascii("italizing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniser"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizer"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("sulisation"),
        dictgen::InsensitiveStr::Ascii("sulise"),
        dictgen::InsensitiveStr::Ascii("sulised"),
        dictgen::InsensitiveStr::Ascii("sulises"),
        dictgen::InsensitiveStr::Ascii("sulising"),
        dictgen::InsensitiveStr::Ascii("sulization"),
        dictgen::InsensitiveStr::Ascii("sulize"),
        dictgen::InsensitiveStr::Ascii("sulized"),
        dictgen::InsensitiveStr::Ascii("sulizes"),
        dictgen::InsensitiveStr::Ascii("sulizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CAPITALIZABLE_2549388273733202801)],
        &[(0b10010, &ENTRY_CAPITALIZABLER_603529729414520201)],
        &[(0b10010, &ENTRY_CAPITALIZABLES_6813737836463367704)],
        &[(0b10010, &ENTRY_CAPITALIZABLEST_2355759451940673988)],
        &[(0b10010, &ENTRY_CAPITALIZATION_701575089089546433)],
        &[(0b10010, &ENTRY_CAPITALIZATIONS_12418153595184643992)],
        &[(0b10010, &ENTRY_CAPITALIZE_14987270073189981607)],
        &[(0b10010, &ENTRY_CAPITALIZED_16586381829524591032)],
        &[(0b10010, &ENTRY_CAPITALIZER_17721887205362296803)],
        &[(0b10010, &ENTRY_CAPITALIZERS_13568479603381288355)],
        &[(0b10010, &ENTRY_CAPITALIZES_8346787254057235765)],
        &[(0b10010, &ENTRY_CAPITALIZING_12592559899378813681)],
        &[(0b01001, &ENTRY_CAPITALIZABLE_2549388273733202801)],
        &[(0b01001, &ENTRY_CAPITALIZABLER_603529729414520201)],
        &[(0b01001, &ENTRY_CAPITALIZABLES_6813737836463367704)],
        &[(0b01001, &ENTRY_CAPITALIZABLEST_2355759451940673988)],
        &[(0b01001, &ENTRY_CAPITALIZATION_701575089089546433)],
        &[(0b01001, &ENTRY_CAPITALIZATIONS_12418153595184643992)],
        &[(0b01001, &ENTRY_CAPITALIZE_14987270073189981607)],
        &[(0b01001, &ENTRY_CAPITALIZED_16586381829524591032)],
        &[(0b01001, &ENTRY_CAPITALIZER_17721887205362296803)],
        &[(0b01001, &ENTRY_CAPITALIZERS_13568479603381288355)],
        &[(0b01001, &ENTRY_CAPITALIZES_8346787254057235765)],
        &[(0b01001, &ENTRY_CAPITALIZING_12592559899378813681)],
        &[(0b10010, &ENTRY_CAPONIZATION_16648254879201289773)],
        &[(0b10010, &ENTRY_CAPONIZE_7723124127427821667)],
        &[(0b10010, &ENTRY_CAPONIZED_3599983764436663496)],
        &[(0b10010, &ENTRY_CAPONIZER_2937515815991396532)],
        &[(0b10010, &ENTRY_CAPONIZES_8112348068369020206)],
        &[(0b10010, &ENTRY_CAPONIZING_4731137034979888377)],
        &[(0b01001, &ENTRY_CAPONIZATION_16648254879201289773)],
        &[(0b01001, &ENTRY_CAPONIZE_7723124127427821667)],
        &[(0b01001, &ENTRY_CAPONIZED_3599983764436663496)],
        &[(0b01001, &ENTRY_CAPONIZER_2937515815991396532)],
        &[(0b01001, &ENTRY_CAPONIZES_8112348068369020206)],
        &[(0b01001, &ENTRY_CAPONIZING_4731137034979888377)],
        &[(0b10010, &ENTRY_CAPSULIZATION_12994547982797650921)],
        &[(0b10010, &ENTRY_CAPSULIZE_8925469580586567241)],
        &[(0b10010, &ENTRY_CAPSULIZED_15163714329989053697)],
        &[(0b10010, &ENTRY_CAPSULIZES_6046785573783515511)],
        &[(0b10010, &ENTRY_CAPSULIZING_14108763304053705443)],
        &[(0b01001, &ENTRY_CAPSULIZATION_12994547982797650921)],
        &[(0b01001, &ENTRY_CAPSULIZE_8925469580586567241)],
        &[(0b01001, &ENTRY_CAPSULIZED_15163714329989053697)],
        &[(0b01001, &ENTRY_CAPSULIZES_6046785573783515511)],
        &[(0b01001, &ENTRY_CAPSULIZING_14108763304053705443)],
    ],
    range: 5..=12,
};

static VARS_CAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CAN_CHILDREN),
    value: None,
};

static VARS_CAN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CANA_NODE),
    None,
    Some(&VARS_CANC_NODE),
    Some(&VARS_CAND_NODE),
    Some(&VARS_CANE_NODE),
    None,
    None,
    None,
    Some(&VARS_CANI_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_CANN_NODE),
    Some(&VARS_CANO_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_CANT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CANT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANT_CHILDREN),
    value: None,
};

pub static VARS_CANT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aloup"),
        dictgen::InsensitiveStr::Ascii("aloups"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_CANTALOUPE_16173297872474332016)],
        &[(0b01001, &ENTRY_CANTALOUPES_964160501109699483)],
        &[(0b10010, &ENTRY_CANTONIZATION_10099357276016788559)],
        &[(0b10010, &ENTRY_CANTONIZATIONS_11360567398468706238)],
        &[(0b10010, &ENTRY_CANTONIZE_12488382334775453573)],
        &[(0b10010, &ENTRY_CANTONIZED_14617271008182532990)],
        &[(0b10010, &ENTRY_CANTONIZES_16402920802638687919)],
        &[(0b10010, &ENTRY_CANTONIZING_9432387339924117920)],
        &[(0b01001, &ENTRY_CANTONIZATION_10099357276016788559)],
        &[(0b01001, &ENTRY_CANTONIZATIONS_11360567398468706238)],
        &[(0b01001, &ENTRY_CANTONIZE_12488382334775453573)],
        &[(0b01001, &ENTRY_CANTONIZED_14617271008182532990)],
        &[(0b01001, &ENTRY_CANTONIZES_16402920802638687919)],
        &[(0b01001, &ENTRY_CANTONIZING_9432387339924117920)],
    ],
    range: 5..=10,
};

static VARS_CANO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANO_CHILDREN),
    value: None,
};

pub static VARS_CANO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nicalisation"),
        dictgen::InsensitiveStr::Ascii("nicalise"),
        dictgen::InsensitiveStr::Ascii("nicalised"),
        dictgen::InsensitiveStr::Ascii("nicalises"),
        dictgen::InsensitiveStr::Ascii("nicalising"),
        dictgen::InsensitiveStr::Ascii("nicalization"),
        dictgen::InsensitiveStr::Ascii("nicalize"),
        dictgen::InsensitiveStr::Ascii("nicalized"),
        dictgen::InsensitiveStr::Ascii("nicalizes"),
        dictgen::InsensitiveStr::Ascii("nicalizing"),
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CANONICALIZATION_9680284371048473324)],
        &[(0b10010, &ENTRY_CANONICALIZE_1859043615515179894)],
        &[(0b10010, &ENTRY_CANONICALIZED_10333001095762961835)],
        &[(0b10010, &ENTRY_CANONICALIZES_18024856614090090716)],
        &[(0b10010, &ENTRY_CANONICALIZING_284685826070047061)],
        &[(0b01001, &ENTRY_CANONICALIZATION_9680284371048473324)],
        &[(0b01001, &ENTRY_CANONICALIZE_1859043615515179894)],
        &[(0b01001, &ENTRY_CANONICALIZED_10333001095762961835)],
        &[(0b01001, &ENTRY_CANONICALIZES_18024856614090090716)],
        &[(0b01001, &ENTRY_CANONICALIZING_284685826070047061)],
        &[(0b10010, &ENTRY_CANONIZATION_2650997251769306758)],
        &[(0b10010, &ENTRY_CANONIZATIONS_1884767107904362564)],
        &[(0b10010, &ENTRY_CANONIZE_3694127234765675696)],
        &[(0b10010, &ENTRY_CANONIZED_15761367761494193573)],
        &[(0b10010, &ENTRY_CANONIZER_9593339360985297224)],
        &[(0b10010, &ENTRY_CANONIZERS_9782656344877819576)],
        &[(0b10010, &ENTRY_CANONIZES_9784118345073131908)],
        &[(0b10010, &ENTRY_CANONIZING_2446378015323590313)],
        &[(0b01001, &ENTRY_CANONIZATION_2650997251769306758)],
        &[(0b01001, &ENTRY_CANONIZATIONS_1884767107904362564)],
        &[(0b01001, &ENTRY_CANONIZE_3694127234765675696)],
        &[(0b01001, &ENTRY_CANONIZED_15761367761494193573)],
        &[(0b01001, &ENTRY_CANONIZER_9593339360985297224)],
        &[(0b01001, &ENTRY_CANONIZERS_9782656344877819576)],
        &[(0b01001, &ENTRY_CANONIZES_9784118345073131908)],
        &[(0b01001, &ENTRY_CANONIZING_2446378015323590313)],
    ],
    range: 4..=12,
};

static VARS_CANN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANN_CHILDREN),
    value: None,
};

pub static VARS_CANN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ibalisation"),
        dictgen::InsensitiveStr::Ascii("ibalisations"),
        dictgen::InsensitiveStr::Ascii("ibalise"),
        dictgen::InsensitiveStr::Ascii("ibalised"),
        dictgen::InsensitiveStr::Ascii("ibalises"),
        dictgen::InsensitiveStr::Ascii("ibalising"),
        dictgen::InsensitiveStr::Ascii("ibalization"),
        dictgen::InsensitiveStr::Ascii("ibalizations"),
        dictgen::InsensitiveStr::Ascii("ibalize"),
        dictgen::InsensitiveStr::Ascii("ibalized"),
        dictgen::InsensitiveStr::Ascii("ibalizes"),
        dictgen::InsensitiveStr::Ascii("ibalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CANNIBALIZATION_10362383723962441168)],
        &[(0b10010, &ENTRY_CANNIBALIZATIONS_8053294690714421066)],
        &[(0b10010, &ENTRY_CANNIBALIZE_12913259420777918440)],
        &[(0b10010, &ENTRY_CANNIBALIZED_13179636865120338437)],
        &[(0b10010, &ENTRY_CANNIBALIZES_5843119974222450091)],
        &[(0b10010, &ENTRY_CANNIBALIZING_16266472115659513272)],
        &[(0b01001, &ENTRY_CANNIBALIZATION_10362383723962441168)],
        &[(0b01001, &ENTRY_CANNIBALIZATIONS_8053294690714421066)],
        &[(0b01001, &ENTRY_CANNIBALIZE_12913259420777918440)],
        &[(0b01001, &ENTRY_CANNIBALIZED_13179636865120338437)],
        &[(0b01001, &ENTRY_CANNIBALIZES_5843119974222450091)],
        &[(0b01001, &ENTRY_CANNIBALIZING_16266472115659513272)],
    ],
    range: 7..=12,
};

static VARS_CANI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANI_CHILDREN),
    value: None,
};

pub static VARS_CANI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sterisation"),
        dictgen::InsensitiveStr::Ascii("sterisations"),
        dictgen::InsensitiveStr::Ascii("sterise"),
        dictgen::InsensitiveStr::Ascii("sterised"),
        dictgen::InsensitiveStr::Ascii("sterises"),
        dictgen::InsensitiveStr::Ascii("sterising"),
        dictgen::InsensitiveStr::Ascii("sterization"),
        dictgen::InsensitiveStr::Ascii("sterizations"),
        dictgen::InsensitiveStr::Ascii("sterize"),
        dictgen::InsensitiveStr::Ascii("sterized"),
        dictgen::InsensitiveStr::Ascii("sterizes"),
        dictgen::InsensitiveStr::Ascii("sterizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CANISTERIZATION_880939025211064061)],
        &[(0b10010, &ENTRY_CANISTERIZATIONS_8729750327946936371)],
        &[(0b10010, &ENTRY_CANISTERIZE_1796105525730141958)],
        &[(0b10010, &ENTRY_CANISTERIZED_12280345176842641097)],
        &[(0b10010, &ENTRY_CANISTERIZES_10797600836947335811)],
        &[(0b10010, &ENTRY_CANISTERIZING_4750329974636684269)],
        &[(0b01001, &ENTRY_CANISTERIZATION_880939025211064061)],
        &[(0b01001, &ENTRY_CANISTERIZATIONS_8729750327946936371)],
        &[(0b01001, &ENTRY_CANISTERIZE_1796105525730141958)],
        &[(0b01001, &ENTRY_CANISTERIZED_12280345176842641097)],
        &[(0b01001, &ENTRY_CANISTERIZES_10797600836947335811)],
        &[(0b01001, &ENTRY_CANISTERIZING_4750329974636684269)],
    ],
    range: 7..=12,
};

static VARS_CANE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANE_CHILDREN),
    value: None,
};

pub static VARS_CANE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("phorae"),
        dictgen::InsensitiveStr::Ascii("phore"),
        dictgen::InsensitiveStr::Ascii("phoroe"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CANEPHORE_18005220336274276713)],
        &[
            (0b00001, &ENTRY_CANEPHORE_18005220336274276713),
            (0b00001, &ENTRY_CANEPHORE_2517412738369461952),
        ],
        &[(0b11010, &ENTRY_CANEPHORE_2517412738369461952)],
    ],
    range: 5..=6,
};

static VARS_CAND_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAND_CHILDREN),
    value: None,
};

pub static VARS_CAND_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_CANDOR_10788361890221941916)],
        &[(0b11001, &ENTRY_CANDORS_11609560572454050104)],
        &[(0b11010, &ENTRY_CANDOR_10788361890221941916)],
        &[(0b11010, &ENTRY_CANDORS_11609560572454050104)],
    ],
    range: 2..=4,
};

static VARS_CANC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANC_CHILDREN),
    value: None,
};

pub static VARS_CANC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elable"),
        dictgen::InsensitiveStr::Ascii("elate"),
        dictgen::InsensitiveStr::Ascii("elated"),
        dictgen::InsensitiveStr::Ascii("elation"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("ellous"),
        dictgen::InsensitiveStr::Ascii("elous"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CANCELABLE_3722417889172603824)],
        &[(0b00001, &ENTRY_CANCELATE_13935007740694861299)],
        &[(0b00001, &ENTRY_CANCELATED_10962527112084997064)],
        &[(0b00001, &ENTRY_CANCELLATION_1555414462165920792)],
        &[(0b00001, &ENTRY_CANCELED_12672342492571604224)],
        &[(0b00001, &ENTRY_CANCELER_12983343936465600908)],
        &[(0b00001, &ENTRY_CANCELERS_3981532768174175193)],
        &[(0b00001, &ENTRY_CANCELING_16146260375495786001)],
        &[(0b11010, &ENTRY_CANCELER_12983343936465600908)],
        &[(0b11010, &ENTRY_CANCELERS_3981532768174175193)],
        &[(0b11010, &ENTRY_CANCELOUS_15814136391491262355)],
        &[(0b00001, &ENTRY_CANCELOUS_15814136391491262355)],
    ],
    range: 4..=7,
};

static VARS_CANA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANA_CHILDREN),
    value: None,
};

pub static VARS_CANA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dianisation"),
        dictgen::InsensitiveStr::Ascii("dianisations"),
        dictgen::InsensitiveStr::Ascii("dianise"),
        dictgen::InsensitiveStr::Ascii("dianises"),
        dictgen::InsensitiveStr::Ascii("dianization"),
        dictgen::InsensitiveStr::Ascii("dianizations"),
        dictgen::InsensitiveStr::Ascii("dianize"),
        dictgen::InsensitiveStr::Ascii("dianizes"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("ller"),
        dictgen::InsensitiveStr::Ascii("llers"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("naean"),
        dictgen::InsensitiveStr::Ascii("nean"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CANADIANIZATION_13182443901388656095)],
        &[(0b10010, &ENTRY_CANADIANIZATIONS_5629413944017512120)],
        &[(0b10010, &ENTRY_CANADIANIZE_14378401002580150005)],
        &[(0b10010, &ENTRY_CANADIANIZES_7814286041803724506)],
        &[(0b01001, &ENTRY_CANADIANIZATION_13182443901388656095)],
        &[(0b01001, &ENTRY_CANADIANIZATIONS_5629413944017512120)],
        &[(0b01001, &ENTRY_CANADIANIZE_14378401002580150005)],
        &[(0b01001, &ENTRY_CANADIANIZES_7814286041803724506)],
        &[(0b00001, &ENTRY_CANALED_17712164795851355663)],
        &[(0b00001, &ENTRY_CANALER_2156584751369726138)],
        &[(0b00001, &ENTRY_CANALERS_3633550320132459566)],
        &[(0b00001, &ENTRY_CANALING_14175464379981390017)],
        &[(0b10010, &ENTRY_CANALIZATION_13228363861342779584)],
        &[(0b10010, &ENTRY_CANALIZATIONS_13532066641589359430)],
        &[(0b10010, &ENTRY_CANALIZE_3951994517517182635)],
        &[(0b10010, &ENTRY_CANALIZED_8165057117631879852)],
        &[(0b10010, &ENTRY_CANALIZES_49113899823800782)],
        &[(0b10010, &ENTRY_CANALIZING_5717449398288828945)],
        &[(0b01001, &ENTRY_CANALIZATION_13228363861342779584)],
        &[(0b01001, &ENTRY_CANALIZATIONS_13532066641589359430)],
        &[(0b01001, &ENTRY_CANALIZE_3951994517517182635)],
        &[(0b01001, &ENTRY_CANALIZED_8165057117631879852)],
        &[(0b01001, &ENTRY_CANALIZES_49113899823800782)],
        &[(0b01001, &ENTRY_CANALIZING_5717449398288828945)],
        &[(0b11010, &ENTRY_CANALED_17712164795851355663)],
        &[(0b11010, &ENTRY_CANALER_2156584751369726138)],
        &[(0b11010, &ENTRY_CANALERS_3633550320132459566)],
        &[(0b11010, &ENTRY_CANALING_14175464379981390017)],
        &[(0b11010, &ENTRY_CANANEAN_15332949567639306041)],
        &[(0b00001, &ENTRY_CANANEAN_15332949567639306041)],
    ],
    range: 3..=12,
};

static VARS_CAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAM_CHILDREN),
    value: None,
};

pub static VARS_CAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isades"),
        dictgen::InsensitiveStr::Ascii("isadoes"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ize"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CAMISADES_723999954797250701)],
        &[(0b11010, &ENTRY_CAMISADES_723999954797250701)],
        &[(0b10010, &ENTRY_CAMIZE_5273973185736720772)],
        &[(0b01001, &ENTRY_CAMIZE_5273973185736720772)],
    ],
    range: 3..=7,
};

static VARS_CAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAL_CHILDREN),
    value: None,
};

pub static VARS_CAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ander"),
        dictgen::InsensitiveStr::Ascii("andre"),
        dictgen::InsensitiveStr::Ascii("caemia"),
        dictgen::InsensitiveStr::Ascii("cemia"),
        dictgen::InsensitiveStr::Ascii("dron"),
        dictgen::InsensitiveStr::Ascii("drons"),
        dictgen::InsensitiveStr::Ascii("endarisation"),
        dictgen::InsensitiveStr::Ascii("endarisations"),
        dictgen::InsensitiveStr::Ascii("endarise"),
        dictgen::InsensitiveStr::Ascii("endarised"),
        dictgen::InsensitiveStr::Ascii("endarises"),
        dictgen::InsensitiveStr::Ascii("endarising"),
        dictgen::InsensitiveStr::Ascii("endarization"),
        dictgen::InsensitiveStr::Ascii("endarizations"),
        dictgen::InsensitiveStr::Ascii("endarize"),
        dictgen::InsensitiveStr::Ascii("endarized"),
        dictgen::InsensitiveStr::Ascii("endarizes"),
        dictgen::InsensitiveStr::Ascii("endarizing"),
        dictgen::InsensitiveStr::Ascii("ender"),
        dictgen::InsensitiveStr::Ascii("endre"),
        dictgen::InsensitiveStr::Ascii("iber"),
        dictgen::InsensitiveStr::Ascii("ibers"),
        dictgen::InsensitiveStr::Ascii("ibre"),
        dictgen::InsensitiveStr::Ascii("ibres"),
        dictgen::InsensitiveStr::Ascii("isthenic"),
        dictgen::InsensitiveStr::Ascii("isthenics"),
        dictgen::InsensitiveStr::Ascii("k"),
        dictgen::InsensitiveStr::Ascii("ked"),
        dictgen::InsensitiveStr::Ascii("king"),
        dictgen::InsensitiveStr::Ascii("kings"),
        dictgen::InsensitiveStr::Ascii("ks"),
        dictgen::InsensitiveStr::Ascii("liper"),
        dictgen::InsensitiveStr::Ascii("lipered"),
        dictgen::InsensitiveStr::Ascii("lipering"),
        dictgen::InsensitiveStr::Ascii("lipers"),
        dictgen::InsensitiveStr::Ascii("lirrhoae"),
        dictgen::InsensitiveStr::Ascii("lirrhoe"),
        dictgen::InsensitiveStr::Ascii("listhenic"),
        dictgen::InsensitiveStr::Ascii("listhenics"),
        dictgen::InsensitiveStr::Ascii("odaemon"),
        dictgen::InsensitiveStr::Ascii("odemon"),
        dictgen::InsensitiveStr::Ascii("vinise"),
        dictgen::InsensitiveStr::Ascii("vinises"),
        dictgen::InsensitiveStr::Ascii("vinize"),
        dictgen::InsensitiveStr::Ascii("vinizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CALANDER_8386886117613566628)],
        &[(0b11010, &ENTRY_CALANDER_8386886117613566628)],
        &[(0b11010, &ENTRY_CALCEMIA_13780473444512332487)],
        &[(0b10001, &ENTRY_CALCEMIA_13780473444512332487)],
        &[(0b10011, &ENTRY_CAULDRON_1773331448073014615)],
        &[(0b10011, &ENTRY_CAULDRONS_5688241368036052829)],
        &[(0b10010, &ENTRY_CALENDARIZATION_3319078431557619935)],
        &[(0b10010, &ENTRY_CALENDARIZATIONS_1625472196367375880)],
        &[(0b10010, &ENTRY_CALENDARIZE_1440485717876612344)],
        &[(0b10010, &ENTRY_CALENDARIZED_11715564102717219815)],
        &[(0b10010, &ENTRY_CALENDARIZES_3253812247299622139)],
        &[(0b10010, &ENTRY_CALENDARIZING_7884481787335064911)],
        &[(0b01001, &ENTRY_CALENDARIZATION_3319078431557619935)],
        &[(0b01001, &ENTRY_CALENDARIZATIONS_1625472196367375880)],
        &[(0b01001, &ENTRY_CALENDARIZE_1440485717876612344)],
        &[(0b01001, &ENTRY_CALENDARIZED_11715564102717219815)],
        &[(0b01001, &ENTRY_CALENDARIZES_3253812247299622139)],
        &[(0b01001, &ENTRY_CALENDARIZING_7884481787335064911)],
        &[(0b00001, &ENTRY_CALENDER_18426116015986884728)],
        &[(0b11010, &ENTRY_CALENDER_18426116015986884728)],
        &[(0b00001, &ENTRY_CALIBER_11979237421213696401)],
        &[(0b00001, &ENTRY_CALIBERS_12175169505129012964)],
        &[(0b11010, &ENTRY_CALIBER_11979237421213696401)],
        &[(0b11010, &ENTRY_CALIBERS_12175169505129012964)],
        &[(0b01001, &ENTRY_CALISTHENIC_1074720409180890750)],
        &[(0b01001, &ENTRY_CALISTHENICS_8747499938229310952)],
        &[
            (0b00001, &ENTRY_CALK_9463720069156928103),
            (0b00001, &ENTRY_CAULK_13405348041672279283),
            (0b00001, &ENTRY_CAULK_5085090702762931673),
        ],
        &[
            (0b00001, &ENTRY_CALKED_17587227683338315155),
            (0b00001, &ENTRY_CAULKED_17850506211135154377),
        ],
        &[
            (0b00001, &ENTRY_CALKING_15122106954759194192),
            (0b00001, &ENTRY_CAULKING_1812804659342859546),
            (0b00001, &ENTRY_CAULK_5085090702762931673),
        ],
        &[(0b00001, &ENTRY_CAULKS_2004629765557914803)],
        &[
            (0b00001, &ENTRY_CALKS_3513793957936189042),
            (0b00001, &ENTRY_CAULKS_2004629765557914803),
            (0b00001, &ENTRY_CAULKS_4230617823899022638),
        ],
        &[(0b11010, &ENTRY_CALIPER_11659384912162704496)],
        &[(0b11010, &ENTRY_CALIPERED_15148589818375924712)],
        &[(0b11010, &ENTRY_CALIPERING_13878626335317126988)],
        &[(0b11010, &ENTRY_CALIPERS_1796103950790864970)],
        &[(0b11010, &ENTRY_CALLIRRHOE_14193156888455455215)],
        &[(0b00001, &ENTRY_CALLIRRHOE_14193156888455455215)],
        &[(0b11010, &ENTRY_CALISTHENIC_1074720409180890750)],
        &[(0b11010, &ENTRY_CALISTHENICS_8747499938229310952)],
        &[(0b11010, &ENTRY_CALODEMON_9407569777520507468)],
        &[(0b00001, &ENTRY_CALODEMON_9407569777520507468)],
        &[(0b10010, &ENTRY_CALVINIZE_3085273063367597860)],
        &[(0b10010, &ENTRY_CALVINIZES_17919041968297410767)],
        &[(0b01001, &ENTRY_CALVINIZE_3085273063367597860)],
        &[(0b01001, &ENTRY_CALVINIZES_17919041968297410767)],
    ],
    range: 1..=13,
};

static VARS_CAF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAF_CHILDREN),
    value: None,
};

pub static VARS_CAF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fer"),
        dictgen::InsensitiveStr::Ascii("fre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CAFFER_9506538294723235326)],
        &[(0b11010, &ENTRY_CAFFER_9506538294723235326)],
    ],
    range: 3..=3,
};

static VARS_CAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAE_CHILDREN),
    value: None,
};

pub static VARS_CAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cally"),
        dictgen::InsensitiveStr::Ascii("citis"),
        dictgen::InsensitiveStr::Ascii("citises"),
        dictgen::InsensitiveStr::Ascii("city"),
        dictgen::InsensitiveStr::Ascii("costomy"),
        dictgen::InsensitiveStr::Ascii("cotomy"),
        dictgen::InsensitiveStr::Ascii("nis"),
        dictgen::InsensitiveStr::Ascii("nogenetic"),
        dictgen::InsensitiveStr::Ascii("nogenetically"),
        dictgen::InsensitiveStr::Ascii("nozoic"),
        dictgen::InsensitiveStr::Ascii("rule"),
        dictgen::InsensitiveStr::Ascii("sar"),
        dictgen::InsensitiveStr::Ascii("saria"),
        dictgen::InsensitiveStr::Ascii("sarise"),
        dictgen::InsensitiveStr::Ascii("sarises"),
        dictgen::InsensitiveStr::Ascii("sarize"),
        dictgen::InsensitiveStr::Ascii("sarizes"),
        dictgen::InsensitiveStr::Ascii("sious"),
        dictgen::InsensitiveStr::Ascii("sium"),
        dictgen::InsensitiveStr::Ascii("siums"),
        dictgen::InsensitiveStr::Ascii("spitose"),
        dictgen::InsensitiveStr::Ascii("spitosely"),
        dictgen::InsensitiveStr::Ascii("stus"),
        dictgen::InsensitiveStr::Ascii("stuses"),
        dictgen::InsensitiveStr::Ascii("sural"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CECALLY_9670506280479282690)],
        &[(0b11010, &ENTRY_CECITIS_3074214842392316094)],
        &[(0b11010, &ENTRY_CECITISES_8125550960993244895)],
        &[(0b11010, &ENTRY_CECITY_109164963209594686)],
        &[(0b11010, &ENTRY_CECOSTOMY_14076938077100733913)],
        &[(0b11010, &ENTRY_CECOTOMY_6391026121304575885)],
        &[(0b11010, &ENTRY_CENIS_12176224815013604688)],
        &[(0b11010, &ENTRY_CENOGENETIC_3476451464373390522)],
        &[(0b11010, &ENTRY_CENOGENETICALLY_1887927515979187697)],
        &[(0b11010, &ENTRY_CENOZOIC_15012859896037847714)],
        &[(0b11010, &ENTRY_CERULE_13807908748488324309)],
        &[(0b11010, &ENTRY_CESAR_17704325165906141578)],
        &[(0b11010, &ENTRY_CESARIA_13260737813085944916)],
        &[(0b10010, &ENTRY_CAESARIZE_18266155686129237935)],
        &[(0b10010, &ENTRY_CAESARIZES_8074863442512394703)],
        &[(0b01001, &ENTRY_CAESARIZE_18266155686129237935)],
        &[(0b01001, &ENTRY_CAESARIZES_8074863442512394703)],
        &[(0b11010, &ENTRY_CESIOUS_11410150702051630927)],
        &[(0b11010, &ENTRY_CESIUM_14697098024822079251)],
        &[(0b11010, &ENTRY_CESIUMS_6672725677512073080)],
        &[(0b11010, &ENTRY_CESPITOSE_6409378686720351127)],
        &[(0b11010, &ENTRY_CESPITOSELY_3931130846381787690)],
        &[(0b11010, &ENTRY_CESTUS_4030396889026927959)],
        &[(0b11010, &ENTRY_CESTUSES_307704550846354852)],
        &[(0b11010, &ENTRY_CESURAL_6753528217264809955)],
    ],
    range: 3..=13,
};

static VARS_CAD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAD_CHILDREN),
    value: None,
};

pub static VARS_CAD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aster"),
        dictgen::InsensitiveStr::Ascii("asters"),
        dictgen::InsensitiveStr::Ascii("astre"),
        dictgen::InsensitiveStr::Ascii("astres"),
        dictgen::InsensitiveStr::Ascii("averise"),
        dictgen::InsensitiveStr::Ascii("averises"),
        dictgen::InsensitiveStr::Ascii("averize"),
        dictgen::InsensitiveStr::Ascii("averizes"),
        dictgen::InsensitiveStr::Ascii("miumise"),
        dictgen::InsensitiveStr::Ascii("miumises"),
        dictgen::InsensitiveStr::Ascii("miumize"),
        dictgen::InsensitiveStr::Ascii("miumizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CADASTER_1284848465582914080)],
        &[(0b00001, &ENTRY_CADASTERS_6862701278625162442)],
        &[(0b11010, &ENTRY_CADASTER_1284848465582914080)],
        &[(0b11010, &ENTRY_CADASTERS_6862701278625162442)],
        &[(0b10010, &ENTRY_CADAVERIZE_14270258494884550711)],
        &[(0b10010, &ENTRY_CADAVERIZES_3809238108442329357)],
        &[(0b01001, &ENTRY_CADAVERIZE_14270258494884550711)],
        &[(0b01001, &ENTRY_CADAVERIZES_3809238108442329357)],
        &[(0b10010, &ENTRY_CADMIUMIZE_4596925533129834601)],
        &[(0b10010, &ENTRY_CADMIUMIZES_15932160358276911610)],
        &[(0b01001, &ENTRY_CADMIUMIZE_4596925533129834601)],
        &[(0b01001, &ENTRY_CADMIUMIZES_15932160358276911610)],
    ],
    range: 5..=8,
};

static VARS_CAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAC_CHILDREN),
    value: None,
};

pub static VARS_CAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("haemia"),
        dictgen::InsensitiveStr::Ascii("haemic"),
        dictgen::InsensitiveStr::Ascii("hemia"),
        dictgen::InsensitiveStr::Ascii("hemic"),
        dictgen::InsensitiveStr::Ascii("oaethes"),
        dictgen::InsensitiveStr::Ascii("odaemon"),
        dictgen::InsensitiveStr::Ascii("odaemoniac"),
        dictgen::InsensitiveStr::Ascii("odaemonial"),
        dictgen::InsensitiveStr::Ascii("odaemonic"),
        dictgen::InsensitiveStr::Ascii("odaemons"),
        dictgen::InsensitiveStr::Ascii("odemon"),
        dictgen::InsensitiveStr::Ascii("odemoniac"),
        dictgen::InsensitiveStr::Ascii("odemonial"),
        dictgen::InsensitiveStr::Ascii("odemonic"),
        dictgen::InsensitiveStr::Ascii("odemons"),
        dictgen::InsensitiveStr::Ascii("oethes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CACESTHESIA_2765173217323765779)],
        &[(0b10001, &ENTRY_CACESTHESIA_2765173217323765779)],
        &[(0b11010, &ENTRY_CACHEMIA_16393627162115505894)],
        &[(0b11010, &ENTRY_CACHEMIC_14712432132181211487)],
        &[(0b10001, &ENTRY_CACHEMIA_16393627162115505894)],
        &[(0b10001, &ENTRY_CACHEMIC_14712432132181211487)],
        &[(0b11010, &ENTRY_CACOETHES_15396969546538260310)],
        &[(0b11010, &ENTRY_CACODEMON_5420155303899502846)],
        &[(0b11010, &ENTRY_CACODEMONIAC_5130334321528000087)],
        &[(0b11010, &ENTRY_CACODEMONIAL_6128539527465489160)],
        &[(0b11010, &ENTRY_CACODEMONIC_5648165095725544727)],
        &[(0b11010, &ENTRY_CACODEMONS_16329535367132592196)],
        &[(0b10001, &ENTRY_CACODEMON_5420155303899502846)],
        &[(0b10001, &ENTRY_CACODEMONIAC_5130334321528000087)],
        &[(0b10001, &ENTRY_CACODEMONIAL_6128539527465489160)],
        &[(0b10001, &ENTRY_CACODEMONIC_5648165095725544727)],
        &[(0b10001, &ENTRY_CACODEMONS_16329535367132592196)],
        &[(0b10001, &ENTRY_CACOETHES_15396969546538260310)],
    ],
    range: 5..=10,
};

static VARS_B_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_B_CHILDREN),
    value: None,
};

static VARS_B_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_BA_NODE),
    None,
    None,
    None,
    Some(&VARS_BE_NODE),
    None,
    None,
    None,
    Some(&VARS_BI_NODE),
    None,
    None,
    Some(&VARS_BL_NODE),
    None,
    None,
    Some(&VARS_BO_NODE),
    None,
    None,
    Some(&VARS_BR_NODE),
    None,
    None,
    Some(&VARS_BU_NODE),
    None,
    None,
    None,
    Some(&VARS_BY_NODE),
    None,
];

static VARS_BY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BY_CHILDREN),
    value: None,
};

pub static VARS_BY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ronise"),
        dictgen::InsensitiveStr::Ascii("ronises"),
        dictgen::InsensitiveStr::Ascii("ronize"),
        dictgen::InsensitiveStr::Ascii("ronizes"),
        dictgen::InsensitiveStr::Ascii("zantinise"),
        dictgen::InsensitiveStr::Ascii("zantinises"),
        dictgen::InsensitiveStr::Ascii("zantinize"),
        dictgen::InsensitiveStr::Ascii("zantinizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BYRONIZE_16464968414469440781)],
        &[(0b10010, &ENTRY_BYRONIZES_18201297154455431805)],
        &[(0b01001, &ENTRY_BYRONIZE_16464968414469440781)],
        &[(0b01001, &ENTRY_BYRONIZES_18201297154455431805)],
        &[(0b10010, &ENTRY_BYZANTINIZE_12213067988390048109)],
        &[(0b10010, &ENTRY_BYZANTINIZES_11684453378746621577)],
        &[(0b01001, &ENTRY_BYZANTINIZE_12213067988390048109)],
        &[(0b01001, &ENTRY_BYZANTINIZES_11684453378746621577)],
    ],
    range: 6..=10,
};

static VARS_BU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BU_CHILDREN),
    value: None,
};

pub static VARS_BU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("daenny"),
        dictgen::InsensitiveStr::Ascii("denny"),
        dictgen::InsensitiveStr::Ascii("reaucratisation"),
        dictgen::InsensitiveStr::Ascii("reaucratisations"),
        dictgen::InsensitiveStr::Ascii("reaucratise"),
        dictgen::InsensitiveStr::Ascii("reaucratised"),
        dictgen::InsensitiveStr::Ascii("reaucratises"),
        dictgen::InsensitiveStr::Ascii("reaucratising"),
        dictgen::InsensitiveStr::Ascii("reaucratization"),
        dictgen::InsensitiveStr::Ascii("reaucratizations"),
        dictgen::InsensitiveStr::Ascii("reaucratize"),
        dictgen::InsensitiveStr::Ascii("reaucratized"),
        dictgen::InsensitiveStr::Ascii("reaucratizes"),
        dictgen::InsensitiveStr::Ascii("reaucratizing"),
        dictgen::InsensitiveStr::Ascii("rglarise"),
        dictgen::InsensitiveStr::Ascii("rglarised"),
        dictgen::InsensitiveStr::Ascii("rglarises"),
        dictgen::InsensitiveStr::Ascii("rglarising"),
        dictgen::InsensitiveStr::Ascii("rglarize"),
        dictgen::InsensitiveStr::Ascii("rglarized"),
        dictgen::InsensitiveStr::Ascii("rglarizes"),
        dictgen::InsensitiveStr::Ascii("rglarizing"),
        dictgen::InsensitiveStr::Ascii("rkha"),
        dictgen::InsensitiveStr::Ascii("rkhas"),
        dictgen::InsensitiveStr::Ascii("rnettise"),
        dictgen::InsensitiveStr::Ascii("rnettised"),
        dictgen::InsensitiveStr::Ascii("rnettises"),
        dictgen::InsensitiveStr::Ascii("rnettising"),
        dictgen::InsensitiveStr::Ascii("rnettize"),
        dictgen::InsensitiveStr::Ascii("rnettized"),
        dictgen::InsensitiveStr::Ascii("rnettizes"),
        dictgen::InsensitiveStr::Ascii("rnettizing"),
        dictgen::InsensitiveStr::Ascii("rqa"),
        dictgen::InsensitiveStr::Ascii("rqas"),
        dictgen::InsensitiveStr::Ascii("sheled"),
        dictgen::InsensitiveStr::Ascii("sheler"),
        dictgen::InsensitiveStr::Ascii("shelers"),
        dictgen::InsensitiveStr::Ascii("sheling"),
        dictgen::InsensitiveStr::Ascii("shelings"),
        dictgen::InsensitiveStr::Ascii("shelled"),
        dictgen::InsensitiveStr::Ascii("sheller"),
        dictgen::InsensitiveStr::Ascii("shellers"),
        dictgen::InsensitiveStr::Ascii("shelling"),
        dictgen::InsensitiveStr::Ascii("shellings"),
        dictgen::InsensitiveStr::Ascii("ssings"),
    ],
    values: &[
        &[(0b11010, &ENTRY_BUDENNY_8301048534741947517)],
        &[(0b00001, &ENTRY_BUDENNY_8301048534741947517)],
        &[(0b10010, &ENTRY_BUREAUCRATIZATION_7250957081103523449)],
        &[(0b10010, &ENTRY_BUREAUCRATIZATIONS_4674366041166989149)],
        &[(0b10010, &ENTRY_BUREAUCRATIZE_13391150115061038607)],
        &[(0b10010, &ENTRY_BUREAUCRATIZED_4248245955080237225)],
        &[(0b10010, &ENTRY_BUREAUCRATIZES_16810259950475596086)],
        &[(0b10010, &ENTRY_BUREAUCRATIZING_8025017160589580538)],
        &[(0b01001, &ENTRY_BUREAUCRATIZATION_7250957081103523449)],
        &[(0b01001, &ENTRY_BUREAUCRATIZATIONS_4674366041166989149)],
        &[(0b01001, &ENTRY_BUREAUCRATIZE_13391150115061038607)],
        &[(0b01001, &ENTRY_BUREAUCRATIZED_4248245955080237225)],
        &[(0b01001, &ENTRY_BUREAUCRATIZES_16810259950475596086)],
        &[(0b01001, &ENTRY_BUREAUCRATIZING_8025017160589580538)],
        &[(0b10010, &ENTRY_BURGLARIZE_1087475814106005332)],
        &[(0b10010, &ENTRY_BURGLARIZED_5921030312710381425)],
        &[(0b10010, &ENTRY_BURGLARIZES_13866286421224924410)],
        &[(0b10010, &ENTRY_BURGLARIZING_18147959943236525815)],
        &[(0b01001, &ENTRY_BURGLARIZE_1087475814106005332)],
        &[(0b01001, &ENTRY_BURGLARIZED_5921030312710381425)],
        &[(0b01001, &ENTRY_BURGLARIZES_13866286421224924410)],
        &[(0b01001, &ENTRY_BURGLARIZING_18147959943236525815)],
        &[(0b01010, &ENTRY_BURKA_17738439542425653268)],
        &[(0b01010, &ENTRY_BURKAS_12070614531615578820)],
        &[(0b10010, &ENTRY_BURNETTIZE_7862530595152906990)],
        &[(0b10010, &ENTRY_BURNETTIZED_13756375894148665827)],
        &[(0b10010, &ENTRY_BURNETTIZES_16655928180448576506)],
        &[(0b10010, &ENTRY_BURNETTIZING_4527669031334060280)],
        &[(0b01001, &ENTRY_BURNETTIZE_7862530595152906990)],
        &[(0b01001, &ENTRY_BURNETTIZED_13756375894148665827)],
        &[(0b01001, &ENTRY_BURNETTIZES_16655928180448576506)],
        &[(0b01001, &ENTRY_BURNETTIZING_4527669031334060280)],
        &[(0b11010, &ENTRY_BURKA_17738439542425653268)],
        &[(0b11010, &ENTRY_BURKAS_12070614531615578820)],
        &[(0b00001, &ENTRY_BUSHELED_1994274500105410677)],
        &[(0b00001, &ENTRY_BUSHELER_17155781392383988946)],
        &[(0b00001, &ENTRY_BUSHELERS_8897857104840276712)],
        &[(0b00001, &ENTRY_BUSHELING_1847310694202977393)],
        &[(0b00001, &ENTRY_BUSHELINGS_2758606437123004621)],
        &[(0b11010, &ENTRY_BUSHELED_1994274500105410677)],
        &[(0b11010, &ENTRY_BUSHELER_17155781392383988946)],
        &[(0b11010, &ENTRY_BUSHELERS_8897857104840276712)],
        &[(0b11010, &ENTRY_BUSHELING_1847310694202977393)],
        &[(0b11010, &ENTRY_BUSHELINGS_2758606437123004621)],
        &[(0b10011, &ENTRY_BUSINGS_8757237867622763594)],
    ],
    range: 3..=16,
};

static VARS_BR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BR_CHILDREN),
    value: None,
};

pub static VARS_BR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("adypnea"),
        dictgen::InsensitiveStr::Ascii("adypnoea"),
        dictgen::InsensitiveStr::Ascii("eathalyse"),
        dictgen::InsensitiveStr::Ascii("eathalysed"),
        dictgen::InsensitiveStr::Ascii("eathalyser"),
        dictgen::InsensitiveStr::Ascii("eathalysers"),
        dictgen::InsensitiveStr::Ascii("eathalyses"),
        dictgen::InsensitiveStr::Ascii("eathalysing"),
        dictgen::InsensitiveStr::Ascii("eathalyze"),
        dictgen::InsensitiveStr::Ascii("eathalyzed"),
        dictgen::InsensitiveStr::Ascii("eathalyzers"),
        dictgen::InsensitiveStr::Ascii("eathalyzes"),
        dictgen::InsensitiveStr::Ascii("eathalyzing"),
        dictgen::InsensitiveStr::Ascii("eloque"),
        dictgen::InsensitiveStr::Ascii("eme"),
        dictgen::InsensitiveStr::Ascii("en"),
        dictgen::InsensitiveStr::Ascii("isa"),
        dictgen::InsensitiveStr::Ascii("iza"),
        dictgen::InsensitiveStr::Ascii("omethylene"),
        dictgen::InsensitiveStr::Ascii("ominise"),
        dictgen::InsensitiveStr::Ascii("ominises"),
        dictgen::InsensitiveStr::Ascii("ominize"),
        dictgen::InsensitiveStr::Ascii("ominizes"),
        dictgen::InsensitiveStr::Ascii("omisation"),
        dictgen::InsensitiveStr::Ascii("omise"),
        dictgen::InsensitiveStr::Ascii("omised"),
        dictgen::InsensitiveStr::Ascii("omising"),
        dictgen::InsensitiveStr::Ascii("omization"),
        dictgen::InsensitiveStr::Ascii("omize"),
        dictgen::InsensitiveStr::Ascii("omized"),
        dictgen::InsensitiveStr::Ascii("omizing"),
        dictgen::InsensitiveStr::Ascii("omoethylene"),
        dictgen::InsensitiveStr::Ascii("utalisation"),
        dictgen::InsensitiveStr::Ascii("utalisations"),
        dictgen::InsensitiveStr::Ascii("utalise"),
        dictgen::InsensitiveStr::Ascii("utalised"),
        dictgen::InsensitiveStr::Ascii("utalises"),
        dictgen::InsensitiveStr::Ascii("utalising"),
        dictgen::InsensitiveStr::Ascii("utalization"),
        dictgen::InsensitiveStr::Ascii("utalizations"),
        dictgen::InsensitiveStr::Ascii("utalize"),
        dictgen::InsensitiveStr::Ascii("utalized"),
        dictgen::InsensitiveStr::Ascii("utalizes"),
        dictgen::InsensitiveStr::Ascii("utalizing"),
    ],
    values: &[
        &[(0b10001, &ENTRY_BRADYPNEA_4442372327480029437)],
        &[(0b11010, &ENTRY_BRADYPNEA_4442372327480029437)],
        &[(0b11010, &ENTRY_BREATHALYZE_10796683967425699198)],
        &[(0b11010, &ENTRY_BREATHALYZED_16539997499095919892)],
        &[(0b11010, &ENTRY_BREATHALYZER_4271010669418934525)],
        &[(0b11010, &ENTRY_BREATHALYZERS_3691744749547968414)],
        &[(0b11010, &ENTRY_BREATHALYZES_11235604268893682846)],
        &[(0b11010, &ENTRY_BREATHALYZING_565448827730861286)],
        &[(0b01001, &ENTRY_BREATHALYZE_10796683967425699198)],
        &[(0b01001, &ENTRY_BREATHALYZED_16539997499095919892)],
        &[(0b00001, &ENTRY_BREATHALYZERS_3691744749547968414)],
        &[(0b01001, &ENTRY_BREATHALYZES_11235604268893682846)],
        &[(0b01001, &ENTRY_BREATHALYZING_565448827730861286)],
        &[(0b11010, &ENTRY_BERLOQUE_15524756595685455268)],
        &[(0b11010, &ENTRY_BERME_6583686006981215988)],
        &[(0b11010, &ENTRY_BERN_2039740744291479118)],
        &[(0b10010, &ENTRY_BRIZA_3574958223447302377)],
        &[(0b01001, &ENTRY_BRIZA_3574958223447302377)],
        &[(0b00001, &ENTRY_BROMETHYLENE_7740792685786840890)],
        &[(0b10010, &ENTRY_BROMINIZE_8193002587551857917)],
        &[(0b10010, &ENTRY_BROMINIZES_5628408947482003092)],
        &[(0b01001, &ENTRY_BROMINIZE_8193002587551857917)],
        &[(0b01001, &ENTRY_BROMINIZES_5628408947482003092)],
        &[(0b10010, &ENTRY_BROMIZATION_5590155013784391685)],
        &[(0b10010, &ENTRY_BROMIZE_10848505058317064152)],
        &[(0b10010, &ENTRY_BROMIZED_6586226641291200206)],
        &[(0b10010, &ENTRY_BROMIZING_10490899539525336887)],
        &[(0b01001, &ENTRY_BROMIZATION_5590155013784391685)],
        &[(0b01001, &ENTRY_BROMIZE_10848505058317064152)],
        &[(0b01001, &ENTRY_BROMIZED_6586226641291200206)],
        &[(0b01001, &ENTRY_BROMIZING_10490899539525336887)],
        &[(0b11010, &ENTRY_BROMETHYLENE_7740792685786840890)],
        &[(0b10010, &ENTRY_BRUTALIZATION_11293320142916899383)],
        &[(0b10010, &ENTRY_BRUTALIZATIONS_14281415064444405659)],
        &[(0b10010, &ENTRY_BRUTALIZE_13435719365361063955)],
        &[(0b10010, &ENTRY_BRUTALIZED_12895970956896346273)],
        &[(0b10010, &ENTRY_BRUTALIZES_15844790462452513749)],
        &[(0b10010, &ENTRY_BRUTALIZING_7797427754196540922)],
        &[(0b01001, &ENTRY_BRUTALIZATION_11293320142916899383)],
        &[(0b01001, &ENTRY_BRUTALIZATIONS_14281415064444405659)],
        &[(0b01001, &ENTRY_BRUTALIZE_13435719365361063955)],
        &[(0b01001, &ENTRY_BRUTALIZED_12895970956896346273)],
        &[(0b01001, &ENTRY_BRUTALIZES_15844790462452513749)],
        &[(0b01001, &ENTRY_BRUTALIZING_7797427754196540922)],
    ],
    range: 2..=12,
};

static VARS_BO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_BO_CHILDREN),
    value: None,
};

static VARS_BO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_BOA_NODE),
    None,
    None,
    None,
    Some(&VARS_BOE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_BOL_NODE),
    None,
    Some(&VARS_BON_NODE),
    None,
    None,
    None,
    Some(&VARS_BOR_NODE),
    Some(&VARS_BOS_NODE),
    Some(&VARS_BOT_NODE),
    Some(&VARS_BOU_NODE),
    None,
    Some(&VARS_BOW_NODE),
    None,
    None,
    None,
];

static VARS_BOW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOW_CHILDREN),
    value: None,
};

pub static VARS_BOW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dlerisation"),
        dictgen::InsensitiveStr::Ascii("dlerisations"),
        dictgen::InsensitiveStr::Ascii("dlerise"),
        dictgen::InsensitiveStr::Ascii("dlerised"),
        dictgen::InsensitiveStr::Ascii("dleriser"),
        dictgen::InsensitiveStr::Ascii("dlerisers"),
        dictgen::InsensitiveStr::Ascii("dlerises"),
        dictgen::InsensitiveStr::Ascii("dlerising"),
        dictgen::InsensitiveStr::Ascii("dlerization"),
        dictgen::InsensitiveStr::Ascii("dlerizations"),
        dictgen::InsensitiveStr::Ascii("dlerize"),
        dictgen::InsensitiveStr::Ascii("dlerized"),
        dictgen::InsensitiveStr::Ascii("dlerizer"),
        dictgen::InsensitiveStr::Ascii("dlerizers"),
        dictgen::InsensitiveStr::Ascii("dlerizes"),
        dictgen::InsensitiveStr::Ascii("dlerizing"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("lder"),
        dictgen::InsensitiveStr::Ascii("lders"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BOWDLERIZATION_8303366286031487639)],
        &[(0b10010, &ENTRY_BOWDLERIZATIONS_6775792789701362692)],
        &[(0b10010, &ENTRY_BOWDLERIZE_5456349648157007190)],
        &[(0b10010, &ENTRY_BOWDLERIZED_4489335143117406489)],
        &[(0b10010, &ENTRY_BOWDLERIZER_6233002729985543010)],
        &[(0b10010, &ENTRY_BOWDLERIZERS_5755041647304781487)],
        &[(0b10010, &ENTRY_BOWDLERIZES_9741187207136026760)],
        &[(0b10010, &ENTRY_BOWDLERIZING_13774867242132431801)],
        &[(0b01001, &ENTRY_BOWDLERIZATION_8303366286031487639)],
        &[(0b01001, &ENTRY_BOWDLERIZATIONS_6775792789701362692)],
        &[(0b01001, &ENTRY_BOWDLERIZE_5456349648157007190)],
        &[(0b01001, &ENTRY_BOWDLERIZED_4489335143117406489)],
        &[(0b01001, &ENTRY_BOWDLERIZER_6233002729985543010)],
        &[(0b01001, &ENTRY_BOWDLERIZERS_5755041647304781487)],
        &[(0b01001, &ENTRY_BOWDLERIZES_9741187207136026760)],
        &[(0b01001, &ENTRY_BOWDLERIZING_13774867242132431801)],
        &[(0b00001, &ENTRY_BOWELED_15475057737247232958)],
        &[(0b00001, &ENTRY_BOWELING_5722084722134662370)],
        &[(0b11010, &ENTRY_BOWELED_15475057737247232958)],
        &[(0b11010, &ENTRY_BOWELING_5722084722134662370)],
        &[(0b00001, &ENTRY_BOULDER_2537004730775027440)],
        &[(0b00001, &ENTRY_BOULDERS_9268529342784684955)],
    ],
    range: 4..=12,
};

static VARS_BOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOU_CHILDREN),
    value: None,
};

pub static VARS_BOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("levardise"),
        dictgen::InsensitiveStr::Ascii("levardises"),
        dictgen::InsensitiveStr::Ascii("levardize"),
        dictgen::InsensitiveStr::Ascii("levardizes"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rage"),
        dictgen::InsensitiveStr::Ascii("rasque"),
        dictgen::InsensitiveStr::Ascii("rbonise"),
        dictgen::InsensitiveStr::Ascii("rbonises"),
        dictgen::InsensitiveStr::Ascii("rbonize"),
        dictgen::InsensitiveStr::Ascii("rbonizes"),
        dictgen::InsensitiveStr::Ascii("rd"),
        dictgen::InsensitiveStr::Ascii("rds"),
        dictgen::InsensitiveStr::Ascii("rg"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BOULEVARDIZE_8382934846655629979)],
        &[(0b10010, &ENTRY_BOULEVARDIZES_14884898377762838680)],
        &[(0b01001, &ENTRY_BOULEVARDIZE_8382934846655629979)],
        &[(0b01001, &ENTRY_BOULEVARDIZES_14884898377762838680)],
        &[(0b11010, &ENTRY_BOR_8171934536008579347)],
        &[(0b11010, &ENTRY_BORAGE_12536470626004536619)],
        &[(0b11010, &ENTRY_BORASQUE_12894117064757155083)],
        &[(0b10010, &ENTRY_BOURBONIZE_17360958086154824656)],
        &[(0b10010, &ENTRY_BOURBONIZES_11928142486642420487)],
        &[(0b01001, &ENTRY_BOURBONIZE_17360958086154824656)],
        &[(0b01001, &ENTRY_BOURBONIZES_11928142486642420487)],
        &[(0b11010, &ENTRY_BORD_9769627334403333891)],
        &[(0b11010, &ENTRY_BORDS_4097557745547974676)],
        &[(0b11010, &ENTRY_BORG_10492083036686991922)],
    ],
    range: 1..=10,
};

static VARS_BOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOT_CHILDREN),
    value: None,
};

pub static VARS_BOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("aniser"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizer"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BOTANIZE_3414900112803410859)],
        &[(0b10010, &ENTRY_BOTANIZED_6623624034808806509)],
        &[(0b10010, &ENTRY_BOTANIZER_12147213895328657457)],
        &[(0b10010, &ENTRY_BOTANIZES_3701375861091440735)],
        &[(0b10010, &ENTRY_BOTANIZING_7854186980211713777)],
        &[(0b01001, &ENTRY_BOTANIZE_3414900112803410859)],
        &[(0b01001, &ENTRY_BOTANIZED_6623624034808806509)],
        &[(0b01001, &ENTRY_BOTANIZER_12147213895328657457)],
        &[(0b01001, &ENTRY_BOTANIZES_3701375861091440735)],
        &[(0b01001, &ENTRY_BOTANIZING_7854186980211713777)],
    ],
    range: 5..=7,
};

static VARS_BOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOS_CHILDREN),
    value: None,
};

pub static VARS_BOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("wellise"),
        dictgen::InsensitiveStr::Ascii("wellised"),
        dictgen::InsensitiveStr::Ascii("wellises"),
        dictgen::InsensitiveStr::Ascii("wellising"),
        dictgen::InsensitiveStr::Ascii("wellize"),
        dictgen::InsensitiveStr::Ascii("wellized"),
        dictgen::InsensitiveStr::Ascii("wellizes"),
        dictgen::InsensitiveStr::Ascii("wellizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BOSWELLIZE_6441210250172667640)],
        &[(0b10010, &ENTRY_BOSWELLIZED_16107372646692584162)],
        &[(0b10010, &ENTRY_BOSWELLIZES_13289068481348615807)],
        &[(0b10010, &ENTRY_BOSWELLIZING_1263019686128444085)],
        &[(0b01001, &ENTRY_BOSWELLIZE_6441210250172667640)],
        &[(0b01001, &ENTRY_BOSWELLIZED_16107372646692584162)],
        &[(0b01001, &ENTRY_BOSWELLIZES_13289068481348615807)],
        &[(0b01001, &ENTRY_BOSWELLIZING_1263019686128444085)],
    ],
    range: 7..=9,
};

static VARS_BOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOR_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_BOR_8171934536008579347)]),
};

pub static VARS_BOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("age"),
        dictgen::InsensitiveStr::Ascii("asque"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("ds"),
        dictgen::InsensitiveStr::Ascii("g"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("izes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BORAGE_12536470626004536619)],
        &[(0b00001, &ENTRY_BORASQUE_12894117064757155083)],
        &[(0b00001, &ENTRY_BORD_9769627334403333891)],
        &[(0b00001, &ENTRY_BORDS_4097557745547974676)],
        &[(0b00001, &ENTRY_BORG_10492083036686991922)],
        &[(0b10010, &ENTRY_BORIZE_9924789501684223687)],
        &[(0b10010, &ENTRY_BORIZES_3258325603896619684)],
        &[(0b01001, &ENTRY_BORIZE_9924789501684223687)],
        &[(0b01001, &ENTRY_BORIZES_3258325603896619684)],
    ],
    range: 1..=5,
};

static VARS_BON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BON_CHILDREN),
    value: None,
};

pub static VARS_BON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("derise"),
        dictgen::InsensitiveStr::Ascii("derize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BONDERIZE_15354415413556562398)],
        &[(0b01001, &ENTRY_BONDERIZE_15354415413556562398)],
    ],
    range: 6..=6,
};

static VARS_BOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOL_CHILDREN),
    value: None,
};

pub static VARS_BOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("oed"),
        dictgen::InsensitiveStr::Ascii("shevise"),
        dictgen::InsensitiveStr::Ascii("shevised"),
        dictgen::InsensitiveStr::Ascii("shevises"),
        dictgen::InsensitiveStr::Ascii("shevising"),
        dictgen::InsensitiveStr::Ascii("shevize"),
        dictgen::InsensitiveStr::Ascii("shevized"),
        dictgen::InsensitiveStr::Ascii("shevizes"),
        dictgen::InsensitiveStr::Ascii("shevizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BOLED_15727675082763127085)],
        &[(0b11010, &ENTRY_BOLED_15727675082763127085)],
        &[(0b10010, &ENTRY_BOLSHEVIZE_7610322087100944959)],
        &[(0b10010, &ENTRY_BOLSHEVIZED_6673756303297064763)],
        &[(0b10010, &ENTRY_BOLSHEVIZES_6863516990622262590)],
        &[(0b10010, &ENTRY_BOLSHEVIZING_18292009629655495635)],
        &[(0b01001, &ENTRY_BOLSHEVIZE_7610322087100944959)],
        &[(0b01001, &ENTRY_BOLSHEVIZED_6673756303297064763)],
        &[(0b01001, &ENTRY_BOLSHEVIZES_6863516990622262590)],
        &[(0b01001, &ENTRY_BOLSHEVIZING_18292009629655495635)],
    ],
    range: 2..=9,
};

static VARS_BOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOE_CHILDREN),
    value: None,
};

pub static VARS_BOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dromius"),
        dictgen::InsensitiveStr::Ascii("hmenism"),
        dictgen::InsensitiveStr::Ascii("hmenist"),
        dictgen::InsensitiveStr::Ascii("hmenite"),
        dictgen::InsensitiveStr::Ascii("lter"),
        dictgen::InsensitiveStr::Ascii("lus"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BOEDROMIUS_9842947399769548785)],
        &[(0b11010, &ENTRY_BEHMENISM_499620659693586399)],
        &[(0b11010, &ENTRY_BEHMENIST_10750646406222017241)],
        &[(0b11010, &ENTRY_BEHMENITE_12524739850869681953)],
        &[(0b11010, &ENTRY_BELTER_13842923605697161200)],
        &[(0b11010, &ENTRY_BELUS_4746563664174667391)],
    ],
    range: 3..=7,
};

static VARS_BOA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOA_CHILDREN),
    value: None,
};

pub static VARS_BOA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("edromius")],
    values: &[&[(0b11010, &ENTRY_BOEDROMIUS_9842947399769548785)]],
    range: 8..=8,
};

static VARS_BL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BL_CHILDREN),
    value: None,
};

pub static VARS_BL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aise"),
        dictgen::InsensitiveStr::Ascii("aize"),
        dictgen::InsensitiveStr::Ascii("amable"),
        dictgen::InsensitiveStr::Ascii("astocele"),
        dictgen::InsensitiveStr::Ascii("astocoele"),
        dictgen::InsensitiveStr::Ascii("astulae"),
        dictgen::InsensitiveStr::Ascii("astule"),
        dictgen::InsensitiveStr::Ascii("ennemesis"),
        dictgen::InsensitiveStr::Ascii("ennoemesis"),
        dictgen::InsensitiveStr::Ascii("ennorrhea"),
        dictgen::InsensitiveStr::Ascii("ennorrhoea"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BLAIZE_8547731719648738728)],
        &[(0b01001, &ENTRY_BLAIZE_8547731719648738728)],
        &[(0b01001, &ENTRY_BLAMABLE_2805926222821580419)],
        &[(0b00001, &ENTRY_BLASTOCELE_16551234140115187761)],
        &[(0b11010, &ENTRY_BLASTOCELE_16551234140115187761)],
        &[(0b11010, &ENTRY_BLASTULE_17366628524335612541)],
        &[(0b00001, &ENTRY_BLASTULE_17366628524335612541)],
        &[(0b00001, &ENTRY_BLENNEMESIS_12539251866010589867)],
        &[(0b11010, &ENTRY_BLENNEMESIS_12539251866010589867)],
        &[(0b10001, &ENTRY_BLENNORRHEA_14826876051258215048)],
        &[(0b11010, &ENTRY_BLENNORRHEA_14826876051258215048)],
    ],
    range: 4..=10,
};

static VARS_BI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_BI_CHILDREN),
    value: None,
};

static VARS_BI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_BIA_NODE),
    None,
    Some(&VARS_BIC_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_BIM_NODE),
    Some(&VARS_BIN_NODE),
    Some(&VARS_BIO_NODE),
    Some(&VARS_BIP_NODE),
    None,
    Some(&VARS_BIR_NODE),
    Some(&VARS_BIS_NODE),
    Some(&VARS_BIT_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_BIZ_NODE),
];

static VARS_BIZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIZ_CHILDREN),
    value: None,
};

pub static VARS_BIZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("et"),
    ],
    values: &[
        &[(0b01001, &ENTRY_BIZE_1335352806591900703)],
        &[(0b01001, &ENTRY_BIZET_12028529403609023964)],
    ],
    range: 1..=2,
};

static VARS_BIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIT_CHILDREN),
    value: None,
};

pub static VARS_BIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tor"),
        dictgen::InsensitiveStr::Ascii("tors"),
        dictgen::InsensitiveStr::Ascii("tour"),
        dictgen::InsensitiveStr::Ascii("tours"),
        dictgen::InsensitiveStr::Ascii("uminisation"),
        dictgen::InsensitiveStr::Ascii("uminisations"),
        dictgen::InsensitiveStr::Ascii("uminise"),
        dictgen::InsensitiveStr::Ascii("uminised"),
        dictgen::InsensitiveStr::Ascii("uminises"),
        dictgen::InsensitiveStr::Ascii("uminising"),
        dictgen::InsensitiveStr::Ascii("uminization"),
        dictgen::InsensitiveStr::Ascii("uminizations"),
        dictgen::InsensitiveStr::Ascii("uminize"),
        dictgen::InsensitiveStr::Ascii("uminized"),
        dictgen::InsensitiveStr::Ascii("uminizes"),
        dictgen::InsensitiveStr::Ascii("uminizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BITTOR_368699142304285977)],
        &[(0b00001, &ENTRY_BITTORS_588301274153684456)],
        &[(0b11010, &ENTRY_BITTOR_368699142304285977)],
        &[(0b11010, &ENTRY_BITTORS_588301274153684456)],
        &[(0b10010, &ENTRY_BITUMINIZATION_9078464743577202911)],
        &[(0b10010, &ENTRY_BITUMINIZATIONS_8741287605557295138)],
        &[(0b10010, &ENTRY_BITUMINIZE_16758630164312898422)],
        &[(0b10010, &ENTRY_BITUMINIZED_17383991200267975906)],
        &[(0b10010, &ENTRY_BITUMINIZES_18048041187765144366)],
        &[(0b10010, &ENTRY_BITUMINIZING_16243512789065027030)],
        &[(0b01001, &ENTRY_BITUMINIZATION_9078464743577202911)],
        &[(0b01001, &ENTRY_BITUMINIZATIONS_8741287605557295138)],
        &[(0b01001, &ENTRY_BITUMINIZE_16758630164312898422)],
        &[(0b01001, &ENTRY_BITUMINIZED_17383991200267975906)],
        &[(0b01001, &ENTRY_BITUMINIZES_18048041187765144366)],
        &[(0b01001, &ENTRY_BITUMINIZING_16243512789065027030)],
    ],
    range: 3..=12,
};

static VARS_BIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIS_CHILDREN),
    value: None,
};

pub static VARS_BIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("et"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tered"),
        dictgen::InsensitiveStr::Ascii("teredder"),
        dictgen::InsensitiveStr::Ascii("tereddest"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tred"),
        dictgen::InsensitiveStr::Ascii("tredder"),
        dictgen::InsensitiveStr::Ascii("treddest"),
        dictgen::InsensitiveStr::Ascii("tres"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BIZE_1335352806591900703)],
        &[(0b10010, &ENTRY_BIZET_12028529403609023964)],
        &[(0b01001, &ENTRY_BISTER_10449402161913041976)],
        &[(0b00001, &ENTRY_BISTERED_17553715744088785419)],
        &[(0b00001, &ENTRY_BISTEREDDER_3060766173300916233)],
        &[(0b00001, &ENTRY_BISTEREDDEST_11484996203378675073)],
        &[(0b01001, &ENTRY_BISTERS_7831835768196639468)],
        &[(0b11010, &ENTRY_BISTER_10449402161913041976)],
        &[(0b11010, &ENTRY_BISTERED_17553715744088785419)],
        &[(0b11010, &ENTRY_BISTEREDDER_3060766173300916233)],
        &[(0b11010, &ENTRY_BISTEREDDEST_11484996203378675073)],
        &[(0b11010, &ENTRY_BISTERS_7831835768196639468)],
    ],
    range: 1..=9,
};

static VARS_BIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIR_CHILDREN),
    value: None,
};

pub static VARS_BIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("minghamise"),
        dictgen::InsensitiveStr::Ascii("minghamises"),
        dictgen::InsensitiveStr::Ascii("minghamize"),
        dictgen::InsensitiveStr::Ascii("minghamizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BIRMINGHAMIZE_7467133353308120939)],
        &[(0b10010, &ENTRY_BIRMINGHAMIZES_7283882146218203623)],
        &[(0b01001, &ENTRY_BIRMINGHAMIZE_7467133353308120939)],
        &[(0b01001, &ENTRY_BIRMINGHAMIZES_7283882146218203623)],
    ],
    range: 10..=11,
};

static VARS_BIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIP_CHILDREN),
    value: None,
};

pub static VARS_BIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olarisation"),
        dictgen::InsensitiveStr::Ascii("olarise"),
        dictgen::InsensitiveStr::Ascii("olarises"),
        dictgen::InsensitiveStr::Ascii("olarization"),
        dictgen::InsensitiveStr::Ascii("olarize"),
        dictgen::InsensitiveStr::Ascii("olarizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BIPOLARIZATION_12827101324489098880)],
        &[(0b10010, &ENTRY_BIPOLARIZE_701724772574228652)],
        &[(0b10010, &ENTRY_BIPOLARIZES_753154636413500379)],
        &[(0b01001, &ENTRY_BIPOLARIZATION_12827101324489098880)],
        &[(0b01001, &ENTRY_BIPOLARIZE_701724772574228652)],
        &[(0b01001, &ENTRY_BIPOLARIZES_753154636413500379)],
    ],
    range: 7..=11,
};

static VARS_BIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIO_CHILDREN),
    value: None,
};

pub static VARS_BIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cenology"),
        dictgen::InsensitiveStr::Ascii("cenose"),
        dictgen::InsensitiveStr::Ascii("cenoses"),
        dictgen::InsensitiveStr::Ascii("cenosis"),
        dictgen::InsensitiveStr::Ascii("cenotic"),
        dictgen::InsensitiveStr::Ascii("coenology"),
        dictgen::InsensitiveStr::Ascii("coenose"),
        dictgen::InsensitiveStr::Ascii("coenoses"),
        dictgen::InsensitiveStr::Ascii("coenosis"),
        dictgen::InsensitiveStr::Ascii("coenotic"),
        dictgen::InsensitiveStr::Ascii("graphise"),
        dictgen::InsensitiveStr::Ascii("graphises"),
        dictgen::InsensitiveStr::Ascii("graphize"),
        dictgen::InsensitiveStr::Ascii("graphizes"),
        dictgen::InsensitiveStr::Ascii("logise"),
        dictgen::InsensitiveStr::Ascii("logises"),
        dictgen::InsensitiveStr::Ascii("logize"),
        dictgen::InsensitiveStr::Ascii("logizes"),
        dictgen::InsensitiveStr::Ascii("synthesised"),
        dictgen::InsensitiveStr::Ascii("synthesized"),
    ],
    values: &[
        &[(0b10001, &ENTRY_BIOCENOLOGY_4739588156815290106)],
        &[(0b10001, &ENTRY_BIOCENOSE_7354639313277820088)],
        &[(0b10001, &ENTRY_BIOCENOSES_16420882441598629495)],
        &[(0b10001, &ENTRY_BIOCENOSIS_12225043537756921240)],
        &[(0b10001, &ENTRY_BIOCENOTIC_2832610417337579792)],
        &[(0b11010, &ENTRY_BIOCENOLOGY_4739588156815290106)],
        &[(0b11010, &ENTRY_BIOCENOSE_7354639313277820088)],
        &[(0b11010, &ENTRY_BIOCENOSES_16420882441598629495)],
        &[(0b11010, &ENTRY_BIOCENOSIS_12225043537756921240)],
        &[(0b11010, &ENTRY_BIOCENOTIC_2832610417337579792)],
        &[(0b10010, &ENTRY_BIOGRAPHIZE_13042383107956929589)],
        &[(0b10010, &ENTRY_BIOGRAPHIZES_15117176767822609083)],
        &[(0b01001, &ENTRY_BIOGRAPHIZE_13042383107956929589)],
        &[(0b01001, &ENTRY_BIOGRAPHIZES_15117176767822609083)],
        &[(0b10010, &ENTRY_BIOLOGIZE_2366287950194440069)],
        &[(0b10010, &ENTRY_BIOLOGIZES_7227182445438079686)],
        &[(0b01001, &ENTRY_BIOLOGIZE_2366287950194440069)],
        &[(0b01001, &ENTRY_BIOLOGIZES_7227182445438079686)],
        &[(0b10010, &ENTRY_BIOSYNTHESIZED_4565096183549369524)],
        &[(0b01001, &ENTRY_BIOSYNTHESIZED_4565096183549369524)],
    ],
    range: 6..=11,
};

static VARS_BIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIN_CHILDREN),
    value: None,
};

pub static VARS_BIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ging")],
    values: &[&[(0b00001, &ENTRY_BINGEING_178843586653742040)]],
    range: 4..=4,
};

static VARS_BIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIM_CHILDREN),
    value: None,
};

pub static VARS_BIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etalist"),
        dictgen::InsensitiveStr::Ascii("etalistic"),
        dictgen::InsensitiveStr::Ascii("etallist"),
        dictgen::InsensitiveStr::Ascii("etallistic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BIMETALIST_3660339346809516859)],
        &[(0b00001, &ENTRY_BIMETALISTIC_5316771108471812616)],
        &[(0b11010, &ENTRY_BIMETALIST_3660339346809516859)],
        &[(0b11010, &ENTRY_BIMETALISTIC_5316771108471812616)],
    ],
    range: 7..=10,
};

static VARS_BIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIC_CHILDREN),
    value: None,
};

pub static VARS_BIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hromatise"),
        dictgen::InsensitiveStr::Ascii("hromatises"),
        dictgen::InsensitiveStr::Ascii("hromatize"),
        dictgen::InsensitiveStr::Ascii("hromatizes"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("oloredder"),
        dictgen::InsensitiveStr::Ascii("oloreddest"),
        dictgen::InsensitiveStr::Ascii("olorous"),
        dictgen::InsensitiveStr::Ascii("olorrer"),
        dictgen::InsensitiveStr::Ascii("olorrest"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olouredder"),
        dictgen::InsensitiveStr::Ascii("oloureddest"),
        dictgen::InsensitiveStr::Ascii("olourer"),
        dictgen::InsensitiveStr::Ascii("olourest"),
        dictgen::InsensitiveStr::Ascii("olourous"),
        dictgen::InsensitiveStr::Ascii("olours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BICHROMATIZE_14037731889057409317)],
        &[(0b10010, &ENTRY_BICHROMATIZES_7036743462950211626)],
        &[(0b01001, &ENTRY_BICHROMATIZE_14037731889057409317)],
        &[(0b01001, &ENTRY_BICHROMATIZES_7036743462950211626)],
        &[(0b10001, &ENTRY_BICOLOR_9128517208708095659)],
        &[(0b10001, &ENTRY_BICOLORED_17289525053828674330)],
        &[(0b10001, &ENTRY_BICOLOREDDER_551370085079086375)],
        &[(0b10001, &ENTRY_BICOLOREDDEST_14358517370132765122)],
        &[(0b00001, &ENTRY_BICOLOROUS_6102303766253637672)],
        &[(0b10001, &ENTRY_BICOLORRER_14811846069806102443)],
        &[(0b10001, &ENTRY_BICOLORREST_17887654307497270458)],
        &[(0b10001, &ENTRY_BICOLORS_9018286664967288585)],
        &[(0b11010, &ENTRY_BICOLOR_9128517208708095659)],
        &[(0b11010, &ENTRY_BICOLORED_17289525053828674330)],
        &[(0b11010, &ENTRY_BICOLOREDDER_551370085079086375)],
        &[(0b11010, &ENTRY_BICOLOREDDEST_14358517370132765122)],
        &[(0b11010, &ENTRY_BICOLORRER_14811846069806102443)],
        &[(0b11010, &ENTRY_BICOLORREST_17887654307497270458)],
        &[(0b11010, &ENTRY_BICOLOROUS_6102303766253637672)],
        &[(0b11010, &ENTRY_BICOLORS_9018286664967288585)],
    ],
    range: 4..=11,
};

static VARS_BIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIA_CHILDREN),
    value: None,
};

pub static VARS_BIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ssed"),
        dictgen::InsensitiveStr::Ascii("ssing"),
    ],
    values: &[
        &[(0b10011, &ENTRY_BIASED_15079696021925521823)],
        &[(0b10011, &ENTRY_BIASING_18108238854297339846)],
    ],
    range: 4..=5,
};

static VARS_BE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_BE_CHILDREN),
    value: None,
};

static VARS_BE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_BEA_NODE),
    None,
    Some(&VARS_BEC_NODE),
    Some(&VARS_BED_NODE),
    Some(&VARS_BEE_NODE),
    Some(&VARS_BEF_NODE),
    Some(&VARS_BEG_NODE),
    Some(&VARS_BEH_NODE),
    None,
    Some(&VARS_BEJ_NODE),
    None,
    Some(&VARS_BEL_NODE),
    Some(&VARS_BEM_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_BER_NODE),
    Some(&VARS_BES_NODE),
    None,
    None,
    Some(&VARS_BEV_NODE),
    None,
    None,
    Some(&VARS_BEY_NODE),
    None,
];

static VARS_BEY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEY_CHILDREN),
    value: None,
};

pub static VARS_BEY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("er")],
    values: &[&[(0b00001, &ENTRY_BEYER_9811279797880466647)]],
    range: 2..=2,
};

static VARS_BEV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEV_CHILDREN),
    value: None,
};

pub static VARS_BEV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
    ],
    values: &[
        &[(0b01001, &ENTRY_BEVELED_10378533536024013853)],
        &[(0b01001, &ENTRY_BEVELER_2498982223785959149)],
        &[(0b01001, &ENTRY_BEVELERS_1892360606418032248)],
        &[(0b01001, &ENTRY_BEVELING_2110798044912558228)],
        &[(0b01001, &ENTRY_BEVELINGS_1501034049167710764)],
        &[(0b11010, &ENTRY_BEVELED_10378533536024013853)],
        &[(0b11010, &ENTRY_BEVELER_2498982223785959149)],
        &[(0b11010, &ENTRY_BEVELERS_1892360606418032248)],
        &[(0b11010, &ENTRY_BEVELING_2110798044912558228)],
        &[(0b11010, &ENTRY_BEVELINGS_1501034049167710764)],
    ],
    range: 4..=7,
};

static VARS_BES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BES_CHILDREN),
    value: None,
};

pub static VARS_BES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("semerise"),
        dictgen::InsensitiveStr::Ascii("semerises"),
        dictgen::InsensitiveStr::Ascii("semerize"),
        dictgen::InsensitiveStr::Ascii("semerizes"),
        dictgen::InsensitiveStr::Ascii("tialise"),
        dictgen::InsensitiveStr::Ascii("tialised"),
        dictgen::InsensitiveStr::Ascii("tialises"),
        dictgen::InsensitiveStr::Ascii("tialising"),
        dictgen::InsensitiveStr::Ascii("tialize"),
        dictgen::InsensitiveStr::Ascii("tialized"),
        dictgen::InsensitiveStr::Ascii("tializes"),
        dictgen::InsensitiveStr::Ascii("tializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BESSEMERIZE_18021306106963646896)],
        &[(0b10010, &ENTRY_BESSEMERIZES_6933758975628828592)],
        &[(0b01001, &ENTRY_BESSEMERIZE_18021306106963646896)],
        &[(0b01001, &ENTRY_BESSEMERIZES_6933758975628828592)],
        &[(0b10010, &ENTRY_BESTIALIZE_13174936385032065942)],
        &[(0b10010, &ENTRY_BESTIALIZED_15762278423047666998)],
        &[(0b10010, &ENTRY_BESTIALIZES_16507878437433357608)],
        &[(0b10010, &ENTRY_BESTIALIZING_10183591289011144098)],
        &[(0b01001, &ENTRY_BESTIALIZE_13174936385032065942)],
        &[(0b01001, &ENTRY_BESTIALIZED_15762278423047666998)],
        &[(0b01001, &ENTRY_BESTIALIZES_16507878437433357608)],
        &[(0b01001, &ENTRY_BESTIALIZING_10183591289011144098)],
    ],
    range: 7..=9,
};

static VARS_BER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BER_CHILDREN),
    value: None,
};

pub static VARS_BER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("ia"),
        dictgen::InsensitiveStr::Ascii("l"),
        dictgen::InsensitiveStr::Ascii("linise"),
        dictgen::InsensitiveStr::Ascii("linises"),
        dictgen::InsensitiveStr::Ascii("linize"),
        dictgen::InsensitiveStr::Ascii("linizes"),
        dictgen::InsensitiveStr::Ascii("loque"),
        dictgen::InsensitiveStr::Ascii("me"),
        dictgen::InsensitiveStr::Ascii("n"),
    ],
    values: &[
        &[(0b11010, &ENTRY_BEERA_15480986539449585414)],
        &[(0b00001, &ENTRY_BERIA_819349540939304958)],
        &[(0b00001, &ENTRY_BERL_14276132883073000569)],
        &[(0b10010, &ENTRY_BERLINIZE_3186846671412575655)],
        &[(0b10010, &ENTRY_BERLINIZES_5434619462225387670)],
        &[(0b01001, &ENTRY_BERLINIZE_3186846671412575655)],
        &[(0b01001, &ENTRY_BERLINIZES_5434619462225387670)],
        &[(0b00001, &ENTRY_BERLOQUE_15524756595685455268)],
        &[(0b00001, &ENTRY_BERME_6583686006981215988)],
        &[(0b00001, &ENTRY_BERN_2039740744291479118)],
    ],
    range: 1..=7,
};

static VARS_BEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEM_CHILDREN),
    value: None,
};

pub static VARS_BEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edaled"),
        dictgen::InsensitiveStr::Ascii("edalled"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BEMEDALED_10031388746689604055)],
        &[(0b11010, &ENTRY_BEMEDALED_10031388746689604055)],
    ],
    range: 6..=7,
};

static VARS_BEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEL_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_BEL_707019223865679891)]),
};

pub static VARS_BEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abor"),
        dictgen::InsensitiveStr::Ascii("abored"),
        dictgen::InsensitiveStr::Ascii("aboring"),
        dictgen::InsensitiveStr::Ascii("abors"),
        dictgen::InsensitiveStr::Ascii("abour"),
        dictgen::InsensitiveStr::Ascii("aboured"),
        dictgen::InsensitiveStr::Ascii("abouring"),
        dictgen::InsensitiveStr::Ascii("abours"),
        dictgen::InsensitiveStr::Ascii("s"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("us"),
    ],
    values: &[
        &[(0b11001, &ENTRY_BELABOR_2245031289291089410)],
        &[(0b11001, &ENTRY_BELABORED_14959360057364846988)],
        &[(0b11001, &ENTRY_BELABORING_16550814486427716841)],
        &[(0b11001, &ENTRY_BELABORS_9616903556092237149)],
        &[(0b11010, &ENTRY_BELABOR_2245031289291089410)],
        &[(0b11010, &ENTRY_BELABORED_14959360057364846988)],
        &[(0b11010, &ENTRY_BELABORING_16550814486427716841)],
        &[(0b11010, &ENTRY_BELABORS_9616903556092237149)],
        &[(0b00001, &ENTRY_BELS_2245276628470254292)],
        &[(0b00001, &ENTRY_BELTER_13842923605697161200)],
        &[(0b00001, &ENTRY_BELUS_4746563664174667391)],
    ],
    range: 1..=8,
};

static VARS_BEJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEJ_CHILDREN),
    value: None,
};

pub static VARS_BEJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eweled"),
        dictgen::InsensitiveStr::Ascii("eweling"),
        dictgen::InsensitiveStr::Ascii("ewelled"),
        dictgen::InsensitiveStr::Ascii("ewelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BEJEWELED_12216934890816407648)],
        &[(0b00001, &ENTRY_BEJEWELING_8804246701630066335)],
        &[(0b11010, &ENTRY_BEJEWELED_12216934890816407648)],
        &[(0b11010, &ENTRY_BEJEWELING_8804246701630066335)],
    ],
    range: 6..=8,
};

static VARS_BEH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEH_CHILDREN),
    value: None,
};

pub static VARS_BEH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avior"),
        dictgen::InsensitiveStr::Ascii("avioral"),
        dictgen::InsensitiveStr::Ascii("avioraler"),
        dictgen::InsensitiveStr::Ascii("avioralest"),
        dictgen::InsensitiveStr::Ascii("aviorally"),
        dictgen::InsensitiveStr::Ascii("aviored"),
        dictgen::InsensitiveStr::Ascii("aviorism"),
        dictgen::InsensitiveStr::Ascii("aviorisms"),
        dictgen::InsensitiveStr::Ascii("aviorist"),
        dictgen::InsensitiveStr::Ascii("avioristic"),
        dictgen::InsensitiveStr::Ascii("avioristicer"),
        dictgen::InsensitiveStr::Ascii("avioristicest"),
        dictgen::InsensitiveStr::Ascii("avioristics"),
        dictgen::InsensitiveStr::Ascii("aviorists"),
        dictgen::InsensitiveStr::Ascii("aviors"),
        dictgen::InsensitiveStr::Ascii("aviour"),
        dictgen::InsensitiveStr::Ascii("avioural"),
        dictgen::InsensitiveStr::Ascii("aviouraler"),
        dictgen::InsensitiveStr::Ascii("aviouralest"),
        dictgen::InsensitiveStr::Ascii("aviourally"),
        dictgen::InsensitiveStr::Ascii("avioured"),
        dictgen::InsensitiveStr::Ascii("aviourism"),
        dictgen::InsensitiveStr::Ascii("aviourisms"),
        dictgen::InsensitiveStr::Ascii("aviourist"),
        dictgen::InsensitiveStr::Ascii("aviouristic"),
        dictgen::InsensitiveStr::Ascii("aviouristicer"),
        dictgen::InsensitiveStr::Ascii("aviouristicest"),
        dictgen::InsensitiveStr::Ascii("aviouristics"),
        dictgen::InsensitiveStr::Ascii("aviourists"),
        dictgen::InsensitiveStr::Ascii("aviours"),
        dictgen::InsensitiveStr::Ascii("menism"),
        dictgen::InsensitiveStr::Ascii("menist"),
        dictgen::InsensitiveStr::Ascii("menite"),
        dictgen::InsensitiveStr::Ascii("oove"),
        dictgen::InsensitiveStr::Ascii("ooved"),
        dictgen::InsensitiveStr::Ascii("ooves"),
        dictgen::InsensitiveStr::Ascii("ooving"),
        dictgen::InsensitiveStr::Ascii("oovingly"),
        dictgen::InsensitiveStr::Ascii("oovings"),
        dictgen::InsensitiveStr::Ascii("ove"),
        dictgen::InsensitiveStr::Ascii("oved"),
        dictgen::InsensitiveStr::Ascii("oves"),
        dictgen::InsensitiveStr::Ascii("oving"),
        dictgen::InsensitiveStr::Ascii("ovingly"),
        dictgen::InsensitiveStr::Ascii("ovings"),
    ],
    values: &[
        &[(0b11001, &ENTRY_BEHAVIOR_4270292057978962250)],
        &[(0b11001, &ENTRY_BEHAVIORAL_1668398487637965302)],
        &[(0b11001, &ENTRY_BEHAVIORALER_15849878698882095342)],
        &[(0b11001, &ENTRY_BEHAVIORALEST_4676686848581067810)],
        &[(0b11001, &ENTRY_BEHAVIORALLY_15603975909970219512)],
        &[(0b11001, &ENTRY_BEHAVIORED_329942682848905839)],
        &[(0b11001, &ENTRY_BEHAVIORISM_16788531821804542526)],
        &[(0b11001, &ENTRY_BEHAVIORISMS_18431005634091902550)],
        &[(0b11001, &ENTRY_BEHAVIORIST_538165502271076270)],
        &[(0b11001, &ENTRY_BEHAVIORISTIC_10912467475164998417)],
        &[(0b11001, &ENTRY_BEHAVIORISTICER_1771754648963132210)],
        &[(0b11001, &ENTRY_BEHAVIORISTICEST_13940464183699495590)],
        &[(0b11001, &ENTRY_BEHAVIORISTICS_9644519070934483422)],
        &[(0b11001, &ENTRY_BEHAVIORISTS_2791913883690306158)],
        &[(0b11001, &ENTRY_BEHAVIORS_17740975427353098200)],
        &[(0b11010, &ENTRY_BEHAVIOR_4270292057978962250)],
        &[(0b11010, &ENTRY_BEHAVIORAL_1668398487637965302)],
        &[(0b11010, &ENTRY_BEHAVIORALER_15849878698882095342)],
        &[(0b11010, &ENTRY_BEHAVIORALEST_4676686848581067810)],
        &[(0b11010, &ENTRY_BEHAVIORALLY_15603975909970219512)],
        &[(0b11010, &ENTRY_BEHAVIORED_329942682848905839)],
        &[(0b11010, &ENTRY_BEHAVIORISM_16788531821804542526)],
        &[(0b11010, &ENTRY_BEHAVIORISMS_18431005634091902550)],
        &[(0b11010, &ENTRY_BEHAVIORIST_538165502271076270)],
        &[(0b11010, &ENTRY_BEHAVIORISTIC_10912467475164998417)],
        &[(0b11010, &ENTRY_BEHAVIORISTICER_1771754648963132210)],
        &[(0b11010, &ENTRY_BEHAVIORISTICEST_13940464183699495590)],
        &[(0b11010, &ENTRY_BEHAVIORISTICS_9644519070934483422)],
        &[(0b11010, &ENTRY_BEHAVIORISTS_2791913883690306158)],
        &[(0b11010, &ENTRY_BEHAVIORS_17740975427353098200)],
        &[(0b00001, &ENTRY_BEHMENISM_499620659693586399)],
        &[(0b00001, &ENTRY_BEHMENIST_10750646406222017241)],
        &[(0b00001, &ENTRY_BEHMENITE_12524739850869681953)],
        &[(0b01001, &ENTRY_BEHOOVE_15601060046872655911)],
        &[(0b01001, &ENTRY_BEHOOVED_19557981828125274)],
        &[(0b01001, &ENTRY_BEHOOVES_18171198361790854374)],
        &[(0b01001, &ENTRY_BEHOOVING_8542587834338786394)],
        &[(0b00001, &ENTRY_BEHOOVINGLY_16685473934888809657)],
        &[(0b01001, &ENTRY_BEHOOVINGS_5611929196356326751)],
        &[(0b10010, &ENTRY_BEHOOVE_15601060046872655911)],
        &[(0b10010, &ENTRY_BEHOOVED_19557981828125274)],
        &[(0b10010, &ENTRY_BEHOOVES_18171198361790854374)],
        &[(0b10010, &ENTRY_BEHOOVING_8542587834338786394)],
        &[(0b11010, &ENTRY_BEHOOVINGLY_16685473934888809657)],
        &[(0b10010, &ENTRY_BEHOOVINGS_5611929196356326751)],
    ],
    range: 3..=14,
};

static VARS_BEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEG_CHILDREN),
    value: None,
};

pub static VARS_BEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lamor"),
        dictgen::InsensitiveStr::Ascii("lamored"),
        dictgen::InsensitiveStr::Ascii("lamoring"),
        dictgen::InsensitiveStr::Ascii("lamors"),
        dictgen::InsensitiveStr::Ascii("lamour"),
        dictgen::InsensitiveStr::Ascii("lamoured"),
        dictgen::InsensitiveStr::Ascii("lamouring"),
        dictgen::InsensitiveStr::Ascii("lamours"),
    ],
    values: &[
        &[(0b10001, &ENTRY_BEGLAMOR_1703384101008507708)],
        &[(0b10001, &ENTRY_BEGLAMORED_3590724218188773450)],
        &[(0b10001, &ENTRY_BEGLAMORING_7478888583297948139)],
        &[(0b10001, &ENTRY_BEGLAMORS_10592558109463498103)],
        &[(0b11010, &ENTRY_BEGLAMOR_1703384101008507708)],
        &[(0b11010, &ENTRY_BEGLAMORED_3590724218188773450)],
        &[(0b11010, &ENTRY_BEGLAMORING_7478888583297948139)],
        &[(0b11010, &ENTRY_BEGLAMORS_10592558109463498103)],
    ],
    range: 5..=9,
};

static VARS_BEF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEF_CHILDREN),
    value: None,
};

pub static VARS_BEF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avor"),
        dictgen::InsensitiveStr::Ascii("avour"),
    ],
    values: &[
        &[(0b10001, &ENTRY_BEFAVOR_65413849177555799)],
        &[(0b11010, &ENTRY_BEFAVOR_65413849177555799)],
    ],
    range: 4..=5,
};

static VARS_BEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEE_CHILDREN),
    value: None,
};

pub static VARS_BEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ra")],
    values: &[&[(0b00001, &ENTRY_BEERA_15480986539449585414)]],
    range: 2..=2,
};

static VARS_BED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BED_CHILDREN),
    value: None,
};

pub static VARS_BED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eviled"),
        dictgen::InsensitiveStr::Ascii("eviling"),
        dictgen::InsensitiveStr::Ascii("evilled"),
        dictgen::InsensitiveStr::Ascii("evilling"),
        dictgen::InsensitiveStr::Ascii("lamise"),
        dictgen::InsensitiveStr::Ascii("lamised"),
        dictgen::InsensitiveStr::Ascii("lamises"),
        dictgen::InsensitiveStr::Ascii("lamising"),
        dictgen::InsensitiveStr::Ascii("lamize"),
        dictgen::InsensitiveStr::Ascii("lamized"),
        dictgen::InsensitiveStr::Ascii("lamizes"),
        dictgen::InsensitiveStr::Ascii("lamizing"),
        dictgen::InsensitiveStr::Ascii("riveled"),
        dictgen::InsensitiveStr::Ascii("riveling"),
        dictgen::InsensitiveStr::Ascii("rivelled"),
        dictgen::InsensitiveStr::Ascii("rivelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BEDEVILED_11085714010658112928)],
        &[(0b00001, &ENTRY_BEDEVILING_10442109879718503775)],
        &[(0b11010, &ENTRY_BEDEVILED_11085714010658112928)],
        &[(0b11010, &ENTRY_BEDEVILING_10442109879718503775)],
        &[(0b10010, &ENTRY_BEDLAMIZE_12750005417077248018)],
        &[(0b10010, &ENTRY_BEDLAMIZED_14377714649143763251)],
        &[(0b10010, &ENTRY_BEDLAMIZES_18120257641318026287)],
        &[(0b10010, &ENTRY_BEDLAMIZING_12768565666893232436)],
        &[(0b01001, &ENTRY_BEDLAMIZE_12750005417077248018)],
        &[(0b01001, &ENTRY_BEDLAMIZED_14377714649143763251)],
        &[(0b01001, &ENTRY_BEDLAMIZES_18120257641318026287)],
        &[(0b01001, &ENTRY_BEDLAMIZING_12768565666893232436)],
        &[(0b00001, &ENTRY_BEDRIVELED_5247906579362000273)],
        &[(0b00001, &ENTRY_BEDRIVELING_10705854559276626799)],
        &[(0b11010, &ENTRY_BEDRIVELED_5247906579362000273)],
        &[(0b11010, &ENTRY_BEDRIVELING_10705854559276626799)],
    ],
    range: 6..=9,
};

static VARS_BEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEC_CHILDREN),
    value: None,
};

pub static VARS_BEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lamor"),
        dictgen::InsensitiveStr::Ascii("lamored"),
        dictgen::InsensitiveStr::Ascii("lamoring"),
        dictgen::InsensitiveStr::Ascii("lamors"),
        dictgen::InsensitiveStr::Ascii("lamour"),
        dictgen::InsensitiveStr::Ascii("lamoured"),
        dictgen::InsensitiveStr::Ascii("lamouring"),
        dictgen::InsensitiveStr::Ascii("lamours"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("udgeled"),
        dictgen::InsensitiveStr::Ascii("udgeling"),
        dictgen::InsensitiveStr::Ascii("udgelled"),
        dictgen::InsensitiveStr::Ascii("udgelling"),
    ],
    values: &[
        &[(0b10001, &ENTRY_BECLAMOR_13213568046754787546)],
        &[(0b10001, &ENTRY_BECLAMORED_17389757210006732941)],
        &[(0b10001, &ENTRY_BECLAMORING_88231575150843084)],
        &[(0b10001, &ENTRY_BECLAMORS_4938562224073978012)],
        &[(0b11010, &ENTRY_BECLAMOR_13213568046754787546)],
        &[(0b11010, &ENTRY_BECLAMORED_17389757210006732941)],
        &[(0b11010, &ENTRY_BECLAMORING_88231575150843084)],
        &[(0b11010, &ENTRY_BECLAMORS_4938562224073978012)],
        &[(0b10001, &ENTRY_BECOLOR_8246072713220014687)],
        &[(0b11010, &ENTRY_BECOLOR_8246072713220014687)],
        &[(0b00001, &ENTRY_BECUDGELED_16064927883688139127)],
        &[(0b00001, &ENTRY_BECUDGELING_3635344060375013463)],
        &[(0b11010, &ENTRY_BECUDGELED_16064927883688139127)],
        &[(0b11010, &ENTRY_BECUDGELING_3635344060375013463)],
    ],
    range: 4..=9,
};

static VARS_BEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEA_CHILDREN),
    value: None,
};

pub static VARS_BEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("verise"),
        dictgen::InsensitiveStr::Ascii("verises"),
        dictgen::InsensitiveStr::Ascii("verize"),
        dictgen::InsensitiveStr::Ascii("verizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BEAVERIZE_1316372293858215780)],
        &[(0b10010, &ENTRY_BEAVERIZES_1624402153648919296)],
        &[(0b01001, &ENTRY_BEAVERIZE_1316372293858215780)],
        &[(0b01001, &ENTRY_BEAVERIZES_1624402153648919296)],
    ],
    range: 6..=7,
};

static VARS_BA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_BA_CHILDREN),
    value: None,
};

static VARS_BA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_BAB_NODE),
    Some(&VARS_BAC_NODE),
    None,
    Some(&VARS_BAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_BAL_NODE),
    None,
    Some(&VARS_BAN_NODE),
    None,
    Some(&VARS_BAP_NODE),
    None,
    Some(&VARS_BAR_NODE),
    Some(&VARS_BAS_NODE),
    Some(&VARS_BAT_NODE),
    Some(&VARS_BAU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_BAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAU_CHILDREN),
    value: None,
};

pub static VARS_BAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lk"),
        dictgen::InsensitiveStr::Ascii("lked"),
        dictgen::InsensitiveStr::Ascii("lking"),
        dictgen::InsensitiveStr::Ascii("lks"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BALK_16035479339777098788)],
        &[(0b10010, &ENTRY_BALKED_3526355814992470448)],
        &[(0b10010, &ENTRY_BALKING_8837528869624452282)],
        &[(0b10010, &ENTRY_BALKS_16564351609417220858)],
    ],
    range: 2..=5,
};

static VARS_BAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAT_CHILDREN),
    value: None,
};

pub static VARS_BAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tleax"),
        dictgen::InsensitiveStr::Ascii("tologise"),
        dictgen::InsensitiveStr::Ascii("tologised"),
        dictgen::InsensitiveStr::Ascii("tologising"),
        dictgen::InsensitiveStr::Ascii("tologize"),
        dictgen::InsensitiveStr::Ascii("tologized"),
        dictgen::InsensitiveStr::Ascii("tologizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BATTLEAXE_5257995273927790498)],
        &[(0b10010, &ENTRY_BATTOLOGIZE_6326709828418364638)],
        &[(0b10010, &ENTRY_BATTOLOGIZED_14848719392834636033)],
        &[(0b10010, &ENTRY_BATTOLOGIZING_14196182369779810637)],
        &[(0b01001, &ENTRY_BATTOLOGIZE_6326709828418364638)],
        &[(0b01001, &ENTRY_BATTOLOGIZED_14848719392834636033)],
        &[(0b01001, &ENTRY_BATTOLOGIZING_14196182369779810637)],
    ],
    range: 5..=10,
};

static VARS_BAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAS_CHILDREN),
    value: None,
};

pub static VARS_BAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tardisation"),
        dictgen::InsensitiveStr::Ascii("tardisations"),
        dictgen::InsensitiveStr::Ascii("tardise"),
        dictgen::InsensitiveStr::Ascii("tardised"),
        dictgen::InsensitiveStr::Ascii("tardises"),
        dictgen::InsensitiveStr::Ascii("tardising"),
        dictgen::InsensitiveStr::Ascii("tardization"),
        dictgen::InsensitiveStr::Ascii("tardizations"),
        dictgen::InsensitiveStr::Ascii("tardize"),
        dictgen::InsensitiveStr::Ascii("tardized"),
        dictgen::InsensitiveStr::Ascii("tardizes"),
        dictgen::InsensitiveStr::Ascii("tardizing"),
        dictgen::InsensitiveStr::Ascii("tinaded"),
        dictgen::InsensitiveStr::Ascii("tinades"),
        dictgen::InsensitiveStr::Ascii("tinadoed"),
        dictgen::InsensitiveStr::Ascii("tinadoes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BASTARDIZATION_4159983584935153450)],
        &[(0b10010, &ENTRY_BASTARDIZATIONS_3269957802823510223)],
        &[(0b10010, &ENTRY_BASTARDIZE_3932717470754109062)],
        &[(0b10010, &ENTRY_BASTARDIZED_8789832174701091014)],
        &[(0b10010, &ENTRY_BASTARDIZES_4123418596066734832)],
        &[(0b10010, &ENTRY_BASTARDIZING_16141466359672648361)],
        &[(0b01001, &ENTRY_BASTARDIZATION_4159983584935153450)],
        &[(0b01001, &ENTRY_BASTARDIZATIONS_3269957802823510223)],
        &[(0b01001, &ENTRY_BASTARDIZE_3932717470754109062)],
        &[(0b01001, &ENTRY_BASTARDIZED_8789832174701091014)],
        &[(0b01001, &ENTRY_BASTARDIZES_4123418596066734832)],
        &[(0b01001, &ENTRY_BASTARDIZING_16141466359672648361)],
        &[(0b00001, &ENTRY_BASTINADED_13143614434412608155)],
        &[(0b00001, &ENTRY_BASTINADES_8442479215705679003)],
        &[(0b11010, &ENTRY_BASTINADED_13143614434412608155)],
        &[(0b11010, &ENTRY_BASTINADES_8442479215705679003)],
    ],
    range: 7..=12,
};

static VARS_BAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAR_CHILDREN),
    value: None,
};

pub static VARS_BAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("barianise"),
        dictgen::InsensitiveStr::Ascii("barianises"),
        dictgen::InsensitiveStr::Ascii("barianize"),
        dictgen::InsensitiveStr::Ascii("barianizes"),
        dictgen::InsensitiveStr::Ascii("barisation"),
        dictgen::InsensitiveStr::Ascii("barisations"),
        dictgen::InsensitiveStr::Ascii("barise"),
        dictgen::InsensitiveStr::Ascii("barised"),
        dictgen::InsensitiveStr::Ascii("barises"),
        dictgen::InsensitiveStr::Ascii("barising"),
        dictgen::InsensitiveStr::Ascii("barization"),
        dictgen::InsensitiveStr::Ascii("barizations"),
        dictgen::InsensitiveStr::Ascii("barize"),
        dictgen::InsensitiveStr::Ascii("barized"),
        dictgen::InsensitiveStr::Ascii("barizes"),
        dictgen::InsensitiveStr::Ascii("barizing"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("onetise"),
        dictgen::InsensitiveStr::Ascii("onetised"),
        dictgen::InsensitiveStr::Ascii("onetising"),
        dictgen::InsensitiveStr::Ascii("onetize"),
        dictgen::InsensitiveStr::Ascii("onetized"),
        dictgen::InsensitiveStr::Ascii("onetizing"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("reled"),
        dictgen::InsensitiveStr::Ascii("reling"),
        dictgen::InsensitiveStr::Ascii("tisan"),
        dictgen::InsensitiveStr::Ascii("tisaned"),
        dictgen::InsensitiveStr::Ascii("tisans"),
        dictgen::InsensitiveStr::Ascii("tizan"),
        dictgen::InsensitiveStr::Ascii("tizaned"),
        dictgen::InsensitiveStr::Ascii("tizans"),
        dictgen::InsensitiveStr::Ascii("ycenter"),
        dictgen::InsensitiveStr::Ascii("ycentre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BARBARIANIZE_17363551505483403455)],
        &[(0b10010, &ENTRY_BARBARIANIZES_9451438009677792437)],
        &[(0b01001, &ENTRY_BARBARIANIZE_17363551505483403455)],
        &[(0b01001, &ENTRY_BARBARIANIZES_9451438009677792437)],
        &[(0b10010, &ENTRY_BARBARIZATION_1565508341740347927)],
        &[(0b10010, &ENTRY_BARBARIZATIONS_16120039862360583028)],
        &[(0b10010, &ENTRY_BARBARIZE_11203839610503788919)],
        &[(0b10010, &ENTRY_BARBARIZED_10589089200149181973)],
        &[(0b10010, &ENTRY_BARBARIZES_11729924502589455167)],
        &[(0b10010, &ENTRY_BARBARIZING_10697728842079700750)],
        &[(0b01001, &ENTRY_BARBARIZATION_1565508341740347927)],
        &[(0b01001, &ENTRY_BARBARIZATIONS_16120039862360583028)],
        &[(0b01001, &ENTRY_BARBARIZE_11203839610503788919)],
        &[(0b01001, &ENTRY_BARBARIZED_10589089200149181973)],
        &[(0b01001, &ENTRY_BARBARIZES_11729924502589455167)],
        &[(0b01001, &ENTRY_BARBARIZING_10697728842079700750)],
        &[(0b11010, &ENTRY_BAER_6801672222137916904)],
        &[(0b10010, &ENTRY_BARONETIZE_16652294292761778174)],
        &[(0b10010, &ENTRY_BARONETIZED_8092986270823381459)],
        &[(0b10010, &ENTRY_BARONETIZING_12517588353963602947)],
        &[(0b01001, &ENTRY_BARONETIZE_16652294292761778174)],
        &[(0b01001, &ENTRY_BARONETIZED_8092986270823381459)],
        &[(0b01001, &ENTRY_BARONETIZING_12517588353963602947)],
        &[(0b10010, &ENTRY_BARONIZE_15371835358034909984)],
        &[(0b10010, &ENTRY_BARONIZES_2125070744284366847)],
        &[(0b01001, &ENTRY_BARONIZE_15371835358034909984)],
        &[(0b01001, &ENTRY_BARONIZES_2125070744284366847)],
        &[(0b00001, &ENTRY_BARRELED_14092667501559584042)],
        &[(0b00001, &ENTRY_BARRELING_14466284948340214047)],
        &[(0b10010, &ENTRY_BARTIZAN_2010969180093715656)],
        &[(0b10010, &ENTRY_BARTIZANED_2053199514898941629)],
        &[(0b10010, &ENTRY_BARTIZANS_5561585073920453699)],
        &[(0b01001, &ENTRY_BARTIZAN_2010969180093715656)],
        &[(0b01001, &ENTRY_BARTIZANED_2053199514898941629)],
        &[(0b01001, &ENTRY_BARTIZANS_5561585073920453699)],
        &[(0b00001, &ENTRY_BARYCENTER_12536678624170103346)],
        &[(0b11010, &ENTRY_BARYCENTER_12536678624170103346)],
    ],
    range: 1..=11,
};

static VARS_BAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAP_CHILDREN),
    value: None,
};

pub static VARS_BAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tisable"),
        dictgen::InsensitiveStr::Ascii("tisables"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tisement"),
        dictgen::InsensitiveStr::Ascii("tisements"),
        dictgen::InsensitiveStr::Ascii("tiser"),
        dictgen::InsensitiveStr::Ascii("tisers"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tizable"),
        dictgen::InsensitiveStr::Ascii("tizables"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizement"),
        dictgen::InsensitiveStr::Ascii("tizements"),
        dictgen::InsensitiveStr::Ascii("tizer"),
        dictgen::InsensitiveStr::Ascii("tizers"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BAPTIZABLE_13863505238468511156)],
        &[(0b10010, &ENTRY_BAPTIZABLES_14077914860012312208)],
        &[(0b10010, &ENTRY_BAPTIZE_17709364285657597325)],
        &[(0b10010, &ENTRY_BAPTIZED_3084779397484844921)],
        &[(0b10010, &ENTRY_BAPTIZEMENT_12442543968934676656)],
        &[(0b10010, &ENTRY_BAPTIZEMENTS_6705599307765015302)],
        &[(0b10010, &ENTRY_BAPTIZER_5319953109508258693)],
        &[(0b10010, &ENTRY_BAPTIZERS_17786948365777430097)],
        &[(0b10010, &ENTRY_BAPTIZES_3674202696170149073)],
        &[(0b10010, &ENTRY_BAPTIZING_4391013702348485363)],
        &[(0b01001, &ENTRY_BAPTIZABLE_13863505238468511156)],
        &[(0b01001, &ENTRY_BAPTIZABLES_14077914860012312208)],
        &[(0b01001, &ENTRY_BAPTIZE_17709364285657597325)],
        &[(0b01001, &ENTRY_BAPTIZED_3084779397484844921)],
        &[(0b01001, &ENTRY_BAPTIZEMENT_12442543968934676656)],
        &[(0b01001, &ENTRY_BAPTIZEMENTS_6705599307765015302)],
        &[(0b01001, &ENTRY_BAPTIZER_5319953109508258693)],
        &[(0b01001, &ENTRY_BAPTIZERS_17786948365777430097)],
        &[(0b01001, &ENTRY_BAPTIZES_3674202696170149073)],
        &[(0b01001, &ENTRY_BAPTIZING_4391013702348485363)],
    ],
    range: 4..=9,
};

static VARS_BAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAN_CHILDREN),
    value: None,
};

pub static VARS_BAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("tamise"),
        dictgen::InsensitiveStr::Ascii("tamises"),
        dictgen::InsensitiveStr::Ascii("tamize"),
        dictgen::InsensitiveStr::Ascii("tamizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BANALIZATION_16998614142961485820)],
        &[(0b10010, &ENTRY_BANALIZATIONS_9864795908067425875)],
        &[(0b10010, &ENTRY_BANALIZE_8060560643976337383)],
        &[(0b10010, &ENTRY_BANALIZED_9878839544450842328)],
        &[(0b10010, &ENTRY_BANALIZES_1210609160280842589)],
        &[(0b10010, &ENTRY_BANALIZING_12280357311629093499)],
        &[(0b01001, &ENTRY_BANALIZATION_16998614142961485820)],
        &[(0b01001, &ENTRY_BANALIZATIONS_9864795908067425875)],
        &[(0b01001, &ENTRY_BANALIZE_8060560643976337383)],
        &[(0b01001, &ENTRY_BANALIZED_9878839544450842328)],
        &[(0b01001, &ENTRY_BANALIZES_1210609160280842589)],
        &[(0b01001, &ENTRY_BANALIZING_12280357311629093499)],
        &[(0b10010, &ENTRY_BANTAMIZE_18144233594259187360)],
        &[(0b10010, &ENTRY_BANTAMIZES_10055099835231772607)],
        &[(0b01001, &ENTRY_BANTAMIZE_18144233594259187360)],
        &[(0b01001, &ENTRY_BANTAMIZES_10055099835231772607)],
    ],
    range: 5..=10,
};

static VARS_BAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAL_CHILDREN),
    value: None,
};

pub static VARS_BAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("kanisation"),
        dictgen::InsensitiveStr::Ascii("kanisations"),
        dictgen::InsensitiveStr::Ascii("kanise"),
        dictgen::InsensitiveStr::Ascii("kanised"),
        dictgen::InsensitiveStr::Ascii("kanises"),
        dictgen::InsensitiveStr::Ascii("kanising"),
        dictgen::InsensitiveStr::Ascii("kanization"),
        dictgen::InsensitiveStr::Ascii("kanizations"),
        dictgen::InsensitiveStr::Ascii("kanize"),
        dictgen::InsensitiveStr::Ascii("kanized"),
        dictgen::InsensitiveStr::Ascii("kanizes"),
        dictgen::InsensitiveStr::Ascii("kanizing"),
        dictgen::InsensitiveStr::Ascii("ladise"),
        dictgen::InsensitiveStr::Ascii("ladised"),
        dictgen::InsensitiveStr::Ascii("ladises"),
        dictgen::InsensitiveStr::Ascii("ladising"),
        dictgen::InsensitiveStr::Ascii("ladize"),
        dictgen::InsensitiveStr::Ascii("ladized"),
        dictgen::InsensitiveStr::Ascii("ladizes"),
        dictgen::InsensitiveStr::Ascii("ladizing"),
        dictgen::InsensitiveStr::Ascii("samise"),
        dictgen::InsensitiveStr::Ascii("samises"),
        dictgen::InsensitiveStr::Ascii("samize"),
        dictgen::InsensitiveStr::Ascii("samizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BALKANIZATION_9747896824720545908)],
        &[(0b10010, &ENTRY_BALKANIZATIONS_7005506925687374553)],
        &[(0b10010, &ENTRY_BALKANIZE_12204669760694621864)],
        &[(0b10010, &ENTRY_BALKANIZED_12279192716835695133)],
        &[(0b10010, &ENTRY_BALKANIZES_2001964342934763145)],
        &[(0b10010, &ENTRY_BALKANIZING_14076694085527168987)],
        &[(0b01001, &ENTRY_BALKANIZATION_9747896824720545908)],
        &[(0b01001, &ENTRY_BALKANIZATIONS_7005506925687374553)],
        &[(0b01001, &ENTRY_BALKANIZE_12204669760694621864)],
        &[(0b01001, &ENTRY_BALKANIZED_12279192716835695133)],
        &[(0b01001, &ENTRY_BALKANIZES_2001964342934763145)],
        &[(0b01001, &ENTRY_BALKANIZING_14076694085527168987)],
        &[(0b10010, &ENTRY_BALLADIZE_756808746628392202)],
        &[(0b10010, &ENTRY_BALLADIZED_1820750950061798946)],
        &[(0b10010, &ENTRY_BALLADIZES_10218527173082256105)],
        &[(0b10010, &ENTRY_BALLADIZING_5773113893296432935)],
        &[(0b01001, &ENTRY_BALLADIZE_756808746628392202)],
        &[(0b01001, &ENTRY_BALLADIZED_1820750950061798946)],
        &[(0b01001, &ENTRY_BALLADIZES_10218527173082256105)],
        &[(0b01001, &ENTRY_BALLADIZING_5773113893296432935)],
        &[(0b10010, &ENTRY_BALSAMIZE_12014560978856048374)],
        &[(0b10010, &ENTRY_BALSAMIZES_12017092060830247485)],
        &[(0b01001, &ENTRY_BALSAMIZE_12014560978856048374)],
        &[(0b01001, &ENTRY_BALSAMIZES_12017092060830247485)],
    ],
    range: 6..=11,
};

static VARS_BAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAE_CHILDREN),
    value: None,
};

pub static VARS_BAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("l"),
        dictgen::InsensitiveStr::Ascii("ls"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("ria"),
        dictgen::InsensitiveStr::Ascii("rl"),
        dictgen::InsensitiveStr::Ascii("yer"),
    ],
    values: &[
        &[(0b11010, &ENTRY_BEL_707019223865679891)],
        &[(0b11010, &ENTRY_BELS_2245276628470254292)],
        &[(0b00001, &ENTRY_BAER_6801672222137916904)],
        &[(0b11010, &ENTRY_BERIA_819349540939304958)],
        &[(0b11010, &ENTRY_BERL_14276132883073000569)],
        &[(0b11010, &ENTRY_BEYER_9811279797880466647)],
    ],
    range: 1..=3,
};

static VARS_BAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAC_CHILDREN),
    value: None,
};

pub static VARS_BAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("helorise"),
        dictgen::InsensitiveStr::Ascii("helorises"),
        dictgen::InsensitiveStr::Ascii("helorize"),
        dictgen::InsensitiveStr::Ascii("helorizes"),
        dictgen::InsensitiveStr::Ascii("illaemia"),
        dictgen::InsensitiveStr::Ascii("illaemias"),
        dictgen::InsensitiveStr::Ascii("illemia"),
        dictgen::InsensitiveStr::Ascii("illemias"),
        dictgen::InsensitiveStr::Ascii("kpedaled"),
        dictgen::InsensitiveStr::Ascii("kpedaling"),
        dictgen::InsensitiveStr::Ascii("kpedalled"),
        dictgen::InsensitiveStr::Ascii("kpedalling"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("teraemia"),
        dictgen::InsensitiveStr::Ascii("teraemias"),
        dictgen::InsensitiveStr::Ascii("teremia"),
        dictgen::InsensitiveStr::Ascii("teremias"),
        dictgen::InsensitiveStr::Ascii("teriaemia"),
        dictgen::InsensitiveStr::Ascii("terias"),
        dictgen::InsensitiveStr::Ascii("teriemia"),
        dictgen::InsensitiveStr::Ascii("terise"),
        dictgen::InsensitiveStr::Ascii("terised"),
        dictgen::InsensitiveStr::Ascii("terises"),
        dictgen::InsensitiveStr::Ascii("terising"),
        dictgen::InsensitiveStr::Ascii("terize"),
        dictgen::InsensitiveStr::Ascii("terized"),
        dictgen::InsensitiveStr::Ascii("terizes"),
        dictgen::InsensitiveStr::Ascii("terizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BACHELORIZE_9276026756047911374)],
        &[(0b10010, &ENTRY_BACHELORIZES_389481611658102282)],
        &[(0b01001, &ENTRY_BACHELORIZE_9276026756047911374)],
        &[(0b01001, &ENTRY_BACHELORIZES_389481611658102282)],
        &[(0b11010, &ENTRY_BACILLEMIA_6856482863549349550)],
        &[(0b11010, &ENTRY_BACILLEMIAS_12787222793673563183)],
        &[(0b10001, &ENTRY_BACILLEMIA_6856482863549349550)],
        &[(0b10001, &ENTRY_BACILLEMIAS_12787222793673563183)],
        &[(0b00001, &ENTRY_BACKPEDALED_6298147286173253590)],
        &[(0b00001, &ENTRY_BACKPEDALING_7980264040948743932)],
        &[(0b11010, &ENTRY_BACKPEDALED_6298147286173253590)],
        &[(0b11010, &ENTRY_BACKPEDALING_7980264040948743932)],
        &[(0b10010, &ENTRY_BACONIZE_9484980945125882746)],
        &[(0b10010, &ENTRY_BACONIZES_12618733997507540246)],
        &[(0b01001, &ENTRY_BACONIZE_9484980945125882746)],
        &[(0b01001, &ENTRY_BACONIZES_12618733997507540246)],
        &[(0b11010, &ENTRY_BACTEREMIA_17628282609276747504)],
        &[(0b11010, &ENTRY_BACTEREMIAS_7320892949977505735)],
        &[(0b10001, &ENTRY_BACTEREMIA_17628282609276747504)],
        &[(0b10001, &ENTRY_BACTEREMIAS_7320892949977505735)],
        &[(0b11010, &ENTRY_BACTERIEMIA_12169850297621826303)],
        &[(0b00001, &ENTRY_BACTERIA_16095578107548828853)],
        &[(0b00001, &ENTRY_BACTERIEMIA_12169850297621826303)],
        &[(0b10010, &ENTRY_BACTERIZE_2554794150826347242)],
        &[(0b10010, &ENTRY_BACTERIZED_4654231266975382567)],
        &[(0b10010, &ENTRY_BACTERIZES_11602946683696054699)],
        &[(0b10010, &ENTRY_BACTERIZING_18102823127423356275)],
        &[(0b01001, &ENTRY_BACTERIZE_2554794150826347242)],
        &[(0b01001, &ENTRY_BACTERIZED_4654231266975382567)],
        &[(0b01001, &ENTRY_BACTERIZES_11602946683696054699)],
        &[(0b01001, &ENTRY_BACTERIZING_18102823127423356275)],
    ],
    range: 5..=10,
};

static VARS_BAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAB_CHILDREN),
    value: None,
};

pub static VARS_BAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elisation"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("elising"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elizing"),
        dictgen::InsensitiveStr::Ascii("ylonise"),
        dictgen::InsensitiveStr::Ascii("ylonises"),
        dictgen::InsensitiveStr::Ascii("ylonize"),
        dictgen::InsensitiveStr::Ascii("ylonizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BABELIZATION_8763023149184870283)],
        &[(0b10010, &ENTRY_BABELIZE_4712093391684542738)],
        &[(0b10010, &ENTRY_BABELIZED_7375337936585492939)],
        &[(0b10010, &ENTRY_BABELIZING_17886762817869717286)],
        &[(0b01001, &ENTRY_BABELIZATION_8763023149184870283)],
        &[(0b01001, &ENTRY_BABELIZE_4712093391684542738)],
        &[(0b01001, &ENTRY_BABELIZED_7375337936585492939)],
        &[(0b01001, &ENTRY_BABELIZING_17886762817869717286)],
        &[(0b10010, &ENTRY_BABYLONIZE_14971641941216790519)],
        &[(0b10010, &ENTRY_BABYLONIZES_2033930356599031067)],
        &[(0b01001, &ENTRY_BABYLONIZE_14971641941216790519)],
        &[(0b01001, &ENTRY_BABYLONIZES_2033930356599031067)],
    ],
    range: 5..=9,
};

static VARS_A_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_A_CHILDREN),
    value: None,
};

static VARS_A_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_AA_NODE),
    Some(&VARS_AB_NODE),
    Some(&VARS_AC_NODE),
    Some(&VARS_AD_NODE),
    Some(&VARS_AE_NODE),
    Some(&VARS_AF_NODE),
    Some(&VARS_AG_NODE),
    None,
    Some(&VARS_AI_NODE),
    None,
    Some(&VARS_AK_NODE),
    Some(&VARS_AL_NODE),
    Some(&VARS_AM_NODE),
    Some(&VARS_AN_NODE),
    None,
    Some(&VARS_AP_NODE),
    None,
    Some(&VARS_AR_NODE),
    Some(&VARS_AS_NODE),
    Some(&VARS_AT_NODE),
    Some(&VARS_AU_NODE),
    Some(&VARS_AV_NODE),
    None,
    Some(&VARS_AX_NODE),
    None,
    Some(&VARS_AZ_NODE),
];

static VARS_AZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AZ_CHILDREN),
    value: None,
};

pub static VARS_AZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("otaemia"),
        dictgen::InsensitiveStr::Ascii("otemia"),
        dictgen::InsensitiveStr::Ascii("otisation"),
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otised"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otising"),
        dictgen::InsensitiveStr::Ascii("otization"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otized"),
        dictgen::InsensitiveStr::Ascii("otizes"),
        dictgen::InsensitiveStr::Ascii("otizing"),
        dictgen::InsensitiveStr::Ascii("otorrhea"),
        dictgen::InsensitiveStr::Ascii("otorrhoea"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AZOTEMIA_5781295612160723689)],
        &[(0b00001, &ENTRY_AZOTEMIA_5781295612160723689)],
        &[(0b10010, &ENTRY_AZOTIZATION_16751764280090329776)],
        &[(0b10010, &ENTRY_AZOTIZE_546840730893237282)],
        &[(0b10010, &ENTRY_AZOTIZED_13190991869542223480)],
        &[(0b10010, &ENTRY_AZOTIZES_3339593282352035892)],
        &[(0b10010, &ENTRY_AZOTIZING_17033259205824301048)],
        &[(0b01001, &ENTRY_AZOTIZATION_16751764280090329776)],
        &[(0b01001, &ENTRY_AZOTIZE_546840730893237282)],
        &[(0b01001, &ENTRY_AZOTIZED_13190991869542223480)],
        &[(0b01001, &ENTRY_AZOTIZES_3339593282352035892)],
        &[(0b01001, &ENTRY_AZOTIZING_17033259205824301048)],
        &[(0b00001, &ENTRY_AZOTORRHEA_5575485772910084978)],
        &[(0b11010, &ENTRY_AZOTORRHEA_5575485772910084978)],
    ],
    range: 5..=9,
};

static VARS_AX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AX_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_AX_8791902263575839056)]),
};

pub static VARS_AX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("iomatisation"),
        dictgen::InsensitiveStr::Ascii("iomatisations"),
        dictgen::InsensitiveStr::Ascii("iomatise"),
        dictgen::InsensitiveStr::Ascii("iomatised"),
        dictgen::InsensitiveStr::Ascii("iomatises"),
        dictgen::InsensitiveStr::Ascii("iomatising"),
        dictgen::InsensitiveStr::Ascii("iomatization"),
        dictgen::InsensitiveStr::Ascii("iomatizations"),
        dictgen::InsensitiveStr::Ascii("iomatize"),
        dictgen::InsensitiveStr::Ascii("iomatized"),
        dictgen::InsensitiveStr::Ascii("iomatizes"),
        dictgen::InsensitiveStr::Ascii("iomatizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AX_8791902263575839056)],
        &[(0b10010, &ENTRY_AXIOMATIZATION_6790026490086177253)],
        &[(0b10010, &ENTRY_AXIOMATIZATIONS_1463433006554034082)],
        &[(0b10010, &ENTRY_AXIOMATIZE_10903214369529991396)],
        &[(0b10010, &ENTRY_AXIOMATIZED_15716028992263544716)],
        &[(0b10010, &ENTRY_AXIOMATIZES_17183333054844420152)],
        &[(0b10010, &ENTRY_AXIOMATIZING_12121192135039396112)],
        &[(0b01001, &ENTRY_AXIOMATIZATION_6790026490086177253)],
        &[(0b01001, &ENTRY_AXIOMATIZATIONS_1463433006554034082)],
        &[(0b01001, &ENTRY_AXIOMATIZE_10903214369529991396)],
        &[(0b01001, &ENTRY_AXIOMATIZED_15716028992263544716)],
        &[(0b01001, &ENTRY_AXIOMATIZES_17183333054844420152)],
        &[(0b01001, &ENTRY_AXIOMATIZING_12121192135039396112)],
    ],
    range: 1..=13,
};

static VARS_AV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AV_CHILDREN),
    value: None,
};

pub static VARS_AV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ianise"),
        dictgen::InsensitiveStr::Ascii("ianised"),
        dictgen::InsensitiveStr::Ascii("ianises"),
        dictgen::InsensitiveStr::Ascii("ianising"),
        dictgen::InsensitiveStr::Ascii("ianize"),
        dictgen::InsensitiveStr::Ascii("ianized"),
        dictgen::InsensitiveStr::Ascii("ianizes"),
        dictgen::InsensitiveStr::Ascii("ianizing"),
        dictgen::InsensitiveStr::Ascii("isandum"),
        dictgen::InsensitiveStr::Ascii("isandums"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("izandum"),
        dictgen::InsensitiveStr::Ascii("izandums"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AVIANIZE_7182789330071991276)],
        &[(0b10010, &ENTRY_AVIANIZED_18028922120466918062)],
        &[(0b10010, &ENTRY_AVIANIZES_3719741787367657653)],
        &[(0b10010, &ENTRY_AVIANIZING_5883523625794290260)],
        &[(0b01001, &ENTRY_AVIANIZE_7182789330071991276)],
        &[(0b01001, &ENTRY_AVIANIZED_18028922120466918062)],
        &[(0b01001, &ENTRY_AVIANIZES_3719741787367657653)],
        &[(0b01001, &ENTRY_AVIANIZING_5883523625794290260)],
        &[(0b10010, &ENTRY_AVIZANDUM_12850456978185242449)],
        &[(0b10010, &ENTRY_AVIZANDUMS_317675797382529405)],
        &[(0b10010, &ENTRY_AVIZE_9529584256565676451)],
        &[(0b10010, &ENTRY_AVIZED_12711210182572791628)],
        &[(0b10010, &ENTRY_AVIZES_4984057433322754178)],
        &[(0b10010, &ENTRY_AVIZING_13649640310586309670)],
        &[(0b01001, &ENTRY_AVIZANDUM_12850456978185242449)],
        &[(0b01001, &ENTRY_AVIZANDUMS_317675797382529405)],
        &[(0b01001, &ENTRY_AVIZE_9529584256565676451)],
        &[(0b01001, &ENTRY_AVIZED_12711210182572791628)],
        &[(0b01001, &ENTRY_AVIZES_4984057433322754178)],
        &[(0b01001, &ENTRY_AVIZING_13649640310586309670)],
    ],
    range: 3..=8,
};

static VARS_AU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AU_CHILDREN),
    value: None,
};

static VARS_AU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_AUN_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_AUS_NODE),
    Some(&VARS_AUT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_AUT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AUT_CHILDREN),
    value: None,
};

static VARS_AUT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_AUTE_NODE),
    None,
    None,
    Some(&VARS_AUTH_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_AUTO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_AUTO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AUTO_CHILDREN),
    value: None,
};

pub static VARS_AUTO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("catalyse"),
        dictgen::InsensitiveStr::Ascii("catalysed"),
        dictgen::InsensitiveStr::Ascii("catalyses"),
        dictgen::InsensitiveStr::Ascii("catalysing"),
        dictgen::InsensitiveStr::Ascii("catalyze"),
        dictgen::InsensitiveStr::Ascii("catalyzed"),
        dictgen::InsensitiveStr::Ascii("catalyzes"),
        dictgen::InsensitiveStr::Ascii("catalyzing"),
        dictgen::InsensitiveStr::Ascii("dialer"),
        dictgen::InsensitiveStr::Ascii("dialler"),
        dictgen::InsensitiveStr::Ascii("ecious"),
        dictgen::InsensitiveStr::Ascii("eciously"),
        dictgen::InsensitiveStr::Ascii("eciousness"),
        dictgen::InsensitiveStr::Ascii("ecism"),
        dictgen::InsensitiveStr::Ascii("ecisms"),
        dictgen::InsensitiveStr::Ascii("ecy"),
        dictgen::InsensitiveStr::Ascii("immunisation"),
        dictgen::InsensitiveStr::Ascii("immunization"),
        dictgen::InsensitiveStr::Ascii("ionisation"),
        dictgen::InsensitiveStr::Ascii("ionization"),
        dictgen::InsensitiveStr::Ascii("lysate"),
        dictgen::InsensitiveStr::Ascii("lysates"),
        dictgen::InsensitiveStr::Ascii("lyse"),
        dictgen::InsensitiveStr::Ascii("lysed"),
        dictgen::InsensitiveStr::Ascii("lyses"),
        dictgen::InsensitiveStr::Ascii("lysing"),
        dictgen::InsensitiveStr::Ascii("lyzate"),
        dictgen::InsensitiveStr::Ascii("lyzates"),
        dictgen::InsensitiveStr::Ascii("lyze"),
        dictgen::InsensitiveStr::Ascii("lyzed"),
        dictgen::InsensitiveStr::Ascii("lyzes"),
        dictgen::InsensitiveStr::Ascii("lyzing"),
        dictgen::InsensitiveStr::Ascii("matisation"),
        dictgen::InsensitiveStr::Ascii("matisations"),
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matization"),
        dictgen::InsensitiveStr::Ascii("matizations"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
        dictgen::InsensitiveStr::Ascii("noae"),
        dictgen::InsensitiveStr::Ascii("noe"),
        dictgen::InsensitiveStr::Ascii("tomise"),
        dictgen::InsensitiveStr::Ascii("tomised"),
        dictgen::InsensitiveStr::Ascii("tomises"),
        dictgen::InsensitiveStr::Ascii("tomising"),
        dictgen::InsensitiveStr::Ascii("tomize"),
        dictgen::InsensitiveStr::Ascii("tomized"),
        dictgen::InsensitiveStr::Ascii("tomizes"),
        dictgen::InsensitiveStr::Ascii("tomizing"),
        dictgen::InsensitiveStr::Ascii("toxaemia"),
        dictgen::InsensitiveStr::Ascii("toxaemias"),
        dictgen::InsensitiveStr::Ascii("toxemia"),
        dictgen::InsensitiveStr::Ascii("toxemias"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AUTOCATALYZE_5461271699135892272)],
        &[(0b10010, &ENTRY_AUTOCATALYZED_997717077170549950)],
        &[(0b10010, &ENTRY_AUTOCATALYZES_16499693018281720964)],
        &[(0b10010, &ENTRY_AUTOCATALYZING_6626129467810870996)],
        &[(0b01001, &ENTRY_AUTOCATALYZE_5461271699135892272)],
        &[(0b01001, &ENTRY_AUTOCATALYZED_997717077170549950)],
        &[(0b01001, &ENTRY_AUTOCATALYZES_16499693018281720964)],
        &[(0b01001, &ENTRY_AUTOCATALYZING_6626129467810870996)],
        &[(0b00001, &ENTRY_AUTODIALER_3883256868475043902)],
        &[(0b11010, &ENTRY_AUTODIALER_3883256868475043902)],
        &[(0b11010, &ENTRY_AUTECIOUS_9016941624955767913)],
        &[(0b11010, &ENTRY_AUTECIOUSLY_7125263249320375817)],
        &[(0b11010, &ENTRY_AUTECIOUSNESS_11999355741493391477)],
        &[(0b11010, &ENTRY_AUTECISM_8206525242512381241)],
        &[(0b11010, &ENTRY_AUTECISMS_10619942660624290956)],
        &[(0b11010, &ENTRY_AUTECY_7368389728914865172)],
        &[(0b10010, &ENTRY_AUTOIMMUNIZATION_9926504789971325367)],
        &[(0b01001, &ENTRY_AUTOIMMUNIZATION_9926504789971325367)],
        &[(0b10010, &ENTRY_AUTOIONIZATION_6325169105459274551)],
        &[(0b01001, &ENTRY_AUTOIONIZATION_6325169105459274551)],
        &[(0b10010, &ENTRY_AUTOLYZATE_4740018979514548136)],
        &[(0b10010, &ENTRY_AUTOLYZATES_7096670691572389437)],
        &[(0b10010, &ENTRY_AUTOLYZE_7221911042390256641)],
        &[(0b10010, &ENTRY_AUTOLYZED_3751603048053936787)],
        &[(0b10010, &ENTRY_AUTOLYZES_10272580890270323304)],
        &[(0b10010, &ENTRY_AUTOLYZING_10091565140641112709)],
        &[(0b01001, &ENTRY_AUTOLYZATE_4740018979514548136)],
        &[(0b01001, &ENTRY_AUTOLYZATES_7096670691572389437)],
        &[(0b01001, &ENTRY_AUTOLYZE_7221911042390256641)],
        &[(0b01001, &ENTRY_AUTOLYZED_3751603048053936787)],
        &[(0b01001, &ENTRY_AUTOLYZES_10272580890270323304)],
        &[(0b01001, &ENTRY_AUTOLYZING_10091565140641112709)],
        &[(0b10010, &ENTRY_AUTOMATIZATION_5810567154782386881)],
        &[(0b10010, &ENTRY_AUTOMATIZATIONS_11353228502294123144)],
        &[(0b10010, &ENTRY_AUTOMATIZE_16310459509383804856)],
        &[(0b10010, &ENTRY_AUTOMATIZED_6360332663543743601)],
        &[(0b10010, &ENTRY_AUTOMATIZES_16200902288701375676)],
        &[(0b10010, &ENTRY_AUTOMATIZING_1555845313837902984)],
        &[(0b01001, &ENTRY_AUTOMATIZATION_5810567154782386881)],
        &[(0b01001, &ENTRY_AUTOMATIZATIONS_11353228502294123144)],
        &[(0b01001, &ENTRY_AUTOMATIZE_16310459509383804856)],
        &[(0b01001, &ENTRY_AUTOMATIZED_6360332663543743601)],
        &[(0b01001, &ENTRY_AUTOMATIZES_16200902288701375676)],
        &[(0b01001, &ENTRY_AUTOMATIZING_1555845313837902984)],
        &[(0b11010, &ENTRY_AUTONOE_13532775087577013215)],
        &[(0b00001, &ENTRY_AUTONOE_13532775087577013215)],
        &[(0b10010, &ENTRY_AUTOTOMIZE_13490570757077519512)],
        &[(0b10010, &ENTRY_AUTOTOMIZED_540920492757769960)],
        &[(0b10010, &ENTRY_AUTOTOMIZES_48604156847444911)],
        &[(0b10010, &ENTRY_AUTOTOMIZING_11853548989644406010)],
        &[(0b01001, &ENTRY_AUTOTOMIZE_13490570757077519512)],
        &[(0b01001, &ENTRY_AUTOTOMIZED_540920492757769960)],
        &[(0b01001, &ENTRY_AUTOTOMIZES_48604156847444911)],
        &[(0b01001, &ENTRY_AUTOTOMIZING_11853548989644406010)],
        &[(0b11010, &ENTRY_AUTOTOXEMIA_7479014975731069357)],
        &[(0b11010, &ENTRY_AUTOTOXEMIAS_10214808257451881715)],
        &[(0b00001, &ENTRY_AUTOTOXEMIA_7479014975731069357)],
        &[(0b00001, &ENTRY_AUTOTOXEMIAS_10214808257451881715)],
    ],
    range: 3..=12,
};

static VARS_AUTH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AUTH_CHILDREN),
    value: None,
};

pub static VARS_AUTH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orisable"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("oriser"),
        dictgen::InsensitiveStr::Ascii("orisers"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orizable"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizer"),
        dictgen::InsensitiveStr::Ascii("orizers"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AUTHORIZABLE_7024929714254597943)],
        &[(0b10010, &ENTRY_AUTHORIZATION_9399085124340736739)],
        &[(0b10010, &ENTRY_AUTHORIZATIONS_11920547268538394932)],
        &[(0b10010, &ENTRY_AUTHORIZE_2165377916187291578)],
        &[(0b10010, &ENTRY_AUTHORIZED_15853776364746167522)],
        &[(0b10010, &ENTRY_AUTHORIZER_10220958941854846496)],
        &[(0b10010, &ENTRY_AUTHORIZERS_2996105333287439187)],
        &[(0b10010, &ENTRY_AUTHORIZES_12688794592033918408)],
        &[(0b10010, &ENTRY_AUTHORIZING_9710867312061027048)],
        &[(0b01001, &ENTRY_AUTHORIZABLE_7024929714254597943)],
        &[(0b01001, &ENTRY_AUTHORIZATION_9399085124340736739)],
        &[(0b01001, &ENTRY_AUTHORIZATIONS_11920547268538394932)],
        &[(0b01001, &ENTRY_AUTHORIZE_2165377916187291578)],
        &[(0b01001, &ENTRY_AUTHORIZED_15853776364746167522)],
        &[(0b01001, &ENTRY_AUTHORIZER_10220958941854846496)],
        &[(0b01001, &ENTRY_AUTHORIZERS_2996105333287439187)],
        &[(0b01001, &ENTRY_AUTHORIZES_12688794592033918408)],
        &[(0b01001, &ENTRY_AUTHORIZING_9710867312061027048)],
    ],
    range: 5..=10,
};

static VARS_AUTE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AUTE_CHILDREN),
    value: None,
};

pub static VARS_AUTE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cious"),
        dictgen::InsensitiveStr::Ascii("ciously"),
        dictgen::InsensitiveStr::Ascii("ciousness"),
        dictgen::InsensitiveStr::Ascii("cism"),
        dictgen::InsensitiveStr::Ascii("cisms"),
        dictgen::InsensitiveStr::Ascii("cy"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AUTECIOUS_9016941624955767913)],
        &[(0b00001, &ENTRY_AUTECIOUSLY_7125263249320375817)],
        &[(0b00001, &ENTRY_AUTECIOUSNESS_11999355741493391477)],
        &[(0b00001, &ENTRY_AUTECISM_8206525242512381241)],
        &[(0b00001, &ENTRY_AUTECISMS_10619942660624290956)],
        &[(0b00001, &ENTRY_AUTECY_7368389728914865172)],
    ],
    range: 2..=9,
};

static VARS_AUS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AUS_CHILDREN),
    value: None,
};

pub static VARS_AUS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tralianise"),
        dictgen::InsensitiveStr::Ascii("tralianises"),
        dictgen::InsensitiveStr::Ascii("tralianize"),
        dictgen::InsensitiveStr::Ascii("tralianizes"),
        dictgen::InsensitiveStr::Ascii("tralopithecinae"),
        dictgen::InsensitiveStr::Ascii("tralopithecine"),
        dictgen::InsensitiveStr::Ascii("trianise"),
        dictgen::InsensitiveStr::Ascii("trianises"),
        dictgen::InsensitiveStr::Ascii("trianize"),
        dictgen::InsensitiveStr::Ascii("trianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AUSTRALIANIZE_8442939799684541917)],
        &[(0b10010, &ENTRY_AUSTRALIANIZES_18424570185752883694)],
        &[(0b01001, &ENTRY_AUSTRALIANIZE_8442939799684541917)],
        &[(0b01001, &ENTRY_AUSTRALIANIZES_18424570185752883694)],
        &[(0b11010, &ENTRY_AUSTRALOPITHECINE_9263939179936660845)],
        &[(0b00001, &ENTRY_AUSTRALOPITHECINE_9263939179936660845)],
        &[(0b10010, &ENTRY_AUSTRIANIZE_986135697638036817)],
        &[(0b10010, &ENTRY_AUSTRIANIZES_15560706707425803347)],
        &[(0b01001, &ENTRY_AUSTRIANIZE_986135697638036817)],
        &[(0b01001, &ENTRY_AUSTRIANIZES_15560706707425803347)],
    ],
    range: 8..=15,
};

static VARS_AUN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AUN_CHILDREN),
    value: None,
};

pub static VARS_AUN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AUNTER_10775345708782097344)],
        &[(0b11010, &ENTRY_AUNTER_10775345708782097344)],
    ],
    range: 3..=3,
};

static VARS_AT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AT_CHILDREN),
    value: None,
};

static VARS_AT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ATH_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_ATM_NODE),
    None,
    Some(&VARS_ATO_NODE),
    None,
    None,
    Some(&VARS_ATR_NODE),
    None,
    Some(&VARS_ATT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ATT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ATT_CHILDREN),
    value: None,
};

pub static VARS_ATT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emper"),
        dictgen::InsensitiveStr::Ascii("empre"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icizing"),
        dictgen::InsensitiveStr::Ascii("itudinisation"),
        dictgen::InsensitiveStr::Ascii("itudinise"),
        dictgen::InsensitiveStr::Ascii("itudinised"),
        dictgen::InsensitiveStr::Ascii("itudiniser"),
        dictgen::InsensitiveStr::Ascii("itudinisers"),
        dictgen::InsensitiveStr::Ascii("itudinises"),
        dictgen::InsensitiveStr::Ascii("itudinising"),
        dictgen::InsensitiveStr::Ascii("itudinisings"),
        dictgen::InsensitiveStr::Ascii("itudinization"),
        dictgen::InsensitiveStr::Ascii("itudinize"),
        dictgen::InsensitiveStr::Ascii("itudinized"),
        dictgen::InsensitiveStr::Ascii("itudinizer"),
        dictgen::InsensitiveStr::Ascii("itudinizers"),
        dictgen::InsensitiveStr::Ascii("itudinizes"),
        dictgen::InsensitiveStr::Ascii("itudinizing"),
        dictgen::InsensitiveStr::Ascii("itudinizings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ATTEMPER_12124624986954113539)],
        &[(0b11010, &ENTRY_ATTEMPER_12124624986954113539)],
        &[(0b10010, &ENTRY_ATTICIZE_16515183819201700111)],
        &[(0b10010, &ENTRY_ATTICIZED_7951296077967341199)],
        &[(0b10010, &ENTRY_ATTICIZES_5529365057194588874)],
        &[(0b10010, &ENTRY_ATTICIZING_2415630028739866198)],
        &[(0b01001, &ENTRY_ATTICIZE_16515183819201700111)],
        &[(0b01001, &ENTRY_ATTICIZED_7951296077967341199)],
        &[(0b01001, &ENTRY_ATTICIZES_5529365057194588874)],
        &[(0b01001, &ENTRY_ATTICIZING_2415630028739866198)],
        &[(0b10010, &ENTRY_ATTITUDINIZATION_16531832101228496151)],
        &[(0b10010, &ENTRY_ATTITUDINIZE_13882543243823601511)],
        &[(0b10010, &ENTRY_ATTITUDINIZED_14589679104763490674)],
        &[(0b10010, &ENTRY_ATTITUDINIZER_12167614530126147382)],
        &[(0b10010, &ENTRY_ATTITUDINIZERS_2041039782349599020)],
        &[(0b10010, &ENTRY_ATTITUDINIZES_8414732033616113994)],
        &[(0b10010, &ENTRY_ATTITUDINIZING_1855190539336439905)],
        &[(0b10010, &ENTRY_ATTITUDINIZINGS_3731252719764627971)],
        &[(0b01001, &ENTRY_ATTITUDINIZATION_16531832101228496151)],
        &[(0b01001, &ENTRY_ATTITUDINIZE_13882543243823601511)],
        &[(0b01001, &ENTRY_ATTITUDINIZED_14589679104763490674)],
        &[(0b01001, &ENTRY_ATTITUDINIZER_12167614530126147382)],
        &[(0b01001, &ENTRY_ATTITUDINIZERS_2041039782349599020)],
        &[(0b01001, &ENTRY_ATTITUDINIZES_8414732033616113994)],
        &[(0b01001, &ENTRY_ATTITUDINIZING_1855190539336439905)],
        &[(0b01001, &ENTRY_ATTITUDINIZINGS_3731252719764627971)],
    ],
    range: 5..=13,
};

static VARS_ATR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ATR_CHILDREN),
    value: None,
};

pub static VARS_ATR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oceruleus"),
        dictgen::InsensitiveStr::Ascii("ocoeruleus"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ATROCERULEUS_870609394004473197)],
        &[(0b11010, &ENTRY_ATROCERULEUS_870609394004473197)],
    ],
    range: 9..=10,
};

static VARS_ATO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ATO_CHILDREN),
    value: None,
};

pub static VARS_ATO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("misability"),
        dictgen::InsensitiveStr::Ascii("misable"),
        dictgen::InsensitiveStr::Ascii("misation"),
        dictgen::InsensitiveStr::Ascii("misations"),
        dictgen::InsensitiveStr::Ascii("mise"),
        dictgen::InsensitiveStr::Ascii("mised"),
        dictgen::InsensitiveStr::Ascii("miser"),
        dictgen::InsensitiveStr::Ascii("misers"),
        dictgen::InsensitiveStr::Ascii("mises"),
        dictgen::InsensitiveStr::Ascii("mising"),
        dictgen::InsensitiveStr::Ascii("mizability"),
        dictgen::InsensitiveStr::Ascii("mizable"),
        dictgen::InsensitiveStr::Ascii("mization"),
        dictgen::InsensitiveStr::Ascii("mizations"),
        dictgen::InsensitiveStr::Ascii("mize"),
        dictgen::InsensitiveStr::Ascii("mized"),
        dictgen::InsensitiveStr::Ascii("mizer"),
        dictgen::InsensitiveStr::Ascii("mizers"),
        dictgen::InsensitiveStr::Ascii("mizes"),
        dictgen::InsensitiveStr::Ascii("mizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ATOMIZABILITY_3064159544702925002)],
        &[(0b10010, &ENTRY_ATOMIZABLE_3154734891333662468)],
        &[(0b10010, &ENTRY_ATOMIZATION_590556657495417532)],
        &[(0b10010, &ENTRY_ATOMIZATIONS_13202958232672091227)],
        &[(0b10010, &ENTRY_ATOMIZE_1487134664435979373)],
        &[(0b10010, &ENTRY_ATOMIZED_14021873460744571304)],
        &[(0b10010, &ENTRY_ATOMIZER_11539225746984001325)],
        &[(0b10010, &ENTRY_ATOMIZERS_7852074573965124043)],
        &[(0b10010, &ENTRY_ATOMIZES_933901040229054200)],
        &[(0b10010, &ENTRY_ATOMIZING_15930852773659767832)],
        &[(0b01001, &ENTRY_ATOMIZABILITY_3064159544702925002)],
        &[(0b01001, &ENTRY_ATOMIZABLE_3154734891333662468)],
        &[(0b01001, &ENTRY_ATOMIZATION_590556657495417532)],
        &[(0b01001, &ENTRY_ATOMIZATIONS_13202958232672091227)],
        &[(0b01001, &ENTRY_ATOMIZE_1487134664435979373)],
        &[(0b01001, &ENTRY_ATOMIZED_14021873460744571304)],
        &[(0b01001, &ENTRY_ATOMIZER_11539225746984001325)],
        &[(0b01001, &ENTRY_ATOMIZERS_7852074573965124043)],
        &[(0b01001, &ENTRY_ATOMIZES_933901040229054200)],
        &[(0b01001, &ENTRY_ATOMIZING_15930852773659767832)],
    ],
    range: 4..=10,
};

static VARS_ATM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ATM_CHILDREN),
    value: None,
};

pub static VARS_ATM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olyse"),
        dictgen::InsensitiveStr::Ascii("olysed"),
        dictgen::InsensitiveStr::Ascii("olyses"),
        dictgen::InsensitiveStr::Ascii("olysing"),
        dictgen::InsensitiveStr::Ascii("olyze"),
        dictgen::InsensitiveStr::Ascii("olyzed"),
        dictgen::InsensitiveStr::Ascii("olyzes"),
        dictgen::InsensitiveStr::Ascii("olyzing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ATMOLYZE_8057568476478476694)],
        &[(0b10010, &ENTRY_ATMOLYZED_14977612454538756584)],
        &[(0b10010, &ENTRY_ATMOLYZES_201081934661402516)],
        &[(0b10010, &ENTRY_ATMOLYZING_9405510802019900450)],
        &[(0b01001, &ENTRY_ATMOLYZE_8057568476478476694)],
        &[(0b01001, &ENTRY_ATMOLYZED_14977612454538756584)],
        &[(0b01001, &ENTRY_ATMOLYZES_201081934661402516)],
        &[(0b01001, &ENTRY_ATMOLYZING_9405510802019900450)],
    ],
    range: 5..=7,
};

static VARS_ATH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ATH_CHILDREN),
    value: None,
};

pub static VARS_ATH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eise"),
        dictgen::InsensitiveStr::Ascii("eised"),
        dictgen::InsensitiveStr::Ascii("eises"),
        dictgen::InsensitiveStr::Ascii("eising"),
        dictgen::InsensitiveStr::Ascii("eize"),
        dictgen::InsensitiveStr::Ascii("eized"),
        dictgen::InsensitiveStr::Ascii("eizes"),
        dictgen::InsensitiveStr::Ascii("eizing"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etising"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("etizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ATHEIZE_3725615390405368489)],
        &[(0b10010, &ENTRY_ATHEIZED_17537019228674510480)],
        &[(0b10010, &ENTRY_ATHEIZES_16042176054703042055)],
        &[(0b10010, &ENTRY_ATHEIZING_16529882185387835743)],
        &[(0b01001, &ENTRY_ATHEIZE_3725615390405368489)],
        &[(0b01001, &ENTRY_ATHEIZED_17537019228674510480)],
        &[(0b01001, &ENTRY_ATHEIZES_16042176054703042055)],
        &[(0b01001, &ENTRY_ATHEIZING_16529882185387835743)],
        &[(0b10010, &ENTRY_ATHETIZE_8594115700031724425)],
        &[(0b10010, &ENTRY_ATHETIZED_11986419619737601090)],
        &[(0b10010, &ENTRY_ATHETIZES_13168875276958946124)],
        &[(0b10010, &ENTRY_ATHETIZING_16435585359530521235)],
        &[(0b01001, &ENTRY_ATHETIZE_8594115700031724425)],
        &[(0b01001, &ENTRY_ATHETIZED_11986419619737601090)],
        &[(0b01001, &ENTRY_ATHETIZES_13168875276958946124)],
        &[(0b01001, &ENTRY_ATHETIZING_16435585359530521235)],
    ],
    range: 4..=7,
};

static VARS_AS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AS_CHILDREN),
    value: None,
};

static VARS_AS_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ASA_NODE),
    None,
    Some(&VARS_ASC_NODE),
    None,
    Some(&VARS_ASE_NODE),
    None,
    None,
    None,
    Some(&VARS_ASI_NODE),
    None,
    None,
    None,
    Some(&VARS_ASM_NODE),
    None,
    None,
    Some(&VARS_ASP_NODE),
    None,
    None,
    Some(&VARS_ASS_NODE),
    Some(&VARS_AST_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_ASY_NODE),
    None,
];

static VARS_ASY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASY_CHILDREN),
    value: None,
};

pub static VARS_ASY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nchronise"),
        dictgen::InsensitiveStr::Ascii("nchronised"),
        dictgen::InsensitiveStr::Ascii("nchronises"),
        dictgen::InsensitiveStr::Ascii("nchronising"),
        dictgen::InsensitiveStr::Ascii("nchronize"),
        dictgen::InsensitiveStr::Ascii("nchronized"),
        dictgen::InsensitiveStr::Ascii("nchronizes"),
        dictgen::InsensitiveStr::Ascii("nchronizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ASYNCHRONIZE_12856870824943050138)],
        &[(0b10010, &ENTRY_ASYNCHRONIZED_14952589787514487817)],
        &[(0b10010, &ENTRY_ASYNCHRONIZES_3583310434940903781)],
        &[(0b10010, &ENTRY_ASYNCHRONIZING_15056432960653345202)],
        &[(0b01001, &ENTRY_ASYNCHRONIZE_12856870824943050138)],
        &[(0b01001, &ENTRY_ASYNCHRONIZED_14952589787514487817)],
        &[(0b01001, &ENTRY_ASYNCHRONIZES_3583310434940903781)],
        &[(0b01001, &ENTRY_ASYNCHRONIZING_15056432960653345202)],
    ],
    range: 9..=11,
};

static VARS_AST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AST_CHILDREN),
    value: None,
};

pub static VARS_AST_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("era"),
        dictgen::InsensitiveStr::Ascii("igmatiser"),
        dictgen::InsensitiveStr::Ascii("igmatisers"),
        dictgen::InsensitiveStr::Ascii("igmatizer"),
        dictgen::InsensitiveStr::Ascii("igmatizers"),
        dictgen::InsensitiveStr::Ascii("raea"),
        dictgen::InsensitiveStr::Ascii("raean"),
        dictgen::InsensitiveStr::Ascii("rea"),
        dictgen::InsensitiveStr::Ascii("rean"),
        dictgen::InsensitiveStr::Ascii("ronomise"),
        dictgen::InsensitiveStr::Ascii("ronomised"),
        dictgen::InsensitiveStr::Ascii("ronomises"),
        dictgen::InsensitiveStr::Ascii("ronomising"),
        dictgen::InsensitiveStr::Ascii("ronomize"),
        dictgen::InsensitiveStr::Ascii("ronomized"),
        dictgen::InsensitiveStr::Ascii("ronomizes"),
        dictgen::InsensitiveStr::Ascii("ronomizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ASTERA_2180294228483451899)],
        &[(0b10010, &ENTRY_ASTIGMATIZER_13677362351199776983)],
        &[(0b10010, &ENTRY_ASTIGMATIZERS_14746285422051377958)],
        &[(0b01001, &ENTRY_ASTIGMATIZER_13677362351199776983)],
        &[(0b01001, &ENTRY_ASTIGMATIZERS_14746285422051377958)],
        &[(0b11010, &ENTRY_ASTREA_13572090690341051490)],
        &[(0b11010, &ENTRY_ASTREAN_13090104080124803741)],
        &[
            (0b11010, &ENTRY_ASTERA_2180294228483451899),
            (0b00001, &ENTRY_ASTREA_13572090690341051490),
        ],
        &[(0b00001, &ENTRY_ASTREAN_13090104080124803741)],
        &[(0b10010, &ENTRY_ASTRONOMIZE_9822118404859723540)],
        &[(0b10010, &ENTRY_ASTRONOMIZED_13008465323667270440)],
        &[(0b10010, &ENTRY_ASTRONOMIZES_13470023486647725922)],
        &[(0b10010, &ENTRY_ASTRONOMIZING_2599501206343230278)],
        &[(0b01001, &ENTRY_ASTRONOMIZE_9822118404859723540)],
        &[(0b01001, &ENTRY_ASTRONOMIZED_13008465323667270440)],
        &[(0b01001, &ENTRY_ASTRONOMIZES_13470023486647725922)],
        &[(0b01001, &ENTRY_ASTRONOMIZING_2599501206343230278)],
    ],
    range: 3..=10,
};

static VARS_ASS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASS_CHILDREN),
    value: None,
};

pub static VARS_ASS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("afetida"),
        dictgen::InsensitiveStr::Ascii("afetidas"),
        dictgen::InsensitiveStr::Ascii("afoetida"),
        dictgen::InsensitiveStr::Ascii("afoetidas"),
        dictgen::InsensitiveStr::Ascii("hole"),
        dictgen::InsensitiveStr::Ascii("holes"),
        dictgen::InsensitiveStr::Ascii("idaean"),
        dictgen::InsensitiveStr::Ascii("idean"),
        dictgen::InsensitiveStr::Ascii("yrianise"),
        dictgen::InsensitiveStr::Ascii("yrianises"),
        dictgen::InsensitiveStr::Ascii("yrianize"),
        dictgen::InsensitiveStr::Ascii("yrianizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ASSAFETIDA_15899167959215961246)],
        &[(0b00001, &ENTRY_ASSAFETIDAS_11098964927816384399)],
        &[(0b11010, &ENTRY_ASSAFETIDA_15899167959215961246)],
        &[(0b11010, &ENTRY_ASSAFETIDAS_11098964927816384399)],
        &[(0b00001, &ENTRY_ASSHOLE_17127558960509698292)],
        &[(0b00001, &ENTRY_ASSHOLES_4727626946303116044)],
        &[(0b11010, &ENTRY_ASSIDEAN_15792750251093397890)],
        &[(0b00001, &ENTRY_ASSIDEAN_15792750251093397890)],
        &[(0b10010, &ENTRY_ASSYRIANIZE_8826733172094433545)],
        &[(0b10010, &ENTRY_ASSYRIANIZES_8778694777663587290)],
        &[(0b01001, &ENTRY_ASSYRIANIZE_8826733172094433545)],
        &[(0b01001, &ENTRY_ASSYRIANIZES_8778694777663587290)],
    ],
    range: 4..=9,
};

static VARS_ASP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASP_CHILDREN),
    value: None,
};

pub static VARS_ASP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("heterise"),
        dictgen::InsensitiveStr::Ascii("heterised"),
        dictgen::InsensitiveStr::Ascii("heterises"),
        dictgen::InsensitiveStr::Ascii("heterising"),
        dictgen::InsensitiveStr::Ascii("heterize"),
        dictgen::InsensitiveStr::Ascii("heterized"),
        dictgen::InsensitiveStr::Ascii("heterizes"),
        dictgen::InsensitiveStr::Ascii("heterizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ASPHETERIZE_386743966224116123)],
        &[(0b10010, &ENTRY_ASPHETERIZED_4823135635369597053)],
        &[(0b10010, &ENTRY_ASPHETERIZES_11246637584979639689)],
        &[(0b10010, &ENTRY_ASPHETERIZING_4104456087110825723)],
        &[(0b01001, &ENTRY_ASPHETERIZE_386743966224116123)],
        &[(0b01001, &ENTRY_ASPHETERIZED_4823135635369597053)],
        &[(0b01001, &ENTRY_ASPHETERIZES_11246637584979639689)],
        &[(0b01001, &ENTRY_ASPHETERIZING_4104456087110825723)],
    ],
    range: 8..=10,
};

static VARS_ASM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASM_CHILDREN),
    value: None,
};

pub static VARS_ASM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onaean"),
        dictgen::InsensitiveStr::Ascii("onean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ASMONEAN_3980004008722900302)],
        &[(0b10001, &ENTRY_ASMONEAN_3980004008722900302)],
    ],
    range: 5..=6,
};

static VARS_ASI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASI_CHILDREN),
    value: None,
};

pub static VARS_ASI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aticisation"),
        dictgen::InsensitiveStr::Ascii("aticisations"),
        dictgen::InsensitiveStr::Ascii("aticise"),
        dictgen::InsensitiveStr::Ascii("aticises"),
        dictgen::InsensitiveStr::Ascii("aticization"),
        dictgen::InsensitiveStr::Ascii("aticizations"),
        dictgen::InsensitiveStr::Ascii("aticize"),
        dictgen::InsensitiveStr::Ascii("aticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ASIATICIZATION_1819881487033607018)],
        &[(0b10010, &ENTRY_ASIATICIZATIONS_12846180914024772704)],
        &[(0b10010, &ENTRY_ASIATICIZE_8144608041170705949)],
        &[(0b10010, &ENTRY_ASIATICIZES_2776515947393687528)],
        &[(0b01001, &ENTRY_ASIATICIZATION_1819881487033607018)],
        &[(0b01001, &ENTRY_ASIATICIZATIONS_12846180914024772704)],
        &[(0b01001, &ENTRY_ASIATICIZE_8144608041170705949)],
        &[(0b01001, &ENTRY_ASIATICIZES_2776515947393687528)],
    ],
    range: 7..=12,
};

static VARS_ASE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASE_CHILDREN),
    value: None,
};

pub static VARS_ASE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("l"),
        dictgen::InsensitiveStr::Ascii("pticise"),
        dictgen::InsensitiveStr::Ascii("pticised"),
        dictgen::InsensitiveStr::Ascii("pticises"),
        dictgen::InsensitiveStr::Ascii("pticising"),
        dictgen::InsensitiveStr::Ascii("pticize"),
        dictgen::InsensitiveStr::Ascii("pticized"),
        dictgen::InsensitiveStr::Ascii("pticizes"),
        dictgen::InsensitiveStr::Ascii("pticizing"),
        dictgen::InsensitiveStr::Ascii("xualisation"),
        dictgen::InsensitiveStr::Ascii("xualise"),
        dictgen::InsensitiveStr::Ascii("xualised"),
        dictgen::InsensitiveStr::Ascii("xualising"),
        dictgen::InsensitiveStr::Ascii("xualization"),
        dictgen::InsensitiveStr::Ascii("xualize"),
        dictgen::InsensitiveStr::Ascii("xualized"),
        dictgen::InsensitiveStr::Ascii("xualizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ASEL_13316537939517839394)],
        &[(0b10010, &ENTRY_ASEPTICIZE_10541466893781045238)],
        &[(0b10010, &ENTRY_ASEPTICIZED_2836264878765353358)],
        &[(0b10010, &ENTRY_ASEPTICIZES_8120884150718749297)],
        &[(0b10010, &ENTRY_ASEPTICIZING_9449519681602460239)],
        &[(0b01001, &ENTRY_ASEPTICIZE_10541466893781045238)],
        &[(0b01001, &ENTRY_ASEPTICIZED_2836264878765353358)],
        &[(0b01001, &ENTRY_ASEPTICIZES_8120884150718749297)],
        &[(0b01001, &ENTRY_ASEPTICIZING_9449519681602460239)],
        &[(0b10010, &ENTRY_ASEXUALIZATION_14681303549267056207)],
        &[(0b10010, &ENTRY_ASEXUALIZE_3884700788598243380)],
        &[(0b10010, &ENTRY_ASEXUALIZED_11368129249013006798)],
        &[(0b10010, &ENTRY_ASEXUALIZING_1318417851724238802)],
        &[(0b01001, &ENTRY_ASEXUALIZATION_14681303549267056207)],
        &[(0b01001, &ENTRY_ASEXUALIZE_3884700788598243380)],
        &[(0b01001, &ENTRY_ASEXUALIZED_11368129249013006798)],
        &[(0b01001, &ENTRY_ASEXUALIZING_1318417851724238802)],
    ],
    range: 1..=11,
};

static VARS_ASC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASC_CHILDREN),
    value: None,
};

pub static VARS_ASC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("endency"),
        dictgen::InsensitiveStr::Ascii("endent"),
        dictgen::InsensitiveStr::Ascii("endents"),
        dictgen::InsensitiveStr::Ascii("lepiadae"),
        dictgen::InsensitiveStr::Ascii("lepiade"),
    ],
    values: &[
        &[(0b01001, &ENTRY_ASCENDANCY_18331730091976203528)],
        &[(0b10011, &ENTRY_ASCENDANT_16268836042646778732)],
        &[(0b10011, &ENTRY_ASCENDANTS_3461593336021850728)],
        &[(0b11010, &ENTRY_ASCLEPIADE_14597264952620988032)],
        &[(0b00001, &ENTRY_ASCLEPIADE_14597264952620988032)],
    ],
    range: 6..=8,
};

static VARS_ASA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASA_CHILDREN),
    value: None,
};

pub static VARS_ASA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("el"),
        dictgen::InsensitiveStr::Ascii("fetida"),
        dictgen::InsensitiveStr::Ascii("fetidas"),
        dictgen::InsensitiveStr::Ascii("foetida"),
        dictgen::InsensitiveStr::Ascii("foetidas"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ASEL_13316537939517839394)],
        &[(0b01001, &ENTRY_ASAFETIDA_7533383003905845995)],
        &[(0b01001, &ENTRY_ASAFETIDAS_7613771138640395119)],
        &[(0b11010, &ENTRY_ASAFETIDA_7533383003905845995)],
        &[(0b11010, &ENTRY_ASAFETIDAS_7613771138640395119)],
    ],
    range: 2..=8,
};

static VARS_AR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AR_CHILDREN),
    value: None,
};

static VARS_AR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ARA_NODE),
    Some(&VARS_ARB_NODE),
    Some(&VARS_ARC_NODE),
    Some(&VARS_ARD_NODE),
    Some(&VARS_ARE_NODE),
    None,
    None,
    None,
    Some(&VARS_ARI_NODE),
    None,
    None,
    None,
    Some(&VARS_ARM_NODE),
    None,
    Some(&VARS_ARO_NODE),
    None,
    None,
    None,
    Some(&VARS_ARS_NODE),
    Some(&VARS_ART_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_ARY_NODE),
    None,
];

static VARS_ARY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARY_CHILDREN),
    value: None,
};

pub static VARS_ARY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("taenoid"),
        dictgen::InsensitiveStr::Ascii("taenoids"),
        dictgen::InsensitiveStr::Ascii("tenoid"),
        dictgen::InsensitiveStr::Ascii("tenoids"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ARYANIZATION_11011851116548884608)],
        &[(0b10010, &ENTRY_ARYANIZE_9893587637116278166)],
        &[(0b10010, &ENTRY_ARYANIZED_13499390712209039689)],
        &[(0b10010, &ENTRY_ARYANIZES_15634323303932059369)],
        &[(0b10010, &ENTRY_ARYANIZING_9395651759559624779)],
        &[(0b01001, &ENTRY_ARYANIZATION_11011851116548884608)],
        &[(0b01001, &ENTRY_ARYANIZE_9893587637116278166)],
        &[(0b01001, &ENTRY_ARYANIZED_13499390712209039689)],
        &[(0b01001, &ENTRY_ARYANIZES_15634323303932059369)],
        &[(0b01001, &ENTRY_ARYANIZING_9395651759559624779)],
        &[(0b11010, &ENTRY_ARYTENOID_6073418440715999154)],
        &[(0b11010, &ENTRY_ARYTENOIDS_8908541045019104137)],
        &[(0b00001, &ENTRY_ARYTENOID_6073418440715999154)],
        &[(0b00001, &ENTRY_ARYTENOIDS_8908541045019104137)],
    ],
    range: 5..=9,
};

static VARS_ART_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ART_CHILDREN),
    value: None,
};

pub static VARS_ART_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("efact"),
        dictgen::InsensitiveStr::Ascii("efacts"),
        dictgen::InsensitiveStr::Ascii("erialisation"),
        dictgen::InsensitiveStr::Ascii("erialisations"),
        dictgen::InsensitiveStr::Ascii("erialise"),
        dictgen::InsensitiveStr::Ascii("erialised"),
        dictgen::InsensitiveStr::Ascii("erialises"),
        dictgen::InsensitiveStr::Ascii("erialising"),
        dictgen::InsensitiveStr::Ascii("erialization"),
        dictgen::InsensitiveStr::Ascii("erializations"),
        dictgen::InsensitiveStr::Ascii("erialize"),
        dictgen::InsensitiveStr::Ascii("erialized"),
        dictgen::InsensitiveStr::Ascii("erializes"),
        dictgen::InsensitiveStr::Ascii("erializing"),
        dictgen::InsensitiveStr::Ascii("hrempyesis"),
        dictgen::InsensitiveStr::Ascii("hroempyesis"),
        dictgen::InsensitiveStr::Ascii("ifact"),
        dictgen::InsensitiveStr::Ascii("ifacts"),
        dictgen::InsensitiveStr::Ascii("ificialise"),
        dictgen::InsensitiveStr::Ascii("ificialised"),
        dictgen::InsensitiveStr::Ascii("ificialises"),
        dictgen::InsensitiveStr::Ascii("ificialising"),
        dictgen::InsensitiveStr::Ascii("ificialize"),
        dictgen::InsensitiveStr::Ascii("ificialized"),
        dictgen::InsensitiveStr::Ascii("ificializes"),
        dictgen::InsensitiveStr::Ascii("ificializing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ARTIFACT_17509472184751868861)],
        &[(0b11010, &ENTRY_ARTIFACTS_1062240257173575487)],
        &[(0b10010, &ENTRY_ARTERIALIZATION_12220214490626585223)],
        &[(0b10010, &ENTRY_ARTERIALIZATIONS_14137202706840549747)],
        &[(0b10010, &ENTRY_ARTERIALIZE_160821330242474661)],
        &[(0b10010, &ENTRY_ARTERIALIZED_13112994890988388396)],
        &[(0b10010, &ENTRY_ARTERIALIZES_17367277747015913948)],
        &[(0b10010, &ENTRY_ARTERIALIZING_12599986629846293545)],
        &[(0b01001, &ENTRY_ARTERIALIZATION_12220214490626585223)],
        &[(0b01001, &ENTRY_ARTERIALIZATIONS_14137202706840549747)],
        &[(0b01001, &ENTRY_ARTERIALIZE_160821330242474661)],
        &[(0b01001, &ENTRY_ARTERIALIZED_13112994890988388396)],
        &[(0b01001, &ENTRY_ARTERIALIZES_17367277747015913948)],
        &[(0b01001, &ENTRY_ARTERIALIZING_12599986629846293545)],
        &[(0b00001, &ENTRY_ARTHREMPYESIS_7196745531112428566)],
        &[(0b11010, &ENTRY_ARTHREMPYESIS_7196745531112428566)],
        &[(0b11001, &ENTRY_ARTIFACT_17509472184751868861)],
        &[(0b11001, &ENTRY_ARTIFACTS_1062240257173575487)],
        &[(0b10010, &ENTRY_ARTIFICIALIZE_11447666319297750586)],
        &[(0b10010, &ENTRY_ARTIFICIALIZED_9369068294747979653)],
        &[(0b10010, &ENTRY_ARTIFICIALIZES_4836192357409582324)],
        &[(0b10010, &ENTRY_ARTIFICIALIZING_2365246669571238443)],
        &[(0b01001, &ENTRY_ARTIFICIALIZE_11447666319297750586)],
        &[(0b01001, &ENTRY_ARTIFICIALIZED_9369068294747979653)],
        &[(0b01001, &ENTRY_ARTIFICIALIZES_4836192357409582324)],
        &[(0b01001, &ENTRY_ARTIFICIALIZING_2365246669571238443)],
    ],
    range: 5..=13,
};

static VARS_ARS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARS_CHILDREN),
    value: None,
};

pub static VARS_ARS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ehole"),
        dictgen::InsensitiveStr::Ascii("eholes"),
        dictgen::InsensitiveStr::Ascii("enicise"),
        dictgen::InsensitiveStr::Ascii("enicises"),
        dictgen::InsensitiveStr::Ascii("enicize"),
        dictgen::InsensitiveStr::Ascii("enicizes"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("inoae"),
        dictgen::InsensitiveStr::Ascii("inoe"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ASS_13267007711731927046)],
        &[(0b11010, &ENTRY_ASSHOLE_17127558960509698292)],
        &[(0b11010, &ENTRY_ASSHOLES_4727626946303116044)],
        &[(0b10010, &ENTRY_ARSENICIZE_15746363128967248584)],
        &[(0b10010, &ENTRY_ARSENICIZES_3348853831535691299)],
        &[(0b01001, &ENTRY_ARSENICIZE_15746363128967248584)],
        &[(0b01001, &ENTRY_ARSENICIZES_3348853831535691299)],
        &[(0b11010, &ENTRY_ASSES_10300641245501717757)],
        &[(0b11010, &ENTRY_ARSINOE_10666641887026095173)],
        &[(0b00001, &ENTRY_ARSINOE_10666641887026095173)],
    ],
    range: 1..=8,
};

static VARS_ARO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARO_CHILDREN),
    value: None,
};

pub static VARS_ARO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matisation"),
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matiser"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matitae"),
        dictgen::InsensitiveStr::Ascii("matite"),
        dictgen::InsensitiveStr::Ascii("matization"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizer"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AROMATIZATION_5370295794385992127)],
        &[(0b10010, &ENTRY_AROMATIZE_17577690372454585657)],
        &[(0b10010, &ENTRY_AROMATIZED_5000984731968850520)],
        &[(0b10010, &ENTRY_AROMATIZER_15090680470059619273)],
        &[(0b10010, &ENTRY_AROMATIZES_11882880046820259901)],
        &[(0b10010, &ENTRY_AROMATIZING_12161529232297358732)],
        &[(0b11010, &ENTRY_AROMATITE_10237287526340905609)],
        &[(0b00001, &ENTRY_AROMATITE_10237287526340905609)],
        &[(0b01001, &ENTRY_AROMATIZATION_5370295794385992127)],
        &[(0b01001, &ENTRY_AROMATIZE_17577690372454585657)],
        &[(0b01001, &ENTRY_AROMATIZED_5000984731968850520)],
        &[(0b01001, &ENTRY_AROMATIZER_15090680470059619273)],
        &[(0b01001, &ENTRY_AROMATIZES_11882880046820259901)],
        &[(0b01001, &ENTRY_AROMATIZING_12161529232297358732)],
    ],
    range: 6..=10,
};

static VARS_ARM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARM_CHILDREN),
    value: None,
};

pub static VARS_ARM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("orbearer"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("orer"),
        dictgen::InsensitiveStr::Ascii("orers"),
        dictgen::InsensitiveStr::Ascii("oried"),
        dictgen::InsensitiveStr::Ascii("ories"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("orless"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("ory"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ourbearer"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ourer"),
        dictgen::InsensitiveStr::Ascii("ourers"),
        dictgen::InsensitiveStr::Ascii("ouried"),
        dictgen::InsensitiveStr::Ascii("ouries"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ourless"),
        dictgen::InsensitiveStr::Ascii("ours"),
        dictgen::InsensitiveStr::Ascii("oury"),
    ],
    values: &[
        &[(0b11001, &ENTRY_ARMOR_4945447914484381803)],
        &[(0b11001, &ENTRY_ARMORBEARER_1318126373750206677)],
        &[(0b11001, &ENTRY_ARMORED_214663291627156832)],
        &[(0b11001, &ENTRY_ARMORER_15410308267945880573)],
        &[(0b11001, &ENTRY_ARMORERS_15576792766558527660)],
        &[(0b11001, &ENTRY_ARMORIED_13916682178209009712)],
        &[(0b11001, &ENTRY_ARMORIES_338319230858200174)],
        &[(0b11001, &ENTRY_ARMORING_10102011884001661988)],
        &[(0b11001, &ENTRY_ARMORLESS_3900174637867577616)],
        &[(0b11001, &ENTRY_ARMORS_14520485620428417155)],
        &[(0b11001, &ENTRY_ARMORY_13479680231027438950)],
        &[(0b11010, &ENTRY_ARMOR_4945447914484381803)],
        &[(0b11010, &ENTRY_ARMORBEARER_1318126373750206677)],
        &[(0b11010, &ENTRY_ARMORED_214663291627156832)],
        &[(0b11010, &ENTRY_ARMORER_15410308267945880573)],
        &[(0b11010, &ENTRY_ARMORERS_15576792766558527660)],
        &[(0b11010, &ENTRY_ARMORIED_13916682178209009712)],
        &[(0b11010, &ENTRY_ARMORIES_338319230858200174)],
        &[(0b11010, &ENTRY_ARMORING_10102011884001661988)],
        &[(0b11010, &ENTRY_ARMORLESS_3900174637867577616)],
        &[(0b11010, &ENTRY_ARMORS_14520485620428417155)],
        &[(0b11010, &ENTRY_ARMORY_13479680231027438950)],
    ],
    range: 2..=9,
};

static VARS_ARI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARI_CHILDREN),
    value: None,
};

pub static VARS_ARI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("mathaea"),
        dictgen::InsensitiveStr::Ascii("mathaean"),
        dictgen::InsensitiveStr::Ascii("mathea"),
        dictgen::InsensitiveStr::Ascii("mathean"),
        dictgen::InsensitiveStr::Ascii("stae"),
        dictgen::InsensitiveStr::Ascii("ste"),
        dictgen::InsensitiveStr::Ascii("thmetisation"),
        dictgen::InsensitiveStr::Ascii("thmetisations"),
        dictgen::InsensitiveStr::Ascii("thmetise"),
        dictgen::InsensitiveStr::Ascii("thmetised"),
        dictgen::InsensitiveStr::Ascii("thmetises"),
        dictgen::InsensitiveStr::Ascii("thmetization"),
        dictgen::InsensitiveStr::Ascii("thmetizations"),
        dictgen::InsensitiveStr::Ascii("thmetize"),
        dictgen::InsensitiveStr::Ascii("thmetized"),
        dictgen::InsensitiveStr::Ascii("thmetizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ARIANIZE_132906611228004832)],
        &[(0b10010, &ENTRY_ARIANIZED_13031592665042016626)],
        &[(0b10010, &ENTRY_ARIANIZES_10045790284059712906)],
        &[(0b10010, &ENTRY_ARIANIZING_8099459434965318815)],
        &[(0b01001, &ENTRY_ARIANIZE_132906611228004832)],
        &[(0b01001, &ENTRY_ARIANIZED_13031592665042016626)],
        &[(0b01001, &ENTRY_ARIANIZES_10045790284059712906)],
        &[(0b01001, &ENTRY_ARIANIZING_8099459434965318815)],
        &[(0b11010, &ENTRY_ARIMATHEA_4355699317638704668)],
        &[(0b11010, &ENTRY_ARIMATHEAN_18132742646935014444)],
        &[(0b10001, &ENTRY_ARIMATHEA_4355699317638704668)],
        &[(0b10001, &ENTRY_ARIMATHEAN_18132742646935014444)],
        &[(0b11010, &ENTRY_ARISTE_13211696162410295795)],
        &[(0b00001, &ENTRY_ARISTE_13211696162410295795)],
        &[(0b10010, &ENTRY_ARITHMETIZATION_15007145642640225991)],
        &[(0b10010, &ENTRY_ARITHMETIZATIONS_11414688757734327435)],
        &[(0b10010, &ENTRY_ARITHMETIZE_1188073595390850037)],
        &[(0b10010, &ENTRY_ARITHMETIZED_3086309834161067134)],
        &[(0b10010, &ENTRY_ARITHMETIZES_4861809149355233475)],
        &[(0b01001, &ENTRY_ARITHMETIZATION_15007145642640225991)],
        &[(0b01001, &ENTRY_ARITHMETIZATIONS_11414688757734327435)],
        &[(0b01001, &ENTRY_ARITHMETIZE_1188073595390850037)],
        &[(0b01001, &ENTRY_ARITHMETIZED_3086309834161067134)],
        &[(0b01001, &ENTRY_ARITHMETIZES_4861809149355233475)],
    ],
    range: 3..=13,
};

static VARS_ARE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARE_CHILDREN),
    value: None,
};

pub static VARS_ARE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ic"),
        dictgen::InsensitiveStr::Ascii("nicolor"),
        dictgen::InsensitiveStr::Ascii("nicolour"),
        dictgen::InsensitiveStr::Ascii("ographer"),
        dictgen::InsensitiveStr::Ascii("ographic"),
        dictgen::InsensitiveStr::Ascii("ographical"),
        dictgen::InsensitiveStr::Ascii("ographies"),
        dictgen::InsensitiveStr::Ascii("ography"),
        dictgen::InsensitiveStr::Ascii("olae"),
        dictgen::InsensitiveStr::Ascii("ole"),
        dictgen::InsensitiveStr::Ascii("ologic"),
        dictgen::InsensitiveStr::Ascii("ological"),
        dictgen::InsensitiveStr::Ascii("ologies"),
        dictgen::InsensitiveStr::Ascii("ologist"),
        dictgen::InsensitiveStr::Ascii("ology"),
        dictgen::InsensitiveStr::Ascii("ometer"),
        dictgen::InsensitiveStr::Ascii("ometers"),
        dictgen::InsensitiveStr::Ascii("ometric"),
        dictgen::InsensitiveStr::Ascii("ometrical"),
        dictgen::InsensitiveStr::Ascii("ostyle"),
        dictgen::InsensitiveStr::Ascii("ostyles"),
        dictgen::InsensitiveStr::Ascii("osystyle"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AERIC_10020180033075484870)],
        &[(0b10001, &ENTRY_ARENICOLOR_5592467329818263804)],
        &[(0b11010, &ENTRY_ARENICOLOR_5592467329818263804)],
        &[(0b11010, &ENTRY_AEROGRAPHER_85789760672961791)],
        &[(0b11010, &ENTRY_AEROGRAPHIC_5707019479991978033)],
        &[(0b11010, &ENTRY_AEROGRAPHICAL_12793888458146758836)],
        &[(0b11010, &ENTRY_AEROGRAPHIES_9522044483381698756)],
        &[(0b11010, &ENTRY_AEROGRAPHY_9279141637627756120)],
        &[(0b11010, &ENTRY_AREOLE_1506224537716675700)],
        &[(0b00001, &ENTRY_AREOLE_1506224537716675700)],
        &[(0b11010, &ENTRY_AEROLOGIC_12163962530263481700)],
        &[(0b11010, &ENTRY_AEROLOGICAL_7520248570186497308)],
        &[(0b11010, &ENTRY_AEROLOGIES_4052658077915194200)],
        &[(0b11010, &ENTRY_AEROLOGIST_233176875293717737)],
        &[(0b11010, &ENTRY_AEROLOGY_3025685712114846212)],
        &[(0b11010, &ENTRY_AEROMETER_17405185222225302259)],
        &[(0b11010, &ENTRY_AEROMETERS_10976694975875082042)],
        &[
            (0b11010, &ENTRY_AEROMETRIC_357071446782082902),
            (0b00001, &ENTRY_AREOMETRIC_5287406644094522168),
        ],
        &[(0b10001, &ENTRY_AREOMETRICAL_5744079483158577745)],
        &[(0b10001, &ENTRY_AREOSTYLE_11631549334090315083)],
        &[(0b10001, &ENTRY_AREOSTYLES_813590045775141111)],
        &[(0b00001, &ENTRY_AREOSYSTYLE_15780594127227324055)],
    ],
    range: 2..=10,
};

static VARS_ARD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARD_CHILDREN),
    value: None,
};

pub static VARS_ARD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_ARDOR_14403534690593993712)],
        &[(0b11001, &ENTRY_ARDORS_3754540775895817864)],
        &[(0b11010, &ENTRY_ARDOR_14403534690593993712)],
        &[(0b11010, &ENTRY_ARDORS_3754540775895817864)],
    ],
    range: 2..=4,
};

static VARS_ARC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARC_CHILDREN),
    value: None,
};

pub static VARS_ARC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hae"),
        dictgen::InsensitiveStr::Ascii("haeal"),
        dictgen::InsensitiveStr::Ascii("haean"),
        dictgen::InsensitiveStr::Ascii("haei"),
        dictgen::InsensitiveStr::Ascii("haeoastronomies"),
        dictgen::InsensitiveStr::Ascii("haeoastronomy"),
        dictgen::InsensitiveStr::Ascii("haeocyte"),
        dictgen::InsensitiveStr::Ascii("haeol"),
        dictgen::InsensitiveStr::Ascii("haeolithic"),
        dictgen::InsensitiveStr::Ascii("haeologian"),
        dictgen::InsensitiveStr::Ascii("haeometries"),
        dictgen::InsensitiveStr::Ascii("haeometry"),
        dictgen::InsensitiveStr::Ascii("haeozic"),
        dictgen::InsensitiveStr::Ascii("haeozoic"),
        dictgen::InsensitiveStr::Ascii("haeus"),
        dictgen::InsensitiveStr::Ascii("haise"),
        dictgen::InsensitiveStr::Ascii("haised"),
        dictgen::InsensitiveStr::Ascii("haiser"),
        dictgen::InsensitiveStr::Ascii("haisers"),
        dictgen::InsensitiveStr::Ascii("haises"),
        dictgen::InsensitiveStr::Ascii("haising"),
        dictgen::InsensitiveStr::Ascii("haize"),
        dictgen::InsensitiveStr::Ascii("haized"),
        dictgen::InsensitiveStr::Ascii("haizer"),
        dictgen::InsensitiveStr::Ascii("haizers"),
        dictgen::InsensitiveStr::Ascii("haizes"),
        dictgen::InsensitiveStr::Ascii("haizing"),
        dictgen::InsensitiveStr::Ascii("he"),
        dictgen::InsensitiveStr::Ascii("heal"),
        dictgen::InsensitiveStr::Ascii("hean"),
        dictgen::InsensitiveStr::Ascii("hei"),
        dictgen::InsensitiveStr::Ascii("heoastronomies"),
        dictgen::InsensitiveStr::Ascii("heoastronomy"),
        dictgen::InsensitiveStr::Ascii("heocyte"),
        dictgen::InsensitiveStr::Ascii("heol"),
        dictgen::InsensitiveStr::Ascii("heolithic"),
        dictgen::InsensitiveStr::Ascii("heologian"),
        dictgen::InsensitiveStr::Ascii("heologic"),
        dictgen::InsensitiveStr::Ascii("heological"),
        dictgen::InsensitiveStr::Ascii("heologies"),
        dictgen::InsensitiveStr::Ascii("heologist"),
        dictgen::InsensitiveStr::Ascii("heologists"),
        dictgen::InsensitiveStr::Ascii("heology"),
        dictgen::InsensitiveStr::Ascii("heometries"),
        dictgen::InsensitiveStr::Ascii("heometry"),
        dictgen::InsensitiveStr::Ascii("heozic"),
        dictgen::InsensitiveStr::Ascii("heozoic"),
        dictgen::InsensitiveStr::Ascii("heus"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
        dictgen::InsensitiveStr::Ascii("togaea"),
        dictgen::InsensitiveStr::Ascii("togaean"),
        dictgen::InsensitiveStr::Ascii("togaeic"),
        dictgen::InsensitiveStr::Ascii("togea"),
        dictgen::InsensitiveStr::Ascii("togean"),
        dictgen::InsensitiveStr::Ascii("togeic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ARCHE_18301530557274881676)],
        &[(0b11010, &ENTRY_ARCHEAL_13572196168963327074)],
        &[(0b11010, &ENTRY_ARCHEAN_937087822525818400)],
        &[(0b11010, &ENTRY_ARCHEI_13567272772083540797)],
        &[(0b11010, &ENTRY_ARCHEOASTRONOMIES_3188854482470694849)],
        &[(0b11010, &ENTRY_ARCHEOASTRONOMY_14404673011142855883)],
        &[(0b11010, &ENTRY_ARCHEOCYTE_6518656963202380847)],
        &[(0b11010, &ENTRY_ARCHEOL_1850162685385094711)],
        &[(0b11010, &ENTRY_ARCHEOLITHIC_13669598449916969809)],
        &[(0b11010, &ENTRY_ARCHEOLOGIAN_7486816702727031922)],
        &[(0b11010, &ENTRY_ARCHEOMETRIES_18248570031046455194)],
        &[(0b11010, &ENTRY_ARCHEOMETRY_11263439246356993945)],
        &[(0b11010, &ENTRY_ARCHEOZIC_6812126952578611645)],
        &[(0b11010, &ENTRY_ARCHEOZOIC_12688097476418777680)],
        &[(0b11010, &ENTRY_ARCHEUS_1712692449173846724)],
        &[(0b10010, &ENTRY_ARCHAIZE_306453875004862597)],
        &[(0b10010, &ENTRY_ARCHAIZED_17502443965255232728)],
        &[(0b10010, &ENTRY_ARCHAIZER_5219609326176256547)],
        &[(0b10010, &ENTRY_ARCHAIZERS_11861316159781209222)],
        &[(0b10010, &ENTRY_ARCHAIZES_3289069090284787945)],
        &[(0b10010, &ENTRY_ARCHAIZING_3514060218818847476)],
        &[(0b01001, &ENTRY_ARCHAIZE_306453875004862597)],
        &[(0b01001, &ENTRY_ARCHAIZED_17502443965255232728)],
        &[(0b01001, &ENTRY_ARCHAIZER_5219609326176256547)],
        &[(0b01001, &ENTRY_ARCHAIZERS_11861316159781209222)],
        &[(0b01001, &ENTRY_ARCHAIZES_3289069090284787945)],
        &[(0b01001, &ENTRY_ARCHAIZING_3514060218818847476)],
        &[(0b00001, &ENTRY_ARCHE_18301530557274881676)],
        &[(0b10001, &ENTRY_ARCHEAL_13572196168963327074)],
        &[(0b10001, &ENTRY_ARCHEAN_937087822525818400)],
        &[(0b10001, &ENTRY_ARCHEI_13567272772083540797)],
        &[(0b10001, &ENTRY_ARCHEOASTRONOMIES_3188854482470694849)],
        &[(0b10001, &ENTRY_ARCHEOASTRONOMY_14404673011142855883)],
        &[(0b10001, &ENTRY_ARCHEOCYTE_6518656963202380847)],
        &[(0b10001, &ENTRY_ARCHEOL_1850162685385094711)],
        &[(0b10001, &ENTRY_ARCHEOLITHIC_13669598449916969809)],
        &[(0b10001, &ENTRY_ARCHEOLOGIAN_7486816702727031922)],
        &[(0b11001, &ENTRY_ARCHAEOLOGIC_175348203002056666)],
        &[(0b11001, &ENTRY_ARCHAEOLOGICAL_10563432210833298458)],
        &[(0b11001, &ENTRY_ARCHAEOLOGIES_8039431778163772974)],
        &[(0b11001, &ENTRY_ARCHAEOLOGIST_12712686763317819627)],
        &[(0b11001, &ENTRY_ARCHAEOLOGISTS_15763944587883983376)],
        &[(0b11001, &ENTRY_ARCHAEOLOGY_10452692803395720100)],
        &[(0b10001, &ENTRY_ARCHEOMETRIES_18248570031046455194)],
        &[(0b10001, &ENTRY_ARCHEOMETRY_11263439246356993945)],
        &[(0b10001, &ENTRY_ARCHEOZIC_6812126952578611645)],
        &[(0b10001, &ENTRY_ARCHEOZOIC_12688097476418777680)],
        &[(0b10001, &ENTRY_ARCHEUS_1712692449173846724)],
        &[(0b10010, &ENTRY_ARCTICIZE_6133925135946423979)],
        &[(0b10010, &ENTRY_ARCTICIZES_9212958491318640697)],
        &[(0b01001, &ENTRY_ARCTICIZE_6133925135946423979)],
        &[(0b01001, &ENTRY_ARCTICIZES_9212958491318640697)],
        &[(0b11010, &ENTRY_ARCTOGEA_7460167982401069798)],
        &[(0b11010, &ENTRY_ARCTOGEAN_3817144683623578243)],
        &[(0b11010, &ENTRY_ARCTOGEIC_6444012158676125424)],
        &[(0b10001, &ENTRY_ARCTOGEA_7460167982401069798)],
        &[(0b10001, &ENTRY_ARCTOGEAN_3817144683623578243)],
        &[(0b10001, &ENTRY_ARCTOGEIC_6444012158676125424)],
    ],
    range: 2..=15,
};

static VARS_ARB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARB_CHILDREN),
    value: None,
};

pub static VARS_ARB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alester"),
        dictgen::InsensitiveStr::Ascii("alestre"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("ores"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("oures"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ARBALESTER_6838431227178078005)],
        &[(0b11010, &ENTRY_ARBALESTER_6838431227178078005)],
        &[(0b01001, &ENTRY_ARBOR_820303798692032572)],
        &[(0b00001, &ENTRY_ARBORED_9841319088226677951)],
        &[(0b01001, &ENTRY_ARBORES_15360373317740002388)],
        &[(0b10010, &ENTRY_ARBORIZATION_15816140615041238184)],
        &[(0b10010, &ENTRY_ARBORIZATIONS_4188589807836256359)],
        &[(0b10010, &ENTRY_ARBORIZE_141711185842618556)],
        &[(0b10010, &ENTRY_ARBORIZED_13640543823605553558)],
        &[(0b10010, &ENTRY_ARBORIZES_3017079272082009873)],
        &[(0b10010, &ENTRY_ARBORIZING_5466669619685035391)],
        &[(0b01001, &ENTRY_ARBORIZATION_15816140615041238184)],
        &[(0b01001, &ENTRY_ARBORIZATIONS_4188589807836256359)],
        &[(0b01001, &ENTRY_ARBORIZE_141711185842618556)],
        &[(0b01001, &ENTRY_ARBORIZED_13640543823605553558)],
        &[(0b01001, &ENTRY_ARBORIZES_3017079272082009873)],
        &[(0b01001, &ENTRY_ARBORIZING_5466669619685035391)],
        &[(0b01001, &ENTRY_ARBORS_2769870038356325080)],
        &[(0b11010, &ENTRY_ARBOR_820303798692032572)],
        &[(0b11010, &ENTRY_ARBORED_9841319088226677951)],
        &[(0b11010, &ENTRY_ARBORES_15360373317740002388)],
        &[(0b11010, &ENTRY_ARBORS_2769870038356325080)],
    ],
    range: 2..=10,
};

static VARS_ARA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARA_CHILDREN),
    value: None,
};

pub static VARS_ARA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bianise"),
        dictgen::InsensitiveStr::Ascii("bianises"),
        dictgen::InsensitiveStr::Ascii("bianize"),
        dictgen::InsensitiveStr::Ascii("bianizes"),
        dictgen::InsensitiveStr::Ascii("bicise"),
        dictgen::InsensitiveStr::Ascii("bicises"),
        dictgen::InsensitiveStr::Ascii("bicize"),
        dictgen::InsensitiveStr::Ascii("bicizes"),
        dictgen::InsensitiveStr::Ascii("bisation"),
        dictgen::InsensitiveStr::Ascii("bisations"),
        dictgen::InsensitiveStr::Ascii("bise"),
        dictgen::InsensitiveStr::Ascii("bised"),
        dictgen::InsensitiveStr::Ascii("bises"),
        dictgen::InsensitiveStr::Ascii("bising"),
        dictgen::InsensitiveStr::Ascii("bization"),
        dictgen::InsensitiveStr::Ascii("bizations"),
        dictgen::InsensitiveStr::Ascii("bize"),
        dictgen::InsensitiveStr::Ascii("bized"),
        dictgen::InsensitiveStr::Ascii("bizes"),
        dictgen::InsensitiveStr::Ascii("bizing"),
        dictgen::InsensitiveStr::Ascii("eometric"),
        dictgen::InsensitiveStr::Ascii("eometrical"),
        dictgen::InsensitiveStr::Ascii("eostyle"),
        dictgen::InsensitiveStr::Ascii("eostyles"),
        dictgen::InsensitiveStr::Ascii("eosystyle"),
        dictgen::InsensitiveStr::Ascii("maean"),
        dictgen::InsensitiveStr::Ascii("maeans"),
        dictgen::InsensitiveStr::Ascii("mean"),
        dictgen::InsensitiveStr::Ascii("means"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ARABIANIZE_14680629114410755510)],
        &[(0b10010, &ENTRY_ARABIANIZES_15399320604140902223)],
        &[(0b01001, &ENTRY_ARABIANIZE_14680629114410755510)],
        &[(0b01001, &ENTRY_ARABIANIZES_15399320604140902223)],
        &[(0b10010, &ENTRY_ARABICIZE_9338400257314658821)],
        &[(0b10010, &ENTRY_ARABICIZES_7961526175874963709)],
        &[(0b01001, &ENTRY_ARABICIZE_9338400257314658821)],
        &[(0b01001, &ENTRY_ARABICIZES_7961526175874963709)],
        &[(0b10010, &ENTRY_ARABIZATION_471491823646004633)],
        &[(0b10010, &ENTRY_ARABIZATIONS_7991225374353590906)],
        &[(0b10010, &ENTRY_ARABIZE_13835410304137115221)],
        &[(0b10010, &ENTRY_ARABIZED_12134857612665569800)],
        &[(0b10010, &ENTRY_ARABIZES_4001226046137904360)],
        &[(0b10010, &ENTRY_ARABIZING_209764483654246227)],
        &[(0b01001, &ENTRY_ARABIZATION_471491823646004633)],
        &[(0b01001, &ENTRY_ARABIZATIONS_7991225374353590906)],
        &[(0b01001, &ENTRY_ARABIZE_13835410304137115221)],
        &[(0b01001, &ENTRY_ARABIZED_12134857612665569800)],
        &[(0b01001, &ENTRY_ARABIZES_4001226046137904360)],
        &[(0b01001, &ENTRY_ARABIZING_209764483654246227)],
        &[(0b11010, &ENTRY_AREOMETRIC_5287406644094522168)],
        &[(0b11010, &ENTRY_AREOMETRICAL_5744079483158577745)],
        &[(0b11010, &ENTRY_AREOSTYLE_11631549334090315083)],
        &[(0b11010, &ENTRY_AREOSTYLES_813590045775141111)],
        &[(0b11010, &ENTRY_AREOSYSTYLE_15780594127227324055)],
        &[(0b11010, &ENTRY_ARAMEAN_8841768638879589571)],
        &[(0b11010, &ENTRY_ARAMEANS_5599443395276229615)],
        &[(0b10001, &ENTRY_ARAMEAN_8841768638879589571)],
        &[(0b10001, &ENTRY_ARAMEANS_5599443395276229615)],
    ],
    range: 4..=10,
};

static VARS_AP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AP_CHILDREN),
    value: None,
};

static VARS_AP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_APA_NODE),
    None,
    None,
    None,
    Some(&VARS_APE_NODE),
    None,
    None,
    Some(&VARS_APH_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_APN_NODE),
    Some(&VARS_APO_NODE),
    Some(&VARS_APP_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_APP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APP_CHILDREN),
    value: None,
};

pub static VARS_APP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("al"),
        dictgen::InsensitiveStr::Ascii("all"),
        dictgen::InsensitiveStr::Ascii("alls"),
        dictgen::InsensitiveStr::Ascii("als"),
        dictgen::InsensitiveStr::Ascii("areled"),
        dictgen::InsensitiveStr::Ascii("areling"),
        dictgen::InsensitiveStr::Ascii("arelled"),
        dictgen::InsensitiveStr::Ascii("arelling"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etisement"),
        dictgen::InsensitiveStr::Ascii("etisements"),
        dictgen::InsensitiveStr::Ascii("etiser"),
        dictgen::InsensitiveStr::Ascii("etisers"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etising"),
        dictgen::InsensitiveStr::Ascii("etisingly"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizement"),
        dictgen::InsensitiveStr::Ascii("etizements"),
        dictgen::InsensitiveStr::Ascii("etizer"),
        dictgen::InsensitiveStr::Ascii("etizers"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("etizing"),
        dictgen::InsensitiveStr::Ascii("etizingly"),
        dictgen::InsensitiveStr::Ascii("risal"),
        dictgen::InsensitiveStr::Ascii("riser"),
        dictgen::InsensitiveStr::Ascii("risers"),
        dictgen::InsensitiveStr::Ascii("risings"),
        dictgen::InsensitiveStr::Ascii("rizal"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizer"),
        dictgen::InsensitiveStr::Ascii("rizers"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
        dictgen::InsensitiveStr::Ascii("rizings"),
    ],
    values: &[
        &[(0b11010, &ENTRY_APPALL_3381232000687374522)],
        &[(0b11001, &ENTRY_APPALL_3381232000687374522)],
        &[(0b11001, &ENTRY_APPALLS_14971304364498187153)],
        &[(0b11010, &ENTRY_APPALLS_14971304364498187153)],
        &[(0b00001, &ENTRY_APPARELED_5914262035984071991)],
        &[(0b00001, &ENTRY_APPARELING_11650623594673700867)],
        &[(0b11010, &ENTRY_APPARELED_5914262035984071991)],
        &[(0b11010, &ENTRY_APPARELING_11650623594673700867)],
        &[(0b10010, &ENTRY_APPETIZE_12214870214458995398)],
        &[(0b10010, &ENTRY_APPETIZED_12779274256898682576)],
        &[(0b10010, &ENTRY_APPETIZEMENT_8175094878206216152)],
        &[(0b10010, &ENTRY_APPETIZEMENTS_5259246039149445790)],
        &[(0b10010, &ENTRY_APPETIZER_8559355853918389374)],
        &[(0b10010, &ENTRY_APPETIZERS_5843282302692262805)],
        &[(0b10010, &ENTRY_APPETIZES_14250778261697102866)],
        &[(0b10010, &ENTRY_APPETIZING_3391416091007273367)],
        &[(0b10010, &ENTRY_APPETIZINGLY_9913312311160671376)],
        &[(0b01001, &ENTRY_APPETIZE_12214870214458995398)],
        &[(0b01001, &ENTRY_APPETIZED_12779274256898682576)],
        &[(0b01001, &ENTRY_APPETIZEMENT_8175094878206216152)],
        &[(0b01001, &ENTRY_APPETIZEMENTS_5259246039149445790)],
        &[(0b01001, &ENTRY_APPETIZER_8559355853918389374)],
        &[(0b01001, &ENTRY_APPETIZERS_5843282302692262805)],
        &[(0b01001, &ENTRY_APPETIZES_14250778261697102866)],
        &[(0b01001, &ENTRY_APPETIZING_3391416091007273367)],
        &[(0b01001, &ENTRY_APPETIZINGLY_9913312311160671376)],
        &[(0b10010, &ENTRY_APPRIZAL_3560063918703465624)],
        &[(0b10010, &ENTRY_APPRIZER_18426176719486326401)],
        &[(0b10010, &ENTRY_APPRIZERS_15195711748329559838)],
        &[(0b10010, &ENTRY_APPRIZINGS_6514643279295543384)],
        &[(0b01001, &ENTRY_APPRIZAL_3560063918703465624)],
        &[(0b01001, &ENTRY_APPRIZE_2772227233704893376)],
        &[(0b01001, &ENTRY_APPRIZED_15906383243546321609)],
        &[(0b01001, &ENTRY_APPRIZER_18426176719486326401)],
        &[(0b01001, &ENTRY_APPRIZERS_15195711748329559838)],
        &[(0b01001, &ENTRY_APPRIZES_16502352422245789053)],
        &[(0b01001, &ENTRY_APPRIZING_12688699470215267857)],
        &[(0b01001, &ENTRY_APPRIZINGS_6514643279295543384)],
    ],
    range: 2..=10,
};

static VARS_APO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_APO_CHILDREN),
    value: None,
};

static VARS_APO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_APOC_NODE),
    None,
    None,
    None,
    Some(&VARS_APOG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_APOL_NODE),
    None,
    None,
    None,
    Some(&VARS_APOP_NODE),
    None,
    Some(&VARS_APOR_NODE),
    Some(&VARS_APOS_NODE),
    Some(&VARS_APOT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_APOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOT_CHILDREN),
    value: None,
};

pub static VARS_APOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hegmatise"),
        dictgen::InsensitiveStr::Ascii("hegmatised"),
        dictgen::InsensitiveStr::Ascii("hegmatises"),
        dictgen::InsensitiveStr::Ascii("hegmatising"),
        dictgen::InsensitiveStr::Ascii("hegmatize"),
        dictgen::InsensitiveStr::Ascii("hegmatized"),
        dictgen::InsensitiveStr::Ascii("hegmatizes"),
        dictgen::InsensitiveStr::Ascii("hegmatizing"),
        dictgen::InsensitiveStr::Ascii("heosise"),
        dictgen::InsensitiveStr::Ascii("heosised"),
        dictgen::InsensitiveStr::Ascii("heosises"),
        dictgen::InsensitiveStr::Ascii("heosising"),
        dictgen::InsensitiveStr::Ascii("heosize"),
        dictgen::InsensitiveStr::Ascii("heosized"),
        dictgen::InsensitiveStr::Ascii("heosizes"),
        dictgen::InsensitiveStr::Ascii("heosizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_APOTHEGMATIZE_15318646925264020123)],
        &[(0b10010, &ENTRY_APOTHEGMATIZED_11678983898765728976)],
        &[(0b10010, &ENTRY_APOTHEGMATIZES_6292798390810092901)],
        &[(0b10010, &ENTRY_APOTHEGMATIZING_10622191304514739480)],
        &[(0b01001, &ENTRY_APOTHEGMATIZE_15318646925264020123)],
        &[(0b01001, &ENTRY_APOTHEGMATIZED_11678983898765728976)],
        &[(0b01001, &ENTRY_APOTHEGMATIZES_6292798390810092901)],
        &[(0b01001, &ENTRY_APOTHEGMATIZING_10622191304514739480)],
        &[(0b10010, &ENTRY_APOTHEOSIZE_6351046197862617198)],
        &[(0b10010, &ENTRY_APOTHEOSIZED_8172850542068614358)],
        &[(0b10010, &ENTRY_APOTHEOSIZES_3324551187478048042)],
        &[(0b10010, &ENTRY_APOTHEOSIZING_10080445523181927742)],
        &[(0b01001, &ENTRY_APOTHEOSIZE_6351046197862617198)],
        &[(0b01001, &ENTRY_APOTHEOSIZED_8172850542068614358)],
        &[(0b01001, &ENTRY_APOTHEOSIZES_3324551187478048042)],
        &[(0b01001, &ENTRY_APOTHEOSIZING_10080445523181927742)],
    ],
    range: 7..=11,
};

static VARS_APOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOS_CHILDREN),
    value: None,
};

pub static VARS_APOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tatisation"),
        dictgen::InsensitiveStr::Ascii("tatise"),
        dictgen::InsensitiveStr::Ascii("tatised"),
        dictgen::InsensitiveStr::Ascii("tatises"),
        dictgen::InsensitiveStr::Ascii("tatising"),
        dictgen::InsensitiveStr::Ascii("tatization"),
        dictgen::InsensitiveStr::Ascii("tatize"),
        dictgen::InsensitiveStr::Ascii("tatized"),
        dictgen::InsensitiveStr::Ascii("tatizes"),
        dictgen::InsensitiveStr::Ascii("tatizing"),
        dictgen::InsensitiveStr::Ascii("tolise"),
        dictgen::InsensitiveStr::Ascii("tolised"),
        dictgen::InsensitiveStr::Ascii("tolises"),
        dictgen::InsensitiveStr::Ascii("tolising"),
        dictgen::InsensitiveStr::Ascii("tolize"),
        dictgen::InsensitiveStr::Ascii("tolized"),
        dictgen::InsensitiveStr::Ascii("tolizes"),
        dictgen::InsensitiveStr::Ascii("tolizing"),
        dictgen::InsensitiveStr::Ascii("trophise"),
        dictgen::InsensitiveStr::Ascii("trophised"),
        dictgen::InsensitiveStr::Ascii("trophises"),
        dictgen::InsensitiveStr::Ascii("trophising"),
        dictgen::InsensitiveStr::Ascii("trophize"),
        dictgen::InsensitiveStr::Ascii("trophized"),
        dictgen::InsensitiveStr::Ascii("trophizes"),
        dictgen::InsensitiveStr::Ascii("trophizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_APOSTATIZATION_1527034887052638394)],
        &[(0b10010, &ENTRY_APOSTATIZE_13080506949193574486)],
        &[(0b10010, &ENTRY_APOSTATIZED_44225222340281598)],
        &[(0b10010, &ENTRY_APOSTATIZES_10706409261795785069)],
        &[(0b10010, &ENTRY_APOSTATIZING_18253376445779049751)],
        &[(0b01001, &ENTRY_APOSTATIZATION_1527034887052638394)],
        &[(0b01001, &ENTRY_APOSTATIZE_13080506949193574486)],
        &[(0b01001, &ENTRY_APOSTATIZED_44225222340281598)],
        &[(0b01001, &ENTRY_APOSTATIZES_10706409261795785069)],
        &[(0b01001, &ENTRY_APOSTATIZING_18253376445779049751)],
        &[(0b10010, &ENTRY_APOSTOLIZE_16199580758148929809)],
        &[(0b10010, &ENTRY_APOSTOLIZED_12140472803938774313)],
        &[(0b10010, &ENTRY_APOSTOLIZES_10959422959941305594)],
        &[(0b10010, &ENTRY_APOSTOLIZING_1815559841608331448)],
        &[(0b01001, &ENTRY_APOSTOLIZE_16199580758148929809)],
        &[(0b01001, &ENTRY_APOSTOLIZED_12140472803938774313)],
        &[(0b01001, &ENTRY_APOSTOLIZES_10959422959941305594)],
        &[(0b01001, &ENTRY_APOSTOLIZING_1815559841608331448)],
        &[(0b10010, &ENTRY_APOSTROPHIZE_17888463482112539780)],
        &[(0b10010, &ENTRY_APOSTROPHIZED_10611323756896254538)],
        &[(0b10010, &ENTRY_APOSTROPHIZES_14704113907193101943)],
        &[(0b10010, &ENTRY_APOSTROPHIZING_5813087553114165636)],
        &[(0b01001, &ENTRY_APOSTROPHIZE_17888463482112539780)],
        &[(0b01001, &ENTRY_APOSTROPHIZED_10611323756896254538)],
        &[(0b01001, &ENTRY_APOSTROPHIZES_14704113907193101943)],
        &[(0b01001, &ENTRY_APOSTROPHIZING_5813087553114165636)],
    ],
    range: 6..=10,
};

static VARS_APOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOR_CHILDREN),
    value: None,
};

pub static VARS_APOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rhea"),
        dictgen::InsensitiveStr::Ascii("rhoea"),
    ],
    values: &[
        &[(0b10001, &ENTRY_APORRHEA_13505526801378634820)],
        &[(0b11010, &ENTRY_APORRHEA_13505526801378634820)],
    ],
    range: 4..=5,
};

static VARS_APOP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOP_CHILDREN),
    value: None,
};

pub static VARS_APOP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hthegmatise"),
        dictgen::InsensitiveStr::Ascii("hthegmatised"),
        dictgen::InsensitiveStr::Ascii("hthegmatises"),
        dictgen::InsensitiveStr::Ascii("hthegmatising"),
        dictgen::InsensitiveStr::Ascii("hthegmatize"),
        dictgen::InsensitiveStr::Ascii("hthegmatized"),
        dictgen::InsensitiveStr::Ascii("hthegmatizes"),
        dictgen::InsensitiveStr::Ascii("hthegmatizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_APOPHTHEGMATIZE_9322689570481861709)],
        &[(0b10010, &ENTRY_APOPHTHEGMATIZED_15838142809164915173)],
        &[(0b10010, &ENTRY_APOPHTHEGMATIZES_2288182367019688298)],
        &[(0b10010, &ENTRY_APOPHTHEGMATIZING_14335129275871173969)],
        &[(0b01001, &ENTRY_APOPHTHEGMATIZE_9322689570481861709)],
        &[(0b01001, &ENTRY_APOPHTHEGMATIZED_15838142809164915173)],
        &[(0b01001, &ENTRY_APOPHTHEGMATIZES_2288182367019688298)],
        &[(0b01001, &ENTRY_APOPHTHEGMATIZING_14335129275871173969)],
    ],
    range: 11..=13,
};

static VARS_APOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOL_CHILDREN),
    value: None,
};

pub static VARS_APOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogiser"),
        dictgen::InsensitiveStr::Ascii("ogisers"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizer"),
        dictgen::InsensitiveStr::Ascii("ogizers"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_APOLOGIZE_14449570546795754812)],
        &[(0b10010, &ENTRY_APOLOGIZED_3547075355470705991)],
        &[(0b10010, &ENTRY_APOLOGIZER_4129656303394632071)],
        &[(0b10010, &ENTRY_APOLOGIZERS_13562651563373661330)],
        &[(0b10010, &ENTRY_APOLOGIZES_13345357472753740063)],
        &[(0b10010, &ENTRY_APOLOGIZING_16657477641936872991)],
        &[(0b01001, &ENTRY_APOLOGIZE_14449570546795754812)],
        &[(0b01001, &ENTRY_APOLOGIZED_3547075355470705991)],
        &[(0b01001, &ENTRY_APOLOGIZER_4129656303394632071)],
        &[(0b01001, &ENTRY_APOLOGIZERS_13562651563373661330)],
        &[(0b01001, &ENTRY_APOLOGIZES_13345357472753740063)],
        &[(0b01001, &ENTRY_APOLOGIZING_16657477641936872991)],
    ],
    range: 5..=7,
};

static VARS_APOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOG_CHILDREN),
    value: None,
};

pub static VARS_APOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aeic"),
        dictgen::InsensitiveStr::Ascii("eic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_APOGEIC_16938772067630214391)],
        &[(0b00001, &ENTRY_APOGEIC_16938772067630214391)],
    ],
    range: 3..=4,
};

static VARS_APOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOC_CHILDREN),
    value: None,
};

pub static VARS_APOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("entre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_APOCENTER_11458252478295656911)],
        &[(0b11010, &ENTRY_APOCENTER_11458252478295656911)],
    ],
    range: 5..=5,
};

static VARS_APN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APN_CHILDREN),
    value: None,
};

pub static VARS_APN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("eal"),
        dictgen::InsensitiveStr::Ascii("eas"),
        dictgen::InsensitiveStr::Ascii("eic"),
        dictgen::InsensitiveStr::Ascii("oea"),
        dictgen::InsensitiveStr::Ascii("oeal"),
        dictgen::InsensitiveStr::Ascii("oeas"),
        dictgen::InsensitiveStr::Ascii("oeic"),
    ],
    values: &[
        &[(0b11001, &ENTRY_APNEA_6406034786678842123)],
        &[(0b10001, &ENTRY_APNEAL_7893743730769229693)],
        &[(0b11001, &ENTRY_APNEAS_2550899720378134826)],
        &[(0b10001, &ENTRY_APNEIC_11719839066153327453)],
        &[(0b10010, &ENTRY_APNEA_6406034786678842123)],
        &[(0b11010, &ENTRY_APNEAL_7893743730769229693)],
        &[(0b10010, &ENTRY_APNEAS_2550899720378134826)],
        &[(0b11010, &ENTRY_APNEIC_11719839066153327453)],
    ],
    range: 2..=4,
};

static VARS_APH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APH_CHILDREN),
    value: None,
};

pub static VARS_APH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aereses"),
        dictgen::InsensitiveStr::Ascii("aeresis"),
        dictgen::InsensitiveStr::Ascii("aeretic"),
        dictgen::InsensitiveStr::Ascii("ereses"),
        dictgen::InsensitiveStr::Ascii("eresis"),
        dictgen::InsensitiveStr::Ascii("eretic"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etising"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("etizing"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("oriser"),
        dictgen::InsensitiveStr::Ascii("orisers"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizer"),
        dictgen::InsensitiveStr::Ascii("orizers"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_APHERESES_8414108081771472699)],
        &[(0b11010, &ENTRY_APHERESIS_11100589747263615656)],
        &[(0b11010, &ENTRY_APHERETIC_14208620861385679102)],
        &[(0b10001, &ENTRY_APHERESES_8414108081771472699)],
        &[(0b10001, &ENTRY_APHERESIS_11100589747263615656)],
        &[(0b10001, &ENTRY_APHERETIC_14208620861385679102)],
        &[(0b10010, &ENTRY_APHETIZE_16986882047083146683)],
        &[(0b10010, &ENTRY_APHETIZED_1858899614002657210)],
        &[(0b10010, &ENTRY_APHETIZES_2606887081258860354)],
        &[(0b10010, &ENTRY_APHETIZING_18044502082485150756)],
        &[(0b01001, &ENTRY_APHETIZE_16986882047083146683)],
        &[(0b01001, &ENTRY_APHETIZED_1858899614002657210)],
        &[(0b01001, &ENTRY_APHETIZES_2606887081258860354)],
        &[(0b01001, &ENTRY_APHETIZING_18044502082485150756)],
        &[(0b10010, &ENTRY_APHORIZE_17513005870741888985)],
        &[(0b10010, &ENTRY_APHORIZED_10249942663715046169)],
        &[(0b10010, &ENTRY_APHORIZER_8971366374709723247)],
        &[(0b10010, &ENTRY_APHORIZERS_6227464678729995966)],
        &[(0b10010, &ENTRY_APHORIZES_16282592296354062486)],
        &[(0b10010, &ENTRY_APHORIZING_8622079489862524646)],
        &[(0b01001, &ENTRY_APHORIZE_17513005870741888985)],
        &[(0b01001, &ENTRY_APHORIZED_10249942663715046169)],
        &[(0b01001, &ENTRY_APHORIZER_8971366374709723247)],
        &[(0b01001, &ENTRY_APHORIZERS_6227464678729995966)],
        &[(0b01001, &ENTRY_APHORIZES_16282592296354062486)],
        &[(0b01001, &ENTRY_APHORIZING_8622079489862524646)],
    ],
    range: 5..=7,
};

static VARS_APE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APE_CHILDREN),
    value: None,
};

pub static VARS_APE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_APESTHESIA_4947771205873763300)],
        &[(0b00001, &ENTRY_APESTHETIC_12430802871942423809)],
    ],
    range: 7..=7,
};

static VARS_APA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APA_CHILDREN),
    value: None,
};

pub static VARS_APA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_APESTHESIA_4947771205873763300)],
        &[(0b11010, &ENTRY_APESTHETIC_12430802871942423809)],
    ],
    range: 8..=8,
};

static VARS_AN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AN_CHILDREN),
    value: None,
};

static VARS_AN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ANA_NODE),
    None,
    Some(&VARS_ANC_NODE),
    None,
    Some(&VARS_ANE_NODE),
    None,
    Some(&VARS_ANG_NODE),
    Some(&VARS_ANH_NODE),
    Some(&VARS_ANI_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_ANN_NODE),
    Some(&VARS_ANO_NODE),
    None,
    None,
    None,
    Some(&VARS_ANS_NODE),
    Some(&VARS_ANT_NODE),
    None,
    Some(&VARS_ANV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_ANV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANV_CHILDREN),
    value: None,
};

pub static VARS_ANV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iled"),
        dictgen::InsensitiveStr::Ascii("iling"),
        dictgen::InsensitiveStr::Ascii("illed"),
        dictgen::InsensitiveStr::Ascii("illing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ANVILED_10560128408729337292)],
        &[(0b00001, &ENTRY_ANVILING_7433811405855295219)],
        &[(0b11010, &ENTRY_ANVILED_10560128408729337292)],
        &[(0b11010, &ENTRY_ANVILING_7433811405855295219)],
    ],
    range: 4..=6,
};

static VARS_ANT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ANT_CHILDREN),
    value: None,
};

static VARS_ANT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ANTA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ANTH_NODE),
    Some(&VARS_ANTI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ANTI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ANTI_CHILDREN),
    value: None,
};

static VARS_ANTI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_ANTIC_NODE),
    None,
    Some(&VARS_ANTIE_NODE),
    Some(&VARS_ANTIF_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ANTIL_NODE),
    Some(&VARS_ANTIM_NODE),
    None,
    Some(&VARS_ANTIO_NODE),
    Some(&VARS_ANTIP_NODE),
    Some(&VARS_ANTIQ_NODE),
    Some(&VARS_ANTIR_NODE),
    Some(&VARS_ANTIS_NODE),
    Some(&VARS_ANTIT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ANTIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIT_CHILDREN),
    value: None,
};

pub static VARS_ANTIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hesise"),
        dictgen::InsensitiveStr::Ascii("hesises"),
        dictgen::InsensitiveStr::Ascii("hesize"),
        dictgen::InsensitiveStr::Ascii("hesizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTITHESIZE_1058411346936412929)],
        &[(0b10010, &ENTRY_ANTITHESIZES_15419652955343816662)],
        &[(0b01001, &ENTRY_ANTITHESIZE_1058411346936412929)],
        &[(0b01001, &ENTRY_ANTITHESIZES_15419652955343816662)],
    ],
    range: 6..=7,
};

static VARS_ANTIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIS_CHILDREN),
    value: None,
};

pub static VARS_ANTIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ensitise"),
        dictgen::InsensitiveStr::Ascii("ensitiser"),
        dictgen::InsensitiveStr::Ascii("ensitisers"),
        dictgen::InsensitiveStr::Ascii("ensitises"),
        dictgen::InsensitiveStr::Ascii("ensitize"),
        dictgen::InsensitiveStr::Ascii("ensitizer"),
        dictgen::InsensitiveStr::Ascii("ensitizers"),
        dictgen::InsensitiveStr::Ascii("ensitizes"),
        dictgen::InsensitiveStr::Ascii("epticise"),
        dictgen::InsensitiveStr::Ascii("epticised"),
        dictgen::InsensitiveStr::Ascii("epticises"),
        dictgen::InsensitiveStr::Ascii("epticising"),
        dictgen::InsensitiveStr::Ascii("epticize"),
        dictgen::InsensitiveStr::Ascii("epticized"),
        dictgen::InsensitiveStr::Ascii("epticizes"),
        dictgen::InsensitiveStr::Ascii("epticizing"),
        dictgen::InsensitiveStr::Ascii("eptise"),
        dictgen::InsensitiveStr::Ascii("eptises"),
        dictgen::InsensitiveStr::Ascii("eptize"),
        dictgen::InsensitiveStr::Ascii("eptizes"),
        dictgen::InsensitiveStr::Ascii("iphon"),
        dictgen::InsensitiveStr::Ascii("iphons"),
        dictgen::InsensitiveStr::Ascii("yphon"),
        dictgen::InsensitiveStr::Ascii("yphons"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTISENSITIZE_7315741175565562422)],
        &[(0b10010, &ENTRY_ANTISENSITIZER_11650037907555957428)],
        &[(0b10010, &ENTRY_ANTISENSITIZERS_16419286437564721876)],
        &[(0b10010, &ENTRY_ANTISENSITIZES_2354288141824290441)],
        &[(0b01001, &ENTRY_ANTISENSITIZE_7315741175565562422)],
        &[(0b01001, &ENTRY_ANTISENSITIZER_11650037907555957428)],
        &[(0b01001, &ENTRY_ANTISENSITIZERS_16419286437564721876)],
        &[(0b01001, &ENTRY_ANTISENSITIZES_2354288141824290441)],
        &[(0b10010, &ENTRY_ANTISEPTICIZE_17211450201235074915)],
        &[(0b10010, &ENTRY_ANTISEPTICIZED_2520924671807636777)],
        &[(0b10010, &ENTRY_ANTISEPTICIZES_12007907144201220689)],
        &[(0b10010, &ENTRY_ANTISEPTICIZING_14355477724725995699)],
        &[(0b01001, &ENTRY_ANTISEPTICIZE_17211450201235074915)],
        &[(0b01001, &ENTRY_ANTISEPTICIZED_2520924671807636777)],
        &[(0b01001, &ENTRY_ANTISEPTICIZES_12007907144201220689)],
        &[(0b01001, &ENTRY_ANTISEPTICIZING_14355477724725995699)],
        &[(0b10010, &ENTRY_ANTISEPTIZE_9636461595861649823)],
        &[(0b10010, &ENTRY_ANTISEPTIZES_5945136746946853006)],
        &[(0b01001, &ENTRY_ANTISEPTIZE_9636461595861649823)],
        &[(0b01001, &ENTRY_ANTISEPTIZES_5945136746946853006)],
        &[(0b00001, &ENTRY_ANTISIPHON_339236546432716601)],
        &[(0b00001, &ENTRY_ANTISIPHONS_3704945021028588018)],
        &[(0b11010, &ENTRY_ANTISIPHON_339236546432716601)],
        &[(0b11010, &ENTRY_ANTISIPHONS_3704945021028588018)],
    ],
    range: 5..=10,
};

static VARS_ANTIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIR_CHILDREN),
    value: None,
};

pub static VARS_ANTIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("umor"),
        dictgen::InsensitiveStr::Ascii("umors"),
        dictgen::InsensitiveStr::Ascii("umour"),
        dictgen::InsensitiveStr::Ascii("umours"),
    ],
    values: &[
        &[(0b10001, &ENTRY_ANTIRUMOR_17153953148157727066)],
        &[(0b10001, &ENTRY_ANTIRUMORS_16425512159663099108)],
        &[(0b11010, &ENTRY_ANTIRUMOR_17153953148157727066)],
        &[(0b11010, &ENTRY_ANTIRUMORS_16425512159663099108)],
    ],
    range: 4..=6,
};

static VARS_ANTIQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIQ_CHILDREN),
    value: None,
};

pub static VARS_ANTIQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uarianise"),
        dictgen::InsensitiveStr::Ascii("uarianises"),
        dictgen::InsensitiveStr::Ascii("uarianize"),
        dictgen::InsensitiveStr::Ascii("uarianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTIQUARIANIZE_602925513374090104)],
        &[(0b10010, &ENTRY_ANTIQUARIANIZES_11348524002909406554)],
        &[(0b01001, &ENTRY_ANTIQUARIANIZE_602925513374090104)],
        &[(0b01001, &ENTRY_ANTIQUARIANIZES_11348524002909406554)],
    ],
    range: 9..=10,
};

static VARS_ANTIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIP_CHILDREN),
    value: None,
};

pub static VARS_ANTIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("athise"),
        dictgen::InsensitiveStr::Ascii("athises"),
        dictgen::InsensitiveStr::Ascii("athize"),
        dictgen::InsensitiveStr::Ascii("athizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTIPATHIZE_12950020852305812100)],
        &[(0b10010, &ENTRY_ANTIPATHIZES_8893096438995410493)],
        &[(0b01001, &ENTRY_ANTIPATHIZE_12950020852305812100)],
        &[(0b01001, &ENTRY_ANTIPATHIZES_8893096438995410493)],
    ],
    range: 6..=7,
};

static VARS_ANTIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIO_CHILDREN),
    value: None,
};

pub static VARS_ANTIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("xidiser"),
        dictgen::InsensitiveStr::Ascii("xidisers"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidisings"),
        dictgen::InsensitiveStr::Ascii("xidizer"),
        dictgen::InsensitiveStr::Ascii("xidizers"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
        dictgen::InsensitiveStr::Ascii("xidizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTIOXIDIZER_7325948835821079989)],
        &[(0b10010, &ENTRY_ANTIOXIDIZERS_2946300150339867189)],
        &[(0b10010, &ENTRY_ANTIOXIDIZING_2990906899241132964)],
        &[(0b10010, &ENTRY_ANTIOXIDIZINGS_6563122223567194985)],
        &[(0b01001, &ENTRY_ANTIOXIDIZER_7325948835821079989)],
        &[(0b01001, &ENTRY_ANTIOXIDIZERS_2946300150339867189)],
        &[(0b01001, &ENTRY_ANTIOXIDIZING_2990906899241132964)],
        &[(0b01001, &ENTRY_ANTIOXIDIZINGS_6563122223567194985)],
    ],
    range: 7..=9,
};

static VARS_ANTIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIM_CHILDREN),
    value: None,
};

pub static VARS_ANTIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ediaeval"),
        dictgen::InsensitiveStr::Ascii("ediaevalism"),
        dictgen::InsensitiveStr::Ascii("ediaevalist"),
        dictgen::InsensitiveStr::Ascii("ediaevally"),
        dictgen::InsensitiveStr::Ascii("edieval"),
        dictgen::InsensitiveStr::Ascii("edievalism"),
        dictgen::InsensitiveStr::Ascii("edievalist"),
        dictgen::InsensitiveStr::Ascii("edievally"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANTIMEDIEVAL_6079389628591026032)],
        &[(0b11010, &ENTRY_ANTIMEDIEVALISM_7738460184381908825)],
        &[(0b11010, &ENTRY_ANTIMEDIEVALIST_3797690273319232950)],
        &[(0b11010, &ENTRY_ANTIMEDIEVALLY_3996358009509159332)],
        &[(0b00001, &ENTRY_ANTIMEDIEVAL_6079389628591026032)],
        &[(0b00001, &ENTRY_ANTIMEDIEVALISM_7738460184381908825)],
        &[(0b00001, &ENTRY_ANTIMEDIEVALIST_3797690273319232950)],
        &[(0b00001, &ENTRY_ANTIMEDIEVALLY_3996358009509159332)],
    ],
    range: 7..=11,
};

static VARS_ANTIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIL_CHILDREN),
    value: None,
};

pub static VARS_ANTIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abor"),
        dictgen::InsensitiveStr::Ascii("abors"),
        dictgen::InsensitiveStr::Ascii("abour"),
        dictgen::InsensitiveStr::Ascii("abours"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("oemic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_ANTILABOR_12742385227052815408)],
        &[(0b10001, &ENTRY_ANTILABORS_10072965400683861214)],
        &[(0b11010, &ENTRY_ANTILABOR_12742385227052815408)],
        &[(0b11010, &ENTRY_ANTILABORS_10072965400683861214)],
        &[(0b00001, &ENTRY_ANTILEMIC_16300171286562799216)],
        &[(0b11010, &ENTRY_ANTILEMIC_16300171286562799216)],
    ],
    range: 4..=6,
};

static VARS_ANTIF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIF_CHILDREN),
    value: None,
};

pub static VARS_ANTIF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ertiliser"),
        dictgen::InsensitiveStr::Ascii("ertilisers"),
        dictgen::InsensitiveStr::Ascii("ertilizer"),
        dictgen::InsensitiveStr::Ascii("ertilizers"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTIFERTILIZER_3859234925250795967)],
        &[(0b10010, &ENTRY_ANTIFERTILIZERS_17153192306547342648)],
        &[(0b01001, &ENTRY_ANTIFERTILIZER_3859234925250795967)],
        &[(0b01001, &ENTRY_ANTIFERTILIZERS_17153192306547342648)],
    ],
    range: 9..=10,
};

static VARS_ANTIE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIE_CHILDREN),
    value: None,
};

pub static VARS_ANTIE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("picenter"),
        dictgen::InsensitiveStr::Ascii("picenters"),
        dictgen::InsensitiveStr::Ascii("picentre"),
        dictgen::InsensitiveStr::Ascii("picentres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ANTIEPICENTER_3071202707801108998)],
        &[(0b00001, &ENTRY_ANTIEPICENTERS_10256915121904123076)],
        &[(0b11010, &ENTRY_ANTIEPICENTER_3071202707801108998)],
        &[(0b11010, &ENTRY_ANTIEPICENTERS_10256915121904123076)],
    ],
    range: 8..=9,
};

static VARS_ANTIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIC_CHILDREN),
    value: None,
};

pub static VARS_ANTIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atalyser"),
        dictgen::InsensitiveStr::Ascii("atalysers"),
        dictgen::InsensitiveStr::Ascii("atalyzer"),
        dictgen::InsensitiveStr::Ascii("atalyzers"),
        dictgen::InsensitiveStr::Ascii("entralisation"),
        dictgen::InsensitiveStr::Ascii("entralisations"),
        dictgen::InsensitiveStr::Ascii("entralization"),
        dictgen::InsensitiveStr::Ascii("entralizations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("izes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANTICATALYZER_2403538639092256699)],
        &[(0b11010, &ENTRY_ANTICATALYZERS_18005867496802671530)],
        &[(0b00001, &ENTRY_ANTICATALYZER_2403538639092256699)],
        &[(0b00001, &ENTRY_ANTICATALYZERS_18005867496802671530)],
        &[(0b10010, &ENTRY_ANTICENTRALIZATION_6549993506754234599)],
        &[(0b10010, &ENTRY_ANTICENTRALIZATIONS_7326512573114353591)],
        &[(0b01001, &ENTRY_ANTICENTRALIZATION_6549993506754234599)],
        &[(0b01001, &ENTRY_ANTICENTRALIZATIONS_7326512573114353591)],
        &[(0b10010, &ENTRY_ANTICIZE_16450270289032006209)],
        &[(0b10010, &ENTRY_ANTICIZES_17574516504268210900)],
        &[(0b01001, &ENTRY_ANTICIZE_16450270289032006209)],
        &[(0b01001, &ENTRY_ANTICIZES_17574516504268210900)],
    ],
    range: 3..=14,
};

static VARS_ANTH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTH_CHILDREN),
    value: None,
};

pub static VARS_ANTH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecological"),
        dictgen::InsensitiveStr::Ascii("ecologist"),
        dictgen::InsensitiveStr::Ascii("ecology"),
        dictgen::InsensitiveStr::Ascii("oecological"),
        dictgen::InsensitiveStr::Ascii("oecologist"),
        dictgen::InsensitiveStr::Ascii("oecology"),
        dictgen::InsensitiveStr::Ascii("ologisation"),
        dictgen::InsensitiveStr::Ascii("ologise"),
        dictgen::InsensitiveStr::Ascii("ologised"),
        dictgen::InsensitiveStr::Ascii("ologiser"),
        dictgen::InsensitiveStr::Ascii("ologises"),
        dictgen::InsensitiveStr::Ascii("ologising"),
        dictgen::InsensitiveStr::Ascii("ologization"),
        dictgen::InsensitiveStr::Ascii("ologize"),
        dictgen::InsensitiveStr::Ascii("ologized"),
        dictgen::InsensitiveStr::Ascii("ologizer"),
        dictgen::InsensitiveStr::Ascii("ologizes"),
        dictgen::InsensitiveStr::Ascii("ologizing"),
        dictgen::InsensitiveStr::Ascii("racaemia"),
        dictgen::InsensitiveStr::Ascii("racemia"),
        dictgen::InsensitiveStr::Ascii("racitisation"),
        dictgen::InsensitiveStr::Ascii("racitisations"),
        dictgen::InsensitiveStr::Ascii("racitization"),
        dictgen::InsensitiveStr::Ascii("racitizations"),
        dictgen::InsensitiveStr::Ascii("ropomorphisation"),
        dictgen::InsensitiveStr::Ascii("ropomorphisations"),
        dictgen::InsensitiveStr::Ascii("ropomorphise"),
        dictgen::InsensitiveStr::Ascii("ropomorphised"),
        dictgen::InsensitiveStr::Ascii("ropomorphises"),
        dictgen::InsensitiveStr::Ascii("ropomorphising"),
        dictgen::InsensitiveStr::Ascii("ropomorphization"),
        dictgen::InsensitiveStr::Ascii("ropomorphizations"),
        dictgen::InsensitiveStr::Ascii("ropomorphize"),
        dictgen::InsensitiveStr::Ascii("ropomorphized"),
        dictgen::InsensitiveStr::Ascii("ropomorphizes"),
        dictgen::InsensitiveStr::Ascii("ropomorphizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ANTHECOLOGICAL_14143186251888620251)],
        &[(0b00001, &ENTRY_ANTHECOLOGIST_6276224592804975713)],
        &[(0b00001, &ENTRY_ANTHECOLOGY_6998050919363516872)],
        &[(0b11010, &ENTRY_ANTHECOLOGICAL_14143186251888620251)],
        &[(0b11010, &ENTRY_ANTHECOLOGIST_6276224592804975713)],
        &[(0b11010, &ENTRY_ANTHECOLOGY_6998050919363516872)],
        &[(0b10010, &ENTRY_ANTHOLOGIZATION_8361206256640017140)],
        &[(0b10010, &ENTRY_ANTHOLOGIZE_5139724017303417861)],
        &[(0b10010, &ENTRY_ANTHOLOGIZED_13481396057773837788)],
        &[(0b10010, &ENTRY_ANTHOLOGIZER_11700942615035532830)],
        &[(0b10010, &ENTRY_ANTHOLOGIZES_3543574969907946599)],
        &[(0b10010, &ENTRY_ANTHOLOGIZING_15922251613207293395)],
        &[(0b01001, &ENTRY_ANTHOLOGIZATION_8361206256640017140)],
        &[(0b01001, &ENTRY_ANTHOLOGIZE_5139724017303417861)],
        &[(0b01001, &ENTRY_ANTHOLOGIZED_13481396057773837788)],
        &[(0b01001, &ENTRY_ANTHOLOGIZER_11700942615035532830)],
        &[(0b01001, &ENTRY_ANTHOLOGIZES_3543574969907946599)],
        &[(0b01001, &ENTRY_ANTHOLOGIZING_15922251613207293395)],
        &[(0b11010, &ENTRY_ANTHRACEMIA_5581827672785610586)],
        &[(0b00001, &ENTRY_ANTHRACEMIA_5581827672785610586)],
        &[(0b10010, &ENTRY_ANTHRACITIZATION_18096241064786453560)],
        &[(0b10010, &ENTRY_ANTHRACITIZATIONS_4432334511743850884)],
        &[(0b01001, &ENTRY_ANTHRACITIZATION_18096241064786453560)],
        &[(0b01001, &ENTRY_ANTHRACITIZATIONS_4432334511743850884)],
        &[(0b10010, &ENTRY_ANTHROPOMORPHIZATION_1063500888938508205)],
        &[(0b10010, &ENTRY_ANTHROPOMORPHIZATIONS_14334826108508926415)],
        &[(0b10010, &ENTRY_ANTHROPOMORPHIZE_728742791191255557)],
        &[(0b10010, &ENTRY_ANTHROPOMORPHIZED_8782099582013525777)],
        &[(0b10010, &ENTRY_ANTHROPOMORPHIZES_11954393995572409567)],
        &[(0b10010, &ENTRY_ANTHROPOMORPHIZING_6013696895454427306)],
        &[(0b01001, &ENTRY_ANTHROPOMORPHIZATION_1063500888938508205)],
        &[(0b01001, &ENTRY_ANTHROPOMORPHIZATIONS_14334826108508926415)],
        &[(0b01001, &ENTRY_ANTHROPOMORPHIZE_728742791191255557)],
        &[(0b01001, &ENTRY_ANTHROPOMORPHIZED_8782099582013525777)],
        &[(0b01001, &ENTRY_ANTHROPOMORPHIZES_11954393995572409567)],
        &[(0b01001, &ENTRY_ANTHROPOMORPHIZING_6013696895454427306)],
    ],
    range: 7..=17,
};

static VARS_ANTA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTA_CHILDREN),
    value: None,
};

pub static VARS_ANTA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gonisable"),
        dictgen::InsensitiveStr::Ascii("gonisation"),
        dictgen::InsensitiveStr::Ascii("gonisations"),
        dictgen::InsensitiveStr::Ascii("gonise"),
        dictgen::InsensitiveStr::Ascii("gonised"),
        dictgen::InsensitiveStr::Ascii("goniser"),
        dictgen::InsensitiveStr::Ascii("gonisers"),
        dictgen::InsensitiveStr::Ascii("gonises"),
        dictgen::InsensitiveStr::Ascii("gonising"),
        dictgen::InsensitiveStr::Ascii("gonizable"),
        dictgen::InsensitiveStr::Ascii("gonization"),
        dictgen::InsensitiveStr::Ascii("gonizations"),
        dictgen::InsensitiveStr::Ascii("gonize"),
        dictgen::InsensitiveStr::Ascii("gonized"),
        dictgen::InsensitiveStr::Ascii("gonizer"),
        dictgen::InsensitiveStr::Ascii("gonizers"),
        dictgen::InsensitiveStr::Ascii("gonizes"),
        dictgen::InsensitiveStr::Ascii("gonizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTAGONIZABLE_16672876007810698994)],
        &[(0b10010, &ENTRY_ANTAGONIZATION_14435040696020930986)],
        &[(0b10010, &ENTRY_ANTAGONIZATIONS_10755990986408867749)],
        &[(0b10010, &ENTRY_ANTAGONIZE_9720477866642638466)],
        &[(0b10010, &ENTRY_ANTAGONIZED_14895933622160991615)],
        &[(0b10010, &ENTRY_ANTAGONIZER_5259834457006162974)],
        &[(0b10010, &ENTRY_ANTAGONIZERS_18158507477094690147)],
        &[(0b10010, &ENTRY_ANTAGONIZES_10024723998796407988)],
        &[(0b10010, &ENTRY_ANTAGONIZING_6352128995314172485)],
        &[(0b01001, &ENTRY_ANTAGONIZABLE_16672876007810698994)],
        &[(0b01001, &ENTRY_ANTAGONIZATION_14435040696020930986)],
        &[(0b01001, &ENTRY_ANTAGONIZATIONS_10755990986408867749)],
        &[(0b01001, &ENTRY_ANTAGONIZE_9720477866642638466)],
        &[(0b01001, &ENTRY_ANTAGONIZED_14895933622160991615)],
        &[(0b01001, &ENTRY_ANTAGONIZER_5259834457006162974)],
        &[(0b01001, &ENTRY_ANTAGONIZERS_18158507477094690147)],
        &[(0b01001, &ENTRY_ANTAGONIZES_10024723998796407988)],
        &[(0b01001, &ENTRY_ANTAGONIZING_6352128995314172485)],
    ],
    range: 6..=11,
};

static VARS_ANS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANS_CHILDREN),
    value: None,
};

pub static VARS_ANS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erinae"),
        dictgen::InsensitiveStr::Ascii("erine"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANSERINE_435108827077494119)],
        &[(0b00001, &ENTRY_ANSERINE_435108827077494119)],
    ],
    range: 5..=6,
};

static VARS_ANO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANO_CHILDREN),
    value: None,
};

pub static VARS_ANO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("disation"),
        dictgen::InsensitiveStr::Ascii("dise"),
        dictgen::InsensitiveStr::Ascii("dised"),
        dictgen::InsensitiveStr::Ascii("dises"),
        dictgen::InsensitiveStr::Ascii("dising"),
        dictgen::InsensitiveStr::Ascii("dization"),
        dictgen::InsensitiveStr::Ascii("dize"),
        dictgen::InsensitiveStr::Ascii("dized"),
        dictgen::InsensitiveStr::Ascii("dizes"),
        dictgen::InsensitiveStr::Ascii("dizing"),
        dictgen::InsensitiveStr::Ascii("esis"),
        dictgen::InsensitiveStr::Ascii("estra"),
        dictgen::InsensitiveStr::Ascii("estri"),
        dictgen::InsensitiveStr::Ascii("estrous"),
        dictgen::InsensitiveStr::Ascii("estrum"),
        dictgen::InsensitiveStr::Ascii("estrus"),
        dictgen::InsensitiveStr::Ascii("estruses"),
        dictgen::InsensitiveStr::Ascii("etic"),
        dictgen::InsensitiveStr::Ascii("nymise"),
        dictgen::InsensitiveStr::Ascii("nymised"),
        dictgen::InsensitiveStr::Ascii("nymises"),
        dictgen::InsensitiveStr::Ascii("nymising"),
        dictgen::InsensitiveStr::Ascii("nymize"),
        dictgen::InsensitiveStr::Ascii("nymized"),
        dictgen::InsensitiveStr::Ascii("nymizes"),
        dictgen::InsensitiveStr::Ascii("nymizing"),
        dictgen::InsensitiveStr::Ascii("ra"),
        dictgen::InsensitiveStr::Ascii("ura"),
        dictgen::InsensitiveStr::Ascii("xaemia"),
        dictgen::InsensitiveStr::Ascii("xaemic"),
        dictgen::InsensitiveStr::Ascii("xemia"),
        dictgen::InsensitiveStr::Ascii("xemic"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANODIZATION_5580158529259728238)],
        &[(0b10010, &ENTRY_ANODIZE_15718660927426923526)],
        &[(0b10010, &ENTRY_ANODIZED_15907709896779053361)],
        &[(0b10010, &ENTRY_ANODIZES_11959401558402485938)],
        &[(0b10010, &ENTRY_ANODIZING_10710921135886181266)],
        &[(0b01001, &ENTRY_ANODIZATION_5580158529259728238)],
        &[(0b01001, &ENTRY_ANODIZE_15718660927426923526)],
        &[(0b01001, &ENTRY_ANODIZED_15907709896779053361)],
        &[(0b01001, &ENTRY_ANODIZES_11959401558402485938)],
        &[(0b01001, &ENTRY_ANODIZING_10710921135886181266)],
        &[(0b11010, &ENTRY_ANESIS_7776956081242083056)],
        &[(0b11010, &ENTRY_ANESTRA_14041355161442029698)],
        &[(0b11010, &ENTRY_ANESTRI_16368817406741696707)],
        &[(0b11010, &ENTRY_ANESTROUS_5073150751378264240)],
        &[(0b11010, &ENTRY_ANESTRUM_567212077285721468)],
        &[(0b11010, &ENTRY_ANESTRUS_4586228225558465424)],
        &[(0b11010, &ENTRY_ANESTRUSES_1462915970085799790)],
        &[(0b11010, &ENTRY_ANETIC_17939635412445225286)],
        &[(0b10010, &ENTRY_ANONYMIZE_5130319832346428250)],
        &[(0b10010, &ENTRY_ANONYMIZED_4031902883171822917)],
        &[(0b10010, &ENTRY_ANONYMIZES_14399027189954385035)],
        &[(0b10010, &ENTRY_ANONYMIZING_8530934326292726993)],
        &[(0b01001, &ENTRY_ANONYMIZE_5130319832346428250)],
        &[(0b01001, &ENTRY_ANONYMIZED_4031902883171822917)],
        &[(0b01001, &ENTRY_ANONYMIZES_14399027189954385035)],
        &[(0b01001, &ENTRY_ANONYMIZING_8530934326292726993)],
        &[(0b00001, &ENTRY_ANORA_15484854256215900019)],
        &[(0b11010, &ENTRY_ANORA_15484854256215900019)],
        &[(0b11010, &ENTRY_ANOXEMIA_15578360103352496477)],
        &[(0b11010, &ENTRY_ANOXEMIC_16205357930146841514)],
        &[(0b10001, &ENTRY_ANOXEMIA_15578360103352496477)],
        &[(0b10001, &ENTRY_ANOXEMIC_16205357930146841514)],
    ],
    range: 2..=8,
};

static VARS_ANN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANN_CHILDREN),
    value: None,
};

pub static VARS_ANN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANNALIZE_4021643013352928238)],
        &[(0b10010, &ENTRY_ANNALIZED_1261285051288210351)],
        &[(0b10010, &ENTRY_ANNALIZES_2533393763215744849)],
        &[(0b10010, &ENTRY_ANNALIZING_17003024744448321410)],
        &[(0b01001, &ENTRY_ANNALIZE_4021643013352928238)],
        &[(0b01001, &ENTRY_ANNALIZED_1261285051288210351)],
        &[(0b01001, &ENTRY_ANNALIZES_2533393763215744849)],
        &[(0b01001, &ENTRY_ANNALIZING_17003024744448321410)],
        &[(0b10010, &ENTRY_ANNUALIZATION_1251681395381896241)],
        &[(0b10010, &ENTRY_ANNUALIZE_14357283589343884058)],
        &[(0b10010, &ENTRY_ANNUALIZED_8158941755303657840)],
        &[(0b10010, &ENTRY_ANNUALIZES_3376871436090240009)],
        &[(0b10010, &ENTRY_ANNUALIZING_14559072289548057157)],
        &[(0b01001, &ENTRY_ANNUALIZATION_1251681395381896241)],
        &[(0b01001, &ENTRY_ANNUALIZE_14357283589343884058)],
        &[(0b01001, &ENTRY_ANNUALIZED_8158941755303657840)],
        &[(0b01001, &ENTRY_ANNUALIZES_3376871436090240009)],
        &[(0b01001, &ENTRY_ANNUALIZING_14559072289548057157)],
    ],
    range: 5..=10,
};

static VARS_ANI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANI_CHILDREN),
    value: None,
};

pub static VARS_ANI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("malisation"),
        dictgen::InsensitiveStr::Ascii("malisations"),
        dictgen::InsensitiveStr::Ascii("malise"),
        dictgen::InsensitiveStr::Ascii("malised"),
        dictgen::InsensitiveStr::Ascii("malises"),
        dictgen::InsensitiveStr::Ascii("malising"),
        dictgen::InsensitiveStr::Ascii("malization"),
        dictgen::InsensitiveStr::Ascii("malizations"),
        dictgen::InsensitiveStr::Ascii("malize"),
        dictgen::InsensitiveStr::Ascii("malized"),
        dictgen::InsensitiveStr::Ascii("malizes"),
        dictgen::InsensitiveStr::Ascii("malizing"),
        dictgen::InsensitiveStr::Ascii("mised"),
        dictgen::InsensitiveStr::Ascii("mized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANIMALIZATION_2531195057486411112)],
        &[(0b10010, &ENTRY_ANIMALIZATIONS_15722635992002526559)],
        &[(0b10010, &ENTRY_ANIMALIZE_13599801917843491747)],
        &[(0b10010, &ENTRY_ANIMALIZED_11992776700792677845)],
        &[(0b10010, &ENTRY_ANIMALIZES_13031030594595132678)],
        &[(0b10010, &ENTRY_ANIMALIZING_16466913009307928576)],
        &[(0b01001, &ENTRY_ANIMALIZATION_2531195057486411112)],
        &[(0b01001, &ENTRY_ANIMALIZATIONS_15722635992002526559)],
        &[(0b01001, &ENTRY_ANIMALIZE_13599801917843491747)],
        &[(0b01001, &ENTRY_ANIMALIZED_11992776700792677845)],
        &[(0b01001, &ENTRY_ANIMALIZES_13031030594595132678)],
        &[(0b01001, &ENTRY_ANIMALIZING_16466913009307928576)],
        &[(0b10010, &ENTRY_ANIMIZED_15864631163138232373)],
        &[(0b01001, &ENTRY_ANIMIZED_15864631163138232373)],
    ],
    range: 5..=11,
};

static VARS_ANH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANH_CHILDREN),
    value: None,
};

pub static VARS_ANH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aematopoiesis"),
        dictgen::InsensitiveStr::Ascii("aematosis"),
        dictgen::InsensitiveStr::Ascii("aemolytic"),
        dictgen::InsensitiveStr::Ascii("ematopoiesis"),
        dictgen::InsensitiveStr::Ascii("ematosis"),
        dictgen::InsensitiveStr::Ascii("emolytic"),
        dictgen::InsensitiveStr::Ascii("ydraemia"),
        dictgen::InsensitiveStr::Ascii("ydraemic"),
        dictgen::InsensitiveStr::Ascii("ydremia"),
        dictgen::InsensitiveStr::Ascii("ydremic"),
        dictgen::InsensitiveStr::Ascii("ydridisation"),
        dictgen::InsensitiveStr::Ascii("ydridisations"),
        dictgen::InsensitiveStr::Ascii("ydridise"),
        dictgen::InsensitiveStr::Ascii("ydridises"),
        dictgen::InsensitiveStr::Ascii("ydridization"),
        dictgen::InsensitiveStr::Ascii("ydridizations"),
        dictgen::InsensitiveStr::Ascii("ydridize"),
        dictgen::InsensitiveStr::Ascii("ydridizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANHEMATOPOIESIS_1868084374074707427)],
        &[(0b11010, &ENTRY_ANHEMATOSIS_11613934029870552602)],
        &[(0b11010, &ENTRY_ANHEMOLYTIC_11227635709932610906)],
        &[(0b10001, &ENTRY_ANHEMATOPOIESIS_1868084374074707427)],
        &[(0b10001, &ENTRY_ANHEMATOSIS_11613934029870552602)],
        &[(0b10001, &ENTRY_ANHEMOLYTIC_11227635709932610906)],
        &[(0b11010, &ENTRY_ANHYDREMIA_16017214998447865170)],
        &[(0b11010, &ENTRY_ANHYDREMIC_4124925984800766575)],
        &[(0b10001, &ENTRY_ANHYDREMIA_16017214998447865170)],
        &[(0b10001, &ENTRY_ANHYDREMIC_4124925984800766575)],
        &[(0b10010, &ENTRY_ANHYDRIDIZATION_6094335914661384615)],
        &[(0b10010, &ENTRY_ANHYDRIDIZATIONS_155841901800213519)],
        &[(0b10010, &ENTRY_ANHYDRIDIZE_14425167166852587859)],
        &[(0b10010, &ENTRY_ANHYDRIDIZES_9033438379003578734)],
        &[(0b01001, &ENTRY_ANHYDRIDIZATION_6094335914661384615)],
        &[(0b01001, &ENTRY_ANHYDRIDIZATIONS_155841901800213519)],
        &[(0b01001, &ENTRY_ANHYDRIDIZE_14425167166852587859)],
        &[(0b01001, &ENTRY_ANHYDRIDIZES_9033438379003578734)],
    ],
    range: 7..=13,
};

static VARS_ANG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANG_CHILDREN),
    value: None,
};

pub static VARS_ANG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elicise"),
        dictgen::InsensitiveStr::Ascii("elicises"),
        dictgen::InsensitiveStr::Ascii("elicize"),
        dictgen::InsensitiveStr::Ascii("elicizes"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("licanise"),
        dictgen::InsensitiveStr::Ascii("licanises"),
        dictgen::InsensitiveStr::Ascii("licanize"),
        dictgen::InsensitiveStr::Ascii("licanizes"),
        dictgen::InsensitiveStr::Ascii("licisation"),
        dictgen::InsensitiveStr::Ascii("licisations"),
        dictgen::InsensitiveStr::Ascii("licise"),
        dictgen::InsensitiveStr::Ascii("licised"),
        dictgen::InsensitiveStr::Ascii("licises"),
        dictgen::InsensitiveStr::Ascii("licising"),
        dictgen::InsensitiveStr::Ascii("licization"),
        dictgen::InsensitiveStr::Ascii("licizations"),
        dictgen::InsensitiveStr::Ascii("licize"),
        dictgen::InsensitiveStr::Ascii("licized"),
        dictgen::InsensitiveStr::Ascii("licizes"),
        dictgen::InsensitiveStr::Ascii("licizing"),
        dictgen::InsensitiveStr::Ascii("raecum"),
        dictgen::InsensitiveStr::Ascii("recum"),
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularisations"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularizations"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANGELICIZE_2482124613561887198)],
        &[(0b10010, &ENTRY_ANGELICIZES_11761206692627296229)],
        &[(0b01001, &ENTRY_ANGELICIZE_2482124613561887198)],
        &[(0b01001, &ENTRY_ANGELICIZES_11761206692627296229)],
        &[(0b10010, &ENTRY_ANGELIZE_11537726138051858659)],
        &[(0b10010, &ENTRY_ANGELIZES_17631239242244040835)],
        &[(0b01001, &ENTRY_ANGELIZE_11537726138051858659)],
        &[(0b01001, &ENTRY_ANGELIZES_17631239242244040835)],
        &[(0b10010, &ENTRY_ANGLICANIZE_5125340706957804024)],
        &[(0b10010, &ENTRY_ANGLICANIZES_10574889558954710022)],
        &[(0b01001, &ENTRY_ANGLICANIZE_5125340706957804024)],
        &[(0b01001, &ENTRY_ANGLICANIZES_10574889558954710022)],
        &[(0b10010, &ENTRY_ANGLICIZATION_2983200592739510459)],
        &[(0b10010, &ENTRY_ANGLICIZATIONS_8469725992410144048)],
        &[(0b10010, &ENTRY_ANGLICIZE_6354255494717016366)],
        &[(0b10010, &ENTRY_ANGLICIZED_14308195744307041473)],
        &[(0b10010, &ENTRY_ANGLICIZES_2840411104211976362)],
        &[(0b10010, &ENTRY_ANGLICIZING_8410491650860737901)],
        &[(0b01001, &ENTRY_ANGLICIZATION_2983200592739510459)],
        &[(0b01001, &ENTRY_ANGLICIZATIONS_8469725992410144048)],
        &[(0b01001, &ENTRY_ANGLICIZE_6354255494717016366)],
        &[(0b01001, &ENTRY_ANGLICIZED_14308195744307041473)],
        &[(0b01001, &ENTRY_ANGLICIZES_2840411104211976362)],
        &[(0b01001, &ENTRY_ANGLICIZING_8410491650860737901)],
        &[(0b11010, &ENTRY_ANGRECUM_7338465098653253052)],
        &[(0b00001, &ENTRY_ANGRECUM_7338465098653253052)],
        &[(0b10010, &ENTRY_ANGULARIZATION_6898328441954759992)],
        &[(0b10010, &ENTRY_ANGULARIZATIONS_15860238483459836121)],
        &[(0b10010, &ENTRY_ANGULARIZE_9783489444920348993)],
        &[(0b10010, &ENTRY_ANGULARIZES_8406976640779414831)],
        &[(0b01001, &ENTRY_ANGULARIZATION_6898328441954759992)],
        &[(0b01001, &ENTRY_ANGULARIZATIONS_15860238483459836121)],
        &[(0b01001, &ENTRY_ANGULARIZE_9783489444920348993)],
        &[(0b01001, &ENTRY_ANGULARIZES_8406976640779414831)],
    ],
    range: 5..=12,
};

static VARS_ANE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANE_CHILDREN),
    value: None,
};

pub static VARS_ANE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matosis"),
        dictgen::InsensitiveStr::Ascii("mia"),
        dictgen::InsensitiveStr::Ascii("mias"),
        dictgen::InsensitiveStr::Ascii("mic"),
        dictgen::InsensitiveStr::Ascii("mically"),
        dictgen::InsensitiveStr::Ascii("micer"),
        dictgen::InsensitiveStr::Ascii("micest"),
        dictgen::InsensitiveStr::Ascii("mics"),
        dictgen::InsensitiveStr::Ascii("retic"),
        dictgen::InsensitiveStr::Ascii("sis"),
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesiant"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthesiologies"),
        dictgen::InsensitiveStr::Ascii("sthesiologist"),
        dictgen::InsensitiveStr::Ascii("sthesiologists"),
        dictgen::InsensitiveStr::Ascii("sthesiology"),
        dictgen::InsensitiveStr::Ascii("sthesis"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
        dictgen::InsensitiveStr::Ascii("sthetically"),
        dictgen::InsensitiveStr::Ascii("stheticer"),
        dictgen::InsensitiveStr::Ascii("stheticest"),
        dictgen::InsensitiveStr::Ascii("sthetics"),
        dictgen::InsensitiveStr::Ascii("sthetisation"),
        dictgen::InsensitiveStr::Ascii("sthetisations"),
        dictgen::InsensitiveStr::Ascii("sthetise"),
        dictgen::InsensitiveStr::Ascii("sthetised"),
        dictgen::InsensitiveStr::Ascii("sthetiser"),
        dictgen::InsensitiveStr::Ascii("sthetisers"),
        dictgen::InsensitiveStr::Ascii("sthetises"),
        dictgen::InsensitiveStr::Ascii("sthetising"),
        dictgen::InsensitiveStr::Ascii("sthetist"),
        dictgen::InsensitiveStr::Ascii("sthetists"),
        dictgen::InsensitiveStr::Ascii("sthetization"),
        dictgen::InsensitiveStr::Ascii("sthetizations"),
        dictgen::InsensitiveStr::Ascii("sthetize"),
        dictgen::InsensitiveStr::Ascii("sthetized"),
        dictgen::InsensitiveStr::Ascii("sthetizer"),
        dictgen::InsensitiveStr::Ascii("sthetizers"),
        dictgen::InsensitiveStr::Ascii("sthetizes"),
        dictgen::InsensitiveStr::Ascii("sthetizing"),
        dictgen::InsensitiveStr::Ascii("sthyl"),
        dictgen::InsensitiveStr::Ascii("stra"),
        dictgen::InsensitiveStr::Ascii("stri"),
        dictgen::InsensitiveStr::Ascii("strous"),
        dictgen::InsensitiveStr::Ascii("strum"),
        dictgen::InsensitiveStr::Ascii("strus"),
        dictgen::InsensitiveStr::Ascii("struses"),
        dictgen::InsensitiveStr::Ascii("tic"),
        dictgen::InsensitiveStr::Ascii("tiological"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ANEMATOSIS_12724418797581501779)],
        &[(0b11001, &ENTRY_ANEMIA_17351338060107863650)],
        &[(0b11001, &ENTRY_ANEMIAS_9703736074959593780)],
        &[(0b11001, &ENTRY_ANEMIC_110986479873166850)],
        &[(0b11001, &ENTRY_ANEMICALLY_1918381762384876054)],
        &[(0b11001, &ENTRY_ANEMICER_10489187624102082516)],
        &[(0b11001, &ENTRY_ANEMICEST_16912294123173826264)],
        &[(0b11001, &ENTRY_ANEMICS_16585338697348245033)],
        &[(0b00001, &ENTRY_ANERETIC_16141834454964794758)],
        &[(0b00001, &ENTRY_ANESIS_7776956081242083056)],
        &[(0b11001, &ENTRY_ANESTHESIA_7949842536189154112)],
        &[(0b11001, &ENTRY_ANESTHESIANT_4746502908533923971)],
        &[(0b11001, &ENTRY_ANESTHESIAS_4599764321131919802)],
        &[(0b11001, &ENTRY_ANESTHESIOLOGIES_140878230116787033)],
        &[(0b11001, &ENTRY_ANESTHESIOLOGIST_11739214388783841528)],
        &[(0b11001, &ENTRY_ANESTHESIOLOGISTS_5917925088694288121)],
        &[(0b11001, &ENTRY_ANESTHESIOLOGY_17372491589772115476)],
        &[(0b11001, &ENTRY_ANESTHESIS_604371175550791390)],
        &[(0b11001, &ENTRY_ANESTHETIC_14288529759943853831)],
        &[(0b11001, &ENTRY_ANESTHETICALLY_16764872851576239321)],
        &[(0b11001, &ENTRY_ANESTHETICER_2077884160248687026)],
        &[(0b11001, &ENTRY_ANESTHETICEST_9846998351210964261)],
        &[(0b11001, &ENTRY_ANESTHETICS_14641815304467888505)],
        &[(0b10000, &ENTRY_ANESTHETIZATION_16202486391697802084)],
        &[(0b10000, &ENTRY_ANESTHETIZATIONS_12188987204886505606)],
        &[(0b10000, &ENTRY_ANESTHETIZE_14671518822963641349)],
        &[(0b10000, &ENTRY_ANESTHETIZED_16430560117590162734)],
        &[(0b10000, &ENTRY_ANESTHETIZER_17277086517171409383)],
        &[(0b10000, &ENTRY_ANESTHETIZERS_5573390178845466914)],
        &[(0b10000, &ENTRY_ANESTHETIZES_6012915426134202133)],
        &[(0b10000, &ENTRY_ANESTHETIZING_9434687273852626047)],
        &[(0b11001, &ENTRY_ANESTHETIST_11538281420926207852)],
        &[(0b11001, &ENTRY_ANESTHETISTS_8704279203965849778)],
        &[(0b00001, &ENTRY_ANESTHETIZATION_16202486391697802084)],
        &[(0b00001, &ENTRY_ANESTHETIZATIONS_12188987204886505606)],
        &[(0b01001, &ENTRY_ANESTHETIZE_14671518822963641349)],
        &[(0b01001, &ENTRY_ANESTHETIZED_16430560117590162734)],
        &[(0b00001, &ENTRY_ANESTHETIZER_17277086517171409383)],
        &[(0b00001, &ENTRY_ANESTHETIZERS_5573390178845466914)],
        &[(0b01001, &ENTRY_ANESTHETIZES_6012915426134202133)],
        &[(0b01001, &ENTRY_ANESTHETIZING_9434687273852626047)],
        &[(0b00001, &ENTRY_ANESTHYL_11441285363633951452)],
        &[(0b10001, &ENTRY_ANESTRA_14041355161442029698)],
        &[(0b10001, &ENTRY_ANESTRI_16368817406741696707)],
        &[(0b10001, &ENTRY_ANESTROUS_5073150751378264240)],
        &[(0b10001, &ENTRY_ANESTRUM_567212077285721468)],
        &[(0b10001, &ENTRY_ANESTRUS_4586228225558465424)],
        &[(0b10001, &ENTRY_ANESTRUSES_1462915970085799790)],
        &[(0b10001, &ENTRY_ANETIC_17939635412445225286)],
        &[(0b10001, &ENTRY_ANETIOLOGICAL_4530118434736804466)],
    ],
    range: 3..=14,
};

static VARS_ANC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANC_CHILDREN),
    value: None,
};

pub static VARS_ANC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hinoae"),
        dictgen::InsensitiveStr::Ascii("hinoe"),
        dictgen::InsensitiveStr::Ascii("illae"),
        dictgen::InsensitiveStr::Ascii("ille"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANCHINOE_11715538892311512591)],
        &[(0b00001, &ENTRY_ANCHINOE_11715538892311512591)],
        &[(0b11010, &ENTRY_ANCILLE_4424192584387520513)],
        &[(0b00001, &ENTRY_ANCILLE_4424192584387520513)],
    ],
    range: 4..=6,
};

static VARS_ANA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ANA_CHILDREN),
    value: None,
};

static VARS_ANA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_ANAB_NODE),
    None,
    None,
    Some(&VARS_ANAE_NODE),
    None,
    Some(&VARS_ANAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_ANAL_NODE),
    None,
    None,
    None,
    Some(&VARS_ANAP_NODE),
    None,
    Some(&VARS_ANAR_NODE),
    None,
    Some(&VARS_ANAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ANAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAT_CHILDREN),
    value: None,
};

pub static VARS_ANAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hematisation"),
        dictgen::InsensitiveStr::Ascii("hematisations"),
        dictgen::InsensitiveStr::Ascii("hematise"),
        dictgen::InsensitiveStr::Ascii("hematised"),
        dictgen::InsensitiveStr::Ascii("hematiser"),
        dictgen::InsensitiveStr::Ascii("hematises"),
        dictgen::InsensitiveStr::Ascii("hematising"),
        dictgen::InsensitiveStr::Ascii("hematization"),
        dictgen::InsensitiveStr::Ascii("hematizations"),
        dictgen::InsensitiveStr::Ascii("hematize"),
        dictgen::InsensitiveStr::Ascii("hematized"),
        dictgen::InsensitiveStr::Ascii("hematizer"),
        dictgen::InsensitiveStr::Ascii("hematizes"),
        dictgen::InsensitiveStr::Ascii("hematizing"),
        dictgen::InsensitiveStr::Ascii("omisable"),
        dictgen::InsensitiveStr::Ascii("omisation"),
        dictgen::InsensitiveStr::Ascii("omise"),
        dictgen::InsensitiveStr::Ascii("omised"),
        dictgen::InsensitiveStr::Ascii("omiser"),
        dictgen::InsensitiveStr::Ascii("omises"),
        dictgen::InsensitiveStr::Ascii("omising"),
        dictgen::InsensitiveStr::Ascii("omizable"),
        dictgen::InsensitiveStr::Ascii("omization"),
        dictgen::InsensitiveStr::Ascii("omize"),
        dictgen::InsensitiveStr::Ascii("omized"),
        dictgen::InsensitiveStr::Ascii("omizer"),
        dictgen::InsensitiveStr::Ascii("omizes"),
        dictgen::InsensitiveStr::Ascii("omizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANATHEMATIZATION_652820925003292708)],
        &[(0b10010, &ENTRY_ANATHEMATIZATIONS_383397386592014889)],
        &[(0b10010, &ENTRY_ANATHEMATIZE_8985478249302198786)],
        &[(0b10010, &ENTRY_ANATHEMATIZED_14882382556399376184)],
        &[(0b10010, &ENTRY_ANATHEMATIZER_18318684354444230221)],
        &[(0b10010, &ENTRY_ANATHEMATIZES_1397436506406873414)],
        &[(0b10010, &ENTRY_ANATHEMATIZING_3364254909178814387)],
        &[(0b01001, &ENTRY_ANATHEMATIZATION_652820925003292708)],
        &[(0b01001, &ENTRY_ANATHEMATIZATIONS_383397386592014889)],
        &[(0b01001, &ENTRY_ANATHEMATIZE_8985478249302198786)],
        &[(0b01001, &ENTRY_ANATHEMATIZED_14882382556399376184)],
        &[(0b01001, &ENTRY_ANATHEMATIZER_18318684354444230221)],
        &[(0b01001, &ENTRY_ANATHEMATIZES_1397436506406873414)],
        &[(0b01001, &ENTRY_ANATHEMATIZING_3364254909178814387)],
        &[(0b10010, &ENTRY_ANATOMIZABLE_4206201642984389225)],
        &[(0b10010, &ENTRY_ANATOMIZATION_2325685116767991731)],
        &[(0b10010, &ENTRY_ANATOMIZE_5992811181160301723)],
        &[(0b10010, &ENTRY_ANATOMIZED_15278909516951232818)],
        &[(0b10010, &ENTRY_ANATOMIZER_13440602250047971691)],
        &[(0b10010, &ENTRY_ANATOMIZES_9984137617813051385)],
        &[(0b10010, &ENTRY_ANATOMIZING_16127461066028765958)],
        &[(0b01001, &ENTRY_ANATOMIZABLE_4206201642984389225)],
        &[(0b01001, &ENTRY_ANATOMIZATION_2325685116767991731)],
        &[(0b01001, &ENTRY_ANATOMIZE_5992811181160301723)],
        &[(0b01001, &ENTRY_ANATOMIZED_15278909516951232818)],
        &[(0b01001, &ENTRY_ANATOMIZER_13440602250047971691)],
        &[(0b01001, &ENTRY_ANATOMIZES_9984137617813051385)],
        &[(0b01001, &ENTRY_ANATOMIZING_16127461066028765958)],
    ],
    range: 5..=13,
};

static VARS_ANAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAR_CHILDREN),
    value: None,
};

pub static VARS_ANAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chise"),
        dictgen::InsensitiveStr::Ascii("chised"),
        dictgen::InsensitiveStr::Ascii("chises"),
        dictgen::InsensitiveStr::Ascii("chising"),
        dictgen::InsensitiveStr::Ascii("chize"),
        dictgen::InsensitiveStr::Ascii("chized"),
        dictgen::InsensitiveStr::Ascii("chizes"),
        dictgen::InsensitiveStr::Ascii("chizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANARCHIZE_1081081497921958560)],
        &[(0b10010, &ENTRY_ANARCHIZED_2265742664355359347)],
        &[(0b10010, &ENTRY_ANARCHIZES_15395751413994518956)],
        &[(0b10010, &ENTRY_ANARCHIZING_2590562487568483557)],
        &[(0b01001, &ENTRY_ANARCHIZE_1081081497921958560)],
        &[(0b01001, &ENTRY_ANARCHIZED_2265742664355359347)],
        &[(0b01001, &ENTRY_ANARCHIZES_15395751413994518956)],
        &[(0b01001, &ENTRY_ANARCHIZING_2590562487568483557)],
    ],
    range: 5..=7,
};

static VARS_ANAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAP_CHILDREN),
    value: None,
};

pub static VARS_ANAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aestically"),
        dictgen::InsensitiveStr::Ascii("estically"),
        dictgen::InsensitiveStr::Ascii("neic"),
        dictgen::InsensitiveStr::Ascii("noeic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANAPESTICALLY_1329709023297995970)],
        &[(0b00001, &ENTRY_ANAPESTICALLY_1329709023297995970)],
        &[(0b00001, &ENTRY_ANAPNEIC_166245242776222043)],
        &[(0b11010, &ENTRY_ANAPNEIC_166245242776222043)],
    ],
    range: 4..=10,
};

static VARS_ANAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAL_CHILDREN),
    value: None,
};

pub static VARS_ANAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
        dictgen::InsensitiveStr::Ascii("ysability"),
        dictgen::InsensitiveStr::Ascii("ysable"),
        dictgen::InsensitiveStr::Ascii("ysabler"),
        dictgen::InsensitiveStr::Ascii("ysablest"),
        dictgen::InsensitiveStr::Ascii("ysation"),
        dictgen::InsensitiveStr::Ascii("ysations"),
        dictgen::InsensitiveStr::Ascii("yse"),
        dictgen::InsensitiveStr::Ascii("ysed"),
        dictgen::InsensitiveStr::Ascii("yser"),
        dictgen::InsensitiveStr::Ascii("ysers"),
        dictgen::InsensitiveStr::Ascii("ysing"),
        dictgen::InsensitiveStr::Ascii("yzability"),
        dictgen::InsensitiveStr::Ascii("yzable"),
        dictgen::InsensitiveStr::Ascii("yzabler"),
        dictgen::InsensitiveStr::Ascii("yzablest"),
        dictgen::InsensitiveStr::Ascii("yzation"),
        dictgen::InsensitiveStr::Ascii("yzations"),
        dictgen::InsensitiveStr::Ascii("yze"),
        dictgen::InsensitiveStr::Ascii("yzed"),
        dictgen::InsensitiveStr::Ascii("yzer"),
        dictgen::InsensitiveStr::Ascii("yzers"),
        dictgen::InsensitiveStr::Ascii("yzes"),
        dictgen::InsensitiveStr::Ascii("yzing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANALOGIZE_3496372555061910029)],
        &[(0b10010, &ENTRY_ANALOGIZED_7650212126382953539)],
        &[(0b10010, &ENTRY_ANALOGIZES_13569410805636149254)],
        &[(0b10010, &ENTRY_ANALOGIZING_5745351008205937159)],
        &[(0b01001, &ENTRY_ANALOGIZE_3496372555061910029)],
        &[(0b01001, &ENTRY_ANALOGIZED_7650212126382953539)],
        &[(0b01001, &ENTRY_ANALOGIZES_13569410805636149254)],
        &[(0b01001, &ENTRY_ANALOGIZING_5745351008205937159)],
        &[(0b10010, &ENTRY_ANALYZABILITY_1173350993735838693)],
        &[(0b10010, &ENTRY_ANALYZABLE_6620659606031844316)],
        &[(0b10010, &ENTRY_ANALYZABLER_1175108799224565364)],
        &[(0b10010, &ENTRY_ANALYZABLEST_6927325114662775659)],
        &[(0b10010, &ENTRY_ANALYZATION_10825307177201093946)],
        &[(0b10010, &ENTRY_ANALYZATIONS_991580025138607997)],
        &[(0b11010, &ENTRY_ANALYZE_12128484930486970639)],
        &[(0b11010, &ENTRY_ANALYZED_15674848014505848991)],
        &[(0b10010, &ENTRY_ANALYZER_5869658529883306960)],
        &[(0b10010, &ENTRY_ANALYZERS_1666949323375308230)],
        &[(0b11010, &ENTRY_ANALYZING_15099411830060036147)],
        &[(0b01001, &ENTRY_ANALYZABILITY_1173350993735838693)],
        &[(0b01001, &ENTRY_ANALYZABLE_6620659606031844316)],
        &[(0b01001, &ENTRY_ANALYZABLER_1175108799224565364)],
        &[(0b01001, &ENTRY_ANALYZABLEST_6927325114662775659)],
        &[(0b01001, &ENTRY_ANALYZATION_10825307177201093946)],
        &[(0b01001, &ENTRY_ANALYZATIONS_991580025138607997)],
        &[(0b01001, &ENTRY_ANALYZE_12128484930486970639)],
        &[(0b01001, &ENTRY_ANALYZED_15674848014505848991)],
        &[(0b01001, &ENTRY_ANALYZER_5869658529883306960)],
        &[(0b01001, &ENTRY_ANALYZERS_1666949323375308230)],
        &[(0b01001, &ENTRY_ANALYZES_2322356799829770580)],
        &[(0b01001, &ENTRY_ANALYZING_15099411830060036147)],
    ],
    range: 3..=9,
};

static VARS_ANAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAG_CHILDREN),
    value: None,
};

pub static VARS_ANAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rammatise"),
        dictgen::InsensitiveStr::Ascii("rammatised"),
        dictgen::InsensitiveStr::Ascii("rammatises"),
        dictgen::InsensitiveStr::Ascii("rammatising"),
        dictgen::InsensitiveStr::Ascii("rammatize"),
        dictgen::InsensitiveStr::Ascii("rammatized"),
        dictgen::InsensitiveStr::Ascii("rammatizes"),
        dictgen::InsensitiveStr::Ascii("rammatizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANAGRAMMATIZE_5529917246968520880)],
        &[(0b10010, &ENTRY_ANAGRAMMATIZED_12777276468218717735)],
        &[(0b10010, &ENTRY_ANAGRAMMATIZES_13672255743930960739)],
        &[(0b10010, &ENTRY_ANAGRAMMATIZING_9269936032771734368)],
        &[(0b01001, &ENTRY_ANAGRAMMATIZE_5529917246968520880)],
        &[(0b01001, &ENTRY_ANAGRAMMATIZED_12777276468218717735)],
        &[(0b01001, &ENTRY_ANAGRAMMATIZES_13672255743930960739)],
        &[(0b01001, &ENTRY_ANAGRAMMATIZING_9269936032771734368)],
    ],
    range: 9..=11,
};

static VARS_ANAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAE_CHILDREN),
    value: None,
};

pub static VARS_ANAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matosis"),
        dictgen::InsensitiveStr::Ascii("mia"),
        dictgen::InsensitiveStr::Ascii("mias"),
        dictgen::InsensitiveStr::Ascii("mic"),
        dictgen::InsensitiveStr::Ascii("mically"),
        dictgen::InsensitiveStr::Ascii("micer"),
        dictgen::InsensitiveStr::Ascii("micest"),
        dictgen::InsensitiveStr::Ascii("mics"),
        dictgen::InsensitiveStr::Ascii("retic"),
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesiant"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthesiologies"),
        dictgen::InsensitiveStr::Ascii("sthesiologist"),
        dictgen::InsensitiveStr::Ascii("sthesiologists"),
        dictgen::InsensitiveStr::Ascii("sthesiology"),
        dictgen::InsensitiveStr::Ascii("sthesis"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
        dictgen::InsensitiveStr::Ascii("sthetically"),
        dictgen::InsensitiveStr::Ascii("stheticer"),
        dictgen::InsensitiveStr::Ascii("stheticest"),
        dictgen::InsensitiveStr::Ascii("sthetics"),
        dictgen::InsensitiveStr::Ascii("sthetisation"),
        dictgen::InsensitiveStr::Ascii("sthetisations"),
        dictgen::InsensitiveStr::Ascii("sthetise"),
        dictgen::InsensitiveStr::Ascii("sthetised"),
        dictgen::InsensitiveStr::Ascii("sthetiser"),
        dictgen::InsensitiveStr::Ascii("sthetisers"),
        dictgen::InsensitiveStr::Ascii("sthetises"),
        dictgen::InsensitiveStr::Ascii("sthetising"),
        dictgen::InsensitiveStr::Ascii("sthetist"),
        dictgen::InsensitiveStr::Ascii("sthetists"),
        dictgen::InsensitiveStr::Ascii("sthetization"),
        dictgen::InsensitiveStr::Ascii("sthetizations"),
        dictgen::InsensitiveStr::Ascii("sthetize"),
        dictgen::InsensitiveStr::Ascii("sthetized"),
        dictgen::InsensitiveStr::Ascii("sthetizer"),
        dictgen::InsensitiveStr::Ascii("sthetizers"),
        dictgen::InsensitiveStr::Ascii("sthetizes"),
        dictgen::InsensitiveStr::Ascii("sthetizing"),
        dictgen::InsensitiveStr::Ascii("sthyl"),
        dictgen::InsensitiveStr::Ascii("tiological"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANEMATOSIS_12724418797581501779)],
        &[(0b10010, &ENTRY_ANEMIA_17351338060107863650)],
        &[(0b10010, &ENTRY_ANEMIAS_9703736074959593780)],
        &[(0b10010, &ENTRY_ANEMIC_110986479873166850)],
        &[(0b10010, &ENTRY_ANEMICALLY_1918381762384876054)],
        &[(0b10010, &ENTRY_ANEMICER_10489187624102082516)],
        &[(0b10010, &ENTRY_ANEMICEST_16912294123173826264)],
        &[(0b10010, &ENTRY_ANEMICS_16585338697348245033)],
        &[(0b11010, &ENTRY_ANERETIC_16141834454964794758)],
        &[(0b11010, &ENTRY_ANESTHESIA_7949842536189154112)],
        &[(0b11010, &ENTRY_ANESTHESIANT_4746502908533923971)],
        &[(0b11010, &ENTRY_ANESTHESIAS_4599764321131919802)],
        &[(0b10010, &ENTRY_ANESTHESIOLOGIES_140878230116787033)],
        &[(0b10010, &ENTRY_ANESTHESIOLOGIST_11739214388783841528)],
        &[(0b10010, &ENTRY_ANESTHESIOLOGISTS_5917925088694288121)],
        &[(0b10010, &ENTRY_ANESTHESIOLOGY_17372491589772115476)],
        &[(0b10010, &ENTRY_ANESTHESIS_604371175550791390)],
        &[(0b11010, &ENTRY_ANESTHETIC_14288529759943853831)],
        &[(0b11010, &ENTRY_ANESTHETICALLY_16764872851576239321)],
        &[(0b11010, &ENTRY_ANESTHETICER_2077884160248687026)],
        &[(0b11010, &ENTRY_ANESTHETICEST_9846998351210964261)],
        &[(0b11010, &ENTRY_ANESTHETICS_14641815304467888505)],
        &[(0b10010, &ENTRY_ANESTHETIZATION_16202486391697802084)],
        &[(0b10010, &ENTRY_ANESTHETIZATIONS_12188987204886505606)],
        &[(0b10010, &ENTRY_ANESTHETIZE_14671518822963641349)],
        &[(0b10010, &ENTRY_ANESTHETIZED_16430560117590162734)],
        &[(0b10010, &ENTRY_ANESTHETIZER_17277086517171409383)],
        &[(0b10010, &ENTRY_ANESTHETIZERS_5573390178845466914)],
        &[(0b10010, &ENTRY_ANESTHETIZES_6012915426134202133)],
        &[(0b10010, &ENTRY_ANESTHETIZING_9434687273852626047)],
        &[(0b11010, &ENTRY_ANESTHETIST_11538281420926207852)],
        &[(0b11010, &ENTRY_ANESTHETISTS_8704279203965849778)],
        &[(0b01000, &ENTRY_ANESTHETIZATION_16202486391697802084)],
        &[(0b01000, &ENTRY_ANESTHETIZATIONS_12188987204886505606)],
        &[(0b01000, &ENTRY_ANESTHETIZE_14671518822963641349)],
        &[(0b01000, &ENTRY_ANESTHETIZED_16430560117590162734)],
        &[(0b01000, &ENTRY_ANESTHETIZER_17277086517171409383)],
        &[(0b01000, &ENTRY_ANESTHETIZERS_5573390178845466914)],
        &[(0b01000, &ENTRY_ANESTHETIZES_6012915426134202133)],
        &[(0b01000, &ENTRY_ANESTHETIZING_9434687273852626047)],
        &[(0b11010, &ENTRY_ANESTHYL_11441285363633951452)],
        &[(0b11010, &ENTRY_ANETIOLOGICAL_4530118434736804466)],
    ],
    range: 3..=14,
};

static VARS_ANAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAB_CHILDREN),
    value: None,
};

pub static VARS_ANAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aptise"),
        dictgen::InsensitiveStr::Ascii("aptised"),
        dictgen::InsensitiveStr::Ascii("aptises"),
        dictgen::InsensitiveStr::Ascii("aptising"),
        dictgen::InsensitiveStr::Ascii("aptize"),
        dictgen::InsensitiveStr::Ascii("aptized"),
        dictgen::InsensitiveStr::Ascii("aptizes"),
        dictgen::InsensitiveStr::Ascii("aptizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANABAPTIZE_11278166687492169507)],
        &[(0b10010, &ENTRY_ANABAPTIZED_16234871345111173088)],
        &[(0b10010, &ENTRY_ANABAPTIZES_7333755464796915136)],
        &[(0b10010, &ENTRY_ANABAPTIZING_18080976513989605902)],
        &[(0b01001, &ENTRY_ANABAPTIZE_11278166687492169507)],
        &[(0b01001, &ENTRY_ANABAPTIZED_16234871345111173088)],
        &[(0b01001, &ENTRY_ANABAPTIZES_7333755464796915136)],
        &[(0b01001, &ENTRY_ANABAPTIZING_18080976513989605902)],
    ],
    range: 6..=8,
};

static VARS_AM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AM_CHILDREN),
    value: None,
};

static VARS_AM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_AMA_NODE),
    Some(&VARS_AMB_NODE),
    None,
    None,
    Some(&VARS_AME_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_AMM_NODE),
    None,
    Some(&VARS_AMO_NODE),
    Some(&VARS_AMP_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_AMY_NODE),
    None,
];

static VARS_AMY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AMY_CHILDREN),
    value: None,
};

pub static VARS_AMY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gdalae"),
        dictgen::InsensitiveStr::Ascii("gdale"),
        dictgen::InsensitiveStr::Ascii("xorrhea"),
        dictgen::InsensitiveStr::Ascii("xorrhoea"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AMYGDALE_11338890394982341606)],
        &[(0b00001, &ENTRY_AMYGDALE_11338890394982341606)],
        &[(0b00001, &ENTRY_AMYXORRHEA_3592031423760777233)],
        &[(0b11010, &ENTRY_AMYXORRHEA_3592031423760777233)],
    ],
    range: 5..=8,
};

static VARS_AMP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AMP_CHILDREN),
    value: None,
};

pub static VARS_AMP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("higaean"),
        dictgen::InsensitiveStr::Ascii("higean"),
        dictgen::InsensitiveStr::Ascii("hitheater"),
        dictgen::InsensitiveStr::Ascii("hitheaters"),
        dictgen::InsensitiveStr::Ascii("hitheatre"),
        dictgen::InsensitiveStr::Ascii("hitheatres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AMPHIGEAN_2663281186252889290)],
        &[(0b00001, &ENTRY_AMPHIGEAN_2663281186252889290)],
        &[(0b01001, &ENTRY_AMPHITHEATER_13906435369224031259)],
        &[(0b01001, &ENTRY_AMPHITHEATERS_976595961664678124)],
        &[(0b11010, &ENTRY_AMPHITHEATER_13906435369224031259)],
        &[(0b11010, &ENTRY_AMPHITHEATERS_976595961664678124)],
    ],
    range: 6..=10,
};

static VARS_AMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AMO_CHILDREN),
    value: None,
};

pub static VARS_AMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eban"),
        dictgen::InsensitiveStr::Ascii("ebean"),
        dictgen::InsensitiveStr::Ascii("ebian"),
        dictgen::InsensitiveStr::Ascii("ebiases"),
        dictgen::InsensitiveStr::Ascii("ebiasis"),
        dictgen::InsensitiveStr::Ascii("ebicidal"),
        dictgen::InsensitiveStr::Ascii("ebicide"),
        dictgen::InsensitiveStr::Ascii("ebid"),
        dictgen::InsensitiveStr::Ascii("ebiform"),
        dictgen::InsensitiveStr::Ascii("ebiosis"),
        dictgen::InsensitiveStr::Ascii("ebocyte"),
        dictgen::InsensitiveStr::Ascii("ebocytes"),
        dictgen::InsensitiveStr::Ascii("eboidism"),
        dictgen::InsensitiveStr::Ascii("ebous"),
        dictgen::InsensitiveStr::Ascii("ebula"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ret"),
        dictgen::InsensitiveStr::Ascii("rism"),
        dictgen::InsensitiveStr::Ascii("risms"),
        dictgen::InsensitiveStr::Ascii("rist"),
        dictgen::InsensitiveStr::Ascii("ristic"),
        dictgen::InsensitiveStr::Ascii("ristics"),
        dictgen::InsensitiveStr::Ascii("rists"),
        dictgen::InsensitiveStr::Ascii("rphisation"),
        dictgen::InsensitiveStr::Ascii("rphise"),
        dictgen::InsensitiveStr::Ascii("rphization"),
        dictgen::InsensitiveStr::Ascii("rphize"),
        dictgen::InsensitiveStr::Ascii("rtisable"),
        dictgen::InsensitiveStr::Ascii("rtisabler"),
        dictgen::InsensitiveStr::Ascii("rtisables"),
        dictgen::InsensitiveStr::Ascii("rtisablest"),
        dictgen::InsensitiveStr::Ascii("rtisation"),
        dictgen::InsensitiveStr::Ascii("rtisations"),
        dictgen::InsensitiveStr::Ascii("rtise"),
        dictgen::InsensitiveStr::Ascii("rtised"),
        dictgen::InsensitiveStr::Ascii("rtisement"),
        dictgen::InsensitiveStr::Ascii("rtisements"),
        dictgen::InsensitiveStr::Ascii("rtises"),
        dictgen::InsensitiveStr::Ascii("rtising"),
        dictgen::InsensitiveStr::Ascii("rtizable"),
        dictgen::InsensitiveStr::Ascii("rtizabler"),
        dictgen::InsensitiveStr::Ascii("rtizables"),
        dictgen::InsensitiveStr::Ascii("rtizablest"),
        dictgen::InsensitiveStr::Ascii("rtization"),
        dictgen::InsensitiveStr::Ascii("rtizations"),
        dictgen::InsensitiveStr::Ascii("rtize"),
        dictgen::InsensitiveStr::Ascii("rtized"),
        dictgen::InsensitiveStr::Ascii("rtizement"),
        dictgen::InsensitiveStr::Ascii("rtizements"),
        dictgen::InsensitiveStr::Ascii("rtizes"),
        dictgen::InsensitiveStr::Ascii("rtizing"),
        dictgen::InsensitiveStr::Ascii("uret"),
        dictgen::InsensitiveStr::Ascii("urism"),
        dictgen::InsensitiveStr::Ascii("urisms"),
        dictgen::InsensitiveStr::Ascii("urist"),
        dictgen::InsensitiveStr::Ascii("uristic"),
        dictgen::InsensitiveStr::Ascii("uristics"),
        dictgen::InsensitiveStr::Ascii("urists"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AMEBAN_11760427595642064735)],
        &[(0b11010, &ENTRY_AMEBEAN_8080760714988914896)],
        &[(0b11010, &ENTRY_AMEBIAN_1868510719746036319)],
        &[(0b11010, &ENTRY_AMEBIASES_191994802519161378)],
        &[(0b11010, &ENTRY_AMEBIASIS_15952343352557455271)],
        &[(0b11010, &ENTRY_AMEBICIDAL_12174992966673417980)],
        &[(0b11010, &ENTRY_AMEBICIDE_6727392976948759380)],
        &[(0b11010, &ENTRY_AMEBID_8990707670752348207)],
        &[(0b11010, &ENTRY_AMEBIFORM_18384809890812519272)],
        &[(0b11010, &ENTRY_AMEBIOSIS_1796168007817567758)],
        &[(0b11010, &ENTRY_AMEBOCYTE_13745214137940733370)],
        &[(0b11010, &ENTRY_AMEBOCYTES_2131705893903646289)],
        &[(0b11010, &ENTRY_AMEBOIDISM_5298244506544781863)],
        &[(0b11010, &ENTRY_AMEBOUS_943579757904752148)],
        &[(0b11010, &ENTRY_AMEBULA_11884806604842186245)],
        &[(0b10010, &ENTRY_AMORALIZE_10530116290419221146)],
        &[(0b10010, &ENTRY_AMORALIZES_5410233152547413336)],
        &[(0b01001, &ENTRY_AMORALIZE_10530116290419221146)],
        &[(0b01001, &ENTRY_AMORALIZES_5410233152547413336)],
        &[(0b00001, &ENTRY_AMORET_4753587475704323862)],
        &[(0b00001, &ENTRY_AMORISM_15369061524023282087)],
        &[(0b00001, &ENTRY_AMORISMS_6181761571118464419)],
        &[(0b00001, &ENTRY_AMORIST_312032137521875674)],
        &[(0b00001, &ENTRY_AMORISTIC_14460066953477032170)],
        &[(0b00001, &ENTRY_AMORISTICS_1227189450459983152)],
        &[(0b00001, &ENTRY_AMORISTS_17336209472802767632)],
        &[(0b10010, &ENTRY_AMORPHIZATION_4466565318810961775)],
        &[(0b10010, &ENTRY_AMORPHIZE_18341333796166530487)],
        &[(0b01001, &ENTRY_AMORPHIZATION_4466565318810961775)],
        &[(0b01001, &ENTRY_AMORPHIZE_18341333796166530487)],
        &[(0b10010, &ENTRY_AMORTIZABLE_16351054998752239198)],
        &[(0b10010, &ENTRY_AMORTIZABLER_18082767998983582677)],
        &[(0b10010, &ENTRY_AMORTIZABLES_9501483392939472572)],
        &[(0b10010, &ENTRY_AMORTIZABLEST_2213906445519340958)],
        &[(0b10010, &ENTRY_AMORTIZATION_18349471581624055412)],
        &[(0b10010, &ENTRY_AMORTIZATIONS_16886902791141844612)],
        &[(0b10010, &ENTRY_AMORTIZE_11005762606748607646)],
        &[(0b10010, &ENTRY_AMORTIZED_2614639190878550237)],
        &[(0b10010, &ENTRY_AMORTIZEMENT_2457588450573582913)],
        &[(0b10010, &ENTRY_AMORTIZEMENTS_3866412779714938646)],
        &[(0b10010, &ENTRY_AMORTIZES_12419679215195830898)],
        &[(0b10010, &ENTRY_AMORTIZING_18247929480308315117)],
        &[(0b01001, &ENTRY_AMORTIZABLE_16351054998752239198)],
        &[(0b01001, &ENTRY_AMORTIZABLER_18082767998983582677)],
        &[(0b01001, &ENTRY_AMORTIZABLES_9501483392939472572)],
        &[(0b01001, &ENTRY_AMORTIZABLEST_2213906445519340958)],
        &[(0b01001, &ENTRY_AMORTIZATION_18349471581624055412)],
        &[(0b01001, &ENTRY_AMORTIZATIONS_16886902791141844612)],
        &[(0b01001, &ENTRY_AMORTIZE_11005762606748607646)],
        &[(0b01001, &ENTRY_AMORTIZED_2614639190878550237)],
        &[(0b01001, &ENTRY_AMORTIZEMENT_2457588450573582913)],
        &[(0b01001, &ENTRY_AMORTIZEMENTS_3866412779714938646)],
        &[(0b01001, &ENTRY_AMORTIZES_12419679215195830898)],
        &[(0b01001, &ENTRY_AMORTIZING_18247929480308315117)],
        &[(0b11010, &ENTRY_AMORET_4753587475704323862)],
        &[(0b11010, &ENTRY_AMORISM_15369061524023282087)],
        &[(0b11010, &ENTRY_AMORISMS_6181761571118464419)],
        &[(0b11010, &ENTRY_AMORIST_312032137521875674)],
        &[(0b11010, &ENTRY_AMORISTIC_14460066953477032170)],
        &[(0b11010, &ENTRY_AMORISTICS_1227189450459983152)],
        &[(0b11010, &ENTRY_AMORISTS_17336209472802767632)],
    ],
    range: 3..=10,
};

static VARS_AMM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AMM_CHILDREN),
    value: None,
};

pub static VARS_AMM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ocete"),
        dictgen::InsensitiveStr::Ascii("ocetes"),
        dictgen::InsensitiveStr::Ascii("ocoete"),
        dictgen::InsensitiveStr::Ascii("ocoetes"),
        dictgen::InsensitiveStr::Ascii("oniaemia"),
        dictgen::InsensitiveStr::Ascii("oniemia"),
    ],
    values: &[
        &[(0b10001, &ENTRY_AMMOCETE_14257434139746734740)],
        &[(0b10001, &ENTRY_AMMOCETES_16461339325418394188)],
        &[(0b11010, &ENTRY_AMMOCETE_14257434139746734740)],
        &[(0b11010, &ENTRY_AMMOCETES_16461339325418394188)],
        &[(0b11010, &ENTRY_AMMONIEMIA_11606025562213027514)],
        &[(0b00001, &ENTRY_AMMONIEMIA_11606025562213027514)],
    ],
    range: 5..=8,
};

static VARS_AME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AME_CHILDREN),
    value: None,
};

pub static VARS_AME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ba"),
        dictgen::InsensitiveStr::Ascii("bae"),
        dictgen::InsensitiveStr::Ascii("ban"),
        dictgen::InsensitiveStr::Ascii("bas"),
        dictgen::InsensitiveStr::Ascii("bean"),
        dictgen::InsensitiveStr::Ascii("bian"),
        dictgen::InsensitiveStr::Ascii("biases"),
        dictgen::InsensitiveStr::Ascii("biasis"),
        dictgen::InsensitiveStr::Ascii("bic"),
        dictgen::InsensitiveStr::Ascii("bicidal"),
        dictgen::InsensitiveStr::Ascii("bicide"),
        dictgen::InsensitiveStr::Ascii("bid"),
        dictgen::InsensitiveStr::Ascii("biform"),
        dictgen::InsensitiveStr::Ascii("biosis"),
        dictgen::InsensitiveStr::Ascii("bocyte"),
        dictgen::InsensitiveStr::Ascii("bocytes"),
        dictgen::InsensitiveStr::Ascii("boid"),
        dictgen::InsensitiveStr::Ascii("boidism"),
        dictgen::InsensitiveStr::Ascii("bous"),
        dictgen::InsensitiveStr::Ascii("bula"),
        dictgen::InsensitiveStr::Ascii("norrhea"),
        dictgen::InsensitiveStr::Ascii("norrheal"),
        dictgen::InsensitiveStr::Ascii("norrheas"),
        dictgen::InsensitiveStr::Ascii("norrheic"),
        dictgen::InsensitiveStr::Ascii("norrhoea"),
        dictgen::InsensitiveStr::Ascii("norrhoeal"),
        dictgen::InsensitiveStr::Ascii("norrhoeas"),
        dictgen::InsensitiveStr::Ascii("norrhoeic"),
        dictgen::InsensitiveStr::Ascii("ricanisation"),
        dictgen::InsensitiveStr::Ascii("ricanisations"),
        dictgen::InsensitiveStr::Ascii("ricanise"),
        dictgen::InsensitiveStr::Ascii("ricanised"),
        dictgen::InsensitiveStr::Ascii("ricaniser"),
        dictgen::InsensitiveStr::Ascii("ricanisers"),
        dictgen::InsensitiveStr::Ascii("ricanises"),
        dictgen::InsensitiveStr::Ascii("ricanising"),
        dictgen::InsensitiveStr::Ascii("ricanization"),
        dictgen::InsensitiveStr::Ascii("ricanizations"),
        dictgen::InsensitiveStr::Ascii("ricanize"),
        dictgen::InsensitiveStr::Ascii("ricanized"),
        dictgen::InsensitiveStr::Ascii("ricanizer"),
        dictgen::InsensitiveStr::Ascii("ricanizers"),
        dictgen::InsensitiveStr::Ascii("ricanizes"),
        dictgen::InsensitiveStr::Ascii("ricanizing"),
    ],
    values: &[
        &[(0b10001, &ENTRY_AMOEBA_6065159277789412432)],
        &[(0b10001, &ENTRY_AMOEBAS_14731335040187035859)],
        &[(0b10001, &ENTRY_AMEBAN_11760427595642064735)],
        &[(0b10001, &ENTRY_AMOEBAS_14731335040187035859)],
        &[(0b10001, &ENTRY_AMEBEAN_8080760714988914896)],
        &[(0b10001, &ENTRY_AMEBIAN_1868510719746036319)],
        &[(0b10001, &ENTRY_AMEBIASES_191994802519161378)],
        &[(0b10001, &ENTRY_AMEBIASIS_15952343352557455271)],
        &[(0b10001, &ENTRY_AMOEBIC_11458986316626520792)],
        &[(0b10001, &ENTRY_AMEBICIDAL_12174992966673417980)],
        &[(0b10001, &ENTRY_AMEBICIDE_6727392976948759380)],
        &[(0b10001, &ENTRY_AMEBID_8990707670752348207)],
        &[(0b10001, &ENTRY_AMEBIFORM_18384809890812519272)],
        &[(0b10001, &ENTRY_AMEBIOSIS_1796168007817567758)],
        &[(0b10001, &ENTRY_AMEBOCYTE_13745214137940733370)],
        &[(0b10001, &ENTRY_AMEBOCYTES_2131705893903646289)],
        &[(0b10001, &ENTRY_AMOEBOID_15535671593298564900)],
        &[(0b10001, &ENTRY_AMEBOIDISM_5298244506544781863)],
        &[(0b10001, &ENTRY_AMEBOUS_943579757904752148)],
        &[(0b10001, &ENTRY_AMEBULA_11884806604842186245)],
        &[(0b11001, &ENTRY_AMENORRHEA_242453106803645932)],
        &[(0b11001, &ENTRY_AMENORRHEAL_14815736395132018820)],
        &[(0b11001, &ENTRY_AMENORRHEAS_3139958337225187988)],
        &[(0b11001, &ENTRY_AMENORRHEIC_7592925368031506722)],
        &[(0b11010, &ENTRY_AMENORRHEA_242453106803645932)],
        &[(0b11010, &ENTRY_AMENORRHEAL_14815736395132018820)],
        &[(0b11010, &ENTRY_AMENORRHEAS_3139958337225187988)],
        &[(0b11010, &ENTRY_AMENORRHEIC_7592925368031506722)],
        &[(0b10010, &ENTRY_AMERICANIZATION_17361533923238172216)],
        &[(0b10010, &ENTRY_AMERICANIZATIONS_10566116106297564484)],
        &[(0b10010, &ENTRY_AMERICANIZE_17271444033069169029)],
        &[(0b10010, &ENTRY_AMERICANIZED_17030997472393305329)],
        &[(0b10010, &ENTRY_AMERICANIZER_8728502865340307492)],
        &[(0b10010, &ENTRY_AMERICANIZERS_13649354426641948375)],
        &[(0b10010, &ENTRY_AMERICANIZES_11703695827536694615)],
        &[(0b10010, &ENTRY_AMERICANIZING_2551380555094033314)],
        &[(0b01001, &ENTRY_AMERICANIZATION_17361533923238172216)],
        &[(0b01001, &ENTRY_AMERICANIZATIONS_10566116106297564484)],
        &[(0b01001, &ENTRY_AMERICANIZE_17271444033069169029)],
        &[(0b01001, &ENTRY_AMERICANIZED_17030997472393305329)],
        &[(0b01001, &ENTRY_AMERICANIZER_8728502865340307492)],
        &[(0b01001, &ENTRY_AMERICANIZERS_13649354426641948375)],
        &[(0b01001, &ENTRY_AMERICANIZES_11703695827536694615)],
        &[(0b01001, &ENTRY_AMERICANIZING_2551380555094033314)],
    ],
    range: 2..=13,
};

static VARS_AMB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AMB_CHILDREN),
    value: None,
};

pub static VARS_AMB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icolorate"),
        dictgen::InsensitiveStr::Ascii("icoloration"),
        dictgen::InsensitiveStr::Ascii("icolourate"),
        dictgen::InsensitiveStr::Ascii("icolouration"),
        dictgen::InsensitiveStr::Ascii("ilaevous"),
        dictgen::InsensitiveStr::Ascii("ilevous"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AMBICOLORATE_16029524865781794692)],
        &[(0b00001, &ENTRY_AMBICOLORATION_9621174709699501824)],
        &[(0b11010, &ENTRY_AMBICOLORATE_16029524865781794692)],
        &[(0b11010, &ENTRY_AMBICOLORATION_9621174709699501824)],
        &[(0b11010, &ENTRY_AMBILEVOUS_15489788216797140394)],
        &[(0b00001, &ENTRY_AMBILEVOUS_15489788216797140394)],
    ],
    range: 7..=12,
};

static VARS_AMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AMA_CHILDREN),
    value: None,
};

pub static VARS_AMA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lgamatise"),
        dictgen::InsensitiveStr::Ascii("lgamatises"),
        dictgen::InsensitiveStr::Ascii("lgamatize"),
        dictgen::InsensitiveStr::Ascii("lgamatizes"),
        dictgen::InsensitiveStr::Ascii("lgamisation"),
        dictgen::InsensitiveStr::Ascii("lgamisations"),
        dictgen::InsensitiveStr::Ascii("lgamise"),
        dictgen::InsensitiveStr::Ascii("lgamises"),
        dictgen::InsensitiveStr::Ascii("lgamization"),
        dictgen::InsensitiveStr::Ascii("lgamizations"),
        dictgen::InsensitiveStr::Ascii("lgamize"),
        dictgen::InsensitiveStr::Ascii("lgamizes"),
        dictgen::InsensitiveStr::Ascii("lthaea"),
        dictgen::InsensitiveStr::Ascii("lthea"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AMALGAMATIZE_10132057674178478300)],
        &[(0b10010, &ENTRY_AMALGAMATIZES_5890643774572641679)],
        &[(0b01001, &ENTRY_AMALGAMATIZE_10132057674178478300)],
        &[(0b01001, &ENTRY_AMALGAMATIZES_5890643774572641679)],
        &[(0b10010, &ENTRY_AMALGAMIZATION_1227895542692594943)],
        &[(0b10010, &ENTRY_AMALGAMIZATIONS_8840243500079413668)],
        &[(0b10010, &ENTRY_AMALGAMIZE_494609927742594122)],
        &[(0b10010, &ENTRY_AMALGAMIZES_9889624041095207817)],
        &[(0b01001, &ENTRY_AMALGAMIZATION_1227895542692594943)],
        &[(0b01001, &ENTRY_AMALGAMIZATIONS_8840243500079413668)],
        &[(0b01001, &ENTRY_AMALGAMIZE_494609927742594122)],
        &[(0b01001, &ENTRY_AMALGAMIZES_9889624041095207817)],
        &[(0b11010, &ENTRY_AMALTHEA_10246271508362727126)],
        &[(0b00001, &ENTRY_AMALTHEA_10246271508362727126)],
    ],
    range: 5..=12,
};

static VARS_AL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AL_CHILDREN),
    value: None,
};

static VARS_AL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_ALB_NODE),
    Some(&VARS_ALC_NODE),
    None,
    Some(&VARS_ALE_NODE),
    None,
    Some(&VARS_ALG_NODE),
    None,
    Some(&VARS_ALI_NODE),
    None,
    Some(&VARS_ALK_NODE),
    Some(&VARS_ALL_NODE),
    Some(&VARS_ALM_NODE),
    None,
    Some(&VARS_ALO_NODE),
    Some(&VARS_ALP_NODE),
    None,
    None,
    None,
    Some(&VARS_ALT_NODE),
    Some(&VARS_ALU_NODE),
    Some(&VARS_ALV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_ALV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALV_CHILDREN),
    value: None,
};

pub static VARS_ALV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eolae"),
        dictgen::InsensitiveStr::Ascii("eole"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ALVEOLE_1468644614341036052)],
        &[(0b00001, &ENTRY_ALVEOLE_1468644614341036052)],
    ],
    range: 4..=5,
};

static VARS_ALU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALU_CHILDREN),
    value: None,
};

pub static VARS_ALU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("minisation"),
        dictgen::InsensitiveStr::Ascii("minise"),
        dictgen::InsensitiveStr::Ascii("minised"),
        dictgen::InsensitiveStr::Ascii("minises"),
        dictgen::InsensitiveStr::Ascii("minising"),
        dictgen::InsensitiveStr::Ascii("minium"),
        dictgen::InsensitiveStr::Ascii("miniums"),
        dictgen::InsensitiveStr::Ascii("minization"),
        dictgen::InsensitiveStr::Ascii("minize"),
        dictgen::InsensitiveStr::Ascii("minized"),
        dictgen::InsensitiveStr::Ascii("minizes"),
        dictgen::InsensitiveStr::Ascii("minizing"),
        dictgen::InsensitiveStr::Ascii("minum"),
        dictgen::InsensitiveStr::Ascii("minums"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALUMINIZATION_9199820651849568446)],
        &[(0b10010, &ENTRY_ALUMINIZE_9483354617585319049)],
        &[(0b10010, &ENTRY_ALUMINIZED_10511736687970899076)],
        &[(0b10010, &ENTRY_ALUMINIZES_13479682276812698370)],
        &[(0b10010, &ENTRY_ALUMINIZING_17184640806714355126)],
        &[(0b10010, &ENTRY_ALUMINUM_14009724291836144060)],
        &[(0b10010, &ENTRY_ALUMINUMS_17635872113099894054)],
        &[(0b01001, &ENTRY_ALUMINIZATION_9199820651849568446)],
        &[(0b01001, &ENTRY_ALUMINIZE_9483354617585319049)],
        &[(0b01001, &ENTRY_ALUMINIZED_10511736687970899076)],
        &[(0b01001, &ENTRY_ALUMINIZES_13479682276812698370)],
        &[(0b01001, &ENTRY_ALUMINIZING_17184640806714355126)],
        &[(0b01001, &ENTRY_ALUMINUM_14009724291836144060)],
        &[(0b01001, &ENTRY_ALUMINUMS_17635872113099894054)],
    ],
    range: 5..=10,
};

static VARS_ALT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALT_CHILDREN),
    value: None,
};

pub static VARS_ALT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ernise"),
        dictgen::InsensitiveStr::Ascii("ernises"),
        dictgen::InsensitiveStr::Ascii("ernize"),
        dictgen::InsensitiveStr::Ascii("ernizes"),
        dictgen::InsensitiveStr::Ascii("haea"),
        dictgen::InsensitiveStr::Ascii("haeas"),
        dictgen::InsensitiveStr::Ascii("haein"),
        dictgen::InsensitiveStr::Ascii("hea"),
        dictgen::InsensitiveStr::Ascii("heas"),
        dictgen::InsensitiveStr::Ascii("hein"),
        dictgen::InsensitiveStr::Ascii("ho"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALTERNIZE_13385825174475592158)],
        &[(0b10010, &ENTRY_ALTERNIZES_6270469533749381019)],
        &[(0b01001, &ENTRY_ALTERNIZE_13385825174475592158)],
        &[(0b01001, &ENTRY_ALTERNIZES_6270469533749381019)],
        &[(0b11010, &ENTRY_ALTHEA_11537003706783870112)],
        &[(0b11010, &ENTRY_ALTHEAS_15869195144516418672)],
        &[(0b11010, &ENTRY_ALTHEIN_5685929198321095359)],
        &[(0b10001, &ENTRY_ALTHEA_11537003706783870112)],
        &[(0b10001, &ENTRY_ALTHEAS_15869195144516418672)],
        &[(0b00001, &ENTRY_ALTHEIN_5685929198321095359)],
        &[(0b00001, &ENTRY_ALTHOUGH_1476504865379962577)],
    ],
    range: 2..=7,
};

static VARS_ALP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALP_CHILDREN),
    value: None,
};

pub static VARS_ALP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("habetisation"),
        dictgen::InsensitiveStr::Ascii("habetisations"),
        dictgen::InsensitiveStr::Ascii("habetise"),
        dictgen::InsensitiveStr::Ascii("habetised"),
        dictgen::InsensitiveStr::Ascii("habetiser"),
        dictgen::InsensitiveStr::Ascii("habetisers"),
        dictgen::InsensitiveStr::Ascii("habetises"),
        dictgen::InsensitiveStr::Ascii("habetising"),
        dictgen::InsensitiveStr::Ascii("habetization"),
        dictgen::InsensitiveStr::Ascii("habetizations"),
        dictgen::InsensitiveStr::Ascii("habetize"),
        dictgen::InsensitiveStr::Ascii("habetized"),
        dictgen::InsensitiveStr::Ascii("habetizer"),
        dictgen::InsensitiveStr::Ascii("habetizers"),
        dictgen::InsensitiveStr::Ascii("habetizes"),
        dictgen::InsensitiveStr::Ascii("habetizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALPHABETIZATION_1968434628773617953)],
        &[(0b10010, &ENTRY_ALPHABETIZATIONS_6211095631410316582)],
        &[(0b10010, &ENTRY_ALPHABETIZE_17413351134035178681)],
        &[(0b10010, &ENTRY_ALPHABETIZED_2753693013313167498)],
        &[(0b10010, &ENTRY_ALPHABETIZER_2275393906060793039)],
        &[(0b10010, &ENTRY_ALPHABETIZERS_7973238112885182445)],
        &[(0b10010, &ENTRY_ALPHABETIZES_5626725721294168785)],
        &[(0b10010, &ENTRY_ALPHABETIZING_3131711685375790300)],
        &[(0b01001, &ENTRY_ALPHABETIZATION_1968434628773617953)],
        &[(0b01001, &ENTRY_ALPHABETIZATIONS_6211095631410316582)],
        &[(0b01001, &ENTRY_ALPHABETIZE_17413351134035178681)],
        &[(0b01001, &ENTRY_ALPHABETIZED_2753693013313167498)],
        &[(0b01001, &ENTRY_ALPHABETIZER_2275393906060793039)],
        &[(0b01001, &ENTRY_ALPHABETIZERS_7973238112885182445)],
        &[(0b01001, &ENTRY_ALPHABETIZES_5626725721294168785)],
        &[(0b01001, &ENTRY_ALPHABETIZING_3131711685375790300)],
    ],
    range: 8..=13,
};

static VARS_ALO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALO_CHILDREN),
    value: None,
};

pub static VARS_ALO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("eus")],
    values: &[&[(0b11010, &ENTRY_ALEUS_3052878685126980247)]],
    range: 3..=3,
};

static VARS_ALM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALM_CHILDREN),
    value: None,
};

pub static VARS_ALM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anack"),
        dictgen::InsensitiveStr::Ascii("anacks"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALMANAC_9022062463507112858)],
        &[(0b10010, &ENTRY_ALMANACS_5174170691068691024)],
    ],
    range: 5..=6,
};

static VARS_ALL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALL_CHILDREN),
    value: None,
};

pub static VARS_ALL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("egorisation"),
        dictgen::InsensitiveStr::Ascii("egorisations"),
        dictgen::InsensitiveStr::Ascii("egorise"),
        dictgen::InsensitiveStr::Ascii("egorised"),
        dictgen::InsensitiveStr::Ascii("egoriser"),
        dictgen::InsensitiveStr::Ascii("egorisers"),
        dictgen::InsensitiveStr::Ascii("egorises"),
        dictgen::InsensitiveStr::Ascii("egorising"),
        dictgen::InsensitiveStr::Ascii("egorization"),
        dictgen::InsensitiveStr::Ascii("egorizations"),
        dictgen::InsensitiveStr::Ascii("egorize"),
        dictgen::InsensitiveStr::Ascii("egorized"),
        dictgen::InsensitiveStr::Ascii("egorizer"),
        dictgen::InsensitiveStr::Ascii("egorizers"),
        dictgen::InsensitiveStr::Ascii("egorizes"),
        dictgen::InsensitiveStr::Ascii("egorizing"),
        dictgen::InsensitiveStr::Ascii("oxuraemia"),
        dictgen::InsensitiveStr::Ascii("oxuremia"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALLEGORIZATION_4541977880287652521)],
        &[(0b10010, &ENTRY_ALLEGORIZATIONS_8012727316187763644)],
        &[(0b10010, &ENTRY_ALLEGORIZE_8243818793381064842)],
        &[(0b10010, &ENTRY_ALLEGORIZED_15639970683830457866)],
        &[(0b10010, &ENTRY_ALLEGORIZER_3988457917108953181)],
        &[(0b10010, &ENTRY_ALLEGORIZERS_14958456277764981191)],
        &[(0b10010, &ENTRY_ALLEGORIZES_264741514106655340)],
        &[(0b10010, &ENTRY_ALLEGORIZING_6032281381406970489)],
        &[(0b01001, &ENTRY_ALLEGORIZATION_4541977880287652521)],
        &[(0b01001, &ENTRY_ALLEGORIZATIONS_8012727316187763644)],
        &[(0b01001, &ENTRY_ALLEGORIZE_8243818793381064842)],
        &[(0b01001, &ENTRY_ALLEGORIZED_15639970683830457866)],
        &[(0b01001, &ENTRY_ALLEGORIZER_3988457917108953181)],
        &[(0b01001, &ENTRY_ALLEGORIZERS_14958456277764981191)],
        &[(0b01001, &ENTRY_ALLEGORIZES_264741514106655340)],
        &[(0b01001, &ENTRY_ALLEGORIZING_6032281381406970489)],
        &[(0b11010, &ENTRY_ALLOXUREMIA_1732700770441739843)],
        &[(0b00001, &ENTRY_ALLOXUREMIA_1732700770441739843)],
    ],
    range: 7..=12,
};

static VARS_ALK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALK_CHILDREN),
    value: None,
};

pub static VARS_ALK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alinisation"),
        dictgen::InsensitiveStr::Ascii("alinisations"),
        dictgen::InsensitiveStr::Ascii("alinise"),
        dictgen::InsensitiveStr::Ascii("alinised"),
        dictgen::InsensitiveStr::Ascii("alinises"),
        dictgen::InsensitiveStr::Ascii("alinising"),
        dictgen::InsensitiveStr::Ascii("alinization"),
        dictgen::InsensitiveStr::Ascii("alinizations"),
        dictgen::InsensitiveStr::Ascii("alinize"),
        dictgen::InsensitiveStr::Ascii("alinized"),
        dictgen::InsensitiveStr::Ascii("alinizes"),
        dictgen::InsensitiveStr::Ascii("alinizing"),
        dictgen::InsensitiveStr::Ascii("alisable"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alizable"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALKALINIZATION_3423502466279984150)],
        &[(0b10010, &ENTRY_ALKALINIZATIONS_6341885267161977275)],
        &[(0b10010, &ENTRY_ALKALINIZE_14771433372647914923)],
        &[(0b10010, &ENTRY_ALKALINIZED_17127755905736389533)],
        &[(0b10010, &ENTRY_ALKALINIZES_8062929759471029941)],
        &[(0b10010, &ENTRY_ALKALINIZING_11857659143291411210)],
        &[(0b01001, &ENTRY_ALKALINIZATION_3423502466279984150)],
        &[(0b01001, &ENTRY_ALKALINIZATIONS_6341885267161977275)],
        &[(0b01001, &ENTRY_ALKALINIZE_14771433372647914923)],
        &[(0b01001, &ENTRY_ALKALINIZED_17127755905736389533)],
        &[(0b01001, &ENTRY_ALKALINIZES_8062929759471029941)],
        &[(0b01001, &ENTRY_ALKALINIZING_11857659143291411210)],
        &[(0b10010, &ENTRY_ALKALIZABLE_13736993329747194170)],
        &[(0b10010, &ENTRY_ALKALIZATION_3651800699418661876)],
        &[(0b10010, &ENTRY_ALKALIZATIONS_13229553745279157491)],
        &[(0b10010, &ENTRY_ALKALIZE_3601892613281117908)],
        &[(0b10010, &ENTRY_ALKALIZED_11259806011761795306)],
        &[(0b10010, &ENTRY_ALKALIZER_14632296185920449101)],
        &[(0b10010, &ENTRY_ALKALIZES_17996521291317798431)],
        &[(0b10010, &ENTRY_ALKALIZING_18021680471530652347)],
        &[(0b01001, &ENTRY_ALKALIZABLE_13736993329747194170)],
        &[(0b01001, &ENTRY_ALKALIZATION_3651800699418661876)],
        &[(0b01001, &ENTRY_ALKALIZATIONS_13229553745279157491)],
        &[(0b01001, &ENTRY_ALKALIZE_3601892613281117908)],
        &[(0b01001, &ENTRY_ALKALIZED_11259806011761795306)],
        &[(0b01001, &ENTRY_ALKALIZER_14632296185920449101)],
        &[(0b01001, &ENTRY_ALKALIZES_17996521291317798431)],
        &[(0b01001, &ENTRY_ALKALIZING_18021680471530652347)],
    ],
    range: 5..=12,
};

static VARS_ALI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALI_CHILDREN),
    value: None,
};

pub static VARS_ALI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("ned"),
        dictgen::InsensitiveStr::Ascii("nement"),
        dictgen::InsensitiveStr::Ascii("nements"),
        dictgen::InsensitiveStr::Ascii("nes"),
        dictgen::InsensitiveStr::Ascii("ning"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALIENIZE_17985228286325897083)],
        &[(0b10010, &ENTRY_ALIENIZES_7602952593780461071)],
        &[(0b01001, &ENTRY_ALIENIZE_17985228286325897083)],
        &[(0b01001, &ENTRY_ALIENIZES_7602952593780461071)],
        &[(0b00001, &ENTRY_ALIGN_4971550510086993659)],
        &[(0b00001, &ENTRY_ALIGNED_8535548357538490917)],
        &[(0b00001, &ENTRY_ALIGNMENT_16172862810825494574)],
        &[(0b00001, &ENTRY_ALIGNMENTS_13271850361761755881)],
        &[(0b00001, &ENTRY_ALIGNS_17212579295098786518)],
        &[(0b00001, &ENTRY_ALIGNING_11906672542962792842)],
    ],
    range: 2..=7,
};

static VARS_ALG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALG_CHILDREN),
    value: None,
};

pub static VARS_ALG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesis"),
        dictgen::InsensitiveStr::Ascii("ebraisation"),
        dictgen::InsensitiveStr::Ascii("ebraisations"),
        dictgen::InsensitiveStr::Ascii("ebraise"),
        dictgen::InsensitiveStr::Ascii("ebraises"),
        dictgen::InsensitiveStr::Ascii("ebraization"),
        dictgen::InsensitiveStr::Ascii("ebraizations"),
        dictgen::InsensitiveStr::Ascii("ebraize"),
        dictgen::InsensitiveStr::Ascii("ebraizes"),
        dictgen::InsensitiveStr::Ascii("esthesis"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ALGESTHESIS_10162337686037967662)],
        &[(0b10010, &ENTRY_ALGEBRAIZATION_1080988040552907317)],
        &[(0b10010, &ENTRY_ALGEBRAIZATIONS_1118204679681555228)],
        &[(0b10010, &ENTRY_ALGEBRAIZE_4974435447622870294)],
        &[(0b10010, &ENTRY_ALGEBRAIZES_14667284517281133424)],
        &[(0b01001, &ENTRY_ALGEBRAIZATION_1080988040552907317)],
        &[(0b01001, &ENTRY_ALGEBRAIZATIONS_1118204679681555228)],
        &[(0b01001, &ENTRY_ALGEBRAIZE_4974435447622870294)],
        &[(0b01001, &ENTRY_ALGEBRAIZES_14667284517281133424)],
        &[(0b00001, &ENTRY_ALGESTHESIS_10162337686037967662)],
    ],
    range: 7..=12,
};

static VARS_ALE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALE_CHILDREN),
    value: None,
};

pub static VARS_ALE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ucaemic"),
        dictgen::InsensitiveStr::Ascii("ucemic"),
        dictgen::InsensitiveStr::Ascii("ukaemic"),
        dictgen::InsensitiveStr::Ascii("ukemic"),
        dictgen::InsensitiveStr::Ascii("us"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ALEUCEMIC_15331592114170624314)],
        &[(0b00001, &ENTRY_ALEUCEMIC_15331592114170624314)],
        &[(0b11010, &ENTRY_ALEUKEMIC_12081345934336952932)],
        &[(0b00001, &ENTRY_ALEUKEMIC_12081345934336952932)],
        &[(0b00001, &ENTRY_ALEUS_3052878685126980247)],
    ],
    range: 2..=7,
};

static VARS_ALC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALC_CHILDREN),
    value: None,
};

pub static VARS_ALC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hemise"),
        dictgen::InsensitiveStr::Ascii("hemised"),
        dictgen::InsensitiveStr::Ascii("hemises"),
        dictgen::InsensitiveStr::Ascii("hemising"),
        dictgen::InsensitiveStr::Ascii("hemize"),
        dictgen::InsensitiveStr::Ascii("hemized"),
        dictgen::InsensitiveStr::Ascii("hemizes"),
        dictgen::InsensitiveStr::Ascii("hemizing"),
        dictgen::InsensitiveStr::Ascii("idae"),
        dictgen::InsensitiveStr::Ascii("ide"),
        dictgen::InsensitiveStr::Ascii("ithoae"),
        dictgen::InsensitiveStr::Ascii("ithoe"),
        dictgen::InsensitiveStr::Ascii("oholisable"),
        dictgen::InsensitiveStr::Ascii("oholisables"),
        dictgen::InsensitiveStr::Ascii("oholisation"),
        dictgen::InsensitiveStr::Ascii("oholisations"),
        dictgen::InsensitiveStr::Ascii("oholise"),
        dictgen::InsensitiveStr::Ascii("oholised"),
        dictgen::InsensitiveStr::Ascii("oholises"),
        dictgen::InsensitiveStr::Ascii("oholising"),
        dictgen::InsensitiveStr::Ascii("oholizable"),
        dictgen::InsensitiveStr::Ascii("oholizables"),
        dictgen::InsensitiveStr::Ascii("oholization"),
        dictgen::InsensitiveStr::Ascii("oholizations"),
        dictgen::InsensitiveStr::Ascii("oholize"),
        dictgen::InsensitiveStr::Ascii("oholized"),
        dictgen::InsensitiveStr::Ascii("oholizes"),
        dictgen::InsensitiveStr::Ascii("oholizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALCHEMIZE_4688225926772014989)],
        &[(0b10010, &ENTRY_ALCHEMIZED_970509173487598237)],
        &[(0b10010, &ENTRY_ALCHEMIZES_11682546917258585686)],
        &[(0b10010, &ENTRY_ALCHEMIZING_6827374645777654741)],
        &[(0b01001, &ENTRY_ALCHEMIZE_4688225926772014989)],
        &[(0b01001, &ENTRY_ALCHEMIZED_970509173487598237)],
        &[(0b01001, &ENTRY_ALCHEMIZES_11682546917258585686)],
        &[(0b01001, &ENTRY_ALCHEMIZING_6827374645777654741)],
        &[(0b11010, &ENTRY_ALCIDE_7180803551810387458)],
        &[(0b00001, &ENTRY_ALCIDE_7180803551810387458)],
        &[(0b11010, &ENTRY_ALCITHOE_18334513949439348849)],
        &[(0b00001, &ENTRY_ALCITHOE_18334513949439348849)],
        &[(0b10010, &ENTRY_ALCOHOLIZABLE_9485403642663692960)],
        &[(0b10010, &ENTRY_ALCOHOLIZABLES_18037838911878128020)],
        &[(0b10010, &ENTRY_ALCOHOLIZATION_2472328753870379661)],
        &[(0b10010, &ENTRY_ALCOHOLIZATIONS_3234492423155906190)],
        &[(0b10010, &ENTRY_ALCOHOLIZE_2784092109356476451)],
        &[(0b10010, &ENTRY_ALCOHOLIZED_10813198565244222907)],
        &[(0b10010, &ENTRY_ALCOHOLIZES_14942241136434110267)],
        &[(0b10010, &ENTRY_ALCOHOLIZING_12094421078983570983)],
        &[(0b01001, &ENTRY_ALCOHOLIZABLE_9485403642663692960)],
        &[(0b01001, &ENTRY_ALCOHOLIZABLES_18037838911878128020)],
        &[(0b01001, &ENTRY_ALCOHOLIZATION_2472328753870379661)],
        &[(0b01001, &ENTRY_ALCOHOLIZATIONS_3234492423155906190)],
        &[(0b01001, &ENTRY_ALCOHOLIZE_2784092109356476451)],
        &[(0b01001, &ENTRY_ALCOHOLIZED_10813198565244222907)],
        &[(0b01001, &ENTRY_ALCOHOLIZES_14942241136434110267)],
        &[(0b01001, &ENTRY_ALCOHOLIZING_12094421078983570983)],
    ],
    range: 3..=12,
};

static VARS_ALB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALB_CHILDREN),
    value: None,
};

pub static VARS_ALB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
        dictgen::InsensitiveStr::Ascii("umeniser"),
        dictgen::InsensitiveStr::Ascii("umenization"),
        dictgen::InsensitiveStr::Ascii("umenizations"),
        dictgen::InsensitiveStr::Ascii("umenize"),
        dictgen::InsensitiveStr::Ascii("umenized"),
        dictgen::InsensitiveStr::Ascii("umenizer"),
        dictgen::InsensitiveStr::Ascii("umenizes"),
        dictgen::InsensitiveStr::Ascii("umenizing"),
        dictgen::InsensitiveStr::Ascii("uminisation"),
        dictgen::InsensitiveStr::Ascii("uminisations"),
        dictgen::InsensitiveStr::Ascii("uminise"),
        dictgen::InsensitiveStr::Ascii("uminised"),
        dictgen::InsensitiveStr::Ascii("uminises"),
        dictgen::InsensitiveStr::Ascii("uminising"),
        dictgen::InsensitiveStr::Ascii("uminization"),
        dictgen::InsensitiveStr::Ascii("uminizations"),
        dictgen::InsensitiveStr::Ascii("uminize"),
        dictgen::InsensitiveStr::Ascii("uminized"),
        dictgen::InsensitiveStr::Ascii("uminizes"),
        dictgen::InsensitiveStr::Ascii("uminizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALBITIZE_6580071593309620120)],
        &[(0b10010, &ENTRY_ALBITIZED_12708773531187894235)],
        &[(0b10010, &ENTRY_ALBITIZES_1247422159797012629)],
        &[(0b10010, &ENTRY_ALBITIZING_16312871487467352322)],
        &[(0b01001, &ENTRY_ALBITIZE_6580071593309620120)],
        &[(0b01001, &ENTRY_ALBITIZED_12708773531187894235)],
        &[(0b01001, &ENTRY_ALBITIZES_1247422159797012629)],
        &[(0b01001, &ENTRY_ALBITIZING_16312871487467352322)],
        &[(0b10010, &ENTRY_ALBUMENIZER_2746832931557084359)],
        &[(0b00001, &ENTRY_ALBUMENIZATION_917091341157704514)],
        &[(0b00001, &ENTRY_ALBUMENIZATIONS_361266413627576903)],
        &[(0b00001, &ENTRY_ALBUMENIZE_9958331304830383569)],
        &[(0b00001, &ENTRY_ALBUMENIZED_5015192375248331764)],
        &[(0b01001, &ENTRY_ALBUMENIZER_2746832931557084359)],
        &[(0b00001, &ENTRY_ALBUMENIZES_7335751188788108476)],
        &[(0b00001, &ENTRY_ALBUMENIZING_16024947632070767741)],
        &[(0b10010, &ENTRY_ALBUMENIZATION_917091341157704514)],
        &[(0b10010, &ENTRY_ALBUMENIZATIONS_361266413627576903)],
        &[(0b10010, &ENTRY_ALBUMENIZE_9958331304830383569)],
        &[(0b10010, &ENTRY_ALBUMENIZED_5015192375248331764)],
        &[(0b10010, &ENTRY_ALBUMENIZES_7335751188788108476)],
        &[(0b10010, &ENTRY_ALBUMENIZING_16024947632070767741)],
        &[(0b01000, &ENTRY_ALBUMENIZATION_917091341157704514)],
        &[(0b01000, &ENTRY_ALBUMENIZATIONS_361266413627576903)],
        &[(0b01000, &ENTRY_ALBUMENIZE_9958331304830383569)],
        &[(0b01000, &ENTRY_ALBUMENIZED_5015192375248331764)],
        &[(0b01000, &ENTRY_ALBUMENIZES_7335751188788108476)],
        &[(0b01000, &ENTRY_ALBUMENIZING_16024947632070767741)],
    ],
    range: 5..=12,
};

static VARS_AK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AK_CHILDREN),
    value: None,
};

pub static VARS_AK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("tistetae"),
        dictgen::InsensitiveStr::Ascii("tistete"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AKER_159315244585453376)],
        &[(0b11010, &ENTRY_AKER_159315244585453376)],
        &[(0b11010, &ENTRY_AKTISTETE_2376014706515547798)],
        &[(0b00001, &ENTRY_AKTISTETE_2376014706515547798)],
    ],
    range: 2..=8,
};

static VARS_AI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AI_CHILDREN),
    value: None,
};

pub static VARS_AI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ger"),
        dictgen::InsensitiveStr::Ascii("gre"),
        dictgen::InsensitiveStr::Ascii("rfoil"),
        dictgen::InsensitiveStr::Ascii("rfoils"),
        dictgen::InsensitiveStr::Ascii("rgel"),
        dictgen::InsensitiveStr::Ascii("rplane"),
        dictgen::InsensitiveStr::Ascii("rplanes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AIGER_5594412989495342326)],
        &[(0b11010, &ENTRY_AIGER_5594412989495342326)],
        &[(0b01001, &ENTRY_AIRFOIL_8793212550719857477)],
        &[(0b01001, &ENTRY_AIRFOILS_16600511204738890239)],
        &[(0b00001, &ENTRY_AIRGEL_13006938656131464461)],
        &[(0b11001, &ENTRY_AIRPLANE_9809064680775935608)],
        &[(0b11001, &ENTRY_AIRPLANES_7495463879091464018)],
    ],
    range: 3..=7,
};

static VARS_AG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AG_CHILDREN),
    value: None,
};

static VARS_AG_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_AGA_NODE),
    None,
    None,
    None,
    Some(&VARS_AGE_NODE),
    None,
    Some(&VARS_AGG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_AGN_NODE),
    Some(&VARS_AGO_NODE),
    None,
    None,
    Some(&VARS_AGR_NODE),
    None,
    None,
    Some(&VARS_AGU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_AGU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGU_CHILDREN),
    value: None,
};

pub static VARS_AGU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AGUIZE_2128537953908418385)],
        &[(0b10010, &ENTRY_AGUIZED_8691849110214980652)],
        &[(0b10010, &ENTRY_AGUIZES_9850955252997743907)],
        &[(0b10010, &ENTRY_AGUIZING_10322941876567610033)],
        &[(0b01001, &ENTRY_AGUIZE_2128537953908418385)],
        &[(0b01001, &ENTRY_AGUIZED_8691849110214980652)],
        &[(0b01001, &ENTRY_AGUIZES_9850955252997743907)],
        &[(0b01001, &ENTRY_AGUIZING_10322941876567610033)],
    ],
    range: 3..=5,
};

static VARS_AGR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGR_CHILDREN),
    value: None,
};

pub static VARS_AGR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arianise"),
        dictgen::InsensitiveStr::Ascii("arianises"),
        dictgen::InsensitiveStr::Ascii("arianize"),
        dictgen::InsensitiveStr::Ascii("arianizes"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AGRARIANIZE_1743127394833633445)],
        &[(0b10010, &ENTRY_AGRARIANIZES_15839932416088518712)],
        &[(0b01001, &ENTRY_AGRARIANIZE_1743127394833633445)],
        &[(0b01001, &ENTRY_AGRARIANIZES_15839932416088518712)],
        &[(0b11010, &ENTRY_AGER_9193302169289361702)],
        &[(0b10010, &ENTRY_AGRIZE_10021775222091159751)],
        &[(0b10010, &ENTRY_AGRIZED_589451309246337777)],
        &[(0b10010, &ENTRY_AGRIZES_3555606021924104510)],
        &[(0b10010, &ENTRY_AGRIZING_13950999867910650133)],
        &[(0b01001, &ENTRY_AGRIZE_10021775222091159751)],
        &[(0b01001, &ENTRY_AGRIZED_589451309246337777)],
        &[(0b01001, &ENTRY_AGRIZES_3555606021924104510)],
        &[(0b01001, &ENTRY_AGRIZING_13950999867910650133)],
    ],
    range: 1..=9,
};

static VARS_AGO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGO_CHILDREN),
    value: None,
};

pub static VARS_AGO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("nisedlies"),
        dictgen::InsensitiveStr::Ascii("nisedly"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nisinglier"),
        dictgen::InsensitiveStr::Ascii("nisingliest"),
        dictgen::InsensitiveStr::Ascii("nisingly"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizedlies"),
        dictgen::InsensitiveStr::Ascii("nizedly"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
        dictgen::InsensitiveStr::Ascii("nizinglier"),
        dictgen::InsensitiveStr::Ascii("nizingliest"),
        dictgen::InsensitiveStr::Ascii("nizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AGONIZE_14877090130667543233)],
        &[(0b10010, &ENTRY_AGONIZED_17678244103143625810)],
        &[(0b10010, &ENTRY_AGONIZEDLIES_7059700506878805363)],
        &[(0b10010, &ENTRY_AGONIZEDLY_4819060413618915382)],
        &[(0b10010, &ENTRY_AGONIZER_10528504234638853717)],
        &[(0b10010, &ENTRY_AGONIZERS_16633588395922410958)],
        &[(0b10010, &ENTRY_AGONIZES_14844009888333237557)],
        &[(0b10010, &ENTRY_AGONIZING_14014895105394090708)],
        &[(0b10010, &ENTRY_AGONIZINGLIER_10296833915180893028)],
        &[(0b10010, &ENTRY_AGONIZINGLIEST_3823537194548772440)],
        &[(0b10010, &ENTRY_AGONIZINGLY_5283227355985477567)],
        &[(0b01001, &ENTRY_AGONIZE_14877090130667543233)],
        &[(0b01001, &ENTRY_AGONIZED_17678244103143625810)],
        &[(0b01001, &ENTRY_AGONIZEDLIES_7059700506878805363)],
        &[(0b01001, &ENTRY_AGONIZEDLY_4819060413618915382)],
        &[(0b01001, &ENTRY_AGONIZER_10528504234638853717)],
        &[(0b01001, &ENTRY_AGONIZERS_16633588395922410958)],
        &[(0b01001, &ENTRY_AGONIZES_14844009888333237557)],
        &[(0b01001, &ENTRY_AGONIZING_14014895105394090708)],
        &[(0b01001, &ENTRY_AGONIZINGLIER_10296833915180893028)],
        &[(0b01001, &ENTRY_AGONIZINGLIEST_3823537194548772440)],
        &[(0b01001, &ENTRY_AGONIZINGLY_5283227355985477567)],
    ],
    range: 4..=11,
};

static VARS_AGN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGN_CHILDREN),
    value: None,
};

pub static VARS_AGN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AGNIZE_7414310572549278419)],
        &[(0b10010, &ENTRY_AGNIZED_3602067665820241778)],
        &[(0b10010, &ENTRY_AGNIZES_7008306488691527610)],
        &[(0b10010, &ENTRY_AGNIZING_10354208092344487767)],
        &[(0b01001, &ENTRY_AGNIZE_7414310572549278419)],
        &[(0b01001, &ENTRY_AGNIZED_3602067665820241778)],
        &[(0b01001, &ENTRY_AGNIZES_7008306488691527610)],
        &[(0b01001, &ENTRY_AGNIZING_10354208092344487767)],
    ],
    range: 3..=5,
};

static VARS_AGG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGG_CHILDREN),
    value: None,
};

pub static VARS_AGG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("randisable"),
        dictgen::InsensitiveStr::Ascii("randisables"),
        dictgen::InsensitiveStr::Ascii("randisation"),
        dictgen::InsensitiveStr::Ascii("randise"),
        dictgen::InsensitiveStr::Ascii("randised"),
        dictgen::InsensitiveStr::Ascii("randisement"),
        dictgen::InsensitiveStr::Ascii("randisements"),
        dictgen::InsensitiveStr::Ascii("randiser"),
        dictgen::InsensitiveStr::Ascii("randisers"),
        dictgen::InsensitiveStr::Ascii("randises"),
        dictgen::InsensitiveStr::Ascii("randising"),
        dictgen::InsensitiveStr::Ascii("randizable"),
        dictgen::InsensitiveStr::Ascii("randizables"),
        dictgen::InsensitiveStr::Ascii("randization"),
        dictgen::InsensitiveStr::Ascii("randize"),
        dictgen::InsensitiveStr::Ascii("randized"),
        dictgen::InsensitiveStr::Ascii("randizement"),
        dictgen::InsensitiveStr::Ascii("randizements"),
        dictgen::InsensitiveStr::Ascii("randizer"),
        dictgen::InsensitiveStr::Ascii("randizers"),
        dictgen::InsensitiveStr::Ascii("randizes"),
        dictgen::InsensitiveStr::Ascii("randizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AGGRANDIZABLE_1037184785288412738)],
        &[(0b10010, &ENTRY_AGGRANDIZABLES_7273443253306031000)],
        &[(0b10010, &ENTRY_AGGRANDIZATION_5817546113677374440)],
        &[(0b10010, &ENTRY_AGGRANDIZE_14928776110274947016)],
        &[(0b10010, &ENTRY_AGGRANDIZED_5678047642823184520)],
        &[(0b10010, &ENTRY_AGGRANDIZEMENT_5112363745808153547)],
        &[(0b10010, &ENTRY_AGGRANDIZEMENTS_13322482535421162803)],
        &[(0b10010, &ENTRY_AGGRANDIZER_14976020900821693201)],
        &[(0b10010, &ENTRY_AGGRANDIZERS_15651589293150719753)],
        &[(0b10010, &ENTRY_AGGRANDIZES_12993795888011857693)],
        &[(0b10010, &ENTRY_AGGRANDIZING_10289964617012803392)],
        &[(0b01001, &ENTRY_AGGRANDIZABLE_1037184785288412738)],
        &[(0b01001, &ENTRY_AGGRANDIZABLES_7273443253306031000)],
        &[(0b01001, &ENTRY_AGGRANDIZATION_5817546113677374440)],
        &[(0b01001, &ENTRY_AGGRANDIZE_14928776110274947016)],
        &[(0b01001, &ENTRY_AGGRANDIZED_5678047642823184520)],
        &[(0b01001, &ENTRY_AGGRANDIZEMENT_5112363745808153547)],
        &[(0b01001, &ENTRY_AGGRANDIZEMENTS_13322482535421162803)],
        &[(0b01001, &ENTRY_AGGRANDIZER_14976020900821693201)],
        &[(0b01001, &ENTRY_AGGRANDIZERS_15651589293150719753)],
        &[(0b01001, &ENTRY_AGGRANDIZES_12993795888011857693)],
        &[(0b01001, &ENTRY_AGGRANDIZING_10289964617012803392)],
    ],
    range: 7..=12,
};

static VARS_AGE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGE_CHILDREN),
    value: None,
};

pub static VARS_AGE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("r"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AGENIZE_1864369248982715174)],
        &[(0b01001, &ENTRY_AGENIZE_1864369248982715174)],
        &[(0b00001, &ENTRY_AGER_9193302169289361702)],
    ],
    range: 1..=4,
};

static VARS_AGA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGA_CHILDREN),
    value: None,
};

pub static VARS_AGA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thodaemon"),
        dictgen::InsensitiveStr::Ascii("thodemon"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AGATHODEMON_18413031701031888707)],
        &[(0b00001, &ENTRY_AGATHODEMON_18413031701031888707)],
        &[(0b10010, &ENTRY_AGATIZE_10108832763949504643)],
        &[(0b10010, &ENTRY_AGATIZES_5599637212136222765)],
        &[(0b01001, &ENTRY_AGATIZE_10108832763949504643)],
        &[(0b01001, &ENTRY_AGATIZES_5599637212136222765)],
    ],
    range: 4..=9,
};

static VARS_AF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AF_CHILDREN),
    value: None,
};

pub static VARS_AF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("feer"),
        dictgen::InsensitiveStr::Ascii("fere"),
        dictgen::InsensitiveStr::Ascii("ricanisation"),
        dictgen::InsensitiveStr::Ascii("ricanisations"),
        dictgen::InsensitiveStr::Ascii("ricanise"),
        dictgen::InsensitiveStr::Ascii("ricanised"),
        dictgen::InsensitiveStr::Ascii("ricanises"),
        dictgen::InsensitiveStr::Ascii("ricanising"),
        dictgen::InsensitiveStr::Ascii("ricanization"),
        dictgen::InsensitiveStr::Ascii("ricanizations"),
        dictgen::InsensitiveStr::Ascii("ricanize"),
        dictgen::InsensitiveStr::Ascii("ricanized"),
        dictgen::InsensitiveStr::Ascii("ricanizes"),
        dictgen::InsensitiveStr::Ascii("ricanizing"),
        dictgen::InsensitiveStr::Ascii("rikanerisation"),
        dictgen::InsensitiveStr::Ascii("rikanerise"),
        dictgen::InsensitiveStr::Ascii("rikanerised"),
        dictgen::InsensitiveStr::Ascii("rikanerises"),
        dictgen::InsensitiveStr::Ascii("rikanerising"),
        dictgen::InsensitiveStr::Ascii("rikanerization"),
        dictgen::InsensitiveStr::Ascii("rikanerize"),
        dictgen::InsensitiveStr::Ascii("rikanerized"),
        dictgen::InsensitiveStr::Ascii("rikanerizes"),
        dictgen::InsensitiveStr::Ascii("rikanerizing"),
        dictgen::InsensitiveStr::Ascii("terward"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AFFEER_6009483293773969784)],
        &[(0b11010, &ENTRY_AFFEER_6009483293773969784)],
        &[(0b10010, &ENTRY_AFRICANIZATION_5413444630763314543)],
        &[(0b10010, &ENTRY_AFRICANIZATIONS_17695007617535110892)],
        &[(0b10010, &ENTRY_AFRICANIZE_8899009377488121155)],
        &[(0b10010, &ENTRY_AFRICANIZED_8120286406579238289)],
        &[(0b10010, &ENTRY_AFRICANIZES_422967171139772976)],
        &[(0b10010, &ENTRY_AFRICANIZING_5922056489408751942)],
        &[(0b01001, &ENTRY_AFRICANIZATION_5413444630763314543)],
        &[(0b01001, &ENTRY_AFRICANIZATIONS_17695007617535110892)],
        &[(0b01001, &ENTRY_AFRICANIZE_8899009377488121155)],
        &[(0b01001, &ENTRY_AFRICANIZED_8120286406579238289)],
        &[(0b01001, &ENTRY_AFRICANIZES_422967171139772976)],
        &[(0b01001, &ENTRY_AFRICANIZING_5922056489408751942)],
        &[(0b10010, &ENTRY_AFRIKANERIZATION_3589787726485032622)],
        &[(0b10010, &ENTRY_AFRIKANERIZE_3316018485342870963)],
        &[(0b10010, &ENTRY_AFRIKANERIZED_16796393449369554865)],
        &[(0b10010, &ENTRY_AFRIKANERIZES_15139135300181540690)],
        &[(0b10010, &ENTRY_AFRIKANERIZING_3981551782275451309)],
        &[(0b01001, &ENTRY_AFRIKANERIZATION_3589787726485032622)],
        &[(0b01001, &ENTRY_AFRIKANERIZE_3316018485342870963)],
        &[(0b01001, &ENTRY_AFRIKANERIZED_16796393449369554865)],
        &[(0b01001, &ENTRY_AFRIKANERIZES_15139135300181540690)],
        &[(0b01001, &ENTRY_AFRIKANERIZING_3981551782275451309)],
        &[(0b01001, &ENTRY_AFTERWARDS_5679799743915530462)],
    ],
    range: 4..=14,
};

static VARS_AE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AE_CHILDREN),
    value: None,
};

static VARS_AE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_AEA_NODE),
    None,
    Some(&VARS_AEC_NODE),
    Some(&VARS_AED_NODE),
    Some(&VARS_AEE_NODE),
    None,
    Some(&VARS_AEG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_AEM_NODE),
    Some(&VARS_AEN_NODE),
    Some(&VARS_AEO_NODE),
    None,
    Some(&VARS_AEQ_NODE),
    Some(&VARS_AER_NODE),
    Some(&VARS_AES_NODE),
    Some(&VARS_AET_NODE),
    None,
    Some(&VARS_AEV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_AEV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEV_CHILDREN),
    value: None,
};

pub static VARS_AEV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("iternal")],
    values: &[&[(0b11010, &ENTRY_EVITERNAL_7722180848811514076)]],
    range: 7..=7,
};

static VARS_AET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AET_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_ET_16709700743642230371)]),
};

pub static VARS_AET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("heling"),
        dictgen::InsensitiveStr::Ascii("hered"),
        dictgen::InsensitiveStr::Ascii("heric"),
        dictgen::InsensitiveStr::Ascii("iogenic"),
        dictgen::InsensitiveStr::Ascii("iologically"),
        dictgen::InsensitiveStr::Ascii("iologist"),
        dictgen::InsensitiveStr::Ascii("iologue"),
        dictgen::InsensitiveStr::Ascii("iology"),
        dictgen::InsensitiveStr::Ascii("iophyllin"),
        dictgen::InsensitiveStr::Ascii("iotropic"),
        dictgen::InsensitiveStr::Ascii("iotropically"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ETHELING_18173115252038941149)],
        &[(0b11010, &ENTRY_ETHERED_14211226607017083705)],
        &[(0b11010, &ENTRY_ETHERIC_10479002354969561160)],
        &[(0b11010, &ENTRY_ETIOGENIC_3830033599800632807)],
        &[(0b10010, &ENTRY_ETIOLOGICALLY_1064612193650452227)],
        &[(0b11010, &ENTRY_ETIOLOGIST_7320826493575703902)],
        &[(0b11010, &ENTRY_ETIOLOGUE_4428360053767153112)],
        &[(0b10010, &ENTRY_ETIOLOGY_4658311861857715324)],
        &[(0b11010, &ENTRY_ETIOPHYLLIN_7707186585402559694)],
        &[(0b11010, &ENTRY_ETIOTROPIC_18055180651114367254)],
        &[(0b11010, &ENTRY_ETIOTROPICALLY_1085913366626989126)],
    ],
    range: 5..=12,
};

static VARS_AES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AES_CHILDREN),
    value: None,
};

pub static VARS_AES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("c"),
        dictgen::InsensitiveStr::Ascii("chynite"),
        dictgen::InsensitiveStr::Ascii("culapian"),
        dictgen::InsensitiveStr::Ascii("culetin"),
        dictgen::InsensitiveStr::Ascii("culin"),
        dictgen::InsensitiveStr::Ascii("op"),
        dictgen::InsensitiveStr::Ascii("theses"),
        dictgen::InsensitiveStr::Ascii("thesia"),
        dictgen::InsensitiveStr::Ascii("thesias"),
        dictgen::InsensitiveStr::Ascii("thesiogen"),
        dictgen::InsensitiveStr::Ascii("thesiogenic"),
        dictgen::InsensitiveStr::Ascii("thesiogens"),
        dictgen::InsensitiveStr::Ascii("thesis"),
        dictgen::InsensitiveStr::Ascii("thetical"),
        dictgen::InsensitiveStr::Ascii("thetician"),
        dictgen::InsensitiveStr::Ascii("theticians"),
        dictgen::InsensitiveStr::Ascii("theticise"),
        dictgen::InsensitiveStr::Ascii("theticised"),
        dictgen::InsensitiveStr::Ascii("theticises"),
        dictgen::InsensitiveStr::Ascii("theticising"),
        dictgen::InsensitiveStr::Ascii("theticize"),
        dictgen::InsensitiveStr::Ascii("theticized"),
        dictgen::InsensitiveStr::Ascii("theticizes"),
        dictgen::InsensitiveStr::Ascii("theticizing"),
        dictgen::InsensitiveStr::Ascii("tivate"),
        dictgen::InsensitiveStr::Ascii("tivated"),
        dictgen::InsensitiveStr::Ascii("tivates"),
        dictgen::InsensitiveStr::Ascii("tivating"),
        dictgen::InsensitiveStr::Ascii("tivation"),
        dictgen::InsensitiveStr::Ascii("tivations"),
        dictgen::InsensitiveStr::Ascii("tivator"),
        dictgen::InsensitiveStr::Ascii("tive"),
        dictgen::InsensitiveStr::Ascii("tuate"),
        dictgen::InsensitiveStr::Ascii("tuous"),
        dictgen::InsensitiveStr::Ascii("ture"),
        dictgen::InsensitiveStr::Ascii("tus"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ESC_11648574405051320816)],
        &[(0b11010, &ENTRY_ESCHYNITE_2605089747859204015)],
        &[(0b11010, &ENTRY_ESCULAPIAN_13519492358303592154)],
        &[(0b11010, &ENTRY_ESCULETIN_672994155433346330)],
        &[(0b11010, &ENTRY_ESCULIN_12107528280435336696)],
        &[(0b11010, &ENTRY_ESOP_12400930167674936381)],
        &[(0b11010, &ENTRY_ESTHESES_5781061020988119088)],
        &[(0b11010, &ENTRY_ESTHESIA_5605519706169745255)],
        &[(0b11010, &ENTRY_ESTHESIAS_18077472499145709356)],
        &[(0b11010, &ENTRY_ESTHESIOGEN_13850970942201599568)],
        &[(0b11010, &ENTRY_ESTHESIOGENIC_8568990898680713091)],
        &[(0b11010, &ENTRY_ESTHESIOGENS_2539942402442311753)],
        &[(0b11010, &ENTRY_ESTHESIS_17178990420713935317)],
        &[(0b11010, &ENTRY_ESTHETICAL_7594838462752271800)],
        &[(0b11010, &ENTRY_ESTHETICIAN_6690642998636082700)],
        &[(0b11010, &ENTRY_ESTHETICIANS_16857352085837156733)],
        &[(0b10010, &ENTRY_AESTHETICIZE_9439384680082563511)],
        &[(0b10010, &ENTRY_AESTHETICIZED_14357851050724930852)],
        &[(0b10010, &ENTRY_AESTHETICIZES_14449755828314805813)],
        &[(0b10010, &ENTRY_AESTHETICIZING_3795115064284345074)],
        &[(0b01001, &ENTRY_AESTHETICIZE_9439384680082563511)],
        &[(0b01001, &ENTRY_AESTHETICIZED_14357851050724930852)],
        &[(0b01001, &ENTRY_AESTHETICIZES_14449755828314805813)],
        &[(0b01001, &ENTRY_AESTHETICIZING_3795115064284345074)],
        &[(0b11010, &ENTRY_ESTIVATE_10836493401844257867)],
        &[(0b11010, &ENTRY_ESTIVATED_5948189904457603376)],
        &[(0b11010, &ENTRY_ESTIVATES_8627334418178723288)],
        &[(0b11010, &ENTRY_ESTIVATING_9498433178617024784)],
        &[(0b11010, &ENTRY_ESTIVATION_6434066985142123064)],
        &[(0b11010, &ENTRY_ESTIVATIONS_15940487245092349305)],
        &[(0b11010, &ENTRY_ESTIVATOR_1664787615112181438)],
        &[(0b11010, &ENTRY_ESTIVE_4965384148538852144)],
        &[(0b11010, &ENTRY_ESTUATE_5365503068852828289)],
        &[(0b11010, &ENTRY_ESTUOUS_10323897909821636581)],
        &[(0b11010, &ENTRY_ESTURE_10845028240222484807)],
        &[(0b11010, &ENTRY_ESTUS_3275119451126332640)],
    ],
    range: 1..=11,
};

static VARS_AER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AER_CHILDREN),
    value: None,
};

pub static VARS_AER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialness"),
        dictgen::InsensitiveStr::Ascii("ic"),
        dictgen::InsensitiveStr::Ascii("ical"),
        dictgen::InsensitiveStr::Ascii("ofoil"),
        dictgen::InsensitiveStr::Ascii("ofoils"),
        dictgen::InsensitiveStr::Ascii("ogel"),
        dictgen::InsensitiveStr::Ascii("ogenesis"),
        dictgen::InsensitiveStr::Ascii("ogenic"),
        dictgen::InsensitiveStr::Ascii("ographer"),
        dictgen::InsensitiveStr::Ascii("ographic"),
        dictgen::InsensitiveStr::Ascii("ographical"),
        dictgen::InsensitiveStr::Ascii("ographies"),
        dictgen::InsensitiveStr::Ascii("ography"),
        dictgen::InsensitiveStr::Ascii("ologic"),
        dictgen::InsensitiveStr::Ascii("ological"),
        dictgen::InsensitiveStr::Ascii("ologies"),
        dictgen::InsensitiveStr::Ascii("ologist"),
        dictgen::InsensitiveStr::Ascii("ology"),
        dictgen::InsensitiveStr::Ascii("ometer"),
        dictgen::InsensitiveStr::Ascii("ometers"),
        dictgen::InsensitiveStr::Ascii("ometric"),
        dictgen::InsensitiveStr::Ascii("ope"),
        dictgen::InsensitiveStr::Ascii("oplane"),
        dictgen::InsensitiveStr::Ascii("oplanes"),
        dictgen::InsensitiveStr::Ascii("os"),
        dictgen::InsensitiveStr::Ascii("ose"),
        dictgen::InsensitiveStr::Ascii("uginous"),
        dictgen::InsensitiveStr::Ascii("ugo"),
        dictgen::InsensitiveStr::Ascii("ugos"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AERIALNESS_4004993463972813657)],
        &[
            (0b00001, &ENTRY_AERIC_10020180033075484870),
            (0b11010, &ENTRY_ERIC_17025031939768003248),
        ],
        &[(0b11010, &ENTRY_ERICAL_8655189856383454932)],
        &[(0b10010, &ENTRY_AIRFOIL_8793212550719857477)],
        &[(0b10010, &ENTRY_AIRFOILS_16600511204738890239)],
        &[(0b11010, &ENTRY_AIRGEL_13006938656131464461)],
        &[(0b11010, &ENTRY_EROGENESIS_4160838603281198154)],
        &[(0b11010, &ENTRY_EROGENIC_3471326385946721331)],
        &[(0b00001, &ENTRY_AEROGRAPHER_85789760672961791)],
        &[(0b00001, &ENTRY_AEROGRAPHIC_5707019479991978033)],
        &[(0b00001, &ENTRY_AEROGRAPHICAL_12793888458146758836)],
        &[(0b00001, &ENTRY_AEROGRAPHIES_9522044483381698756)],
        &[(0b00001, &ENTRY_AEROGRAPHY_9279141637627756120)],
        &[(0b00001, &ENTRY_AEROLOGIC_12163962530263481700)],
        &[(0b00001, &ENTRY_AEROLOGICAL_7520248570186497308)],
        &[(0b00001, &ENTRY_AEROLOGIES_4052658077915194200)],
        &[(0b00001, &ENTRY_AEROLOGIST_233176875293717737)],
        &[(0b00001, &ENTRY_AEROLOGY_3025685712114846212)],
        &[(0b00001, &ENTRY_AEROMETER_17405185222225302259)],
        &[(0b00001, &ENTRY_AEROMETERS_10976694975875082042)],
        &[(0b00001, &ENTRY_AEROMETRIC_357071446782082902)],
        &[(0b00001, &ENTRY_AEROPE_1173414714172364053)],
        &[(0b10010, &ENTRY_AIRPLANE_9809064680775935608)],
        &[(0b10010, &ENTRY_AIRPLANES_7495463879091464018)],
        &[(0b11010, &ENTRY_EROS_3972390604755404559)],
        &[(0b11010, &ENTRY_EROSE_3198202279341053863)],
        &[(0b11010, &ENTRY_ERUGINOUS_14659575552896773213)],
        &[(0b11010, &ENTRY_ERUGO_5752272360915842141)],
        &[(0b11010, &ENTRY_ERUGOS_8349991962965375484)],
    ],
    range: 2..=10,
};

static VARS_AEQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEQ_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_EQ_4118536122320847820)]),
};

pub static VARS_AEQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_AEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEO_CHILDREN),
    value: None,
};

pub static VARS_AEO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lic"),
        dictgen::InsensitiveStr::Ascii("lipile"),
        dictgen::InsensitiveStr::Ascii("lipiles"),
        dictgen::InsensitiveStr::Ascii("lotropic"),
        dictgen::InsensitiveStr::Ascii("nian"),
        dictgen::InsensitiveStr::Ascii("nism"),
        dictgen::InsensitiveStr::Ascii("nisms"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EOLIC_1257979122017004290)],
        &[(0b11010, &ENTRY_EOLIPILE_525577760526182208)],
        &[(0b11010, &ENTRY_EOLIPILES_15636106136610023127)],
        &[(0b11010, &ENTRY_EOLOTROPIC_10112988872948927516)],
        &[(0b11010, &ENTRY_EONIAN_16940933942216477131)],
        &[(0b11010, &ENTRY_EONISM_977800046438629687)],
        &[(0b11010, &ENTRY_EONISMS_13164743036852291403)],
    ],
    range: 3..=8,
};

static VARS_AEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEN_CHILDREN),
    value: None,
};

pub static VARS_AEN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("eid")],
    values: &[&[(0b11010, &ENTRY_ENEID_6327528208754564632)]],
    range: 3..=3,
};

static VARS_AEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEM_CHILDREN),
    value: None,
};

pub static VARS_AEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ule"),
        dictgen::InsensitiveStr::Ascii("uled"),
        dictgen::InsensitiveStr::Ascii("ules"),
        dictgen::InsensitiveStr::Ascii("uling"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EMULE_16137428121845795673)],
        &[(0b11010, &ENTRY_EMULED_9191420579655492028)],
        &[(0b11010, &ENTRY_EMULES_16077893382767699411)],
        &[(0b11010, &ENTRY_EMULING_10065143813695027214)],
    ],
    range: 3..=5,
};

static VARS_AEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEG_CHILDREN),
    value: None,
};

pub static VARS_AEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ilops"),
        dictgen::InsensitiveStr::Ascii("logue"),
        dictgen::InsensitiveStr::Ascii("ophony"),
        dictgen::InsensitiveStr::Ascii("ritude"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EGER_16805159729335837493)],
        &[(0b11010, &ENTRY_EGILOPS_2883782480068163532)],
        &[(0b11010, &ENTRY_EGLOGUE_4915760052338290285)],
        &[(0b11010, &ENTRY_EGOPHONY_7733383031638246128)],
        &[(0b11010, &ENTRY_EGRITUDE_5267691897554984547)],
    ],
    range: 2..=6,
};

static VARS_AEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEE_CHILDREN),
    value: None,
};

pub static VARS_AEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("tes")],
    values: &[&[(0b00001, &ENTRY_AEETES_13542365644841844170)]],
    range: 3..=3,
};

static VARS_AED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AED_CHILDREN),
    value: None,
};

pub static VARS_AED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icule"),
        dictgen::InsensitiveStr::Ascii("ility"),
        dictgen::InsensitiveStr::Ascii("on"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EDICULE_900504125909275639)],
        &[(0b11010, &ENTRY_EDILITY_15442566410145406587)],
        &[(0b00001, &ENTRY_AEDON_154112683300897898)],
    ],
    range: 2..=5,
};

static VARS_AEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEC_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_EC_8754556227184431879)]),
};

pub static VARS_AEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_AEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEA_CHILDREN),
    value: None,
};

pub static VARS_AEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("etes")],
    values: &[&[(0b11010, &ENTRY_AEETES_13542365644841844170)]],
    range: 4..=4,
};

static VARS_AD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AD_CHILDREN),
    value: None,
};

pub static VARS_AD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("ulterise"),
        dictgen::InsensitiveStr::Ascii("ulterised"),
        dictgen::InsensitiveStr::Ascii("ulterises"),
        dictgen::InsensitiveStr::Ascii("ulterising"),
        dictgen::InsensitiveStr::Ascii("ulterize"),
        dictgen::InsensitiveStr::Ascii("ulterized"),
        dictgen::InsensitiveStr::Ascii("ulterizes"),
        dictgen::InsensitiveStr::Ascii("ulterizing"),
        dictgen::InsensitiveStr::Ascii("venae"),
        dictgen::InsensitiveStr::Ascii("vene"),
        dictgen::InsensitiveStr::Ascii("verbialise"),
        dictgen::InsensitiveStr::Ascii("verbialised"),
        dictgen::InsensitiveStr::Ascii("verbialises"),
        dictgen::InsensitiveStr::Ascii("verbialising"),
        dictgen::InsensitiveStr::Ascii("verbialize"),
        dictgen::InsensitiveStr::Ascii("verbialized"),
        dictgen::InsensitiveStr::Ascii("verbializes"),
        dictgen::InsensitiveStr::Ascii("verbializing"),
        dictgen::InsensitiveStr::Ascii("vertisable"),
        dictgen::InsensitiveStr::Ascii("vertizable"),
        dictgen::InsensitiveStr::Ascii("vertize"),
        dictgen::InsensitiveStr::Ascii("vertized"),
        dictgen::InsensitiveStr::Ascii("vertizement"),
        dictgen::InsensitiveStr::Ascii("vertizements"),
        dictgen::InsensitiveStr::Ascii("vertizes"),
        dictgen::InsensitiveStr::Ascii("vertizing"),
        dictgen::InsensitiveStr::Ascii("z"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ADONIZE_9178378309873589364)],
        &[(0b10010, &ENTRY_ADONIZED_8994982395070697189)],
        &[(0b10010, &ENTRY_ADONIZES_5180294177954570043)],
        &[(0b10010, &ENTRY_ADONIZING_12335415346364396948)],
        &[(0b01001, &ENTRY_ADONIZE_9178378309873589364)],
        &[(0b01001, &ENTRY_ADONIZED_8994982395070697189)],
        &[(0b01001, &ENTRY_ADONIZES_5180294177954570043)],
        &[(0b01001, &ENTRY_ADONIZING_12335415346364396948)],
        &[(0b10010, &ENTRY_ADULTERIZE_73593365349204046)],
        &[(0b10010, &ENTRY_ADULTERIZED_9763204502317995248)],
        &[(0b10010, &ENTRY_ADULTERIZES_13280491913308940345)],
        &[(0b10010, &ENTRY_ADULTERIZING_6129631349753712424)],
        &[(0b01001, &ENTRY_ADULTERIZE_73593365349204046)],
        &[(0b01001, &ENTRY_ADULTERIZED_9763204502317995248)],
        &[(0b01001, &ENTRY_ADULTERIZES_13280491913308940345)],
        &[(0b01001, &ENTRY_ADULTERIZING_6129631349753712424)],
        &[(0b11010, &ENTRY_ADVENE_18287987560888224844)],
        &[(0b00001, &ENTRY_ADVENE_18287987560888224844)],
        &[(0b10010, &ENTRY_ADVERBIALIZE_17916331335305335337)],
        &[(0b10010, &ENTRY_ADVERBIALIZED_3830213448715883497)],
        &[(0b10010, &ENTRY_ADVERBIALIZES_5820829360340254947)],
        &[(0b10010, &ENTRY_ADVERBIALIZING_15432695712972446502)],
        &[(0b01001, &ENTRY_ADVERBIALIZE_17916331335305335337)],
        &[(0b01001, &ENTRY_ADVERBIALIZED_3830213448715883497)],
        &[(0b01001, &ENTRY_ADVERBIALIZES_5820829360340254947)],
        &[(0b01001, &ENTRY_ADVERBIALIZING_15432695712972446502)],
        &[(0b10010, &ENTRY_ADVERTIZABLE_16861669403088199904)],
        &[(0b01001, &ENTRY_ADVERTIZABLE_16861669403088199904)],
        &[(0b00001, &ENTRY_ADVERTISE_1587220052516245642)],
        &[(0b00001, &ENTRY_ADVERTISED_16571098524643298315)],
        &[(0b00001, &ENTRY_ADVERTISEMENT_617466274215936600)],
        &[(0b00001, &ENTRY_ADVERTISEMENTS_10822012965069036505)],
        &[(0b00001, &ENTRY_ADVERTISES_18397243032181025507)],
        &[(0b00001, &ENTRY_ADVERTISING_17484433287178545655)],
        &[(0b00001, &ENTRY_ADZE_730807116656886229)],
    ],
    range: 1..=12,
};

static VARS_AC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AC_CHILDREN),
    value: None,
};

static VARS_AC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ACA_NODE),
    None,
    Some(&VARS_ACC_NODE),
    None,
    Some(&VARS_ACE_NODE),
    None,
    None,
    Some(&VARS_ACH_NODE),
    Some(&VARS_ACI_NODE),
    None,
    Some(&VARS_ACK_NODE),
    None,
    Some(&VARS_ACM_NODE),
    None,
    Some(&VARS_ACO_NODE),
    None,
    None,
    Some(&VARS_ACR_NODE),
    None,
    Some(&VARS_ACT_NODE),
    Some(&VARS_ACU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_ACU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACU_CHILDREN),
    value: None,
};

pub static VARS_ACU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ACUESTHESIA_2551841406714567072)],
        &[(0b00001, &ENTRY_ACUESTHESIA_2551841406714567072)],
    ],
    range: 8..=9,
};

static VARS_ACT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACT_CHILDREN),
    value: None,
};

pub static VARS_ACT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ACTUALIZATION_4669686872691310817)],
        &[(0b10010, &ENTRY_ACTUALIZATIONS_15085416589313391950)],
        &[(0b10010, &ENTRY_ACTUALIZE_3735240609323878703)],
        &[(0b10010, &ENTRY_ACTUALIZED_16024949220724570012)],
        &[(0b10010, &ENTRY_ACTUALIZES_83603976374293051)],
        &[(0b10010, &ENTRY_ACTUALIZING_1158152971406011993)],
        &[(0b01001, &ENTRY_ACTUALIZATION_4669686872691310817)],
        &[(0b01001, &ENTRY_ACTUALIZATIONS_15085416589313391950)],
        &[(0b01001, &ENTRY_ACTUALIZE_3735240609323878703)],
        &[(0b01001, &ENTRY_ACTUALIZED_16024949220724570012)],
        &[(0b01001, &ENTRY_ACTUALIZES_83603976374293051)],
        &[(0b01001, &ENTRY_ACTUALIZING_1158152971406011993)],
    ],
    range: 6..=11,
};

static VARS_ACR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACR_CHILDREN),
    value: None,
};

pub static VARS_ACR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("oaesthesia"),
        dictgen::InsensitiveStr::Ascii("oanaesthesia"),
        dictgen::InsensitiveStr::Ascii("oanesthesia"),
        dictgen::InsensitiveStr::Ascii("oesthesia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ACER_10559783275550880926)],
        &[(0b11010, &ENTRY_ACROESTHESIA_9867964161600790636)],
        &[(0b11010, &ENTRY_ACROANESTHESIA_17682962239194259572)],
        &[(0b00001, &ENTRY_ACROANESTHESIA_17682962239194259572)],
        &[(0b00001, &ENTRY_ACROESTHESIA_9867964161600790636)],
    ],
    range: 1..=12,
};

static VARS_ACO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACO_CHILDREN),
    value: None,
};

pub static VARS_ACO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emetae"),
        dictgen::InsensitiveStr::Ascii("emetic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ACEMETAE_2145096676283883033)],
        &[(0b11010, &ENTRY_ACEMETIC_1512001350131721736)],
    ],
    range: 6..=6,
};

static VARS_ACM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACM_CHILDREN),
    value: None,
};

pub static VARS_ACM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ACMESTHESIA_2751090835262553738)],
        &[(0b00001, &ENTRY_ACMESTHESIA_2751090835262553738)],
    ],
    range: 8..=9,
};

static VARS_ACK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACK_CHILDREN),
    value: None,
};

pub static VARS_ACK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nowledgment"),
        dictgen::InsensitiveStr::Ascii("nowledgments"),
    ],
    values: &[
        &[(0b01001, &ENTRY_ACKNOWLEDGMENT_111837139751826554)],
        &[(0b01001, &ENTRY_ACKNOWLEDGMENTS_11271013032845791746)],
    ],
    range: 11..=12,
};

static VARS_ACI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACI_CHILDREN),
    value: None,
};

pub static VARS_ACI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("daemia"),
        dictgen::InsensitiveStr::Ascii("demia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ACIDEMIA_12451435266197798062)],
        &[(0b10001, &ENTRY_ACIDEMIA_12451435266197798062)],
    ],
    range: 5..=6,
};

static VARS_ACH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACH_CHILDREN),
    value: None,
};

pub static VARS_ACH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aenia"),
        dictgen::InsensitiveStr::Ascii("aenium"),
        dictgen::InsensitiveStr::Ascii("aeniums"),
        dictgen::InsensitiveStr::Ascii("aenocarp"),
        dictgen::InsensitiveStr::Ascii("enia"),
        dictgen::InsensitiveStr::Ascii("enium"),
        dictgen::InsensitiveStr::Ascii("eniums"),
        dictgen::InsensitiveStr::Ascii("enocarp"),
        dictgen::InsensitiveStr::Ascii("roiocythaemia"),
        dictgen::InsensitiveStr::Ascii("roiocythemia"),
        dictgen::InsensitiveStr::Ascii("romatisation"),
        dictgen::InsensitiveStr::Ascii("romatisations"),
        dictgen::InsensitiveStr::Ascii("romatise"),
        dictgen::InsensitiveStr::Ascii("romatised"),
        dictgen::InsensitiveStr::Ascii("romatises"),
        dictgen::InsensitiveStr::Ascii("romatising"),
        dictgen::InsensitiveStr::Ascii("romatization"),
        dictgen::InsensitiveStr::Ascii("romatizations"),
        dictgen::InsensitiveStr::Ascii("romatize"),
        dictgen::InsensitiveStr::Ascii("romatized"),
        dictgen::InsensitiveStr::Ascii("romatizes"),
        dictgen::InsensitiveStr::Ascii("romatizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ACHENIA_15454382729924397265)],
        &[(0b11010, &ENTRY_ACHENIUM_14796554973093514234)],
        &[(0b11010, &ENTRY_ACHENIUMS_5142378399040991537)],
        &[(0b11010, &ENTRY_ACHENOCARP_7169126193221725124)],
        &[(0b10001, &ENTRY_ACHENIA_15454382729924397265)],
        &[(0b10001, &ENTRY_ACHENIUM_14796554973093514234)],
        &[(0b10001, &ENTRY_ACHENIUMS_5142378399040991537)],
        &[(0b10001, &ENTRY_ACHENOCARP_7169126193221725124)],
        &[(0b11010, &ENTRY_ACHROIOCYTHEMIA_2971073665180782900)],
        &[(0b10001, &ENTRY_ACHROIOCYTHEMIA_2971073665180782900)],
        &[(0b10010, &ENTRY_ACHROMATIZATION_14364965481195842976)],
        &[(0b10010, &ENTRY_ACHROMATIZATIONS_1920892661060054972)],
        &[(0b10010, &ENTRY_ACHROMATIZE_13441575736049030515)],
        &[(0b10010, &ENTRY_ACHROMATIZED_11831854968043811514)],
        &[(0b10010, &ENTRY_ACHROMATIZES_11528246343369451539)],
        &[(0b10010, &ENTRY_ACHROMATIZING_5008978235002854282)],
        &[(0b01001, &ENTRY_ACHROMATIZATION_14364965481195842976)],
        &[(0b01001, &ENTRY_ACHROMATIZATIONS_1920892661060054972)],
        &[(0b01001, &ENTRY_ACHROMATIZE_13441575736049030515)],
        &[(0b01001, &ENTRY_ACHROMATIZED_11831854968043811514)],
        &[(0b01001, &ENTRY_ACHROMATIZES_11528246343369451539)],
        &[(0b01001, &ENTRY_ACHROMATIZING_5008978235002854282)],
    ],
    range: 4..=13,
};

static VARS_ACE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACE_CHILDREN),
    value: None,
};

pub static VARS_ACE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("metae"),
        dictgen::InsensitiveStr::Ascii("metic"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("tonaemia"),
        dictgen::InsensitiveStr::Ascii("tonaemic"),
        dictgen::InsensitiveStr::Ascii("tonemia"),
        dictgen::InsensitiveStr::Ascii("tonemic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_ACEMETAE_2145096676283883033)],
        &[(0b10001, &ENTRY_ACEMETIC_1512001350131721736)],
        &[(0b00001, &ENTRY_ACER_10559783275550880926)],
        &[(0b11010, &ENTRY_ACETONEMIA_7788618646225821950)],
        &[(0b11010, &ENTRY_ACETONEMIC_14601852950460693787)],
        &[(0b10001, &ENTRY_ACETONEMIA_7788618646225821950)],
        &[(0b10001, &ENTRY_ACETONEMIC_14601852950460693787)],
    ],
    range: 1..=8,
};

static VARS_ACC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACC_CHILDREN),
    value: None,
};

pub static VARS_ACC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("essorise"),
        dictgen::InsensitiveStr::Ascii("essorised"),
        dictgen::InsensitiveStr::Ascii("essorises"),
        dictgen::InsensitiveStr::Ascii("essorising"),
        dictgen::InsensitiveStr::Ascii("essorize"),
        dictgen::InsensitiveStr::Ascii("essorized"),
        dictgen::InsensitiveStr::Ascii("essorizes"),
        dictgen::InsensitiveStr::Ascii("essorizing"),
        dictgen::InsensitiveStr::Ascii("limatisable"),
        dictgen::InsensitiveStr::Ascii("limatisation"),
        dictgen::InsensitiveStr::Ascii("limatise"),
        dictgen::InsensitiveStr::Ascii("limatised"),
        dictgen::InsensitiveStr::Ascii("limatiser"),
        dictgen::InsensitiveStr::Ascii("limatisers"),
        dictgen::InsensitiveStr::Ascii("limatises"),
        dictgen::InsensitiveStr::Ascii("limatising"),
        dictgen::InsensitiveStr::Ascii("limatizable"),
        dictgen::InsensitiveStr::Ascii("limatization"),
        dictgen::InsensitiveStr::Ascii("limatize"),
        dictgen::InsensitiveStr::Ascii("limatized"),
        dictgen::InsensitiveStr::Ascii("limatizer"),
        dictgen::InsensitiveStr::Ascii("limatizers"),
        dictgen::InsensitiveStr::Ascii("limatizes"),
        dictgen::InsensitiveStr::Ascii("limatizing"),
        dictgen::InsensitiveStr::Ascii("orage"),
        dictgen::InsensitiveStr::Ascii("oraged"),
        dictgen::InsensitiveStr::Ascii("orages"),
        dictgen::InsensitiveStr::Ascii("oraging"),
        dictgen::InsensitiveStr::Ascii("ourage"),
        dictgen::InsensitiveStr::Ascii("ouraged"),
        dictgen::InsensitiveStr::Ascii("ourages"),
        dictgen::InsensitiveStr::Ascii("ouraging"),
        dictgen::InsensitiveStr::Ascii("outer"),
        dictgen::InsensitiveStr::Ascii("outered"),
        dictgen::InsensitiveStr::Ascii("outering"),
        dictgen::InsensitiveStr::Ascii("outerment"),
        dictgen::InsensitiveStr::Ascii("outerments"),
        dictgen::InsensitiveStr::Ascii("outers"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ACCESSORIZE_11617210258539552709)],
        &[(0b10010, &ENTRY_ACCESSORIZED_16819425426462683049)],
        &[(0b10010, &ENTRY_ACCESSORIZES_17250993592859046715)],
        &[(0b10010, &ENTRY_ACCESSORIZING_7867120879431421529)],
        &[(0b01001, &ENTRY_ACCESSORIZE_11617210258539552709)],
        &[(0b01001, &ENTRY_ACCESSORIZED_16819425426462683049)],
        &[(0b01001, &ENTRY_ACCESSORIZES_17250993592859046715)],
        &[(0b01001, &ENTRY_ACCESSORIZING_7867120879431421529)],
        &[(0b10010, &ENTRY_ACCLIMATIZABLE_10412930146797183971)],
        &[(0b10010, &ENTRY_ACCLIMATIZATION_17249634281186105692)],
        &[(0b10010, &ENTRY_ACCLIMATIZE_12341890419648119606)],
        &[(0b10010, &ENTRY_ACCLIMATIZED_18204400938003696366)],
        &[(0b10010, &ENTRY_ACCLIMATIZER_13670552975880707315)],
        &[(0b10010, &ENTRY_ACCLIMATIZERS_6788284312246842736)],
        &[(0b10010, &ENTRY_ACCLIMATIZES_11293424161032753847)],
        &[(0b10010, &ENTRY_ACCLIMATIZING_5604828123835799328)],
        &[(0b01001, &ENTRY_ACCLIMATIZABLE_10412930146797183971)],
        &[(0b01001, &ENTRY_ACCLIMATIZATION_17249634281186105692)],
        &[(0b01001, &ENTRY_ACCLIMATIZE_12341890419648119606)],
        &[(0b01001, &ENTRY_ACCLIMATIZED_18204400938003696366)],
        &[(0b01001, &ENTRY_ACCLIMATIZER_13670552975880707315)],
        &[(0b01001, &ENTRY_ACCLIMATIZERS_6788284312246842736)],
        &[(0b01001, &ENTRY_ACCLIMATIZES_11293424161032753847)],
        &[(0b01001, &ENTRY_ACCLIMATIZING_5604828123835799328)],
        &[(0b00001, &ENTRY_ACCORAGE_1619864749009219684)],
        &[(0b00001, &ENTRY_ACCORAGED_2739526311191792783)],
        &[(0b00001, &ENTRY_ACCORAGES_2283049235879645767)],
        &[(0b00001, &ENTRY_ACCORAGING_10971941715508219241)],
        &[(0b11010, &ENTRY_ACCORAGE_1619864749009219684)],
        &[(0b11010, &ENTRY_ACCORAGED_2739526311191792783)],
        &[(0b11010, &ENTRY_ACCORAGES_2283049235879645767)],
        &[(0b11010, &ENTRY_ACCORAGING_10971941715508219241)],
        &[(0b00001, &ENTRY_ACCOUTER_972199126233896575)],
        &[(0b00001, &ENTRY_ACCOUTERED_1879271502352972191)],
        &[(0b00001, &ENTRY_ACCOUTERING_4561163924549595645)],
        &[(0b00001, &ENTRY_ACCOUTERMENT_9608115872698025560)],
        &[(0b00001, &ENTRY_ACCOUTERMENTS_6877400773059867645)],
        &[(0b00001, &ENTRY_ACCOUTERS_13168290146957425825)],
    ],
    range: 5..=12,
};

static VARS_ACA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACA_CHILDREN),
    value: None,
};

pub static VARS_ACA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("demise"),
        dictgen::InsensitiveStr::Ascii("demised"),
        dictgen::InsensitiveStr::Ascii("demising"),
        dictgen::InsensitiveStr::Ascii("demize"),
        dictgen::InsensitiveStr::Ascii("demized"),
        dictgen::InsensitiveStr::Ascii("demizing"),
        dictgen::InsensitiveStr::Ascii("lephae"),
        dictgen::InsensitiveStr::Ascii("lephe"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ACADEMIZE_1653978011392822415)],
        &[(0b10010, &ENTRY_ACADEMIZED_12652361630960572647)],
        &[(0b10010, &ENTRY_ACADEMIZING_13791460485139002326)],
        &[(0b01001, &ENTRY_ACADEMIZE_1653978011392822415)],
        &[(0b01001, &ENTRY_ACADEMIZED_12652361630960572647)],
        &[(0b01001, &ENTRY_ACADEMIZING_13791460485139002326)],
        &[(0b11010, &ENTRY_ACALEPHE_5567416919940396758)],
        &[(0b00001, &ENTRY_ACALEPHE_5567416919940396758)],
    ],
    range: 5..=8,
};

static VARS_AB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AB_CHILDREN),
    value: None,
};

pub static VARS_AB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etter"),
        dictgen::InsensitiveStr::Ascii("etters"),
        dictgen::InsensitiveStr::Ascii("normalise"),
        dictgen::InsensitiveStr::Ascii("normalised"),
        dictgen::InsensitiveStr::Ascii("normalising"),
        dictgen::InsensitiveStr::Ascii("normalize"),
        dictgen::InsensitiveStr::Ascii("normalized"),
        dictgen::InsensitiveStr::Ascii("normalizing"),
        dictgen::InsensitiveStr::Ascii("olitionise"),
        dictgen::InsensitiveStr::Ascii("olitionised"),
        dictgen::InsensitiveStr::Ascii("olitionising"),
        dictgen::InsensitiveStr::Ascii("olitionize"),
        dictgen::InsensitiveStr::Ascii("olitionized"),
        dictgen::InsensitiveStr::Ascii("olitionizing"),
        dictgen::InsensitiveStr::Ascii("ridgement"),
        dictgen::InsensitiveStr::Ascii("ridgements"),
    ],
    values: &[
        &[(0b10011, &ENTRY_ABETTOR_17495586682475011085)],
        &[(0b10011, &ENTRY_ABETTORS_14954007126644140096)],
        &[(0b10010, &ENTRY_ABNORMALIZE_2138945550157605656)],
        &[(0b10010, &ENTRY_ABNORMALIZED_16425917454320151237)],
        &[(0b10010, &ENTRY_ABNORMALIZING_1668185405051794878)],
        &[(0b01001, &ENTRY_ABNORMALIZE_2138945550157605656)],
        &[(0b01001, &ENTRY_ABNORMALIZED_16425917454320151237)],
        &[(0b01001, &ENTRY_ABNORMALIZING_1668185405051794878)],
        &[(0b10010, &ENTRY_ABOLITIONIZE_6409647185352991216)],
        &[(0b10010, &ENTRY_ABOLITIONIZED_12202672614744661268)],
        &[(0b10010, &ENTRY_ABOLITIONIZING_7935837180291188971)],
        &[(0b01001, &ENTRY_ABOLITIONIZE_6409647185352991216)],
        &[(0b01001, &ENTRY_ABOLITIONIZED_12202672614744661268)],
        &[(0b01001, &ENTRY_ABOLITIONIZING_7935837180291188971)],
        &[(0b11010, &ENTRY_ABRIDGMENT_6696980223623735112)],
        &[(0b11010, &ENTRY_ABRIDGMENTS_1895547516404179990)],
    ],
    range: 5..=12,
};

static VARS_AA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AA_CHILDREN),
    value: None,
};

pub static VARS_AA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edon"),
        dictgen::InsensitiveStr::Ascii("erialness"),
        dictgen::InsensitiveStr::Ascii("erope"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AEDON_154112683300897898)],
        &[(0b11010, &ENTRY_AERIALNESS_4004993463972813657)],
        &[(0b11010, &ENTRY_AEROPE_1173414714172364053)],
    ],
    range: 4..=9,
};

pub const NO_INVALID: bool = true;

pub(crate) static ENTRY_ABETTORS_14954007126644140096: VariantsMap =
    [&["abettors"], &["abetters"], &["abettors"], &["abetters"]];

pub(crate) static ENTRY_ABETTOR_17495586682475011085: VariantsMap =
    [&["abettor"], &["abetter"], &["abettor"], &["abetter"]];

pub(crate) static ENTRY_ABNORMALIZED_16425917454320151237: VariantsMap = [
    &["abnormalized"],
    &["abnormalised"],
    &["abnormalized"],
    &["abnormalised"],
];

pub(crate) static ENTRY_ABNORMALIZE_2138945550157605656: VariantsMap = [
    &["abnormalize"],
    &["abnormalise"],
    &["abnormalize"],
    &["abnormalise"],
];

pub(crate) static ENTRY_ABNORMALIZING_1668185405051794878: VariantsMap = [
    &["abnormalizing"],
    &["abnormalising"],
    &["abnormalizing"],
    &["abnormalising"],
];

pub(crate) static ENTRY_ABOLITIONIZED_12202672614744661268: VariantsMap = [
    &["abolitionized"],
    &["abolitionised"],
    &["abolitionized"],
    &["abolitionised"],
];

pub(crate) static ENTRY_ABOLITIONIZE_6409647185352991216: VariantsMap = [
    &["abolitionize"],
    &["abolitionise"],
    &["abolitionize"],
    &["abolitionise"],
];

pub(crate) static ENTRY_ABOLITIONIZING_7935837180291188971: VariantsMap = [
    &["abolitionizing"],
    &["abolitionising"],
    &["abolitionizing"],
    &["abolitionising"],
];

pub(crate) static ENTRY_ABRIDGMENTS_1895547516404179990: VariantsMap = [
    &["abridgments"],
    &["abridgements"],
    &["abridgements"],
    &["abridgements"],
];

pub(crate) static ENTRY_ABRIDGMENT_6696980223623735112: VariantsMap = [
    &["abridgment"],
    &["abridgement"],
    &["abridgement"],
    &["abridgement"],
];

pub(crate) static ENTRY_ACADEMIZED_12652361630960572647: VariantsMap = [
    &["academized"],
    &["academised"],
    &["academized"],
    &["academised"],
];

pub(crate) static ENTRY_ACADEMIZE_1653978011392822415: VariantsMap = [
    &["academize"],
    &["academise"],
    &["academize"],
    &["academise"],
];

pub(crate) static ENTRY_ACADEMIZING_13791460485139002326: VariantsMap = [
    &["academizing"],
    &["academising"],
    &["academizing"],
    &["academising"],
];

pub(crate) static ENTRY_ACALEPHE_5567416919940396758: VariantsMap = [
    &["acalephe"],
    &["acalephae"],
    &["acalephae"],
    &["acalephae"],
];

pub(crate) static ENTRY_ACCESSORIZED_16819425426462683049: VariantsMap = [
    &["accessorized"],
    &["accessorised"],
    &["accessorized"],
    &["accessorised"],
];

pub(crate) static ENTRY_ACCESSORIZES_17250993592859046715: VariantsMap = [
    &["accessorizes"],
    &["accessorises"],
    &["accessorizes"],
    &["accessorises"],
];

pub(crate) static ENTRY_ACCESSORIZE_11617210258539552709: VariantsMap = [
    &["accessorize"],
    &["accessorise"],
    &["accessorize"],
    &["accessorise"],
];

pub(crate) static ENTRY_ACCESSORIZING_7867120879431421529: VariantsMap = [
    &["accessorizing"],
    &["accessorising"],
    &["accessorizing"],
    &["accessorising"],
];

pub(crate) static ENTRY_ACCLIMATIZABLE_10412930146797183971: VariantsMap = [
    &["acclimatizable"],
    &["acclimatisable"],
    &["acclimatizable"],
    &["acclimatisable"],
];

pub(crate) static ENTRY_ACCLIMATIZATION_17249634281186105692: VariantsMap = [
    &["acclimatization"],
    &["acclimatisation"],
    &["acclimatization"],
    &["acclimatisation"],
];

pub(crate) static ENTRY_ACCLIMATIZED_18204400938003696366: VariantsMap = [
    &["acclimatized"],
    &["acclimatised"],
    &["acclimatized"],
    &["acclimatised"],
];

pub(crate) static ENTRY_ACCLIMATIZERS_6788284312246842736: VariantsMap = [
    &["acclimatizers"],
    &["acclimatisers"],
    &["acclimatizers"],
    &["acclimatisers"],
];

pub(crate) static ENTRY_ACCLIMATIZER_13670552975880707315: VariantsMap = [
    &["acclimatizer"],
    &["acclimatiser"],
    &["acclimatizer"],
    &["acclimatiser"],
];

pub(crate) static ENTRY_ACCLIMATIZES_11293424161032753847: VariantsMap = [
    &["acclimatizes"],
    &["acclimatises"],
    &["acclimatizes"],
    &["acclimatises"],
];

pub(crate) static ENTRY_ACCLIMATIZE_12341890419648119606: VariantsMap = [
    &["acclimatize"],
    &["acclimatise"],
    &["acclimatize"],
    &["acclimatise"],
];

pub(crate) static ENTRY_ACCLIMATIZING_5604828123835799328: VariantsMap = [
    &["acclimatizing"],
    &["acclimatising"],
    &["acclimatizing"],
    &["acclimatising"],
];

pub(crate) static ENTRY_ACCORAGED_2739526311191792783: VariantsMap = [
    &["accoraged"],
    &["accouraged"],
    &["accouraged"],
    &["accouraged"],
];

pub(crate) static ENTRY_ACCORAGES_2283049235879645767: VariantsMap = [
    &["accorages"],
    &["accourages"],
    &["accourages"],
    &["accourages"],
];

pub(crate) static ENTRY_ACCORAGE_1619864749009219684: VariantsMap = [
    &["accorage"],
    &["accourage"],
    &["accourage"],
    &["accourage"],
];

pub(crate) static ENTRY_ACCORAGING_10971941715508219241: VariantsMap = [
    &["accoraging"],
    &["accouraging"],
    &["accouraging"],
    &["accouraging"],
];

pub(crate) static ENTRY_ACCOUTERED_1879271502352972191: VariantsMap = [
    &["accoutered"],
    &["accoutred"],
    &["accoutred"],
    &["accoutred"],
];

pub(crate) static ENTRY_ACCOUTERING_4561163924549595645: VariantsMap = [
    &["accoutering"],
    &["accoutring"],
    &["accoutring"],
    &["accoutring"],
];

pub(crate) static ENTRY_ACCOUTERMENTS_6877400773059867645: VariantsMap = [
    &["accouterments"],
    &["accoutrements"],
    &["accoutrements"],
    &["accoutrements"],
];

pub(crate) static ENTRY_ACCOUTERMENT_9608115872698025560: VariantsMap = [
    &["accouterment"],
    &["accoutrement"],
    &["accoutrement"],
    &["accoutrement"],
];

pub(crate) static ENTRY_ACCOUTERS_13168290146957425825: VariantsMap = [
    &["accouters"],
    &["accoutres"],
    &["accoutres"],
    &["accoutres"],
];

pub(crate) static ENTRY_ACCOUTER_972199126233896575: VariantsMap =
    [&["accouter"], &["accoutre"], &["accoutre"], &["accoutre"]];

pub(crate) static ENTRY_ACEMETAE_2145096676283883033: VariantsMap = [
    &["acemetae"],
    &["acoemetae"],
    &["acoemetae"],
    &["acoemetae"],
];

pub(crate) static ENTRY_ACEMETIC_1512001350131721736: VariantsMap = [
    &["acemetic"],
    &["acoemetic"],
    &["acoemetic"],
    &["acoemetic"],
];

pub(crate) static ENTRY_ACER_10559783275550880926: VariantsMap =
    [&["acer"], &["acre"], &["acre"], &["acre"]];

pub(crate) static ENTRY_ACETONEMIA_7788618646225821950: VariantsMap = [
    &["acetonemia"],
    &["acetonaemia"],
    &["acetonaemia"],
    &["acetonaemia"],
];

pub(crate) static ENTRY_ACETONEMIC_14601852950460693787: VariantsMap = [
    &["acetonemic"],
    &["acetonaemic"],
    &["acetonaemic"],
    &["acetonaemic"],
];

pub(crate) static ENTRY_ACHENIA_15454382729924397265: VariantsMap =
    [&["achenia"], &["achaenia"], &["achaenia"], &["achaenia"]];

pub(crate) static ENTRY_ACHENIUMS_5142378399040991537: VariantsMap = [
    &["acheniums"],
    &["achaeniums"],
    &["achaeniums"],
    &["achaeniums"],
];

pub(crate) static ENTRY_ACHENIUM_14796554973093514234: VariantsMap = [
    &["achenium"],
    &["achaenium"],
    &["achaenium"],
    &["achaenium"],
];

pub(crate) static ENTRY_ACHENOCARP_7169126193221725124: VariantsMap = [
    &["achenocarp"],
    &["achaenocarp"],
    &["achaenocarp"],
    &["achaenocarp"],
];

pub(crate) static ENTRY_ACHROIOCYTHEMIA_2971073665180782900: VariantsMap = [
    &["achroiocythemia"],
    &["achroiocythaemia"],
    &["achroiocythaemia"],
    &["achroiocythaemia"],
];

pub(crate) static ENTRY_ACHROMATIZATIONS_1920892661060054972: VariantsMap = [
    &["achromatizations"],
    &["achromatisations"],
    &["achromatizations"],
    &["achromatisations"],
];

pub(crate) static ENTRY_ACHROMATIZATION_14364965481195842976: VariantsMap = [
    &["achromatization"],
    &["achromatisation"],
    &["achromatization"],
    &["achromatisation"],
];

pub(crate) static ENTRY_ACHROMATIZED_11831854968043811514: VariantsMap = [
    &["achromatized"],
    &["achromatised"],
    &["achromatized"],
    &["achromatised"],
];

pub(crate) static ENTRY_ACHROMATIZES_11528246343369451539: VariantsMap = [
    &["achromatizes"],
    &["achromatises"],
    &["achromatizes"],
    &["achromatises"],
];

pub(crate) static ENTRY_ACHROMATIZE_13441575736049030515: VariantsMap = [
    &["achromatize"],
    &["achromatise"],
    &["achromatize"],
    &["achromatise"],
];

pub(crate) static ENTRY_ACHROMATIZING_5008978235002854282: VariantsMap = [
    &["achromatizing"],
    &["achromatising"],
    &["achromatizing"],
    &["achromatising"],
];

pub(crate) static ENTRY_ACIDEMIA_12451435266197798062: VariantsMap = [
    &["acidemia"],
    &["acidaemia"],
    &["acidaemia"],
    &["acidaemia"],
];

pub(crate) static ENTRY_ACKNOWLEDGMENTS_11271013032845791746: VariantsMap = [
    &["acknowledgments"],
    &["acknowledgements"],
    &["acknowledgements"],
    &["acknowledgements"],
];

pub(crate) static ENTRY_ACKNOWLEDGMENT_111837139751826554: VariantsMap = [
    &["acknowledgment"],
    &["acknowledgement"],
    &["acknowledgement"],
    &["acknowledgement"],
];

pub(crate) static ENTRY_ACMESTHESIA_2751090835262553738: VariantsMap = [
    &["acmesthesia"],
    &["acmaesthesia"],
    &["acmaesthesia"],
    &["acmaesthesia"],
];

pub(crate) static ENTRY_ACROANESTHESIA_17682962239194259572: VariantsMap = [
    &["acroanesthesia"],
    &["acroanaesthesia"],
    &["acroanaesthesia"],
    &["acroanaesthesia"],
];

pub(crate) static ENTRY_ACROESTHESIA_9867964161600790636: VariantsMap = [
    &["acroesthesia"],
    &["acroaesthesia"],
    &["acroaesthesia"],
    &["acroaesthesia"],
];

pub(crate) static ENTRY_ACTUALIZATIONS_15085416589313391950: VariantsMap = [
    &["actualizations"],
    &["actualisations"],
    &["actualizations"],
    &["actualisations"],
];

pub(crate) static ENTRY_ACTUALIZATION_4669686872691310817: VariantsMap = [
    &["actualization"],
    &["actualisation"],
    &["actualization"],
    &["actualisation"],
];

pub(crate) static ENTRY_ACTUALIZED_16024949220724570012: VariantsMap = [
    &["actualized"],
    &["actualised"],
    &["actualized"],
    &["actualised"],
];

pub(crate) static ENTRY_ACTUALIZES_83603976374293051: VariantsMap = [
    &["actualizes"],
    &["actualises"],
    &["actualizes"],
    &["actualises"],
];

pub(crate) static ENTRY_ACTUALIZE_3735240609323878703: VariantsMap = [
    &["actualize"],
    &["actualise"],
    &["actualize"],
    &["actualise"],
];

pub(crate) static ENTRY_ACTUALIZING_1158152971406011993: VariantsMap = [
    &["actualizing"],
    &["actualising"],
    &["actualizing"],
    &["actualising"],
];

pub(crate) static ENTRY_ACUESTHESIA_2551841406714567072: VariantsMap = [
    &["acuesthesia"],
    &["acuaesthesia"],
    &["acuaesthesia"],
    &["acuaesthesia"],
];

pub(crate) static ENTRY_ADONIZED_8994982395070697189: VariantsMap =
    [&["adonized"], &["adonised"], &["adonized"], &["adonised"]];

pub(crate) static ENTRY_ADONIZES_5180294177954570043: VariantsMap =
    [&["adonizes"], &["adonises"], &["adonizes"], &["adonises"]];

pub(crate) static ENTRY_ADONIZE_9178378309873589364: VariantsMap =
    [&["adonize"], &["adonise"], &["adonize"], &["adonise"]];

pub(crate) static ENTRY_ADONIZING_12335415346364396948: VariantsMap = [
    &["adonizing"],
    &["adonising"],
    &["adonizing"],
    &["adonising"],
];

pub(crate) static ENTRY_ADULTERIZED_9763204502317995248: VariantsMap = [
    &["adulterized"],
    &["adulterised"],
    &["adulterized"],
    &["adulterised"],
];

pub(crate) static ENTRY_ADULTERIZES_13280491913308940345: VariantsMap = [
    &["adulterizes"],
    &["adulterises"],
    &["adulterizes"],
    &["adulterises"],
];

pub(crate) static ENTRY_ADULTERIZE_73593365349204046: VariantsMap = [
    &["adulterize"],
    &["adulterise"],
    &["adulterize"],
    &["adulterise"],
];

pub(crate) static ENTRY_ADULTERIZING_6129631349753712424: VariantsMap = [
    &["adulterizing"],
    &["adulterising"],
    &["adulterizing"],
    &["adulterising"],
];

pub(crate) static ENTRY_ADVENE_18287987560888224844: VariantsMap =
    [&["advene"], &["advenae"], &["advenae"], &["advenae"]];

pub(crate) static ENTRY_ADVERBIALIZED_3830213448715883497: VariantsMap = [
    &["adverbialized"],
    &["adverbialised"],
    &["adverbialized"],
    &["adverbialised"],
];

pub(crate) static ENTRY_ADVERBIALIZES_5820829360340254947: VariantsMap = [
    &["adverbializes"],
    &["adverbialises"],
    &["adverbializes"],
    &["adverbialises"],
];

pub(crate) static ENTRY_ADVERBIALIZE_17916331335305335337: VariantsMap = [
    &["adverbialize"],
    &["adverbialise"],
    &["adverbialize"],
    &["adverbialise"],
];

pub(crate) static ENTRY_ADVERBIALIZING_15432695712972446502: VariantsMap = [
    &["adverbializing"],
    &["adverbialising"],
    &["adverbializing"],
    &["adverbialising"],
];

pub(crate) static ENTRY_ADVERTISED_16571098524643298315: VariantsMap = [
    &["advertised"],
    &["advertised"],
    &["advertised"],
    &["advertised"],
];

pub(crate) static ENTRY_ADVERTISEMENTS_10822012965069036505: VariantsMap = [
    &["advertisements"],
    &["advertisements"],
    &["advertisements"],
    &["advertisements"],
];

pub(crate) static ENTRY_ADVERTISEMENT_617466274215936600: VariantsMap = [
    &["advertisement"],
    &["advertisement"],
    &["advertisement"],
    &["advertisement"],
];

pub(crate) static ENTRY_ADVERTISES_18397243032181025507: VariantsMap = [
    &["advertises"],
    &["advertises"],
    &["advertises"],
    &["advertises"],
];

pub(crate) static ENTRY_ADVERTISE_1587220052516245642: VariantsMap = [
    &["advertise"],
    &["advertise"],
    &["advertise"],
    &["advertise"],
];

pub(crate) static ENTRY_ADVERTISING_17484433287178545655: VariantsMap = [
    &["advertising"],
    &["advertising"],
    &["advertising"],
    &["advertising"],
];

pub(crate) static ENTRY_ADVERTIZABLE_16861669403088199904: VariantsMap = [
    &["advertizable"],
    &["advertisable"],
    &["advertizable"],
    &["advertisable"],
];

pub(crate) static ENTRY_ADZE_730807116656886229: VariantsMap =
    [&["adze"], &["adze"], &["adze"], &["adze"]];

pub(crate) static ENTRY_AEDILES_9510493690992644415: VariantsMap =
    [&["aediles"], &["aediles"], &["aediles"], &["aediles"]];

pub(crate) static ENTRY_AEDILE_15038900667105730092: VariantsMap =
    [&["aedile"], &["aedile"], &["aedile"], &["aedile"]];

pub(crate) static ENTRY_AEDON_154112683300897898: VariantsMap =
    [&["aedon"], &["aaedon"], &["aaedon"], &["aaedon"]];

pub(crate) static ENTRY_AEETES_13542365644841844170: VariantsMap =
    [&["aeetes"], &["aeaetes"], &["aeaetes"], &["aeaetes"]];

pub(crate) static ENTRY_AEGISES_11533648482988821845: VariantsMap =
    [&["aegises"], &["aegises"], &["aegises"], &["aegises"]];

pub(crate) static ENTRY_AEGIS_8763057825902985675: VariantsMap =
    [&["aegis"], &["aegis"], &["aegis"], &["aegis"]];

pub(crate) static ENTRY_AERIALNESS_4004993463972813657: VariantsMap = [
    &["aerialness"],
    &["aaerialness"],
    &["aaerialness"],
    &["aaerialness"],
];

pub(crate) static ENTRY_AERIC_10020180033075484870: VariantsMap =
    [&["aeric"], &["areic"], &["areic"], &["areic"]];

pub(crate) static ENTRY_AERIE_17068047033087189954: VariantsMap =
    [&["aerie"], &["aerie"], &["aerie"], &["aerie"]];

pub(crate) static ENTRY_AEROGRAPHER_85789760672961791: VariantsMap = [
    &["aerographer"],
    &["areographer"],
    &["areographer"],
    &["areographer"],
];

pub(crate) static ENTRY_AEROGRAPHICAL_12793888458146758836: VariantsMap = [
    &["aerographical"],
    &["areographical"],
    &["areographical"],
    &["areographical"],
];

pub(crate) static ENTRY_AEROGRAPHIC_5707019479991978033: VariantsMap = [
    &["aerographic"],
    &["areographic"],
    &["areographic"],
    &["areographic"],
];

pub(crate) static ENTRY_AEROGRAPHIES_9522044483381698756: VariantsMap = [
    &["aerographies"],
    &["areographies"],
    &["areographies"],
    &["areographies"],
];

pub(crate) static ENTRY_AEROGRAPHY_9279141637627756120: VariantsMap = [
    &["aerography"],
    &["areography"],
    &["areography"],
    &["areography"],
];

pub(crate) static ENTRY_AEROLOGICAL_7520248570186497308: VariantsMap = [
    &["aerological"],
    &["areological"],
    &["areological"],
    &["areological"],
];

pub(crate) static ENTRY_AEROLOGIC_12163962530263481700: VariantsMap = [
    &["aerologic"],
    &["areologic"],
    &["areologic"],
    &["areologic"],
];

pub(crate) static ENTRY_AEROLOGIES_4052658077915194200: VariantsMap = [
    &["aerologies"],
    &["areologies"],
    &["areologies"],
    &["areologies"],
];

pub(crate) static ENTRY_AEROLOGIST_233176875293717737: VariantsMap = [
    &["aerologist"],
    &["areologist"],
    &["areologist"],
    &["areologist"],
];

pub(crate) static ENTRY_AEROLOGY_3025685712114846212: VariantsMap =
    [&["aerology"], &["areology"], &["areology"], &["areology"]];

pub(crate) static ENTRY_AEROMETERS_10976694975875082042: VariantsMap = [
    &["aerometers"],
    &["areometers"],
    &["areometers"],
    &["areometers"],
];

pub(crate) static ENTRY_AEROMETER_17405185222225302259: VariantsMap = [
    &["aerometer"],
    &["areometer"],
    &["areometer"],
    &["areometer"],
];

pub(crate) static ENTRY_AEROMETRIC_357071446782082902: VariantsMap = [
    &["aerometric"],
    &["areometric"],
    &["areometric"],
    &["areometric"],
];

pub(crate) static ENTRY_AEROPE_1173414714172364053: VariantsMap =
    [&["aerope"], &["aaerope"], &["aaerope"], &["aaerope"]];

pub(crate) static ENTRY_AESTHETES_15012821507993100258: VariantsMap = [
    &["aesthetes"],
    &["aesthetes"],
    &["aesthetes"],
    &["aesthetes"],
];

pub(crate) static ENTRY_AESTHETE_6475321551135991601: VariantsMap =
    [&["aesthete"], &["aesthete"], &["aesthete"], &["aesthete"]];

pub(crate) static ENTRY_AESTHETICALLY_4393362297255043635: VariantsMap = [
    &["aesthetically"],
    &["aesthetically"],
    &["aesthetically"],
    &["aesthetically"],
];

pub(crate) static ENTRY_AESTHETICIZED_14357851050724930852: VariantsMap = [
    &["aestheticized"],
    &["aestheticised"],
    &["aestheticized"],
    &["aestheticised"],
];

pub(crate) static ENTRY_AESTHETICIZES_14449755828314805813: VariantsMap = [
    &["aestheticizes"],
    &["aestheticises"],
    &["aestheticizes"],
    &["aestheticises"],
];

pub(crate) static ENTRY_AESTHETICIZE_9439384680082563511: VariantsMap = [
    &["aestheticize"],
    &["aestheticise"],
    &["aestheticize"],
    &["aestheticise"],
];

pub(crate) static ENTRY_AESTHETICIZING_3795115064284345074: VariantsMap = [
    &["aestheticizing"],
    &["aestheticising"],
    &["aestheticizing"],
    &["aestheticising"],
];

pub(crate) static ENTRY_AESTHETICS_3207114874897219410: VariantsMap = [
    &["aesthetics"],
    &["aesthetics"],
    &["aesthetics"],
    &["aesthetics"],
];

pub(crate) static ENTRY_AESTHETIC_5817909166486372441: VariantsMap = [
    &["aesthetic"],
    &["aesthetic"],
    &["aesthetic"],
    &["aesthetic"],
];

pub(crate) static ENTRY_AFFEER_6009483293773969784: VariantsMap =
    [&["affeer"], &["affere"], &["affere"], &["affere"]];

pub(crate) static ENTRY_AFRICANIZATIONS_17695007617535110892: VariantsMap = [
    &["africanizations"],
    &["africanisations"],
    &["africanizations"],
    &["africanisations"],
];

pub(crate) static ENTRY_AFRICANIZATION_5413444630763314543: VariantsMap = [
    &["africanization"],
    &["africanisation"],
    &["africanization"],
    &["africanisation"],
];

pub(crate) static ENTRY_AFRICANIZED_8120286406579238289: VariantsMap = [
    &["africanized"],
    &["africanised"],
    &["africanized"],
    &["africanised"],
];

pub(crate) static ENTRY_AFRICANIZES_422967171139772976: VariantsMap = [
    &["africanizes"],
    &["africanises"],
    &["africanizes"],
    &["africanises"],
];

pub(crate) static ENTRY_AFRICANIZE_8899009377488121155: VariantsMap = [
    &["africanize"],
    &["africanise"],
    &["africanize"],
    &["africanise"],
];

pub(crate) static ENTRY_AFRICANIZING_5922056489408751942: VariantsMap = [
    &["africanizing"],
    &["africanising"],
    &["africanizing"],
    &["africanising"],
];

pub(crate) static ENTRY_AFRIKANERIZATION_3589787726485032622: VariantsMap = [
    &["afrikanerization"],
    &["afrikanerisation"],
    &["afrikanerization"],
    &["afrikanerisation"],
];

pub(crate) static ENTRY_AFRIKANERIZED_16796393449369554865: VariantsMap = [
    &["afrikanerized"],
    &["afrikanerised"],
    &["afrikanerized"],
    &["afrikanerised"],
];

pub(crate) static ENTRY_AFRIKANERIZES_15139135300181540690: VariantsMap = [
    &["afrikanerizes"],
    &["afrikanerises"],
    &["afrikanerizes"],
    &["afrikanerises"],
];

pub(crate) static ENTRY_AFRIKANERIZE_3316018485342870963: VariantsMap = [
    &["afrikanerize"],
    &["afrikanerise"],
    &["afrikanerize"],
    &["afrikanerise"],
];

pub(crate) static ENTRY_AFRIKANERIZING_3981551782275451309: VariantsMap = [
    &["afrikanerizing"],
    &["afrikanerising"],
    &["afrikanerizing"],
    &["afrikanerising"],
];

pub(crate) static ENTRY_AFTERWARDS_5679799743915530462: VariantsMap = [
    &["afterward", "afterwards"],
    &["afterwards"],
    &["afterwards"],
    &["afterwards"],
];

pub(crate) static ENTRY_AGATHODEMON_18413031701031888707: VariantsMap = [
    &["agathodemon"],
    &["agathodaemon"],
    &["agathodaemon"],
    &["agathodaemon"],
];

pub(crate) static ENTRY_AGATIZES_5599637212136222765: VariantsMap =
    [&["agatizes"], &["agatises"], &["agatizes"], &["agatises"]];

pub(crate) static ENTRY_AGATIZE_10108832763949504643: VariantsMap =
    [&["agatize"], &["agatise"], &["agatize"], &["agatise"]];

pub(crate) static ENTRY_AGENIZE_1864369248982715174: VariantsMap =
    [&["agenize"], &["agenise"], &["agenize"], &["agenise"]];

pub(crate) static ENTRY_AGER_9193302169289361702: VariantsMap =
    [&["ager"], &["agre"], &["agre"], &["agre"]];

pub(crate) static ENTRY_AGGRANDIZABLES_7273443253306031000: VariantsMap = [
    &["aggrandizables"],
    &["aggrandisables"],
    &["aggrandizables"],
    &["aggrandisables"],
];

pub(crate) static ENTRY_AGGRANDIZABLE_1037184785288412738: VariantsMap = [
    &["aggrandizable"],
    &["aggrandisable"],
    &["aggrandizable"],
    &["aggrandisable"],
];

pub(crate) static ENTRY_AGGRANDIZATION_5817546113677374440: VariantsMap = [
    &["aggrandization"],
    &["aggrandisation"],
    &["aggrandization"],
    &["aggrandisation"],
];

pub(crate) static ENTRY_AGGRANDIZED_5678047642823184520: VariantsMap = [
    &["aggrandized"],
    &["aggrandised"],
    &["aggrandized"],
    &["aggrandised"],
];

pub(crate) static ENTRY_AGGRANDIZEMENTS_13322482535421162803: VariantsMap = [
    &["aggrandizements"],
    &["aggrandisements"],
    &["aggrandizements"],
    &["aggrandisements"],
];

pub(crate) static ENTRY_AGGRANDIZEMENT_5112363745808153547: VariantsMap = [
    &["aggrandizement"],
    &["aggrandisement"],
    &["aggrandizement"],
    &["aggrandisement"],
];

pub(crate) static ENTRY_AGGRANDIZERS_15651589293150719753: VariantsMap = [
    &["aggrandizers"],
    &["aggrandisers"],
    &["aggrandizers"],
    &["aggrandisers"],
];

pub(crate) static ENTRY_AGGRANDIZER_14976020900821693201: VariantsMap = [
    &["aggrandizer"],
    &["aggrandiser"],
    &["aggrandizer"],
    &["aggrandiser"],
];

pub(crate) static ENTRY_AGGRANDIZES_12993795888011857693: VariantsMap = [
    &["aggrandizes"],
    &["aggrandises"],
    &["aggrandizes"],
    &["aggrandises"],
];

pub(crate) static ENTRY_AGGRANDIZE_14928776110274947016: VariantsMap = [
    &["aggrandize"],
    &["aggrandise"],
    &["aggrandize"],
    &["aggrandise"],
];

pub(crate) static ENTRY_AGGRANDIZING_10289964617012803392: VariantsMap = [
    &["aggrandizing"],
    &["aggrandising"],
    &["aggrandizing"],
    &["aggrandising"],
];

pub(crate) static ENTRY_AGNIZED_3602067665820241778: VariantsMap =
    [&["agnized"], &["agnised"], &["agnized"], &["agnised"]];

pub(crate) static ENTRY_AGNIZES_7008306488691527610: VariantsMap =
    [&["agnizes"], &["agnises"], &["agnizes"], &["agnises"]];

pub(crate) static ENTRY_AGNIZE_7414310572549278419: VariantsMap =
    [&["agnize"], &["agnise"], &["agnize"], &["agnise"]];

pub(crate) static ENTRY_AGNIZING_10354208092344487767: VariantsMap =
    [&["agnizing"], &["agnising"], &["agnizing"], &["agnising"]];

pub(crate) static ENTRY_AGONIZEDLIES_7059700506878805363: VariantsMap = [
    &["agonizedlies"],
    &["agonisedlies"],
    &["agonizedlies"],
    &["agonisedlies"],
];

pub(crate) static ENTRY_AGONIZEDLY_4819060413618915382: VariantsMap = [
    &["agonizedly"],
    &["agonisedly"],
    &["agonizedly"],
    &["agonisedly"],
];

pub(crate) static ENTRY_AGONIZED_17678244103143625810: VariantsMap =
    [&["agonized"], &["agonised"], &["agonized"], &["agonised"]];

pub(crate) static ENTRY_AGONIZERS_16633588395922410958: VariantsMap = [
    &["agonizers"],
    &["agonisers"],
    &["agonizers"],
    &["agonisers"],
];

pub(crate) static ENTRY_AGONIZER_10528504234638853717: VariantsMap =
    [&["agonizer"], &["agoniser"], &["agonizer"], &["agoniser"]];

pub(crate) static ENTRY_AGONIZES_14844009888333237557: VariantsMap =
    [&["agonizes"], &["agonises"], &["agonizes"], &["agonises"]];

pub(crate) static ENTRY_AGONIZE_14877090130667543233: VariantsMap =
    [&["agonize"], &["agonise"], &["agonize"], &["agonise"]];

pub(crate) static ENTRY_AGONIZINGLIER_10296833915180893028: VariantsMap = [
    &["agonizinglier"],
    &["agonisinglier"],
    &["agonizinglier"],
    &["agonisinglier"],
];

pub(crate) static ENTRY_AGONIZINGLIEST_3823537194548772440: VariantsMap = [
    &["agonizingliest"],
    &["agonisingliest"],
    &["agonizingliest"],
    &["agonisingliest"],
];

pub(crate) static ENTRY_AGONIZINGLY_5283227355985477567: VariantsMap = [
    &["agonizingly"],
    &["agonisingly"],
    &["agonizingly"],
    &["agonisingly"],
];

pub(crate) static ENTRY_AGONIZING_14014895105394090708: VariantsMap = [
    &["agonizing"],
    &["agonising"],
    &["agonizing"],
    &["agonising"],
];

pub(crate) static ENTRY_AGRARIANIZES_15839932416088518712: VariantsMap = [
    &["agrarianizes"],
    &["agrarianises"],
    &["agrarianizes"],
    &["agrarianises"],
];

pub(crate) static ENTRY_AGRARIANIZE_1743127394833633445: VariantsMap = [
    &["agrarianize"],
    &["agrarianise"],
    &["agrarianize"],
    &["agrarianise"],
];

pub(crate) static ENTRY_AGRIZED_589451309246337777: VariantsMap =
    [&["agrized"], &["agrised"], &["agrized"], &["agrised"]];

pub(crate) static ENTRY_AGRIZES_3555606021924104510: VariantsMap =
    [&["agrizes"], &["agrises"], &["agrizes"], &["agrises"]];

pub(crate) static ENTRY_AGRIZE_10021775222091159751: VariantsMap =
    [&["agrize"], &["agrise"], &["agrize"], &["agrise"]];

pub(crate) static ENTRY_AGRIZING_13950999867910650133: VariantsMap =
    [&["agrizing"], &["agrising"], &["agrizing"], &["agrising"]];

pub(crate) static ENTRY_AGUIZED_8691849110214980652: VariantsMap =
    [&["aguized"], &["aguised"], &["aguized"], &["aguised"]];

pub(crate) static ENTRY_AGUIZES_9850955252997743907: VariantsMap =
    [&["aguizes"], &["aguises"], &["aguizes"], &["aguises"]];

pub(crate) static ENTRY_AGUIZE_2128537953908418385: VariantsMap =
    [&["aguize"], &["aguise"], &["aguize"], &["aguise"]];

pub(crate) static ENTRY_AGUIZING_10322941876567610033: VariantsMap =
    [&["aguizing"], &["aguising"], &["aguizing"], &["aguising"]];

pub(crate) static ENTRY_AIGER_5594412989495342326: VariantsMap =
    [&["aiger"], &["aigre"], &["aigre"], &["aigre"]];

pub(crate) static ENTRY_AIRFOILS_16600511204738890239: VariantsMap =
    [&["airfoils"], &["aerofoils"], &["airfoils"], &["aerofoils"]];

pub(crate) static ENTRY_AIRFOIL_8793212550719857477: VariantsMap =
    [&["airfoil"], &["aerofoil"], &["airfoil"], &["aerofoil"]];

pub(crate) static ENTRY_AIRGEL_13006938656131464461: VariantsMap =
    [&["airgel"], &["aerogel"], &["aerogel"], &["aerogel"]];

pub(crate) static ENTRY_AIRPLANES_7495463879091464018: VariantsMap = [
    &["airplanes"],
    &["aeroplanes"],
    &["airplanes"],
    &["aeroplanes"],
];

pub(crate) static ENTRY_AIRPLANE_9809064680775935608: VariantsMap =
    [&["airplane"], &["aeroplane"], &["airplane"], &["aeroplane"]];

pub(crate) static ENTRY_AKER_159315244585453376: VariantsMap =
    [&["aker"], &["akre"], &["akre"], &["akre"]];

pub(crate) static ENTRY_AKTISTETE_2376014706515547798: VariantsMap = [
    &["aktistete"],
    &["aktistetae"],
    &["aktistetae"],
    &["aktistetae"],
];

pub(crate) static ENTRY_ALBITIZED_12708773531187894235: VariantsMap = [
    &["albitized"],
    &["albitised"],
    &["albitized"],
    &["albitised"],
];

pub(crate) static ENTRY_ALBITIZES_1247422159797012629: VariantsMap = [
    &["albitizes"],
    &["albitises"],
    &["albitizes"],
    &["albitises"],
];

pub(crate) static ENTRY_ALBITIZE_6580071593309620120: VariantsMap =
    [&["albitize"], &["albitise"], &["albitize"], &["albitise"]];

pub(crate) static ENTRY_ALBITIZING_16312871487467352322: VariantsMap = [
    &["albitizing"],
    &["albitising"],
    &["albitizing"],
    &["albitising"],
];

pub(crate) static ENTRY_ALBUMENIZATIONS_361266413627576903: VariantsMap = [
    &["albumenizations"],
    &["albuminisations"],
    &["albuminizations"],
    &["albuminisations"],
];

pub(crate) static ENTRY_ALBUMENIZATION_917091341157704514: VariantsMap = [
    &["albumenization"],
    &["albuminisation"],
    &["albuminization"],
    &["albuminisation"],
];

pub(crate) static ENTRY_ALBUMENIZED_5015192375248331764: VariantsMap = [
    &["albumenized"],
    &["albuminised"],
    &["albuminized"],
    &["albuminised"],
];

pub(crate) static ENTRY_ALBUMENIZER_2746832931557084359: VariantsMap = [
    &["albumenizer"],
    &["albumeniser"],
    &["albumenizer"],
    &["albumeniser"],
];

pub(crate) static ENTRY_ALBUMENIZES_7335751188788108476: VariantsMap = [
    &["albumenizes"],
    &["albuminises"],
    &["albuminizes"],
    &["albuminises"],
];

pub(crate) static ENTRY_ALBUMENIZE_9958331304830383569: VariantsMap = [
    &["albumenize"],
    &["albuminise"],
    &["albuminize"],
    &["albuminise"],
];

pub(crate) static ENTRY_ALBUMENIZING_16024947632070767741: VariantsMap = [
    &["albumenizing"],
    &["albuminising"],
    &["albuminizing"],
    &["albuminising"],
];

pub(crate) static ENTRY_ALCHEMIZED_970509173487598237: VariantsMap = [
    &["alchemized"],
    &["alchemised"],
    &["alchemized"],
    &["alchemised"],
];

pub(crate) static ENTRY_ALCHEMIZES_11682546917258585686: VariantsMap = [
    &["alchemizes"],
    &["alchemises"],
    &["alchemizes"],
    &["alchemises"],
];

pub(crate) static ENTRY_ALCHEMIZE_4688225926772014989: VariantsMap = [
    &["alchemize"],
    &["alchemise"],
    &["alchemize"],
    &["alchemise"],
];

pub(crate) static ENTRY_ALCHEMIZING_6827374645777654741: VariantsMap = [
    &["alchemizing"],
    &["alchemising"],
    &["alchemizing"],
    &["alchemising"],
];

pub(crate) static ENTRY_ALCIDE_7180803551810387458: VariantsMap =
    [&["alcide"], &["alcidae"], &["alcidae"], &["alcidae"]];

pub(crate) static ENTRY_ALCITHOE_18334513949439348849: VariantsMap = [
    &["alcithoe"],
    &["alcithoae"],
    &["alcithoae"],
    &["alcithoae"],
];

pub(crate) static ENTRY_ALCOHOLIZABLES_18037838911878128020: VariantsMap = [
    &["alcoholizables"],
    &["alcoholisables"],
    &["alcoholizables"],
    &["alcoholisables"],
];

pub(crate) static ENTRY_ALCOHOLIZABLE_9485403642663692960: VariantsMap = [
    &["alcoholizable"],
    &["alcoholisable"],
    &["alcoholizable"],
    &["alcoholisable"],
];

pub(crate) static ENTRY_ALCOHOLIZATIONS_3234492423155906190: VariantsMap = [
    &["alcoholizations"],
    &["alcoholisations"],
    &["alcoholizations"],
    &["alcoholisations"],
];

pub(crate) static ENTRY_ALCOHOLIZATION_2472328753870379661: VariantsMap = [
    &["alcoholization"],
    &["alcoholisation"],
    &["alcoholization"],
    &["alcoholisation"],
];

pub(crate) static ENTRY_ALCOHOLIZED_10813198565244222907: VariantsMap = [
    &["alcoholized"],
    &["alcoholised"],
    &["alcoholized"],
    &["alcoholised"],
];

pub(crate) static ENTRY_ALCOHOLIZES_14942241136434110267: VariantsMap = [
    &["alcoholizes"],
    &["alcoholises"],
    &["alcoholizes"],
    &["alcoholises"],
];

pub(crate) static ENTRY_ALCOHOLIZE_2784092109356476451: VariantsMap = [
    &["alcoholize"],
    &["alcoholise"],
    &["alcoholize"],
    &["alcoholise"],
];

pub(crate) static ENTRY_ALCOHOLIZING_12094421078983570983: VariantsMap = [
    &["alcoholizing"],
    &["alcoholising"],
    &["alcoholizing"],
    &["alcoholising"],
];

pub(crate) static ENTRY_ALEUCEMIC_15331592114170624314: VariantsMap = [
    &["aleucemic"],
    &["aleucaemic"],
    &["aleucaemic"],
    &["aleucaemic"],
];

pub(crate) static ENTRY_ALEUKEMIC_12081345934336952932: VariantsMap = [
    &["aleukemic"],
    &["aleukaemic"],
    &["aleukaemic"],
    &["aleukaemic"],
];

pub(crate) static ENTRY_ALEUS_3052878685126980247: VariantsMap =
    [&["aleus"], &["aloeus"], &["aloeus"], &["aloeus"]];

pub(crate) static ENTRY_ALGEBRAIZATIONS_1118204679681555228: VariantsMap = [
    &["algebraizations"],
    &["algebraisations"],
    &["algebraizations"],
    &["algebraisations"],
];

pub(crate) static ENTRY_ALGEBRAIZATION_1080988040552907317: VariantsMap = [
    &["algebraization"],
    &["algebraisation"],
    &["algebraization"],
    &["algebraisation"],
];

pub(crate) static ENTRY_ALGEBRAIZES_14667284517281133424: VariantsMap = [
    &["algebraizes"],
    &["algebraises"],
    &["algebraizes"],
    &["algebraises"],
];

pub(crate) static ENTRY_ALGEBRAIZE_4974435447622870294: VariantsMap = [
    &["algebraize"],
    &["algebraise"],
    &["algebraize"],
    &["algebraise"],
];

pub(crate) static ENTRY_ALGESTHESIS_10162337686037967662: VariantsMap = [
    &["algesthesis"],
    &["algaesthesis"],
    &["algaesthesis"],
    &["algaesthesis"],
];

pub(crate) static ENTRY_ALIENIZES_7602952593780461071: VariantsMap = [
    &["alienizes"],
    &["alienises"],
    &["alienizes"],
    &["alienises"],
];

pub(crate) static ENTRY_ALIENIZE_17985228286325897083: VariantsMap =
    [&["alienize"], &["alienise"], &["alienize"], &["alienise"]];

pub(crate) static ENTRY_ALIGNED_8535548357538490917: VariantsMap =
    [&["aligned"], &["aligned"], &["aligned"], &["aligned"]];

pub(crate) static ENTRY_ALIGNING_11906672542962792842: VariantsMap =
    [&["aligning"], &["aligning"], &["aligning"], &["aligning"]];

pub(crate) static ENTRY_ALIGNMENTS_13271850361761755881: VariantsMap = [
    &["alignments"],
    &["alignments"],
    &["alignments"],
    &["alignments"],
];

pub(crate) static ENTRY_ALIGNMENT_16172862810825494574: VariantsMap = [
    &["alignment"],
    &["alignment"],
    &["alignment"],
    &["alignment"],
];

pub(crate) static ENTRY_ALIGNS_17212579295098786518: VariantsMap =
    [&["aligns"], &["aligns"], &["aligns"], &["aligns"]];

pub(crate) static ENTRY_ALIGN_4971550510086993659: VariantsMap =
    [&["align"], &["align"], &["align"], &["align"]];

pub(crate) static ENTRY_ALKALINIZATIONS_6341885267161977275: VariantsMap = [
    &["alkalinizations"],
    &["alkalinisations"],
    &["alkalinizations"],
    &["alkalinisations"],
];

pub(crate) static ENTRY_ALKALINIZATION_3423502466279984150: VariantsMap = [
    &["alkalinization"],
    &["alkalinisation"],
    &["alkalinization"],
    &["alkalinisation"],
];

pub(crate) static ENTRY_ALKALINIZED_17127755905736389533: VariantsMap = [
    &["alkalinized"],
    &["alkalinised"],
    &["alkalinized"],
    &["alkalinised"],
];

pub(crate) static ENTRY_ALKALINIZES_8062929759471029941: VariantsMap = [
    &["alkalinizes"],
    &["alkalinises"],
    &["alkalinizes"],
    &["alkalinises"],
];

pub(crate) static ENTRY_ALKALINIZE_14771433372647914923: VariantsMap = [
    &["alkalinize"],
    &["alkalinise"],
    &["alkalinize"],
    &["alkalinise"],
];

pub(crate) static ENTRY_ALKALINIZING_11857659143291411210: VariantsMap = [
    &["alkalinizing"],
    &["alkalinising"],
    &["alkalinizing"],
    &["alkalinising"],
];

pub(crate) static ENTRY_ALKALIZABLE_13736993329747194170: VariantsMap = [
    &["alkalizable"],
    &["alkalisable"],
    &["alkalizable"],
    &["alkalisable"],
];

pub(crate) static ENTRY_ALKALIZATIONS_13229553745279157491: VariantsMap = [
    &["alkalizations"],
    &["alkalisations"],
    &["alkalizations"],
    &["alkalisations"],
];

pub(crate) static ENTRY_ALKALIZATION_3651800699418661876: VariantsMap = [
    &["alkalization"],
    &["alkalisation"],
    &["alkalization"],
    &["alkalisation"],
];

pub(crate) static ENTRY_ALKALIZED_11259806011761795306: VariantsMap = [
    &["alkalized"],
    &["alkalised"],
    &["alkalized"],
    &["alkalised"],
];

pub(crate) static ENTRY_ALKALIZER_14632296185920449101: VariantsMap = [
    &["alkalizer"],
    &["alkaliser"],
    &["alkalizer"],
    &["alkaliser"],
];

pub(crate) static ENTRY_ALKALIZES_17996521291317798431: VariantsMap = [
    &["alkalizes"],
    &["alkalises"],
    &["alkalizes"],
    &["alkalises"],
];

pub(crate) static ENTRY_ALKALIZE_3601892613281117908: VariantsMap =
    [&["alkalize"], &["alkalise"], &["alkalize"], &["alkalise"]];

pub(crate) static ENTRY_ALKALIZING_18021680471530652347: VariantsMap = [
    &["alkalizing"],
    &["alkalising"],
    &["alkalizing"],
    &["alkalising"],
];

pub(crate) static ENTRY_ALLEGORIZATIONS_8012727316187763644: VariantsMap = [
    &["allegorizations"],
    &["allegorisations"],
    &["allegorizations"],
    &["allegorisations"],
];

pub(crate) static ENTRY_ALLEGORIZATION_4541977880287652521: VariantsMap = [
    &["allegorization"],
    &["allegorisation"],
    &["allegorization"],
    &["allegorisation"],
];

pub(crate) static ENTRY_ALLEGORIZED_15639970683830457866: VariantsMap = [
    &["allegorized"],
    &["allegorised"],
    &["allegorized"],
    &["allegorised"],
];

pub(crate) static ENTRY_ALLEGORIZERS_14958456277764981191: VariantsMap = [
    &["allegorizers"],
    &["allegorisers"],
    &["allegorizers"],
    &["allegorisers"],
];

pub(crate) static ENTRY_ALLEGORIZER_3988457917108953181: VariantsMap = [
    &["allegorizer"],
    &["allegoriser"],
    &["allegorizer"],
    &["allegoriser"],
];

pub(crate) static ENTRY_ALLEGORIZES_264741514106655340: VariantsMap = [
    &["allegorizes"],
    &["allegorises"],
    &["allegorizes"],
    &["allegorises"],
];

pub(crate) static ENTRY_ALLEGORIZE_8243818793381064842: VariantsMap = [
    &["allegorize"],
    &["allegorise"],
    &["allegorize"],
    &["allegorise"],
];

pub(crate) static ENTRY_ALLEGORIZING_6032281381406970489: VariantsMap = [
    &["allegorizing"],
    &["allegorising"],
    &["allegorizing"],
    &["allegorising"],
];

pub(crate) static ENTRY_ALLOXUREMIA_1732700770441739843: VariantsMap = [
    &["alloxuremia"],
    &["alloxuraemia"],
    &["alloxuraemia"],
    &["alloxuraemia"],
];

pub(crate) static ENTRY_ALMANACS_5174170691068691024: VariantsMap =
    [&["almanacs"], &["almanacs"], &["almanacs"], &["almanacs"]];

pub(crate) static ENTRY_ALMANAC_9022062463507112858: VariantsMap =
    [&["almanac"], &["almanac"], &["almanac"], &["almanac"]];

pub(crate) static ENTRY_ALPHABETIZATIONS_6211095631410316582: VariantsMap = [
    &["alphabetizations"],
    &["alphabetisations"],
    &["alphabetizations"],
    &["alphabetisations"],
];

pub(crate) static ENTRY_ALPHABETIZATION_1968434628773617953: VariantsMap = [
    &["alphabetization"],
    &["alphabetisation"],
    &["alphabetization"],
    &["alphabetisation"],
];

pub(crate) static ENTRY_ALPHABETIZED_2753693013313167498: VariantsMap = [
    &["alphabetized"],
    &["alphabetised"],
    &["alphabetized"],
    &["alphabetised"],
];

pub(crate) static ENTRY_ALPHABETIZERS_7973238112885182445: VariantsMap = [
    &["alphabetizers"],
    &["alphabetisers"],
    &["alphabetizers"],
    &["alphabetisers"],
];

pub(crate) static ENTRY_ALPHABETIZER_2275393906060793039: VariantsMap = [
    &["alphabetizer"],
    &["alphabetiser"],
    &["alphabetizer"],
    &["alphabetiser"],
];

pub(crate) static ENTRY_ALPHABETIZES_5626725721294168785: VariantsMap = [
    &["alphabetizes"],
    &["alphabetises"],
    &["alphabetizes"],
    &["alphabetises"],
];

pub(crate) static ENTRY_ALPHABETIZE_17413351134035178681: VariantsMap = [
    &["alphabetize"],
    &["alphabetise"],
    &["alphabetize"],
    &["alphabetise"],
];

pub(crate) static ENTRY_ALPHABETIZING_3131711685375790300: VariantsMap = [
    &["alphabetizing"],
    &["alphabetising"],
    &["alphabetizing"],
    &["alphabetising"],
];

pub(crate) static ENTRY_ALTERNIZES_6270469533749381019: VariantsMap = [
    &["alternizes"],
    &["alternises"],
    &["alternizes"],
    &["alternises"],
];

pub(crate) static ENTRY_ALTERNIZE_13385825174475592158: VariantsMap = [
    &["alternize"],
    &["alternise"],
    &["alternize"],
    &["alternise"],
];

pub(crate) static ENTRY_ALTHEAS_15869195144516418672: VariantsMap =
    [&["altheas"], &["althaeas"], &["althaeas"], &["althaeas"]];

pub(crate) static ENTRY_ALTHEA_11537003706783870112: VariantsMap =
    [&["althea"], &["althaea"], &["althaea"], &["althaea"]];

pub(crate) static ENTRY_ALTHEIN_5685929198321095359: VariantsMap =
    [&["althein"], &["althaein"], &["althaein"], &["althaein"]];

pub(crate) static ENTRY_ALTHOUGH_1476504865379962577: VariantsMap =
    [&["although"], &["although"], &["although"], &["although"]];

pub(crate) static ENTRY_ALUMINIZATION_9199820651849568446: VariantsMap = [
    &["aluminization"],
    &["aluminisation"],
    &["aluminization"],
    &["aluminisation"],
];

pub(crate) static ENTRY_ALUMINIZED_10511736687970899076: VariantsMap = [
    &["aluminized"],
    &["aluminised"],
    &["aluminized"],
    &["aluminised"],
];

pub(crate) static ENTRY_ALUMINIZES_13479682276812698370: VariantsMap = [
    &["aluminizes"],
    &["aluminises"],
    &["aluminizes"],
    &["aluminises"],
];

pub(crate) static ENTRY_ALUMINIZE_9483354617585319049: VariantsMap = [
    &["aluminize"],
    &["aluminise"],
    &["aluminize"],
    &["aluminise"],
];

pub(crate) static ENTRY_ALUMINIZING_17184640806714355126: VariantsMap = [
    &["aluminizing"],
    &["aluminising"],
    &["aluminizing"],
    &["aluminising"],
];

pub(crate) static ENTRY_ALUMINUMS_17635872113099894054: VariantsMap = [
    &["aluminums"],
    &["aluminiums"],
    &["aluminums"],
    &["aluminiums"],
];

pub(crate) static ENTRY_ALUMINUM_14009724291836144060: VariantsMap =
    [&["aluminum"], &["aluminium"], &["aluminum"], &["aluminium"]];

pub(crate) static ENTRY_ALVEOLE_1468644614341036052: VariantsMap =
    [&["alveole"], &["alveolae"], &["alveolae"], &["alveolae"]];

pub(crate) static ENTRY_AMALGAMATIZES_5890643774572641679: VariantsMap = [
    &["amalgamatizes"],
    &["amalgamatises"],
    &["amalgamatizes"],
    &["amalgamatises"],
];

pub(crate) static ENTRY_AMALGAMATIZE_10132057674178478300: VariantsMap = [
    &["amalgamatize"],
    &["amalgamatise"],
    &["amalgamatize"],
    &["amalgamatise"],
];

pub(crate) static ENTRY_AMALGAMIZATIONS_8840243500079413668: VariantsMap = [
    &["amalgamizations"],
    &["amalgamisations"],
    &["amalgamizations"],
    &["amalgamisations"],
];

pub(crate) static ENTRY_AMALGAMIZATION_1227895542692594943: VariantsMap = [
    &["amalgamization"],
    &["amalgamisation"],
    &["amalgamization"],
    &["amalgamisation"],
];

pub(crate) static ENTRY_AMALGAMIZES_9889624041095207817: VariantsMap = [
    &["amalgamizes"],
    &["amalgamises"],
    &["amalgamizes"],
    &["amalgamises"],
];

pub(crate) static ENTRY_AMALGAMIZE_494609927742594122: VariantsMap = [
    &["amalgamize"],
    &["amalgamise"],
    &["amalgamize"],
    &["amalgamise"],
];

pub(crate) static ENTRY_AMALTHEA_10246271508362727126: VariantsMap = [
    &["amalthea"],
    &["amalthaea"],
    &["amalthaea"],
    &["amalthaea"],
];

pub(crate) static ENTRY_AMBICOLORATE_16029524865781794692: VariantsMap = [
    &["ambicolorate"],
    &["ambicolourate"],
    &["ambicolourate"],
    &["ambicolourate"],
];

pub(crate) static ENTRY_AMBICOLORATION_9621174709699501824: VariantsMap = [
    &["ambicoloration"],
    &["ambicolouration"],
    &["ambicolouration"],
    &["ambicolouration"],
];

pub(crate) static ENTRY_AMBILEVOUS_15489788216797140394: VariantsMap = [
    &["ambilevous"],
    &["ambilaevous"],
    &["ambilaevous"],
    &["ambilaevous"],
];

pub(crate) static ENTRY_AMEBAN_11760427595642064735: VariantsMap =
    [&["ameban"], &["amoeban"], &["amoeban"], &["amoeban"]];

pub(crate) static ENTRY_AMEBEAN_8080760714988914896: VariantsMap =
    [&["amebean"], &["amoebean"], &["amoebean"], &["amoebean"]];

pub(crate) static ENTRY_AMEBIAN_1868510719746036319: VariantsMap =
    [&["amebian"], &["amoebian"], &["amoebian"], &["amoebian"]];

pub(crate) static ENTRY_AMEBIASES_191994802519161378: VariantsMap = [
    &["amebiases"],
    &["amoebiases"],
    &["amoebiases"],
    &["amoebiases"],
];

pub(crate) static ENTRY_AMEBIASIS_15952343352557455271: VariantsMap = [
    &["amebiasis"],
    &["amoebiasis"],
    &["amoebiasis"],
    &["amoebiasis"],
];

pub(crate) static ENTRY_AMEBICIDAL_12174992966673417980: VariantsMap = [
    &["amebicidal"],
    &["amoebicidal"],
    &["amoebicidal"],
    &["amoebicidal"],
];

pub(crate) static ENTRY_AMEBICIDE_6727392976948759380: VariantsMap = [
    &["amebicide"],
    &["amoebicide"],
    &["amoebicide"],
    &["amoebicide"],
];

pub(crate) static ENTRY_AMEBID_8990707670752348207: VariantsMap =
    [&["amebid"], &["amoebid"], &["amoebid"], &["amoebid"]];

pub(crate) static ENTRY_AMEBIFORM_18384809890812519272: VariantsMap = [
    &["amebiform"],
    &["amoebiform"],
    &["amoebiform"],
    &["amoebiform"],
];

pub(crate) static ENTRY_AMEBIOSIS_1796168007817567758: VariantsMap = [
    &["amebiosis"],
    &["amoebiosis"],
    &["amoebiosis"],
    &["amoebiosis"],
];

pub(crate) static ENTRY_AMEBOCYTES_2131705893903646289: VariantsMap = [
    &["amebocytes"],
    &["amoebocytes"],
    &["amoebocytes"],
    &["amoebocytes"],
];

pub(crate) static ENTRY_AMEBOCYTE_13745214137940733370: VariantsMap = [
    &["amebocyte"],
    &["amoebocyte"],
    &["amoebocyte"],
    &["amoebocyte"],
];

pub(crate) static ENTRY_AMEBOIDISM_5298244506544781863: VariantsMap = [
    &["ameboidism"],
    &["amoeboidism"],
    &["amoeboidism"],
    &["amoeboidism"],
];

pub(crate) static ENTRY_AMEBOUS_943579757904752148: VariantsMap =
    [&["amebous"], &["amoebous"], &["amoebous"], &["amoebous"]];

pub(crate) static ENTRY_AMEBULA_11884806604842186245: VariantsMap =
    [&["amebula"], &["amoebula"], &["amoebula"], &["amoebula"]];

pub(crate) static ENTRY_AMENORRHEAL_14815736395132018820: VariantsMap = [
    &["amenorrheal"],
    &["amenorrhoeal"],
    &["amenorrheal"],
    &["amenorrhoeal"],
];

pub(crate) static ENTRY_AMENORRHEAS_3139958337225187988: VariantsMap = [
    &["amenorrheas"],
    &["amenorrhoeas"],
    &["amenorrheas"],
    &["amenorrhoeas"],
];

pub(crate) static ENTRY_AMENORRHEA_242453106803645932: VariantsMap = [
    &["amenorrhea"],
    &["amenorrhoea"],
    &["amenorrhea"],
    &["amenorrhoea"],
];

pub(crate) static ENTRY_AMENORRHEIC_7592925368031506722: VariantsMap = [
    &["amenorrheic"],
    &["amenorrhoeic"],
    &["amenorrheic"],
    &["amenorrhoeic"],
];

pub(crate) static ENTRY_AMERICANIZATIONS_10566116106297564484: VariantsMap = [
    &["americanizations"],
    &["americanisations"],
    &["americanizations"],
    &["americanisations"],
];

pub(crate) static ENTRY_AMERICANIZATION_17361533923238172216: VariantsMap = [
    &["americanization"],
    &["americanisation"],
    &["americanization"],
    &["americanisation"],
];

pub(crate) static ENTRY_AMERICANIZED_17030997472393305329: VariantsMap = [
    &["americanized"],
    &["americanised"],
    &["americanized"],
    &["americanised"],
];

pub(crate) static ENTRY_AMERICANIZERS_13649354426641948375: VariantsMap = [
    &["americanizers"],
    &["americanisers"],
    &["americanizers"],
    &["americanisers"],
];

pub(crate) static ENTRY_AMERICANIZER_8728502865340307492: VariantsMap = [
    &["americanizer"],
    &["americaniser"],
    &["americanizer"],
    &["americaniser"],
];

pub(crate) static ENTRY_AMERICANIZES_11703695827536694615: VariantsMap = [
    &["americanizes"],
    &["americanises"],
    &["americanizes"],
    &["americanises"],
];

pub(crate) static ENTRY_AMERICANIZE_17271444033069169029: VariantsMap = [
    &["americanize"],
    &["americanise"],
    &["americanize"],
    &["americanise"],
];

pub(crate) static ENTRY_AMERICANIZING_2551380555094033314: VariantsMap = [
    &["americanizing"],
    &["americanising"],
    &["americanizing"],
    &["americanising"],
];

pub(crate) static ENTRY_AMMOCETES_16461339325418394188: VariantsMap = [
    &["ammocetes"],
    &["ammocoetes"],
    &["ammocoetes"],
    &["ammocoetes"],
];

pub(crate) static ENTRY_AMMOCETE_14257434139746734740: VariantsMap = [
    &["ammocete"],
    &["ammocoete"],
    &["ammocoete"],
    &["ammocoete"],
];

pub(crate) static ENTRY_AMMONIEMIA_11606025562213027514: VariantsMap = [
    &["ammoniemia"],
    &["ammoniaemia"],
    &["ammoniaemia"],
    &["ammoniaemia"],
];

pub(crate) static ENTRY_AMOEBAS_14731335040187035859: VariantsMap =
    [&["amoebas"], &["amoebas"], &["amoebas"], &["amoebas"]];

pub(crate) static ENTRY_AMOEBA_6065159277789412432: VariantsMap =
    [&["amoeba"], &["amoeba"], &["amoeba"], &["amoeba"]];

pub(crate) static ENTRY_AMOEBIC_11458986316626520792: VariantsMap =
    [&["amoebic"], &["amoebic"], &["amoebic"], &["amoebic"]];

pub(crate) static ENTRY_AMOEBOID_15535671593298564900: VariantsMap =
    [&["amoeboid"], &["amoeboid"], &["amoeboid"], &["amoeboid"]];

pub(crate) static ENTRY_AMORALIZES_5410233152547413336: VariantsMap = [
    &["amoralizes"],
    &["amoralises"],
    &["amoralizes"],
    &["amoralises"],
];

pub(crate) static ENTRY_AMORALIZE_10530116290419221146: VariantsMap = [
    &["amoralize"],
    &["amoralise"],
    &["amoralize"],
    &["amoralise"],
];

pub(crate) static ENTRY_AMORET_4753587475704323862: VariantsMap =
    [&["amoret"], &["amouret"], &["amouret"], &["amouret"]];

pub(crate) static ENTRY_AMORISMS_6181761571118464419: VariantsMap = [
    &["amorisms"],
    &["amourisms"],
    &["amourisms"],
    &["amourisms"],
];

pub(crate) static ENTRY_AMORISM_15369061524023282087: VariantsMap =
    [&["amorism"], &["amourism"], &["amourism"], &["amourism"]];

pub(crate) static ENTRY_AMORISTICS_1227189450459983152: VariantsMap = [
    &["amoristics"],
    &["amouristics"],
    &["amouristics"],
    &["amouristics"],
];

pub(crate) static ENTRY_AMORISTIC_14460066953477032170: VariantsMap = [
    &["amoristic"],
    &["amouristic"],
    &["amouristic"],
    &["amouristic"],
];

pub(crate) static ENTRY_AMORISTS_17336209472802767632: VariantsMap = [
    &["amorists"],
    &["amourists"],
    &["amourists"],
    &["amourists"],
];

pub(crate) static ENTRY_AMORIST_312032137521875674: VariantsMap =
    [&["amorist"], &["amourist"], &["amourist"], &["amourist"]];

pub(crate) static ENTRY_AMORPHIZATION_4466565318810961775: VariantsMap = [
    &["amorphization"],
    &["amorphisation"],
    &["amorphization"],
    &["amorphisation"],
];

pub(crate) static ENTRY_AMORPHIZE_18341333796166530487: VariantsMap = [
    &["amorphize"],
    &["amorphise"],
    &["amorphize"],
    &["amorphise"],
];

pub(crate) static ENTRY_AMORTIZABLER_18082767998983582677: VariantsMap = [
    &["amortizabler"],
    &["amortisabler"],
    &["amortizabler"],
    &["amortisabler"],
];

pub(crate) static ENTRY_AMORTIZABLEST_2213906445519340958: VariantsMap = [
    &["amortizablest"],
    &["amortisablest"],
    &["amortizablest"],
    &["amortisablest"],
];

pub(crate) static ENTRY_AMORTIZABLES_9501483392939472572: VariantsMap = [
    &["amortizables"],
    &["amortisables"],
    &["amortizables"],
    &["amortisables"],
];

pub(crate) static ENTRY_AMORTIZABLE_16351054998752239198: VariantsMap = [
    &["amortizable"],
    &["amortisable"],
    &["amortizable"],
    &["amortisable"],
];

pub(crate) static ENTRY_AMORTIZATIONS_16886902791141844612: VariantsMap = [
    &["amortizations"],
    &["amortisations"],
    &["amortizations"],
    &["amortisations"],
];

pub(crate) static ENTRY_AMORTIZATION_18349471581624055412: VariantsMap = [
    &["amortization"],
    &["amortisation"],
    &["amortization"],
    &["amortisation"],
];

pub(crate) static ENTRY_AMORTIZED_2614639190878550237: VariantsMap = [
    &["amortized"],
    &["amortised"],
    &["amortized"],
    &["amortised"],
];

pub(crate) static ENTRY_AMORTIZEMENTS_3866412779714938646: VariantsMap = [
    &["amortizements"],
    &["amortisements"],
    &["amortizements"],
    &["amortisements"],
];

pub(crate) static ENTRY_AMORTIZEMENT_2457588450573582913: VariantsMap = [
    &["amortizement"],
    &["amortisement"],
    &["amortizement"],
    &["amortisement"],
];

pub(crate) static ENTRY_AMORTIZES_12419679215195830898: VariantsMap = [
    &["amortizes"],
    &["amortises"],
    &["amortizes"],
    &["amortises"],
];

pub(crate) static ENTRY_AMORTIZE_11005762606748607646: VariantsMap =
    [&["amortize"], &["amortise"], &["amortize"], &["amortise"]];

pub(crate) static ENTRY_AMORTIZING_18247929480308315117: VariantsMap = [
    &["amortizing"],
    &["amortising"],
    &["amortizing"],
    &["amortising"],
];

pub(crate) static ENTRY_AMPHIGEAN_2663281186252889290: VariantsMap = [
    &["amphigean"],
    &["amphigaean"],
    &["amphigaean"],
    &["amphigaean"],
];

pub(crate) static ENTRY_AMPHITHEATERS_976595961664678124: VariantsMap = [
    &["amphitheaters"],
    &["amphitheatres"],
    &["amphitheatres"],
    &["amphitheatres"],
];

pub(crate) static ENTRY_AMPHITHEATER_13906435369224031259: VariantsMap = [
    &["amphitheater"],
    &["amphitheatre"],
    &["amphitheatre"],
    &["amphitheatre"],
];

pub(crate) static ENTRY_AMYGDALE_11338890394982341606: VariantsMap = [
    &["amygdale"],
    &["amygdalae"],
    &["amygdalae"],
    &["amygdalae"],
];

pub(crate) static ENTRY_AMYXORRHEA_3592031423760777233: VariantsMap = [
    &["amyxorrhea"],
    &["amyxorrhoea"],
    &["amyxorrhoea"],
    &["amyxorrhoea"],
];

pub(crate) static ENTRY_ANABAPTIZED_16234871345111173088: VariantsMap = [
    &["anabaptized"],
    &["anabaptised"],
    &["anabaptized"],
    &["anabaptised"],
];

pub(crate) static ENTRY_ANABAPTIZES_7333755464796915136: VariantsMap = [
    &["anabaptizes"],
    &["anabaptises"],
    &["anabaptizes"],
    &["anabaptises"],
];

pub(crate) static ENTRY_ANABAPTIZE_11278166687492169507: VariantsMap = [
    &["anabaptize"],
    &["anabaptise"],
    &["anabaptize"],
    &["anabaptise"],
];

pub(crate) static ENTRY_ANABAPTIZING_18080976513989605902: VariantsMap = [
    &["anabaptizing"],
    &["anabaptising"],
    &["anabaptizing"],
    &["anabaptising"],
];

pub(crate) static ENTRY_ANAGRAMMATIZED_12777276468218717735: VariantsMap = [
    &["anagrammatized"],
    &["anagrammatised"],
    &["anagrammatized"],
    &["anagrammatised"],
];

pub(crate) static ENTRY_ANAGRAMMATIZES_13672255743930960739: VariantsMap = [
    &["anagrammatizes"],
    &["anagrammatises"],
    &["anagrammatizes"],
    &["anagrammatises"],
];

pub(crate) static ENTRY_ANAGRAMMATIZE_5529917246968520880: VariantsMap = [
    &["anagrammatize"],
    &["anagrammatise"],
    &["anagrammatize"],
    &["anagrammatise"],
];

pub(crate) static ENTRY_ANAGRAMMATIZING_9269936032771734368: VariantsMap = [
    &["anagrammatizing"],
    &["anagrammatising"],
    &["anagrammatizing"],
    &["anagrammatising"],
];

pub(crate) static ENTRY_ANALOGIZED_7650212126382953539: VariantsMap = [
    &["analogized"],
    &["analogised"],
    &["analogized"],
    &["analogised"],
];

pub(crate) static ENTRY_ANALOGIZES_13569410805636149254: VariantsMap = [
    &["analogizes"],
    &["analogises"],
    &["analogizes"],
    &["analogises"],
];

pub(crate) static ENTRY_ANALOGIZE_3496372555061910029: VariantsMap = [
    &["analogize"],
    &["analogise"],
    &["analogize"],
    &["analogise"],
];

pub(crate) static ENTRY_ANALOGIZING_5745351008205937159: VariantsMap = [
    &["analogizing"],
    &["analogising"],
    &["analogizing"],
    &["analogising"],
];

pub(crate) static ENTRY_ANALYZABILITY_1173350993735838693: VariantsMap = [
    &["analyzability"],
    &["analysability"],
    &["analyzability"],
    &["analysability"],
];

pub(crate) static ENTRY_ANALYZABLER_1175108799224565364: VariantsMap = [
    &["analyzabler"],
    &["analysabler"],
    &["analyzabler"],
    &["analysabler"],
];

pub(crate) static ENTRY_ANALYZABLEST_6927325114662775659: VariantsMap = [
    &["analyzablest"],
    &["analysablest"],
    &["analyzablest"],
    &["analysablest"],
];

pub(crate) static ENTRY_ANALYZABLE_6620659606031844316: VariantsMap = [
    &["analyzable"],
    &["analysable"],
    &["analyzable"],
    &["analysable"],
];

pub(crate) static ENTRY_ANALYZATIONS_991580025138607997: VariantsMap = [
    &["analyzations"],
    &["analysations"],
    &["analyzations"],
    &["analysations"],
];

pub(crate) static ENTRY_ANALYZATION_10825307177201093946: VariantsMap = [
    &["analyzation"],
    &["analysation"],
    &["analyzation"],
    &["analysation"],
];

pub(crate) static ENTRY_ANALYZED_15674848014505848991: VariantsMap =
    [&["analyzed"], &["analysed"], &["analyzed"], &["analysed"]];

pub(crate) static ENTRY_ANALYZERS_1666949323375308230: VariantsMap = [
    &["analyzers"],
    &["analysers"],
    &["analyzers"],
    &["analysers"],
];

pub(crate) static ENTRY_ANALYZER_5869658529883306960: VariantsMap =
    [&["analyzer"], &["analyser"], &["analyzer"], &["analyser"]];

pub(crate) static ENTRY_ANALYZES_2322356799829770580: VariantsMap =
    [&["analyzes"], &["analyses"], &["analyzes"], &["analyses"]];

pub(crate) static ENTRY_ANALYZE_12128484930486970639: VariantsMap =
    [&["analyze"], &["analyse"], &["analyze"], &["analyse"]];

pub(crate) static ENTRY_ANALYZING_15099411830060036147: VariantsMap = [
    &["analyzing"],
    &["analysing"],
    &["analyzing"],
    &["analysing"],
];

pub(crate) static ENTRY_ANAPESTICALLY_1329709023297995970: VariantsMap = [
    &["anapestically"],
    &["anapaestically"],
    &["anapaestically"],
    &["anapaestically"],
];

pub(crate) static ENTRY_ANAPNEIC_166245242776222043: VariantsMap = [
    &["anapneic"],
    &["anapnoeic"],
    &["anapnoeic"],
    &["anapnoeic"],
];

pub(crate) static ENTRY_ANARCHIZED_2265742664355359347: VariantsMap = [
    &["anarchized"],
    &["anarchised"],
    &["anarchized"],
    &["anarchised"],
];

pub(crate) static ENTRY_ANARCHIZES_15395751413994518956: VariantsMap = [
    &["anarchizes"],
    &["anarchises"],
    &["anarchizes"],
    &["anarchises"],
];

pub(crate) static ENTRY_ANARCHIZE_1081081497921958560: VariantsMap = [
    &["anarchize"],
    &["anarchise"],
    &["anarchize"],
    &["anarchise"],
];

pub(crate) static ENTRY_ANARCHIZING_2590562487568483557: VariantsMap = [
    &["anarchizing"],
    &["anarchising"],
    &["anarchizing"],
    &["anarchising"],
];

pub(crate) static ENTRY_ANATHEMATIZATIONS_383397386592014889: VariantsMap = [
    &["anathematizations"],
    &["anathematisations"],
    &["anathematizations"],
    &["anathematisations"],
];

pub(crate) static ENTRY_ANATHEMATIZATION_652820925003292708: VariantsMap = [
    &["anathematization"],
    &["anathematisation"],
    &["anathematization"],
    &["anathematisation"],
];

pub(crate) static ENTRY_ANATHEMATIZED_14882382556399376184: VariantsMap = [
    &["anathematized"],
    &["anathematised"],
    &["anathematized"],
    &["anathematised"],
];

pub(crate) static ENTRY_ANATHEMATIZER_18318684354444230221: VariantsMap = [
    &["anathematizer"],
    &["anathematiser"],
    &["anathematizer"],
    &["anathematiser"],
];

pub(crate) static ENTRY_ANATHEMATIZES_1397436506406873414: VariantsMap = [
    &["anathematizes"],
    &["anathematises"],
    &["anathematizes"],
    &["anathematises"],
];

pub(crate) static ENTRY_ANATHEMATIZE_8985478249302198786: VariantsMap = [
    &["anathematize"],
    &["anathematise"],
    &["anathematize"],
    &["anathematise"],
];

pub(crate) static ENTRY_ANATHEMATIZING_3364254909178814387: VariantsMap = [
    &["anathematizing"],
    &["anathematising"],
    &["anathematizing"],
    &["anathematising"],
];

pub(crate) static ENTRY_ANATOMIZABLE_4206201642984389225: VariantsMap = [
    &["anatomizable"],
    &["anatomisable"],
    &["anatomizable"],
    &["anatomisable"],
];

pub(crate) static ENTRY_ANATOMIZATION_2325685116767991731: VariantsMap = [
    &["anatomization"],
    &["anatomisation"],
    &["anatomization"],
    &["anatomisation"],
];

pub(crate) static ENTRY_ANATOMIZED_15278909516951232818: VariantsMap = [
    &["anatomized"],
    &["anatomised"],
    &["anatomized"],
    &["anatomised"],
];

pub(crate) static ENTRY_ANATOMIZER_13440602250047971691: VariantsMap = [
    &["anatomizer"],
    &["anatomiser"],
    &["anatomizer"],
    &["anatomiser"],
];

pub(crate) static ENTRY_ANATOMIZES_9984137617813051385: VariantsMap = [
    &["anatomizes"],
    &["anatomises"],
    &["anatomizes"],
    &["anatomises"],
];

pub(crate) static ENTRY_ANATOMIZE_5992811181160301723: VariantsMap = [
    &["anatomize"],
    &["anatomise"],
    &["anatomize"],
    &["anatomise"],
];

pub(crate) static ENTRY_ANATOMIZING_16127461066028765958: VariantsMap = [
    &["anatomizing"],
    &["anatomising"],
    &["anatomizing"],
    &["anatomising"],
];

pub(crate) static ENTRY_ANCHINOE_11715538892311512591: VariantsMap = [
    &["anchinoe"],
    &["anchinoae"],
    &["anchinoae"],
    &["anchinoae"],
];

pub(crate) static ENTRY_ANCILLE_4424192584387520513: VariantsMap =
    [&["ancille"], &["ancillae"], &["ancillae"], &["ancillae"]];

pub(crate) static ENTRY_ANEMATOSIS_12724418797581501779: VariantsMap = [
    &["anematosis"],
    &["anaematosis"],
    &["anaematosis"],
    &["anaematosis"],
];

pub(crate) static ENTRY_ANEMIAS_9703736074959593780: VariantsMap =
    [&["anemias"], &["anaemias"], &["anemias"], &["anaemias"]];

pub(crate) static ENTRY_ANEMIA_17351338060107863650: VariantsMap =
    [&["anemia"], &["anaemia"], &["anemia"], &["anaemia"]];

pub(crate) static ENTRY_ANEMICALLY_1918381762384876054: VariantsMap = [
    &["anemically"],
    &["anaemically"],
    &["anemically"],
    &["anaemically"],
];

pub(crate) static ENTRY_ANEMICER_10489187624102082516: VariantsMap =
    [&["anemicer"], &["anaemicer"], &["anemicer"], &["anaemicer"]];

pub(crate) static ENTRY_ANEMICEST_16912294123173826264: VariantsMap = [
    &["anemicest"],
    &["anaemicest"],
    &["anemicest"],
    &["anaemicest"],
];

pub(crate) static ENTRY_ANEMICS_16585338697348245033: VariantsMap =
    [&["anemics"], &["anaemics"], &["anemics"], &["anaemics"]];

pub(crate) static ENTRY_ANEMIC_110986479873166850: VariantsMap =
    [&["anemic"], &["anaemic"], &["anemic"], &["anaemic"]];

pub(crate) static ENTRY_ANERETIC_16141834454964794758: VariantsMap = [
    &["aneretic"],
    &["anaeretic"],
    &["anaeretic"],
    &["anaeretic"],
];

pub(crate) static ENTRY_ANESIS_7776956081242083056: VariantsMap =
    [&["anesis"], &["anoesis"], &["anoesis"], &["anoesis"]];

pub(crate) static ENTRY_ANESTHESIANT_4746502908533923971: VariantsMap = [
    &["anesthesiant"],
    &["anaesthesiant"],
    &["anaesthesiant"],
    &["anaesthesiant"],
];

pub(crate) static ENTRY_ANESTHESIAS_4599764321131919802: VariantsMap = [
    &["anesthesias"],
    &["anaesthesias"],
    &["anaesthesias"],
    &["anaesthesias"],
];

pub(crate) static ENTRY_ANESTHESIA_7949842536189154112: VariantsMap = [
    &["anesthesia"],
    &["anaesthesia"],
    &["anaesthesia"],
    &["anaesthesia"],
];

pub(crate) static ENTRY_ANESTHESIOLOGIES_140878230116787033: VariantsMap = [
    &["anesthesiologies"],
    &["anaesthesiologies"],
    &["anesthesiologies"],
    &["anaesthesiologies"],
];

pub(crate) static ENTRY_ANESTHESIOLOGISTS_5917925088694288121: VariantsMap = [
    &["anesthesiologists"],
    &["anaesthesiologists"],
    &["anesthesiologists"],
    &["anaesthesiologists"],
];

pub(crate) static ENTRY_ANESTHESIOLOGIST_11739214388783841528: VariantsMap = [
    &["anesthesiologist"],
    &["anaesthesiologist"],
    &["anesthesiologist"],
    &["anaesthesiologist"],
];

pub(crate) static ENTRY_ANESTHESIOLOGY_17372491589772115476: VariantsMap = [
    &["anesthesiology"],
    &["anaesthesiology"],
    &["anesthesiology"],
    &["anaesthesiology"],
];

pub(crate) static ENTRY_ANESTHESIS_604371175550791390: VariantsMap = [
    &["anesthesis"],
    &["anaesthesis"],
    &["anesthesis"],
    &["anaesthesis"],
];

pub(crate) static ENTRY_ANESTHETICALLY_16764872851576239321: VariantsMap = [
    &["anesthetically"],
    &["anaesthetically"],
    &["anaesthetically"],
    &["anaesthetically"],
];

pub(crate) static ENTRY_ANESTHETICER_2077884160248687026: VariantsMap = [
    &["anestheticer"],
    &["anaestheticer"],
    &["anaestheticer"],
    &["anaestheticer"],
];

pub(crate) static ENTRY_ANESTHETICEST_9846998351210964261: VariantsMap = [
    &["anestheticest"],
    &["anaestheticest"],
    &["anaestheticest"],
    &["anaestheticest"],
];

pub(crate) static ENTRY_ANESTHETICS_14641815304467888505: VariantsMap = [
    &["anesthetics"],
    &["anaesthetics"],
    &["anaesthetics"],
    &["anaesthetics"],
];

pub(crate) static ENTRY_ANESTHETIC_14288529759943853831: VariantsMap = [
    &["anesthetic"],
    &["anaesthetic"],
    &["anaesthetic"],
    &["anaesthetic"],
];

pub(crate) static ENTRY_ANESTHETISTS_8704279203965849778: VariantsMap = [
    &["anesthetists"],
    &["anaesthetists"],
    &["anaesthetists"],
    &["anaesthetists"],
];

pub(crate) static ENTRY_ANESTHETIST_11538281420926207852: VariantsMap = [
    &["anesthetist"],
    &["anaesthetist"],
    &["anaesthetist"],
    &["anaesthetist"],
];

pub(crate) static ENTRY_ANESTHETIZATIONS_12188987204886505606: VariantsMap = [
    &["anesthetizations"],
    &["anaesthetisations"],
    &["anaesthetizations"],
    &["anaesthetisations"],
];

pub(crate) static ENTRY_ANESTHETIZATION_16202486391697802084: VariantsMap = [
    &["anesthetization"],
    &["anaesthetisation"],
    &["anaesthetization"],
    &["anaesthetisation"],
];

pub(crate) static ENTRY_ANESTHETIZED_16430560117590162734: VariantsMap = [
    &["anesthetized"],
    &["anaesthetised"],
    &["anaesthetized"],
    &["anaesthetised"],
];

pub(crate) static ENTRY_ANESTHETIZERS_5573390178845466914: VariantsMap = [
    &["anesthetizers"],
    &["anaesthetisers"],
    &["anaesthetizers"],
    &["anaesthetisers"],
];

pub(crate) static ENTRY_ANESTHETIZER_17277086517171409383: VariantsMap = [
    &["anesthetizer"],
    &["anaesthetiser"],
    &["anaesthetizer"],
    &["anaesthetiser"],
];

pub(crate) static ENTRY_ANESTHETIZES_6012915426134202133: VariantsMap = [
    &["anesthetizes"],
    &["anaesthetises"],
    &["anaesthetizes"],
    &["anaesthetises"],
];

pub(crate) static ENTRY_ANESTHETIZE_14671518822963641349: VariantsMap = [
    &["anesthetize"],
    &["anaesthetise"],
    &["anaesthetize"],
    &["anaesthetise"],
];

pub(crate) static ENTRY_ANESTHETIZING_9434687273852626047: VariantsMap = [
    &["anesthetizing"],
    &["anaesthetising"],
    &["anaesthetizing"],
    &["anaesthetising"],
];

pub(crate) static ENTRY_ANESTHYL_11441285363633951452: VariantsMap = [
    &["anesthyl"],
    &["anaesthyl"],
    &["anaesthyl"],
    &["anaesthyl"],
];

pub(crate) static ENTRY_ANESTRA_14041355161442029698: VariantsMap =
    [&["anestra"], &["anoestra"], &["anoestra"], &["anoestra"]];

pub(crate) static ENTRY_ANESTRI_16368817406741696707: VariantsMap =
    [&["anestri"], &["anoestri"], &["anoestri"], &["anoestri"]];

pub(crate) static ENTRY_ANESTROUS_5073150751378264240: VariantsMap = [
    &["anestrous"],
    &["anoestrous"],
    &["anoestrous"],
    &["anoestrous"],
];

pub(crate) static ENTRY_ANESTRUM_567212077285721468: VariantsMap = [
    &["anestrum"],
    &["anoestrum"],
    &["anoestrum"],
    &["anoestrum"],
];

pub(crate) static ENTRY_ANESTRUSES_1462915970085799790: VariantsMap = [
    &["anestruses"],
    &["anoestruses"],
    &["anoestruses"],
    &["anoestruses"],
];

pub(crate) static ENTRY_ANESTRUS_4586228225558465424: VariantsMap = [
    &["anestrus"],
    &["anoestrus"],
    &["anoestrus"],
    &["anoestrus"],
];

pub(crate) static ENTRY_ANETIC_17939635412445225286: VariantsMap =
    [&["anetic"], &["anoetic"], &["anoetic"], &["anoetic"]];

pub(crate) static ENTRY_ANETIOLOGICAL_4530118434736804466: VariantsMap = [
    &["anetiological"],
    &["anaetiological"],
    &["anaetiological"],
    &["anaetiological"],
];

pub(crate) static ENTRY_ANGELICIZES_11761206692627296229: VariantsMap = [
    &["angelicizes"],
    &["angelicises"],
    &["angelicizes"],
    &["angelicises"],
];

pub(crate) static ENTRY_ANGELICIZE_2482124613561887198: VariantsMap = [
    &["angelicize"],
    &["angelicise"],
    &["angelicize"],
    &["angelicise"],
];

pub(crate) static ENTRY_ANGELIZES_17631239242244040835: VariantsMap = [
    &["angelizes"],
    &["angelises"],
    &["angelizes"],
    &["angelises"],
];

pub(crate) static ENTRY_ANGELIZE_11537726138051858659: VariantsMap =
    [&["angelize"], &["angelise"], &["angelize"], &["angelise"]];

pub(crate) static ENTRY_ANGLICANIZES_10574889558954710022: VariantsMap = [
    &["anglicanizes"],
    &["anglicanises"],
    &["anglicanizes"],
    &["anglicanises"],
];

pub(crate) static ENTRY_ANGLICANIZE_5125340706957804024: VariantsMap = [
    &["anglicanize"],
    &["anglicanise"],
    &["anglicanize"],
    &["anglicanise"],
];

pub(crate) static ENTRY_ANGLICIZATIONS_8469725992410144048: VariantsMap = [
    &["anglicizations"],
    &["anglicisations"],
    &["anglicizations"],
    &["anglicisations"],
];

pub(crate) static ENTRY_ANGLICIZATION_2983200592739510459: VariantsMap = [
    &["anglicization"],
    &["anglicisation"],
    &["anglicization"],
    &["anglicisation"],
];

pub(crate) static ENTRY_ANGLICIZED_14308195744307041473: VariantsMap = [
    &["anglicized"],
    &["anglicised"],
    &["anglicized"],
    &["anglicised"],
];

pub(crate) static ENTRY_ANGLICIZES_2840411104211976362: VariantsMap = [
    &["anglicizes"],
    &["anglicises"],
    &["anglicizes"],
    &["anglicises"],
];

pub(crate) static ENTRY_ANGLICIZE_6354255494717016366: VariantsMap = [
    &["anglicize"],
    &["anglicise"],
    &["anglicize"],
    &["anglicise"],
];

pub(crate) static ENTRY_ANGLICIZING_8410491650860737901: VariantsMap = [
    &["anglicizing"],
    &["anglicising"],
    &["anglicizing"],
    &["anglicising"],
];

pub(crate) static ENTRY_ANGRECUM_7338465098653253052: VariantsMap = [
    &["angrecum"],
    &["angraecum"],
    &["angraecum"],
    &["angraecum"],
];

pub(crate) static ENTRY_ANGULARIZATIONS_15860238483459836121: VariantsMap = [
    &["angularizations"],
    &["angularisations"],
    &["angularizations"],
    &["angularisations"],
];

pub(crate) static ENTRY_ANGULARIZATION_6898328441954759992: VariantsMap = [
    &["angularization"],
    &["angularisation"],
    &["angularization"],
    &["angularisation"],
];

pub(crate) static ENTRY_ANGULARIZES_8406976640779414831: VariantsMap = [
    &["angularizes"],
    &["angularises"],
    &["angularizes"],
    &["angularises"],
];

pub(crate) static ENTRY_ANGULARIZE_9783489444920348993: VariantsMap = [
    &["angularize"],
    &["angularise"],
    &["angularize"],
    &["angularise"],
];

pub(crate) static ENTRY_ANHEMATOPOIESIS_1868084374074707427: VariantsMap = [
    &["anhematopoiesis"],
    &["anhaematopoiesis"],
    &["anhaematopoiesis"],
    &["anhaematopoiesis"],
];

pub(crate) static ENTRY_ANHEMATOSIS_11613934029870552602: VariantsMap = [
    &["anhematosis"],
    &["anhaematosis"],
    &["anhaematosis"],
    &["anhaematosis"],
];

pub(crate) static ENTRY_ANHEMOLYTIC_11227635709932610906: VariantsMap = [
    &["anhemolytic"],
    &["anhaemolytic"],
    &["anhaemolytic"],
    &["anhaemolytic"],
];

pub(crate) static ENTRY_ANHYDREMIA_16017214998447865170: VariantsMap = [
    &["anhydremia"],
    &["anhydraemia"],
    &["anhydraemia"],
    &["anhydraemia"],
];

pub(crate) static ENTRY_ANHYDREMIC_4124925984800766575: VariantsMap = [
    &["anhydremic"],
    &["anhydraemic"],
    &["anhydraemic"],
    &["anhydraemic"],
];

pub(crate) static ENTRY_ANHYDRIDIZATIONS_155841901800213519: VariantsMap = [
    &["anhydridizations"],
    &["anhydridisations"],
    &["anhydridizations"],
    &["anhydridisations"],
];

pub(crate) static ENTRY_ANHYDRIDIZATION_6094335914661384615: VariantsMap = [
    &["anhydridization"],
    &["anhydridisation"],
    &["anhydridization"],
    &["anhydridisation"],
];

pub(crate) static ENTRY_ANHYDRIDIZES_9033438379003578734: VariantsMap = [
    &["anhydridizes"],
    &["anhydridises"],
    &["anhydridizes"],
    &["anhydridises"],
];

pub(crate) static ENTRY_ANHYDRIDIZE_14425167166852587859: VariantsMap = [
    &["anhydridize"],
    &["anhydridise"],
    &["anhydridize"],
    &["anhydridise"],
];

pub(crate) static ENTRY_ANIMALIZATIONS_15722635992002526559: VariantsMap = [
    &["animalizations"],
    &["animalisations"],
    &["animalizations"],
    &["animalisations"],
];

pub(crate) static ENTRY_ANIMALIZATION_2531195057486411112: VariantsMap = [
    &["animalization"],
    &["animalisation"],
    &["animalization"],
    &["animalisation"],
];

pub(crate) static ENTRY_ANIMALIZED_11992776700792677845: VariantsMap = [
    &["animalized"],
    &["animalised"],
    &["animalized"],
    &["animalised"],
];

pub(crate) static ENTRY_ANIMALIZES_13031030594595132678: VariantsMap = [
    &["animalizes"],
    &["animalises"],
    &["animalizes"],
    &["animalises"],
];

pub(crate) static ENTRY_ANIMALIZE_13599801917843491747: VariantsMap = [
    &["animalize"],
    &["animalise"],
    &["animalize"],
    &["animalise"],
];

pub(crate) static ENTRY_ANIMALIZING_16466913009307928576: VariantsMap = [
    &["animalizing"],
    &["animalising"],
    &["animalizing"],
    &["animalising"],
];

pub(crate) static ENTRY_ANIMIZED_15864631163138232373: VariantsMap =
    [&["animized"], &["animised"], &["animized"], &["animised"]];

pub(crate) static ENTRY_ANNALIZED_1261285051288210351: VariantsMap = [
    &["annalized"],
    &["annalised"],
    &["annalized"],
    &["annalised"],
];

pub(crate) static ENTRY_ANNALIZES_2533393763215744849: VariantsMap = [
    &["annalizes"],
    &["annalises"],
    &["annalizes"],
    &["annalises"],
];

pub(crate) static ENTRY_ANNALIZE_4021643013352928238: VariantsMap =
    [&["annalize"], &["annalise"], &["annalize"], &["annalise"]];

pub(crate) static ENTRY_ANNALIZING_17003024744448321410: VariantsMap = [
    &["annalizing"],
    &["annalising"],
    &["annalizing"],
    &["annalising"],
];

pub(crate) static ENTRY_ANNUALIZATION_1251681395381896241: VariantsMap = [
    &["annualization"],
    &["annualisation"],
    &["annualization"],
    &["annualisation"],
];

pub(crate) static ENTRY_ANNUALIZED_8158941755303657840: VariantsMap = [
    &["annualized"],
    &["annualised"],
    &["annualized"],
    &["annualised"],
];

pub(crate) static ENTRY_ANNUALIZES_3376871436090240009: VariantsMap = [
    &["annualizes"],
    &["annualises"],
    &["annualizes"],
    &["annualises"],
];

pub(crate) static ENTRY_ANNUALIZE_14357283589343884058: VariantsMap = [
    &["annualize"],
    &["annualise"],
    &["annualize"],
    &["annualise"],
];

pub(crate) static ENTRY_ANNUALIZING_14559072289548057157: VariantsMap = [
    &["annualizing"],
    &["annualising"],
    &["annualizing"],
    &["annualising"],
];

pub(crate) static ENTRY_ANODIZATION_5580158529259728238: VariantsMap = [
    &["anodization"],
    &["anodisation"],
    &["anodization"],
    &["anodisation"],
];

pub(crate) static ENTRY_ANODIZED_15907709896779053361: VariantsMap =
    [&["anodized"], &["anodised"], &["anodized"], &["anodised"]];

pub(crate) static ENTRY_ANODIZES_11959401558402485938: VariantsMap =
    [&["anodizes"], &["anodises"], &["anodizes"], &["anodises"]];

pub(crate) static ENTRY_ANODIZE_15718660927426923526: VariantsMap =
    [&["anodize"], &["anodise"], &["anodize"], &["anodise"]];

pub(crate) static ENTRY_ANODIZING_10710921135886181266: VariantsMap = [
    &["anodizing"],
    &["anodising"],
    &["anodizing"],
    &["anodising"],
];

pub(crate) static ENTRY_ANONYMIZED_4031902883171822917: VariantsMap = [
    &["anonymized"],
    &["anonymised"],
    &["anonymized"],
    &["anonymised"],
];

pub(crate) static ENTRY_ANONYMIZES_14399027189954385035: VariantsMap = [
    &["anonymizes"],
    &["anonymises"],
    &["anonymizes"],
    &["anonymises"],
];

pub(crate) static ENTRY_ANONYMIZE_5130319832346428250: VariantsMap = [
    &["anonymize"],
    &["anonymise"],
    &["anonymize"],
    &["anonymise"],
];

pub(crate) static ENTRY_ANONYMIZING_8530934326292726993: VariantsMap = [
    &["anonymizing"],
    &["anonymising"],
    &["anonymizing"],
    &["anonymising"],
];

pub(crate) static ENTRY_ANORA_15484854256215900019: VariantsMap =
    [&["anora"], &["anoura"], &["anoura"], &["anoura"]];

pub(crate) static ENTRY_ANOXEMIA_15578360103352496477: VariantsMap = [
    &["anoxemia"],
    &["anoxaemia"],
    &["anoxaemia"],
    &["anoxaemia"],
];

pub(crate) static ENTRY_ANOXEMIC_16205357930146841514: VariantsMap = [
    &["anoxemic"],
    &["anoxaemic"],
    &["anoxaemic"],
    &["anoxaemic"],
];

pub(crate) static ENTRY_ANSERINE_435108827077494119: VariantsMap = [
    &["anserine"],
    &["anserinae"],
    &["anserinae"],
    &["anserinae"],
];

pub(crate) static ENTRY_ANTAGONIZABLE_16672876007810698994: VariantsMap = [
    &["antagonizable"],
    &["antagonisable"],
    &["antagonizable"],
    &["antagonisable"],
];

pub(crate) static ENTRY_ANTAGONIZATIONS_10755990986408867749: VariantsMap = [
    &["antagonizations"],
    &["antagonisations"],
    &["antagonizations"],
    &["antagonisations"],
];

pub(crate) static ENTRY_ANTAGONIZATION_14435040696020930986: VariantsMap = [
    &["antagonization"],
    &["antagonisation"],
    &["antagonization"],
    &["antagonisation"],
];

pub(crate) static ENTRY_ANTAGONIZED_14895933622160991615: VariantsMap = [
    &["antagonized"],
    &["antagonised"],
    &["antagonized"],
    &["antagonised"],
];

pub(crate) static ENTRY_ANTAGONIZERS_18158507477094690147: VariantsMap = [
    &["antagonizers"],
    &["antagonisers"],
    &["antagonizers"],
    &["antagonisers"],
];

pub(crate) static ENTRY_ANTAGONIZER_5259834457006162974: VariantsMap = [
    &["antagonizer"],
    &["antagoniser"],
    &["antagonizer"],
    &["antagoniser"],
];

pub(crate) static ENTRY_ANTAGONIZES_10024723998796407988: VariantsMap = [
    &["antagonizes"],
    &["antagonises"],
    &["antagonizes"],
    &["antagonises"],
];

pub(crate) static ENTRY_ANTAGONIZE_9720477866642638466: VariantsMap = [
    &["antagonize"],
    &["antagonise"],
    &["antagonize"],
    &["antagonise"],
];

pub(crate) static ENTRY_ANTAGONIZING_6352128995314172485: VariantsMap = [
    &["antagonizing"],
    &["antagonising"],
    &["antagonizing"],
    &["antagonising"],
];

pub(crate) static ENTRY_ANTHECOLOGICAL_14143186251888620251: VariantsMap = [
    &["anthecological"],
    &["anthoecological"],
    &["anthoecological"],
    &["anthoecological"],
];

pub(crate) static ENTRY_ANTHECOLOGIST_6276224592804975713: VariantsMap = [
    &["anthecologist"],
    &["anthoecologist"],
    &["anthoecologist"],
    &["anthoecologist"],
];

pub(crate) static ENTRY_ANTHECOLOGY_6998050919363516872: VariantsMap = [
    &["anthecology"],
    &["anthoecology"],
    &["anthoecology"],
    &["anthoecology"],
];

pub(crate) static ENTRY_ANTHOLOGIZATION_8361206256640017140: VariantsMap = [
    &["anthologization"],
    &["anthologisation"],
    &["anthologization"],
    &["anthologisation"],
];

pub(crate) static ENTRY_ANTHOLOGIZED_13481396057773837788: VariantsMap = [
    &["anthologized"],
    &["anthologised"],
    &["anthologized"],
    &["anthologised"],
];

pub(crate) static ENTRY_ANTHOLOGIZER_11700942615035532830: VariantsMap = [
    &["anthologizer"],
    &["anthologiser"],
    &["anthologizer"],
    &["anthologiser"],
];

pub(crate) static ENTRY_ANTHOLOGIZES_3543574969907946599: VariantsMap = [
    &["anthologizes"],
    &["anthologises"],
    &["anthologizes"],
    &["anthologises"],
];

pub(crate) static ENTRY_ANTHOLOGIZE_5139724017303417861: VariantsMap = [
    &["anthologize"],
    &["anthologise"],
    &["anthologize"],
    &["anthologise"],
];

pub(crate) static ENTRY_ANTHOLOGIZING_15922251613207293395: VariantsMap = [
    &["anthologizing"],
    &["anthologising"],
    &["anthologizing"],
    &["anthologising"],
];

pub(crate) static ENTRY_ANTHRACEMIA_5581827672785610586: VariantsMap = [
    &["anthracemia"],
    &["anthracaemia"],
    &["anthracaemia"],
    &["anthracaemia"],
];

pub(crate) static ENTRY_ANTHRACITIZATIONS_4432334511743850884: VariantsMap = [
    &["anthracitizations"],
    &["anthracitisations"],
    &["anthracitizations"],
    &["anthracitisations"],
];

pub(crate) static ENTRY_ANTHRACITIZATION_18096241064786453560: VariantsMap = [
    &["anthracitization"],
    &["anthracitisation"],
    &["anthracitization"],
    &["anthracitisation"],
];

pub(crate) static ENTRY_ANTHROPOMORPHIZATIONS_14334826108508926415: VariantsMap = [
    &["anthropomorphizations"],
    &["anthropomorphisations"],
    &["anthropomorphizations"],
    &["anthropomorphisations"],
];

pub(crate) static ENTRY_ANTHROPOMORPHIZATION_1063500888938508205: VariantsMap = [
    &["anthropomorphization"],
    &["anthropomorphisation"],
    &["anthropomorphization"],
    &["anthropomorphisation"],
];

pub(crate) static ENTRY_ANTHROPOMORPHIZED_8782099582013525777: VariantsMap = [
    &["anthropomorphized"],
    &["anthropomorphised"],
    &["anthropomorphized"],
    &["anthropomorphised"],
];

pub(crate) static ENTRY_ANTHROPOMORPHIZES_11954393995572409567: VariantsMap = [
    &["anthropomorphizes"],
    &["anthropomorphises"],
    &["anthropomorphizes"],
    &["anthropomorphises"],
];

pub(crate) static ENTRY_ANTHROPOMORPHIZE_728742791191255557: VariantsMap = [
    &["anthropomorphize"],
    &["anthropomorphise"],
    &["anthropomorphize"],
    &["anthropomorphise"],
];

pub(crate) static ENTRY_ANTHROPOMORPHIZING_6013696895454427306: VariantsMap = [
    &["anthropomorphizing"],
    &["anthropomorphising"],
    &["anthropomorphizing"],
    &["anthropomorphising"],
];

pub(crate) static ENTRY_ANTICATALYZERS_18005867496802671530: VariantsMap = [
    &["anticatalyzers"],
    &["anticatalysers"],
    &["anticatalysers"],
    &["anticatalysers"],
];

pub(crate) static ENTRY_ANTICATALYZER_2403538639092256699: VariantsMap = [
    &["anticatalyzer"],
    &["anticatalyser"],
    &["anticatalyser"],
    &["anticatalyser"],
];

pub(crate) static ENTRY_ANTICENTRALIZATIONS_7326512573114353591: VariantsMap = [
    &["anticentralizations"],
    &["anticentralisations"],
    &["anticentralizations"],
    &["anticentralisations"],
];

pub(crate) static ENTRY_ANTICENTRALIZATION_6549993506754234599: VariantsMap = [
    &["anticentralization"],
    &["anticentralisation"],
    &["anticentralization"],
    &["anticentralisation"],
];

pub(crate) static ENTRY_ANTICIZES_17574516504268210900: VariantsMap = [
    &["anticizes"],
    &["anticises"],
    &["anticizes"],
    &["anticises"],
];

pub(crate) static ENTRY_ANTICIZE_16450270289032006209: VariantsMap =
    [&["anticize"], &["anticise"], &["anticize"], &["anticise"]];

pub(crate) static ENTRY_ANTIEPICENTERS_10256915121904123076: VariantsMap = [
    &["antiepicenters"],
    &["antiepicentres"],
    &["antiepicentres"],
    &["antiepicentres"],
];

pub(crate) static ENTRY_ANTIEPICENTER_3071202707801108998: VariantsMap = [
    &["antiepicenter"],
    &["antiepicentre"],
    &["antiepicentre"],
    &["antiepicentre"],
];

pub(crate) static ENTRY_ANTIFERTILIZERS_17153192306547342648: VariantsMap = [
    &["antifertilizers"],
    &["antifertilisers"],
    &["antifertilizers"],
    &["antifertilisers"],
];

pub(crate) static ENTRY_ANTIFERTILIZER_3859234925250795967: VariantsMap = [
    &["antifertilizer"],
    &["antifertiliser"],
    &["antifertilizer"],
    &["antifertiliser"],
];

pub(crate) static ENTRY_ANTILABORS_10072965400683861214: VariantsMap = [
    &["antilabors"],
    &["antilabours"],
    &["antilabours"],
    &["antilabours"],
];

pub(crate) static ENTRY_ANTILABOR_12742385227052815408: VariantsMap = [
    &["antilabor"],
    &["antilabour"],
    &["antilabour"],
    &["antilabour"],
];

pub(crate) static ENTRY_ANTILEMIC_16300171286562799216: VariantsMap = [
    &["antilemic"],
    &["antiloemic"],
    &["antiloemic"],
    &["antiloemic"],
];

pub(crate) static ENTRY_ANTIMEDIEVALISM_7738460184381908825: VariantsMap = [
    &["antimedievalism"],
    &["antimediaevalism"],
    &["antimediaevalism"],
    &["antimediaevalism"],
];

pub(crate) static ENTRY_ANTIMEDIEVALIST_3797690273319232950: VariantsMap = [
    &["antimedievalist"],
    &["antimediaevalist"],
    &["antimediaevalist"],
    &["antimediaevalist"],
];

pub(crate) static ENTRY_ANTIMEDIEVALLY_3996358009509159332: VariantsMap = [
    &["antimedievally"],
    &["antimediaevally"],
    &["antimediaevally"],
    &["antimediaevally"],
];

pub(crate) static ENTRY_ANTIMEDIEVAL_6079389628591026032: VariantsMap = [
    &["antimedieval"],
    &["antimediaeval"],
    &["antimediaeval"],
    &["antimediaeval"],
];

pub(crate) static ENTRY_ANTIOXIDIZERS_2946300150339867189: VariantsMap = [
    &["antioxidizers"],
    &["antioxidisers"],
    &["antioxidizers"],
    &["antioxidisers"],
];

pub(crate) static ENTRY_ANTIOXIDIZER_7325948835821079989: VariantsMap = [
    &["antioxidizer"],
    &["antioxidiser"],
    &["antioxidizer"],
    &["antioxidiser"],
];

pub(crate) static ENTRY_ANTIOXIDIZINGS_6563122223567194985: VariantsMap = [
    &["antioxidizings"],
    &["antioxidisings"],
    &["antioxidizings"],
    &["antioxidisings"],
];

pub(crate) static ENTRY_ANTIOXIDIZING_2990906899241132964: VariantsMap = [
    &["antioxidizing"],
    &["antioxidising"],
    &["antioxidizing"],
    &["antioxidising"],
];

pub(crate) static ENTRY_ANTIPATHIZES_8893096438995410493: VariantsMap = [
    &["antipathizes"],
    &["antipathises"],
    &["antipathizes"],
    &["antipathises"],
];

pub(crate) static ENTRY_ANTIPATHIZE_12950020852305812100: VariantsMap = [
    &["antipathize"],
    &["antipathise"],
    &["antipathize"],
    &["antipathise"],
];

pub(crate) static ENTRY_ANTIQUARIANIZES_11348524002909406554: VariantsMap = [
    &["antiquarianizes"],
    &["antiquarianises"],
    &["antiquarianizes"],
    &["antiquarianises"],
];

pub(crate) static ENTRY_ANTIQUARIANIZE_602925513374090104: VariantsMap = [
    &["antiquarianize"],
    &["antiquarianise"],
    &["antiquarianize"],
    &["antiquarianise"],
];

pub(crate) static ENTRY_ANTIRUMORS_16425512159663099108: VariantsMap = [
    &["antirumors"],
    &["antirumours"],
    &["antirumours"],
    &["antirumours"],
];

pub(crate) static ENTRY_ANTIRUMOR_17153953148157727066: VariantsMap = [
    &["antirumor"],
    &["antirumour"],
    &["antirumour"],
    &["antirumour"],
];

pub(crate) static ENTRY_ANTISENSITIZERS_16419286437564721876: VariantsMap = [
    &["antisensitizers"],
    &["antisensitisers"],
    &["antisensitizers"],
    &["antisensitisers"],
];

pub(crate) static ENTRY_ANTISENSITIZER_11650037907555957428: VariantsMap = [
    &["antisensitizer"],
    &["antisensitiser"],
    &["antisensitizer"],
    &["antisensitiser"],
];

pub(crate) static ENTRY_ANTISENSITIZES_2354288141824290441: VariantsMap = [
    &["antisensitizes"],
    &["antisensitises"],
    &["antisensitizes"],
    &["antisensitises"],
];

pub(crate) static ENTRY_ANTISENSITIZE_7315741175565562422: VariantsMap = [
    &["antisensitize"],
    &["antisensitise"],
    &["antisensitize"],
    &["antisensitise"],
];

pub(crate) static ENTRY_ANTISEPTICIZED_2520924671807636777: VariantsMap = [
    &["antisepticized"],
    &["antisepticised"],
    &["antisepticized"],
    &["antisepticised"],
];

pub(crate) static ENTRY_ANTISEPTICIZES_12007907144201220689: VariantsMap = [
    &["antisepticizes"],
    &["antisepticises"],
    &["antisepticizes"],
    &["antisepticises"],
];

pub(crate) static ENTRY_ANTISEPTICIZE_17211450201235074915: VariantsMap = [
    &["antisepticize"],
    &["antisepticise"],
    &["antisepticize"],
    &["antisepticise"],
];

pub(crate) static ENTRY_ANTISEPTICIZING_14355477724725995699: VariantsMap = [
    &["antisepticizing"],
    &["antisepticising"],
    &["antisepticizing"],
    &["antisepticising"],
];

pub(crate) static ENTRY_ANTISEPTIZES_5945136746946853006: VariantsMap = [
    &["antiseptizes"],
    &["antiseptises"],
    &["antiseptizes"],
    &["antiseptises"],
];

pub(crate) static ENTRY_ANTISEPTIZE_9636461595861649823: VariantsMap = [
    &["antiseptize"],
    &["antiseptise"],
    &["antiseptize"],
    &["antiseptise"],
];

pub(crate) static ENTRY_ANTISIPHONS_3704945021028588018: VariantsMap = [
    &["antisiphons"],
    &["antisyphons"],
    &["antisyphons"],
    &["antisyphons"],
];

pub(crate) static ENTRY_ANTISIPHON_339236546432716601: VariantsMap = [
    &["antisiphon"],
    &["antisyphon"],
    &["antisyphon"],
    &["antisyphon"],
];

pub(crate) static ENTRY_ANTITHESIZES_15419652955343816662: VariantsMap = [
    &["antithesizes"],
    &["antithesises"],
    &["antithesizes"],
    &["antithesises"],
];

pub(crate) static ENTRY_ANTITHESIZE_1058411346936412929: VariantsMap = [
    &["antithesize"],
    &["antithesise"],
    &["antithesize"],
    &["antithesise"],
];

pub(crate) static ENTRY_ANVILED_10560128408729337292: VariantsMap =
    [&["anviled"], &["anvilled"], &["anvilled"], &["anvilled"]];

pub(crate) static ENTRY_ANVILING_7433811405855295219: VariantsMap = [
    &["anviling"],
    &["anvilling"],
    &["anvilling"],
    &["anvilling"],
];

pub(crate) static ENTRY_APESTHESIA_4947771205873763300: VariantsMap = [
    &["apesthesia"],
    &["apaesthesia"],
    &["apaesthesia"],
    &["apaesthesia"],
];

pub(crate) static ENTRY_APESTHETIC_12430802871942423809: VariantsMap = [
    &["apesthetic"],
    &["apaesthetic"],
    &["apaesthetic"],
    &["apaesthetic"],
];

pub(crate) static ENTRY_APHERESES_8414108081771472699: VariantsMap = [
    &["aphereses"],
    &["aphaereses"],
    &["aphaereses"],
    &["aphaereses"],
];

pub(crate) static ENTRY_APHERESIS_11100589747263615656: VariantsMap = [
    &["apheresis"],
    &["aphaeresis"],
    &["aphaeresis"],
    &["aphaeresis"],
];

pub(crate) static ENTRY_APHERETIC_14208620861385679102: VariantsMap = [
    &["apheretic"],
    &["aphaeretic"],
    &["aphaeretic"],
    &["aphaeretic"],
];

pub(crate) static ENTRY_APHETIZED_1858899614002657210: VariantsMap = [
    &["aphetized"],
    &["aphetised"],
    &["aphetized"],
    &["aphetised"],
];

pub(crate) static ENTRY_APHETIZES_2606887081258860354: VariantsMap = [
    &["aphetizes"],
    &["aphetises"],
    &["aphetizes"],
    &["aphetises"],
];

pub(crate) static ENTRY_APHETIZE_16986882047083146683: VariantsMap =
    [&["aphetize"], &["aphetise"], &["aphetize"], &["aphetise"]];

pub(crate) static ENTRY_APHETIZING_18044502082485150756: VariantsMap = [
    &["aphetizing"],
    &["aphetising"],
    &["aphetizing"],
    &["aphetising"],
];

pub(crate) static ENTRY_APHORIZED_10249942663715046169: VariantsMap = [
    &["aphorized"],
    &["aphorised"],
    &["aphorized"],
    &["aphorised"],
];

pub(crate) static ENTRY_APHORIZERS_6227464678729995966: VariantsMap = [
    &["aphorizers"],
    &["aphorisers"],
    &["aphorizers"],
    &["aphorisers"],
];

pub(crate) static ENTRY_APHORIZER_8971366374709723247: VariantsMap = [
    &["aphorizer"],
    &["aphoriser"],
    &["aphorizer"],
    &["aphoriser"],
];

pub(crate) static ENTRY_APHORIZES_16282592296354062486: VariantsMap = [
    &["aphorizes"],
    &["aphorises"],
    &["aphorizes"],
    &["aphorises"],
];

pub(crate) static ENTRY_APHORIZE_17513005870741888985: VariantsMap =
    [&["aphorize"], &["aphorise"], &["aphorize"], &["aphorise"]];

pub(crate) static ENTRY_APHORIZING_8622079489862524646: VariantsMap = [
    &["aphorizing"],
    &["aphorising"],
    &["aphorizing"],
    &["aphorising"],
];

pub(crate) static ENTRY_APNEAL_7893743730769229693: VariantsMap =
    [&["apneal"], &["apnoeal"], &["apnoeal"], &["apnoeal"]];

pub(crate) static ENTRY_APNEAS_2550899720378134826: VariantsMap =
    [&["apneas"], &["apnoeas"], &["apneas"], &["apnoeas"]];

pub(crate) static ENTRY_APNEA_6406034786678842123: VariantsMap =
    [&["apnea"], &["apnoea"], &["apnea"], &["apnoea"]];

pub(crate) static ENTRY_APNEIC_11719839066153327453: VariantsMap =
    [&["apneic"], &["apnoeic"], &["apnoeic"], &["apnoeic"]];

pub(crate) static ENTRY_APOCENTER_11458252478295656911: VariantsMap = [
    &["apocenter"],
    &["apocentre"],
    &["apocentre"],
    &["apocentre"],
];

pub(crate) static ENTRY_APOGEIC_16938772067630214391: VariantsMap =
    [&["apogeic"], &["apogaeic"], &["apogaeic"], &["apogaeic"]];

pub(crate) static ENTRY_APOLOGIZED_3547075355470705991: VariantsMap = [
    &["apologized"],
    &["apologised"],
    &["apologized"],
    &["apologised"],
];

pub(crate) static ENTRY_APOLOGIZERS_13562651563373661330: VariantsMap = [
    &["apologizers"],
    &["apologisers"],
    &["apologizers"],
    &["apologisers"],
];

pub(crate) static ENTRY_APOLOGIZER_4129656303394632071: VariantsMap = [
    &["apologizer"],
    &["apologiser"],
    &["apologizer"],
    &["apologiser"],
];

pub(crate) static ENTRY_APOLOGIZES_13345357472753740063: VariantsMap = [
    &["apologizes"],
    &["apologises"],
    &["apologizes"],
    &["apologises"],
];

pub(crate) static ENTRY_APOLOGIZE_14449570546795754812: VariantsMap = [
    &["apologize"],
    &["apologise"],
    &["apologize"],
    &["apologise"],
];

pub(crate) static ENTRY_APOLOGIZING_16657477641936872991: VariantsMap = [
    &["apologizing"],
    &["apologising"],
    &["apologizing"],
    &["apologising"],
];

pub(crate) static ENTRY_APOPHTHEGMATIZED_15838142809164915173: VariantsMap = [
    &["apophthegmatized"],
    &["apophthegmatised"],
    &["apophthegmatized"],
    &["apophthegmatised"],
];

pub(crate) static ENTRY_APOPHTHEGMATIZES_2288182367019688298: VariantsMap = [
    &["apophthegmatizes"],
    &["apophthegmatises"],
    &["apophthegmatizes"],
    &["apophthegmatises"],
];

pub(crate) static ENTRY_APOPHTHEGMATIZE_9322689570481861709: VariantsMap = [
    &["apophthegmatize"],
    &["apophthegmatise"],
    &["apophthegmatize"],
    &["apophthegmatise"],
];

pub(crate) static ENTRY_APOPHTHEGMATIZING_14335129275871173969: VariantsMap = [
    &["apophthegmatizing"],
    &["apophthegmatising"],
    &["apophthegmatizing"],
    &["apophthegmatising"],
];

pub(crate) static ENTRY_APORRHEA_13505526801378634820: VariantsMap = [
    &["aporrhea"],
    &["aporrhoea"],
    &["aporrhoea"],
    &["aporrhoea"],
];

pub(crate) static ENTRY_APOSTATIZATION_1527034887052638394: VariantsMap = [
    &["apostatization"],
    &["apostatisation"],
    &["apostatization"],
    &["apostatisation"],
];

pub(crate) static ENTRY_APOSTATIZED_44225222340281598: VariantsMap = [
    &["apostatized"],
    &["apostatised"],
    &["apostatized"],
    &["apostatised"],
];

pub(crate) static ENTRY_APOSTATIZES_10706409261795785069: VariantsMap = [
    &["apostatizes"],
    &["apostatises"],
    &["apostatizes"],
    &["apostatises"],
];

pub(crate) static ENTRY_APOSTATIZE_13080506949193574486: VariantsMap = [
    &["apostatize"],
    &["apostatise"],
    &["apostatize"],
    &["apostatise"],
];

pub(crate) static ENTRY_APOSTATIZING_18253376445779049751: VariantsMap = [
    &["apostatizing"],
    &["apostatising"],
    &["apostatizing"],
    &["apostatising"],
];

pub(crate) static ENTRY_APOSTOLIZED_12140472803938774313: VariantsMap = [
    &["apostolized"],
    &["apostolised"],
    &["apostolized"],
    &["apostolised"],
];

pub(crate) static ENTRY_APOSTOLIZES_10959422959941305594: VariantsMap = [
    &["apostolizes"],
    &["apostolises"],
    &["apostolizes"],
    &["apostolises"],
];

pub(crate) static ENTRY_APOSTOLIZE_16199580758148929809: VariantsMap = [
    &["apostolize"],
    &["apostolise"],
    &["apostolize"],
    &["apostolise"],
];

pub(crate) static ENTRY_APOSTOLIZING_1815559841608331448: VariantsMap = [
    &["apostolizing"],
    &["apostolising"],
    &["apostolizing"],
    &["apostolising"],
];

pub(crate) static ENTRY_APOSTROPHIZED_10611323756896254538: VariantsMap = [
    &["apostrophized"],
    &["apostrophised"],
    &["apostrophized"],
    &["apostrophised"],
];

pub(crate) static ENTRY_APOSTROPHIZES_14704113907193101943: VariantsMap = [
    &["apostrophizes"],
    &["apostrophises"],
    &["apostrophizes"],
    &["apostrophises"],
];

pub(crate) static ENTRY_APOSTROPHIZE_17888463482112539780: VariantsMap = [
    &["apostrophize"],
    &["apostrophise"],
    &["apostrophize"],
    &["apostrophise"],
];

pub(crate) static ENTRY_APOSTROPHIZING_5813087553114165636: VariantsMap = [
    &["apostrophizing"],
    &["apostrophising"],
    &["apostrophizing"],
    &["apostrophising"],
];

pub(crate) static ENTRY_APOTHEGMATIZED_11678983898765728976: VariantsMap = [
    &["apothegmatized"],
    &["apothegmatised"],
    &["apothegmatized"],
    &["apothegmatised"],
];

pub(crate) static ENTRY_APOTHEGMATIZES_6292798390810092901: VariantsMap = [
    &["apothegmatizes"],
    &["apothegmatises"],
    &["apothegmatizes"],
    &["apothegmatises"],
];

pub(crate) static ENTRY_APOTHEGMATIZE_15318646925264020123: VariantsMap = [
    &["apothegmatize"],
    &["apothegmatise"],
    &["apothegmatize"],
    &["apothegmatise"],
];

pub(crate) static ENTRY_APOTHEGMATIZING_10622191304514739480: VariantsMap = [
    &["apothegmatizing"],
    &["apothegmatising"],
    &["apothegmatizing"],
    &["apothegmatising"],
];

pub(crate) static ENTRY_APOTHEOSIZED_8172850542068614358: VariantsMap = [
    &["apotheosized"],
    &["apotheosised"],
    &["apotheosized"],
    &["apotheosised"],
];

pub(crate) static ENTRY_APOTHEOSIZES_3324551187478048042: VariantsMap = [
    &["apotheosizes"],
    &["apotheosises"],
    &["apotheosizes"],
    &["apotheosises"],
];

pub(crate) static ENTRY_APOTHEOSIZE_6351046197862617198: VariantsMap = [
    &["apotheosize"],
    &["apotheosise"],
    &["apotheosize"],
    &["apotheosise"],
];

pub(crate) static ENTRY_APOTHEOSIZING_10080445523181927742: VariantsMap = [
    &["apotheosizing"],
    &["apotheosising"],
    &["apotheosizing"],
    &["apotheosising"],
];

pub(crate) static ENTRY_APPALLS_14971304364498187153: VariantsMap =
    [&["appalls"], &["appals"], &["appalls"], &["appals"]];

pub(crate) static ENTRY_APPALL_3381232000687374522: VariantsMap =
    [&["appall"], &["appal"], &["appall"], &["appal"]];

pub(crate) static ENTRY_APPARELED_5914262035984071991: VariantsMap = [
    &["appareled"],
    &["apparelled"],
    &["apparelled"],
    &["apparelled"],
];

pub(crate) static ENTRY_APPARELING_11650623594673700867: VariantsMap = [
    &["appareling"],
    &["apparelling"],
    &["apparelling"],
    &["apparelling"],
];

pub(crate) static ENTRY_APPETIZED_12779274256898682576: VariantsMap = [
    &["appetized"],
    &["appetised"],
    &["appetized"],
    &["appetised"],
];

pub(crate) static ENTRY_APPETIZEMENTS_5259246039149445790: VariantsMap = [
    &["appetizements"],
    &["appetisements"],
    &["appetizements"],
    &["appetisements"],
];

pub(crate) static ENTRY_APPETIZEMENT_8175094878206216152: VariantsMap = [
    &["appetizement"],
    &["appetisement"],
    &["appetizement"],
    &["appetisement"],
];

pub(crate) static ENTRY_APPETIZERS_5843282302692262805: VariantsMap = [
    &["appetizers"],
    &["appetisers"],
    &["appetizers"],
    &["appetisers"],
];

pub(crate) static ENTRY_APPETIZER_8559355853918389374: VariantsMap = [
    &["appetizer"],
    &["appetiser"],
    &["appetizer"],
    &["appetiser"],
];

pub(crate) static ENTRY_APPETIZES_14250778261697102866: VariantsMap = [
    &["appetizes"],
    &["appetises"],
    &["appetizes"],
    &["appetises"],
];

pub(crate) static ENTRY_APPETIZE_12214870214458995398: VariantsMap =
    [&["appetize"], &["appetise"], &["appetize"], &["appetise"]];

pub(crate) static ENTRY_APPETIZINGLY_9913312311160671376: VariantsMap = [
    &["appetizingly"],
    &["appetisingly"],
    &["appetizingly"],
    &["appetisingly"],
];

pub(crate) static ENTRY_APPETIZING_3391416091007273367: VariantsMap = [
    &["appetizing"],
    &["appetising"],
    &["appetizing"],
    &["appetising"],
];

pub(crate) static ENTRY_APPRIZAL_3560063918703465624: VariantsMap =
    [&["apprizal"], &["apprisal"], &["apprizal"], &["apprisal"]];

pub(crate) static ENTRY_APPRIZED_15906383243546321609: VariantsMap =
    [&["apprized"], &["apprised"], &["apprized"], &["apprised"]];

pub(crate) static ENTRY_APPRIZERS_15195711748329559838: VariantsMap = [
    &["apprizers"],
    &["apprisers"],
    &["apprizers"],
    &["apprisers"],
];

pub(crate) static ENTRY_APPRIZER_18426176719486326401: VariantsMap =
    [&["apprizer"], &["appriser"], &["apprizer"], &["appriser"]];

pub(crate) static ENTRY_APPRIZES_16502352422245789053: VariantsMap =
    [&["apprizes"], &["apprises"], &["apprizes"], &["apprises"]];

pub(crate) static ENTRY_APPRIZE_2772227233704893376: VariantsMap =
    [&["apprize"], &["apprise"], &["apprize"], &["apprise"]];

pub(crate) static ENTRY_APPRIZINGS_6514643279295543384: VariantsMap = [
    &["apprizings"],
    &["apprisings"],
    &["apprizings"],
    &["apprisings"],
];

pub(crate) static ENTRY_APPRIZING_12688699470215267857: VariantsMap = [
    &["apprizing"],
    &["apprising"],
    &["apprizing"],
    &["apprising"],
];

pub(crate) static ENTRY_ARABIANIZES_15399320604140902223: VariantsMap = [
    &["arabianizes"],
    &["arabianises"],
    &["arabianizes"],
    &["arabianises"],
];

pub(crate) static ENTRY_ARABIANIZE_14680629114410755510: VariantsMap = [
    &["arabianize"],
    &["arabianise"],
    &["arabianize"],
    &["arabianise"],
];

pub(crate) static ENTRY_ARABICIZES_7961526175874963709: VariantsMap = [
    &["arabicizes"],
    &["arabicises"],
    &["arabicizes"],
    &["arabicises"],
];

pub(crate) static ENTRY_ARABICIZE_9338400257314658821: VariantsMap = [
    &["arabicize"],
    &["arabicise"],
    &["arabicize"],
    &["arabicise"],
];

pub(crate) static ENTRY_ARABIZATIONS_7991225374353590906: VariantsMap = [
    &["arabizations"],
    &["arabisations"],
    &["arabizations"],
    &["arabisations"],
];

pub(crate) static ENTRY_ARABIZATION_471491823646004633: VariantsMap = [
    &["arabization"],
    &["arabisation"],
    &["arabization"],
    &["arabisation"],
];

pub(crate) static ENTRY_ARABIZED_12134857612665569800: VariantsMap =
    [&["arabized"], &["arabised"], &["arabized"], &["arabised"]];

pub(crate) static ENTRY_ARABIZES_4001226046137904360: VariantsMap =
    [&["arabizes"], &["arabises"], &["arabizes"], &["arabises"]];

pub(crate) static ENTRY_ARABIZE_13835410304137115221: VariantsMap =
    [&["arabize"], &["arabise"], &["arabize"], &["arabise"]];

pub(crate) static ENTRY_ARABIZING_209764483654246227: VariantsMap = [
    &["arabizing"],
    &["arabising"],
    &["arabizing"],
    &["arabising"],
];

pub(crate) static ENTRY_ARAMEANS_5599443395276229615: VariantsMap = [
    &["arameans"],
    &["aramaeans"],
    &["aramaeans"],
    &["aramaeans"],
];

pub(crate) static ENTRY_ARAMEAN_8841768638879589571: VariantsMap =
    [&["aramean"], &["aramaean"], &["aramaean"], &["aramaean"]];

pub(crate) static ENTRY_ARBALESTER_6838431227178078005: VariantsMap = [
    &["arbalester"],
    &["arbalestre"],
    &["arbalestre"],
    &["arbalestre"],
];

pub(crate) static ENTRY_ARBORED_9841319088226677951: VariantsMap =
    [&["arbored"], &["arboured"], &["arboured"], &["arboured"]];

pub(crate) static ENTRY_ARBORES_15360373317740002388: VariantsMap =
    [&["arbores"], &["arboures"], &["arboures"], &["arboures"]];

pub(crate) static ENTRY_ARBORIZATIONS_4188589807836256359: VariantsMap = [
    &["arborizations"],
    &["arborisations"],
    &["arborizations"],
    &["arborisations"],
];

pub(crate) static ENTRY_ARBORIZATION_15816140615041238184: VariantsMap = [
    &["arborization"],
    &["arborisation"],
    &["arborization"],
    &["arborisation"],
];

pub(crate) static ENTRY_ARBORIZED_13640543823605553558: VariantsMap = [
    &["arborized"],
    &["arborised"],
    &["arborized"],
    &["arborised"],
];

pub(crate) static ENTRY_ARBORIZES_3017079272082009873: VariantsMap = [
    &["arborizes"],
    &["arborises"],
    &["arborizes"],
    &["arborises"],
];

pub(crate) static ENTRY_ARBORIZE_141711185842618556: VariantsMap =
    [&["arborize"], &["arborise"], &["arborize"], &["arborise"]];

pub(crate) static ENTRY_ARBORIZING_5466669619685035391: VariantsMap = [
    &["arborizing"],
    &["arborising"],
    &["arborizing"],
    &["arborising"],
];

pub(crate) static ENTRY_ARBORS_2769870038356325080: VariantsMap =
    [&["arbors"], &["arbours"], &["arbours"], &["arbours"]];

pub(crate) static ENTRY_ARBOR_820303798692032572: VariantsMap =
    [&["arbor"], &["arbour"], &["arbour"], &["arbour"]];

pub(crate) static ENTRY_ARCHAEOLOGICAL_10563432210833298458: VariantsMap = [
    &["archaeological"],
    &["archaeological"],
    &["archaeological"],
    &["archaeological"],
];

pub(crate) static ENTRY_ARCHAEOLOGIC_175348203002056666: VariantsMap = [
    &["archaeologic"],
    &["archaeologic"],
    &["archaeologic"],
    &["archaeologic"],
];

pub(crate) static ENTRY_ARCHAEOLOGIES_8039431778163772974: VariantsMap = [
    &["archaeologies"],
    &["archaeologies"],
    &["archaeologies"],
    &["archaeologies"],
];

pub(crate) static ENTRY_ARCHAEOLOGISTS_15763944587883983376: VariantsMap = [
    &["archaeologists"],
    &["archaeologists"],
    &["archaeologists"],
    &["archaeologists"],
];

pub(crate) static ENTRY_ARCHAEOLOGIST_12712686763317819627: VariantsMap = [
    &["archaeologist"],
    &["archaeologist"],
    &["archaeologist"],
    &["archaeologist"],
];

pub(crate) static ENTRY_ARCHAEOLOGY_10452692803395720100: VariantsMap = [
    &["archaeology"],
    &["archaeology"],
    &["archaeology"],
    &["archaeology"],
];

pub(crate) static ENTRY_ARCHAIZED_17502443965255232728: VariantsMap = [
    &["archaized"],
    &["archaised"],
    &["archaized"],
    &["archaised"],
];

pub(crate) static ENTRY_ARCHAIZERS_11861316159781209222: VariantsMap = [
    &["archaizers"],
    &["archaisers"],
    &["archaizers"],
    &["archaisers"],
];

pub(crate) static ENTRY_ARCHAIZER_5219609326176256547: VariantsMap = [
    &["archaizer"],
    &["archaiser"],
    &["archaizer"],
    &["archaiser"],
];

pub(crate) static ENTRY_ARCHAIZES_3289069090284787945: VariantsMap = [
    &["archaizes"],
    &["archaises"],
    &["archaizes"],
    &["archaises"],
];

pub(crate) static ENTRY_ARCHAIZE_306453875004862597: VariantsMap =
    [&["archaize"], &["archaise"], &["archaize"], &["archaise"]];

pub(crate) static ENTRY_ARCHAIZING_3514060218818847476: VariantsMap = [
    &["archaizing"],
    &["archaising"],
    &["archaizing"],
    &["archaising"],
];

pub(crate) static ENTRY_ARCHEAL_13572196168963327074: VariantsMap =
    [&["archeal"], &["archaeal"], &["archaeal"], &["archaeal"]];

pub(crate) static ENTRY_ARCHEAN_937087822525818400: VariantsMap =
    [&["archean"], &["archaean"], &["archaean"], &["archaean"]];

pub(crate) static ENTRY_ARCHEI_13567272772083540797: VariantsMap =
    [&["archei"], &["archaei"], &["archaei"], &["archaei"]];

pub(crate) static ENTRY_ARCHEOASTRONOMIES_3188854482470694849: VariantsMap = [
    &["archeoastronomies"],
    &["archaeoastronomies"],
    &["archaeoastronomies"],
    &["archaeoastronomies"],
];

pub(crate) static ENTRY_ARCHEOASTRONOMY_14404673011142855883: VariantsMap = [
    &["archeoastronomy"],
    &["archaeoastronomy"],
    &["archaeoastronomy"],
    &["archaeoastronomy"],
];

pub(crate) static ENTRY_ARCHEOCYTE_6518656963202380847: VariantsMap = [
    &["archeocyte"],
    &["archaeocyte"],
    &["archaeocyte"],
    &["archaeocyte"],
];

pub(crate) static ENTRY_ARCHEOLITHIC_13669598449916969809: VariantsMap = [
    &["archeolithic"],
    &["archaeolithic"],
    &["archaeolithic"],
    &["archaeolithic"],
];

pub(crate) static ENTRY_ARCHEOLOGIAN_7486816702727031922: VariantsMap = [
    &["archeologian"],
    &["archaeologian"],
    &["archaeologian"],
    &["archaeologian"],
];

pub(crate) static ENTRY_ARCHEOL_1850162685385094711: VariantsMap =
    [&["archeol"], &["archaeol"], &["archaeol"], &["archaeol"]];

pub(crate) static ENTRY_ARCHEOMETRIES_18248570031046455194: VariantsMap = [
    &["archeometries"],
    &["archaeometries"],
    &["archaeometries"],
    &["archaeometries"],
];

pub(crate) static ENTRY_ARCHEOMETRY_11263439246356993945: VariantsMap = [
    &["archeometry"],
    &["archaeometry"],
    &["archaeometry"],
    &["archaeometry"],
];

pub(crate) static ENTRY_ARCHEOZIC_6812126952578611645: VariantsMap = [
    &["archeozic"],
    &["archaeozic"],
    &["archaeozic"],
    &["archaeozic"],
];

pub(crate) static ENTRY_ARCHEOZOIC_12688097476418777680: VariantsMap = [
    &["archeozoic"],
    &["archaeozoic"],
    &["archaeozoic"],
    &["archaeozoic"],
];

pub(crate) static ENTRY_ARCHEUS_1712692449173846724: VariantsMap =
    [&["archeus"], &["archaeus"], &["archaeus"], &["archaeus"]];

pub(crate) static ENTRY_ARCHE_18301530557274881676: VariantsMap =
    [&["arche"], &["archae"], &["archae"], &["archae"]];

pub(crate) static ENTRY_ARCTICIZES_9212958491318640697: VariantsMap = [
    &["arcticizes"],
    &["arcticises"],
    &["arcticizes"],
    &["arcticises"],
];

pub(crate) static ENTRY_ARCTICIZE_6133925135946423979: VariantsMap = [
    &["arcticize"],
    &["arcticise"],
    &["arcticize"],
    &["arcticise"],
];

pub(crate) static ENTRY_ARCTOGEAN_3817144683623578243: VariantsMap = [
    &["arctogean"],
    &["arctogaean"],
    &["arctogaean"],
    &["arctogaean"],
];

pub(crate) static ENTRY_ARCTOGEA_7460167982401069798: VariantsMap = [
    &["arctogea"],
    &["arctogaea"],
    &["arctogaea"],
    &["arctogaea"],
];

pub(crate) static ENTRY_ARCTOGEIC_6444012158676125424: VariantsMap = [
    &["arctogeic"],
    &["arctogaeic"],
    &["arctogaeic"],
    &["arctogaeic"],
];

pub(crate) static ENTRY_ARDORS_3754540775895817864: VariantsMap =
    [&["ardors"], &["ardours"], &["ardours"], &["ardours"]];

pub(crate) static ENTRY_ARDOR_14403534690593993712: VariantsMap =
    [&["ardor"], &["ardour"], &["ardour"], &["ardour"]];

pub(crate) static ENTRY_ARENICOLOR_5592467329818263804: VariantsMap = [
    &["arenicolor"],
    &["arenicolour"],
    &["arenicolour"],
    &["arenicolour"],
];

pub(crate) static ENTRY_AREOLE_1506224537716675700: VariantsMap =
    [&["areole"], &["areolae"], &["areolae"], &["areolae"]];

pub(crate) static ENTRY_AREOMETRICAL_5744079483158577745: VariantsMap = [
    &["areometrical"],
    &["araeometrical"],
    &["araeometrical"],
    &["araeometrical"],
];

pub(crate) static ENTRY_AREOMETRIC_5287406644094522168: VariantsMap = [
    &["areometric"],
    &["araeometric"],
    &["araeometric"],
    &["araeometric"],
];

pub(crate) static ENTRY_AREOSTYLES_813590045775141111: VariantsMap = [
    &["areostyles"],
    &["araeostyles"],
    &["araeostyles"],
    &["araeostyles"],
];

pub(crate) static ENTRY_AREOSTYLE_11631549334090315083: VariantsMap = [
    &["areostyle"],
    &["araeostyle"],
    &["araeostyle"],
    &["araeostyle"],
];

pub(crate) static ENTRY_AREOSYSTYLE_15780594127227324055: VariantsMap = [
    &["areosystyle"],
    &["araeosystyle"],
    &["araeosystyle"],
    &["araeosystyle"],
];

pub(crate) static ENTRY_ARIANIZED_13031592665042016626: VariantsMap = [
    &["arianized"],
    &["arianised"],
    &["arianized"],
    &["arianised"],
];

pub(crate) static ENTRY_ARIANIZES_10045790284059712906: VariantsMap = [
    &["arianizes"],
    &["arianises"],
    &["arianizes"],
    &["arianises"],
];

pub(crate) static ENTRY_ARIANIZE_132906611228004832: VariantsMap =
    [&["arianize"], &["arianise"], &["arianize"], &["arianise"]];

pub(crate) static ENTRY_ARIANIZING_8099459434965318815: VariantsMap = [
    &["arianizing"],
    &["arianising"],
    &["arianizing"],
    &["arianising"],
];

pub(crate) static ENTRY_ARIMATHEAN_18132742646935014444: VariantsMap = [
    &["arimathean"],
    &["arimathaean"],
    &["arimathaean"],
    &["arimathaean"],
];

pub(crate) static ENTRY_ARIMATHEA_4355699317638704668: VariantsMap = [
    &["arimathea"],
    &["arimathaea"],
    &["arimathaea"],
    &["arimathaea"],
];

pub(crate) static ENTRY_ARISTE_13211696162410295795: VariantsMap =
    [&["ariste"], &["aristae"], &["aristae"], &["aristae"]];

pub(crate) static ENTRY_ARITHMETIZATIONS_11414688757734327435: VariantsMap = [
    &["arithmetizations"],
    &["arithmetisations"],
    &["arithmetizations"],
    &["arithmetisations"],
];

pub(crate) static ENTRY_ARITHMETIZATION_15007145642640225991: VariantsMap = [
    &["arithmetization"],
    &["arithmetisation"],
    &["arithmetization"],
    &["arithmetisation"],
];

pub(crate) static ENTRY_ARITHMETIZED_3086309834161067134: VariantsMap = [
    &["arithmetized"],
    &["arithmetised"],
    &["arithmetized"],
    &["arithmetised"],
];

pub(crate) static ENTRY_ARITHMETIZES_4861809149355233475: VariantsMap = [
    &["arithmetizes"],
    &["arithmetises"],
    &["arithmetizes"],
    &["arithmetises"],
];

pub(crate) static ENTRY_ARITHMETIZE_1188073595390850037: VariantsMap = [
    &["arithmetize"],
    &["arithmetise"],
    &["arithmetize"],
    &["arithmetise"],
];

pub(crate) static ENTRY_ARMORBEARER_1318126373750206677: VariantsMap = [
    &["armorbearer"],
    &["armourbearer"],
    &["armourbearer"],
    &["armourbearer"],
];

pub(crate) static ENTRY_ARMORED_214663291627156832: VariantsMap =
    [&["armored"], &["armoured"], &["armoured"], &["armoured"]];

pub(crate) static ENTRY_ARMORERS_15576792766558527660: VariantsMap = [
    &["armorers"],
    &["armourers"],
    &["armourers"],
    &["armourers"],
];

pub(crate) static ENTRY_ARMORER_15410308267945880573: VariantsMap =
    [&["armorer"], &["armourer"], &["armourer"], &["armourer"]];

pub(crate) static ENTRY_ARMORIED_13916682178209009712: VariantsMap = [
    &["armoried"],
    &["armouried"],
    &["armouried"],
    &["armouried"],
];

pub(crate) static ENTRY_ARMORIES_338319230858200174: VariantsMap = [
    &["armories"],
    &["armouries"],
    &["armouries"],
    &["armouries"],
];

pub(crate) static ENTRY_ARMORING_10102011884001661988: VariantsMap = [
    &["armoring"],
    &["armouring"],
    &["armouring"],
    &["armouring"],
];

pub(crate) static ENTRY_ARMORLESS_3900174637867577616: VariantsMap = [
    &["armorless"],
    &["armourless"],
    &["armourless"],
    &["armourless"],
];

pub(crate) static ENTRY_ARMORS_14520485620428417155: VariantsMap =
    [&["armors"], &["armours"], &["armours"], &["armours"]];

pub(crate) static ENTRY_ARMORY_13479680231027438950: VariantsMap =
    [&["armory"], &["armoury"], &["armoury"], &["armoury"]];

pub(crate) static ENTRY_ARMOR_4945447914484381803: VariantsMap =
    [&["armor"], &["armour"], &["armour"], &["armour"]];

pub(crate) static ENTRY_AROMATITE_10237287526340905609: VariantsMap = [
    &["aromatite"],
    &["aromatitae"],
    &["aromatitae"],
    &["aromatitae"],
];

pub(crate) static ENTRY_AROMATIZATION_5370295794385992127: VariantsMap = [
    &["aromatization"],
    &["aromatisation"],
    &["aromatization"],
    &["aromatisation"],
];

pub(crate) static ENTRY_AROMATIZED_5000984731968850520: VariantsMap = [
    &["aromatized"],
    &["aromatised"],
    &["aromatized"],
    &["aromatised"],
];

pub(crate) static ENTRY_AROMATIZER_15090680470059619273: VariantsMap = [
    &["aromatizer"],
    &["aromatiser"],
    &["aromatizer"],
    &["aromatiser"],
];

pub(crate) static ENTRY_AROMATIZES_11882880046820259901: VariantsMap = [
    &["aromatizes"],
    &["aromatises"],
    &["aromatizes"],
    &["aromatises"],
];

pub(crate) static ENTRY_AROMATIZE_17577690372454585657: VariantsMap = [
    &["aromatize"],
    &["aromatise"],
    &["aromatize"],
    &["aromatise"],
];

pub(crate) static ENTRY_AROMATIZING_12161529232297358732: VariantsMap = [
    &["aromatizing"],
    &["aromatising"],
    &["aromatizing"],
    &["aromatising"],
];

pub(crate) static ENTRY_ARSENICIZES_3348853831535691299: VariantsMap = [
    &["arsenicizes"],
    &["arsenicises"],
    &["arsenicizes"],
    &["arsenicises"],
];

pub(crate) static ENTRY_ARSENICIZE_15746363128967248584: VariantsMap = [
    &["arsenicize"],
    &["arsenicise"],
    &["arsenicize"],
    &["arsenicise"],
];

pub(crate) static ENTRY_ARSINOE_10666641887026095173: VariantsMap =
    [&["arsinoe"], &["arsinoae"], &["arsinoae"], &["arsinoae"]];

pub(crate) static ENTRY_ARTERIALIZATIONS_14137202706840549747: VariantsMap = [
    &["arterializations"],
    &["arterialisations"],
    &["arterializations"],
    &["arterialisations"],
];

pub(crate) static ENTRY_ARTERIALIZATION_12220214490626585223: VariantsMap = [
    &["arterialization"],
    &["arterialisation"],
    &["arterialization"],
    &["arterialisation"],
];

pub(crate) static ENTRY_ARTERIALIZED_13112994890988388396: VariantsMap = [
    &["arterialized"],
    &["arterialised"],
    &["arterialized"],
    &["arterialised"],
];

pub(crate) static ENTRY_ARTERIALIZES_17367277747015913948: VariantsMap = [
    &["arterializes"],
    &["arterialises"],
    &["arterializes"],
    &["arterialises"],
];

pub(crate) static ENTRY_ARTERIALIZE_160821330242474661: VariantsMap = [
    &["arterialize"],
    &["arterialise"],
    &["arterialize"],
    &["arterialise"],
];

pub(crate) static ENTRY_ARTERIALIZING_12599986629846293545: VariantsMap = [
    &["arterializing"],
    &["arterialising"],
    &["arterializing"],
    &["arterialising"],
];

pub(crate) static ENTRY_ARTHREMPYESIS_7196745531112428566: VariantsMap = [
    &["arthrempyesis"],
    &["arthroempyesis"],
    &["arthroempyesis"],
    &["arthroempyesis"],
];

pub(crate) static ENTRY_ARTIFACTS_1062240257173575487: VariantsMap = [
    &["artifacts"],
    &["artefacts"],
    &["artifacts"],
    &["artefacts"],
];

pub(crate) static ENTRY_ARTIFACT_17509472184751868861: VariantsMap =
    [&["artifact"], &["artefact"], &["artifact"], &["artefact"]];

pub(crate) static ENTRY_ARTIFICIALIZED_9369068294747979653: VariantsMap = [
    &["artificialized"],
    &["artificialised"],
    &["artificialized"],
    &["artificialised"],
];

pub(crate) static ENTRY_ARTIFICIALIZES_4836192357409582324: VariantsMap = [
    &["artificializes"],
    &["artificialises"],
    &["artificializes"],
    &["artificialises"],
];

pub(crate) static ENTRY_ARTIFICIALIZE_11447666319297750586: VariantsMap = [
    &["artificialize"],
    &["artificialise"],
    &["artificialize"],
    &["artificialise"],
];

pub(crate) static ENTRY_ARTIFICIALIZING_2365246669571238443: VariantsMap = [
    &["artificializing"],
    &["artificialising"],
    &["artificializing"],
    &["artificialising"],
];

pub(crate) static ENTRY_ARYANIZATION_11011851116548884608: VariantsMap = [
    &["aryanization"],
    &["aryanisation"],
    &["aryanization"],
    &["aryanisation"],
];

pub(crate) static ENTRY_ARYANIZED_13499390712209039689: VariantsMap = [
    &["aryanized"],
    &["aryanised"],
    &["aryanized"],
    &["aryanised"],
];

pub(crate) static ENTRY_ARYANIZES_15634323303932059369: VariantsMap = [
    &["aryanizes"],
    &["aryanises"],
    &["aryanizes"],
    &["aryanises"],
];

pub(crate) static ENTRY_ARYANIZE_9893587637116278166: VariantsMap =
    [&["aryanize"], &["aryanise"], &["aryanize"], &["aryanise"]];

pub(crate) static ENTRY_ARYANIZING_9395651759559624779: VariantsMap = [
    &["aryanizing"],
    &["aryanising"],
    &["aryanizing"],
    &["aryanising"],
];

pub(crate) static ENTRY_ARYTENOIDS_8908541045019104137: VariantsMap = [
    &["arytenoids"],
    &["arytaenoids"],
    &["arytaenoids"],
    &["arytaenoids"],
];

pub(crate) static ENTRY_ARYTENOID_6073418440715999154: VariantsMap = [
    &["arytenoid"],
    &["arytaenoid"],
    &["arytaenoid"],
    &["arytaenoid"],
];

pub(crate) static ENTRY_ASAFETIDAS_7613771138640395119: VariantsMap = [
    &["asafetidas"],
    &["asafoetidas"],
    &["asafetidas"],
    &["asafoetidas"],
];

pub(crate) static ENTRY_ASAFETIDA_7533383003905845995: VariantsMap = [
    &["asafetida"],
    &["asafoetida"],
    &["asafetida"],
    &["asafoetida"],
];

pub(crate) static ENTRY_ASCENDANCY_18331730091976203528: VariantsMap = [
    &["ascendancy"],
    &["ascendancy"],
    &["ascendancy"],
    &["ascendancy"],
];

pub(crate) static ENTRY_ASCENDANTS_3461593336021850728: VariantsMap = [
    &["ascendants"],
    &["ascendants"],
    &["ascendants"],
    &["ascendants"],
];

pub(crate) static ENTRY_ASCENDANT_16268836042646778732: VariantsMap = [
    &["ascendant"],
    &["ascendant"],
    &["ascendant"],
    &["ascendant"],
];

pub(crate) static ENTRY_ASCLEPIADE_14597264952620988032: VariantsMap = [
    &["asclepiade"],
    &["asclepiadae"],
    &["asclepiadae"],
    &["asclepiadae"],
];

pub(crate) static ENTRY_ASEL_13316537939517839394: VariantsMap =
    [&["asel"], &["asael"], &["asael"], &["asael"]];

pub(crate) static ENTRY_ASEPTICIZED_2836264878765353358: VariantsMap = [
    &["asepticized"],
    &["asepticised"],
    &["asepticized"],
    &["asepticised"],
];

pub(crate) static ENTRY_ASEPTICIZES_8120884150718749297: VariantsMap = [
    &["asepticizes"],
    &["asepticises"],
    &["asepticizes"],
    &["asepticises"],
];

pub(crate) static ENTRY_ASEPTICIZE_10541466893781045238: VariantsMap = [
    &["asepticize"],
    &["asepticise"],
    &["asepticize"],
    &["asepticise"],
];

pub(crate) static ENTRY_ASEPTICIZING_9449519681602460239: VariantsMap = [
    &["asepticizing"],
    &["asepticising"],
    &["asepticizing"],
    &["asepticising"],
];

pub(crate) static ENTRY_ASEXUALIZATION_14681303549267056207: VariantsMap = [
    &["asexualization"],
    &["asexualisation"],
    &["asexualization"],
    &["asexualisation"],
];

pub(crate) static ENTRY_ASEXUALIZED_11368129249013006798: VariantsMap = [
    &["asexualized"],
    &["asexualised"],
    &["asexualized"],
    &["asexualised"],
];

pub(crate) static ENTRY_ASEXUALIZE_3884700788598243380: VariantsMap = [
    &["asexualize"],
    &["asexualise"],
    &["asexualize"],
    &["asexualise"],
];

pub(crate) static ENTRY_ASEXUALIZING_1318417851724238802: VariantsMap = [
    &["asexualizing"],
    &["asexualising"],
    &["asexualizing"],
    &["asexualising"],
];

pub(crate) static ENTRY_ASIATICIZATIONS_12846180914024772704: VariantsMap = [
    &["asiaticizations"],
    &["asiaticisations"],
    &["asiaticizations"],
    &["asiaticisations"],
];

pub(crate) static ENTRY_ASIATICIZATION_1819881487033607018: VariantsMap = [
    &["asiaticization"],
    &["asiaticisation"],
    &["asiaticization"],
    &["asiaticisation"],
];

pub(crate) static ENTRY_ASIATICIZES_2776515947393687528: VariantsMap = [
    &["asiaticizes"],
    &["asiaticises"],
    &["asiaticizes"],
    &["asiaticises"],
];

pub(crate) static ENTRY_ASIATICIZE_8144608041170705949: VariantsMap = [
    &["asiaticize"],
    &["asiaticise"],
    &["asiaticize"],
    &["asiaticise"],
];

pub(crate) static ENTRY_ASMONEAN_3980004008722900302: VariantsMap = [
    &["asmonean"],
    &["asmonaean"],
    &["asmonaean"],
    &["asmonaean"],
];

pub(crate) static ENTRY_ASPHETERIZED_4823135635369597053: VariantsMap = [
    &["aspheterized"],
    &["aspheterised"],
    &["aspheterized"],
    &["aspheterised"],
];

pub(crate) static ENTRY_ASPHETERIZES_11246637584979639689: VariantsMap = [
    &["aspheterizes"],
    &["aspheterises"],
    &["aspheterizes"],
    &["aspheterises"],
];

pub(crate) static ENTRY_ASPHETERIZE_386743966224116123: VariantsMap = [
    &["aspheterize"],
    &["aspheterise"],
    &["aspheterize"],
    &["aspheterise"],
];

pub(crate) static ENTRY_ASPHETERIZING_4104456087110825723: VariantsMap = [
    &["aspheterizing"],
    &["aspheterising"],
    &["aspheterizing"],
    &["aspheterising"],
];

pub(crate) static ENTRY_ASSAFETIDAS_11098964927816384399: VariantsMap = [
    &["assafetidas"],
    &["assafoetidas"],
    &["assafoetidas"],
    &["assafoetidas"],
];

pub(crate) static ENTRY_ASSAFETIDA_15899167959215961246: VariantsMap = [
    &["assafetida"],
    &["assafoetida"],
    &["assafoetida"],
    &["assafoetida"],
];

pub(crate) static ENTRY_ASSES_10300641245501717757: VariantsMap =
    [&["asses"], &["arses"], &["arses"], &["arses"]];

pub(crate) static ENTRY_ASSHOLES_4727626946303116044: VariantsMap = [
    &["assholes"],
    &["arseholes"],
    &["arseholes"],
    &["arseholes"],
];

pub(crate) static ENTRY_ASSHOLE_17127558960509698292: VariantsMap =
    [&["asshole"], &["arsehole"], &["arsehole"], &["arsehole"]];

pub(crate) static ENTRY_ASSIDEAN_15792750251093397890: VariantsMap = [
    &["assidean"],
    &["assidaean"],
    &["assidaean"],
    &["assidaean"],
];

pub(crate) static ENTRY_ASSYRIANIZES_8778694777663587290: VariantsMap = [
    &["assyrianizes"],
    &["assyrianises"],
    &["assyrianizes"],
    &["assyrianises"],
];

pub(crate) static ENTRY_ASSYRIANIZE_8826733172094433545: VariantsMap = [
    &["assyrianize"],
    &["assyrianise"],
    &["assyrianize"],
    &["assyrianise"],
];

pub(crate) static ENTRY_ASS_13267007711731927046: VariantsMap =
    [&["ass"], &["arse"], &["arse"], &["arse"]];

pub(crate) static ENTRY_ASTERA_2180294228483451899: VariantsMap =
    [&["astera"], &["astrea"], &["astrea"], &["astrea"]];

pub(crate) static ENTRY_ASTIGMATIZERS_14746285422051377958: VariantsMap = [
    &["astigmatizers"],
    &["astigmatisers"],
    &["astigmatizers"],
    &["astigmatisers"],
];

pub(crate) static ENTRY_ASTIGMATIZER_13677362351199776983: VariantsMap = [
    &["astigmatizer"],
    &["astigmatiser"],
    &["astigmatizer"],
    &["astigmatiser"],
];

pub(crate) static ENTRY_ASTREAN_13090104080124803741: VariantsMap =
    [&["astrean"], &["astraean"], &["astraean"], &["astraean"]];

pub(crate) static ENTRY_ASTREA_13572090690341051490: VariantsMap =
    [&["astrea"], &["astraea"], &["astraea"], &["astraea"]];

pub(crate) static ENTRY_ASTRONOMIZED_13008465323667270440: VariantsMap = [
    &["astronomized"],
    &["astronomised"],
    &["astronomized"],
    &["astronomised"],
];

pub(crate) static ENTRY_ASTRONOMIZES_13470023486647725922: VariantsMap = [
    &["astronomizes"],
    &["astronomises"],
    &["astronomizes"],
    &["astronomises"],
];

pub(crate) static ENTRY_ASTRONOMIZE_9822118404859723540: VariantsMap = [
    &["astronomize"],
    &["astronomise"],
    &["astronomize"],
    &["astronomise"],
];

pub(crate) static ENTRY_ASTRONOMIZING_2599501206343230278: VariantsMap = [
    &["astronomizing"],
    &["astronomising"],
    &["astronomizing"],
    &["astronomising"],
];

pub(crate) static ENTRY_ASYNCHRONIZED_14952589787514487817: VariantsMap = [
    &["asynchronized"],
    &["asynchronised"],
    &["asynchronized"],
    &["asynchronised"],
];

pub(crate) static ENTRY_ASYNCHRONIZES_3583310434940903781: VariantsMap = [
    &["asynchronizes"],
    &["asynchronises"],
    &["asynchronizes"],
    &["asynchronises"],
];

pub(crate) static ENTRY_ASYNCHRONIZE_12856870824943050138: VariantsMap = [
    &["asynchronize"],
    &["asynchronise"],
    &["asynchronize"],
    &["asynchronise"],
];

pub(crate) static ENTRY_ASYNCHRONIZING_15056432960653345202: VariantsMap = [
    &["asynchronizing"],
    &["asynchronising"],
    &["asynchronizing"],
    &["asynchronising"],
];

pub(crate) static ENTRY_ATHEIZED_17537019228674510480: VariantsMap =
    [&["atheized"], &["atheised"], &["atheized"], &["atheised"]];

pub(crate) static ENTRY_ATHEIZES_16042176054703042055: VariantsMap =
    [&["atheizes"], &["atheises"], &["atheizes"], &["atheises"]];

pub(crate) static ENTRY_ATHEIZE_3725615390405368489: VariantsMap =
    [&["atheize"], &["atheise"], &["atheize"], &["atheise"]];

pub(crate) static ENTRY_ATHEIZING_16529882185387835743: VariantsMap = [
    &["atheizing"],
    &["atheising"],
    &["atheizing"],
    &["atheising"],
];

pub(crate) static ENTRY_ATHETIZED_11986419619737601090: VariantsMap = [
    &["athetized"],
    &["athetised"],
    &["athetized"],
    &["athetised"],
];

pub(crate) static ENTRY_ATHETIZES_13168875276958946124: VariantsMap = [
    &["athetizes"],
    &["athetises"],
    &["athetizes"],
    &["athetises"],
];

pub(crate) static ENTRY_ATHETIZE_8594115700031724425: VariantsMap =
    [&["athetize"], &["athetise"], &["athetize"], &["athetise"]];

pub(crate) static ENTRY_ATHETIZING_16435585359530521235: VariantsMap = [
    &["athetizing"],
    &["athetising"],
    &["athetizing"],
    &["athetising"],
];

pub(crate) static ENTRY_ATMOLYZED_14977612454538756584: VariantsMap = [
    &["atmolyzed"],
    &["atmolysed"],
    &["atmolyzed"],
    &["atmolysed"],
];

pub(crate) static ENTRY_ATMOLYZES_201081934661402516: VariantsMap = [
    &["atmolyzes"],
    &["atmolyses"],
    &["atmolyzes"],
    &["atmolyses"],
];

pub(crate) static ENTRY_ATMOLYZE_8057568476478476694: VariantsMap =
    [&["atmolyze"], &["atmolyse"], &["atmolyze"], &["atmolyse"]];

pub(crate) static ENTRY_ATMOLYZING_9405510802019900450: VariantsMap = [
    &["atmolyzing"],
    &["atmolysing"],
    &["atmolyzing"],
    &["atmolysing"],
];

pub(crate) static ENTRY_ATOMIZABILITY_3064159544702925002: VariantsMap = [
    &["atomizability"],
    &["atomisability"],
    &["atomizability"],
    &["atomisability"],
];

pub(crate) static ENTRY_ATOMIZABLE_3154734891333662468: VariantsMap = [
    &["atomizable"],
    &["atomisable"],
    &["atomizable"],
    &["atomisable"],
];

pub(crate) static ENTRY_ATOMIZATIONS_13202958232672091227: VariantsMap = [
    &["atomizations"],
    &["atomisations"],
    &["atomizations"],
    &["atomisations"],
];

pub(crate) static ENTRY_ATOMIZATION_590556657495417532: VariantsMap = [
    &["atomization"],
    &["atomisation"],
    &["atomization"],
    &["atomisation"],
];

pub(crate) static ENTRY_ATOMIZED_14021873460744571304: VariantsMap =
    [&["atomized"], &["atomised"], &["atomized"], &["atomised"]];

pub(crate) static ENTRY_ATOMIZERS_7852074573965124043: VariantsMap = [
    &["atomizers"],
    &["atomisers"],
    &["atomizers"],
    &["atomisers"],
];

pub(crate) static ENTRY_ATOMIZER_11539225746984001325: VariantsMap =
    [&["atomizer"], &["atomiser"], &["atomizer"], &["atomiser"]];

pub(crate) static ENTRY_ATOMIZES_933901040229054200: VariantsMap =
    [&["atomizes"], &["atomises"], &["atomizes"], &["atomises"]];

pub(crate) static ENTRY_ATOMIZE_1487134664435979373: VariantsMap =
    [&["atomize"], &["atomise"], &["atomize"], &["atomise"]];

pub(crate) static ENTRY_ATOMIZING_15930852773659767832: VariantsMap = [
    &["atomizing"],
    &["atomising"],
    &["atomizing"],
    &["atomising"],
];

pub(crate) static ENTRY_ATROCERULEUS_870609394004473197: VariantsMap = [
    &["atroceruleus"],
    &["atrocoeruleus"],
    &["atrocoeruleus"],
    &["atrocoeruleus"],
];

pub(crate) static ENTRY_ATTEMPER_12124624986954113539: VariantsMap =
    [&["attemper"], &["attempre"], &["attempre"], &["attempre"]];

pub(crate) static ENTRY_ATTICIZED_7951296077967341199: VariantsMap = [
    &["atticized"],
    &["atticised"],
    &["atticized"],
    &["atticised"],
];

pub(crate) static ENTRY_ATTICIZES_5529365057194588874: VariantsMap = [
    &["atticizes"],
    &["atticises"],
    &["atticizes"],
    &["atticises"],
];

pub(crate) static ENTRY_ATTICIZE_16515183819201700111: VariantsMap =
    [&["atticize"], &["atticise"], &["atticize"], &["atticise"]];

pub(crate) static ENTRY_ATTICIZING_2415630028739866198: VariantsMap = [
    &["atticizing"],
    &["atticising"],
    &["atticizing"],
    &["atticising"],
];

pub(crate) static ENTRY_ATTITUDINIZATION_16531832101228496151: VariantsMap = [
    &["attitudinization"],
    &["attitudinisation"],
    &["attitudinization"],
    &["attitudinisation"],
];

pub(crate) static ENTRY_ATTITUDINIZED_14589679104763490674: VariantsMap = [
    &["attitudinized"],
    &["attitudinised"],
    &["attitudinized"],
    &["attitudinised"],
];

pub(crate) static ENTRY_ATTITUDINIZERS_2041039782349599020: VariantsMap = [
    &["attitudinizers"],
    &["attitudinisers"],
    &["attitudinizers"],
    &["attitudinisers"],
];

pub(crate) static ENTRY_ATTITUDINIZER_12167614530126147382: VariantsMap = [
    &["attitudinizer"],
    &["attitudiniser"],
    &["attitudinizer"],
    &["attitudiniser"],
];

pub(crate) static ENTRY_ATTITUDINIZES_8414732033616113994: VariantsMap = [
    &["attitudinizes"],
    &["attitudinises"],
    &["attitudinizes"],
    &["attitudinises"],
];

pub(crate) static ENTRY_ATTITUDINIZE_13882543243823601511: VariantsMap = [
    &["attitudinize"],
    &["attitudinise"],
    &["attitudinize"],
    &["attitudinise"],
];

pub(crate) static ENTRY_ATTITUDINIZINGS_3731252719764627971: VariantsMap = [
    &["attitudinizings"],
    &["attitudinisings"],
    &["attitudinizings"],
    &["attitudinisings"],
];

pub(crate) static ENTRY_ATTITUDINIZING_1855190539336439905: VariantsMap = [
    &["attitudinizing"],
    &["attitudinising"],
    &["attitudinizing"],
    &["attitudinising"],
];

pub(crate) static ENTRY_AUNTER_10775345708782097344: VariantsMap =
    [&["aunter"], &["auntre"], &["auntre"], &["auntre"]];

pub(crate) static ENTRY_AUSTRALIANIZES_18424570185752883694: VariantsMap = [
    &["australianizes"],
    &["australianises"],
    &["australianizes"],
    &["australianises"],
];

pub(crate) static ENTRY_AUSTRALIANIZE_8442939799684541917: VariantsMap = [
    &["australianize"],
    &["australianise"],
    &["australianize"],
    &["australianise"],
];

pub(crate) static ENTRY_AUSTRALOPITHECINE_9263939179936660845: VariantsMap = [
    &["australopithecine"],
    &["australopithecinae"],
    &["australopithecinae"],
    &["australopithecinae"],
];

pub(crate) static ENTRY_AUSTRIANIZES_15560706707425803347: VariantsMap = [
    &["austrianizes"],
    &["austrianises"],
    &["austrianizes"],
    &["austrianises"],
];

pub(crate) static ENTRY_AUSTRIANIZE_986135697638036817: VariantsMap = [
    &["austrianize"],
    &["austrianise"],
    &["austrianize"],
    &["austrianise"],
];

pub(crate) static ENTRY_AUTECIOUSLY_7125263249320375817: VariantsMap = [
    &["auteciously"],
    &["autoeciously"],
    &["autoeciously"],
    &["autoeciously"],
];

pub(crate) static ENTRY_AUTECIOUSNESS_11999355741493391477: VariantsMap = [
    &["auteciousness"],
    &["autoeciousness"],
    &["autoeciousness"],
    &["autoeciousness"],
];

pub(crate) static ENTRY_AUTECIOUS_9016941624955767913: VariantsMap = [
    &["autecious"],
    &["autoecious"],
    &["autoecious"],
    &["autoecious"],
];

pub(crate) static ENTRY_AUTECISMS_10619942660624290956: VariantsMap = [
    &["autecisms"],
    &["autoecisms"],
    &["autoecisms"],
    &["autoecisms"],
];

pub(crate) static ENTRY_AUTECISM_8206525242512381241: VariantsMap = [
    &["autecism"],
    &["autoecism"],
    &["autoecism"],
    &["autoecism"],
];

pub(crate) static ENTRY_AUTECY_7368389728914865172: VariantsMap =
    [&["autecy"], &["autoecy"], &["autoecy"], &["autoecy"]];

pub(crate) static ENTRY_AUTHORIZABLE_7024929714254597943: VariantsMap = [
    &["authorizable"],
    &["authorisable"],
    &["authorizable"],
    &["authorisable"],
];

pub(crate) static ENTRY_AUTHORIZATIONS_11920547268538394932: VariantsMap = [
    &["authorizations"],
    &["authorisations"],
    &["authorizations"],
    &["authorisations"],
];

pub(crate) static ENTRY_AUTHORIZATION_9399085124340736739: VariantsMap = [
    &["authorization"],
    &["authorisation"],
    &["authorization"],
    &["authorisation"],
];

pub(crate) static ENTRY_AUTHORIZED_15853776364746167522: VariantsMap = [
    &["authorized"],
    &["authorised"],
    &["authorized"],
    &["authorised"],
];

pub(crate) static ENTRY_AUTHORIZERS_2996105333287439187: VariantsMap = [
    &["authorizers"],
    &["authorisers"],
    &["authorizers"],
    &["authorisers"],
];

pub(crate) static ENTRY_AUTHORIZER_10220958941854846496: VariantsMap = [
    &["authorizer"],
    &["authoriser"],
    &["authorizer"],
    &["authoriser"],
];

pub(crate) static ENTRY_AUTHORIZES_12688794592033918408: VariantsMap = [
    &["authorizes"],
    &["authorises"],
    &["authorizes"],
    &["authorises"],
];

pub(crate) static ENTRY_AUTHORIZE_2165377916187291578: VariantsMap = [
    &["authorize"],
    &["authorise"],
    &["authorize"],
    &["authorise"],
];

pub(crate) static ENTRY_AUTHORIZING_9710867312061027048: VariantsMap = [
    &["authorizing"],
    &["authorising"],
    &["authorizing"],
    &["authorising"],
];

pub(crate) static ENTRY_AUTOCATALYZED_997717077170549950: VariantsMap = [
    &["autocatalyzed"],
    &["autocatalysed"],
    &["autocatalyzed"],
    &["autocatalysed"],
];

pub(crate) static ENTRY_AUTOCATALYZES_16499693018281720964: VariantsMap = [
    &["autocatalyzes"],
    &["autocatalyses"],
    &["autocatalyzes"],
    &["autocatalyses"],
];

pub(crate) static ENTRY_AUTOCATALYZE_5461271699135892272: VariantsMap = [
    &["autocatalyze"],
    &["autocatalyse"],
    &["autocatalyze"],
    &["autocatalyse"],
];

pub(crate) static ENTRY_AUTOCATALYZING_6626129467810870996: VariantsMap = [
    &["autocatalyzing"],
    &["autocatalysing"],
    &["autocatalyzing"],
    &["autocatalysing"],
];

pub(crate) static ENTRY_AUTODIALER_3883256868475043902: VariantsMap = [
    &["autodialer"],
    &["autodialler"],
    &["autodialler"],
    &["autodialler"],
];

pub(crate) static ENTRY_AUTOIMMUNIZATION_9926504789971325367: VariantsMap = [
    &["autoimmunization"],
    &["autoimmunisation"],
    &["autoimmunization"],
    &["autoimmunisation"],
];

pub(crate) static ENTRY_AUTOIONIZATION_6325169105459274551: VariantsMap = [
    &["autoionization"],
    &["autoionisation"],
    &["autoionization"],
    &["autoionisation"],
];

pub(crate) static ENTRY_AUTOLYZATES_7096670691572389437: VariantsMap = [
    &["autolyzates"],
    &["autolysates"],
    &["autolyzates"],
    &["autolysates"],
];

pub(crate) static ENTRY_AUTOLYZATE_4740018979514548136: VariantsMap = [
    &["autolyzate"],
    &["autolysate"],
    &["autolyzate"],
    &["autolysate"],
];

pub(crate) static ENTRY_AUTOLYZED_3751603048053936787: VariantsMap = [
    &["autolyzed"],
    &["autolysed"],
    &["autolyzed"],
    &["autolysed"],
];

pub(crate) static ENTRY_AUTOLYZES_10272580890270323304: VariantsMap = [
    &["autolyzes"],
    &["autolyses"],
    &["autolyzes"],
    &["autolyses"],
];

pub(crate) static ENTRY_AUTOLYZE_7221911042390256641: VariantsMap =
    [&["autolyze"], &["autolyse"], &["autolyze"], &["autolyse"]];

pub(crate) static ENTRY_AUTOLYZING_10091565140641112709: VariantsMap = [
    &["autolyzing"],
    &["autolysing"],
    &["autolyzing"],
    &["autolysing"],
];

pub(crate) static ENTRY_AUTOMATIZATIONS_11353228502294123144: VariantsMap = [
    &["automatizations"],
    &["automatisations"],
    &["automatizations"],
    &["automatisations"],
];

pub(crate) static ENTRY_AUTOMATIZATION_5810567154782386881: VariantsMap = [
    &["automatization"],
    &["automatisation"],
    &["automatization"],
    &["automatisation"],
];

pub(crate) static ENTRY_AUTOMATIZED_6360332663543743601: VariantsMap = [
    &["automatized"],
    &["automatised"],
    &["automatized"],
    &["automatised"],
];

pub(crate) static ENTRY_AUTOMATIZES_16200902288701375676: VariantsMap = [
    &["automatizes"],
    &["automatises"],
    &["automatizes"],
    &["automatises"],
];

pub(crate) static ENTRY_AUTOMATIZE_16310459509383804856: VariantsMap = [
    &["automatize"],
    &["automatise"],
    &["automatize"],
    &["automatise"],
];

pub(crate) static ENTRY_AUTOMATIZING_1555845313837902984: VariantsMap = [
    &["automatizing"],
    &["automatising"],
    &["automatizing"],
    &["automatising"],
];

pub(crate) static ENTRY_AUTONOE_13532775087577013215: VariantsMap =
    [&["autonoe"], &["autonoae"], &["autonoae"], &["autonoae"]];

pub(crate) static ENTRY_AUTOTOMIZED_540920492757769960: VariantsMap = [
    &["autotomized"],
    &["autotomised"],
    &["autotomized"],
    &["autotomised"],
];

pub(crate) static ENTRY_AUTOTOMIZES_48604156847444911: VariantsMap = [
    &["autotomizes"],
    &["autotomises"],
    &["autotomizes"],
    &["autotomises"],
];

pub(crate) static ENTRY_AUTOTOMIZE_13490570757077519512: VariantsMap = [
    &["autotomize"],
    &["autotomise"],
    &["autotomize"],
    &["autotomise"],
];

pub(crate) static ENTRY_AUTOTOMIZING_11853548989644406010: VariantsMap = [
    &["autotomizing"],
    &["autotomising"],
    &["autotomizing"],
    &["autotomising"],
];

pub(crate) static ENTRY_AUTOTOXEMIAS_10214808257451881715: VariantsMap = [
    &["autotoxemias"],
    &["autotoxaemias"],
    &["autotoxaemias"],
    &["autotoxaemias"],
];

pub(crate) static ENTRY_AUTOTOXEMIA_7479014975731069357: VariantsMap = [
    &["autotoxemia"],
    &["autotoxaemia"],
    &["autotoxaemia"],
    &["autotoxaemia"],
];

pub(crate) static ENTRY_AVIANIZED_18028922120466918062: VariantsMap = [
    &["avianized"],
    &["avianised"],
    &["avianized"],
    &["avianised"],
];

pub(crate) static ENTRY_AVIANIZES_3719741787367657653: VariantsMap = [
    &["avianizes"],
    &["avianises"],
    &["avianizes"],
    &["avianises"],
];

pub(crate) static ENTRY_AVIANIZE_7182789330071991276: VariantsMap =
    [&["avianize"], &["avianise"], &["avianize"], &["avianise"]];

pub(crate) static ENTRY_AVIANIZING_5883523625794290260: VariantsMap = [
    &["avianizing"],
    &["avianising"],
    &["avianizing"],
    &["avianising"],
];

pub(crate) static ENTRY_AVIZANDUMS_317675797382529405: VariantsMap = [
    &["avizandums"],
    &["avisandums"],
    &["avizandums"],
    &["avisandums"],
];

pub(crate) static ENTRY_AVIZANDUM_12850456978185242449: VariantsMap = [
    &["avizandum"],
    &["avisandum"],
    &["avizandum"],
    &["avisandum"],
];

pub(crate) static ENTRY_AVIZED_12711210182572791628: VariantsMap =
    [&["avized"], &["avised"], &["avized"], &["avised"]];

pub(crate) static ENTRY_AVIZES_4984057433322754178: VariantsMap =
    [&["avizes"], &["avises"], &["avizes"], &["avises"]];

pub(crate) static ENTRY_AVIZE_9529584256565676451: VariantsMap =
    [&["avize"], &["avise"], &["avize"], &["avise"]];

pub(crate) static ENTRY_AVIZING_13649640310586309670: VariantsMap =
    [&["avizing"], &["avising"], &["avizing"], &["avising"]];

pub(crate) static ENTRY_AXIOMATIZATIONS_1463433006554034082: VariantsMap = [
    &["axiomatizations"],
    &["axiomatisations"],
    &["axiomatizations"],
    &["axiomatisations"],
];

pub(crate) static ENTRY_AXIOMATIZATION_6790026490086177253: VariantsMap = [
    &["axiomatization"],
    &["axiomatisation"],
    &["axiomatization"],
    &["axiomatisation"],
];

pub(crate) static ENTRY_AXIOMATIZED_15716028992263544716: VariantsMap = [
    &["axiomatized"],
    &["axiomatised"],
    &["axiomatized"],
    &["axiomatised"],
];

pub(crate) static ENTRY_AXIOMATIZES_17183333054844420152: VariantsMap = [
    &["axiomatizes"],
    &["axiomatises"],
    &["axiomatizes"],
    &["axiomatises"],
];

pub(crate) static ENTRY_AXIOMATIZE_10903214369529991396: VariantsMap = [
    &["axiomatize"],
    &["axiomatise"],
    &["axiomatize"],
    &["axiomatise"],
];

pub(crate) static ENTRY_AXIOMATIZING_12121192135039396112: VariantsMap = [
    &["axiomatizing"],
    &["axiomatising"],
    &["axiomatizing"],
    &["axiomatising"],
];

pub(crate) static ENTRY_AX_8791902263575839056: VariantsMap =
    [&["ax"], &["axe"], &["axe"], &["axe"]];

pub(crate) static ENTRY_AZOTEMIA_5781295612160723689: VariantsMap = [
    &["azotemia"],
    &["azotaemia"],
    &["azotaemia"],
    &["azotaemia"],
];

pub(crate) static ENTRY_AZOTIZATION_16751764280090329776: VariantsMap = [
    &["azotization"],
    &["azotisation"],
    &["azotization"],
    &["azotisation"],
];

pub(crate) static ENTRY_AZOTIZED_13190991869542223480: VariantsMap =
    [&["azotized"], &["azotised"], &["azotized"], &["azotised"]];

pub(crate) static ENTRY_AZOTIZES_3339593282352035892: VariantsMap =
    [&["azotizes"], &["azotises"], &["azotizes"], &["azotises"]];

pub(crate) static ENTRY_AZOTIZE_546840730893237282: VariantsMap =
    [&["azotize"], &["azotise"], &["azotize"], &["azotise"]];

pub(crate) static ENTRY_AZOTIZING_17033259205824301048: VariantsMap = [
    &["azotizing"],
    &["azotising"],
    &["azotizing"],
    &["azotising"],
];

pub(crate) static ENTRY_AZOTORRHEA_5575485772910084978: VariantsMap = [
    &["azotorrhea"],
    &["azotorrhoea"],
    &["azotorrhoea"],
    &["azotorrhoea"],
];

pub(crate) static ENTRY_BABELIZATION_8763023149184870283: VariantsMap = [
    &["babelization"],
    &["babelisation"],
    &["babelization"],
    &["babelisation"],
];

pub(crate) static ENTRY_BABELIZED_7375337936585492939: VariantsMap = [
    &["babelized"],
    &["babelised"],
    &["babelized"],
    &["babelised"],
];

pub(crate) static ENTRY_BABELIZE_4712093391684542738: VariantsMap =
    [&["babelize"], &["babelise"], &["babelize"], &["babelise"]];

pub(crate) static ENTRY_BABELIZING_17886762817869717286: VariantsMap = [
    &["babelizing"],
    &["babelising"],
    &["babelizing"],
    &["babelising"],
];

pub(crate) static ENTRY_BABYLONIZES_2033930356599031067: VariantsMap = [
    &["babylonizes"],
    &["babylonises"],
    &["babylonizes"],
    &["babylonises"],
];

pub(crate) static ENTRY_BABYLONIZE_14971641941216790519: VariantsMap = [
    &["babylonize"],
    &["babylonise"],
    &["babylonize"],
    &["babylonise"],
];

pub(crate) static ENTRY_BACHELORIZES_389481611658102282: VariantsMap = [
    &["bachelorizes"],
    &["bachelorises"],
    &["bachelorizes"],
    &["bachelorises"],
];

pub(crate) static ENTRY_BACHELORIZE_9276026756047911374: VariantsMap = [
    &["bachelorize"],
    &["bachelorise"],
    &["bachelorize"],
    &["bachelorise"],
];

pub(crate) static ENTRY_BACILLEMIAS_12787222793673563183: VariantsMap = [
    &["bacillemias"],
    &["bacillaemias"],
    &["bacillaemias"],
    &["bacillaemias"],
];

pub(crate) static ENTRY_BACILLEMIA_6856482863549349550: VariantsMap = [
    &["bacillemia"],
    &["bacillaemia"],
    &["bacillaemia"],
    &["bacillaemia"],
];

pub(crate) static ENTRY_BACKPEDALED_6298147286173253590: VariantsMap = [
    &["backpedaled"],
    &["backpedalled"],
    &["backpedalled"],
    &["backpedalled"],
];

pub(crate) static ENTRY_BACKPEDALING_7980264040948743932: VariantsMap = [
    &["backpedaling"],
    &["backpedalling"],
    &["backpedalling"],
    &["backpedalling"],
];

pub(crate) static ENTRY_BACONIZES_12618733997507540246: VariantsMap = [
    &["baconizes"],
    &["baconises"],
    &["baconizes"],
    &["baconises"],
];

pub(crate) static ENTRY_BACONIZE_9484980945125882746: VariantsMap =
    [&["baconize"], &["baconise"], &["baconize"], &["baconise"]];

pub(crate) static ENTRY_BACTEREMIAS_7320892949977505735: VariantsMap = [
    &["bacteremias"],
    &["bacteraemias"],
    &["bacteraemias"],
    &["bacteraemias"],
];

pub(crate) static ENTRY_BACTEREMIA_17628282609276747504: VariantsMap = [
    &["bacteremia"],
    &["bacteraemia"],
    &["bacteraemia"],
    &["bacteraemia"],
];

pub(crate) static ENTRY_BACTERIA_16095578107548828853: VariantsMap =
    [&["bacteria"], &["bacteria"], &["bacteria"], &["bacteria"]];

pub(crate) static ENTRY_BACTERIEMIA_12169850297621826303: VariantsMap = [
    &["bacteriemia"],
    &["bacteriaemia"],
    &["bacteriaemia"],
    &["bacteriaemia"],
];

pub(crate) static ENTRY_BACTERIZED_4654231266975382567: VariantsMap = [
    &["bacterized"],
    &["bacterised"],
    &["bacterized"],
    &["bacterised"],
];

pub(crate) static ENTRY_BACTERIZES_11602946683696054699: VariantsMap = [
    &["bacterizes"],
    &["bacterises"],
    &["bacterizes"],
    &["bacterises"],
];

pub(crate) static ENTRY_BACTERIZE_2554794150826347242: VariantsMap = [
    &["bacterize"],
    &["bacterise"],
    &["bacterize"],
    &["bacterise"],
];

pub(crate) static ENTRY_BACTERIZING_18102823127423356275: VariantsMap = [
    &["bacterizing"],
    &["bacterising"],
    &["bacterizing"],
    &["bacterising"],
];

pub(crate) static ENTRY_BAER_6801672222137916904: VariantsMap =
    [&["baer"], &["bare"], &["bare"], &["bare"]];

pub(crate) static ENTRY_BALKANIZATIONS_7005506925687374553: VariantsMap = [
    &["balkanizations"],
    &["balkanisations"],
    &["balkanizations"],
    &["balkanisations"],
];

pub(crate) static ENTRY_BALKANIZATION_9747896824720545908: VariantsMap = [
    &["balkanization"],
    &["balkanisation"],
    &["balkanization"],
    &["balkanisation"],
];

pub(crate) static ENTRY_BALKANIZED_12279192716835695133: VariantsMap = [
    &["balkanized"],
    &["balkanised"],
    &["balkanized"],
    &["balkanised"],
];

pub(crate) static ENTRY_BALKANIZES_2001964342934763145: VariantsMap = [
    &["balkanizes"],
    &["balkanises"],
    &["balkanizes"],
    &["balkanises"],
];

pub(crate) static ENTRY_BALKANIZE_12204669760694621864: VariantsMap = [
    &["balkanize"],
    &["balkanise"],
    &["balkanize"],
    &["balkanise"],
];

pub(crate) static ENTRY_BALKANIZING_14076694085527168987: VariantsMap = [
    &["balkanizing"],
    &["balkanising"],
    &["balkanizing"],
    &["balkanising"],
];

pub(crate) static ENTRY_BALKED_3526355814992470448: VariantsMap =
    [&["balked"], &["baulked"], &["balked"], &["baulked"]];

pub(crate) static ENTRY_BALKING_8837528869624452282: VariantsMap =
    [&["balking"], &["baulking"], &["balking"], &["baulking"]];

pub(crate) static ENTRY_BALKS_16564351609417220858: VariantsMap =
    [&["balks"], &["baulks"], &["balks"], &["baulks"]];

pub(crate) static ENTRY_BALK_16035479339777098788: VariantsMap =
    [&["balk"], &["baulk"], &["balk"], &["baulk"]];

pub(crate) static ENTRY_BALLADIZED_1820750950061798946: VariantsMap = [
    &["balladized"],
    &["balladised"],
    &["balladized"],
    &["balladised"],
];

pub(crate) static ENTRY_BALLADIZES_10218527173082256105: VariantsMap = [
    &["balladizes"],
    &["balladises"],
    &["balladizes"],
    &["balladises"],
];

pub(crate) static ENTRY_BALLADIZE_756808746628392202: VariantsMap = [
    &["balladize"],
    &["balladise"],
    &["balladize"],
    &["balladise"],
];

pub(crate) static ENTRY_BALLADIZING_5773113893296432935: VariantsMap = [
    &["balladizing"],
    &["balladising"],
    &["balladizing"],
    &["balladising"],
];

pub(crate) static ENTRY_BALSAMIZES_12017092060830247485: VariantsMap = [
    &["balsamizes"],
    &["balsamises"],
    &["balsamizes"],
    &["balsamises"],
];

pub(crate) static ENTRY_BALSAMIZE_12014560978856048374: VariantsMap = [
    &["balsamize"],
    &["balsamise"],
    &["balsamize"],
    &["balsamise"],
];

pub(crate) static ENTRY_BANALIZATIONS_9864795908067425875: VariantsMap = [
    &["banalizations"],
    &["banalisations"],
    &["banalizations"],
    &["banalisations"],
];

pub(crate) static ENTRY_BANALIZATION_16998614142961485820: VariantsMap = [
    &["banalization"],
    &["banalisation"],
    &["banalization"],
    &["banalisation"],
];

pub(crate) static ENTRY_BANALIZED_9878839544450842328: VariantsMap = [
    &["banalized"],
    &["banalised"],
    &["banalized"],
    &["banalised"],
];

pub(crate) static ENTRY_BANALIZES_1210609160280842589: VariantsMap = [
    &["banalizes"],
    &["banalises"],
    &["banalizes"],
    &["banalises"],
];

pub(crate) static ENTRY_BANALIZE_8060560643976337383: VariantsMap =
    [&["banalize"], &["banalise"], &["banalize"], &["banalise"]];

pub(crate) static ENTRY_BANALIZING_12280357311629093499: VariantsMap = [
    &["banalizing"],
    &["banalising"],
    &["banalizing"],
    &["banalising"],
];

pub(crate) static ENTRY_BANTAMIZES_10055099835231772607: VariantsMap = [
    &["bantamizes"],
    &["bantamises"],
    &["bantamizes"],
    &["bantamises"],
];

pub(crate) static ENTRY_BANTAMIZE_18144233594259187360: VariantsMap = [
    &["bantamize"],
    &["bantamise"],
    &["bantamize"],
    &["bantamise"],
];

pub(crate) static ENTRY_BAPTIZABLES_14077914860012312208: VariantsMap = [
    &["baptizables"],
    &["baptisables"],
    &["baptizables"],
    &["baptisables"],
];

pub(crate) static ENTRY_BAPTIZABLE_13863505238468511156: VariantsMap = [
    &["baptizable"],
    &["baptisable"],
    &["baptizable"],
    &["baptisable"],
];

pub(crate) static ENTRY_BAPTIZED_3084779397484844921: VariantsMap =
    [&["baptized"], &["baptised"], &["baptized"], &["baptised"]];

pub(crate) static ENTRY_BAPTIZEMENTS_6705599307765015302: VariantsMap = [
    &["baptizements"],
    &["baptisements"],
    &["baptizements"],
    &["baptisements"],
];

pub(crate) static ENTRY_BAPTIZEMENT_12442543968934676656: VariantsMap = [
    &["baptizement"],
    &["baptisement"],
    &["baptizement"],
    &["baptisement"],
];

pub(crate) static ENTRY_BAPTIZERS_17786948365777430097: VariantsMap = [
    &["baptizers"],
    &["baptisers"],
    &["baptizers"],
    &["baptisers"],
];

pub(crate) static ENTRY_BAPTIZER_5319953109508258693: VariantsMap =
    [&["baptizer"], &["baptiser"], &["baptizer"], &["baptiser"]];

pub(crate) static ENTRY_BAPTIZES_3674202696170149073: VariantsMap =
    [&["baptizes"], &["baptises"], &["baptizes"], &["baptises"]];

pub(crate) static ENTRY_BAPTIZE_17709364285657597325: VariantsMap =
    [&["baptize"], &["baptise"], &["baptize"], &["baptise"]];

pub(crate) static ENTRY_BAPTIZING_4391013702348485363: VariantsMap = [
    &["baptizing"],
    &["baptising"],
    &["baptizing"],
    &["baptising"],
];

pub(crate) static ENTRY_BARBARIANIZES_9451438009677792437: VariantsMap = [
    &["barbarianizes"],
    &["barbarianises"],
    &["barbarianizes"],
    &["barbarianises"],
];

pub(crate) static ENTRY_BARBARIANIZE_17363551505483403455: VariantsMap = [
    &["barbarianize"],
    &["barbarianise"],
    &["barbarianize"],
    &["barbarianise"],
];

pub(crate) static ENTRY_BARBARIZATIONS_16120039862360583028: VariantsMap = [
    &["barbarizations"],
    &["barbarisations"],
    &["barbarizations"],
    &["barbarisations"],
];

pub(crate) static ENTRY_BARBARIZATION_1565508341740347927: VariantsMap = [
    &["barbarization"],
    &["barbarisation"],
    &["barbarization"],
    &["barbarisation"],
];

pub(crate) static ENTRY_BARBARIZED_10589089200149181973: VariantsMap = [
    &["barbarized"],
    &["barbarised"],
    &["barbarized"],
    &["barbarised"],
];

pub(crate) static ENTRY_BARBARIZES_11729924502589455167: VariantsMap = [
    &["barbarizes"],
    &["barbarises"],
    &["barbarizes"],
    &["barbarises"],
];

pub(crate) static ENTRY_BARBARIZE_11203839610503788919: VariantsMap = [
    &["barbarize"],
    &["barbarise"],
    &["barbarize"],
    &["barbarise"],
];

pub(crate) static ENTRY_BARBARIZING_10697728842079700750: VariantsMap = [
    &["barbarizing"],
    &["barbarising"],
    &["barbarizing"],
    &["barbarising"],
];

pub(crate) static ENTRY_BARONETIZED_8092986270823381459: VariantsMap = [
    &["baronetized"],
    &["baronetised"],
    &["baronetized"],
    &["baronetised"],
];

pub(crate) static ENTRY_BARONETIZE_16652294292761778174: VariantsMap = [
    &["baronetize"],
    &["baronetise"],
    &["baronetize"],
    &["baronetise"],
];

pub(crate) static ENTRY_BARONETIZING_12517588353963602947: VariantsMap = [
    &["baronetizing"],
    &["baronetising"],
    &["baronetizing"],
    &["baronetising"],
];

pub(crate) static ENTRY_BARONIZES_2125070744284366847: VariantsMap = [
    &["baronizes"],
    &["baronises"],
    &["baronizes"],
    &["baronises"],
];

pub(crate) static ENTRY_BARONIZE_15371835358034909984: VariantsMap =
    [&["baronize"], &["baronise"], &["baronize"], &["baronise"]];

pub(crate) static ENTRY_BARRELED_14092667501559584042: VariantsMap = [
    &["barreled"],
    &["barrelled"],
    &["barrelled"],
    &["barrelled"],
];

pub(crate) static ENTRY_BARRELING_14466284948340214047: VariantsMap = [
    &["barreling"],
    &["barrelling"],
    &["barrelling"],
    &["barrelling"],
];

pub(crate) static ENTRY_BARTIZANED_2053199514898941629: VariantsMap = [
    &["bartizaned"],
    &["bartisaned"],
    &["bartizaned"],
    &["bartisaned"],
];

pub(crate) static ENTRY_BARTIZANS_5561585073920453699: VariantsMap = [
    &["bartizans"],
    &["bartisans"],
    &["bartizans"],
    &["bartisans"],
];

pub(crate) static ENTRY_BARTIZAN_2010969180093715656: VariantsMap =
    [&["bartizan"], &["bartisan"], &["bartizan"], &["bartisan"]];

pub(crate) static ENTRY_BARYCENTER_12536678624170103346: VariantsMap = [
    &["barycenter"],
    &["barycentre"],
    &["barycentre"],
    &["barycentre"],
];

pub(crate) static ENTRY_BASTARDIZATIONS_3269957802823510223: VariantsMap = [
    &["bastardizations"],
    &["bastardisations"],
    &["bastardizations"],
    &["bastardisations"],
];

pub(crate) static ENTRY_BASTARDIZATION_4159983584935153450: VariantsMap = [
    &["bastardization"],
    &["bastardisation"],
    &["bastardization"],
    &["bastardisation"],
];

pub(crate) static ENTRY_BASTARDIZED_8789832174701091014: VariantsMap = [
    &["bastardized"],
    &["bastardised"],
    &["bastardized"],
    &["bastardised"],
];

pub(crate) static ENTRY_BASTARDIZES_4123418596066734832: VariantsMap = [
    &["bastardizes"],
    &["bastardises"],
    &["bastardizes"],
    &["bastardises"],
];

pub(crate) static ENTRY_BASTARDIZE_3932717470754109062: VariantsMap = [
    &["bastardize"],
    &["bastardise"],
    &["bastardize"],
    &["bastardise"],
];

pub(crate) static ENTRY_BASTARDIZING_16141466359672648361: VariantsMap = [
    &["bastardizing"],
    &["bastardising"],
    &["bastardizing"],
    &["bastardising"],
];

pub(crate) static ENTRY_BASTINADED_13143614434412608155: VariantsMap = [
    &["bastinaded"],
    &["bastinadoed"],
    &["bastinadoed"],
    &["bastinadoed"],
];

pub(crate) static ENTRY_BASTINADES_8442479215705679003: VariantsMap = [
    &["bastinades"],
    &["bastinadoes"],
    &["bastinadoes"],
    &["bastinadoes"],
];

pub(crate) static ENTRY_BATTLEAXE_5257995273927790498: VariantsMap = [
    &["battleaxe"],
    &["battleaxe"],
    &["battleaxe"],
    &["battleaxe"],
];

pub(crate) static ENTRY_BATTOLOGIZED_14848719392834636033: VariantsMap = [
    &["battologized"],
    &["battologised"],
    &["battologized"],
    &["battologised"],
];

pub(crate) static ENTRY_BATTOLOGIZE_6326709828418364638: VariantsMap = [
    &["battologize"],
    &["battologise"],
    &["battologize"],
    &["battologise"],
];

pub(crate) static ENTRY_BATTOLOGIZING_14196182369779810637: VariantsMap = [
    &["battologizing"],
    &["battologising"],
    &["battologizing"],
    &["battologising"],
];

pub(crate) static ENTRY_BEAVERIZES_1624402153648919296: VariantsMap = [
    &["beaverizes"],
    &["beaverises"],
    &["beaverizes"],
    &["beaverises"],
];

pub(crate) static ENTRY_BEAVERIZE_1316372293858215780: VariantsMap = [
    &["beaverize"],
    &["beaverise"],
    &["beaverize"],
    &["beaverise"],
];

pub(crate) static ENTRY_BECLAMORED_17389757210006732941: VariantsMap = [
    &["beclamored"],
    &["beclamoured"],
    &["beclamoured"],
    &["beclamoured"],
];

pub(crate) static ENTRY_BECLAMORING_88231575150843084: VariantsMap = [
    &["beclamoring"],
    &["beclamouring"],
    &["beclamouring"],
    &["beclamouring"],
];

pub(crate) static ENTRY_BECLAMORS_4938562224073978012: VariantsMap = [
    &["beclamors"],
    &["beclamours"],
    &["beclamours"],
    &["beclamours"],
];

pub(crate) static ENTRY_BECLAMOR_13213568046754787546: VariantsMap = [
    &["beclamor"],
    &["beclamour"],
    &["beclamour"],
    &["beclamour"],
];

pub(crate) static ENTRY_BECOLOR_8246072713220014687: VariantsMap =
    [&["becolor"], &["becolour"], &["becolour"], &["becolour"]];

pub(crate) static ENTRY_BECUDGELED_16064927883688139127: VariantsMap = [
    &["becudgeled"],
    &["becudgelled"],
    &["becudgelled"],
    &["becudgelled"],
];

pub(crate) static ENTRY_BECUDGELING_3635344060375013463: VariantsMap = [
    &["becudgeling"],
    &["becudgelling"],
    &["becudgelling"],
    &["becudgelling"],
];

pub(crate) static ENTRY_BEDEVILED_11085714010658112928: VariantsMap = [
    &["bedeviled"],
    &["bedevilled"],
    &["bedevilled"],
    &["bedevilled"],
];

pub(crate) static ENTRY_BEDEVILING_10442109879718503775: VariantsMap = [
    &["bedeviling"],
    &["bedevilling"],
    &["bedevilling"],
    &["bedevilling"],
];

pub(crate) static ENTRY_BEDLAMIZED_14377714649143763251: VariantsMap = [
    &["bedlamized"],
    &["bedlamised"],
    &["bedlamized"],
    &["bedlamised"],
];

pub(crate) static ENTRY_BEDLAMIZES_18120257641318026287: VariantsMap = [
    &["bedlamizes"],
    &["bedlamises"],
    &["bedlamizes"],
    &["bedlamises"],
];

pub(crate) static ENTRY_BEDLAMIZE_12750005417077248018: VariantsMap = [
    &["bedlamize"],
    &["bedlamise"],
    &["bedlamize"],
    &["bedlamise"],
];

pub(crate) static ENTRY_BEDLAMIZING_12768565666893232436: VariantsMap = [
    &["bedlamizing"],
    &["bedlamising"],
    &["bedlamizing"],
    &["bedlamising"],
];

pub(crate) static ENTRY_BEDRIVELED_5247906579362000273: VariantsMap = [
    &["bedriveled"],
    &["bedrivelled"],
    &["bedrivelled"],
    &["bedrivelled"],
];

pub(crate) static ENTRY_BEDRIVELING_10705854559276626799: VariantsMap = [
    &["bedriveling"],
    &["bedrivelling"],
    &["bedrivelling"],
    &["bedrivelling"],
];

pub(crate) static ENTRY_BEERA_15480986539449585414: VariantsMap =
    [&["beera"], &["berea"], &["berea"], &["berea"]];

pub(crate) static ENTRY_BEFAVOR_65413849177555799: VariantsMap =
    [&["befavor"], &["befavour"], &["befavour"], &["befavour"]];

pub(crate) static ENTRY_BEGLAMORED_3590724218188773450: VariantsMap = [
    &["beglamored"],
    &["beglamoured"],
    &["beglamoured"],
    &["beglamoured"],
];

pub(crate) static ENTRY_BEGLAMORING_7478888583297948139: VariantsMap = [
    &["beglamoring"],
    &["beglamouring"],
    &["beglamouring"],
    &["beglamouring"],
];

pub(crate) static ENTRY_BEGLAMORS_10592558109463498103: VariantsMap = [
    &["beglamors"],
    &["beglamours"],
    &["beglamours"],
    &["beglamours"],
];

pub(crate) static ENTRY_BEGLAMOR_1703384101008507708: VariantsMap = [
    &["beglamor"],
    &["beglamour"],
    &["beglamour"],
    &["beglamour"],
];

pub(crate) static ENTRY_BEHAVIORALER_15849878698882095342: VariantsMap = [
    &["behavioraler"],
    &["behaviouraler"],
    &["behaviouraler"],
    &["behaviouraler"],
];

pub(crate) static ENTRY_BEHAVIORALEST_4676686848581067810: VariantsMap = [
    &["behavioralest"],
    &["behaviouralest"],
    &["behaviouralest"],
    &["behaviouralest"],
];

pub(crate) static ENTRY_BEHAVIORALLY_15603975909970219512: VariantsMap = [
    &["behaviorally"],
    &["behaviourally"],
    &["behaviourally"],
    &["behaviourally"],
];

pub(crate) static ENTRY_BEHAVIORAL_1668398487637965302: VariantsMap = [
    &["behavioral"],
    &["behavioural"],
    &["behavioural"],
    &["behavioural"],
];

pub(crate) static ENTRY_BEHAVIORED_329942682848905839: VariantsMap = [
    &["behaviored"],
    &["behavioured"],
    &["behavioured"],
    &["behavioured"],
];

pub(crate) static ENTRY_BEHAVIORISMS_18431005634091902550: VariantsMap = [
    &["behaviorisms"],
    &["behaviourisms"],
    &["behaviourisms"],
    &["behaviourisms"],
];

pub(crate) static ENTRY_BEHAVIORISM_16788531821804542526: VariantsMap = [
    &["behaviorism"],
    &["behaviourism"],
    &["behaviourism"],
    &["behaviourism"],
];

pub(crate) static ENTRY_BEHAVIORISTICER_1771754648963132210: VariantsMap = [
    &["behavioristicer"],
    &["behaviouristicer"],
    &["behaviouristicer"],
    &["behaviouristicer"],
];

pub(crate) static ENTRY_BEHAVIORISTICEST_13940464183699495590: VariantsMap = [
    &["behavioristicest"],
    &["behaviouristicest"],
    &["behaviouristicest"],
    &["behaviouristicest"],
];

pub(crate) static ENTRY_BEHAVIORISTICS_9644519070934483422: VariantsMap = [
    &["behavioristics"],
    &["behaviouristics"],
    &["behaviouristics"],
    &["behaviouristics"],
];

pub(crate) static ENTRY_BEHAVIORISTIC_10912467475164998417: VariantsMap = [
    &["behavioristic"],
    &["behaviouristic"],
    &["behaviouristic"],
    &["behaviouristic"],
];

pub(crate) static ENTRY_BEHAVIORISTS_2791913883690306158: VariantsMap = [
    &["behaviorists"],
    &["behaviourists"],
    &["behaviourists"],
    &["behaviourists"],
];

pub(crate) static ENTRY_BEHAVIORIST_538165502271076270: VariantsMap = [
    &["behaviorist"],
    &["behaviourist"],
    &["behaviourist"],
    &["behaviourist"],
];

pub(crate) static ENTRY_BEHAVIORS_17740975427353098200: VariantsMap = [
    &["behaviors"],
    &["behaviours"],
    &["behaviours"],
    &["behaviours"],
];

pub(crate) static ENTRY_BEHAVIOR_4270292057978962250: VariantsMap = [
    &["behavior"],
    &["behaviour"],
    &["behaviour"],
    &["behaviour"],
];

pub(crate) static ENTRY_BEHMENISM_499620659693586399: VariantsMap = [
    &["behmenism"],
    &["boehmenism"],
    &["boehmenism"],
    &["boehmenism"],
];

pub(crate) static ENTRY_BEHMENIST_10750646406222017241: VariantsMap = [
    &["behmenist"],
    &["boehmenist"],
    &["boehmenist"],
    &["boehmenist"],
];

pub(crate) static ENTRY_BEHMENITE_12524739850869681953: VariantsMap = [
    &["behmenite"],
    &["boehmenite"],
    &["boehmenite"],
    &["boehmenite"],
];

pub(crate) static ENTRY_BEHOOVED_19557981828125274: VariantsMap =
    [&["behooved"], &["behoved"], &["behooved"], &["behoved"]];

pub(crate) static ENTRY_BEHOOVES_18171198361790854374: VariantsMap =
    [&["behooves"], &["behoves"], &["behooves"], &["behoves"]];

pub(crate) static ENTRY_BEHOOVE_15601060046872655911: VariantsMap =
    [&["behoove"], &["behove"], &["behoove"], &["behove"]];

pub(crate) static ENTRY_BEHOOVINGLY_16685473934888809657: VariantsMap = [
    &["behoovingly"],
    &["behovingly"],
    &["behovingly"],
    &["behovingly"],
];

pub(crate) static ENTRY_BEHOOVINGS_5611929196356326751: VariantsMap = [
    &["behoovings"],
    &["behovings"],
    &["behoovings"],
    &["behovings"],
];

pub(crate) static ENTRY_BEHOOVING_8542587834338786394: VariantsMap =
    [&["behooving"], &["behoving"], &["behooving"], &["behoving"]];

pub(crate) static ENTRY_BEJEWELED_12216934890816407648: VariantsMap = [
    &["bejeweled"],
    &["bejewelled"],
    &["bejewelled"],
    &["bejewelled"],
];

pub(crate) static ENTRY_BEJEWELING_8804246701630066335: VariantsMap = [
    &["bejeweling"],
    &["bejewelling"],
    &["bejewelling"],
    &["bejewelling"],
];

pub(crate) static ENTRY_BELABORED_14959360057364846988: VariantsMap = [
    &["belabored"],
    &["belaboured"],
    &["belaboured"],
    &["belaboured"],
];

pub(crate) static ENTRY_BELABORING_16550814486427716841: VariantsMap = [
    &["belaboring"],
    &["belabouring"],
    &["belabouring"],
    &["belabouring"],
];

pub(crate) static ENTRY_BELABORS_9616903556092237149: VariantsMap = [
    &["belabors"],
    &["belabours"],
    &["belabours"],
    &["belabours"],
];

pub(crate) static ENTRY_BELABOR_2245031289291089410: VariantsMap =
    [&["belabor"], &["belabour"], &["belabour"], &["belabour"]];

pub(crate) static ENTRY_BELS_2245276628470254292: VariantsMap =
    [&["bels"], &["baels"], &["baels"], &["baels"]];

pub(crate) static ENTRY_BELTER_13842923605697161200: VariantsMap =
    [&["belter"], &["boelter"], &["boelter"], &["boelter"]];

pub(crate) static ENTRY_BELUS_4746563664174667391: VariantsMap =
    [&["belus"], &["boelus"], &["boelus"], &["boelus"]];

pub(crate) static ENTRY_BEL_707019223865679891: VariantsMap =
    [&["bel"], &["bael"], &["bael"], &["bael"]];

pub(crate) static ENTRY_BEMEDALED_10031388746689604055: VariantsMap = [
    &["bemedaled"],
    &["bemedalled"],
    &["bemedalled"],
    &["bemedalled"],
];

pub(crate) static ENTRY_BERIA_819349540939304958: VariantsMap =
    [&["beria"], &["baeria"], &["baeria"], &["baeria"]];

pub(crate) static ENTRY_BERLINIZES_5434619462225387670: VariantsMap = [
    &["berlinizes"],
    &["berlinises"],
    &["berlinizes"],
    &["berlinises"],
];

pub(crate) static ENTRY_BERLINIZE_3186846671412575655: VariantsMap = [
    &["berlinize"],
    &["berlinise"],
    &["berlinize"],
    &["berlinise"],
];

pub(crate) static ENTRY_BERLOQUE_15524756595685455268: VariantsMap =
    [&["berloque"], &["breloque"], &["breloque"], &["breloque"]];

pub(crate) static ENTRY_BERL_14276132883073000569: VariantsMap =
    [&["berl"], &["baerl"], &["baerl"], &["baerl"]];

pub(crate) static ENTRY_BERME_6583686006981215988: VariantsMap =
    [&["berme"], &["breme"], &["breme"], &["breme"]];

pub(crate) static ENTRY_BERN_2039740744291479118: VariantsMap =
    [&["bern"], &["bren"], &["bren"], &["bren"]];

pub(crate) static ENTRY_BESSEMERIZES_6933758975628828592: VariantsMap = [
    &["bessemerizes"],
    &["bessemerises"],
    &["bessemerizes"],
    &["bessemerises"],
];

pub(crate) static ENTRY_BESSEMERIZE_18021306106963646896: VariantsMap = [
    &["bessemerize"],
    &["bessemerise"],
    &["bessemerize"],
    &["bessemerise"],
];

pub(crate) static ENTRY_BESTIALIZED_15762278423047666998: VariantsMap = [
    &["bestialized"],
    &["bestialised"],
    &["bestialized"],
    &["bestialised"],
];

pub(crate) static ENTRY_BESTIALIZES_16507878437433357608: VariantsMap = [
    &["bestializes"],
    &["bestialises"],
    &["bestializes"],
    &["bestialises"],
];

pub(crate) static ENTRY_BESTIALIZE_13174936385032065942: VariantsMap = [
    &["bestialize"],
    &["bestialise"],
    &["bestialize"],
    &["bestialise"],
];

pub(crate) static ENTRY_BESTIALIZING_10183591289011144098: VariantsMap = [
    &["bestializing"],
    &["bestialising"],
    &["bestializing"],
    &["bestialising"],
];

pub(crate) static ENTRY_BEVELED_10378533536024013853: VariantsMap =
    [&["beveled"], &["bevelled"], &["bevelled"], &["bevelled"]];

pub(crate) static ENTRY_BEVELERS_1892360606418032248: VariantsMap = [
    &["bevelers"],
    &["bevellers"],
    &["bevellers"],
    &["bevellers"],
];

pub(crate) static ENTRY_BEVELER_2498982223785959149: VariantsMap =
    [&["beveler"], &["beveller"], &["beveller"], &["beveller"]];

pub(crate) static ENTRY_BEVELINGS_1501034049167710764: VariantsMap = [
    &["bevelings"],
    &["bevellings"],
    &["bevellings"],
    &["bevellings"],
];

pub(crate) static ENTRY_BEVELING_2110798044912558228: VariantsMap = [
    &["beveling"],
    &["bevelling"],
    &["bevelling"],
    &["bevelling"],
];

pub(crate) static ENTRY_BEYER_9811279797880466647: VariantsMap =
    [&["beyer"], &["baeyer"], &["baeyer"], &["baeyer"]];

pub(crate) static ENTRY_BIASED_15079696021925521823: VariantsMap =
    [&["biased"], &["biased"], &["biased"], &["biased"]];

pub(crate) static ENTRY_BIASING_18108238854297339846: VariantsMap =
    [&["biasing"], &["biasing"], &["biasing"], &["biasing"]];

pub(crate) static ENTRY_BICHROMATIZES_7036743462950211626: VariantsMap = [
    &["bichromatizes"],
    &["bichromatises"],
    &["bichromatizes"],
    &["bichromatises"],
];

pub(crate) static ENTRY_BICHROMATIZE_14037731889057409317: VariantsMap = [
    &["bichromatize"],
    &["bichromatise"],
    &["bichromatize"],
    &["bichromatise"],
];

pub(crate) static ENTRY_BICOLOREDDER_551370085079086375: VariantsMap = [
    &["bicoloredder"],
    &["bicolouredder"],
    &["bicolouredder"],
    &["bicolouredder"],
];

pub(crate) static ENTRY_BICOLOREDDEST_14358517370132765122: VariantsMap = [
    &["bicoloreddest"],
    &["bicoloureddest"],
    &["bicoloureddest"],
    &["bicoloureddest"],
];

pub(crate) static ENTRY_BICOLORED_17289525053828674330: VariantsMap = [
    &["bicolored"],
    &["bicoloured"],
    &["bicoloured"],
    &["bicoloured"],
];

pub(crate) static ENTRY_BICOLOROUS_6102303766253637672: VariantsMap = [
    &["bicolorous"],
    &["bicolourous"],
    &["bicolourous"],
    &["bicolourous"],
];

pub(crate) static ENTRY_BICOLORRER_14811846069806102443: VariantsMap = [
    &["bicolorrer"],
    &["bicolourer"],
    &["bicolourer"],
    &["bicolourer"],
];

pub(crate) static ENTRY_BICOLORREST_17887654307497270458: VariantsMap = [
    &["bicolorrest"],
    &["bicolourest"],
    &["bicolourest"],
    &["bicolourest"],
];

pub(crate) static ENTRY_BICOLORS_9018286664967288585: VariantsMap = [
    &["bicolors"],
    &["bicolours"],
    &["bicolours"],
    &["bicolours"],
];

pub(crate) static ENTRY_BICOLOR_9128517208708095659: VariantsMap =
    [&["bicolor"], &["bicolour"], &["bicolour"], &["bicolour"]];

pub(crate) static ENTRY_BIMETALISTIC_5316771108471812616: VariantsMap = [
    &["bimetalistic"],
    &["bimetallistic"],
    &["bimetallistic"],
    &["bimetallistic"],
];

pub(crate) static ENTRY_BIMETALIST_3660339346809516859: VariantsMap = [
    &["bimetalist"],
    &["bimetallist"],
    &["bimetallist"],
    &["bimetallist"],
];

pub(crate) static ENTRY_BINGEING_178843586653742040: VariantsMap =
    [&["bingeing"], &["bingeing"], &["bingeing"], &["bingeing"]];

pub(crate) static ENTRY_BIOCENOLOGY_4739588156815290106: VariantsMap = [
    &["biocenology"],
    &["biocoenology"],
    &["biocoenology"],
    &["biocoenology"],
];

pub(crate) static ENTRY_BIOCENOSES_16420882441598629495: VariantsMap = [
    &["biocenoses"],
    &["biocoenoses"],
    &["biocoenoses"],
    &["biocoenoses"],
];

pub(crate) static ENTRY_BIOCENOSE_7354639313277820088: VariantsMap = [
    &["biocenose"],
    &["biocoenose"],
    &["biocoenose"],
    &["biocoenose"],
];

pub(crate) static ENTRY_BIOCENOSIS_12225043537756921240: VariantsMap = [
    &["biocenosis"],
    &["biocoenosis"],
    &["biocoenosis"],
    &["biocoenosis"],
];

pub(crate) static ENTRY_BIOCENOTIC_2832610417337579792: VariantsMap = [
    &["biocenotic"],
    &["biocoenotic"],
    &["biocoenotic"],
    &["biocoenotic"],
];

pub(crate) static ENTRY_BIOGRAPHIZES_15117176767822609083: VariantsMap = [
    &["biographizes"],
    &["biographises"],
    &["biographizes"],
    &["biographises"],
];

pub(crate) static ENTRY_BIOGRAPHIZE_13042383107956929589: VariantsMap = [
    &["biographize"],
    &["biographise"],
    &["biographize"],
    &["biographise"],
];

pub(crate) static ENTRY_BIOLOGIZES_7227182445438079686: VariantsMap = [
    &["biologizes"],
    &["biologises"],
    &["biologizes"],
    &["biologises"],
];

pub(crate) static ENTRY_BIOLOGIZE_2366287950194440069: VariantsMap = [
    &["biologize"],
    &["biologise"],
    &["biologize"],
    &["biologise"],
];

pub(crate) static ENTRY_BIOSYNTHESIZED_4565096183549369524: VariantsMap = [
    &["biosynthesized"],
    &["biosynthesised"],
    &["biosynthesized"],
    &["biosynthesised"],
];

pub(crate) static ENTRY_BIPOLARIZATION_12827101324489098880: VariantsMap = [
    &["bipolarization"],
    &["bipolarisation"],
    &["bipolarization"],
    &["bipolarisation"],
];

pub(crate) static ENTRY_BIPOLARIZES_753154636413500379: VariantsMap = [
    &["bipolarizes"],
    &["bipolarises"],
    &["bipolarizes"],
    &["bipolarises"],
];

pub(crate) static ENTRY_BIPOLARIZE_701724772574228652: VariantsMap = [
    &["bipolarize"],
    &["bipolarise"],
    &["bipolarize"],
    &["bipolarise"],
];

pub(crate) static ENTRY_BIRMINGHAMIZES_7283882146218203623: VariantsMap = [
    &["birminghamizes"],
    &["birminghamises"],
    &["birminghamizes"],
    &["birminghamises"],
];

pub(crate) static ENTRY_BIRMINGHAMIZE_7467133353308120939: VariantsMap = [
    &["birminghamize"],
    &["birminghamise"],
    &["birminghamize"],
    &["birminghamise"],
];

pub(crate) static ENTRY_BISTEREDDER_3060766173300916233: VariantsMap = [
    &["bisteredder"],
    &["bistredder"],
    &["bistredder"],
    &["bistredder"],
];

pub(crate) static ENTRY_BISTEREDDEST_11484996203378675073: VariantsMap = [
    &["bistereddest"],
    &["bistreddest"],
    &["bistreddest"],
    &["bistreddest"],
];

pub(crate) static ENTRY_BISTERED_17553715744088785419: VariantsMap =
    [&["bistered"], &["bistred"], &["bistred"], &["bistred"]];

pub(crate) static ENTRY_BISTERS_7831835768196639468: VariantsMap =
    [&["bisters"], &["bistres"], &["bistres"], &["bistres"]];

pub(crate) static ENTRY_BISTER_10449402161913041976: VariantsMap =
    [&["bister"], &["bistre"], &["bistre"], &["bistre"]];

pub(crate) static ENTRY_BITTORS_588301274153684456: VariantsMap =
    [&["bittors"], &["bittours"], &["bittours"], &["bittours"]];

pub(crate) static ENTRY_BITTOR_368699142304285977: VariantsMap =
    [&["bittor"], &["bittour"], &["bittour"], &["bittour"]];

pub(crate) static ENTRY_BITUMINIZATIONS_8741287605557295138: VariantsMap = [
    &["bituminizations"],
    &["bituminisations"],
    &["bituminizations"],
    &["bituminisations"],
];

pub(crate) static ENTRY_BITUMINIZATION_9078464743577202911: VariantsMap = [
    &["bituminization"],
    &["bituminisation"],
    &["bituminization"],
    &["bituminisation"],
];

pub(crate) static ENTRY_BITUMINIZED_17383991200267975906: VariantsMap = [
    &["bituminized"],
    &["bituminised"],
    &["bituminized"],
    &["bituminised"],
];

pub(crate) static ENTRY_BITUMINIZES_18048041187765144366: VariantsMap = [
    &["bituminizes"],
    &["bituminises"],
    &["bituminizes"],
    &["bituminises"],
];

pub(crate) static ENTRY_BITUMINIZE_16758630164312898422: VariantsMap = [
    &["bituminize"],
    &["bituminise"],
    &["bituminize"],
    &["bituminise"],
];

pub(crate) static ENTRY_BITUMINIZING_16243512789065027030: VariantsMap = [
    &["bituminizing"],
    &["bituminising"],
    &["bituminizing"],
    &["bituminising"],
];

pub(crate) static ENTRY_BIZET_12028529403609023964: VariantsMap =
    [&["bizet"], &["biset"], &["bizet"], &["biset"]];

pub(crate) static ENTRY_BIZE_1335352806591900703: VariantsMap =
    [&["bize"], &["bise"], &["bize"], &["bise"]];

pub(crate) static ENTRY_BLAIZE_8547731719648738728: VariantsMap =
    [&["blaize"], &["blaise"], &["blaize"], &["blaise"]];

pub(crate) static ENTRY_BLAMABLE_2805926222821580419: VariantsMap = [
    &["blamable"],
    &["blameable"],
    &["blameable"],
    &["blameable"],
];

pub(crate) static ENTRY_BLASTOCELE_16551234140115187761: VariantsMap = [
    &["blastocele"],
    &["blastocoele"],
    &["blastocoele"],
    &["blastocoele"],
];

pub(crate) static ENTRY_BLASTULE_17366628524335612541: VariantsMap = [
    &["blastule"],
    &["blastulae"],
    &["blastulae"],
    &["blastulae"],
];

pub(crate) static ENTRY_BLENNEMESIS_12539251866010589867: VariantsMap = [
    &["blennemesis"],
    &["blennoemesis"],
    &["blennoemesis"],
    &["blennoemesis"],
];

pub(crate) static ENTRY_BLENNORRHEA_14826876051258215048: VariantsMap = [
    &["blennorrhea"],
    &["blennorrhoea"],
    &["blennorrhoea"],
    &["blennorrhoea"],
];

pub(crate) static ENTRY_BOEDROMIUS_9842947399769548785: VariantsMap = [
    &["boedromius"],
    &["boaedromius"],
    &["boaedromius"],
    &["boaedromius"],
];

pub(crate) static ENTRY_BOLED_15727675082763127085: VariantsMap =
    [&["boled"], &["boloed"], &["boloed"], &["boloed"]];

pub(crate) static ENTRY_BOLSHEVIZED_6673756303297064763: VariantsMap = [
    &["bolshevized"],
    &["bolshevised"],
    &["bolshevized"],
    &["bolshevised"],
];

pub(crate) static ENTRY_BOLSHEVIZES_6863516990622262590: VariantsMap = [
    &["bolshevizes"],
    &["bolshevises"],
    &["bolshevizes"],
    &["bolshevises"],
];

pub(crate) static ENTRY_BOLSHEVIZE_7610322087100944959: VariantsMap = [
    &["bolshevize"],
    &["bolshevise"],
    &["bolshevize"],
    &["bolshevise"],
];

pub(crate) static ENTRY_BOLSHEVIZING_18292009629655495635: VariantsMap = [
    &["bolshevizing"],
    &["bolshevising"],
    &["bolshevizing"],
    &["bolshevising"],
];

pub(crate) static ENTRY_BONDERIZE_15354415413556562398: VariantsMap = [
    &["bonderize"],
    &["bonderise"],
    &["bonderize"],
    &["bonderise"],
];

pub(crate) static ENTRY_BORAGE_12536470626004536619: VariantsMap =
    [&["borage"], &["bourage"], &["bourage"], &["bourage"]];

pub(crate) static ENTRY_BORASQUE_12894117064757155083: VariantsMap = [
    &["borasque"],
    &["bourasque"],
    &["bourasque"],
    &["bourasque"],
];

pub(crate) static ENTRY_BORDS_4097557745547974676: VariantsMap =
    [&["bords"], &["bourds"], &["bourds"], &["bourds"]];

pub(crate) static ENTRY_BORD_9769627334403333891: VariantsMap =
    [&["bord"], &["bourd"], &["bourd"], &["bourd"]];

pub(crate) static ENTRY_BORG_10492083036686991922: VariantsMap =
    [&["borg"], &["bourg"], &["bourg"], &["bourg"]];

pub(crate) static ENTRY_BORIZES_3258325603896619684: VariantsMap =
    [&["borizes"], &["borises"], &["borizes"], &["borises"]];

pub(crate) static ENTRY_BORIZE_9924789501684223687: VariantsMap =
    [&["borize"], &["borise"], &["borize"], &["borise"]];

pub(crate) static ENTRY_BOR_8171934536008579347: VariantsMap =
    [&["bor"], &["bour"], &["bour"], &["bour"]];

pub(crate) static ENTRY_BOSWELLIZED_16107372646692584162: VariantsMap = [
    &["boswellized"],
    &["boswellised"],
    &["boswellized"],
    &["boswellised"],
];

pub(crate) static ENTRY_BOSWELLIZES_13289068481348615807: VariantsMap = [
    &["boswellizes"],
    &["boswellises"],
    &["boswellizes"],
    &["boswellises"],
];

pub(crate) static ENTRY_BOSWELLIZE_6441210250172667640: VariantsMap = [
    &["boswellize"],
    &["boswellise"],
    &["boswellize"],
    &["boswellise"],
];

pub(crate) static ENTRY_BOSWELLIZING_1263019686128444085: VariantsMap = [
    &["boswellizing"],
    &["boswellising"],
    &["boswellizing"],
    &["boswellising"],
];

pub(crate) static ENTRY_BOTANIZED_6623624034808806509: VariantsMap = [
    &["botanized"],
    &["botanised"],
    &["botanized"],
    &["botanised"],
];

pub(crate) static ENTRY_BOTANIZER_12147213895328657457: VariantsMap = [
    &["botanizer"],
    &["botaniser"],
    &["botanizer"],
    &["botaniser"],
];

pub(crate) static ENTRY_BOTANIZES_3701375861091440735: VariantsMap = [
    &["botanizes"],
    &["botanises"],
    &["botanizes"],
    &["botanises"],
];

pub(crate) static ENTRY_BOTANIZE_3414900112803410859: VariantsMap =
    [&["botanize"], &["botanise"], &["botanize"], &["botanise"]];

pub(crate) static ENTRY_BOTANIZING_7854186980211713777: VariantsMap = [
    &["botanizing"],
    &["botanising"],
    &["botanizing"],
    &["botanising"],
];

pub(crate) static ENTRY_BOULDERS_9268529342784684955: VariantsMap =
    [&["boulders"], &["boulders"], &["boulders"], &["boulders"]];

pub(crate) static ENTRY_BOULDER_2537004730775027440: VariantsMap =
    [&["boulder"], &["boulder"], &["boulder"], &["boulder"]];

pub(crate) static ENTRY_BOULEVARDIZES_14884898377762838680: VariantsMap = [
    &["boulevardizes"],
    &["boulevardises"],
    &["boulevardizes"],
    &["boulevardises"],
];

pub(crate) static ENTRY_BOULEVARDIZE_8382934846655629979: VariantsMap = [
    &["boulevardize"],
    &["boulevardise"],
    &["boulevardize"],
    &["boulevardise"],
];

pub(crate) static ENTRY_BOURBONIZES_11928142486642420487: VariantsMap = [
    &["bourbonizes"],
    &["bourbonises"],
    &["bourbonizes"],
    &["bourbonises"],
];

pub(crate) static ENTRY_BOURBONIZE_17360958086154824656: VariantsMap = [
    &["bourbonize"],
    &["bourbonise"],
    &["bourbonize"],
    &["bourbonise"],
];

pub(crate) static ENTRY_BOWDLERIZATIONS_6775792789701362692: VariantsMap = [
    &["bowdlerizations"],
    &["bowdlerisations"],
    &["bowdlerizations"],
    &["bowdlerisations"],
];

pub(crate) static ENTRY_BOWDLERIZATION_8303366286031487639: VariantsMap = [
    &["bowdlerization"],
    &["bowdlerisation"],
    &["bowdlerization"],
    &["bowdlerisation"],
];

pub(crate) static ENTRY_BOWDLERIZED_4489335143117406489: VariantsMap = [
    &["bowdlerized"],
    &["bowdlerised"],
    &["bowdlerized"],
    &["bowdlerised"],
];

pub(crate) static ENTRY_BOWDLERIZERS_5755041647304781487: VariantsMap = [
    &["bowdlerizers"],
    &["bowdlerisers"],
    &["bowdlerizers"],
    &["bowdlerisers"],
];

pub(crate) static ENTRY_BOWDLERIZER_6233002729985543010: VariantsMap = [
    &["bowdlerizer"],
    &["bowdleriser"],
    &["bowdlerizer"],
    &["bowdleriser"],
];

pub(crate) static ENTRY_BOWDLERIZES_9741187207136026760: VariantsMap = [
    &["bowdlerizes"],
    &["bowdlerises"],
    &["bowdlerizes"],
    &["bowdlerises"],
];

pub(crate) static ENTRY_BOWDLERIZE_5456349648157007190: VariantsMap = [
    &["bowdlerize"],
    &["bowdlerise"],
    &["bowdlerize"],
    &["bowdlerise"],
];

pub(crate) static ENTRY_BOWDLERIZING_13774867242132431801: VariantsMap = [
    &["bowdlerizing"],
    &["bowdlerising"],
    &["bowdlerizing"],
    &["bowdlerising"],
];

pub(crate) static ENTRY_BOWELED_15475057737247232958: VariantsMap =
    [&["boweled"], &["bowelled"], &["bowelled"], &["bowelled"]];

pub(crate) static ENTRY_BOWELING_5722084722134662370: VariantsMap = [
    &["boweling"],
    &["bowelling"],
    &["bowelling"],
    &["bowelling"],
];

pub(crate) static ENTRY_BRADYPNEA_4442372327480029437: VariantsMap = [
    &["bradypnea"],
    &["bradypnoea"],
    &["bradypnoea"],
    &["bradypnoea"],
];

pub(crate) static ENTRY_BREATHALYZED_16539997499095919892: VariantsMap = [
    &["breathalyzed"],
    &["breathalysed"],
    &["breathalyzed"],
    &["breathalysed"],
];

pub(crate) static ENTRY_BREATHALYZERS_3691744749547968414: VariantsMap = [
    &["breathalyzers"],
    &["breathalysers"],
    &["breathalysers"],
    &["breathalysers"],
];

pub(crate) static ENTRY_BREATHALYZER_4271010669418934525: VariantsMap = [
    &["breathalyzer"],
    &["breathalyser"],
    &["breathalyser"],
    &["breathalyser"],
];

pub(crate) static ENTRY_BREATHALYZES_11235604268893682846: VariantsMap = [
    &["breathalyzes"],
    &["breathalyses"],
    &["breathalyzes"],
    &["breathalyses"],
];

pub(crate) static ENTRY_BREATHALYZE_10796683967425699198: VariantsMap = [
    &["breathalyze"],
    &["breathalyse"],
    &["breathalyze"],
    &["breathalyse"],
];

pub(crate) static ENTRY_BREATHALYZING_565448827730861286: VariantsMap = [
    &["breathalyzing"],
    &["breathalysing"],
    &["breathalyzing"],
    &["breathalysing"],
];

pub(crate) static ENTRY_BRIZA_3574958223447302377: VariantsMap =
    [&["briza"], &["brisa"], &["briza"], &["brisa"]];

pub(crate) static ENTRY_BROMETHYLENE_7740792685786840890: VariantsMap = [
    &["bromethylene"],
    &["bromoethylene"],
    &["bromoethylene"],
    &["bromoethylene"],
];

pub(crate) static ENTRY_BROMINIZES_5628408947482003092: VariantsMap = [
    &["brominizes"],
    &["brominises"],
    &["brominizes"],
    &["brominises"],
];

pub(crate) static ENTRY_BROMINIZE_8193002587551857917: VariantsMap = [
    &["brominize"],
    &["brominise"],
    &["brominize"],
    &["brominise"],
];

pub(crate) static ENTRY_BROMIZATION_5590155013784391685: VariantsMap = [
    &["bromization"],
    &["bromisation"],
    &["bromization"],
    &["bromisation"],
];

pub(crate) static ENTRY_BROMIZED_6586226641291200206: VariantsMap =
    [&["bromized"], &["bromised"], &["bromized"], &["bromised"]];

pub(crate) static ENTRY_BROMIZE_10848505058317064152: VariantsMap =
    [&["bromize"], &["bromise"], &["bromize"], &["bromise"]];

pub(crate) static ENTRY_BROMIZING_10490899539525336887: VariantsMap = [
    &["bromizing"],
    &["bromising"],
    &["bromizing"],
    &["bromising"],
];

pub(crate) static ENTRY_BRUTALIZATIONS_14281415064444405659: VariantsMap = [
    &["brutalizations"],
    &["brutalisations"],
    &["brutalizations"],
    &["brutalisations"],
];

pub(crate) static ENTRY_BRUTALIZATION_11293320142916899383: VariantsMap = [
    &["brutalization"],
    &["brutalisation"],
    &["brutalization"],
    &["brutalisation"],
];

pub(crate) static ENTRY_BRUTALIZED_12895970956896346273: VariantsMap = [
    &["brutalized"],
    &["brutalised"],
    &["brutalized"],
    &["brutalised"],
];

pub(crate) static ENTRY_BRUTALIZES_15844790462452513749: VariantsMap = [
    &["brutalizes"],
    &["brutalises"],
    &["brutalizes"],
    &["brutalises"],
];

pub(crate) static ENTRY_BRUTALIZE_13435719365361063955: VariantsMap = [
    &["brutalize"],
    &["brutalise"],
    &["brutalize"],
    &["brutalise"],
];

pub(crate) static ENTRY_BRUTALIZING_7797427754196540922: VariantsMap = [
    &["brutalizing"],
    &["brutalising"],
    &["brutalizing"],
    &["brutalising"],
];

pub(crate) static ENTRY_BUDENNY_8301048534741947517: VariantsMap =
    [&["budenny"], &["budaenny"], &["budaenny"], &["budaenny"]];

pub(crate) static ENTRY_BUREAUCRATIZATIONS_4674366041166989149: VariantsMap = [
    &["bureaucratizations"],
    &["bureaucratisations"],
    &["bureaucratizations"],
    &["bureaucratisations"],
];

pub(crate) static ENTRY_BUREAUCRATIZATION_7250957081103523449: VariantsMap = [
    &["bureaucratization"],
    &["bureaucratisation"],
    &["bureaucratization"],
    &["bureaucratisation"],
];

pub(crate) static ENTRY_BUREAUCRATIZED_4248245955080237225: VariantsMap = [
    &["bureaucratized"],
    &["bureaucratised"],
    &["bureaucratized"],
    &["bureaucratised"],
];

pub(crate) static ENTRY_BUREAUCRATIZES_16810259950475596086: VariantsMap = [
    &["bureaucratizes"],
    &["bureaucratises"],
    &["bureaucratizes"],
    &["bureaucratises"],
];

pub(crate) static ENTRY_BUREAUCRATIZE_13391150115061038607: VariantsMap = [
    &["bureaucratize"],
    &["bureaucratise"],
    &["bureaucratize"],
    &["bureaucratise"],
];

pub(crate) static ENTRY_BUREAUCRATIZING_8025017160589580538: VariantsMap = [
    &["bureaucratizing"],
    &["bureaucratising"],
    &["bureaucratizing"],
    &["bureaucratising"],
];

pub(crate) static ENTRY_BURGLARIZED_5921030312710381425: VariantsMap = [
    &["burglarized"],
    &["burglarised"],
    &["burglarized"],
    &["burglarised"],
];

pub(crate) static ENTRY_BURGLARIZES_13866286421224924410: VariantsMap = [
    &["burglarizes"],
    &["burglarises"],
    &["burglarizes"],
    &["burglarises"],
];

pub(crate) static ENTRY_BURGLARIZE_1087475814106005332: VariantsMap = [
    &["burglarize"],
    &["burglarise"],
    &["burglarize"],
    &["burglarise"],
];

pub(crate) static ENTRY_BURGLARIZING_18147959943236525815: VariantsMap = [
    &["burglarizing"],
    &["burglarising"],
    &["burglarizing"],
    &["burglarising"],
];

pub(crate) static ENTRY_BURKAS_12070614531615578820: VariantsMap = [
    &["burkas"],
    &["burkas", "burkhas", "burqas"],
    &["burkas", "burkhas", "burqas"],
    &["burqas"],
];

pub(crate) static ENTRY_BURKA_17738439542425653268: VariantsMap = [
    &["burka"],
    &["burka", "burkha", "burqa"],
    &["burka", "burkha", "burqa"],
    &["burqa"],
];

pub(crate) static ENTRY_BURNETTIZED_13756375894148665827: VariantsMap = [
    &["burnettized"],
    &["burnettised"],
    &["burnettized"],
    &["burnettised"],
];

pub(crate) static ENTRY_BURNETTIZES_16655928180448576506: VariantsMap = [
    &["burnettizes"],
    &["burnettises"],
    &["burnettizes"],
    &["burnettises"],
];

pub(crate) static ENTRY_BURNETTIZE_7862530595152906990: VariantsMap = [
    &["burnettize"],
    &["burnettise"],
    &["burnettize"],
    &["burnettise"],
];

pub(crate) static ENTRY_BURNETTIZING_4527669031334060280: VariantsMap = [
    &["burnettizing"],
    &["burnettising"],
    &["burnettizing"],
    &["burnettising"],
];

pub(crate) static ENTRY_BUSHELED_1994274500105410677: VariantsMap = [
    &["busheled"],
    &["bushelled"],
    &["bushelled"],
    &["bushelled"],
];

pub(crate) static ENTRY_BUSHELERS_8897857104840276712: VariantsMap = [
    &["bushelers"],
    &["bushellers"],
    &["bushellers"],
    &["bushellers"],
];

pub(crate) static ENTRY_BUSHELER_17155781392383988946: VariantsMap = [
    &["busheler"],
    &["busheller"],
    &["busheller"],
    &["busheller"],
];

pub(crate) static ENTRY_BUSHELINGS_2758606437123004621: VariantsMap = [
    &["bushelings"],
    &["bushellings"],
    &["bushellings"],
    &["bushellings"],
];

pub(crate) static ENTRY_BUSHELING_1847310694202977393: VariantsMap = [
    &["busheling"],
    &["bushelling"],
    &["bushelling"],
    &["bushelling"],
];

pub(crate) static ENTRY_BUSINGS_8757237867622763594: VariantsMap =
    [&["busings"], &["bussings"], &["busings"], &["bussings"]];

pub(crate) static ENTRY_BYRONIZES_18201297154455431805: VariantsMap = [
    &["byronizes"],
    &["byronises"],
    &["byronizes"],
    &["byronises"],
];

pub(crate) static ENTRY_BYRONIZE_16464968414469440781: VariantsMap =
    [&["byronize"], &["byronise"], &["byronize"], &["byronise"]];

pub(crate) static ENTRY_BYZANTINIZES_11684453378746621577: VariantsMap = [
    &["byzantinizes"],
    &["byzantinises"],
    &["byzantinizes"],
    &["byzantinises"],
];

pub(crate) static ENTRY_BYZANTINIZE_12213067988390048109: VariantsMap = [
    &["byzantinize"],
    &["byzantinise"],
    &["byzantinize"],
    &["byzantinise"],
];

pub(crate) static ENTRY_CACESTHESIA_2765173217323765779: VariantsMap = [
    &["cacesthesia"],
    &["cacaesthesia"],
    &["cacaesthesia"],
    &["cacaesthesia"],
];

pub(crate) static ENTRY_CACHEMIA_16393627162115505894: VariantsMap = [
    &["cachemia"],
    &["cachaemia"],
    &["cachaemia"],
    &["cachaemia"],
];

pub(crate) static ENTRY_CACHEMIC_14712432132181211487: VariantsMap = [
    &["cachemic"],
    &["cachaemic"],
    &["cachaemic"],
    &["cachaemic"],
];

pub(crate) static ENTRY_CACODEMONIAC_5130334321528000087: VariantsMap = [
    &["cacodemoniac"],
    &["cacodaemoniac"],
    &["cacodaemoniac"],
    &["cacodaemoniac"],
];

pub(crate) static ENTRY_CACODEMONIAL_6128539527465489160: VariantsMap = [
    &["cacodemonial"],
    &["cacodaemonial"],
    &["cacodaemonial"],
    &["cacodaemonial"],
];

pub(crate) static ENTRY_CACODEMONIC_5648165095725544727: VariantsMap = [
    &["cacodemonic"],
    &["cacodaemonic"],
    &["cacodaemonic"],
    &["cacodaemonic"],
];

pub(crate) static ENTRY_CACODEMONS_16329535367132592196: VariantsMap = [
    &["cacodemons"],
    &["cacodaemons"],
    &["cacodaemons"],
    &["cacodaemons"],
];

pub(crate) static ENTRY_CACODEMON_5420155303899502846: VariantsMap = [
    &["cacodemon"],
    &["cacodaemon"],
    &["cacodaemon"],
    &["cacodaemon"],
];

pub(crate) static ENTRY_CACOETHES_15396969546538260310: VariantsMap = [
    &["cacoethes"],
    &["cacoaethes"],
    &["cacoaethes"],
    &["cacoaethes"],
];

pub(crate) static ENTRY_CADASTERS_6862701278625162442: VariantsMap = [
    &["cadasters"],
    &["cadastres"],
    &["cadastres"],
    &["cadastres"],
];

pub(crate) static ENTRY_CADASTER_1284848465582914080: VariantsMap =
    [&["cadaster"], &["cadastre"], &["cadastre"], &["cadastre"]];

pub(crate) static ENTRY_CADAVERIZES_3809238108442329357: VariantsMap = [
    &["cadaverizes"],
    &["cadaverises"],
    &["cadaverizes"],
    &["cadaverises"],
];

pub(crate) static ENTRY_CADAVERIZE_14270258494884550711: VariantsMap = [
    &["cadaverize"],
    &["cadaverise"],
    &["cadaverize"],
    &["cadaverise"],
];

pub(crate) static ENTRY_CADMIUMIZES_15932160358276911610: VariantsMap = [
    &["cadmiumizes"],
    &["cadmiumises"],
    &["cadmiumizes"],
    &["cadmiumises"],
];

pub(crate) static ENTRY_CADMIUMIZE_4596925533129834601: VariantsMap = [
    &["cadmiumize"],
    &["cadmiumise"],
    &["cadmiumize"],
    &["cadmiumise"],
];

pub(crate) static ENTRY_CAESARIZES_8074863442512394703: VariantsMap = [
    &["caesarizes"],
    &["caesarises"],
    &["caesarizes"],
    &["caesarises"],
];

pub(crate) static ENTRY_CAESARIZE_18266155686129237935: VariantsMap = [
    &["caesarize"],
    &["caesarise"],
    &["caesarize"],
    &["caesarise"],
];

pub(crate) static ENTRY_CAFFER_9506538294723235326: VariantsMap =
    [&["caffer"], &["caffre"], &["caffre"], &["caffre"]];

pub(crate) static ENTRY_CALANDER_8386886117613566628: VariantsMap =
    [&["calander"], &["calandre"], &["calandre"], &["calandre"]];

pub(crate) static ENTRY_CALCEMIA_13780473444512332487: VariantsMap = [
    &["calcemia"],
    &["calcaemia"],
    &["calcaemia"],
    &["calcaemia"],
];

pub(crate) static ENTRY_CALENDARIZATIONS_1625472196367375880: VariantsMap = [
    &["calendarizations"],
    &["calendarisations"],
    &["calendarizations"],
    &["calendarisations"],
];

pub(crate) static ENTRY_CALENDARIZATION_3319078431557619935: VariantsMap = [
    &["calendarization"],
    &["calendarisation"],
    &["calendarization"],
    &["calendarisation"],
];

pub(crate) static ENTRY_CALENDARIZED_11715564102717219815: VariantsMap = [
    &["calendarized"],
    &["calendarised"],
    &["calendarized"],
    &["calendarised"],
];

pub(crate) static ENTRY_CALENDARIZES_3253812247299622139: VariantsMap = [
    &["calendarizes"],
    &["calendarises"],
    &["calendarizes"],
    &["calendarises"],
];

pub(crate) static ENTRY_CALENDARIZE_1440485717876612344: VariantsMap = [
    &["calendarize"],
    &["calendarise"],
    &["calendarize"],
    &["calendarise"],
];

pub(crate) static ENTRY_CALENDARIZING_7884481787335064911: VariantsMap = [
    &["calendarizing"],
    &["calendarising"],
    &["calendarizing"],
    &["calendarising"],
];

pub(crate) static ENTRY_CALENDER_18426116015986884728: VariantsMap =
    [&["calender"], &["calendre"], &["calendre"], &["calendre"]];

pub(crate) static ENTRY_CALIBERS_12175169505129012964: VariantsMap =
    [&["calibers"], &["calibres"], &["calibres"], &["calibres"]];

pub(crate) static ENTRY_CALIBER_11979237421213696401: VariantsMap =
    [&["caliber"], &["calibre"], &["calibre"], &["calibre"]];

pub(crate) static ENTRY_CALIPERED_15148589818375924712: VariantsMap = [
    &["calipered"],
    &["calipered"],
    &["calipered"],
    &["calipered"],
];

pub(crate) static ENTRY_CALIPERING_13878626335317126988: VariantsMap = [
    &["calipering"],
    &["calipering"],
    &["calipering"],
    &["calipering"],
];

pub(crate) static ENTRY_CALIPERS_1796103950790864970: VariantsMap =
    [&["calipers"], &["calipers"], &["calipers"], &["calipers"]];

pub(crate) static ENTRY_CALIPER_11659384912162704496: VariantsMap =
    [&["caliper"], &["caliper"], &["caliper"], &["caliper"]];

pub(crate) static ENTRY_CALISTHENICS_8747499938229310952: VariantsMap = [
    &["calisthenics"],
    &["callisthenics"],
    &["calisthenics"],
    &["callisthenics"],
];

pub(crate) static ENTRY_CALISTHENIC_1074720409180890750: VariantsMap = [
    &["calisthenic"],
    &["callisthenic"],
    &["calisthenic"],
    &["callisthenic"],
];

pub(crate) static ENTRY_CALKED_17587227683338315155: VariantsMap =
    [&["calked"], &["caulked"], &["caulked"], &["caulked"]];

pub(crate) static ENTRY_CALKING_15122106954759194192: VariantsMap =
    [&["calking"], &["caulking"], &["caulking"], &["caulking"]];

pub(crate) static ENTRY_CALKS_3513793957936189042: VariantsMap =
    [&["calks"], &["caulks"], &["caulks"], &["caulks"]];

pub(crate) static ENTRY_CALK_9463720069156928103: VariantsMap =
    [&["calk"], &["caulk"], &["caulk"], &["caulk"]];

pub(crate) static ENTRY_CALLIRRHOE_14193156888455455215: VariantsMap = [
    &["callirrhoe"],
    &["callirrhoae"],
    &["callirrhoae"],
    &["callirrhoae"],
];

pub(crate) static ENTRY_CALODEMON_9407569777520507468: VariantsMap = [
    &["calodemon"],
    &["calodaemon"],
    &["calodaemon"],
    &["calodaemon"],
];

pub(crate) static ENTRY_CALVINIZES_17919041968297410767: VariantsMap = [
    &["calvinizes"],
    &["calvinises"],
    &["calvinizes"],
    &["calvinises"],
];

pub(crate) static ENTRY_CALVINIZE_3085273063367597860: VariantsMap = [
    &["calvinize"],
    &["calvinise"],
    &["calvinize"],
    &["calvinise"],
];

pub(crate) static ENTRY_CAMISADES_723999954797250701: VariantsMap = [
    &["camisades"],
    &["camisadoes"],
    &["camisadoes"],
    &["camisadoes"],
];

pub(crate) static ENTRY_CAMIZE_5273973185736720772: VariantsMap =
    [&["camize"], &["camise"], &["camize"], &["camise"]];

pub(crate) static ENTRY_CANADIANIZATIONS_5629413944017512120: VariantsMap = [
    &["canadianizations"],
    &["canadianisations"],
    &["canadianizations"],
    &["canadianisations"],
];

pub(crate) static ENTRY_CANADIANIZATION_13182443901388656095: VariantsMap = [
    &["canadianization"],
    &["canadianisation"],
    &["canadianization"],
    &["canadianisation"],
];

pub(crate) static ENTRY_CANADIANIZES_7814286041803724506: VariantsMap = [
    &["canadianizes"],
    &["canadianises"],
    &["canadianizes"],
    &["canadianises"],
];

pub(crate) static ENTRY_CANADIANIZE_14378401002580150005: VariantsMap = [
    &["canadianize"],
    &["canadianise"],
    &["canadianize"],
    &["canadianise"],
];

pub(crate) static ENTRY_CANALED_17712164795851355663: VariantsMap =
    [&["canaled"], &["canalled"], &["canalled"], &["canalled"]];

pub(crate) static ENTRY_CANALERS_3633550320132459566: VariantsMap = [
    &["canalers"],
    &["canallers"],
    &["canallers"],
    &["canallers"],
];

pub(crate) static ENTRY_CANALER_2156584751369726138: VariantsMap =
    [&["canaler"], &["canaller"], &["canaller"], &["canaller"]];

pub(crate) static ENTRY_CANALING_14175464379981390017: VariantsMap = [
    &["canaling"],
    &["canalling"],
    &["canalling"],
    &["canalling"],
];

pub(crate) static ENTRY_CANALIZATIONS_13532066641589359430: VariantsMap = [
    &["canalizations"],
    &["canalisations"],
    &["canalizations"],
    &["canalisations"],
];

pub(crate) static ENTRY_CANALIZATION_13228363861342779584: VariantsMap = [
    &["canalization"],
    &["canalisation"],
    &["canalization"],
    &["canalisation"],
];

pub(crate) static ENTRY_CANALIZED_8165057117631879852: VariantsMap = [
    &["canalized"],
    &["canalised"],
    &["canalized"],
    &["canalised"],
];

pub(crate) static ENTRY_CANALIZES_49113899823800782: VariantsMap = [
    &["canalizes"],
    &["canalises"],
    &["canalizes"],
    &["canalises"],
];

pub(crate) static ENTRY_CANALIZE_3951994517517182635: VariantsMap =
    [&["canalize"], &["canalise"], &["canalize"], &["canalise"]];

pub(crate) static ENTRY_CANALIZING_5717449398288828945: VariantsMap = [
    &["canalizing"],
    &["canalising"],
    &["canalizing"],
    &["canalising"],
];

pub(crate) static ENTRY_CANANEAN_15332949567639306041: VariantsMap = [
    &["cananean"],
    &["cananaean"],
    &["cananaean"],
    &["cananaean"],
];

pub(crate) static ENTRY_CANCELABLE_3722417889172603824: VariantsMap = [
    &["cancelable"],
    &["cancellable"],
    &["cancellable"],
    &["cancellable"],
];

pub(crate) static ENTRY_CANCELATED_10962527112084997064: VariantsMap = [
    &["cancelated"],
    &["cancellated"],
    &["cancellated"],
    &["cancellated"],
];

pub(crate) static ENTRY_CANCELATE_13935007740694861299: VariantsMap = [
    &["cancelate"],
    &["cancellate"],
    &["cancellate"],
    &["cancellate"],
];

pub(crate) static ENTRY_CANCELED_12672342492571604224: VariantsMap = [
    &["canceled"],
    &["cancelled"],
    &["cancelled"],
    &["cancelled"],
];

pub(crate) static ENTRY_CANCELERS_3981532768174175193: VariantsMap = [
    &["cancelers"],
    &["cancellers"],
    &["cancellers"],
    &["cancellers"],
];

pub(crate) static ENTRY_CANCELER_12983343936465600908: VariantsMap = [
    &["canceler"],
    &["canceller"],
    &["canceller"],
    &["canceller"],
];

pub(crate) static ENTRY_CANCELING_16146260375495786001: VariantsMap = [
    &["canceling"],
    &["cancelling"],
    &["cancelling"],
    &["cancelling"],
];

pub(crate) static ENTRY_CANCELLATION_1555414462165920792: VariantsMap = [
    &["cancellation"],
    &["cancellation"],
    &["cancellation"],
    &["cancellation"],
];

pub(crate) static ENTRY_CANCELOUS_15814136391491262355: VariantsMap = [
    &["cancelous"],
    &["cancellous"],
    &["cancellous"],
    &["cancellous"],
];

pub(crate) static ENTRY_CANDORS_11609560572454050104: VariantsMap =
    [&["candors"], &["candours"], &["candours"], &["candours"]];

pub(crate) static ENTRY_CANDOR_10788361890221941916: VariantsMap =
    [&["candor"], &["candour"], &["candour"], &["candour"]];

pub(crate) static ENTRY_CANEPHORE_18005220336274276713: VariantsMap = [
    &["canephore"],
    &["canephorae"],
    &["canephorae"],
    &["canephorae"],
];

pub(crate) static ENTRY_CANEPHORE_2517412738369461952: VariantsMap = [
    &["canephore"],
    &["canephoroe"],
    &["canephoroe"],
    &["canephoroe"],
];

pub(crate) static ENTRY_CANISTERIZATIONS_8729750327946936371: VariantsMap = [
    &["canisterizations"],
    &["canisterisations"],
    &["canisterizations"],
    &["canisterisations"],
];

pub(crate) static ENTRY_CANISTERIZATION_880939025211064061: VariantsMap = [
    &["canisterization"],
    &["canisterisation"],
    &["canisterization"],
    &["canisterisation"],
];

pub(crate) static ENTRY_CANISTERIZED_12280345176842641097: VariantsMap = [
    &["canisterized"],
    &["canisterised"],
    &["canisterized"],
    &["canisterised"],
];

pub(crate) static ENTRY_CANISTERIZES_10797600836947335811: VariantsMap = [
    &["canisterizes"],
    &["canisterises"],
    &["canisterizes"],
    &["canisterises"],
];

pub(crate) static ENTRY_CANISTERIZE_1796105525730141958: VariantsMap = [
    &["canisterize"],
    &["canisterise"],
    &["canisterize"],
    &["canisterise"],
];

pub(crate) static ENTRY_CANISTERIZING_4750329974636684269: VariantsMap = [
    &["canisterizing"],
    &["canisterising"],
    &["canisterizing"],
    &["canisterising"],
];

pub(crate) static ENTRY_CANNIBALIZATIONS_8053294690714421066: VariantsMap = [
    &["cannibalizations"],
    &["cannibalisations"],
    &["cannibalizations"],
    &["cannibalisations"],
];

pub(crate) static ENTRY_CANNIBALIZATION_10362383723962441168: VariantsMap = [
    &["cannibalization"],
    &["cannibalisation"],
    &["cannibalization"],
    &["cannibalisation"],
];

pub(crate) static ENTRY_CANNIBALIZED_13179636865120338437: VariantsMap = [
    &["cannibalized"],
    &["cannibalised"],
    &["cannibalized"],
    &["cannibalised"],
];

pub(crate) static ENTRY_CANNIBALIZES_5843119974222450091: VariantsMap = [
    &["cannibalizes"],
    &["cannibalises"],
    &["cannibalizes"],
    &["cannibalises"],
];

pub(crate) static ENTRY_CANNIBALIZE_12913259420777918440: VariantsMap = [
    &["cannibalize"],
    &["cannibalise"],
    &["cannibalize"],
    &["cannibalise"],
];

pub(crate) static ENTRY_CANNIBALIZING_16266472115659513272: VariantsMap = [
    &["cannibalizing"],
    &["cannibalising"],
    &["cannibalizing"],
    &["cannibalising"],
];

pub(crate) static ENTRY_CANONICALIZATION_9680284371048473324: VariantsMap = [
    &["canonicalization"],
    &["canonicalisation"],
    &["canonicalization"],
    &["canonicalisation"],
];

pub(crate) static ENTRY_CANONICALIZED_10333001095762961835: VariantsMap = [
    &["canonicalized"],
    &["canonicalised"],
    &["canonicalized"],
    &["canonicalised"],
];

pub(crate) static ENTRY_CANONICALIZES_18024856614090090716: VariantsMap = [
    &["canonicalizes"],
    &["canonicalises"],
    &["canonicalizes"],
    &["canonicalises"],
];

pub(crate) static ENTRY_CANONICALIZE_1859043615515179894: VariantsMap = [
    &["canonicalize"],
    &["canonicalise"],
    &["canonicalize"],
    &["canonicalise"],
];

pub(crate) static ENTRY_CANONICALIZING_284685826070047061: VariantsMap = [
    &["canonicalizing"],
    &["canonicalising"],
    &["canonicalizing"],
    &["canonicalising"],
];

pub(crate) static ENTRY_CANONIZATIONS_1884767107904362564: VariantsMap = [
    &["canonizations"],
    &["canonisations"],
    &["canonizations"],
    &["canonisations"],
];

pub(crate) static ENTRY_CANONIZATION_2650997251769306758: VariantsMap = [
    &["canonization"],
    &["canonisation"],
    &["canonization"],
    &["canonisation"],
];

pub(crate) static ENTRY_CANONIZED_15761367761494193573: VariantsMap = [
    &["canonized"],
    &["canonised"],
    &["canonized"],
    &["canonised"],
];

pub(crate) static ENTRY_CANONIZERS_9782656344877819576: VariantsMap = [
    &["canonizers"],
    &["canonisers"],
    &["canonizers"],
    &["canonisers"],
];

pub(crate) static ENTRY_CANONIZER_9593339360985297224: VariantsMap = [
    &["canonizer"],
    &["canoniser"],
    &["canonizer"],
    &["canoniser"],
];

pub(crate) static ENTRY_CANONIZES_9784118345073131908: VariantsMap = [
    &["canonizes"],
    &["canonises"],
    &["canonizes"],
    &["canonises"],
];

pub(crate) static ENTRY_CANONIZE_3694127234765675696: VariantsMap =
    [&["canonize"], &["canonise"], &["canonize"], &["canonise"]];

pub(crate) static ENTRY_CANONIZING_2446378015323590313: VariantsMap = [
    &["canonizing"],
    &["canonising"],
    &["canonizing"],
    &["canonising"],
];

pub(crate) static ENTRY_CANTALOUPES_964160501109699483: VariantsMap = [
    &["cantaloupes"],
    &["cantaloupes"],
    &["cantaloupes"],
    &["cantaloupes"],
];

pub(crate) static ENTRY_CANTALOUPE_16173297872474332016: VariantsMap = [
    &["cantaloupe"],
    &["cantaloupe"],
    &["cantaloupe"],
    &["cantaloupe"],
];

pub(crate) static ENTRY_CANTONIZATIONS_11360567398468706238: VariantsMap = [
    &["cantonizations"],
    &["cantonisations"],
    &["cantonizations"],
    &["cantonisations"],
];

pub(crate) static ENTRY_CANTONIZATION_10099357276016788559: VariantsMap = [
    &["cantonization"],
    &["cantonisation"],
    &["cantonization"],
    &["cantonisation"],
];

pub(crate) static ENTRY_CANTONIZED_14617271008182532990: VariantsMap = [
    &["cantonized"],
    &["cantonised"],
    &["cantonized"],
    &["cantonised"],
];

pub(crate) static ENTRY_CANTONIZES_16402920802638687919: VariantsMap = [
    &["cantonizes"],
    &["cantonises"],
    &["cantonizes"],
    &["cantonises"],
];

pub(crate) static ENTRY_CANTONIZE_12488382334775453573: VariantsMap = [
    &["cantonize"],
    &["cantonise"],
    &["cantonize"],
    &["cantonise"],
];

pub(crate) static ENTRY_CANTONIZING_9432387339924117920: VariantsMap = [
    &["cantonizing"],
    &["cantonising"],
    &["cantonizing"],
    &["cantonising"],
];

pub(crate) static ENTRY_CAPITALIZABLER_603529729414520201: VariantsMap = [
    &["capitalizabler"],
    &["capitalisabler"],
    &["capitalizabler"],
    &["capitalisabler"],
];

pub(crate) static ENTRY_CAPITALIZABLEST_2355759451940673988: VariantsMap = [
    &["capitalizablest"],
    &["capitalisablest"],
    &["capitalizablest"],
    &["capitalisablest"],
];

pub(crate) static ENTRY_CAPITALIZABLES_6813737836463367704: VariantsMap = [
    &["capitalizables"],
    &["capitalisables"],
    &["capitalizables"],
    &["capitalisables"],
];

pub(crate) static ENTRY_CAPITALIZABLE_2549388273733202801: VariantsMap = [
    &["capitalizable"],
    &["capitalisable"],
    &["capitalizable"],
    &["capitalisable"],
];

pub(crate) static ENTRY_CAPITALIZATIONS_12418153595184643992: VariantsMap = [
    &["capitalizations"],
    &["capitalisations"],
    &["capitalizations"],
    &["capitalisations"],
];

pub(crate) static ENTRY_CAPITALIZATION_701575089089546433: VariantsMap = [
    &["capitalization"],
    &["capitalisation"],
    &["capitalization"],
    &["capitalisation"],
];

pub(crate) static ENTRY_CAPITALIZED_16586381829524591032: VariantsMap = [
    &["capitalized"],
    &["capitalised"],
    &["capitalized"],
    &["capitalised"],
];

pub(crate) static ENTRY_CAPITALIZERS_13568479603381288355: VariantsMap = [
    &["capitalizers"],
    &["capitalisers"],
    &["capitalizers"],
    &["capitalisers"],
];

pub(crate) static ENTRY_CAPITALIZER_17721887205362296803: VariantsMap = [
    &["capitalizer"],
    &["capitaliser"],
    &["capitalizer"],
    &["capitaliser"],
];

pub(crate) static ENTRY_CAPITALIZES_8346787254057235765: VariantsMap = [
    &["capitalizes"],
    &["capitalises"],
    &["capitalizes"],
    &["capitalises"],
];

pub(crate) static ENTRY_CAPITALIZE_14987270073189981607: VariantsMap = [
    &["capitalize"],
    &["capitalise"],
    &["capitalize"],
    &["capitalise"],
];

pub(crate) static ENTRY_CAPITALIZING_12592559899378813681: VariantsMap = [
    &["capitalizing"],
    &["capitalising"],
    &["capitalizing"],
    &["capitalising"],
];

pub(crate) static ENTRY_CAPONIZATION_16648254879201289773: VariantsMap = [
    &["caponization"],
    &["caponisation"],
    &["caponization"],
    &["caponisation"],
];

pub(crate) static ENTRY_CAPONIZED_3599983764436663496: VariantsMap = [
    &["caponized"],
    &["caponised"],
    &["caponized"],
    &["caponised"],
];

pub(crate) static ENTRY_CAPONIZER_2937515815991396532: VariantsMap = [
    &["caponizer"],
    &["caponiser"],
    &["caponizer"],
    &["caponiser"],
];

pub(crate) static ENTRY_CAPONIZES_8112348068369020206: VariantsMap = [
    &["caponizes"],
    &["caponises"],
    &["caponizes"],
    &["caponises"],
];

pub(crate) static ENTRY_CAPONIZE_7723124127427821667: VariantsMap =
    [&["caponize"], &["caponise"], &["caponize"], &["caponise"]];

pub(crate) static ENTRY_CAPONIZING_4731137034979888377: VariantsMap = [
    &["caponizing"],
    &["caponising"],
    &["caponizing"],
    &["caponising"],
];

pub(crate) static ENTRY_CAPSULIZATION_12994547982797650921: VariantsMap = [
    &["capsulization"],
    &["capsulisation"],
    &["capsulization"],
    &["capsulisation"],
];

pub(crate) static ENTRY_CAPSULIZED_15163714329989053697: VariantsMap = [
    &["capsulized"],
    &["capsulised"],
    &["capsulized"],
    &["capsulised"],
];

pub(crate) static ENTRY_CAPSULIZES_6046785573783515511: VariantsMap = [
    &["capsulizes"],
    &["capsulises"],
    &["capsulizes"],
    &["capsulises"],
];

pub(crate) static ENTRY_CAPSULIZE_8925469580586567241: VariantsMap = [
    &["capsulize"],
    &["capsulise"],
    &["capsulize"],
    &["capsulise"],
];

pub(crate) static ENTRY_CAPSULIZING_14108763304053705443: VariantsMap = [
    &["capsulizing"],
    &["capsulising"],
    &["capsulizing"],
    &["capsulising"],
];

pub(crate) static ENTRY_CARACOLED_17261812764511727457: VariantsMap = [
    &["caracoled"],
    &["caracolled"],
    &["caracolled"],
    &["caracolled"],
];

pub(crate) static ENTRY_CARACOLING_3661744636660380050: VariantsMap = [
    &["caracoling"],
    &["caracolling"],
    &["caracolling"],
    &["caracolling"],
];

pub(crate) static ENTRY_CARAMELIZATIONS_2385837672145447407: VariantsMap = [
    &["caramelizations"],
    &["caramelisations"],
    &["caramelizations"],
    &["caramelisations"],
];

pub(crate) static ENTRY_CARAMELIZATION_12515762504964341677: VariantsMap = [
    &["caramelization"],
    &["caramelisation"],
    &["caramelization"],
    &["caramelisation"],
];

pub(crate) static ENTRY_CARAMELIZED_7793381247604239400: VariantsMap = [
    &["caramelized"],
    &["caramelised"],
    &["caramelized"],
    &["caramelised"],
];

pub(crate) static ENTRY_CARAMELIZES_6059982956966755570: VariantsMap = [
    &["caramelizes"],
    &["caramelises"],
    &["caramelizes"],
    &["caramelises"],
];

pub(crate) static ENTRY_CARAMELIZE_1110104959262710985: VariantsMap = [
    &["caramelize"],
    &["caramelise"],
    &["caramelize"],
    &["caramelise"],
];

pub(crate) static ENTRY_CARAMELIZING_2936515763713237491: VariantsMap = [
    &["caramelizing"],
    &["caramelising"],
    &["caramelizing"],
    &["caramelising"],
];

pub(crate) static ENTRY_CARBOLIZATION_1668321139010867766: VariantsMap = [
    &["carbolization"],
    &["carbolisation"],
    &["carbolization"],
    &["carbolisation"],
];

pub(crate) static ENTRY_CARBOLIZED_1304647434125401295: VariantsMap = [
    &["carbolized"],
    &["carbolised"],
    &["carbolized"],
    &["carbolised"],
];

pub(crate) static ENTRY_CARBOLIZES_18256554089605613959: VariantsMap = [
    &["carbolizes"],
    &["carbolises"],
    &["carbolizes"],
    &["carbolises"],
];

pub(crate) static ENTRY_CARBOLIZE_18199301992433580177: VariantsMap = [
    &["carbolize"],
    &["carbolise"],
    &["carbolize"],
    &["carbolise"],
];

pub(crate) static ENTRY_CARBOLIZING_15468275393703968978: VariantsMap = [
    &["carbolizing"],
    &["carbolising"],
    &["carbolizing"],
    &["carbolising"],
];

pub(crate) static ENTRY_CARBONADES_2718956912399980360: VariantsMap = [
    &["carbonades"],
    &["carbonadoes"],
    &["carbonadoes"],
    &["carbonadoes"],
];

pub(crate) static ENTRY_CARBONATIZATIONS_16224281628260636804: VariantsMap = [
    &["carbonatizations"],
    &["carbonatisations"],
    &["carbonatizations"],
    &["carbonatisations"],
];

pub(crate) static ENTRY_CARBONATIZATION_8679961555762969779: VariantsMap = [
    &["carbonatization"],
    &["carbonatisation"],
    &["carbonatization"],
    &["carbonatisation"],
];

pub(crate) static ENTRY_CARBONIZABLER_5983353872794548574: VariantsMap = [
    &["carbonizabler"],
    &["carbonisabler"],
    &["carbonizabler"],
    &["carbonisabler"],
];

pub(crate) static ENTRY_CARBONIZABLEST_8906777685042270793: VariantsMap = [
    &["carbonizablest"],
    &["carbonisablest"],
    &["carbonizablest"],
    &["carbonisablest"],
];

pub(crate) static ENTRY_CARBONIZABLES_15010240797533617511: VariantsMap = [
    &["carbonizables"],
    &["carbonisables"],
    &["carbonizables"],
    &["carbonisables"],
];

pub(crate) static ENTRY_CARBONIZABLE_9770507971838358591: VariantsMap = [
    &["carbonizable"],
    &["carbonisable"],
    &["carbonizable"],
    &["carbonisable"],
];

pub(crate) static ENTRY_CARBONIZATIONS_13100027598773896835: VariantsMap = [
    &["carbonizations"],
    &["carbonisations"],
    &["carbonizations"],
    &["carbonisations"],
];

pub(crate) static ENTRY_CARBONIZATION_16165847968956959109: VariantsMap = [
    &["carbonization"],
    &["carbonisation"],
    &["carbonization"],
    &["carbonisation"],
];

pub(crate) static ENTRY_CARBONIZED_14007117269969730084: VariantsMap = [
    &["carbonized"],
    &["carbonised"],
    &["carbonized"],
    &["carbonised"],
];

pub(crate) static ENTRY_CARBONIZERS_6321314892804174768: VariantsMap = [
    &["carbonizers"],
    &["carbonisers"],
    &["carbonizers"],
    &["carbonisers"],
];

pub(crate) static ENTRY_CARBONIZER_13548993741300401082: VariantsMap = [
    &["carbonizer"],
    &["carboniser"],
    &["carbonizer"],
    &["carboniser"],
];

pub(crate) static ENTRY_CARBONIZES_4601016301417314989: VariantsMap = [
    &["carbonizes"],
    &["carbonises"],
    &["carbonizes"],
    &["carbonises"],
];

pub(crate) static ENTRY_CARBONIZE_1296979562221113559: VariantsMap = [
    &["carbonize"],
    &["carbonise"],
    &["carbonize"],
    &["carbonise"],
];

pub(crate) static ENTRY_CARBONIZING_9584599099267202250: VariantsMap = [
    &["carbonizing"],
    &["carbonising"],
    &["carbonizing"],
    &["carbonising"],
];

pub(crate) static ENTRY_CARBURETORS_17976622243676266477: VariantsMap = [
    &["carburetors"],
    &["carburettors"],
    &["carburettors"],
    &["carburettors"],
];

pub(crate) static ENTRY_CARBURETOR_796458217902184728: VariantsMap = [
    &["carburetor"],
    &["carburettor"],
    &["carburettor"],
    &["carburettor"],
];

pub(crate) static ENTRY_CARBURIZATIONS_9387786085754507277: VariantsMap = [
    &["carburizations"],
    &["carburisations"],
    &["carburizations"],
    &["carburisations"],
];

pub(crate) static ENTRY_CARBURIZATION_3111751723008963789: VariantsMap = [
    &["carburization"],
    &["carburisation"],
    &["carburization"],
    &["carburisation"],
];

pub(crate) static ENTRY_CARBURIZED_11327808482383627961: VariantsMap = [
    &["carburized"],
    &["carburised"],
    &["carburized"],
    &["carburised"],
];

pub(crate) static ENTRY_CARBURIZER_1208889746894515605: VariantsMap = [
    &["carburizer"],
    &["carburiser"],
    &["carburizer"],
    &["carburiser"],
];

pub(crate) static ENTRY_CARBURIZES_1569393480555670518: VariantsMap = [
    &["carburizes"],
    &["carburises"],
    &["carburizes"],
    &["carburises"],
];

pub(crate) static ENTRY_CARBURIZE_3007037993552406791: VariantsMap = [
    &["carburize"],
    &["carburise"],
    &["carburize"],
    &["carburise"],
];

pub(crate) static ENTRY_CARBURIZING_2531220195880162003: VariantsMap = [
    &["carburizing"],
    &["carburising"],
    &["carburizing"],
    &["carburising"],
];

pub(crate) static ENTRY_CARDIE_5254053559491595290: VariantsMap =
    [&["cardie"], &["cardiae"], &["cardiae"], &["cardiae"]];

pub(crate) static ENTRY_CARDUELINE_12160806795445300820: VariantsMap = [
    &["cardueline"],
    &["carduelinae"],
    &["carduelinae"],
    &["carduelinae"],
];

pub(crate) static ENTRY_CARNALIZED_12290977097104986519: VariantsMap = [
    &["carnalized"],
    &["carnalised"],
    &["carnalized"],
    &["carnalised"],
];

pub(crate) static ENTRY_CARNALIZES_10340856607662046936: VariantsMap = [
    &["carnalizes"],
    &["carnalises"],
    &["carnalizes"],
    &["carnalises"],
];

pub(crate) static ENTRY_CARNALIZE_888189908487025980: VariantsMap = [
    &["carnalize"],
    &["carnalise"],
    &["carnalize"],
    &["carnalise"],
];

pub(crate) static ENTRY_CARNALIZING_11439495256258951221: VariantsMap = [
    &["carnalizing"],
    &["carnalising"],
    &["carnalizing"],
    &["carnalising"],
];

pub(crate) static ENTRY_CAROLED_4418735863611872467: VariantsMap =
    [&["caroled"], &["carolled"], &["carolled"], &["carolled"]];

pub(crate) static ENTRY_CAROLERS_5398425405494964276: VariantsMap = [
    &["carolers"],
    &["carollers"],
    &["carollers"],
    &["carollers"],
];

pub(crate) static ENTRY_CAROLER_4713116399310207395: VariantsMap =
    [&["caroler"], &["caroller"], &["caroller"], &["caroller"]];

pub(crate) static ENTRY_CAROLING_6802531412817349154: VariantsMap = [
    &["caroling"],
    &["carolling"],
    &["carolling"],
    &["carolling"],
];

pub(crate) static ENTRY_CAROTINEMIA_3890327621498954431: VariantsMap = [
    &["carotinemia"],
    &["carotinaemia"],
    &["carotinaemia"],
    &["carotinaemia"],
];

pub(crate) static ENTRY_CARTELIZATIONS_9619770345243460310: VariantsMap = [
    &["cartelizations"],
    &["cartelisations"],
    &["cartelizations"],
    &["cartelisations"],
];

pub(crate) static ENTRY_CARTELIZATION_16312929833092298961: VariantsMap = [
    &["cartelization"],
    &["cartelisation"],
    &["cartelization"],
    &["cartelisation"],
];

pub(crate) static ENTRY_CARTELIZED_12213627611344387963: VariantsMap = [
    &["cartelized"],
    &["cartelised"],
    &["cartelized"],
    &["cartelised"],
];

pub(crate) static ENTRY_CARTELIZES_7591657395331891195: VariantsMap = [
    &["cartelizes"],
    &["cartelises"],
    &["cartelizes"],
    &["cartelises"],
];

pub(crate) static ENTRY_CARTELIZE_2833428251960695439: VariantsMap = [
    &["cartelize"],
    &["cartelise"],
    &["cartelize"],
    &["cartelise"],
];

pub(crate) static ENTRY_CARTELIZING_11143164166226551666: VariantsMap = [
    &["cartelizing"],
    &["cartelising"],
    &["cartelizing"],
    &["cartelising"],
];

pub(crate) static ENTRY_CASTORIZEDS_6148490693168594327: VariantsMap = [
    &["castorizeds"],
    &["castoriseds"],
    &["castorizeds"],
    &["castoriseds"],
];

pub(crate) static ENTRY_CASTORIZED_10151818395862381641: VariantsMap = [
    &["castorized"],
    &["castorised"],
    &["castorized"],
    &["castorised"],
];

pub(crate) static ENTRY_CASUALIZATIONS_1177089607693079865: VariantsMap = [
    &["casualizations"],
    &["casualisations"],
    &["casualizations"],
    &["casualisations"],
];

pub(crate) static ENTRY_CASUALIZATION_17265270261689405024: VariantsMap = [
    &["casualization"],
    &["casualisation"],
    &["casualization"],
    &["casualisation"],
];

pub(crate) static ENTRY_CASUALIZED_4864891523978676413: VariantsMap = [
    &["casualized"],
    &["casualised"],
    &["casualized"],
    &["casualised"],
];

pub(crate) static ENTRY_CASUALIZES_4478609648430497928: VariantsMap = [
    &["casualizes"],
    &["casualises"],
    &["casualizes"],
    &["casualises"],
];

pub(crate) static ENTRY_CASUALIZE_17972861847589378190: VariantsMap = [
    &["casualize"],
    &["casualise"],
    &["casualize"],
    &["casualise"],
];

pub(crate) static ENTRY_CASUALIZING_16059580509092791196: VariantsMap = [
    &["casualizing"],
    &["casualising"],
    &["casualizing"],
    &["casualising"],
];

pub(crate) static ENTRY_CATABOLIZE_11816197913174352635: VariantsMap = [
    &["catabolize"],
    &["catabolise"],
    &["catabolize"],
    &["catabolise"],
];

pub(crate) static ENTRY_CATALOGED_13847517650261824048: VariantsMap = [
    &["cataloged"],
    &["catalogued"],
    &["catalogued"],
    &["catalogued"],
];

pub(crate) static ENTRY_CATALOGERS_4685828953878934730: VariantsMap = [
    &["catalogers"],
    &["cataloguers"],
    &["cataloguers"],
    &["cataloguers"],
];

pub(crate) static ENTRY_CATALOGER_17511688898877974998: VariantsMap = [
    &["cataloger"],
    &["cataloguer"],
    &["cataloguer"],
    &["cataloguer"],
];

pub(crate) static ENTRY_CATALOGING_9488455222365923997: VariantsMap = [
    &["cataloging"],
    &["cataloguing"],
    &["cataloguing"],
    &["cataloguing"],
];

pub(crate) static ENTRY_CATALOGS_5196696314182792455: VariantsMap = [
    &["catalogs"],
    &["catalogues"],
    &["catalogues"],
    &["catalogues"],
];

pub(crate) static ENTRY_CATALOGUIZED_8601558565793987799: VariantsMap = [
    &["cataloguized"],
    &["cataloguised"],
    &["cataloguized"],
    &["cataloguised"],
];

pub(crate) static ENTRY_CATALOGUIZES_3670496253316543674: VariantsMap = [
    &["cataloguizes"],
    &["cataloguises"],
    &["cataloguizes"],
    &["cataloguises"],
];

pub(crate) static ENTRY_CATALOGUIZE_14984251796182303314: VariantsMap = [
    &["cataloguize"],
    &["cataloguise"],
    &["cataloguize"],
    &["cataloguise"],
];

pub(crate) static ENTRY_CATALOGUIZING_6606816050812238917: VariantsMap = [
    &["cataloguizing"],
    &["cataloguising"],
    &["cataloguizing"],
    &["cataloguising"],
];

pub(crate) static ENTRY_CATALOG_565730177416789533: VariantsMap =
    [&["catalog"], &["catalogue"], &["catalogue"], &["catalogue"]];

pub(crate) static ENTRY_CATALYZED_18179839917863952435: VariantsMap = [
    &["catalyzed"],
    &["catalysed"],
    &["catalyzed"],
    &["catalysed"],
];

pub(crate) static ENTRY_CATALYZERS_7508097445503599240: VariantsMap = [
    &["catalyzers"],
    &["catalysers"],
    &["catalysers"],
    &["catalysers"],
];

pub(crate) static ENTRY_CATALYZER_11797586490562423657: VariantsMap = [
    &["catalyzer"],
    &["catalyser"],
    &["catalyser"],
    &["catalyser"],
];

pub(crate) static ENTRY_CATALYZES_11042547222296624347: VariantsMap = [
    &["catalyzes"],
    &["catalyses"],
    &["catalyzes"],
    &["catalyses"],
];

pub(crate) static ENTRY_CATALYZE_5340148730721059753: VariantsMap =
    [&["catalyze"], &["catalyse"], &["catalyze"], &["catalyse"]];

pub(crate) static ENTRY_CATALYZING_13540847378063734907: VariantsMap = [
    &["catalyzing"],
    &["catalysing"],
    &["catalyzing"],
    &["catalysing"],
];

pub(crate) static ENTRY_CATECHIZABLER_16489482911634337625: VariantsMap = [
    &["catechizabler"],
    &["catechisabler"],
    &["catechizabler"],
    &["catechisabler"],
];

pub(crate) static ENTRY_CATECHIZABLEST_15304433722914372605: VariantsMap = [
    &["catechizablest"],
    &["catechisablest"],
    &["catechizablest"],
    &["catechisablest"],
];

pub(crate) static ENTRY_CATECHIZABLES_16080446590160289539: VariantsMap = [
    &["catechizables"],
    &["catechisables"],
    &["catechizables"],
    &["catechisables"],
];

pub(crate) static ENTRY_CATECHIZABLE_8148927032591971850: VariantsMap = [
    &["catechizable"],
    &["catechisable"],
    &["catechizable"],
    &["catechisable"],
];

pub(crate) static ENTRY_CATECHIZATIONS_1066006272641891178: VariantsMap = [
    &["catechizations"],
    &["catechisations"],
    &["catechizations"],
    &["catechisations"],
];

pub(crate) static ENTRY_CATECHIZATION_10980745592282334992: VariantsMap = [
    &["catechization"],
    &["catechisation"],
    &["catechization"],
    &["catechisation"],
];

pub(crate) static ENTRY_CATECHIZED_12525365667138826112: VariantsMap = [
    &["catechized"],
    &["catechised"],
    &["catechized"],
    &["catechised"],
];

pub(crate) static ENTRY_CATECHIZERS_7954123406223722552: VariantsMap = [
    &["catechizers"],
    &["catechisers"],
    &["catechizers"],
    &["catechisers"],
];

pub(crate) static ENTRY_CATECHIZER_7607670417085575365: VariantsMap = [
    &["catechizer"],
    &["catechiser"],
    &["catechizer"],
    &["catechiser"],
];

pub(crate) static ENTRY_CATECHIZES_15782633201911980832: VariantsMap = [
    &["catechizes"],
    &["catechises"],
    &["catechizes"],
    &["catechises"],
];

pub(crate) static ENTRY_CATECHIZE_5115052394209545163: VariantsMap = [
    &["catechize"],
    &["catechise"],
    &["catechize"],
    &["catechise"],
];

pub(crate) static ENTRY_CATECHIZINGS_8339955228064173770: VariantsMap = [
    &["catechizings"],
    &["catechisings"],
    &["catechizings"],
    &["catechisings"],
];

pub(crate) static ENTRY_CATECHIZING_3256072816982004976: VariantsMap = [
    &["catechizing"],
    &["catechising"],
    &["catechizing"],
    &["catechising"],
];

pub(crate) static ENTRY_CATEGORIZATIONS_16946076754480761936: VariantsMap = [
    &["categorizations"],
    &["categorisations"],
    &["categorizations"],
    &["categorisations"],
];

pub(crate) static ENTRY_CATEGORIZATION_18434363169100289749: VariantsMap = [
    &["categorization"],
    &["categorisation"],
    &["categorization"],
    &["categorisation"],
];

pub(crate) static ENTRY_CATEGORIZED_3860898201662042852: VariantsMap = [
    &["categorized"],
    &["categorised"],
    &["categorized"],
    &["categorised"],
];

pub(crate) static ENTRY_CATEGORIZERS_15733945145429406975: VariantsMap = [
    &["categorizers"],
    &["categorisers"],
    &["categorizers"],
    &["categorisers"],
];

pub(crate) static ENTRY_CATEGORIZER_9728655756054218872: VariantsMap = [
    &["categorizer"],
    &["categoriser"],
    &["categorizer"],
    &["categoriser"],
];

pub(crate) static ENTRY_CATEGORIZES_5429500333056172375: VariantsMap = [
    &["categorizes"],
    &["categorises"],
    &["categorizes"],
    &["categorises"],
];

pub(crate) static ENTRY_CATEGORIZE_8200356101421109194: VariantsMap = [
    &["categorize"],
    &["categorise"],
    &["categorize"],
    &["categorise"],
];

pub(crate) static ENTRY_CATEGORIZING_3255461076933906932: VariantsMap = [
    &["categorizing"],
    &["categorising"],
    &["categorizing"],
    &["categorising"],
];

pub(crate) static ENTRY_CATHARIZED_7243939307071691808: VariantsMap = [
    &["catharized"],
    &["catharised"],
    &["catharized"],
    &["catharised"],
];

pub(crate) static ENTRY_CATHARIZES_5237565431552696013: VariantsMap = [
    &["catharizes"],
    &["catharises"],
    &["catharizes"],
    &["catharises"],
];

pub(crate) static ENTRY_CATHARIZE_1274769098491691139: VariantsMap = [
    &["catharize"],
    &["catharise"],
    &["catharize"],
    &["catharise"],
];

pub(crate) static ENTRY_CATHARIZING_7925028932359317897: VariantsMap = [
    &["catharizing"],
    &["catharising"],
    &["catharizing"],
    &["catharising"],
];

pub(crate) static ENTRY_CATHETERIZATIONS_5962217885260693783: VariantsMap = [
    &["catheterizations"],
    &["catheterisations"],
    &["catheterizations"],
    &["catheterisations"],
];

pub(crate) static ENTRY_CATHETERIZATION_3744811591478338437: VariantsMap = [
    &["catheterization"],
    &["catheterisation"],
    &["catheterization"],
    &["catheterisation"],
];

pub(crate) static ENTRY_CATHETERIZED_2068677963449945916: VariantsMap = [
    &["catheterized"],
    &["catheterised"],
    &["catheterized"],
    &["catheterised"],
];

pub(crate) static ENTRY_CATHETERIZES_8282905890220338225: VariantsMap = [
    &["catheterizes"],
    &["catheterises"],
    &["catheterizes"],
    &["catheterises"],
];

pub(crate) static ENTRY_CATHETERIZE_6223868023340323760: VariantsMap = [
    &["catheterize"],
    &["catheterise"],
    &["catheterize"],
    &["catheterise"],
];

pub(crate) static ENTRY_CATHETERIZING_9242723783135014192: VariantsMap = [
    &["catheterizing"],
    &["catheterising"],
    &["catheterizing"],
    &["catheterising"],
];

pub(crate) static ENTRY_CATHOLICIZATIONS_16523318186466117967: VariantsMap = [
    &["catholicizations"],
    &["catholicisations"],
    &["catholicizations"],
    &["catholicisations"],
];

pub(crate) static ENTRY_CATHOLICIZATION_12300499468594157854: VariantsMap = [
    &["catholicization"],
    &["catholicisation"],
    &["catholicization"],
    &["catholicisation"],
];

pub(crate) static ENTRY_CATHOLICIZED_10053746865059391537: VariantsMap = [
    &["catholicized"],
    &["catholicised"],
    &["catholicized"],
    &["catholicised"],
];

pub(crate) static ENTRY_CATHOLICIZERS_3541962920626482853: VariantsMap = [
    &["catholicizers"],
    &["catholicisers"],
    &["catholicizers"],
    &["catholicisers"],
];

pub(crate) static ENTRY_CATHOLICIZER_3986145398863481078: VariantsMap = [
    &["catholicizer"],
    &["catholiciser"],
    &["catholicizer"],
    &["catholiciser"],
];

pub(crate) static ENTRY_CATHOLICIZES_10974246470223113109: VariantsMap = [
    &["catholicizes"],
    &["catholicises"],
    &["catholicizes"],
    &["catholicises"],
];

pub(crate) static ENTRY_CATHOLICIZE_10498710367246830234: VariantsMap = [
    &["catholicize"],
    &["catholicise"],
    &["catholicize"],
    &["catholicise"],
];

pub(crate) static ENTRY_CATHOLICIZING_16243083594073649559: VariantsMap = [
    &["catholicizing"],
    &["catholicising"],
    &["catholicizing"],
    &["catholicising"],
];

pub(crate) static ENTRY_CAULDRONS_5688241368036052829: VariantsMap = [
    &["caldrons", "cauldrons"],
    &["cauldrons"],
    &["cauldrons"],
    &["cauldrons"],
];

pub(crate) static ENTRY_CAULDRON_1773331448073014615: VariantsMap = [
    &["caldron", "cauldron"],
    &["cauldron"],
    &["cauldron"],
    &["cauldron"],
];

pub(crate) static ENTRY_CAULKED_17850506211135154377: VariantsMap =
    [&["caulked"], &["caulked"], &["caulked"], &["caulked"]];

pub(crate) static ENTRY_CAULKING_1812804659342859546: VariantsMap =
    [&["caulking"], &["caulking"], &["caulking"], &["caulking"]];

pub(crate) static ENTRY_CAULKS_2004629765557914803: VariantsMap =
    [&["caulks"], &["caulks"], &["caulks"], &["caulks"]];

pub(crate) static ENTRY_CAULKS_4230617823899022638: VariantsMap =
    [&["caulks"], &["caulks"], &["caulks"], &["caulks"]];

pub(crate) static ENTRY_CAULK_13405348041672279283: VariantsMap =
    [&["caulk"], &["caulk"], &["caulk"], &["caulk"]];

pub(crate) static ENTRY_CAULK_5085090702762931673: VariantsMap =
    [&["caulk"], &["caulk"], &["caulk"], &["caulk"]];

pub(crate) static ENTRY_CAUSTICIZATIONS_8334657249022891576: VariantsMap = [
    &["causticizations"],
    &["causticisations"],
    &["causticizations"],
    &["causticisations"],
];

pub(crate) static ENTRY_CAUSTICIZATION_783439317842741879: VariantsMap = [
    &["causticization"],
    &["causticisation"],
    &["causticization"],
    &["causticisation"],
];

pub(crate) static ENTRY_CAUSTICIZERS_5473710480358282522: VariantsMap = [
    &["causticizers"],
    &["causticisers"],
    &["causticizers"],
    &["causticisers"],
];

pub(crate) static ENTRY_CAUSTICIZER_6841395610651928471: VariantsMap = [
    &["causticizer"],
    &["causticiser"],
    &["causticizer"],
    &["causticiser"],
];

pub(crate) static ENTRY_CAUSTICIZES_6084094714495938613: VariantsMap = [
    &["causticizes"],
    &["causticises"],
    &["causticizes"],
    &["causticises"],
];

pub(crate) static ENTRY_CAUSTICIZE_4584551572444823336: VariantsMap = [
    &["causticize"],
    &["causticise"],
    &["causticize"],
    &["causticise"],
];

pub(crate) static ENTRY_CAUTERIZATIONS_4890341307628816522: VariantsMap = [
    &["cauterizations"],
    &["cauterisations"],
    &["cauterizations"],
    &["cauterisations"],
];

pub(crate) static ENTRY_CAUTERIZATION_11314889126154078843: VariantsMap = [
    &["cauterization"],
    &["cauterisation"],
    &["cauterization"],
    &["cauterisation"],
];

pub(crate) static ENTRY_CAUTERIZED_12118160833980913736: VariantsMap = [
    &["cauterized"],
    &["cauterised"],
    &["cauterized"],
    &["cauterised"],
];

pub(crate) static ENTRY_CAUTERIZES_17337688368809469148: VariantsMap = [
    &["cauterizes"],
    &["cauterises"],
    &["cauterizes"],
    &["cauterises"],
];

pub(crate) static ENTRY_CAUTERIZE_11145047639262148996: VariantsMap = [
    &["cauterize"],
    &["cauterise"],
    &["cauterize"],
    &["cauterise"],
];

pub(crate) static ENTRY_CAUTERIZING_14426485505826676009: VariantsMap = [
    &["cauterizing"],
    &["cauterising"],
    &["cauterizing"],
    &["cauterising"],
];

pub(crate) static ENTRY_CAVIARS_11505002019485473608: VariantsMap =
    [&["caviars"], &["caviars"], &["caviars"], &["caviars"]];

pub(crate) static ENTRY_CAVIAR_13293796828806890873: VariantsMap =
    [&["caviar"], &["caviar"], &["caviar"], &["caviar"]];

pub(crate) static ENTRY_CAVILATION_6190881958167857313: VariantsMap = [
    &["cavilation"],
    &["cavillation"],
    &["cavillation"],
    &["cavillation"],
];

pub(crate) static ENTRY_CAVILED_11192889244066147526: VariantsMap =
    [&["caviled"], &["cavilled"], &["cavilled"], &["cavilled"]];

pub(crate) static ENTRY_CAVILERS_12077868647577851396: VariantsMap = [
    &["cavilers"],
    &["cavillers"],
    &["cavillers"],
    &["cavillers"],
];

pub(crate) static ENTRY_CAVILER_9496917240731757934: VariantsMap =
    [&["caviler"], &["caviller"], &["caviller"], &["caviller"]];

pub(crate) static ENTRY_CAVILINGS_2004720957308004113: VariantsMap = [
    &["cavilings"],
    &["cavillings"],
    &["cavillings"],
    &["cavillings"],
];

pub(crate) static ENTRY_CAVILING_17734305391918802240: VariantsMap = [
    &["caviling"],
    &["cavilling"],
    &["cavilling"],
    &["cavilling"],
];

pub(crate) static ENTRY_CECALLY_9670506280479282690: VariantsMap =
    [&["cecally"], &["caecally"], &["caecally"], &["caecally"]];

pub(crate) static ENTRY_CECITISES_8125550960993244895: VariantsMap = [
    &["cecitises"],
    &["caecitises"],
    &["caecitises"],
    &["caecitises"],
];

pub(crate) static ENTRY_CECITIS_3074214842392316094: VariantsMap =
    [&["cecitis"], &["caecitis"], &["caecitis"], &["caecitis"]];

pub(crate) static ENTRY_CECITY_109164963209594686: VariantsMap =
    [&["cecity"], &["caecity"], &["caecity"], &["caecity"]];

pub(crate) static ENTRY_CECOSTOMY_14076938077100733913: VariantsMap = [
    &["cecostomy"],
    &["caecostomy"],
    &["caecostomy"],
    &["caecostomy"],
];

pub(crate) static ENTRY_CECOTOMY_6391026121304575885: VariantsMap = [
    &["cecotomy"],
    &["caecotomy"],
    &["caecotomy"],
    &["caecotomy"],
];

pub(crate) static ENTRY_CELASTRACEAE_248052160521437337: VariantsMap = [
    &["celastraceae"],
    &["coelastraceae"],
    &["coelastraceae"],
    &["coelastraceae"],
];

pub(crate) static ENTRY_CELASTRACEOUS_13139092700507364792: VariantsMap = [
    &["celastraceous"],
    &["coelastraceous"],
    &["coelastraceous"],
    &["coelastraceous"],
];

pub(crate) static ENTRY_CELESTIALIZES_9179277409781355070: VariantsMap = [
    &["celestializes"],
    &["celestialises"],
    &["celestializes"],
    &["celestialises"],
];

pub(crate) static ENTRY_CELESTIALIZE_538727862299269646: VariantsMap = [
    &["celestialize"],
    &["celestialise"],
    &["celestialize"],
    &["celestialise"],
];

pub(crate) static ENTRY_CELESTINE_6574095563191113248: VariantsMap = [
    &["celestine"],
    &["coelestine"],
    &["coelestine"],
    &["coelestine"],
];

pub(crate) static ENTRY_CELIACS_7167873050372594104: VariantsMap =
    [&["celiacs"], &["coeliacs"], &["coeliacs"], &["coeliacs"]];

pub(crate) static ENTRY_CELIAC_18102856828663564552: VariantsMap =
    [&["celiac"], &["coeliac"], &["coeliac"], &["coeliac"]];

pub(crate) static ENTRY_CELIALGIA_4390117124611657564: VariantsMap = [
    &["celialgia"],
    &["coelialgia"],
    &["coelialgia"],
    &["coelialgia"],
];

pub(crate) static ENTRY_CELIOMYALGIA_11280554360719408547: VariantsMap = [
    &["celiomyalgia"],
    &["coeliomyalgia"],
    &["coeliomyalgia"],
    &["coeliomyalgia"],
];

pub(crate) static ENTRY_CELIORRHEA_6798475442650879420: VariantsMap = [
    &["celiorrhea"],
    &["coeliorrhea"],
    &["coeliorrhea"],
    &["coeliorrhea"],
];

pub(crate) static ENTRY_CELIOSCOPY_10064554083059800495: VariantsMap = [
    &["celioscopy"],
    &["coelioscopy"],
    &["coelioscopy"],
    &["coelioscopy"],
];

pub(crate) static ENTRY_CELIOTOMY_7002375967235750854: VariantsMap = [
    &["celiotomy"],
    &["coeliotomy"],
    &["coeliotomy"],
    &["coeliotomy"],
];

pub(crate) static ENTRY_CELOMATA_9462689710315550329: VariantsMap = [
    &["celomata"],
    &["coelomata"],
    &["coelomata"],
    &["coelomata"],
];

pub(crate) static ENTRY_CELOMA_16635368470102536323: VariantsMap =
    [&["celoma"], &["coeloma"], &["coeloma"], &["coeloma"]];

pub(crate) static ENTRY_CELOMS_4896390401945145201: VariantsMap =
    [&["celoms"], &["coeloms"], &["coeloms"], &["coeloms"]];

pub(crate) static ENTRY_CELOM_6954296651788090066: VariantsMap =
    [&["celom"], &["coelom"], &["coelom"], &["coelom"]];

pub(crate) static ENTRY_CELOSCOPE_4883213512077398928: VariantsMap = [
    &["celoscope"],
    &["coeloscope"],
    &["coeloscope"],
    &["coeloscope"],
];

pub(crate) static ENTRY_CELTICIZES_1129237498010014182: VariantsMap = [
    &["celticizes"],
    &["celticises"],
    &["celticizes"],
    &["celticises"],
];

pub(crate) static ENTRY_CELTICIZE_7118296023797408335: VariantsMap = [
    &["celticize"],
    &["celticise"],
    &["celticize"],
    &["celticise"],
];

pub(crate) static ENTRY_CENACLE_11560322831244580416: VariantsMap =
    [&["cenacle"], &["coenacle"], &["coenacle"], &["coenacle"]];

pub(crate) static ENTRY_CENACULUM_9966061997534531582: VariantsMap = [
    &["cenaculum"],
    &["coenaculum"],
    &["coenaculum"],
    &["coenaculum"],
];

pub(crate) static ENTRY_CENESTHESIAS_16287981603481963061: VariantsMap = [
    &["cenesthesias"],
    &["coenesthesias"],
    &["coenesthesias"],
    &["coenesthesias"],
];

pub(crate) static ENTRY_CENESTHESIA_4011067798171287989: VariantsMap = [
    &["cenesthesia"],
    &["coenesthesia"],
    &["coenesthesia"],
    &["coenesthesia"],
];

pub(crate) static ENTRY_CENESTHESIS_9192577966958417138: VariantsMap = [
    &["cenesthesis"],
    &["coenesthesis"],
    &["coenesthesis"],
    &["coenesthesis"],
];

pub(crate) static ENTRY_CENIS_12176224815013604688: VariantsMap =
    [&["cenis"], &["caenis"], &["caenis"], &["caenis"]];

pub(crate) static ENTRY_CENOBE_15621742511041336445: VariantsMap =
    [&["cenobe"], &["coenobe"], &["coenobe"], &["coenobe"]];

pub(crate) static ENTRY_CENOBITES_13837713854551690629: VariantsMap = [
    &["cenobites"],
    &["coenobites"],
    &["cenobites"],
    &["coenobites"],
];

pub(crate) static ENTRY_CENOBITE_3238719954758957076: VariantsMap =
    [&["cenobite"], &["coenobite"], &["cenobite"], &["coenobite"]];

pub(crate) static ENTRY_CENOBITICAL_6881474597185636655: VariantsMap = [
    &["cenobitical"],
    &["coenobitical"],
    &["cenobitical"],
    &["coenobitical"],
];

pub(crate) static ENTRY_CENOBITIC_14473057480801204596: VariantsMap = [
    &["cenobitic"],
    &["coenobitic"],
    &["cenobitic"],
    &["coenobitic"],
];

pub(crate) static ENTRY_CENOBITISM_10552992890229559594: VariantsMap = [
    &["cenobitism"],
    &["coenobitism"],
    &["coenobitism"],
    &["coenobitism"],
];

pub(crate) static ENTRY_CENOBIUM_9531258636879765081: VariantsMap = [
    &["cenobium"],
    &["coenobium"],
    &["coenobium"],
    &["coenobium"],
];

pub(crate) static ENTRY_CENOBY_12287306148631547483: VariantsMap =
    [&["cenoby"], &["coenoby"], &["coenoby"], &["coenoby"]];

pub(crate) static ENTRY_CENOGENETICALLY_1887927515979187697: VariantsMap = [
    &["cenogenetically"],
    &["caenogenetically"],
    &["caenogenetically"],
    &["caenogenetically"],
];

pub(crate) static ENTRY_CENOGENETIC_3476451464373390522: VariantsMap = [
    &["cenogenetic"],
    &["caenogenetic"],
    &["caenogenetic"],
    &["caenogenetic"],
];

pub(crate) static ENTRY_CENOGENETIC_5287833837469101531: VariantsMap = [
    &["cenogenetic"],
    &["coenogenetic"],
    &["coenogenetic"],
    &["coenogenetic"],
];

pub(crate) static ENTRY_CENOSITE_14996204277047943901: VariantsMap = [
    &["cenosite"],
    &["coenosite"],
    &["coenosite"],
    &["coenosite"],
];

pub(crate) static ENTRY_CENOSPECIES_1304456854215858015: VariantsMap = [
    &["cenospecies"],
    &["coenospecies"],
    &["coenospecies"],
    &["coenospecies"],
];

pub(crate) static ENTRY_CENOSPECIFICALLY_14746841820461979584: VariantsMap = [
    &["cenospecifically"],
    &["coenospecifically"],
    &["coenospecifically"],
    &["coenospecifically"],
];

pub(crate) static ENTRY_CENOSPECIFIC_200658439075912747: VariantsMap = [
    &["cenospecific"],
    &["coenospecific"],
    &["coenospecific"],
    &["coenospecific"],
];

pub(crate) static ENTRY_CENOZOIC_15012859896037847714: VariantsMap = [
    &["cenozoic"],
    &["caenozoic"],
    &["caenozoic"],
    &["caenozoic"],
];

pub(crate) static ENTRY_CENTERABLES_15482936396077523679: VariantsMap = [
    &["centerables"],
    &["centreables"],
    &["centreables"],
    &["centreables"],
];

pub(crate) static ENTRY_CENTERABLE_1736442923708139393: VariantsMap = [
    &["centerable"],
    &["centreable"],
    &["centreable"],
    &["centreable"],
];

pub(crate) static ENTRY_CENTERBOARDS_8162665466509661850: VariantsMap = [
    &["centerboards"],
    &["centreboards"],
    &["centreboards"],
    &["centreboards"],
];

pub(crate) static ENTRY_CENTERBOARD_12936059728076156984: VariantsMap = [
    &["centerboard"],
    &["centreboard"],
    &["centreboard"],
    &["centreboard"],
];

pub(crate) static ENTRY_CENTERED_15927189749167280073: VariantsMap =
    [&["centered"], &["centred"], &["centred"], &["centred"]];

pub(crate) static ENTRY_CENTERERS_12660813565427012077: VariantsMap =
    [&["centerers"], &["centrers"], &["centrers"], &["centrers"]];

pub(crate) static ENTRY_CENTERER_2663515071115995852: VariantsMap =
    [&["centerer"], &["centrer"], &["centrer"], &["centrer"]];

pub(crate) static ENTRY_CENTERFOLDS_6987098084704804029: VariantsMap = [
    &["centerfolds"],
    &["centrefolds"],
    &["centrefolds"],
    &["centrefolds"],
];

pub(crate) static ENTRY_CENTERFOLD_13964837998835453817: VariantsMap = [
    &["centerfold"],
    &["centrefold"],
    &["centrefold"],
    &["centrefold"],
];

pub(crate) static ENTRY_CENTERINGS_14821164417176031250: VariantsMap = [
    &["centerings"],
    &["centrings"],
    &["centrings"],
    &["centrings"],
];

pub(crate) static ENTRY_CENTERING_12678821431832397053: VariantsMap =
    [&["centering"], &["centring"], &["centring"], &["centring"]];

pub(crate) static ENTRY_CENTERLESSER_11642941641041736956: VariantsMap = [
    &["centerlesser"],
    &["centrelesser"],
    &["centrelesser"],
    &["centrelesser"],
];

pub(crate) static ENTRY_CENTERLESSEST_13108645794898456200: VariantsMap = [
    &["centerlessest"],
    &["centrelessest"],
    &["centrelessest"],
    &["centrelessest"],
];

pub(crate) static ENTRY_CENTERLESS_9593765835963687698: VariantsMap = [
    &["centerless"],
    &["centreless"],
    &["centreless"],
    &["centreless"],
];

pub(crate) static ENTRY_CENTERLINES_5503867658086621883: VariantsMap = [
    &["centerlines"],
    &["centrelines"],
    &["centrelines"],
    &["centrelines"],
];

pub(crate) static ENTRY_CENTERLINE_8193954350816983103: VariantsMap = [
    &["centerline"],
    &["centreline"],
    &["centreline"],
    &["centreline"],
];

pub(crate) static ENTRY_CENTERMOST_17931621876330932092: VariantsMap = [
    &["centermost"],
    &["centremost"],
    &["centremost"],
    &["centremost"],
];

pub(crate) static ENTRY_CENTERPIECES_9003602563873687762: VariantsMap = [
    &["centerpieces"],
    &["centrepieces"],
    &["centrepieces"],
    &["centrepieces"],
];

pub(crate) static ENTRY_CENTERPIECE_8959571131813824904: VariantsMap = [
    &["centerpiece"],
    &["centrepiece"],
    &["centrepiece"],
    &["centrepiece"],
];

pub(crate) static ENTRY_CENTERS_3653356479744194617: VariantsMap =
    [&["centers"], &["centres"], &["centres"], &["centres"]];

pub(crate) static ENTRY_CENTERVILLE_1463746369386483595: VariantsMap = [
    &["centerville"],
    &["centreville"],
    &["centreville"],
    &["centreville"],
];

pub(crate) static ENTRY_CENTER_2062827205925125611: VariantsMap =
    [&["center"], &["centre"], &["centre"], &["centre"]];

pub(crate) static ENTRY_CENTIGRAMS_4446712383280702017: VariantsMap = [
    &["centigrams"],
    &["centigrams"],
    &["centigrams"],
    &["centigrams"],
];

pub(crate) static ENTRY_CENTIGRAM_16369133942610299137: VariantsMap = [
    &["centigram"],
    &["centigram"],
    &["centigram"],
    &["centigram"],
];

pub(crate) static ENTRY_CENTILITERS_1152239446012655040: VariantsMap = [
    &["centiliters"],
    &["centilitres"],
    &["centilitres"],
    &["centilitres"],
];

pub(crate) static ENTRY_CENTILITER_5486758117872326030: VariantsMap = [
    &["centiliter"],
    &["centilitre"],
    &["centilitre"],
    &["centilitre"],
];

pub(crate) static ENTRY_CENTIMETERS_2488768602472487806: VariantsMap = [
    &["centimeters"],
    &["centimetres"],
    &["centimetres"],
    &["centimetres"],
];

pub(crate) static ENTRY_CENTIMETER_16919893077343778486: VariantsMap = [
    &["centimeter"],
    &["centimetre"],
    &["centimetre"],
    &["centimetre"],
];

pub(crate) static ENTRY_CENTRALIZATIONS_14077284492075609276: VariantsMap = [
    &["centralizations"],
    &["centralisations"],
    &["centralizations"],
    &["centralisations"],
];

pub(crate) static ENTRY_CENTRALIZATION_14489606925183485682: VariantsMap = [
    &["centralization"],
    &["centralisation"],
    &["centralization"],
    &["centralisation"],
];

pub(crate) static ENTRY_CENTRALIZED_11571044202801829690: VariantsMap = [
    &["centralized"],
    &["centralised"],
    &["centralized"],
    &["centralised"],
];

pub(crate) static ENTRY_CENTRALIZERS_17147959706080239831: VariantsMap = [
    &["centralizers"],
    &["centralisers"],
    &["centralizers"],
    &["centralisers"],
];

pub(crate) static ENTRY_CENTRALIZER_6120657287536400694: VariantsMap = [
    &["centralizer"],
    &["centraliser"],
    &["centralizer"],
    &["centraliser"],
];

pub(crate) static ENTRY_CENTRALIZES_13364036337997133322: VariantsMap = [
    &["centralizes"],
    &["centralises"],
    &["centralizes"],
    &["centralises"],
];

pub(crate) static ENTRY_CENTRALIZE_3598052449531879733: VariantsMap = [
    &["centralize"],
    &["centralise"],
    &["centralize"],
    &["centralise"],
];

pub(crate) static ENTRY_CENTRALIZING_16563092158705447235: VariantsMap = [
    &["centralizing"],
    &["centralising"],
    &["centralizing"],
    &["centralising"],
];

pub(crate) static ENTRY_CENTRIFUGALIZATIONS_10177560764588170199: VariantsMap = [
    &["centrifugalizations"],
    &["centrifugalisations"],
    &["centrifugalizations"],
    &["centrifugalisations"],
];

pub(crate) static ENTRY_CENTRIFUGALIZATION_9870283591412029358: VariantsMap = [
    &["centrifugalization"],
    &["centrifugalisation"],
    &["centrifugalization"],
    &["centrifugalisation"],
];

pub(crate) static ENTRY_CENTRIFUGALIZED_10606420628931925286: VariantsMap = [
    &["centrifugalized"],
    &["centrifugalised"],
    &["centrifugalized"],
    &["centrifugalised"],
];

pub(crate) static ENTRY_CENTRIFUGALIZES_2357194867049429611: VariantsMap = [
    &["centrifugalizes"],
    &["centrifugalises"],
    &["centrifugalizes"],
    &["centrifugalises"],
];

pub(crate) static ENTRY_CENTRIFUGALIZE_16234395767957633471: VariantsMap = [
    &["centrifugalize"],
    &["centrifugalise"],
    &["centrifugalize"],
    &["centrifugalise"],
];

pub(crate) static ENTRY_CENTRIFUGALIZING_3551395843046197608: VariantsMap = [
    &["centrifugalizing"],
    &["centrifugalising"],
    &["centrifugalizing"],
    &["centrifugalising"],
];

pub(crate) static ENTRY_CEPHALIZATIONS_4196229478743299448: VariantsMap = [
    &["cephalizations"],
    &["cephalisations"],
    &["cephalizations"],
    &["cephalisations"],
];

pub(crate) static ENTRY_CEPHALIZATION_9633792686486937214: VariantsMap = [
    &["cephalization"],
    &["cephalisation"],
    &["cephalization"],
    &["cephalisation"],
];

pub(crate) static ENTRY_CERATINS_11807307117212505372: VariantsMap =
    [&["ceratins"], &["creatins"], &["creatins"], &["creatins"]];

pub(crate) static ENTRY_CERATIN_12655188086840180608: VariantsMap =
    [&["ceratin"], &["creatin"], &["creatin"], &["creatin"]];

pub(crate) static ENTRY_CERAT_952631974668920340: VariantsMap =
    [&["cerat"], &["creat"], &["creat"], &["creat"]];

pub(crate) static ENTRY_CERA_4010763817295674400: VariantsMap =
    [&["cera"], &["crea"], &["crea"], &["crea"]];

pub(crate) static ENTRY_CEREBRALIZATIONS_6843095609202501892: VariantsMap = [
    &["cerebralizations"],
    &["cerebralisations"],
    &["cerebralizations"],
    &["cerebralisations"],
];

pub(crate) static ENTRY_CEREBRALIZATION_16112629056325862157: VariantsMap = [
    &["cerebralization"],
    &["cerebralisation"],
    &["cerebralization"],
    &["cerebralisation"],
];

pub(crate) static ENTRY_CEREBRALIZES_3809932987263287223: VariantsMap = [
    &["cerebralizes"],
    &["cerebralises"],
    &["cerebralizes"],
    &["cerebralises"],
];

pub(crate) static ENTRY_CEREBRALIZE_10176941368321775199: VariantsMap = [
    &["cerebralize"],
    &["cerebralise"],
    &["cerebralize"],
    &["cerebralise"],
];

pub(crate) static ENTRY_CEREMONIALIZES_10200837703193624027: VariantsMap = [
    &["ceremonializes"],
    &["ceremonialises"],
    &["ceremonializes"],
    &["ceremonialises"],
];

pub(crate) static ENTRY_CEREMONIALIZE_16487784841115936970: VariantsMap = [
    &["ceremonialize"],
    &["ceremonialise"],
    &["ceremonialize"],
    &["ceremonialise"],
];

pub(crate) static ENTRY_CERES_13909916927122501672: VariantsMap =
    [&["ceres"], &["crees"], &["crees"], &["crees"]];

pub(crate) static ENTRY_CERE_7492486766027596747: VariantsMap =
    [&["cere"], &["cree"], &["cree"], &["cree"]];

pub(crate) static ENTRY_CEROLITE_13936865573619235917: VariantsMap =
    [&["cerolite"], &["creolite"], &["creolite"], &["creolite"]];

pub(crate) static ENTRY_CERULEOLACTITE_14138382859124709242: VariantsMap = [
    &["ceruleolactite"],
    &["coeruleolactite"],
    &["coeruleolactite"],
    &["coeruleolactite"],
];

pub(crate) static ENTRY_CERULE_13807908748488324309: VariantsMap =
    [&["cerule"], &["caerule"], &["caerule"], &["caerule"]];

pub(crate) static ENTRY_CER_7391662671400680429: VariantsMap =
    [&["cer"], &["cre"], &["cre"], &["cre"]];

pub(crate) static ENTRY_CESARIA_13260737813085944916: VariantsMap =
    [&["cesaria"], &["caesaria"], &["caesaria"], &["caesaria"]];

pub(crate) static ENTRY_CESAR_17704325165906141578: VariantsMap =
    [&["cesar"], &["caesar"], &["caesar"], &["caesar"]];

pub(crate) static ENTRY_CESIOUS_11410150702051630927: VariantsMap =
    [&["cesious"], &["caesious"], &["caesious"], &["caesious"]];

pub(crate) static ENTRY_CESIUMS_6672725677512073080: VariantsMap =
    [&["cesiums"], &["caesiums"], &["cesiums"], &["caesiums"]];

pub(crate) static ENTRY_CESIUM_14697098024822079251: VariantsMap =
    [&["cesium"], &["caesium"], &["cesium"], &["caesium"]];

pub(crate) static ENTRY_CESPITOSELY_3931130846381787690: VariantsMap = [
    &["cespitosely"],
    &["caespitosely"],
    &["caespitosely"],
    &["caespitosely"],
];

pub(crate) static ENTRY_CESPITOSE_6409378686720351127: VariantsMap = [
    &["cespitose"],
    &["caespitose"],
    &["caespitose"],
    &["caespitose"],
];

pub(crate) static ENTRY_CESTUSES_307704550846354852: VariantsMap = [
    &["cestuses"],
    &["caestuses"],
    &["caestuses"],
    &["caestuses"],
];

pub(crate) static ENTRY_CESTUS_4030396889026927959: VariantsMap =
    [&["cestus"], &["caestus"], &["caestus"], &["caestus"]];

pub(crate) static ENTRY_CESURAL_6753528217264809955: VariantsMap =
    [&["cesural"], &["caesural"], &["caesural"], &["caesural"]];

pub(crate) static ENTRY_CETUS_5843508028170188409: VariantsMap =
    [&["cetus"], &["coetus"], &["coetus"], &["coetus"]];

pub(crate) static ENTRY_CE_17001278784018973857: VariantsMap =
    [&["ce"], &["coe"], &["coe"], &["coe"]];

pub(crate) static ENTRY_CHACES_12737065532724784535: VariantsMap =
    [&["chaces"], &["chacoes"], &["chacoes"], &["chacoes"]];

pub(crate) static ENTRY_CHALAZE_12687207023115659676: VariantsMap =
    [&["chalaze"], &["chalazae"], &["chalazae"], &["chalazae"]];

pub(crate) static ENTRY_CHALDEANS_12673514258939936489: VariantsMap = [
    &["chaldeans"],
    &["chaldaeans"],
    &["chaldaeans"],
    &["chaldaeans"],
];

pub(crate) static ENTRY_CHAMELEONIZES_18219192353443797519: VariantsMap = [
    &["chameleonizes"],
    &["chameleonises"],
    &["chameleonizes"],
    &["chameleonises"],
];

pub(crate) static ENTRY_CHAMELEONIZE_6643805712111426796: VariantsMap = [
    &["chameleonize"],
    &["chameleonise"],
    &["chameleonize"],
    &["chameleonise"],
];

pub(crate) static ENTRY_CHAMIZAL_16232076464897458404: VariantsMap =
    [&["chamizal"], &["chamisal"], &["chamizal"], &["chamisal"]];

pub(crate) static ENTRY_CHAMPIONIZES_10731216498351955029: VariantsMap = [
    &["championizes"],
    &["championises"],
    &["championizes"],
    &["championises"],
];

pub(crate) static ENTRY_CHAMPIONIZE_8022492695135570679: VariantsMap = [
    &["championize"],
    &["championise"],
    &["championize"],
    &["championise"],
];

pub(crate) static ENTRY_CHANNELED_3884192849125819469: VariantsMap = [
    &["channeled"],
    &["channelled"],
    &["channelled"],
    &["channelled"],
];

pub(crate) static ENTRY_CHANNELERS_16612593297039553035: VariantsMap = [
    &["channelers"],
    &["channellers"],
    &["channellers"],
    &["channellers"],
];

pub(crate) static ENTRY_CHANNELER_7136881456277511173: VariantsMap = [
    &["channeler"],
    &["channeller"],
    &["channeller"],
    &["channeller"],
];

pub(crate) static ENTRY_CHANNELING_4768505129233237962: VariantsMap = [
    &["channeling"],
    &["channelling"],
    &["channelling"],
    &["channelling"],
];

pub(crate) static ENTRY_CHANNELIZATIONS_2195360393747957501: VariantsMap = [
    &["channelizations"],
    &["channelisations"],
    &["channelizations"],
    &["channelisations"],
];

pub(crate) static ENTRY_CHANNELIZATION_7847892923196708836: VariantsMap = [
    &["channelization"],
    &["channelisation"],
    &["channelization"],
    &["channelisation"],
];

pub(crate) static ENTRY_CHANNELIZED_5449663681030349216: VariantsMap = [
    &["channelized"],
    &["channelised"],
    &["channelized"],
    &["channelised"],
];

pub(crate) static ENTRY_CHANNELIZES_8130546736139303129: VariantsMap = [
    &["channelizes"],
    &["channelises"],
    &["channelizes"],
    &["channelises"],
];

pub(crate) static ENTRY_CHANNELIZE_9103946204000221039: VariantsMap = [
    &["channelize"],
    &["channelise"],
    &["channelize"],
    &["channelise"],
];

pub(crate) static ENTRY_CHANNELIZING_6754708663381850003: VariantsMap = [
    &["channelizing"],
    &["channelising"],
    &["channelizing"],
    &["channelising"],
];

pub(crate) static ENTRY_CHAPTALIZATIONS_7700818675877073771: VariantsMap = [
    &["chaptalizations"],
    &["chaptalisations"],
    &["chaptalizations"],
    &["chaptalisations"],
];

pub(crate) static ENTRY_CHAPTALIZATION_6504001854346497205: VariantsMap = [
    &["chaptalization"],
    &["chaptalisation"],
    &["chaptalization"],
    &["chaptalisation"],
];

pub(crate) static ENTRY_CHAPTALIZED_4461125988509678051: VariantsMap = [
    &["chaptalized"],
    &["chaptalised"],
    &["chaptalized"],
    &["chaptalised"],
];

pub(crate) static ENTRY_CHAPTALIZES_7896297337499803290: VariantsMap = [
    &["chaptalizes"],
    &["chaptalises"],
    &["chaptalizes"],
    &["chaptalises"],
];

pub(crate) static ENTRY_CHAPTALIZE_14248650062578755426: VariantsMap = [
    &["chaptalize"],
    &["chaptalise"],
    &["chaptalize"],
    &["chaptalise"],
];

pub(crate) static ENTRY_CHAPTALIZING_17220948961295716354: VariantsMap = [
    &["chaptalizing"],
    &["chaptalising"],
    &["chaptalizing"],
    &["chaptalising"],
];

pub(crate) static ENTRY_CHARACTERIZABLER_14184251246782572062: VariantsMap = [
    &["characterizabler"],
    &["characterisabler"],
    &["characterizabler"],
    &["characterisabler"],
];

pub(crate) static ENTRY_CHARACTERIZABLEST_4747819617396262494: VariantsMap = [
    &["characterizablest"],
    &["characterisablest"],
    &["characterizablest"],
    &["characterisablest"],
];

pub(crate) static ENTRY_CHARACTERIZABLES_5781065015666250414: VariantsMap = [
    &["characterizables"],
    &["characterisables"],
    &["characterizables"],
    &["characterisables"],
];

pub(crate) static ENTRY_CHARACTERIZABLE_6565431935227576065: VariantsMap = [
    &["characterizable"],
    &["characterisable"],
    &["characterizable"],
    &["characterisable"],
];

pub(crate) static ENTRY_CHARACTERIZATIONS_13277352132965580301: VariantsMap = [
    &["characterizations"],
    &["characterisations"],
    &["characterizations"],
    &["characterisations"],
];

pub(crate) static ENTRY_CHARACTERIZATION_11550110625481177338: VariantsMap = [
    &["characterization"],
    &["characterisation"],
    &["characterization"],
    &["characterisation"],
];

pub(crate) static ENTRY_CHARACTERIZED_17817519055123408875: VariantsMap = [
    &["characterized"],
    &["characterised"],
    &["characterized"],
    &["characterised"],
];

pub(crate) static ENTRY_CHARACTERIZERS_1378131457915956997: VariantsMap = [
    &["characterizers"],
    &["characterisers"],
    &["characterizers"],
    &["characterisers"],
];

pub(crate) static ENTRY_CHARACTERIZER_2691742990866193884: VariantsMap = [
    &["characterizer"],
    &["characteriser"],
    &["characterizer"],
    &["characteriser"],
];

pub(crate) static ENTRY_CHARACTERIZES_14017907572178871492: VariantsMap = [
    &["characterizes"],
    &["characterises"],
    &["characterizes"],
    &["characterises"],
];

pub(crate) static ENTRY_CHARACTERIZE_14637565961485771135: VariantsMap = [
    &["characterize"],
    &["characterise"],
    &["characterize"],
    &["characterise"],
];

pub(crate) static ENTRY_CHARACTERIZING_15152517398466769326: VariantsMap = [
    &["characterizing"],
    &["characterising"],
    &["characterizing"],
    &["characterising"],
];

pub(crate) static ENTRY_CHARER_1702867236913115290: VariantsMap =
    [&["charer"], &["charre"], &["charre"], &["charre"]];

pub(crate) static ENTRY_CHATTELIZATIONS_2797949953247855051: VariantsMap = [
    &["chattelizations"],
    &["chattelisations"],
    &["chattelizations"],
    &["chattelisations"],
];

pub(crate) static ENTRY_CHATTELIZATION_2351241488930486091: VariantsMap = [
    &["chattelization"],
    &["chattelisation"],
    &["chattelization"],
    &["chattelisation"],
];

pub(crate) static ENTRY_CHATTELIZES_10654226472445860357: VariantsMap = [
    &["chattelizes"],
    &["chattelises"],
    &["chattelizes"],
    &["chattelises"],
];

pub(crate) static ENTRY_CHATTELIZE_10573267935784980008: VariantsMap = [
    &["chattelize"],
    &["chattelise"],
    &["chattelize"],
    &["chattelise"],
];

pub(crate) static ENTRY_CHECKBOOKS_17373327628350162625: VariantsMap = [
    &["checkbooks"],
    &["chequebooks"],
    &["chequebooks"],
    &["chequebooks"],
];

pub(crate) static ENTRY_CHECKBOOK_1836353332372798027: VariantsMap = [
    &["checkbook"],
    &["chequebook"],
    &["chequebook"],
    &["chequebook"],
];

pub(crate) static ENTRY_CHECKED_9204677386650577893: VariantsMap =
    [&["checked"], &["chequed"], &["chequed"], &["chequed"]];

pub(crate) static ENTRY_CHECKERBOARDS_4609233615704287762: VariantsMap = [
    &["checkerboards"],
    &["chequerboards"],
    &["chequerboards"],
    &["chequerboards"],
];

pub(crate) static ENTRY_CHECKERBOARD_16789724192435672675: VariantsMap = [
    &["checkerboard"],
    &["chequerboard"],
    &["chequerboard"],
    &["chequerboard"],
];

pub(crate) static ENTRY_CHECKERED_9945873716414107297: VariantsMap = [
    &["checkered"],
    &["chequered"],
    &["checkered"],
    &["chequered"],
];

pub(crate) static ENTRY_CHECKERING_4080085454000431870: VariantsMap = [
    &["checkering"],
    &["chequering"],
    &["checkering"],
    &["chequering"],
];

pub(crate) static ENTRY_CHECKERS_10330904262647298958: VariantsMap =
    [&["checkers"], &["chequers"], &["checkers"], &["chequers"]];

pub(crate) static ENTRY_CHECKER_15996220430790986329: VariantsMap =
    [&["checker"], &["chequer"], &["checker"], &["chequer"]];

pub(crate) static ENTRY_CHECKING_12809623155680137187: VariantsMap =
    [&["checking"], &["chequing"], &["chequing"], &["chequing"]];

pub(crate) static ENTRY_CHECKS_2013661607139878581: VariantsMap =
    [&["checks"], &["cheques"], &["cheques"], &["cheques"]];

pub(crate) static ENTRY_CHECK_9710872025351452895: VariantsMap =
    [&["check"], &["cheque"], &["cheque"], &["cheque"]];

pub(crate) static ENTRY_CHEERFULIZES_5741050836564918219: VariantsMap = [
    &["cheerfulizes"],
    &["cheerfulises"],
    &["cheerfulizes"],
    &["cheerfulises"],
];

pub(crate) static ENTRY_CHEERFULIZE_10570276368652022687: VariantsMap = [
    &["cheerfulize"],
    &["cheerfulise"],
    &["cheerfulize"],
    &["cheerfulise"],
];

pub(crate) static ENTRY_CHEERLY_9201421946306221416: VariantsMap =
    [&["cheerly"], &["cherely"], &["cherely"], &["cherely"]];

pub(crate) static ENTRY_CHELICERE_7180330785369795833: VariantsMap = [
    &["chelicere"],
    &["chelicerae"],
    &["chelicerae"],
    &["chelicerae"],
];

pub(crate) static ENTRY_CHEMICALIZATIONS_3842257322989197933: VariantsMap = [
    &["chemicalizations"],
    &["chemicalisations"],
    &["chemicalizations"],
    &["chemicalisations"],
];

pub(crate) static ENTRY_CHEMICALIZATION_1118964376798303878: VariantsMap = [
    &["chemicalization"],
    &["chemicalisation"],
    &["chemicalization"],
    &["chemicalisation"],
];

pub(crate) static ENTRY_CHEMICALIZES_1636425057650084951: VariantsMap = [
    &["chemicalizes"],
    &["chemicalises"],
    &["chemicalizes"],
    &["chemicalises"],
];

pub(crate) static ENTRY_CHEMICALIZE_10557765234290972373: VariantsMap = [
    &["chemicalize"],
    &["chemicalise"],
    &["chemicalize"],
    &["chemicalise"],
];

pub(crate) static ENTRY_CHENIXES_12373276886429414482: VariantsMap = [
    &["chenixes"],
    &["choenixes"],
    &["choenixes"],
    &["choenixes"],
];

pub(crate) static ENTRY_CHENIX_9436665074503213945: VariantsMap =
    [&["chenix"], &["choenix"], &["choenix"], &["choenix"]];

pub(crate) static ENTRY_CHETOPOD_189649762509045765: VariantsMap = [
    &["chetopod"],
    &["chaetopod"],
    &["chaetopod"],
    &["chaetopod"],
];

pub(crate) static ENTRY_CHIFFER_14039870972729192317: VariantsMap =
    [&["chiffer"], &["chiffre"], &["chiffre"], &["chiffre"]];

pub(crate) static ENTRY_CHILDER_1783990015359332295: VariantsMap =
    [&["childer"], &["childre"], &["childre"], &["childre"]];

pub(crate) static ENTRY_CHILIES_17046197863582163056: VariantsMap =
    [&["chilies"], &["chillies"], &["chilies"], &["chillies"]];

pub(crate) static ENTRY_CHILI_8746464747530279303: VariantsMap =
    [&["chili"], &["chilli"], &["chili"], &["chilli"]];

pub(crate) static ENTRY_CHIMERIDS_13323620337760204404: VariantsMap = [
    &["chimerids"],
    &["chimaerids"],
    &["chimaerids"],
    &["chimaerids"],
];

pub(crate) static ENTRY_CHIMERID_12009697971234596857: VariantsMap = [
    &["chimerid"],
    &["chimaerid"],
    &["chimaerid"],
    &["chimaerid"],
];

pub(crate) static ENTRY_CHIMERISMS_14057193106240919198: VariantsMap = [
    &["chimerisms"],
    &["chimaerisms"],
    &["chimaerisms"],
    &["chimaerisms"],
];

pub(crate) static ENTRY_CHIMERISM_4161896008783758509: VariantsMap = [
    &["chimerism"],
    &["chimaerism"],
    &["chimaerism"],
    &["chimaerism"],
];

pub(crate) static ENTRY_CHISELED_15546949667254573790: VariantsMap = [
    &["chiseled"],
    &["chiselled"],
    &["chiselled"],
    &["chiselled"],
];

pub(crate) static ENTRY_CHISELERS_13598630043321083893: VariantsMap = [
    &["chiselers"],
    &["chisellers"],
    &["chisellers"],
    &["chisellers"],
];

pub(crate) static ENTRY_CHISELER_1587603412683173146: VariantsMap = [
    &["chiseler"],
    &["chiseller"],
    &["chiseller"],
    &["chiseller"],
];

pub(crate) static ENTRY_CHISELING_4623966446629021871: VariantsMap = [
    &["chiseling"],
    &["chiselling"],
    &["chiselling"],
    &["chiselling"],
];

pub(crate) static ENTRY_CHLORANEMIA_11270485874157916083: VariantsMap = [
    &["chloranemia"],
    &["chloranaemia"],
    &["chloranaemia"],
    &["chloranaemia"],
];

pub(crate) static ENTRY_CHLOREMIA_7420263500114563596: VariantsMap = [
    &["chloremia"],
    &["chloraemia"],
    &["chloraemia"],
    &["chloraemia"],
];

pub(crate) static ENTRY_CHLORIDIZED_13964319076359404488: VariantsMap = [
    &["chloridized"],
    &["chloridised"],
    &["chloridized"],
    &["chloridised"],
];

pub(crate) static ENTRY_CHLORIDIZES_9839694069117617871: VariantsMap = [
    &["chloridizes"],
    &["chloridises"],
    &["chloridizes"],
    &["chloridises"],
];

pub(crate) static ENTRY_CHLORIDIZE_9409684253444584379: VariantsMap = [
    &["chloridize"],
    &["chloridise"],
    &["chloridize"],
    &["chloridise"],
];

pub(crate) static ENTRY_CHLORIDIZING_6720106718363520715: VariantsMap = [
    &["chloridizing"],
    &["chloridising"],
    &["chloridizing"],
    &["chloridising"],
];

pub(crate) static ENTRY_CHLORINIZED_15553237296393813828: VariantsMap = [
    &["chlorinized"],
    &["chlorinised"],
    &["chlorinized"],
    &["chlorinised"],
];

pub(crate) static ENTRY_CHLORINIZES_11665336668178598109: VariantsMap = [
    &["chlorinizes"],
    &["chlorinises"],
    &["chlorinizes"],
    &["chlorinises"],
];

pub(crate) static ENTRY_CHLORINIZE_12524672883670643023: VariantsMap = [
    &["chlorinize"],
    &["chlorinise"],
    &["chlorinize"],
    &["chlorinise"],
];

pub(crate) static ENTRY_CHLORINIZING_14635019816160510486: VariantsMap = [
    &["chlorinizing"],
    &["chlorinising"],
    &["chlorinizing"],
    &["chlorinising"],
];

pub(crate) static ENTRY_CHLORITIZATIONS_10355800894312961778: VariantsMap = [
    &["chloritizations"],
    &["chloritisations"],
    &["chloritizations"],
    &["chloritisations"],
];

pub(crate) static ENTRY_CHLORITIZATION_6737319641916521224: VariantsMap = [
    &["chloritization"],
    &["chloritisation"],
    &["chloritization"],
    &["chloritisation"],
];

pub(crate) static ENTRY_CHLOROANEMIA_13191336111224105809: VariantsMap = [
    &["chloroanemia"],
    &["chloroanaemia"],
    &["chloroanaemia"],
    &["chloroanaemia"],
];

pub(crate) static ENTRY_CHLOROFORMIZATIONS_4190940435587315261: VariantsMap = [
    &["chloroformizations"],
    &["chloroformisations"],
    &["chloroformizations"],
    &["chloroformisations"],
];

pub(crate) static ENTRY_CHLOROFORMIZATION_8020987499143049943: VariantsMap = [
    &["chloroformization"],
    &["chloroformisation"],
    &["chloroformization"],
    &["chloroformisation"],
];

pub(crate) static ENTRY_CHLOROFORMIZES_17289598219370180905: VariantsMap = [
    &["chloroformizes"],
    &["chloroformises"],
    &["chloroformizes"],
    &["chloroformises"],
];

pub(crate) static ENTRY_CHLOROFORMIZE_9691972914840499500: VariantsMap = [
    &["chloroformize"],
    &["chloroformise"],
    &["chloroformize"],
    &["chloroformise"],
];

pub(crate) static ENTRY_CHOEPHORI_10552773655980362861: VariantsMap = [
    &["choephori"],
    &["choaephori"],
    &["choaephori"],
    &["choaephori"],
];

pub(crate) static ENTRY_CHOLEMIAS_2456580251486109547: VariantsMap = [
    &["cholemias"],
    &["cholaemias"],
    &["cholaemias"],
    &["cholaemias"],
];

pub(crate) static ENTRY_CHOLEMIA_6834066919164531101: VariantsMap = [
    &["cholemia"],
    &["cholaemia"],
    &["cholaemia"],
    &["cholaemia"],
];

pub(crate) static ENTRY_CHOLOPHEIN_5429784934275487908: VariantsMap = [
    &["cholophein"],
    &["cholophaein"],
    &["cholophaein"],
    &["cholophaein"],
];

pub(crate) static ENTRY_CHORIZATIONS_13097819281236468089: VariantsMap = [
    &["chorizations"],
    &["chorisations"],
    &["chorizations"],
    &["chorisations"],
];

pub(crate) static ENTRY_CHORIZATION_11714300496685916511: VariantsMap = [
    &["chorization"],
    &["chorisation"],
    &["chorization"],
    &["chorisation"],
];

pub(crate) static ENTRY_CHRISTIANIZATIONS_16703091698980017207: VariantsMap = [
    &["christianizations"],
    &["christianisations"],
    &["christianizations"],
    &["christianisations"],
];

pub(crate) static ENTRY_CHRISTIANIZATION_11631799398993571501: VariantsMap = [
    &["christianization"],
    &["christianisation"],
    &["christianization"],
    &["christianisation"],
];

pub(crate) static ENTRY_CHRISTIANIZED_14623745351432413209: VariantsMap = [
    &["christianized"],
    &["christianised"],
    &["christianized"],
    &["christianised"],
];

pub(crate) static ENTRY_CHRISTIANIZERS_548699853676213111: VariantsMap = [
    &["christianizers"],
    &["christianisers"],
    &["christianizers"],
    &["christianisers"],
];

pub(crate) static ENTRY_CHRISTIANIZER_2479285670414112843: VariantsMap = [
    &["christianizer"],
    &["christianiser"],
    &["christianizer"],
    &["christianiser"],
];

pub(crate) static ENTRY_CHRISTIANIZES_5529854457085699383: VariantsMap = [
    &["christianizes"],
    &["christianises"],
    &["christianizes"],
    &["christianises"],
];

pub(crate) static ENTRY_CHRISTIANIZE_15479599846963049140: VariantsMap = [
    &["christianize"],
    &["christianise"],
    &["christianize"],
    &["christianise"],
];

pub(crate) static ENTRY_CHRISTIANIZING_18179844943674675649: VariantsMap = [
    &["christianizing"],
    &["christianising"],
    &["christianizing"],
    &["christianising"],
];

pub(crate) static ENTRY_CHROMATIZES_13288811852915667150: VariantsMap = [
    &["chromatizes"],
    &["chromatises"],
    &["chromatizes"],
    &["chromatises"],
];

pub(crate) static ENTRY_CHROMATIZE_2668025850337683157: VariantsMap = [
    &["chromatize"],
    &["chromatise"],
    &["chromatize"],
    &["chromatise"],
];

pub(crate) static ENTRY_CHROMESTHESIA_13054371463552987700: VariantsMap = [
    &["chromesthesia"],
    &["chromaesthesia"],
    &["chromaesthesia"],
    &["chromaesthesia"],
];

pub(crate) static ENTRY_CHROMICIZES_13307038207206351843: VariantsMap = [
    &["chromicizes"],
    &["chromicises"],
    &["chromicizes"],
    &["chromicises"],
];

pub(crate) static ENTRY_CHROMICIZE_12696401195528858571: VariantsMap = [
    &["chromicize"],
    &["chromicise"],
    &["chromicize"],
    &["chromicise"],
];

pub(crate) static ENTRY_CHROMIZED_12919396713518006471: VariantsMap = [
    &["chromized"],
    &["chromised"],
    &["chromized"],
    &["chromised"],
];

pub(crate) static ENTRY_CHROMIZES_5753213299896220168: VariantsMap = [
    &["chromizes"],
    &["chromises"],
    &["chromizes"],
    &["chromises"],
];

pub(crate) static ENTRY_CHROMIZE_12632752465699049760: VariantsMap =
    [&["chromize"], &["chromise"], &["chromize"], &["chromise"]];

pub(crate) static ENTRY_CHROMIZING_5933298884828048845: VariantsMap = [
    &["chromizing"],
    &["chromising"],
    &["chromizing"],
    &["chromising"],
];

pub(crate) static ENTRY_CHRONOLOGIZED_15542262960559957529: VariantsMap = [
    &["chronologized"],
    &["chronologised"],
    &["chronologized"],
    &["chronologised"],
];

pub(crate) static ENTRY_CHRONOLOGIZES_13298230809874096677: VariantsMap = [
    &["chronologizes"],
    &["chronologises"],
    &["chronologizes"],
    &["chronologises"],
];

pub(crate) static ENTRY_CHRONOLOGIZE_3452679310375560624: VariantsMap = [
    &["chronologize"],
    &["chronologise"],
    &["chronologize"],
    &["chronologise"],
];

pub(crate) static ENTRY_CHRONOLOGIZING_12511502139252569918: VariantsMap = [
    &["chronologizing"],
    &["chronologising"],
    &["chronologizing"],
    &["chronologising"],
];

pub(crate) static ENTRY_CICATRICES_17574423838445240061: VariantsMap = [
    &["cicatrices"],
    &["cicatrices"],
    &["cicatrices"],
    &["cicatrices"],
];

pub(crate) static ENTRY_CICATRICULE_3423950138630950565: VariantsMap = [
    &["cicatricule"],
    &["cicatriculae"],
    &["cicatriculae"],
    &["cicatriculae"],
];

pub(crate) static ENTRY_CICATRIZANT_14580030762509411820: VariantsMap = [
    &["cicatrizant"],
    &["cicatrisant"],
    &["cicatrizant"],
    &["cicatrisant"],
];

pub(crate) static ENTRY_CICATRIZATE_13034404440200633128: VariantsMap = [
    &["cicatrizate"],
    &["cicatrisate"],
    &["cicatrizate"],
    &["cicatrisate"],
];

pub(crate) static ENTRY_CICATRIZATIONS_6401479390305959155: VariantsMap = [
    &["cicatrizations"],
    &["cicatrisations"],
    &["cicatrizations"],
    &["cicatrisations"],
];

pub(crate) static ENTRY_CICATRIZATION_9264802001449770315: VariantsMap = [
    &["cicatrization"],
    &["cicatrisation"],
    &["cicatrization"],
    &["cicatrisation"],
];

pub(crate) static ENTRY_CICATRIZED_1828890261939464598: VariantsMap = [
    &["cicatrized"],
    &["cicatrised"],
    &["cicatrized"],
    &["cicatrised"],
];

pub(crate) static ENTRY_CICATRIZER_7968728130764832311: VariantsMap = [
    &["cicatrizer"],
    &["cicatriser"],
    &["cicatrizer"],
    &["cicatriser"],
];

pub(crate) static ENTRY_CICATRIZES_10804914940535295994: VariantsMap = [
    &["cicatrizes"],
    &["cicatrises"],
    &["cicatrizes"],
    &["cicatrises"],
];

pub(crate) static ENTRY_CICATRIZE_10818694238612969910: VariantsMap = [
    &["cicatrize"],
    &["cicatrise"],
    &["cicatrize"],
    &["cicatrise"],
];

pub(crate) static ENTRY_CICATRIZING_2146572731064124559: VariantsMap = [
    &["cicatrizing"],
    &["cicatrising"],
    &["cicatrizing"],
    &["cicatrising"],
];

pub(crate) static ENTRY_CICERONIANIZES_8272191235039896374: VariantsMap = [
    &["ciceronianizes"],
    &["ciceronianises"],
    &["ciceronianizes"],
    &["ciceronianises"],
];

pub(crate) static ENTRY_CICERONIANIZE_954039864252417924: VariantsMap = [
    &["ciceronianize"],
    &["ciceronianise"],
    &["ciceronianize"],
    &["ciceronianise"],
];

pub(crate) static ENTRY_CIGARETTES_16419249441518698267: VariantsMap = [
    &["cigarettes"],
    &["cigarettes"],
    &["cigarettes"],
    &["cigarettes"],
];

pub(crate) static ENTRY_CIGARETTE_5420991040189256779: VariantsMap = [
    &["cigarette"],
    &["cigarette"],
    &["cigarette"],
    &["cigarette"],
];

pub(crate) static ENTRY_CIMICIDE_16199859638855147432: VariantsMap = [
    &["cimicide"],
    &["cimicidae"],
    &["cimicidae"],
    &["cimicidae"],
];

pub(crate) static ENTRY_CINCHONIZATIONS_11466854488565689917: VariantsMap = [
    &["cinchonizations"],
    &["cinchonisations"],
    &["cinchonizations"],
    &["cinchonisations"],
];

pub(crate) static ENTRY_CINCHONIZATION_8898418899758893781: VariantsMap = [
    &["cinchonization"],
    &["cinchonisation"],
    &["cinchonization"],
    &["cinchonisation"],
];

pub(crate) static ENTRY_CINCHONIZED_10320384586732033099: VariantsMap = [
    &["cinchonized"],
    &["cinchonised"],
    &["cinchonized"],
    &["cinchonised"],
];

pub(crate) static ENTRY_CINCHONIZES_13630850583605907955: VariantsMap = [
    &["cinchonizes"],
    &["cinchonises"],
    &["cinchonizes"],
    &["cinchonises"],
];

pub(crate) static ENTRY_CINCHONIZE_7002464384875628561: VariantsMap = [
    &["cinchonize"],
    &["cinchonise"],
    &["cinchonize"],
    &["cinchonise"],
];

pub(crate) static ENTRY_CINCHONIZING_1127474968700444323: VariantsMap = [
    &["cinchonizing"],
    &["cinchonising"],
    &["cinchonizing"],
    &["cinchonising"],
];

pub(crate) static ENTRY_CINEMATIZE_887503370904956303: VariantsMap = [
    &["cinematize"],
    &["cinematise"],
    &["cinematize"],
    &["cinematise"],
];

pub(crate) static ENTRY_CINTER_12423048040489747966: VariantsMap =
    [&["cinter"], &["cintre"], &["cintre"], &["cintre"]];

pub(crate) static ENTRY_CIPHERED_15203892274342132278: VariantsMap =
    [&["ciphered"], &["ciphered"], &["ciphered"], &["ciphered"]];

pub(crate) static ENTRY_CIPHERING_14057839138660888428: VariantsMap = [
    &["ciphering"],
    &["ciphering"],
    &["ciphering"],
    &["ciphering"],
];

pub(crate) static ENTRY_CIPHERS_4808512383208465724: VariantsMap =
    [&["ciphers"], &["ciphers"], &["ciphers"], &["ciphers"]];

pub(crate) static ENTRY_CIPHER_16521802570229937628: VariantsMap =
    [&["cipher"], &["cipher"], &["cipher"], &["cipher"]];

pub(crate) static ENTRY_CIRCEAN_13914378621232486516: VariantsMap =
    [&["circean"], &["circaean"], &["circaean"], &["circaean"]];

pub(crate) static ENTRY_CIRCULARIZATIONS_15969413902903833833: VariantsMap = [
    &["circularizations"],
    &["circularisations"],
    &["circularizations"],
    &["circularisations"],
];

pub(crate) static ENTRY_CIRCULARIZATION_13446228978184474783: VariantsMap = [
    &["circularization"],
    &["circularisation"],
    &["circularization"],
    &["circularisation"],
];

pub(crate) static ENTRY_CIRCULARIZED_10196681630788896392: VariantsMap = [
    &["circularized"],
    &["circularised"],
    &["circularized"],
    &["circularised"],
];

pub(crate) static ENTRY_CIRCULARIZERS_9385945421646713627: VariantsMap = [
    &["circularizers"],
    &["circularisers"],
    &["circularizers"],
    &["circularisers"],
];

pub(crate) static ENTRY_CIRCULARIZER_5474163430499344980: VariantsMap = [
    &["circularizer"],
    &["circulariser"],
    &["circularizer"],
    &["circulariser"],
];

pub(crate) static ENTRY_CIRCULARIZES_2687194339579068787: VariantsMap = [
    &["circularizes"],
    &["circularises"],
    &["circularizes"],
    &["circularises"],
];

pub(crate) static ENTRY_CIRCULARIZE_17976452635575197775: VariantsMap = [
    &["circularize"],
    &["circularise"],
    &["circularize"],
    &["circularise"],
];

pub(crate) static ENTRY_CIRCULARIZING_5021096955296996517: VariantsMap = [
    &["circularizing"],
    &["circularising"],
    &["circularizing"],
    &["circularising"],
];

pub(crate) static ENTRY_CIRCUMCENTERS_12086402493856101663: VariantsMap = [
    &["circumcenters"],
    &["circumcentres"],
    &["circumcentres"],
    &["circumcentres"],
];

pub(crate) static ENTRY_CIRCUMCENTER_13368725237225377813: VariantsMap = [
    &["circumcenter"],
    &["circumcentre"],
    &["circumcentre"],
    &["circumcentre"],
];

pub(crate) static ENTRY_CIRCUMESOPHAGAL_15080034942492674876: VariantsMap = [
    &["circumesophagal"],
    &["circumoesophagal"],
    &["circumoesophagal"],
    &["circumoesophagal"],
];

pub(crate) static ENTRY_CITHERNS_3103642542221543646: VariantsMap =
    [&["citherns"], &["cithrens"], &["cithrens"], &["cithrens"]];

pub(crate) static ENTRY_CITHERN_7019582320411452194: VariantsMap =
    [&["cithern"], &["cithren"], &["cithren"], &["cithren"]];

pub(crate) static ENTRY_CITIZENIZED_9568727046657390022: VariantsMap = [
    &["citizenized"],
    &["citizenised"],
    &["citizenized"],
    &["citizenised"],
];

pub(crate) static ENTRY_CITIZENIZES_16757027513992676737: VariantsMap = [
    &["citizenizes"],
    &["citizenises"],
    &["citizenizes"],
    &["citizenises"],
];

pub(crate) static ENTRY_CITIZENIZE_8500004873095245347: VariantsMap = [
    &["citizenize"],
    &["citizenise"],
    &["citizenize"],
    &["citizenise"],
];

pub(crate) static ENTRY_CITIZENIZING_3145059359855704610: VariantsMap = [
    &["citizenizing"],
    &["citizenising"],
    &["citizenizing"],
    &["citizenising"],
];

pub(crate) static ENTRY_CIVILIANIZATIONS_1184580639044287766: VariantsMap = [
    &["civilianizations"],
    &["civilianisations"],
    &["civilianizations"],
    &["civilianisations"],
];

pub(crate) static ENTRY_CIVILIANIZATION_7286943312580518737: VariantsMap = [
    &["civilianization"],
    &["civilianisation"],
    &["civilianization"],
    &["civilianisation"],
];

pub(crate) static ENTRY_CIVILIANIZED_15858039446683412237: VariantsMap = [
    &["civilianized"],
    &["civilianised"],
    &["civilianized"],
    &["civilianised"],
];

pub(crate) static ENTRY_CIVILIANIZES_7876834226685948201: VariantsMap = [
    &["civilianizes"],
    &["civilianises"],
    &["civilianizes"],
    &["civilianises"],
];

pub(crate) static ENTRY_CIVILIANIZE_9200206390563342469: VariantsMap = [
    &["civilianize"],
    &["civilianise"],
    &["civilianize"],
    &["civilianise"],
];

pub(crate) static ENTRY_CIVILIANIZING_13031723867600209433: VariantsMap = [
    &["civilianizing"],
    &["civilianising"],
    &["civilianizing"],
    &["civilianising"],
];

pub(crate) static ENTRY_CIVILIZABLER_1074825683746490989: VariantsMap = [
    &["civilizabler"],
    &["civilisabler"],
    &["civilizabler"],
    &["civilisabler"],
];

pub(crate) static ENTRY_CIVILIZABLEST_12041786786344794314: VariantsMap = [
    &["civilizablest"],
    &["civilisablest"],
    &["civilizablest"],
    &["civilisablest"],
];

pub(crate) static ENTRY_CIVILIZABLES_4607646917173663003: VariantsMap = [
    &["civilizables"],
    &["civilisables"],
    &["civilizables"],
    &["civilisables"],
];

pub(crate) static ENTRY_CIVILIZABLE_9989179314754294521: VariantsMap = [
    &["civilizable"],
    &["civilisable"],
    &["civilizable"],
    &["civilisable"],
];

pub(crate) static ENTRY_CIVILIZATIONALER_5751340816103939865: VariantsMap = [
    &["civilizationaler"],
    &["civilisationaler"],
    &["civilizationaler"],
    &["civilisationaler"],
];

pub(crate) static ENTRY_CIVILIZATIONALEST_9429491474830355260: VariantsMap = [
    &["civilizationalest"],
    &["civilisationalest"],
    &["civilizationalest"],
    &["civilisationalest"],
];

pub(crate) static ENTRY_CIVILIZATIONALS_7189230314901517664: VariantsMap = [
    &["civilizationals"],
    &["civilisationals"],
    &["civilizationals"],
    &["civilisationals"],
];

pub(crate) static ENTRY_CIVILIZATIONAL_13278373598904289511: VariantsMap = [
    &["civilizational"],
    &["civilisational"],
    &["civilizational"],
    &["civilisational"],
];

pub(crate) static ENTRY_CIVILIZATIONS_8013365541301592457: VariantsMap = [
    &["civilizations"],
    &["civilisations"],
    &["civilizations"],
    &["civilisations"],
];

pub(crate) static ENTRY_CIVILIZATION_15411020791056209676: VariantsMap = [
    &["civilization"],
    &["civilisation"],
    &["civilization"],
    &["civilisation"],
];

pub(crate) static ENTRY_CIVILIZATORY_8170984304313567948: VariantsMap = [
    &["civilizatory"],
    &["civilisatory"],
    &["civilizatory"],
    &["civilisatory"],
];

pub(crate) static ENTRY_CIVILIZEDNESSES_3387643148858025856: VariantsMap = [
    &["civilizednesses"],
    &["civilisednesses"],
    &["civilizednesses"],
    &["civilisednesses"],
];

pub(crate) static ENTRY_CIVILIZEDNESS_2902568270319878801: VariantsMap = [
    &["civilizedness"],
    &["civilisedness"],
    &["civilizedness"],
    &["civilisedness"],
];

pub(crate) static ENTRY_CIVILIZED_8223404244720114957: VariantsMap = [
    &["civilized"],
    &["civilised"],
    &["civilized"],
    &["civilised"],
];

pub(crate) static ENTRY_CIVILIZERS_3015830727153297093: VariantsMap = [
    &["civilizers"],
    &["civilisers"],
    &["civilizers"],
    &["civilisers"],
];

pub(crate) static ENTRY_CIVILIZER_8024073242072515118: VariantsMap = [
    &["civilizer"],
    &["civiliser"],
    &["civilizer"],
    &["civiliser"],
];

pub(crate) static ENTRY_CIVILIZES_9333851959553393399: VariantsMap = [
    &["civilizes"],
    &["civilises"],
    &["civilizes"],
    &["civilises"],
];

pub(crate) static ENTRY_CIVILIZE_16590332670644302211: VariantsMap =
    [&["civilize"], &["civilise"], &["civilize"], &["civilise"]];

pub(crate) static ENTRY_CIVILIZING_17372507961283340052: VariantsMap = [
    &["civilizing"],
    &["civilising"],
    &["civilizing"],
    &["civilising"],
];

pub(crate) static ENTRY_CIZE_17978395450979456583: VariantsMap =
    [&["cize"], &["cise"], &["cize"], &["cise"]];

pub(crate) static ENTRY_CLAMORED_2092729859202254484: VariantsMap = [
    &["clamored"],
    &["clamoured"],
    &["clamoured"],
    &["clamoured"],
];

pub(crate) static ENTRY_CLAMORERS_11938498029963459379: VariantsMap = [
    &["clamorers"],
    &["clamourers"],
    &["clamourers"],
    &["clamourers"],
];

pub(crate) static ENTRY_CLAMORER_2016537190882321769: VariantsMap = [
    &["clamorer"],
    &["clamourer"],
    &["clamourer"],
    &["clamourer"],
];

pub(crate) static ENTRY_CLAMORING_17170493137896914728: VariantsMap = [
    &["clamoring"],
    &["clamouring"],
    &["clamouring"],
    &["clamouring"],
];

pub(crate) static ENTRY_CLAMORIST_1995860053434361541: VariantsMap = [
    &["clamorist"],
    &["clamourist"],
    &["clamourist"],
    &["clamourist"],
];

pub(crate) static ENTRY_CLAMORSOME_330894112921712012: VariantsMap = [
    &["clamorsome"],
    &["clamoursome"],
    &["clamoursome"],
    &["clamoursome"],
];

pub(crate) static ENTRY_CLAMORS_12585789829012154512: VariantsMap =
    [&["clamors"], &["clamours"], &["clamours"], &["clamours"]];

pub(crate) static ENTRY_CLAMOR_5158185862304229945: VariantsMap =
    [&["clamor"], &["clamour"], &["clamour"], &["clamour"]];

pub(crate) static ENTRY_CLANGORED_4896068625903464560: VariantsMap = [
    &["clangored"],
    &["clangoured"],
    &["clangoured"],
    &["clangoured"],
];

pub(crate) static ENTRY_CLANGORING_2067393512241593148: VariantsMap = [
    &["clangoring"],
    &["clangouring"],
    &["clangouring"],
    &["clangouring"],
];

pub(crate) static ENTRY_CLANGORS_9815521559387015927: VariantsMap = [
    &["clangors"],
    &["clangours"],
    &["clangours"],
    &["clangours"],
];

pub(crate) static ENTRY_CLANGOR_11068622204017638397: VariantsMap =
    [&["clangor"], &["clangour"], &["clangour"], &["clangour"]];

pub(crate) static ENTRY_CLARES_5409815003752679904: VariantsMap =
    [&["clares"], &["claroes"], &["claroes"], &["claroes"]];

pub(crate) static ENTRY_CLARINETISTS_6735422107420159102: VariantsMap = [
    &["clarinetists"],
    &["clarinettists"],
    &["clarinetists"],
    &["clarinettists"],
];

pub(crate) static ENTRY_CLARINETIST_10300531156065359462: VariantsMap = [
    &["clarinetist"],
    &["clarinettist"],
    &["clarinetist"],
    &["clarinettist"],
];

pub(crate) static ENTRY_CLASSICALIZES_2327042308575389083: VariantsMap = [
    &["classicalizes"],
    &["classicalises"],
    &["classicalizes"],
    &["classicalises"],
];

pub(crate) static ENTRY_CLASSICALIZE_14979442572681110295: VariantsMap = [
    &["classicalize"],
    &["classicalise"],
    &["classicalize"],
    &["classicalise"],
];

pub(crate) static ENTRY_CLASSICIZATION_16187684362412692047: VariantsMap = [
    &["classicization"],
    &["classicisation"],
    &["classicization"],
    &["classicisation"],
];

pub(crate) static ENTRY_CLASSICIZED_1424459898101384526: VariantsMap = [
    &["classicized"],
    &["classicised"],
    &["classicized"],
    &["classicised"],
];

pub(crate) static ENTRY_CLASSICIZES_5416184573508461528: VariantsMap = [
    &["classicizes"],
    &["classicises"],
    &["classicizes"],
    &["classicises"],
];

pub(crate) static ENTRY_CLASSICIZE_6173596440580862000: VariantsMap = [
    &["classicize"],
    &["classicise"],
    &["classicize"],
    &["classicise"],
];

pub(crate) static ENTRY_CLASSICIZING_7645297896587290775: VariantsMap = [
    &["classicizing"],
    &["classicising"],
    &["classicizing"],
    &["classicising"],
];

pub(crate) static ENTRY_CLAUSULE_13784658851539783980: VariantsMap = [
    &["clausule"],
    &["clausulae"],
    &["clausulae"],
    &["clausulae"],
];

pub(crate) static ENTRY_CLERICALIZES_9868541024178822970: VariantsMap = [
    &["clericalizes"],
    &["clericalises"],
    &["clericalizes"],
    &["clericalises"],
];

pub(crate) static ENTRY_CLERICALIZE_8419668540187724800: VariantsMap = [
    &["clericalize"],
    &["clericalise"],
    &["clericalize"],
    &["clericalise"],
];

pub(crate) static ENTRY_CLETE_9114346982470440863: VariantsMap =
    [&["clete"], &["cloete"], &["cloete"], &["cloete"]];

pub(crate) static ENTRY_CLIMATIZED_8642688561481903657: VariantsMap = [
    &["climatized"],
    &["climatised"],
    &["climatized"],
    &["climatised"],
];

pub(crate) static ENTRY_CLIMATIZES_10325703256837622121: VariantsMap = [
    &["climatizes"],
    &["climatises"],
    &["climatizes"],
    &["climatises"],
];

pub(crate) static ENTRY_CLIMATIZE_17719324526044936011: VariantsMap = [
    &["climatize"],
    &["climatise"],
    &["climatize"],
    &["climatise"],
];

pub(crate) static ENTRY_CLIMATIZING_12047667901968744541: VariantsMap = [
    &["climatizing"],
    &["climatising"],
    &["climatizing"],
    &["climatising"],
];

pub(crate) static ENTRY_CLOWER_14920406222871692430: VariantsMap =
    [&["clower"], &["clowre"], &["clowre"], &["clowre"]];

pub(crate) static ENTRY_CLYTIE_15430707852737482986: VariantsMap =
    [&["clytie"], &["clytiae"], &["clytiae"], &["clytiae"]];

pub(crate) static ENTRY_COALIZED_3645830777684850035: VariantsMap =
    [&["coalized"], &["coalised"], &["coalized"], &["coalised"]];

pub(crate) static ENTRY_COALIZERS_12486481008714536417: VariantsMap = [
    &["coalizers"],
    &["coalisers"],
    &["coalizers"],
    &["coalisers"],
];

pub(crate) static ENTRY_COALIZER_5925785296167946025: VariantsMap =
    [&["coalizer"], &["coaliser"], &["coalizer"], &["coaliser"]];

pub(crate) static ENTRY_COALIZES_580286287171430443: VariantsMap =
    [&["coalizes"], &["coalises"], &["coalizes"], &["coalises"]];

pub(crate) static ENTRY_COALIZE_11558724977177179550: VariantsMap =
    [&["coalize"], &["coalise"], &["coalize"], &["coalise"]];

pub(crate) static ENTRY_COALIZING_694156750091536205: VariantsMap = [
    &["coalizing"],
    &["coalising"],
    &["coalizing"],
    &["coalising"],
];

pub(crate) static ENTRY_COCAINIZATIONS_17964048038138593445: VariantsMap = [
    &["cocainizations"],
    &["cocainisations"],
    &["cocainizations"],
    &["cocainisations"],
];

pub(crate) static ENTRY_COCAINIZATION_1565985876637474561: VariantsMap = [
    &["cocainization"],
    &["cocainisation"],
    &["cocainization"],
    &["cocainisation"],
];

pub(crate) static ENTRY_COCAINIZED_14547823316205743882: VariantsMap = [
    &["cocainized"],
    &["cocainised"],
    &["cocainized"],
    &["cocainised"],
];

pub(crate) static ENTRY_COCAINIZES_15635621286592311027: VariantsMap = [
    &["cocainizes"],
    &["cocainises"],
    &["cocainizes"],
    &["cocainises"],
];

pub(crate) static ENTRY_COCAINIZE_3674396344816602030: VariantsMap = [
    &["cocainize"],
    &["cocainise"],
    &["cocainize"],
    &["cocainise"],
];

pub(crate) static ENTRY_COCAINIZING_4136645123820639818: VariantsMap = [
    &["cocainizing"],
    &["cocainising"],
    &["cocainizing"],
    &["cocainising"],
];

pub(crate) static ENTRY_COCUIZA_14986726333358901234: VariantsMap =
    [&["cocuiza"], &["cocuisa"], &["cocuiza"], &["cocuisa"]];

pub(crate) static ENTRY_COEDUCATIONALIZES_9568142082441537090: VariantsMap = [
    &["coeducationalizes"],
    &["coeducationalises"],
    &["coeducationalizes"],
    &["coeducationalises"],
];

pub(crate) static ENTRY_COEDUCATIONALIZE_3086000341959483566: VariantsMap = [
    &["coeducationalize"],
    &["coeducationalise"],
    &["coeducationalize"],
    &["coeducationalise"],
];

pub(crate) static ENTRY_COENAMORED_14206991445267202710: VariantsMap = [
    &["coenamored"],
    &["coenamoured"],
    &["coenamoured"],
    &["coenamoured"],
];

pub(crate) static ENTRY_COENAMORING_8672063553065406305: VariantsMap = [
    &["coenamoring"],
    &["coenamouring"],
    &["coenamouring"],
    &["coenamouring"],
];

pub(crate) static ENTRY_COENAMORMENT_5585745797135358489: VariantsMap = [
    &["coenamorment"],
    &["coenamourment"],
    &["coenamourment"],
    &["coenamourment"],
];

pub(crate) static ENTRY_COENAMORS_14785645811529661699: VariantsMap = [
    &["coenamors"],
    &["coenamours"],
    &["coenamours"],
    &["coenamours"],
];

pub(crate) static ENTRY_COENAMOR_12585202648195371106: VariantsMap = [
    &["coenamor"],
    &["coenamour"],
    &["coenamour"],
    &["coenamour"],
];

pub(crate) static ENTRY_COEQUALIZES_452700607554473573: VariantsMap = [
    &["coequalizes"],
    &["coequalises"],
    &["coequalizes"],
    &["coequalises"],
];

pub(crate) static ENTRY_COEQUALIZE_8933102284206871912: VariantsMap = [
    &["coequalize"],
    &["coequalise"],
    &["coequalize"],
    &["coequalise"],
];

pub(crate) static ENTRY_COE_15056580635786997263: VariantsMap =
    [&["coe"], &["cooe"], &["cooe"], &["cooe"]];

pub(crate) static ENTRY_COGNIZABILITY_3446315876410265322: VariantsMap = [
    &["cognizability"],
    &["cognisability"],
    &["cognizability"],
    &["cognisability"],
];

pub(crate) static ENTRY_COGNIZABLENESS_8915902797245580552: VariantsMap = [
    &["cognizableness"],
    &["cognisableness"],
    &["cognizableness"],
    &["cognisableness"],
];

pub(crate) static ENTRY_COGNIZABLER_15866973125677355856: VariantsMap = [
    &["cognizabler"],
    &["cognisabler"],
    &["cognizabler"],
    &["cognisabler"],
];

pub(crate) static ENTRY_COGNIZABLEST_2508940668012161280: VariantsMap = [
    &["cognizablest"],
    &["cognisablest"],
    &["cognizablest"],
    &["cognisablest"],
];

pub(crate) static ENTRY_COGNIZABLE_17452455676169531153: VariantsMap = [
    &["cognizable"],
    &["cognisable"],
    &["cognizable"],
    &["cognisable"],
];

pub(crate) static ENTRY_COGNIZABLIER_12566683806712864297: VariantsMap = [
    &["cognizablier"],
    &["cognisablier"],
    &["cognizablier"],
    &["cognisablier"],
];

pub(crate) static ENTRY_COGNIZABLIEST_10273112470027332981: VariantsMap = [
    &["cognizabliest"],
    &["cognisabliest"],
    &["cognizabliest"],
    &["cognisabliest"],
];

pub(crate) static ENTRY_COGNIZABLY_7985411479326092139: VariantsMap = [
    &["cognizably"],
    &["cognisably"],
    &["cognizably"],
    &["cognisably"],
];

pub(crate) static ENTRY_COGNIZANCES_278004122060158781: VariantsMap = [
    &["cognizances"],
    &["cognisances"],
    &["cognizances"],
    &["cognisances"],
];

pub(crate) static ENTRY_COGNIZANCE_16406744570348652654: VariantsMap = [
    &["cognizance"],
    &["cognisance"],
    &["cognizance"],
    &["cognisance"],
];

pub(crate) static ENTRY_COGNIZANTER_1642202493657548366: VariantsMap = [
    &["cognizanter"],
    &["cognisanter"],
    &["cognizanter"],
    &["cognisanter"],
];

pub(crate) static ENTRY_COGNIZANTEST_2041114456387040574: VariantsMap = [
    &["cognizantest"],
    &["cognisantest"],
    &["cognizantest"],
    &["cognisantest"],
];

pub(crate) static ENTRY_COGNIZANT_8482318087824381990: VariantsMap = [
    &["cognizant"],
    &["cognisant"],
    &["cognizant"],
    &["cognisant"],
];

pub(crate) static ENTRY_COGNIZED_6020528868489883774: VariantsMap =
    [&["cognized"], &["cognised"], &["cognized"], &["cognised"]];

pub(crate) static ENTRY_COGNIZERS_3699936194698127720: VariantsMap = [
    &["cognizers"],
    &["cognisers"],
    &["cognizers"],
    &["cognisers"],
];

pub(crate) static ENTRY_COGNIZER_16090594603569153260: VariantsMap =
    [&["cognizer"], &["cogniser"], &["cognizer"], &["cogniser"]];

pub(crate) static ENTRY_COGNIZES_10693547746110885948: VariantsMap =
    [&["cognizes"], &["cognises"], &["cognizes"], &["cognises"]];

pub(crate) static ENTRY_COGNIZE_2805454015471605031: VariantsMap =
    [&["cognize"], &["cognise"], &["cognize"], &["cognise"]];

pub(crate) static ENTRY_COGNIZING_4439407777143073908: VariantsMap = [
    &["cognizing"],
    &["cognising"],
    &["cognizing"],
    &["cognising"],
];

pub(crate) static ENTRY_COLLATERALIZE_8441122820061036167: VariantsMap = [
    &["collateralize"],
    &["collateralise"],
    &["collateralize"],
    &["collateralise"],
];

pub(crate) static ENTRY_COLLECTIBLES_7358720680663200346: VariantsMap = [
    &["collectibles"],
    &["collectables"],
    &["collectibles"],
    &["collectables"],
];

pub(crate) static ENTRY_COLLECTIBLE_1730285011498072035: VariantsMap = [
    &["collectible"],
    &["collectable"],
    &["collectible"],
    &["collectable"],
];

pub(crate) static ENTRY_COLLECTIVIZATIONS_6195427118788754823: VariantsMap = [
    &["collectivizations"],
    &["collectivisations"],
    &["collectivizations"],
    &["collectivisations"],
];

pub(crate) static ENTRY_COLLECTIVIZATION_1362380877833359975: VariantsMap = [
    &["collectivization"],
    &["collectivisation"],
    &["collectivization"],
    &["collectivisation"],
];

pub(crate) static ENTRY_COLLECTIVIZED_6132833186626165249: VariantsMap = [
    &["collectivized"],
    &["collectivised"],
    &["collectivized"],
    &["collectivised"],
];

pub(crate) static ENTRY_COLLECTIVIZES_10627545540156031817: VariantsMap = [
    &["collectivizes"],
    &["collectivises"],
    &["collectivizes"],
    &["collectivises"],
];

pub(crate) static ENTRY_COLLECTIVIZE_12809074466084828054: VariantsMap = [
    &["collectivize"],
    &["collectivise"],
    &["collectivize"],
    &["collectivise"],
];

pub(crate) static ENTRY_COLLECTIVIZING_7798244009757756216: VariantsMap = [
    &["collectivizing"],
    &["collectivising"],
    &["collectivizing"],
    &["collectivising"],
];

pub(crate) static ENTRY_COLLOQUIALIZES_4056117948065720431: VariantsMap = [
    &["colloquializes"],
    &["colloquialises"],
    &["colloquializes"],
    &["colloquialises"],
];

pub(crate) static ENTRY_COLLOQUIALIZE_6461602182250284611: VariantsMap = [
    &["colloquialize"],
    &["colloquialise"],
    &["colloquialize"],
    &["colloquialise"],
];

pub(crate) static ENTRY_COLLOQUIZED_13559947537098336546: VariantsMap = [
    &["colloquized"],
    &["colloquised"],
    &["colloquized"],
    &["colloquised"],
];

pub(crate) static ENTRY_COLLOQUIZES_6598013176193983362: VariantsMap = [
    &["colloquizes"],
    &["colloquises"],
    &["colloquizes"],
    &["colloquises"],
];

pub(crate) static ENTRY_COLLOQUIZE_15542701926724482347: VariantsMap = [
    &["colloquize"],
    &["colloquise"],
    &["colloquize"],
    &["colloquise"],
];

pub(crate) static ENTRY_COLLOQUIZING_18394182203016272897: VariantsMap = [
    &["colloquizing"],
    &["colloquising"],
    &["colloquizing"],
    &["colloquising"],
];

pub(crate) static ENTRY_COLONIALIZED_9330153878225199389: VariantsMap = [
    &["colonialized"],
    &["colonialised"],
    &["colonialized"],
    &["colonialised"],
];

pub(crate) static ENTRY_COLONIALIZES_960436986919349894: VariantsMap = [
    &["colonializes"],
    &["colonialises"],
    &["colonializes"],
    &["colonialises"],
];

pub(crate) static ENTRY_COLONIALIZE_2476668941415938404: VariantsMap = [
    &["colonialize"],
    &["colonialise"],
    &["colonialize"],
    &["colonialise"],
];

pub(crate) static ENTRY_COLONIALIZING_17918492670165907096: VariantsMap = [
    &["colonializing"],
    &["colonialising"],
    &["colonializing"],
    &["colonialising"],
];

pub(crate) static ENTRY_COLONIZABILITIES_11409323284499327132: VariantsMap = [
    &["colonizabilities"],
    &["colonisabilities"],
    &["colonizabilities"],
    &["colonisabilities"],
];

pub(crate) static ENTRY_COLONIZABILITY_15907592922758162551: VariantsMap = [
    &["colonizability"],
    &["colonisability"],
    &["colonizability"],
    &["colonisability"],
];

pub(crate) static ENTRY_COLONIZABLER_8047959087063068506: VariantsMap = [
    &["colonizabler"],
    &["colonisabler"],
    &["colonizabler"],
    &["colonisabler"],
];

pub(crate) static ENTRY_COLONIZABLEST_13440662900309087302: VariantsMap = [
    &["colonizablest"],
    &["colonisablest"],
    &["colonizablest"],
    &["colonisablest"],
];

pub(crate) static ENTRY_COLONIZABLES_3770494241206552717: VariantsMap = [
    &["colonizables"],
    &["colonisables"],
    &["colonizables"],
    &["colonisables"],
];

pub(crate) static ENTRY_COLONIZABLE_13323742069868648887: VariantsMap = [
    &["colonizable"],
    &["colonisable"],
    &["colonizable"],
    &["colonisable"],
];

pub(crate) static ENTRY_COLONIZATIONISTS_15686995795564411609: VariantsMap = [
    &["colonizationists"],
    &["colonisationists"],
    &["colonizationists"],
    &["colonisationists"],
];

pub(crate) static ENTRY_COLONIZATIONIST_4791984041393920785: VariantsMap = [
    &["colonizationist"],
    &["colonisationist"],
    &["colonizationist"],
    &["colonisationist"],
];

pub(crate) static ENTRY_COLONIZATIONS_5914393406246107629: VariantsMap = [
    &["colonizations"],
    &["colonisations"],
    &["colonizations"],
    &["colonisations"],
];

pub(crate) static ENTRY_COLONIZATION_5170205300413493772: VariantsMap = [
    &["colonization"],
    &["colonisation"],
    &["colonization"],
    &["colonisation"],
];

pub(crate) static ENTRY_COLONIZED_1613678129917812032: VariantsMap = [
    &["colonized"],
    &["colonised"],
    &["colonized"],
    &["colonised"],
];

pub(crate) static ENTRY_COLONIZERS_8168468522547534282: VariantsMap = [
    &["colonizers"],
    &["colonisers"],
    &["colonizers"],
    &["colonisers"],
];

pub(crate) static ENTRY_COLONIZER_12757929901281569170: VariantsMap = [
    &["colonizer"],
    &["coloniser"],
    &["colonizer"],
    &["coloniser"],
];

pub(crate) static ENTRY_COLONIZES_12944167433051970340: VariantsMap = [
    &["colonizes"],
    &["colonises"],
    &["colonizes"],
    &["colonises"],
];

pub(crate) static ENTRY_COLONIZE_15736921118583985460: VariantsMap =
    [&["colonize"], &["colonise"], &["colonize"], &["colonise"]];

pub(crate) static ENTRY_COLONIZING_10333921368822957164: VariantsMap = [
    &["colonizing"],
    &["colonising"],
    &["colonizing"],
    &["colonising"],
];

pub(crate) static ENTRY_COLORABILITIES_9958964032688729898: VariantsMap = [
    &["colorabilities"],
    &["colourabilities"],
    &["colourabilities"],
    &["colourabilities"],
];

pub(crate) static ENTRY_COLORABILITY_4981844209136751100: VariantsMap = [
    &["colorability"],
    &["colourability"],
    &["colourability"],
    &["colourability"],
];

pub(crate) static ENTRY_COLORABLENESSES_3851955312082062820: VariantsMap = [
    &["colorablenesses"],
    &["colourablenesses"],
    &["colourablenesses"],
    &["colourablenesses"],
];

pub(crate) static ENTRY_COLORABLENESS_2481325297280462095: VariantsMap = [
    &["colorableness"],
    &["colourableness"],
    &["colourableness"],
    &["colourableness"],
];

pub(crate) static ENTRY_COLORABLER_9668141786678165672: VariantsMap = [
    &["colorabler"],
    &["colourabler"],
    &["colourabler"],
    &["colourabler"],
];

pub(crate) static ENTRY_COLORABLEST_7942972157513237380: VariantsMap = [
    &["colorablest"],
    &["colourablest"],
    &["colourablest"],
    &["colourablest"],
];

pub(crate) static ENTRY_COLORABLES_9835654246095695799: VariantsMap = [
    &["colorables"],
    &["colourables"],
    &["colourables"],
    &["colourables"],
];

pub(crate) static ENTRY_COLORABLE_7050710397577980432: VariantsMap = [
    &["colorable"],
    &["colourable"],
    &["colourable"],
    &["colourable"],
];

pub(crate) static ENTRY_COLORABLIER_6977421189014021102: VariantsMap = [
    &["colorablier"],
    &["colourablier"],
    &["colourablier"],
    &["colourablier"],
];

pub(crate) static ENTRY_COLORABLIEST_11146624897447970828: VariantsMap = [
    &["colorabliest"],
    &["colourabliest"],
    &["colourabliest"],
    &["colourabliest"],
];

pub(crate) static ENTRY_COLORABLIES_12294270181831783929: VariantsMap = [
    &["colorablies"],
    &["colourablies"],
    &["colourablies"],
    &["colourablies"],
];

pub(crate) static ENTRY_COLORABLY_9468463993023925722: VariantsMap = [
    &["colorably"],
    &["colourably"],
    &["colourably"],
    &["colourably"],
];

pub(crate) static ENTRY_COLORADOITE_8833920578577260105: VariantsMap = [
    &["coloradoite"],
    &["colouradoite"],
    &["colouradoite"],
    &["colouradoite"],
];

pub(crate) static ENTRY_COLORAMA_1846226585848796493: VariantsMap = [
    &["colorama"],
    &["colourama"],
    &["colourama"],
    &["colourama"],
];

pub(crate) static ENTRY_COLORANTS_5504580436166605292: VariantsMap = [
    &["colorants"],
    &["colourants"],
    &["colourants"],
    &["colourants"],
];

pub(crate) static ENTRY_COLORANT_8508078357677443619: VariantsMap = [
    &["colorant"],
    &["colourant"],
    &["colourant"],
    &["colourant"],
];

pub(crate) static ENTRY_COLORATE_1487899690349145487: VariantsMap = [
    &["colorate"],
    &["colourate"],
    &["colourate"],
    &["colourate"],
];

pub(crate) static ENTRY_COLORATIONALER_2315908441786659774: VariantsMap = [
    &["colorationaler"],
    &["colorationaler"],
    &["colorationaler"],
    &["colorationaler"],
];

pub(crate) static ENTRY_COLORATIONALEST_18397653125866719085: VariantsMap = [
    &["colorationalest"],
    &["colorationalest"],
    &["colorationalest"],
    &["colorationalest"],
];

pub(crate) static ENTRY_COLORATIONALLIER_11478779488477057274: VariantsMap = [
    &["colorationallier"],
    &["colorationallier"],
    &["colorationallier"],
    &["colorationallier"],
];

pub(crate) static ENTRY_COLORATIONALLIEST_10706588560840167842: VariantsMap = [
    &["colorationalliest"],
    &["colorationalliest"],
    &["colorationalliest"],
    &["colorationalliest"],
];

pub(crate) static ENTRY_COLORATIONALLY_858328911743147657: VariantsMap = [
    &["colorationally"],
    &["colorationally"],
    &["colorationally"],
    &["colorationally"],
];

pub(crate) static ENTRY_COLORATIONAL_16753288079293957487: VariantsMap = [
    &["colorational"],
    &["colorational"],
    &["colorational"],
    &["colorational"],
];

pub(crate) static ENTRY_COLORATIONS_10032620475490215127: VariantsMap = [
    &["colorations"],
    &["colorations", "colourations"],
    &["colorations"],
    &["colorations", "colourations"],
];

pub(crate) static ENTRY_COLORATION_16722034247789816535: VariantsMap = [
    &["coloration"],
    &["coloration", "colouration"],
    &["coloration"],
    &["coloration", "colouration"],
];

pub(crate) static ENTRY_COLORATIVE_10364780649786282163: VariantsMap = [
    &["colorative"],
    &["colourative"],
    &["colourative"],
    &["colourative"],
];

pub(crate) static ENTRY_COLORBEARER_16302991417022897520: VariantsMap = [
    &["colorbearer"],
    &["colourbearer"],
    &["colourbearer"],
    &["colourbearer"],
];

pub(crate) static ENTRY_COLORBLINDNESSES_14269141498431512170: VariantsMap = [
    &["colorblindnesses"],
    &["colourblindnesses"],
    &["colourblindnesses"],
    &["colourblindnesses"],
];

pub(crate) static ENTRY_COLORBLINDNESS_18174910962271343344: VariantsMap = [
    &["colorblindness"],
    &["colourblindness"],
    &["colourblindness"],
    &["colourblindness"],
];

pub(crate) static ENTRY_COLORBLIND_16694090854179664434: VariantsMap = [
    &["colorblind"],
    &["colourblind"],
    &["colourblind"],
    &["colourblind"],
];

pub(crate) static ENTRY_COLORBRED_5216310496600520453: VariantsMap = [
    &["colorbred"],
    &["colourbred"],
    &["colourbred"],
    &["colourbred"],
];

pub(crate) static ENTRY_COLORBREEDING_14340643893363063008: VariantsMap = [
    &["colorbreeding"],
    &["colourbreeding"],
    &["colourbreeding"],
    &["colourbreeding"],
];

pub(crate) static ENTRY_COLORBREEDS_11113473641764637830: VariantsMap = [
    &["colorbreeds"],
    &["colourbreeds"],
    &["colourbreeds"],
    &["colourbreeds"],
];

pub(crate) static ENTRY_COLORBREED_5358779689549478848: VariantsMap = [
    &["colorbreed"],
    &["colourbreed"],
    &["colourbreed"],
    &["colourbreed"],
];

pub(crate) static ENTRY_COLORCASTED_15703965836749186308: VariantsMap = [
    &["colorcasted"],
    &["colourcasted"],
    &["colourcasted"],
    &["colourcasted"],
];

pub(crate) static ENTRY_COLORCASTERS_6200168122277172332: VariantsMap = [
    &["colorcasters"],
    &["colourcasters"],
    &["colourcasters"],
    &["colourcasters"],
];

pub(crate) static ENTRY_COLORCASTER_3993571528628164298: VariantsMap = [
    &["colorcaster"],
    &["colourcaster"],
    &["colourcaster"],
    &["colourcaster"],
];

pub(crate) static ENTRY_COLORCASTING_18326831152918404831: VariantsMap = [
    &["colorcasting"],
    &["colourcasting"],
    &["colourcasting"],
    &["colourcasting"],
];

pub(crate) static ENTRY_COLORCASTS_15491829989405229642: VariantsMap = [
    &["colorcasts"],
    &["colourcasts"],
    &["colourcasts"],
    &["colourcasts"],
];

pub(crate) static ENTRY_COLORCAST_2201027249760625617: VariantsMap = [
    &["colorcast"],
    &["colourcast"],
    &["colourcast"],
    &["colourcast"],
];

pub(crate) static ENTRY_COLORECTAL_11824441472361931850: VariantsMap = [
    &["colorectal"],
    &["colourectal"],
    &["colourectal"],
    &["colourectal"],
];

pub(crate) static ENTRY_COLORECTITIS_18158962813924379828: VariantsMap = [
    &["colorectitis"],
    &["colourectitis"],
    &["colourectitis"],
    &["colourectitis"],
];

pub(crate) static ENTRY_COLORECTOSTOMY_15787993662663226229: VariantsMap = [
    &["colorectostomy"],
    &["colourectostomy"],
    &["colourectostomy"],
    &["colourectostomy"],
];

pub(crate) static ENTRY_COLOREDS_3930825355719143828: VariantsMap = [
    &["coloreds"],
    &["coloureds"],
    &["coloureds"],
    &["coloureds"],
];

pub(crate) static ENTRY_COLORED_16993799574214757686: VariantsMap =
    [&["colored"], &["coloured"], &["coloured"], &["coloured"]];

pub(crate) static ENTRY_COLORERS_13681356278503403951: VariantsMap = [
    &["colorers"],
    &["colourers"],
    &["colourers"],
    &["colourers"],
];

pub(crate) static ENTRY_COLORER_14593090349752845026: VariantsMap =
    [&["colorer"], &["colourer"], &["colourer"], &["colourer"]];

pub(crate) static ENTRY_COLORFASTNESSES_10917750449768357558: VariantsMap = [
    &["colorfastnesses"],
    &["colourfastnesses"],
    &["colourfastnesses"],
    &["colourfastnesses"],
];

pub(crate) static ENTRY_COLORFASTNESS_17325104284808699862: VariantsMap = [
    &["colorfastness"],
    &["colourfastness"],
    &["colourfastness"],
    &["colourfastness"],
];

pub(crate) static ENTRY_COLORFAST_6749057993199514856: VariantsMap = [
    &["colorfast"],
    &["colourfast"],
    &["colourfast"],
    &["colourfast"],
];

pub(crate) static ENTRY_COLORFULER_4366882207953732907: VariantsMap = [
    &["colorfuler"],
    &["colourfuler"],
    &["colourfuler"],
    &["colourfuler"],
];

pub(crate) static ENTRY_COLORFULEST_15151264088558637473: VariantsMap = [
    &["colorfulest"],
    &["colourfulest"],
    &["colourfulest"],
    &["colourfulest"],
];

pub(crate) static ENTRY_COLORFULLIER_12948386305746310089: VariantsMap = [
    &["colorfullier"],
    &["colourfullier"],
    &["colourfullier"],
    &["colourfullier"],
];

pub(crate) static ENTRY_COLORFULLIEST_14305289677627923994: VariantsMap = [
    &["colorfulliest"],
    &["colourfulliest"],
    &["colourfulliest"],
    &["colourfulliest"],
];

pub(crate) static ENTRY_COLORFULLY_12792342106302406309: VariantsMap = [
    &["colorfully"],
    &["colourfully"],
    &["colourfully"],
    &["colourfully"],
];

pub(crate) static ENTRY_COLORFULNESSES_12191353247710978564: VariantsMap = [
    &["colorfulnesses"],
    &["colourfulnesses"],
    &["colourfulnesses"],
    &["colourfulnesses"],
];

pub(crate) static ENTRY_COLORFULNESS_15839726768009061296: VariantsMap = [
    &["colorfulness"],
    &["colourfulness"],
    &["colourfulness"],
    &["colourfulness"],
];

pub(crate) static ENTRY_COLORFUL_4806683583475489506: VariantsMap = [
    &["colorful"],
    &["colourful"],
    &["colourful"],
    &["colourful"],
];

pub(crate) static ENTRY_COLORIFICS_14988984988237436693: VariantsMap = [
    &["colorifics"],
    &["colourifics"],
    &["colourifics"],
    &["colourifics"],
];

pub(crate) static ENTRY_COLORIFIC_18224680928850475846: VariantsMap = [
    &["colorific"],
    &["colourific"],
    &["colourific"],
    &["colourific"],
];

pub(crate) static ENTRY_COLORIMETERS_11304231755461980338: VariantsMap = [
    &["colorimeters"],
    &["colorimeters"],
    &["colorimeters"],
    &["colorimeters"],
];

pub(crate) static ENTRY_COLORIMETER_7886930247663758657: VariantsMap = [
    &["colorimeter"],
    &["colorimeter"],
    &["colorimeter"],
    &["colorimeter"],
];

pub(crate) static ENTRY_COLORIMETRICALLY_17982031766432667637: VariantsMap = [
    &["colorimetrically"],
    &["colourimetrically"],
    &["colourimetrically"],
    &["colourimetrically"],
];

pub(crate) static ENTRY_COLORIMETRICAL_5893759513244621607: VariantsMap = [
    &["colorimetrical"],
    &["colourimetrical"],
    &["colourimetrical"],
    &["colourimetrical"],
];

pub(crate) static ENTRY_COLORIMETRICS_7899060896503658636: VariantsMap = [
    &["colorimetrics"],
    &["colorimetrics"],
    &["colorimetrics"],
    &["colorimetrics"],
];

pub(crate) static ENTRY_COLORIMETRIC_7191450808866389504: VariantsMap = [
    &["colorimetric"],
    &["colorimetric"],
    &["colorimetric"],
    &["colorimetric"],
];

pub(crate) static ENTRY_COLORIMETRIES_4002895138139503597: VariantsMap = [
    &["colorimetries"],
    &["colorimetries"],
    &["colorimetries"],
    &["colorimetries"],
];

pub(crate) static ENTRY_COLORIMETRIST_9206995085391335333: VariantsMap = [
    &["colorimetrist"],
    &["colourimetrist"],
    &["colourimetrist"],
    &["colourimetrist"],
];

pub(crate) static ENTRY_COLORIMETRY_17653132236103689829: VariantsMap = [
    &["colorimetry"],
    &["colorimetry"],
    &["colorimetry"],
    &["colorimetry"],
];

pub(crate) static ENTRY_COLORINGS_7915048393125592470: VariantsMap = [
    &["colorings"],
    &["colourings"],
    &["colourings"],
    &["colourings"],
];

pub(crate) static ENTRY_COLORING_1146707622868481032: VariantsMap = [
    &["coloring"],
    &["colouring"],
    &["colouring"],
    &["colouring"],
];

pub(crate) static ENTRY_COLORISMS_18256708391175621780: VariantsMap = [
    &["colorisms"],
    &["colourisms"],
    &["colourisms"],
    &["colourisms"],
];

pub(crate) static ENTRY_COLORISM_16137276040089598557: VariantsMap = [
    &["colorism"],
    &["colourism"],
    &["colourism"],
    &["colourism"],
];

pub(crate) static ENTRY_COLORISTICALLY_5424161462341646669: VariantsMap = [
    &["coloristically"],
    &["colouristically"],
    &["colouristically"],
    &["colouristically"],
];

pub(crate) static ENTRY_COLORISTICER_7005818059703147231: VariantsMap = [
    &["coloristicer"],
    &["colouristicer"],
    &["colouristicer"],
    &["colouristicer"],
];

pub(crate) static ENTRY_COLORISTICEST_2156436723060189793: VariantsMap = [
    &["coloristicest"],
    &["colouristicest"],
    &["colouristicest"],
    &["colouristicest"],
];

pub(crate) static ENTRY_COLORISTICS_13996615122580621680: VariantsMap = [
    &["coloristics"],
    &["colouristics"],
    &["colouristics"],
    &["colouristics"],
];

pub(crate) static ENTRY_COLORISTIC_399320276255558866: VariantsMap = [
    &["coloristic"],
    &["colouristic"],
    &["colouristic"],
    &["colouristic"],
];

pub(crate) static ENTRY_COLORISTS_12579547357893269970: VariantsMap = [
    &["colorists"],
    &["colourists"],
    &["colourists"],
    &["colourists"],
];

pub(crate) static ENTRY_COLORIST_17294665081422796979: VariantsMap = [
    &["colorist"],
    &["colourist"],
    &["colourist"],
    &["colourist"],
];

pub(crate) static ENTRY_COLORIZATIONS_18157034030783136605: VariantsMap = [
    &["colorizations"],
    &["colourisations"],
    &["colourizations"],
    &["colourisations"],
];

pub(crate) static ENTRY_COLORIZATION_14308932529511399348: VariantsMap = [
    &["colorization"],
    &["colourisation"],
    &["colourization"],
    &["colourisation"],
];

pub(crate) static ENTRY_COLORIZED_960777906946234161: VariantsMap = [
    &["colorized"],
    &["colourised"],
    &["colourized"],
    &["colourised"],
];

pub(crate) static ENTRY_COLORIZES_12131917003294390385: VariantsMap = [
    &["colorizes"],
    &["colourises"],
    &["colourizes"],
    &["colourises"],
];

pub(crate) static ENTRY_COLORIZE_18354734970370761815: VariantsMap = [
    &["colorize"],
    &["colourise"],
    &["colourize"],
    &["colourise"],
];

pub(crate) static ENTRY_COLORIZING_2471786832873381659: VariantsMap = [
    &["colorizing"],
    &["colourising"],
    &["colourizing"],
    &["colourising"],
];

pub(crate) static ENTRY_COLORLESSER_14130375164463853792: VariantsMap = [
    &["colorlesser"],
    &["colourlesser"],
    &["colourlesser"],
    &["colourlesser"],
];

pub(crate) static ENTRY_COLORLESSEST_14480954022966990260: VariantsMap = [
    &["colorlessest"],
    &["colourlessest"],
    &["colourlessest"],
    &["colourlessest"],
];

pub(crate) static ENTRY_COLORLESSLIER_4162646048805483531: VariantsMap = [
    &["colorlesslier"],
    &["colourlesslier"],
    &["colourlesslier"],
    &["colourlesslier"],
];

pub(crate) static ENTRY_COLORLESSLIEST_12869681984000132288: VariantsMap = [
    &["colorlessliest"],
    &["colourlessliest"],
    &["colourlessliest"],
    &["colourlessliest"],
];

pub(crate) static ENTRY_COLORLESSLY_13297396459356641001: VariantsMap = [
    &["colorlessly"],
    &["colourlessly"],
    &["colourlessly"],
    &["colourlessly"],
];

pub(crate) static ENTRY_COLORLESSNESSES_6266382497440905953: VariantsMap = [
    &["colorlessnesses"],
    &["colourlessnesses"],
    &["colourlessnesses"],
    &["colourlessnesses"],
];

pub(crate) static ENTRY_COLORLESSNESS_9336682862246396379: VariantsMap = [
    &["colorlessness"],
    &["colourlessness"],
    &["colourlessness"],
    &["colourlessness"],
];

pub(crate) static ENTRY_COLORLESS_79666121160281791: VariantsMap = [
    &["colorless"],
    &["colourless"],
    &["colourless"],
    &["colourless"],
];

pub(crate) static ENTRY_COLORMAKER_18240822022788344542: VariantsMap = [
    &["colormaker"],
    &["colourmaker"],
    &["colourmaker"],
    &["colourmaker"],
];

pub(crate) static ENTRY_COLORMAKING_5754969022058419268: VariantsMap = [
    &["colormaking"],
    &["colourmaking"],
    &["colourmaking"],
    &["colourmaking"],
];

pub(crate) static ENTRY_COLORMAN_14198957698124507708: VariantsMap = [
    &["colorman"],
    &["colourman"],
    &["colourman"],
    &["colourman"],
];

pub(crate) static ENTRY_COLORMAPS_11344428357452815640: VariantsMap = [
    &["colormaps"],
    &["colourmaps"],
    &["colourmaps"],
    &["colourmaps"],
];

pub(crate) static ENTRY_COLORMAP_17016045057031205698: VariantsMap = [
    &["colormap"],
    &["colourmap"],
    &["colourmap"],
    &["colourmap"],
];

pub(crate) static ENTRY_COLORMEN_14804279233130680016: VariantsMap = [
    &["colormen"],
    &["colourmen"],
    &["colourmen"],
    &["colourmen"],
];

pub(crate) static ENTRY_COLOROTO_10920719126014730348: VariantsMap = [
    &["coloroto"],
    &["colouroto"],
    &["colouroto"],
    &["colouroto"],
];

pub(crate) static ENTRY_COLORPOINTS_5692566788742856472: VariantsMap = [
    &["colorpoints"],
    &["colourpoints"],
    &["colourpoints"],
    &["colourpoints"],
];

pub(crate) static ENTRY_COLORPOINT_1488326999809355845: VariantsMap = [
    &["colorpoint"],
    &["colourpoint"],
    &["colourpoint"],
    &["colourpoint"],
];

pub(crate) static ENTRY_COLORREST_13441910764710538786: VariantsMap = [
    &["colorrest"],
    &["colourest"],
    &["colourest"],
    &["colourest"],
];

pub(crate) static ENTRY_COLORRHAPHY_9426928456383049814: VariantsMap = [
    &["colorrhaphy"],
    &["colourrhaphy"],
    &["colourrhaphy"],
    &["colourrhaphy"],
];

pub(crate) static ENTRY_COLORS_11482118763257927768: VariantsMap =
    [&["colors"], &["colours"], &["colours"], &["colours"]];

pub(crate) static ENTRY_COLORTYPE_8791391695518930895: VariantsMap = [
    &["colortype"],
    &["colourtype"],
    &["colourtype"],
    &["colourtype"],
];

pub(crate) static ENTRY_COLORWAYS_4628145222031734139: VariantsMap = [
    &["colorways"],
    &["colourways"],
    &["colourways"],
    &["colourways"],
];

pub(crate) static ENTRY_COLORWAY_17470413378276487899: VariantsMap = [
    &["colorway"],
    &["colourway"],
    &["colourway"],
    &["colourway"],
];

pub(crate) static ENTRY_COLORY_692735169960595413: VariantsMap =
    [&["colory"], &["coloury"], &["coloury"], &["coloury"]];

pub(crate) static ENTRY_COLOR_4390088940109675041: VariantsMap =
    [&["color"], &["colour"], &["colour"], &["colour"]];

pub(crate) static ENTRY_COLUMNIZATIONS_4008802043920010207: VariantsMap = [
    &["columnizations"],
    &["columnisations"],
    &["columnizations"],
    &["columnisations"],
];

pub(crate) static ENTRY_COLUMNIZATION_5232248272406510285: VariantsMap = [
    &["columnization"],
    &["columnisation"],
    &["columnization"],
    &["columnisation"],
];

pub(crate) static ENTRY_COLUMNIZED_1732014965343684845: VariantsMap = [
    &["columnized"],
    &["columnised"],
    &["columnized"],
    &["columnised"],
];

pub(crate) static ENTRY_COLUMNIZES_4402893970233063575: VariantsMap = [
    &["columnizes"],
    &["columnises"],
    &["columnizes"],
    &["columnises"],
];

pub(crate) static ENTRY_COLUMNIZE_14711333916026596986: VariantsMap = [
    &["columnize"],
    &["columnise"],
    &["columnize"],
    &["columnise"],
];

pub(crate) static ENTRY_COLUMNIZING_2889638109077339111: VariantsMap = [
    &["columnizing"],
    &["columnising"],
    &["columnizing"],
    &["columnising"],
];

pub(crate) static ENTRY_COMEDIA_1600668820158737311: VariantsMap =
    [&["comedia"], &["comoedia"], &["comoedia"], &["comoedia"]];

pub(crate) static ENTRY_COMMERCIALIZATIONS_1148877062636686126: VariantsMap = [
    &["commercializations"],
    &["commercialisations"],
    &["commercializations"],
    &["commercialisations"],
];

pub(crate) static ENTRY_COMMERCIALIZATION_11469816268140890812: VariantsMap = [
    &["commercialization"],
    &["commercialisation"],
    &["commercialization"],
    &["commercialisation"],
];

pub(crate) static ENTRY_COMMERCIALIZED_2494708843919137706: VariantsMap = [
    &["commercialized"],
    &["commercialised"],
    &["commercialized"],
    &["commercialised"],
];

pub(crate) static ENTRY_COMMERCIALIZES_14762377282271056556: VariantsMap = [
    &["commercializes"],
    &["commercialises"],
    &["commercializes"],
    &["commercialises"],
];

pub(crate) static ENTRY_COMMERCIALIZE_1137904747608279477: VariantsMap = [
    &["commercialize"],
    &["commercialise"],
    &["commercialize"],
    &["commercialise"],
];

pub(crate) static ENTRY_COMMERCIALIZING_11104285966117995808: VariantsMap = [
    &["commercializing"],
    &["commercialising"],
    &["commercializing"],
    &["commercialising"],
];

pub(crate) static ENTRY_COMMONIZES_5349922175331423897: VariantsMap = [
    &["commonizes"],
    &["commonises"],
    &["commonizes"],
    &["commonises"],
];

pub(crate) static ENTRY_COMMONIZE_13451392529140004615: VariantsMap = [
    &["commonize"],
    &["commonise"],
    &["commonize"],
    &["commonise"],
];

pub(crate) static ENTRY_COMMUNALIZATIONS_9017291405367751157: VariantsMap = [
    &["communalizations"],
    &["communalisations"],
    &["communalizations"],
    &["communalisations"],
];

pub(crate) static ENTRY_COMMUNALIZATION_6966761097767900834: VariantsMap = [
    &["communalization"],
    &["communalisation"],
    &["communalization"],
    &["communalisation"],
];

pub(crate) static ENTRY_COMMUNALIZED_10899726674894063394: VariantsMap = [
    &["communalized"],
    &["communalised"],
    &["communalized"],
    &["communalised"],
];

pub(crate) static ENTRY_COMMUNALIZERS_15123475272425091783: VariantsMap = [
    &["communalizers"],
    &["communalisers"],
    &["communalizers"],
    &["communalisers"],
];

pub(crate) static ENTRY_COMMUNALIZER_8227245558039401681: VariantsMap = [
    &["communalizer"],
    &["communaliser"],
    &["communalizer"],
    &["communaliser"],
];

pub(crate) static ENTRY_COMMUNALIZES_10018478960559246487: VariantsMap = [
    &["communalizes"],
    &["communalises"],
    &["communalizes"],
    &["communalises"],
];

pub(crate) static ENTRY_COMMUNALIZE_11496551884840027380: VariantsMap = [
    &["communalize"],
    &["communalise"],
    &["communalize"],
    &["communalise"],
];

pub(crate) static ENTRY_COMMUNALIZING_10440823094828579805: VariantsMap = [
    &["communalizing"],
    &["communalising"],
    &["communalizing"],
    &["communalising"],
];

pub(crate) static ENTRY_COMMUNIZATIONS_5313326036601660607: VariantsMap = [
    &["communizations"],
    &["communisations"],
    &["communizations"],
    &["communisations"],
];

pub(crate) static ENTRY_COMMUNIZATION_4610686521220792898: VariantsMap = [
    &["communization"],
    &["communisation"],
    &["communization"],
    &["communisation"],
];

pub(crate) static ENTRY_COMMUNIZED_3470806738778989383: VariantsMap = [
    &["communized"],
    &["communised"],
    &["communized"],
    &["communised"],
];

pub(crate) static ENTRY_COMMUNIZES_1087544272453039357: VariantsMap = [
    &["communizes"],
    &["communises"],
    &["communizes"],
    &["communises"],
];

pub(crate) static ENTRY_COMMUNIZE_14906500406546755200: VariantsMap = [
    &["communize"],
    &["communise"],
    &["communize"],
    &["communise"],
];

pub(crate) static ENTRY_COMMUNIZING_7736146114310476831: VariantsMap = [
    &["communizing"],
    &["communising"],
    &["communizing"],
    &["communising"],
];

pub(crate) static ENTRY_COMPANIONIZES_17140744362563906153: VariantsMap = [
    &["companionizes"],
    &["companionises"],
    &["companionizes"],
    &["companionises"],
];

pub(crate) static ENTRY_COMPANIONIZE_14698523764786642117: VariantsMap = [
    &["companionize"],
    &["companionise"],
    &["companionize"],
    &["companionise"],
];

pub(crate) static ENTRY_COMPARTMENTALIZATIONS_7803350045421233416: VariantsMap = [
    &["compartmentalizations"],
    &["compartmentalisations"],
    &["compartmentalizations"],
    &["compartmentalisations"],
];

pub(crate) static ENTRY_COMPARTMENTALIZATION_8817670805873858578: VariantsMap = [
    &["compartmentalization"],
    &["compartmentalisation"],
    &["compartmentalization"],
    &["compartmentalisation"],
];

pub(crate) static ENTRY_COMPARTMENTALIZED_5318284676300892382: VariantsMap = [
    &["compartmentalized"],
    &["compartmentalised"],
    &["compartmentalized"],
    &["compartmentalised"],
];

pub(crate) static ENTRY_COMPARTMENTALIZES_295558042693607522: VariantsMap = [
    &["compartmentalizes"],
    &["compartmentalises"],
    &["compartmentalizes"],
    &["compartmentalises"],
];

pub(crate) static ENTRY_COMPARTMENTALIZE_8466180960814001454: VariantsMap = [
    &["compartmentalize"],
    &["compartmentalise"],
    &["compartmentalize"],
    &["compartmentalise"],
];

pub(crate) static ENTRY_COMPARTMENTALIZING_180997580421371176: VariantsMap = [
    &["compartmentalizing"],
    &["compartmentalising"],
    &["compartmentalizing"],
    &["compartmentalising"],
];

pub(crate) static ENTRY_COMPARTMENTIZES_10064645464410787449: VariantsMap = [
    &["compartmentizes"],
    &["compartmentises"],
    &["compartmentizes"],
    &["compartmentises"],
];

pub(crate) static ENTRY_COMPARTMENTIZE_17471420907240441116: VariantsMap = [
    &["compartmentize"],
    &["compartmentise"],
    &["compartmentize"],
    &["compartmentise"],
];

pub(crate) static ENTRY_COMPER_16144834334055019782: VariantsMap =
    [&["comper"], &["compoer"], &["compoer"], &["compoer"]];

pub(crate) static ENTRY_COMPLEMENTIZER_937168745129410584: VariantsMap = [
    &["complementizer"],
    &["complementiser"],
    &["complementizer"],
    &["complementiser"],
];

pub(crate) static ENTRY_COMPOSITE_12658187924614050642: VariantsMap = [
    &["composite"],
    &["compositae"],
    &["compositae"],
    &["compositae"],
];

pub(crate) static ENTRY_COMPREHENSIVIZATIONS_88315432366576424: VariantsMap = [
    &["comprehensivizations"],
    &["comprehensivisations"],
    &["comprehensivizations"],
    &["comprehensivisations"],
];

pub(crate) static ENTRY_COMPREHENSIVIZATION_3208133082700888116: VariantsMap = [
    &["comprehensivization"],
    &["comprehensivisation"],
    &["comprehensivization"],
    &["comprehensivisation"],
];

pub(crate) static ENTRY_COMPREHENSIVIZED_17416398274270240432: VariantsMap = [
    &["comprehensivized"],
    &["comprehensivised"],
    &["comprehensivized"],
    &["comprehensivised"],
];

pub(crate) static ENTRY_COMPREHENSIVIZES_2364696171145838288: VariantsMap = [
    &["comprehensivizes"],
    &["comprehensivises"],
    &["comprehensivizes"],
    &["comprehensivises"],
];

pub(crate) static ENTRY_COMPREHENSIVIZE_15456592777056386140: VariantsMap = [
    &["comprehensivize"],
    &["comprehensivise"],
    &["comprehensivize"],
    &["comprehensivise"],
];

pub(crate) static ENTRY_COMPREHENSIVIZING_9798923127976660537: VariantsMap = [
    &["comprehensivizing"],
    &["comprehensivising"],
    &["comprehensivizing"],
    &["comprehensivising"],
];

pub(crate) static ENTRY_COMPRIZABLE_7612510701093420227: VariantsMap = [
    &["comprizable"],
    &["comprisable"],
    &["comprizable"],
    &["comprisable"],
];

pub(crate) static ENTRY_COMPRIZAL_7506253949548704435: VariantsMap = [
    &["comprizal"],
    &["comprisal"],
    &["comprizal"],
    &["comprisal"],
];

pub(crate) static ENTRY_COMPUTERIZABLE_7194148740250173181: VariantsMap = [
    &["computerizable"],
    &["computerisable"],
    &["computerizable"],
    &["computerisable"],
];

pub(crate) static ENTRY_COMPUTERIZATIONS_14988232009287248263: VariantsMap = [
    &["computerizations"],
    &["computerisations"],
    &["computerizations"],
    &["computerisations"],
];

pub(crate) static ENTRY_COMPUTERIZATION_8388242133507632203: VariantsMap = [
    &["computerization"],
    &["computerisation"],
    &["computerization"],
    &["computerisation"],
];

pub(crate) static ENTRY_COMPUTERIZED_17906439342563202559: VariantsMap = [
    &["computerized"],
    &["computerised"],
    &["computerized"],
    &["computerised"],
];

pub(crate) static ENTRY_COMPUTERIZES_5839612827384030489: VariantsMap = [
    &["computerizes"],
    &["computerises"],
    &["computerizes"],
    &["computerises"],
];

pub(crate) static ENTRY_COMPUTERIZE_540581710185506773: VariantsMap = [
    &["computerize"],
    &["computerise"],
    &["computerize"],
    &["computerise"],
];

pub(crate) static ENTRY_COMPUTERIZING_9293272863931059588: VariantsMap = [
    &["computerizing"],
    &["computerising"],
    &["computerizing"],
    &["computerising"],
];

pub(crate) static ENTRY_CONCENTERED_10443891162354344149: VariantsMap = [
    &["concentered"],
    &["concentred"],
    &["concentred"],
    &["concentred"],
];

pub(crate) static ENTRY_CONCENTERING_12833772605844930946: VariantsMap = [
    &["concentering"],
    &["concentring"],
    &["concentring"],
    &["concentring"],
];

pub(crate) static ENTRY_CONCENTERS_7325901945687233731: VariantsMap = [
    &["concenters"],
    &["concentres"],
    &["concentres"],
    &["concentres"],
];

pub(crate) static ENTRY_CONCENTER_14635484834787157155: VariantsMap = [
    &["concenter"],
    &["concentre"],
    &["concentre"],
    &["concentre"],
];

pub(crate) static ENTRY_CONCEPTUALIZATIONS_1431558151182672246: VariantsMap = [
    &["conceptualizations"],
    &["conceptualisations"],
    &["conceptualizations"],
    &["conceptualisations"],
];

pub(crate) static ENTRY_CONCEPTUALIZATION_1957977035290831317: VariantsMap = [
    &["conceptualization"],
    &["conceptualisation"],
    &["conceptualization"],
    &["conceptualisation"],
];

pub(crate) static ENTRY_CONCEPTUALIZED_16855689032804433939: VariantsMap = [
    &["conceptualized"],
    &["conceptualised"],
    &["conceptualized"],
    &["conceptualised"],
];

pub(crate) static ENTRY_CONCEPTUALIZER_14985502701134901202: VariantsMap = [
    &["conceptualizer"],
    &["conceptualiser"],
    &["conceptualizer"],
    &["conceptualiser"],
];

pub(crate) static ENTRY_CONCEPTUALIZES_3109330931899076925: VariantsMap = [
    &["conceptualizes"],
    &["conceptualises"],
    &["conceptualizes"],
    &["conceptualises"],
];

pub(crate) static ENTRY_CONCEPTUALIZE_14569429550467897306: VariantsMap = [
    &["conceptualize"],
    &["conceptualise"],
    &["conceptualize"],
    &["conceptualise"],
];

pub(crate) static ENTRY_CONCEPTUALIZING_3830098906802741483: VariantsMap = [
    &["conceptualizing"],
    &["conceptualising"],
    &["conceptualizing"],
    &["conceptualising"],
];

pub(crate) static ENTRY_CONCERTIST_12843597612273738002: VariantsMap = [
    &["concertist"],
    &["concretist"],
    &["concretist"],
    &["concretist"],
];

pub(crate) static ENTRY_CONCERTIZED_8186570394307997010: VariantsMap = [
    &["concertized"],
    &["concertised"],
    &["concertized"],
    &["concertised"],
];

pub(crate) static ENTRY_CONCERTIZERS_16324384319575570385: VariantsMap = [
    &["concertizers"],
    &["concertisers"],
    &["concertizers"],
    &["concertisers"],
];

pub(crate) static ENTRY_CONCERTIZER_8023331987711270226: VariantsMap = [
    &["concertizer"],
    &["concertiser"],
    &["concertizer"],
    &["concertiser"],
];

pub(crate) static ENTRY_CONCERTIZES_16396741238386452819: VariantsMap = [
    &["concertizes"],
    &["concertises"],
    &["concertizes"],
    &["concertises"],
];

pub(crate) static ENTRY_CONCERTIZE_6315390562327616511: VariantsMap = [
    &["concertize"],
    &["concertise"],
    &["concertize"],
    &["concertise"],
];

pub(crate) static ENTRY_CONCERTIZING_8848777050159359780: VariantsMap = [
    &["concertizing"],
    &["concertising"],
    &["concertizing"],
    &["concertising"],
];

pub(crate) static ENTRY_CONCHE_5133084355374835635: VariantsMap =
    [&["conche"], &["conchae"], &["conchae"], &["conchae"]];

pub(crate) static ENTRY_CONCOLOROUS_17104772201009728838: VariantsMap = [
    &["concolorous"],
    &["concolourous"],
    &["concolourous"],
    &["concolourous"],
];

pub(crate) static ENTRY_CONCOLOR_1624705544613646046: VariantsMap = [
    &["concolor"],
    &["concolour"],
    &["concolour"],
    &["concolour"],
];

pub(crate) static ENTRY_CONCRETIZATIONS_16577819847117636011: VariantsMap = [
    &["concretizations"],
    &["concretisations"],
    &["concretizations"],
    &["concretisations"],
];

pub(crate) static ENTRY_CONCRETIZATION_16748795997403623068: VariantsMap = [
    &["concretization"],
    &["concretisation"],
    &["concretization"],
    &["concretisation"],
];

pub(crate) static ENTRY_CONCRETIZED_11886059222443029705: VariantsMap = [
    &["concretized"],
    &["concretised"],
    &["concretized"],
    &["concretised"],
];

pub(crate) static ENTRY_CONCRETIZES_14708644144755990132: VariantsMap = [
    &["concretizes"],
    &["concretises"],
    &["concretizes"],
    &["concretises"],
];

pub(crate) static ENTRY_CONCRETIZE_2393131352307099452: VariantsMap = [
    &["concretize"],
    &["concretise"],
    &["concretize"],
    &["concretise"],
];

pub(crate) static ENTRY_CONCRETIZING_6612279978454068181: VariantsMap = [
    &["concretizing"],
    &["concretising"],
    &["concretizing"],
    &["concretising"],
];

pub(crate) static ENTRY_CONDITIONALIZES_12954903983960396279: VariantsMap = [
    &["conditionalizes"],
    &["conditionalises"],
    &["conditionalizes"],
    &["conditionalises"],
];

pub(crate) static ENTRY_CONDITIONALIZE_17715539903517618589: VariantsMap = [
    &["conditionalize"],
    &["conditionalise"],
    &["conditionalize"],
    &["conditionalise"],
];

pub(crate) static ENTRY_CONFEDERATIZES_11332452239971933051: VariantsMap = [
    &["confederatizes"],
    &["confederatises"],
    &["confederatizes"],
    &["confederatises"],
];

pub(crate) static ENTRY_CONFEDERATIZE_2482426421068477118: VariantsMap = [
    &["confederatize"],
    &["confederatise"],
    &["confederatize"],
    &["confederatise"],
];

pub(crate) static ENTRY_CONGENIALIZES_16044870707549003069: VariantsMap = [
    &["congenializes"],
    &["congenialises"],
    &["congenializes"],
    &["congenialises"],
];

pub(crate) static ENTRY_CONGENIALIZE_10692985883053956904: VariantsMap = [
    &["congenialize"],
    &["congenialise"],
    &["congenialize"],
    &["congenialise"],
];

pub(crate) static ENTRY_CONGES_7410724732817107806: VariantsMap =
    [&["conges"], &["congoes"], &["congoes"], &["congoes"]];

pub(crate) static ENTRY_CONGREGATIONALIZES_320017757737745163: VariantsMap = [
    &["congregationalizes"],
    &["congregationalises"],
    &["congregationalizes"],
    &["congregationalises"],
];

pub(crate) static ENTRY_CONGREGATIONALIZE_11421943368574877519: VariantsMap = [
    &["congregationalize"],
    &["congregationalise"],
    &["congregationalize"],
    &["congregationalise"],
];

pub(crate) static ENTRY_CONNECTABLE_7524650066461359012: VariantsMap = [
    &["connectable"],
    &["connectable"],
    &["connectable"],
    &["connectable"],
];

pub(crate) static ENTRY_CONNECTIONS_13854358641231956725: VariantsMap = [
    &["connections"],
    &["connections"],
    &["connections"],
    &["connections"],
];

pub(crate) static ENTRY_CONNECTION_16157944294383303345: VariantsMap = [
    &["connection"],
    &["connection"],
    &["connection"],
    &["connection"],
];

pub(crate) static ENTRY_CONNECTORS_2449191281557186850: VariantsMap = [
    &["connectors"],
    &["connectors"],
    &["connectors"],
    &["connectors"],
];

pub(crate) static ENTRY_CONNECTOR_13923636240148187800: VariantsMap = [
    &["connector"],
    &["connector"],
    &["connector"],
    &["connector"],
];

pub(crate) static ENTRY_CONSERVATIZED_16667414097441419360: VariantsMap = [
    &["conservatized"],
    &["conservatised"],
    &["conservatized"],
    &["conservatised"],
];

pub(crate) static ENTRY_CONSERVATIZES_12340270739151171364: VariantsMap = [
    &["conservatizes"],
    &["conservatises"],
    &["conservatizes"],
    &["conservatises"],
];

pub(crate) static ENTRY_CONSERVATIZE_3646372571466696766: VariantsMap = [
    &["conservatize"],
    &["conservatise"],
    &["conservatize"],
    &["conservatise"],
];

pub(crate) static ENTRY_CONSERVATIZING_11488144501185235678: VariantsMap = [
    &["conservatizing"],
    &["conservatising"],
    &["conservatizing"],
    &["conservatising"],
];

pub(crate) static ENTRY_CONSONANTIZED_1739085823699319625: VariantsMap = [
    &["consonantized"],
    &["consonantised"],
    &["consonantized"],
    &["consonantised"],
];

pub(crate) static ENTRY_CONSONANTIZES_6704700096758384175: VariantsMap = [
    &["consonantizes"],
    &["consonantises"],
    &["consonantizes"],
    &["consonantises"],
];

pub(crate) static ENTRY_CONSONANTIZE_15868785799560721590: VariantsMap = [
    &["consonantize"],
    &["consonantise"],
    &["consonantize"],
    &["consonantise"],
];

pub(crate) static ENTRY_CONSONANTIZING_14994297411492896579: VariantsMap = [
    &["consonantizing"],
    &["consonantising"],
    &["consonantizing"],
    &["consonantising"],
];

pub(crate) static ENTRY_CONSTITUTIONALIZATIONS_12583158008471493273: VariantsMap = [
    &["constitutionalizations"],
    &["constitutionalisations"],
    &["constitutionalizations"],
    &["constitutionalisations"],
];

pub(crate) static ENTRY_CONSTITUTIONALIZATION_2780065667348017791: VariantsMap = [
    &["constitutionalization"],
    &["constitutionalisation"],
    &["constitutionalization"],
    &["constitutionalisation"],
];

pub(crate) static ENTRY_CONSTITUTIONALIZED_43545588069914801: VariantsMap = [
    &["constitutionalized"],
    &["constitutionalised"],
    &["constitutionalized"],
    &["constitutionalised"],
];

pub(crate) static ENTRY_CONSTITUTIONALIZES_10615302449483893069: VariantsMap = [
    &["constitutionalizes"],
    &["constitutionalises"],
    &["constitutionalizes"],
    &["constitutionalises"],
];

pub(crate) static ENTRY_CONSTITUTIONALIZE_10610919002840977320: VariantsMap = [
    &["constitutionalize"],
    &["constitutionalise"],
    &["constitutionalize"],
    &["constitutionalise"],
];

pub(crate) static ENTRY_CONSTITUTIONALIZING_68455832474437967: VariantsMap = [
    &["constitutionalizing"],
    &["constitutionalising"],
    &["constitutionalizing"],
    &["constitutionalising"],
];

pub(crate) static ENTRY_CONTAINERIZATIONS_1825293490197224406: VariantsMap = [
    &["containerizations"],
    &["containerisations"],
    &["containerizations"],
    &["containerisations"],
];

pub(crate) static ENTRY_CONTAINERIZATION_357714449239345018: VariantsMap = [
    &["containerization"],
    &["containerisation"],
    &["containerization"],
    &["containerisation"],
];

pub(crate) static ENTRY_CONTAINERIZED_11191961675041311832: VariantsMap = [
    &["containerized"],
    &["containerised"],
    &["containerized"],
    &["containerised"],
];

pub(crate) static ENTRY_CONTAINERIZES_128119427989538890: VariantsMap = [
    &["containerizes"],
    &["containerises"],
    &["containerizes"],
    &["containerises"],
];

pub(crate) static ENTRY_CONTAINERIZE_16524442428649009741: VariantsMap = [
    &["containerize"],
    &["containerise"],
    &["containerize"],
    &["containerise"],
];

pub(crate) static ENTRY_CONTAINERIZING_13615379785688951746: VariantsMap = [
    &["containerizing"],
    &["containerising"],
    &["containerizing"],
    &["containerising"],
];

pub(crate) static ENTRY_CONTEMPORIZATION_7973281613236719624: VariantsMap = [
    &["contemporization"],
    &["contemporisation"],
    &["contemporization"],
    &["contemporisation"],
];

pub(crate) static ENTRY_CONTEMPORIZED_17912597175826461474: VariantsMap = [
    &["contemporized"],
    &["contemporised"],
    &["contemporized"],
    &["contemporised"],
];

pub(crate) static ENTRY_CONTEMPORIZES_15323099493170636003: VariantsMap = [
    &["contemporizes"],
    &["contemporises"],
    &["contemporizes"],
    &["contemporises"],
];

pub(crate) static ENTRY_CONTEMPORIZE_18324583852979424629: VariantsMap = [
    &["contemporize"],
    &["contemporise"],
    &["contemporize"],
    &["contemporise"],
];

pub(crate) static ENTRY_CONTEMPORIZING_12751018645468916685: VariantsMap = [
    &["contemporizing"],
    &["contemporising"],
    &["contemporizing"],
    &["contemporising"],
];

pub(crate) static ENTRY_CONTEXTUALIZATIONS_17844118780680419482: VariantsMap = [
    &["contextualizations"],
    &["contextualisations"],
    &["contextualizations"],
    &["contextualisations"],
];

pub(crate) static ENTRY_CONTEXTUALIZATION_15725305900345696430: VariantsMap = [
    &["contextualization"],
    &["contextualisation"],
    &["contextualization"],
    &["contextualisation"],
];

pub(crate) static ENTRY_CONTEXTUALIZED_13151283679008083721: VariantsMap = [
    &["contextualized"],
    &["contextualised"],
    &["contextualized"],
    &["contextualised"],
];

pub(crate) static ENTRY_CONTEXTUALIZES_9989549820338407239: VariantsMap = [
    &["contextualizes"],
    &["contextualises"],
    &["contextualizes"],
    &["contextualises"],
];

pub(crate) static ENTRY_CONTEXTUALIZE_1732229238408526525: VariantsMap = [
    &["contextualize"],
    &["contextualise"],
    &["contextualize"],
    &["contextualise"],
];

pub(crate) static ENTRY_CONTEXTUALIZING_15565025679692944311: VariantsMap = [
    &["contextualizing"],
    &["contextualising"],
    &["contextualizing"],
    &["contextualising"],
];

pub(crate) static ENTRY_CONTINENTALIZES_7922821302652628557: VariantsMap = [
    &["continentalizes"],
    &["continentalises"],
    &["continentalizes"],
    &["continentalises"],
];

pub(crate) static ENTRY_CONTINENTALIZE_4849218751129058653: VariantsMap = [
    &["continentalize"],
    &["continentalise"],
    &["continentalize"],
    &["continentalise"],
];

pub(crate) static ENTRY_CONTROVERSIALIZES_10595020217935359413: VariantsMap = [
    &["controversializes"],
    &["controversialises"],
    &["controversializes"],
    &["controversialises"],
];

pub(crate) static ENTRY_CONTROVERSIALIZE_7578510810226772147: VariantsMap = [
    &["controversialize"],
    &["controversialise"],
    &["controversialize"],
    &["controversialise"],
];

pub(crate) static ENTRY_CONUNDRUMIZES_5697079552794062501: VariantsMap = [
    &["conundrumizes"],
    &["conundrumises"],
    &["conundrumizes"],
    &["conundrumises"],
];

pub(crate) static ENTRY_CONUNDRUMIZE_12445914040901915336: VariantsMap = [
    &["conundrumize"],
    &["conundrumise"],
    &["conundrumize"],
    &["conundrumise"],
];

pub(crate) static ENTRY_CONVENTIONALIZATIONS_17887109827005802547: VariantsMap = [
    &["conventionalizations"],
    &["conventionalisations"],
    &["conventionalizations"],
    &["conventionalisations"],
];

pub(crate) static ENTRY_CONVENTIONALIZATION_9500763137802119350: VariantsMap = [
    &["conventionalization"],
    &["conventionalisation"],
    &["conventionalization"],
    &["conventionalisation"],
];

pub(crate) static ENTRY_CONVENTIONALIZED_2515352950983299261: VariantsMap = [
    &["conventionalized"],
    &["conventionalised"],
    &["conventionalized"],
    &["conventionalised"],
];

pub(crate) static ENTRY_CONVENTIONALIZES_9956067957387320740: VariantsMap = [
    &["conventionalizes"],
    &["conventionalises"],
    &["conventionalizes"],
    &["conventionalises"],
];

pub(crate) static ENTRY_CONVENTIONALIZE_8965825227981389572: VariantsMap = [
    &["conventionalize"],
    &["conventionalise"],
    &["conventionalize"],
    &["conventionalise"],
];

pub(crate) static ENTRY_CONVENTIONALIZING_1207910973175187527: VariantsMap = [
    &["conventionalizing"],
    &["conventionalising"],
    &["conventionalizing"],
    &["conventionalising"],
];

pub(crate) static ENTRY_CONVENTIONIZES_8607084348592237232: VariantsMap = [
    &["conventionizes"],
    &["conventionises"],
    &["conventionizes"],
    &["conventionises"],
];

pub(crate) static ENTRY_CONVENTIONIZE_7190828471187981506: VariantsMap = [
    &["conventionize"],
    &["conventionise"],
    &["conventionize"],
    &["conventionise"],
];

pub(crate) static ENTRY_CONVERSATIONIZES_18287566729258936019: VariantsMap = [
    &["conversationizes"],
    &["conversationises"],
    &["conversationizes"],
    &["conversationises"],
];

pub(crate) static ENTRY_CONVERSATIONIZE_10644563930821457875: VariantsMap = [
    &["conversationize"],
    &["conversationise"],
    &["conversationize"],
    &["conversationise"],
];

pub(crate) static ENTRY_CONVERTERS_18202666178479349443: VariantsMap = [
    &["converters"],
    &["converters"],
    &["converters"],
    &["converters"],
];

pub(crate) static ENTRY_CONVERTERS_2794867188871344776: VariantsMap = [
    &["converters"],
    &["converters"],
    &["converters"],
    &["converters"],
];

pub(crate) static ENTRY_CONVERTER_11042638331866408272: VariantsMap = [
    &["converter"],
    &["converter"],
    &["converter"],
    &["converter"],
];

pub(crate) static ENTRY_CONVERTER_9597145040682608749: VariantsMap = [
    &["converter"],
    &["converter"],
    &["converter"],
    &["converter"],
];

pub(crate) static ENTRY_CONVEYORIZED_4580194486713878999: VariantsMap = [
    &["conveyorized"],
    &["conveyorised"],
    &["conveyorized"],
    &["conveyorised"],
];

pub(crate) static ENTRY_CONVEYORIZES_8443332349483946519: VariantsMap = [
    &["conveyorizes"],
    &["conveyorises"],
    &["conveyorizes"],
    &["conveyorises"],
];

pub(crate) static ENTRY_CONVEYORIZE_7183391646528291733: VariantsMap = [
    &["conveyorize"],
    &["conveyorise"],
    &["conveyorize"],
    &["conveyorise"],
];

pub(crate) static ENTRY_CONVEYORIZING_193492211454742065: VariantsMap = [
    &["conveyorizing"],
    &["conveyorising"],
    &["conveyorizing"],
    &["conveyorising"],
];

pub(crate) static ENTRY_CONVIVIALIZES_10501313390440810552: VariantsMap = [
    &["convivializes"],
    &["convivialises"],
    &["convivializes"],
    &["convivialises"],
];

pub(crate) static ENTRY_CONVIVIALIZE_10958239774543390437: VariantsMap = [
    &["convivialize"],
    &["convivialise"],
    &["convivialize"],
    &["convivialise"],
];

pub(crate) static ENTRY_COOKIE_9287663065088073450: VariantsMap =
    [&["cookie"], &["cookie"], &["cookie"], &["cookie"]];

pub(crate) static ENTRY_COPOLYMERIZATIONS_1735711282043986975: VariantsMap = [
    &["copolymerizations"],
    &["copolymerisations"],
    &["copolymerizations"],
    &["copolymerisations"],
];

pub(crate) static ENTRY_COPOLYMERIZATION_9906853656154549423: VariantsMap = [
    &["copolymerization"],
    &["copolymerisation"],
    &["copolymerization"],
    &["copolymerisation"],
];

pub(crate) static ENTRY_COPOLYMERIZED_4836344646706287325: VariantsMap = [
    &["copolymerized"],
    &["copolymerised"],
    &["copolymerized"],
    &["copolymerised"],
];

pub(crate) static ENTRY_COPOLYMERIZES_3215794498833268659: VariantsMap = [
    &["copolymerizes"],
    &["copolymerises"],
    &["copolymerizes"],
    &["copolymerises"],
];

pub(crate) static ENTRY_COPOLYMERIZE_2974760063313637629: VariantsMap = [
    &["copolymerize"],
    &["copolymerise"],
    &["copolymerize"],
    &["copolymerise"],
];

pub(crate) static ENTRY_COPOLYMERIZING_343564958295258899: VariantsMap = [
    &["copolymerizing"],
    &["copolymerising"],
    &["copolymerizing"],
    &["copolymerising"],
];

pub(crate) static ENTRY_COPPERIZATIONS_3873804989120766921: VariantsMap = [
    &["copperizations"],
    &["copperisations"],
    &["copperizations"],
    &["copperisations"],
];

pub(crate) static ENTRY_COPPERIZATION_2232365228358153481: VariantsMap = [
    &["copperization"],
    &["copperisation"],
    &["copperization"],
    &["copperisation"],
];

pub(crate) static ENTRY_COPPERIZES_10154527404496674895: VariantsMap = [
    &["copperizes"],
    &["copperises"],
    &["copperizes"],
    &["copperises"],
];

pub(crate) static ENTRY_COPPERIZE_11487691990144705431: VariantsMap = [
    &["copperize"],
    &["copperise"],
    &["copperize"],
    &["copperise"],
];

pub(crate) static ENTRY_COPREMIA_979590469354878339: VariantsMap = [
    &["copremia"],
    &["copraemia"],
    &["copraemia"],
    &["copraemia"],
];

pub(crate) static ENTRY_COPREMIC_2536455939195658636: VariantsMap = [
    &["copremic"],
    &["copraemic"],
    &["copraemic"],
    &["copraemic"],
];

pub(crate) static ENTRY_CORALED_14441209538548736417: VariantsMap =
    [&["coraled"], &["coralled"], &["coralled"], &["coralled"]];

pub(crate) static ENTRY_CORANTOES_10805751077677468198: VariantsMap = [
    &["corantoes"],
    &["courantoes"],
    &["courantoes"],
    &["courantoes"],
];

pub(crate) static ENTRY_CORANTOS_10727231399317582642: VariantsMap = [
    &["corantos"],
    &["courantos"],
    &["courantos"],
    &["courantos"],
];

pub(crate) static ENTRY_CORANTO_449281456667886469: VariantsMap =
    [&["coranto"], &["couranto"], &["couranto"], &["couranto"]];

pub(crate) static ENTRY_CORBED_6613581470338211217: VariantsMap =
    [&["corbed"], &["courbed"], &["courbed"], &["courbed"]];

pub(crate) static ENTRY_CORBELED_6696681783303093325: VariantsMap = [
    &["corbeled"],
    &["corbelled"],
    &["corbelled"],
    &["corbelled"],
];

pub(crate) static ENTRY_CORBELINGS_3333039851766534882: VariantsMap = [
    &["corbelings"],
    &["corbellings"],
    &["corbellings"],
    &["corbellings"],
];

pub(crate) static ENTRY_CORBELING_14073722108296010081: VariantsMap = [
    &["corbeling"],
    &["corbelling"],
    &["corbelling"],
    &["corbelling"],
];

pub(crate) static ENTRY_CORBE_9500946030049509925: VariantsMap =
    [&["corbe"], &["courbe"], &["courbe"], &["courbe"]];

pub(crate) static ENTRY_CORDIALIZED_4522684783827889079: VariantsMap = [
    &["cordialized"],
    &["cordialised"],
    &["cordialized"],
    &["cordialised"],
];

pub(crate) static ENTRY_CORDIALIZES_5004163444219892172: VariantsMap = [
    &["cordializes"],
    &["cordialises"],
    &["cordializes"],
    &["cordialises"],
];

pub(crate) static ENTRY_CORDIALIZE_14444478676753919887: VariantsMap = [
    &["cordialize"],
    &["cordialise"],
    &["cordialize"],
    &["cordialise"],
];

pub(crate) static ENTRY_CORDIALIZING_4461609946720434424: VariantsMap = [
    &["cordializing"],
    &["cordialising"],
    &["cordializing"],
    &["cordialising"],
];

pub(crate) static ENTRY_CORGE_17485843320272456103: VariantsMap =
    [&["corge"], &["courge"], &["courge"], &["courge"]];

pub(crate) static ENTRY_CORINTHIANIZED_14231677469452975998: VariantsMap = [
    &["corinthianized"],
    &["corinthianised"],
    &["corinthianized"],
    &["corinthianised"],
];

pub(crate) static ENTRY_CORINTHIANIZES_4980508561030799726: VariantsMap = [
    &["corinthianizes"],
    &["corinthianises"],
    &["corinthianizes"],
    &["corinthianises"],
];

pub(crate) static ENTRY_CORINTHIANIZE_14380160817703322777: VariantsMap = [
    &["corinthianize"],
    &["corinthianise"],
    &["corinthianize"],
    &["corinthianise"],
];

pub(crate) static ENTRY_CORINTHIANIZING_3286736123626060904: VariantsMap = [
    &["corinthianizing"],
    &["corinthianising"],
    &["corinthianizing"],
    &["corinthianising"],
];

pub(crate) static ENTRY_CORPOREALIZATIONS_4194611580429909973: VariantsMap = [
    &["corporealizations"],
    &["corporealisations"],
    &["corporealizations"],
    &["corporealisations"],
];

pub(crate) static ENTRY_CORPOREALIZATION_7151572681191131638: VariantsMap = [
    &["corporealization"],
    &["corporealisation"],
    &["corporealization"],
    &["corporealisation"],
];

pub(crate) static ENTRY_CORPOREALIZED_4844383411397455314: VariantsMap = [
    &["corporealized"],
    &["corporealised"],
    &["corporealized"],
    &["corporealised"],
];

pub(crate) static ENTRY_CORPOREALIZES_12122791156138928858: VariantsMap = [
    &["corporealizes"],
    &["corporealises"],
    &["corporealizes"],
    &["corporealises"],
];

pub(crate) static ENTRY_CORPOREALIZE_176880298140876486: VariantsMap = [
    &["corporealize"],
    &["corporealise"],
    &["corporealize"],
    &["corporealise"],
];

pub(crate) static ENTRY_CORPOREALIZING_13300853358390651516: VariantsMap = [
    &["corporealizing"],
    &["corporealising"],
    &["corporealizing"],
    &["corporealising"],
];

pub(crate) static ENTRY_CORSY_2581357179624818778: VariantsMap =
    [&["corsy"], &["coursy"], &["coursy"], &["coursy"]];

pub(crate) static ENTRY_CORTAGE_240810678292962993: VariantsMap =
    [&["cortage"], &["courtage"], &["courtage"], &["courtage"]];

pub(crate) static ENTRY_CORTINE_7414842809696171862: VariantsMap =
    [&["cortine"], &["cortinae"], &["cortinae"], &["cortinae"]];

pub(crate) static ENTRY_CORTIN_15506462001994757631: VariantsMap =
    [&["cortin"], &["courtin"], &["courtin"], &["courtin"]];

pub(crate) static ENTRY_CORVE_469980777380433756: VariantsMap =
    [&["corve"], &["corvae"], &["corvae"], &["corvae"]];

pub(crate) static ENTRY_CORYPHES_2551099835554491861: VariantsMap = [
    &["coryphes"],
    &["coryphaes"],
    &["coryphaes"],
    &["coryphaes"],
];

pub(crate) static ENTRY_CORYPHE_12873350252360823738: VariantsMap =
    [&["coryphe"], &["coryphae"], &["coryphae"], &["coryphae"]];

pub(crate) static ENTRY_COSMETICIZED_13587523395309881775: VariantsMap = [
    &["cosmeticized"],
    &["cosmeticised"],
    &["cosmeticized"],
    &["cosmeticised"],
];

pub(crate) static ENTRY_COSMETICIZES_14677656770429071116: VariantsMap = [
    &["cosmeticizes"],
    &["cosmeticises"],
    &["cosmeticizes"],
    &["cosmeticises"],
];

pub(crate) static ENTRY_COSMETICIZE_7229806576940444951: VariantsMap = [
    &["cosmeticize"],
    &["cosmeticise"],
    &["cosmeticize"],
    &["cosmeticise"],
];

pub(crate) static ENTRY_COSMETICIZING_14659907444405436840: VariantsMap = [
    &["cosmeticizing"],
    &["cosmeticising"],
    &["cosmeticizing"],
    &["cosmeticising"],
];

pub(crate) static ENTRY_COSMOPOLITANIZATIONS_8321319186324517850: VariantsMap = [
    &["cosmopolitanizations"],
    &["cosmopolitanisations"],
    &["cosmopolitanizations"],
    &["cosmopolitanisations"],
];

pub(crate) static ENTRY_COSMOPOLITANIZATION_5720036499017135205: VariantsMap = [
    &["cosmopolitanization"],
    &["cosmopolitanisation"],
    &["cosmopolitanization"],
    &["cosmopolitanisation"],
];

pub(crate) static ENTRY_COSMOPOLITANIZED_7733201348304626234: VariantsMap = [
    &["cosmopolitanized"],
    &["cosmopolitanised"],
    &["cosmopolitanized"],
    &["cosmopolitanised"],
];

pub(crate) static ENTRY_COSMOPOLITANIZES_10510882645788399153: VariantsMap = [
    &["cosmopolitanizes"],
    &["cosmopolitanises"],
    &["cosmopolitanizes"],
    &["cosmopolitanises"],
];

pub(crate) static ENTRY_COSMOPOLITANIZE_2274947466234383776: VariantsMap = [
    &["cosmopolitanize"],
    &["cosmopolitanise"],
    &["cosmopolitanize"],
    &["cosmopolitanise"],
];

pub(crate) static ENTRY_COSMOPOLITANIZING_8986323684241042113: VariantsMap = [
    &["cosmopolitanizing"],
    &["cosmopolitanising"],
    &["cosmopolitanizing"],
    &["cosmopolitanising"],
];

pub(crate) static ENTRY_COSPLENDOR_2580856102842719661: VariantsMap = [
    &["cosplendor"],
    &["cosplendour"],
    &["cosplendour"],
    &["cosplendour"],
];

pub(crate) static ENTRY_COSTE_2504691656191425333: VariantsMap =
    [&["coste"], &["costae"], &["costae"], &["costae"]];

pub(crate) static ENTRY_COSTUMIER_9518731460874060467: VariantsMap = [
    &["costumier"],
    &["costumire"],
    &["costumire"],
    &["costumire"],
];

pub(crate) static ENTRY_COTTE_5426452040563003837: VariantsMap =
    [&["cotte"], &["cottae"], &["cottae"], &["cottae"]];

pub(crate) static ENTRY_COTTONIZATIONS_659824657489867728: VariantsMap = [
    &["cottonizations"],
    &["cottonisations"],
    &["cottonizations"],
    &["cottonisations"],
];

pub(crate) static ENTRY_COTTONIZATION_9129202047860498194: VariantsMap = [
    &["cottonization"],
    &["cottonisation"],
    &["cottonization"],
    &["cottonisation"],
];

pub(crate) static ENTRY_COTTONIZES_16537091607400846202: VariantsMap = [
    &["cottonizes"],
    &["cottonises"],
    &["cottonizes"],
    &["cottonises"],
];

pub(crate) static ENTRY_COTTONIZE_7266294437242654895: VariantsMap = [
    &["cottonize"],
    &["cottonise"],
    &["cottonize"],
    &["cottonise"],
];

pub(crate) static ENTRY_COTYLE_6691433492815997580: VariantsMap =
    [&["cotyle"], &["cotylae"], &["cotylae"], &["cotylae"]];

pub(crate) static ENTRY_COUNCILORSHIPS_3525523011873776596: VariantsMap = [
    &["councilorships"],
    &["councillorships"],
    &["councillorships"],
    &["councillorships"],
];

pub(crate) static ENTRY_COUNCILORSHIP_16998032340551826478: VariantsMap = [
    &["councilorship"],
    &["councillorship"],
    &["councillorship"],
    &["councillorship"],
];

pub(crate) static ENTRY_COUNCILORS_8086440655852289978: VariantsMap = [
    &["councilors"],
    &["councillors"],
    &["councillors"],
    &["councillors"],
];

pub(crate) static ENTRY_COUNCILOR_15580609476721559009: VariantsMap = [
    &["councilor"],
    &["councillor"],
    &["councillor"],
    &["councillor"],
];

pub(crate) static ENTRY_COUNSELED_10079969979774535185: VariantsMap = [
    &["counseled"],
    &["counselled"],
    &["counselled"],
    &["counselled"],
];

pub(crate) static ENTRY_COUNSELEE_2663336403792418618: VariantsMap = [
    &["counselee"],
    &["counsellee"],
    &["counsellee"],
    &["counsellee"],
];

pub(crate) static ENTRY_COUNSELING_3362710659606651238: VariantsMap = [
    &["counseling"],
    &["counselling"],
    &["counselling"],
    &["counselling"],
];

pub(crate) static ENTRY_COUNSELORSHIPS_3885641614196374389: VariantsMap = [
    &["counselorships"],
    &["counsellorships"],
    &["counsellorships"],
    &["counsellorships"],
];

pub(crate) static ENTRY_COUNSELORSHIP_184117096334597007: VariantsMap = [
    &["counselorship"],
    &["counsellorship"],
    &["counsellorship"],
    &["counsellorship"],
];

pub(crate) static ENTRY_COUNSELORS_1887733060441859158: VariantsMap = [
    &["counselors"],
    &["counsellors"],
    &["counsellors"],
    &["counsellors"],
];

pub(crate) static ENTRY_COUNSELOR_13404070207747695814: VariantsMap = [
    &["counselor"],
    &["counsellor"],
    &["counsellor"],
    &["counsellor"],
];

pub(crate) static ENTRY_COUNTERCOLORED_14141979223186124542: VariantsMap = [
    &["countercolored"],
    &["countercoloured"],
    &["countercoloured"],
    &["countercoloured"],
];

pub(crate) static ENTRY_COUNTOR_3607924860727110166: VariantsMap =
    [&["countor"], &["countour"], &["countour"], &["countour"]];

pub(crate) static ENTRY_COZIED_6562646973128567884: VariantsMap =
    [&["cozied"], &["cosied"], &["cozied"], &["cosied"]];

pub(crate) static ENTRY_COZIER_9366197992019890355: VariantsMap =
    [&["cozier"], &["cosier"], &["cozier"], &["cosier"]];

pub(crate) static ENTRY_COZIEST_10595392179485625103: VariantsMap =
    [&["coziest"], &["cosiest"], &["coziest"], &["cosiest"]];

pub(crate) static ENTRY_COZIES_1955518053712297702: VariantsMap =
    [&["cozies"], &["cosies"], &["cozies"], &["cosies"]];

pub(crate) static ENTRY_COZILY_9030881398920983543: VariantsMap =
    [&["cozily"], &["cosily"], &["cozily"], &["cosily"]];

pub(crate) static ENTRY_COZINESS_3678850341916343717: VariantsMap =
    [&["coziness"], &["cosiness"], &["coziness"], &["cosiness"]];

pub(crate) static ENTRY_COZYING_15155247936314647373: VariantsMap =
    [&["cozying"], &["cosying"], &["cozying"], &["cosying"]];

pub(crate) static ENTRY_COZY_7236665209258571742: VariantsMap =
    [&["cozy"], &["cosy"], &["cozy"], &["cosy"]];

pub(crate) static ENTRY_CRAIZEY_4366032612918169570: VariantsMap =
    [&["craizey"], &["craisey"], &["craizey"], &["craisey"]];

pub(crate) static ENTRY_CRAMBES_13590842356025353019: VariantsMap =
    [&["crambes"], &["cramboes"], &["cramboes"], &["cramboes"]];

pub(crate) static ENTRY_CRAWLERIZES_6301045917084390617: VariantsMap = [
    &["crawlerizes"],
    &["crawlerises"],
    &["crawlerizes"],
    &["crawlerises"],
];

pub(crate) static ENTRY_CRAWLERIZE_16511383301840652370: VariantsMap = [
    &["crawlerize"],
    &["crawlerise"],
    &["crawlerize"],
    &["crawlerise"],
];

pub(crate) static ENTRY_CREATURIZES_1248731206347691357: VariantsMap = [
    &["creaturizes"],
    &["creaturises"],
    &["creaturizes"],
    &["creaturises"],
];

pub(crate) static ENTRY_CREATURIZE_7728183535168976997: VariantsMap = [
    &["creaturize"],
    &["creaturise"],
    &["creaturize"],
    &["creaturise"],
];

pub(crate) static ENTRY_CRENELATED_14791658803956712009: VariantsMap = [
    &["crenelated"],
    &["crenellated"],
    &["crenellated"],
    &["crenellated"],
];

pub(crate) static ENTRY_CRENELATER_11388015695766004333: VariantsMap = [
    &["crenelater"],
    &["crenellater"],
    &["crenellater"],
    &["crenellater"],
];

pub(crate) static ENTRY_CRENELATEST_14183406657979002478: VariantsMap = [
    &["crenelatest"],
    &["crenellatest"],
    &["crenellatest"],
    &["crenellatest"],
];

pub(crate) static ENTRY_CRENELATES_10245337469566174666: VariantsMap = [
    &["crenelates"],
    &["crenellates"],
    &["crenellates"],
    &["crenellates"],
];

pub(crate) static ENTRY_CRENELATE_16654827051033938768: VariantsMap = [
    &["crenelate"],
    &["crenellate"],
    &["crenellate"],
    &["crenellate"],
];

pub(crate) static ENTRY_CRENELATING_17583663146982717987: VariantsMap = [
    &["crenelating"],
    &["crenellating"],
    &["crenellating"],
    &["crenellating"],
];

pub(crate) static ENTRY_CRENELATIONS_15328070542518467567: VariantsMap = [
    &["crenelations"],
    &["crenellations"],
    &["crenellations"],
    &["crenellations"],
];

pub(crate) static ENTRY_CRENELATION_11524933049185072103: VariantsMap = [
    &["crenelation"],
    &["crenellation"],
    &["crenellation"],
    &["crenellation"],
];

pub(crate) static ENTRY_CRENELED_16014586123533609952: VariantsMap = [
    &["creneled"],
    &["crenelled"],
    &["crenelled"],
    &["crenelled"],
];

pub(crate) static ENTRY_CRENELING_5311342342273872232: VariantsMap = [
    &["creneling"],
    &["crenelling"],
    &["crenelling"],
    &["crenelling"],
];

pub(crate) static ENTRY_CREOLIZATIONS_17009489055568961562: VariantsMap = [
    &["creolizations"],
    &["creolisations"],
    &["creolizations"],
    &["creolisations"],
];

pub(crate) static ENTRY_CREOLIZATION_18113727530889902093: VariantsMap = [
    &["creolization"],
    &["creolisation"],
    &["creolization"],
    &["creolisation"],
];

pub(crate) static ENTRY_CREOLIZED_11852473936521640088: VariantsMap = [
    &["creolized"],
    &["creolised"],
    &["creolized"],
    &["creolised"],
];

pub(crate) static ENTRY_CREOLIZES_17960363375761238839: VariantsMap = [
    &["creolizes"],
    &["creolises"],
    &["creolizes"],
    &["creolises"],
];

pub(crate) static ENTRY_CREOLIZE_146003202220590288: VariantsMap =
    [&["creolize"], &["creolise"], &["creolize"], &["creolise"]];

pub(crate) static ENTRY_CREOLIZING_13664113412449994869: VariantsMap = [
    &["creolizing"],
    &["creolising"],
    &["creolizing"],
    &["creolising"],
];

pub(crate) static ENTRY_CRETINIZATIONS_8151443991713584435: VariantsMap = [
    &["cretinizations"],
    &["cretinisations"],
    &["cretinizations"],
    &["cretinisations"],
];

pub(crate) static ENTRY_CRETINIZATION_12141340075954838361: VariantsMap = [
    &["cretinization"],
    &["cretinisation"],
    &["cretinization"],
    &["cretinisation"],
];

pub(crate) static ENTRY_CRETINIZED_558201944204822698: VariantsMap = [
    &["cretinized"],
    &["cretinised"],
    &["cretinized"],
    &["cretinised"],
];

pub(crate) static ENTRY_CRETINIZES_7179221825296926291: VariantsMap = [
    &["cretinizes"],
    &["cretinises"],
    &["cretinizes"],
    &["cretinises"],
];

pub(crate) static ENTRY_CRETINIZE_13005767874816748250: VariantsMap = [
    &["cretinize"],
    &["cretinise"],
    &["cretinize"],
    &["cretinise"],
];

pub(crate) static ENTRY_CRETINIZING_6901184386136281414: VariantsMap = [
    &["cretinizing"],
    &["cretinising"],
    &["cretinizing"],
    &["cretinising"],
];

pub(crate) static ENTRY_CRIMINALIZATIONS_9877401047859565771: VariantsMap = [
    &["criminalizations"],
    &["criminalisations"],
    &["criminalizations"],
    &["criminalisations"],
];

pub(crate) static ENTRY_CRIMINALIZATION_12203512332897805584: VariantsMap = [
    &["criminalization"],
    &["criminalisation"],
    &["criminalization"],
    &["criminalisation"],
];

pub(crate) static ENTRY_CRIMINALIZED_3582649755795597508: VariantsMap = [
    &["criminalized"],
    &["criminalised"],
    &["criminalized"],
    &["criminalised"],
];

pub(crate) static ENTRY_CRIMINALIZES_7223829830621296974: VariantsMap = [
    &["criminalizes"],
    &["criminalises"],
    &["criminalizes"],
    &["criminalises"],
];

pub(crate) static ENTRY_CRIMINALIZE_9971594675545300062: VariantsMap = [
    &["criminalize"],
    &["criminalise"],
    &["criminalize"],
    &["criminalise"],
];

pub(crate) static ENTRY_CRIMINALIZING_12354761681927219659: VariantsMap = [
    &["criminalizing"],
    &["criminalising"],
    &["criminalizing"],
    &["criminalising"],
];

pub(crate) static ENTRY_CRITICIZABLER_16750540382481946795: VariantsMap = [
    &["criticizabler"],
    &["criticisabler"],
    &["criticizabler"],
    &["criticisabler"],
];

pub(crate) static ENTRY_CRITICIZABLEST_444603967053446436: VariantsMap = [
    &["criticizablest"],
    &["criticisablest"],
    &["criticizablest"],
    &["criticisablest"],
];

pub(crate) static ENTRY_CRITICIZABLES_14668868341788863043: VariantsMap = [
    &["criticizables"],
    &["criticisables"],
    &["criticizables"],
    &["criticisables"],
];

pub(crate) static ENTRY_CRITICIZABLE_12337979955682572299: VariantsMap = [
    &["criticizable"],
    &["criticisable"],
    &["criticizable"],
    &["criticisable"],
];

pub(crate) static ENTRY_CRITICIZED_10569362492506305842: VariantsMap = [
    &["criticized"],
    &["criticised"],
    &["criticized"],
    &["criticised"],
];

pub(crate) static ENTRY_CRITICIZERS_17493845359467775710: VariantsMap = [
    &["criticizers"],
    &["criticisers"],
    &["criticizers"],
    &["criticisers"],
];

pub(crate) static ENTRY_CRITICIZER_8603387376111275284: VariantsMap = [
    &["criticizer"],
    &["criticiser"],
    &["criticizer"],
    &["criticiser"],
];

pub(crate) static ENTRY_CRITICIZES_11166250956805349653: VariantsMap = [
    &["criticizes"],
    &["criticises"],
    &["criticizes"],
    &["criticises"],
];

pub(crate) static ENTRY_CRITICIZE_13517498827728588589: VariantsMap = [
    &["criticize"],
    &["criticise"],
    &["criticize"],
    &["criticise"],
];

pub(crate) static ENTRY_CRITICIZINGLIER_14296714278669892281: VariantsMap = [
    &["criticizinglier"],
    &["criticisinglier"],
    &["criticizinglier"],
    &["criticisinglier"],
];

pub(crate) static ENTRY_CRITICIZINGLIEST_13633098824583378573: VariantsMap = [
    &["criticizingliest"],
    &["criticisingliest"],
    &["criticizingliest"],
    &["criticisingliest"],
];

pub(crate) static ENTRY_CRITICIZINGLIES_15160186189638892532: VariantsMap = [
    &["criticizinglies"],
    &["criticisinglies"],
    &["criticizinglies"],
    &["criticisinglies"],
];

pub(crate) static ENTRY_CRITICIZINGLY_11847434186733349799: VariantsMap = [
    &["criticizingly"],
    &["criticisingly"],
    &["criticizingly"],
    &["criticisingly"],
];

pub(crate) static ENTRY_CRITICIZING_14274101564029962026: VariantsMap = [
    &["criticizing"],
    &["criticising"],
    &["criticizing"],
    &["criticising"],
];

pub(crate) static ENTRY_CROFTERIZATIONS_15656785732855226560: VariantsMap = [
    &["crofterizations"],
    &["crofterisations"],
    &["crofterizations"],
    &["crofterisations"],
];

pub(crate) static ENTRY_CROFTERIZATION_4057900818249510176: VariantsMap = [
    &["crofterization"],
    &["crofterisation"],
    &["crofterization"],
    &["crofterisation"],
];

pub(crate) static ENTRY_CROFTERIZES_8832761325441693011: VariantsMap = [
    &["crofterizes"],
    &["crofterises"],
    &["crofterizes"],
    &["crofterises"],
];

pub(crate) static ENTRY_CROFTERIZE_15285078638244483958: VariantsMap = [
    &["crofterize"],
    &["crofterise"],
    &["crofterize"],
    &["crofterise"],
];

pub(crate) static ENTRY_CRUELER_965105578349190970: VariantsMap =
    [&["crueler"], &["crueller"], &["crueller"], &["crueller"]];

pub(crate) static ENTRY_CRUELEST_13236978233703918484: VariantsMap = [
    &["cruelest"],
    &["cruellest"],
    &["cruellest"],
    &["cruellest"],
];

pub(crate) static ENTRY_CRUELIZES_4558925592934439514: VariantsMap = [
    &["cruelizes"],
    &["cruelises"],
    &["cruelizes"],
    &["cruelises"],
];

pub(crate) static ENTRY_CRUELIZE_15407828798782205437: VariantsMap =
    [&["cruelize"], &["cruelise"], &["cruelize"], &["cruelise"]];

pub(crate) static ENTRY_CRYESTHESIA_7209068238753136776: VariantsMap = [
    &["cryesthesia"],
    &["cryaesthesia"],
    &["cryaesthesia"],
    &["cryaesthesia"],
];

pub(crate) static ENTRY_CRYOANESTHESIA_9229830264131529463: VariantsMap = [
    &["cryoanesthesia"],
    &["cryoanaesthesia"],
    &["cryoanaesthesia"],
    &["cryoanaesthesia"],
];

pub(crate) static ENTRY_CRYPTANALYZES_15535208005224777574: VariantsMap = [
    &["cryptanalyzes"],
    &["cryptanalyses"],
    &["cryptanalyzes"],
    &["cryptanalyses"],
];

pub(crate) static ENTRY_CRYPTESTHESIAS_15435745145193473110: VariantsMap = [
    &["cryptesthesias"],
    &["cryptaesthesias"],
    &["cryptaesthesias"],
    &["cryptaesthesias"],
];

pub(crate) static ENTRY_CRYPTESTHESIA_4340108141979706017: VariantsMap = [
    &["cryptesthesia"],
    &["cryptaesthesia"],
    &["cryptaesthesia"],
    &["cryptaesthesia"],
];

pub(crate) static ENTRY_CRYPTESTHETIC_2683184143393101964: VariantsMap = [
    &["cryptesthetic"],
    &["cryptaesthetic"],
    &["cryptaesthetic"],
    &["cryptaesthetic"],
];

pub(crate) static ENTRY_CRYSTALLIZABILITIES_78809746787495534: VariantsMap = [
    &["crystallizabilities"],
    &["crystallisabilities"],
    &["crystallizabilities"],
    &["crystallisabilities"],
];

pub(crate) static ENTRY_CRYSTALLIZABILITY_8925485498433699838: VariantsMap = [
    &["crystallizability"],
    &["crystallisability"],
    &["crystallizability"],
    &["crystallisability"],
];

pub(crate) static ENTRY_CRYSTALLIZABLER_10028068295407018641: VariantsMap = [
    &["crystallizabler"],
    &["crystallisabler"],
    &["crystallizabler"],
    &["crystallisabler"],
];

pub(crate) static ENTRY_CRYSTALLIZABLEST_15524726073324327188: VariantsMap = [
    &["crystallizablest"],
    &["crystallisablest"],
    &["crystallizablest"],
    &["crystallisablest"],
];

pub(crate) static ENTRY_CRYSTALLIZABLES_5177371679598980802: VariantsMap = [
    &["crystallizables"],
    &["crystallisables"],
    &["crystallizables"],
    &["crystallisables"],
];

pub(crate) static ENTRY_CRYSTALLIZABLE_16889159866170496088: VariantsMap = [
    &["crystallizable"],
    &["crystallisable"],
    &["crystallizable"],
    &["crystallisable"],
];

pub(crate) static ENTRY_CRYSTALLIZATIONS_18023920101940919054: VariantsMap = [
    &["crystallizations"],
    &["crystallisations"],
    &["crystallizations"],
    &["crystallisations"],
];

pub(crate) static ENTRY_CRYSTALLIZATION_8976951361725962128: VariantsMap = [
    &["crystallization"],
    &["crystallisation"],
    &["crystallization"],
    &["crystallisation"],
];

pub(crate) static ENTRY_CRYSTALLIZED_248195502747238890: VariantsMap = [
    &["crystallized"],
    &["crystallised"],
    &["crystallized"],
    &["crystallised"],
];

pub(crate) static ENTRY_CRYSTALLIZERS_11409497017545724908: VariantsMap = [
    &["crystallizers"],
    &["crystallisers"],
    &["crystallizers"],
    &["crystallisers"],
];

pub(crate) static ENTRY_CRYSTALLIZER_17740031004687030742: VariantsMap = [
    &["crystallizer"],
    &["crystalliser"],
    &["crystallizer"],
    &["crystalliser"],
];

pub(crate) static ENTRY_CRYSTALLIZES_10883222514964571084: VariantsMap = [
    &["crystallizes"],
    &["crystallises"],
    &["crystallizes"],
    &["crystallises"],
];

pub(crate) static ENTRY_CRYSTALLIZE_3680960475075584665: VariantsMap = [
    &["crystallize"],
    &["crystallise"],
    &["crystallize"],
    &["crystallise"],
];

pub(crate) static ENTRY_CRYSTALLIZING_16188565388667490505: VariantsMap = [
    &["crystallizing"],
    &["crystallising"],
    &["crystallizing"],
    &["crystallising"],
];

pub(crate) static ENTRY_CUBANIZES_451693161566111602: VariantsMap = [
    &["cubanizes"],
    &["cubanises"],
    &["cubanizes"],
    &["cubanises"],
];

pub(crate) static ENTRY_CUBANIZE_2187405951985618166: VariantsMap =
    [&["cubanize"], &["cubanise"], &["cubanize"], &["cubanise"]];

pub(crate) static ENTRY_CUCKOLDIZED_14528006487293492545: VariantsMap = [
    &["cuckoldized"],
    &["cuckoldised"],
    &["cuckoldized"],
    &["cuckoldised"],
];

pub(crate) static ENTRY_CUCKOLDIZES_2342079244115513031: VariantsMap = [
    &["cuckoldizes"],
    &["cuckoldises"],
    &["cuckoldizes"],
    &["cuckoldises"],
];

pub(crate) static ENTRY_CUCKOLDIZE_16118722183687227180: VariantsMap = [
    &["cuckoldize"],
    &["cuckoldise"],
    &["cuckoldize"],
    &["cuckoldise"],
];

pub(crate) static ENTRY_CUCKOLDIZING_5733984869361635766: VariantsMap = [
    &["cuckoldizing"],
    &["cuckoldising"],
    &["cuckoldizing"],
    &["cuckoldising"],
];

pub(crate) static ENTRY_CUDGELED_9692005941001882555: VariantsMap = [
    &["cudgeled"],
    &["cudgelled"],
    &["cudgelled"],
    &["cudgelled"],
];

pub(crate) static ENTRY_CUDGELERS_9715477768767548981: VariantsMap = [
    &["cudgelers"],
    &["cudgellers"],
    &["cudgellers"],
    &["cudgellers"],
];

pub(crate) static ENTRY_CUDGELER_8422885901453267960: VariantsMap = [
    &["cudgeler"],
    &["cudgeller"],
    &["cudgeller"],
    &["cudgeller"],
];

pub(crate) static ENTRY_CUDGELINGS_15615614002141274961: VariantsMap = [
    &["cudgelings"],
    &["cudgellings"],
    &["cudgellings"],
    &["cudgellings"],
];

pub(crate) static ENTRY_CUDGELING_8911435466137772919: VariantsMap = [
    &["cudgeling"],
    &["cudgelling"],
    &["cudgelling"],
    &["cudgelling"],
];

pub(crate) static ENTRY_CULICIDE_16583607724694171506: VariantsMap = [
    &["culicide"],
    &["culicidae"],
    &["culicidae"],
    &["culicidae"],
];

pub(crate) static ENTRY_CULTURIZATIONS_10014747967141783123: VariantsMap = [
    &["culturizations"],
    &["culturisations"],
    &["culturizations"],
    &["culturisations"],
];

pub(crate) static ENTRY_CULTURIZATION_8543494668590567803: VariantsMap = [
    &["culturization"],
    &["culturisation"],
    &["culturization"],
    &["culturisation"],
];

pub(crate) static ENTRY_CULTURIZES_5511084100185314818: VariantsMap = [
    &["culturizes"],
    &["culturises"],
    &["culturizes"],
    &["culturises"],
];

pub(crate) static ENTRY_CULTURIZE_574509036799042170: VariantsMap = [
    &["culturize"],
    &["culturise"],
    &["culturize"],
    &["culturise"],
];

pub(crate) static ENTRY_CUPELATION_6970002014185731346: VariantsMap = [
    &["cupelation"],
    &["cupellation"],
    &["cupellation"],
    &["cupellation"],
];

pub(crate) static ENTRY_CUPELED_10239795116537207270: VariantsMap =
    [&["cupeled"], &["cupelled"], &["cupelled"], &["cupelled"]];

pub(crate) static ENTRY_CUPELERS_12036428482700876979: VariantsMap = [
    &["cupelers"],
    &["cupellers"],
    &["cupellers"],
    &["cupellers"],
];

pub(crate) static ENTRY_CUPELER_9495986041110761502: VariantsMap =
    [&["cupeler"], &["cupeller"], &["cupeller"], &["cupeller"]];

pub(crate) static ENTRY_CUPELING_1424135100214219307: VariantsMap = [
    &["cupeling"],
    &["cupelling"],
    &["cupelling"],
    &["cupelling"],
];

pub(crate) static ENTRY_CUPULE_12537732425607401603: VariantsMap =
    [&["cupule"], &["cupulae"], &["cupulae"], &["cupulae"]];

pub(crate) static ENTRY_CURARIZED_11693769575589653647: VariantsMap = [
    &["curarized"],
    &["curarised"],
    &["curarized"],
    &["curarised"],
];

pub(crate) static ENTRY_CURARIZES_17992342785692504556: VariantsMap = [
    &["curarizes"],
    &["curarises"],
    &["curarizes"],
    &["curarises"],
];

pub(crate) static ENTRY_CURARIZE_14052932738253349451: VariantsMap =
    [&["curarize"], &["curarise"], &["curarize"], &["curarise"]];

pub(crate) static ENTRY_CURARIZING_8798739795306767891: VariantsMap = [
    &["curarizing"],
    &["curarising"],
    &["curarizing"],
    &["curarising"],
];

pub(crate) static ENTRY_CURATIZES_3945298158977001204: VariantsMap = [
    &["curatizes"],
    &["curatises"],
    &["curatizes"],
    &["curatises"],
];

pub(crate) static ENTRY_CURATIZE_6140878767375219419: VariantsMap =
    [&["curatize"], &["curatise"], &["curatize"], &["curatise"]];

pub(crate) static ENTRY_CURBED_1749064354422368895: VariantsMap =
    [&["curbed"], &["kerbed"], &["curbed"], &["kerbed"]];

pub(crate) static ENTRY_CURBING_4261884005739231831: VariantsMap =
    [&["curbing"], &["kerbing"], &["curbing"], &["kerbing"]];

pub(crate) static ENTRY_CURBS_3570783962680392558: VariantsMap =
    [&["curbs"], &["kerbs"], &["curbs"], &["kerbs"]];

pub(crate) static ENTRY_CURB_9612809176224939948: VariantsMap =
    [&["curb"], &["kerb"], &["curb"], &["kerb"]];

pub(crate) static ENTRY_CURRICULARIZATIONS_6183818344426773100: VariantsMap = [
    &["curricularizations"],
    &["curricularisations"],
    &["curricularizations"],
    &["curricularisations"],
];

pub(crate) static ENTRY_CURRICULARIZATION_434350820790147885: VariantsMap = [
    &["curricularization"],
    &["curricularisation"],
    &["curricularization"],
    &["curricularisation"],
];

pub(crate) static ENTRY_CURRICULARIZES_13267456067224993371: VariantsMap = [
    &["curricularizes"],
    &["curricularises"],
    &["curricularizes"],
    &["curricularises"],
];

pub(crate) static ENTRY_CURRICULARIZE_4667478241371657714: VariantsMap = [
    &["curricularize"],
    &["curricularise"],
    &["curricularize"],
    &["curricularise"],
];

pub(crate) static ENTRY_CUSTOMIZABLE_13082591789323327431: VariantsMap = [
    &["customizable"],
    &["customisable"],
    &["customizable"],
    &["customisable"],
];

pub(crate) static ENTRY_CUSTOMIZATIONS_4094977061478290809: VariantsMap = [
    &["customizations"],
    &["customisations"],
    &["customizations"],
    &["customisations"],
];

pub(crate) static ENTRY_CUSTOMIZATION_6533324325688675249: VariantsMap = [
    &["customization"],
    &["customisation"],
    &["customization"],
    &["customisation"],
];

pub(crate) static ENTRY_CUSTOMIZED_18152983780958356874: VariantsMap = [
    &["customized"],
    &["customised"],
    &["customized"],
    &["customised"],
];

pub(crate) static ENTRY_CUSTOMIZERS_12285041107419930743: VariantsMap = [
    &["customizers"],
    &["customisers"],
    &["customizers"],
    &["customisers"],
];

pub(crate) static ENTRY_CUSTOMIZER_11779086965135396229: VariantsMap = [
    &["customizer"],
    &["customiser"],
    &["customizer"],
    &["customiser"],
];

pub(crate) static ENTRY_CUSTOMIZES_5070925338090106827: VariantsMap = [
    &["customizes"],
    &["customises"],
    &["customizes"],
    &["customises"],
];

pub(crate) static ENTRY_CUSTOMIZE_8330776599249555820: VariantsMap = [
    &["customize"],
    &["customise"],
    &["customize"],
    &["customise"],
];

pub(crate) static ENTRY_CUSTOMIZING_2510425683526861127: VariantsMap = [
    &["customizing"],
    &["customising"],
    &["customizing"],
    &["customising"],
];

pub(crate) static ENTRY_CUTICOLOR_749118681891659729: VariantsMap = [
    &["cuticolor"],
    &["cuticolour"],
    &["cuticolour"],
    &["cuticolour"],
];

pub(crate) static ENTRY_CUTINIZATIONS_15507232556236784571: VariantsMap = [
    &["cutinizations"],
    &["cutinisations"],
    &["cutinizations"],
    &["cutinisations"],
];

pub(crate) static ENTRY_CUTINIZATION_3225990792951117269: VariantsMap = [
    &["cutinization"],
    &["cutinisation"],
    &["cutinization"],
    &["cutinisation"],
];

pub(crate) static ENTRY_CUTINIZED_13245491328214081401: VariantsMap = [
    &["cutinized"],
    &["cutinised"],
    &["cutinized"],
    &["cutinised"],
];

pub(crate) static ENTRY_CUTINIZES_15457760425980991257: VariantsMap = [
    &["cutinizes"],
    &["cutinises"],
    &["cutinizes"],
    &["cutinises"],
];

pub(crate) static ENTRY_CUTINIZE_15723941317771284250: VariantsMap =
    [&["cutinize"], &["cutinise"], &["cutinize"], &["cutinise"]];

pub(crate) static ENTRY_CUTINIZING_3424452919945485048: VariantsMap = [
    &["cutinizing"],
    &["cutinising"],
    &["cutinizing"],
    &["cutinising"],
];

pub(crate) static ENTRY_CUTIZATIONS_17957033495950051125: VariantsMap = [
    &["cutizations"],
    &["cutisations"],
    &["cutizations"],
    &["cutisations"],
];

pub(crate) static ENTRY_CUTIZATION_16266962016865617854: VariantsMap = [
    &["cutization"],
    &["cutisation"],
    &["cutization"],
    &["cutisation"],
];

pub(crate) static ENTRY_CUVE_2708295972808503112: VariantsMap =
    [&["cuve"], &["cuvae"], &["cuvae"], &["cuvae"]];

pub(crate) static ENTRY_CYANEE_8351179455076677468: VariantsMap =
    [&["cyanee"], &["cyaneae"], &["cyaneae"], &["cyaneae"]];

pub(crate) static ENTRY_CYANIZED_4456713039660344440: VariantsMap =
    [&["cyanized"], &["cyanised"], &["cyanized"], &["cyanised"]];

pub(crate) static ENTRY_CYANIZES_2442374963273240913: VariantsMap =
    [&["cyanizes"], &["cyanises"], &["cyanizes"], &["cyanises"]];

pub(crate) static ENTRY_CYANIZE_18317689038562952818: VariantsMap =
    [&["cyanize"], &["cyanise"], &["cyanize"], &["cyanise"]];

pub(crate) static ENTRY_CYANIZING_20662407404582315: VariantsMap = [
    &["cyanizing"],
    &["cyanising"],
    &["cyanizing"],
    &["cyanising"],
];

pub(crate) static ENTRY_CYANOMETHEMOGLOBIN_12769153246273536208: VariantsMap = [
    &["cyanomethemoglobin"],
    &["cyanomethaemoglobin"],
    &["cyanomethaemoglobin"],
    &["cyanomethaemoglobin"],
];

pub(crate) static ENTRY_CYCLIZATIONS_846436386408180033: VariantsMap = [
    &["cyclizations"],
    &["cyclisations"],
    &["cyclizations"],
    &["cyclisations"],
];

pub(crate) static ENTRY_CYCLIZATION_15526264059961831355: VariantsMap = [
    &["cyclization"],
    &["cyclisation"],
    &["cyclization"],
    &["cyclisation"],
];

pub(crate) static ENTRY_CYCLIZED_15172658726383026502: VariantsMap =
    [&["cyclized"], &["cyclised"], &["cyclized"], &["cyclised"]];

pub(crate) static ENTRY_CYCLIZES_10110148238244620541: VariantsMap =
    [&["cyclizes"], &["cyclises"], &["cyclizes"], &["cyclises"]];

pub(crate) static ENTRY_CYCLIZE_6968162168191291774: VariantsMap =
    [&["cyclize"], &["cyclise"], &["cyclize"], &["cyclise"]];

pub(crate) static ENTRY_CYCLIZING_10944596226901344600: VariantsMap = [
    &["cyclizing"],
    &["cyclising"],
    &["cyclizing"],
    &["cyclising"],
];

pub(crate) static ENTRY_CYME_893707718890012153: VariantsMap =
    [&["cyme"], &["cymae"], &["cymae"], &["cymae"]];

pub(crate) static ENTRY_CZARS_17220740917194786378: VariantsMap =
    [&["czars"], &["tsars"], &["czars"], &["tsars"]];

pub(crate) static ENTRY_CZAR_10918908885952851126: VariantsMap =
    [&["czar"], &["tsar"], &["czar"], &["tsar"]];

pub(crate) static ENTRY_CZECHIZATIONS_1280147882515365800: VariantsMap = [
    &["czechizations"],
    &["czechisations"],
    &["czechizations"],
    &["czechisations"],
];

pub(crate) static ENTRY_CZECHIZATION_5873051794680913883: VariantsMap = [
    &["czechization"],
    &["czechisation"],
    &["czechization"],
    &["czechisation"],
];

pub(crate) static ENTRY_DANAIDE_15818498892253686536: VariantsMap =
    [&["danaide"], &["danaidae"], &["danaidae"], &["danaidae"]];

pub(crate) static ENTRY_DANDIZETTE_5936439417225702170: VariantsMap = [
    &["dandizette"],
    &["dandisette"],
    &["dandizette"],
    &["dandisette"],
];

pub(crate) static ENTRY_DANDYIZES_8481185232790854326: VariantsMap = [
    &["dandyizes"],
    &["dandyises"],
    &["dandyizes"],
    &["dandyises"],
];

pub(crate) static ENTRY_DANDYIZE_17840706303249111284: VariantsMap =
    [&["dandyize"], &["dandyise"], &["dandyize"], &["dandyise"]];

pub(crate) static ENTRY_DANE_9169321821790361286: VariantsMap =
    [&["dane"], &["danae"], &["danae"], &["danae"]];

pub(crate) static ENTRY_DANIZATIONS_7756796548817532718: VariantsMap = [
    &["danizations"],
    &["danisations"],
    &["danizations"],
    &["danisations"],
];

pub(crate) static ENTRY_DANIZATION_8107686361857058644: VariantsMap = [
    &["danization"],
    &["danisation"],
    &["danization"],
    &["danisation"],
];

pub(crate) static ENTRY_DANIZES_12632956829925791843: VariantsMap =
    [&["danizes"], &["danises"], &["danizes"], &["danises"]];

pub(crate) static ENTRY_DANIZE_5515013359300588165: VariantsMap =
    [&["danize"], &["danise"], &["danize"], &["danise"]];

pub(crate) static ENTRY_DARWINIZES_8098473267747389683: VariantsMap = [
    &["darwinizes"],
    &["darwinises"],
    &["darwinizes"],
    &["darwinises"],
];

pub(crate) static ENTRY_DARWINIZE_12330149218554050438: VariantsMap = [
    &["darwinize"],
    &["darwinise"],
    &["darwinize"],
    &["darwinise"],
];

pub(crate) static ENTRY_DASTARDIZES_5293835990122312524: VariantsMap = [
    &["dastardizes"],
    &["dastardises"],
    &["dastardizes"],
    &["dastardises"],
];

pub(crate) static ENTRY_DASTARDIZE_17208857305345984482: VariantsMap = [
    &["dastardize"],
    &["dastardise"],
    &["dastardize"],
    &["dastardise"],
];

pub(crate) static ENTRY_DEACONIZES_2282161273560974649: VariantsMap = [
    &["deaconizes"],
    &["deaconises"],
    &["deaconizes"],
    &["deaconises"],
];

pub(crate) static ENTRY_DEACONIZE_239384026809512957: VariantsMap = [
    &["deaconize"],
    &["deaconise"],
    &["deaconize"],
    &["deaconise"],
];

pub(crate) static ENTRY_DEADRIZE_13632024912068492778: VariantsMap =
    [&["deadrize"], &["deadrise"], &["deadrize"], &["deadrise"]];

pub(crate) static ENTRY_DEALCOHOLIZED_5860794855975302138: VariantsMap = [
    &["dealcoholized"],
    &["dealcoholised"],
    &["dealcoholized"],
    &["dealcoholised"],
];

pub(crate) static ENTRY_DEALCOHOLIZES_3132733363085655905: VariantsMap = [
    &["dealcoholizes"],
    &["dealcoholises"],
    &["dealcoholizes"],
    &["dealcoholises"],
];

pub(crate) static ENTRY_DEALCOHOLIZE_434858633952871464: VariantsMap = [
    &["dealcoholize"],
    &["dealcoholise"],
    &["dealcoholize"],
    &["dealcoholise"],
];

pub(crate) static ENTRY_DEALCOHOLIZING_4070885849740585749: VariantsMap = [
    &["dealcoholizing"],
    &["dealcoholising"],
    &["dealcoholizing"],
    &["dealcoholising"],
];

pub(crate) static ENTRY_DEAMINIZE_1967701233443135959: VariantsMap = [
    &["deaminize"],
    &["deaminise"],
    &["deaminize"],
    &["deaminise"],
];

pub(crate) static ENTRY_DECAPITALIZATIONS_10231502913320043128: VariantsMap = [
    &["decapitalizations"],
    &["decapitalisations"],
    &["decapitalizations"],
    &["decapitalisations"],
];

pub(crate) static ENTRY_DECAPITALIZATION_1901543172013658650: VariantsMap = [
    &["decapitalization"],
    &["decapitalisation"],
    &["decapitalization"],
    &["decapitalisation"],
];

pub(crate) static ENTRY_DECAPITALIZED_4301222274905658857: VariantsMap = [
    &["decapitalized"],
    &["decapitalised"],
    &["decapitalized"],
    &["decapitalised"],
];

pub(crate) static ENTRY_DECAPITALIZES_13874569898481582362: VariantsMap = [
    &["decapitalizes"],
    &["decapitalises"],
    &["decapitalizes"],
    &["decapitalises"],
];

pub(crate) static ENTRY_DECAPITALIZE_4356343600200271051: VariantsMap = [
    &["decapitalize"],
    &["decapitalise"],
    &["decapitalize"],
    &["decapitalise"],
];

pub(crate) static ENTRY_DECAPITALIZING_1775343748326764728: VariantsMap = [
    &["decapitalizing"],
    &["decapitalising"],
    &["decapitalizing"],
    &["decapitalising"],
];

pub(crate) static ENTRY_DECARBONIZATIONS_16017243127754390829: VariantsMap = [
    &["decarbonizations"],
    &["decarbonisations"],
    &["decarbonizations"],
    &["decarbonisations"],
];

pub(crate) static ENTRY_DECARBONIZATION_11478706021702952565: VariantsMap = [
    &["decarbonization"],
    &["decarbonisation"],
    &["decarbonization"],
    &["decarbonisation"],
];

pub(crate) static ENTRY_DECARBONIZED_10394178489330721396: VariantsMap = [
    &["decarbonized"],
    &["decarbonised"],
    &["decarbonized"],
    &["decarbonised"],
];

pub(crate) static ENTRY_DECARBONIZERS_17342232878961752295: VariantsMap = [
    &["decarbonizers"],
    &["decarbonisers"],
    &["decarbonizers"],
    &["decarbonisers"],
];

pub(crate) static ENTRY_DECARBONIZER_6312932521576530142: VariantsMap = [
    &["decarbonizer"],
    &["decarboniser"],
    &["decarbonizer"],
    &["decarboniser"],
];

pub(crate) static ENTRY_DECARBONIZES_11122308997566756604: VariantsMap = [
    &["decarbonizes"],
    &["decarbonises"],
    &["decarbonizes"],
    &["decarbonises"],
];

pub(crate) static ENTRY_DECARBONIZE_17211928749740566614: VariantsMap = [
    &["decarbonize"],
    &["decarbonise"],
    &["decarbonize"],
    &["decarbonise"],
];

pub(crate) static ENTRY_DECARBONIZING_5775070557566850865: VariantsMap = [
    &["decarbonizing"],
    &["decarbonising"],
    &["decarbonizing"],
    &["decarbonising"],
];

pub(crate) static ENTRY_DECARBURIZATIONS_707144490166188138: VariantsMap = [
    &["decarburizations"],
    &["decarburisations"],
    &["decarburizations"],
    &["decarburisations"],
];

pub(crate) static ENTRY_DECARBURIZATION_8009088083185706945: VariantsMap = [
    &["decarburization"],
    &["decarburisation"],
    &["decarburization"],
    &["decarburisation"],
];

pub(crate) static ENTRY_DECARBURIZED_1086979997678475265: VariantsMap = [
    &["decarburized"],
    &["decarburised"],
    &["decarburized"],
    &["decarburised"],
];

pub(crate) static ENTRY_DECARBURIZES_1172943395595033147: VariantsMap = [
    &["decarburizes"],
    &["decarburises"],
    &["decarburizes"],
    &["decarburises"],
];

pub(crate) static ENTRY_DECARBURIZE_4982039598579376654: VariantsMap = [
    &["decarburize"],
    &["decarburise"],
    &["decarburize"],
    &["decarburise"],
];

pub(crate) static ENTRY_DECARBURIZING_15557851551596582391: VariantsMap = [
    &["decarburizing"],
    &["decarburising"],
    &["decarburizing"],
    &["decarburising"],
];

pub(crate) static ENTRY_DECASUALIZATIONS_16861279937161161131: VariantsMap = [
    &["decasualizations"],
    &["decasualisations"],
    &["decasualizations"],
    &["decasualisations"],
];

pub(crate) static ENTRY_DECASUALIZATION_6341396589709137255: VariantsMap = [
    &["decasualization"],
    &["decasualisation"],
    &["decasualization"],
    &["decasualisation"],
];

pub(crate) static ENTRY_DECASUALIZED_15267631738259466587: VariantsMap = [
    &["decasualized"],
    &["decasualised"],
    &["decasualized"],
    &["decasualised"],
];

pub(crate) static ENTRY_DECASUALIZE_2974632681155668648: VariantsMap = [
    &["decasualize"],
    &["decasualise"],
    &["decasualize"],
    &["decasualise"],
];

pub(crate) static ENTRY_DECASUALIZING_12949252096566039416: VariantsMap = [
    &["decasualizing"],
    &["decasualising"],
    &["decasualizing"],
    &["decasualising"],
];

pub(crate) static ENTRY_DECENTERS_1428026027855636170: VariantsMap = [
    &["decenters"],
    &["decentres"],
    &["decentres"],
    &["decentres"],
];

pub(crate) static ENTRY_DECENTRALIZATIONIST_7530718361872221052: VariantsMap = [
    &["decentralizationist"],
    &["decentralisationist"],
    &["decentralizationist"],
    &["decentralisationist"],
];

pub(crate) static ENTRY_DECENTRALIZATIONS_15028307675843910435: VariantsMap = [
    &["decentralizations"],
    &["decentralisations"],
    &["decentralizations"],
    &["decentralisations"],
];

pub(crate) static ENTRY_DECENTRALIZATION_14989034485163734668: VariantsMap = [
    &["decentralization"],
    &["decentralisation"],
    &["decentralization"],
    &["decentralisation"],
];

pub(crate) static ENTRY_DECENTRALIZED_15938901073912000317: VariantsMap = [
    &["decentralized"],
    &["decentralised"],
    &["decentralized"],
    &["decentralised"],
];

pub(crate) static ENTRY_DECENTRALIZES_8990159632087872438: VariantsMap = [
    &["decentralizes"],
    &["decentralises"],
    &["decentralizes"],
    &["decentralises"],
];

pub(crate) static ENTRY_DECENTRALIZE_17306384894132674147: VariantsMap = [
    &["decentralize"],
    &["decentralise"],
    &["decentralize"],
    &["decentralise"],
];

pub(crate) static ENTRY_DECENTRALIZING_11771308820494191656: VariantsMap = [
    &["decentralizing"],
    &["decentralising"],
    &["decentralizing"],
    &["decentralising"],
];

pub(crate) static ENTRY_DECEREBRIZED_9540346435806066143: VariantsMap = [
    &["decerebrized"],
    &["decerebrised"],
    &["decerebrized"],
    &["decerebrised"],
];

pub(crate) static ENTRY_DECEREBRIZES_4566139257381137550: VariantsMap = [
    &["decerebrizes"],
    &["decerebrises"],
    &["decerebrizes"],
    &["decerebrises"],
];

pub(crate) static ENTRY_DECEREBRIZE_3339748175537557282: VariantsMap = [
    &["decerebrize"],
    &["decerebrise"],
    &["decerebrize"],
    &["decerebrise"],
];

pub(crate) static ENTRY_DECEREBRIZING_9951042741513666052: VariantsMap = [
    &["decerebrizing"],
    &["decerebrising"],
    &["decerebrizing"],
    &["decerebrising"],
];

pub(crate) static ENTRY_DECHRISTIANIZATIONS_9362852101358454817: VariantsMap = [
    &["dechristianizations"],
    &["dechristianisations"],
    &["dechristianizations"],
    &["dechristianisations"],
];

pub(crate) static ENTRY_DECHRISTIANIZATION_9661661223970321419: VariantsMap = [
    &["dechristianization"],
    &["dechristianisation"],
    &["dechristianization"],
    &["dechristianisation"],
];

pub(crate) static ENTRY_DECHRISTIANIZED_6053330827461756799: VariantsMap = [
    &["dechristianized"],
    &["dechristianised"],
    &["dechristianized"],
    &["dechristianised"],
];

pub(crate) static ENTRY_DECHRISTIANIZES_881703834826854403: VariantsMap = [
    &["dechristianizes"],
    &["dechristianises"],
    &["dechristianizes"],
    &["dechristianises"],
];

pub(crate) static ENTRY_DECHRISTIANIZE_18071236489381249425: VariantsMap = [
    &["dechristianize"],
    &["dechristianise"],
    &["dechristianize"],
    &["dechristianise"],
];

pub(crate) static ENTRY_DECHRISTIANIZING_5393715445133549748: VariantsMap = [
    &["dechristianizing"],
    &["dechristianising"],
    &["dechristianizing"],
    &["dechristianising"],
];

pub(crate) static ENTRY_DECIGRAMS_6387241613823447779: VariantsMap = [
    &["decigrams"],
    &["decigrams"],
    &["decigrams"],
    &["decigrams"],
];

pub(crate) static ENTRY_DECIGRAM_1038669198251789426: VariantsMap =
    [&["decigram"], &["decigram"], &["decigram"], &["decigram"]];

pub(crate) static ENTRY_DECILITERS_151708397377325111: VariantsMap = [
    &["deciliters"],
    &["decilitres"],
    &["decilitres"],
    &["decilitres"],
];

pub(crate) static ENTRY_DECILITER_16596592820215375084: VariantsMap = [
    &["deciliter"],
    &["decilitre"],
    &["decilitre"],
    &["decilitre"],
];

pub(crate) static ENTRY_DECIMALIZATIONS_14219964716573449259: VariantsMap = [
    &["decimalizations"],
    &["decimalisations"],
    &["decimalizations"],
    &["decimalisations"],
];

pub(crate) static ENTRY_DECIMALIZATION_6585979287053082594: VariantsMap = [
    &["decimalization"],
    &["decimalisation"],
    &["decimalization"],
    &["decimalisation"],
];

pub(crate) static ENTRY_DECIMALIZED_8364548564908015686: VariantsMap = [
    &["decimalized"],
    &["decimalised"],
    &["decimalized"],
    &["decimalised"],
];

pub(crate) static ENTRY_DECIMALIZES_15979587779699755101: VariantsMap = [
    &["decimalizes"],
    &["decimalises"],
    &["decimalizes"],
    &["decimalises"],
];

pub(crate) static ENTRY_DECIMALIZE_6260219389368908768: VariantsMap = [
    &["decimalize"],
    &["decimalise"],
    &["decimalize"],
    &["decimalise"],
];

pub(crate) static ENTRY_DECIMALIZING_17193949793978263746: VariantsMap = [
    &["decimalizing"],
    &["decimalising"],
    &["decimalizing"],
    &["decimalising"],
];

pub(crate) static ENTRY_DECIMETERS_10623100407909187264: VariantsMap = [
    &["decimeters"],
    &["decimetres"],
    &["decimetres"],
    &["decimetres"],
];

pub(crate) static ENTRY_DECIMETER_5877956144268963607: VariantsMap = [
    &["decimeter"],
    &["decimetre"],
    &["decimetre"],
    &["decimetre"],
];

pub(crate) static ENTRY_DECIVILIZED_5549046655328836217: VariantsMap = [
    &["decivilized"],
    &["decivilised"],
    &["decivilized"],
    &["decivilised"],
];

pub(crate) static ENTRY_DECIVILIZES_13869478196538743509: VariantsMap = [
    &["decivilizes"],
    &["decivilises"],
    &["decivilizes"],
    &["decivilises"],
];

pub(crate) static ENTRY_DECIVILIZE_1843830017556346024: VariantsMap = [
    &["decivilize"],
    &["decivilise"],
    &["decivilize"],
    &["decivilise"],
];

pub(crate) static ENTRY_DECIVILIZING_11884011725903167539: VariantsMap = [
    &["decivilizing"],
    &["decivilising"],
    &["decivilizing"],
    &["decivilising"],
];

pub(crate) static ENTRY_DECOLONIZATIONS_15958442548094153342: VariantsMap = [
    &["decolonizations"],
    &["decolonisations"],
    &["decolonizations"],
    &["decolonisations"],
];

pub(crate) static ENTRY_DECOLONIZATION_1486129639809542135: VariantsMap = [
    &["decolonization"],
    &["decolonisation"],
    &["decolonization"],
    &["decolonisation"],
];

pub(crate) static ENTRY_DECOLONIZED_4107643671609353888: VariantsMap = [
    &["decolonized"],
    &["decolonised"],
    &["decolonized"],
    &["decolonised"],
];

pub(crate) static ENTRY_DECOLONIZES_2371774017479885060: VariantsMap = [
    &["decolonizes"],
    &["decolonises"],
    &["decolonizes"],
    &["decolonises"],
];

pub(crate) static ENTRY_DECOLONIZE_8186463036478425034: VariantsMap = [
    &["decolonize"],
    &["decolonise"],
    &["decolonize"],
    &["decolonise"],
];

pub(crate) static ENTRY_DECOLONIZING_9800590501891725470: VariantsMap = [
    &["decolonizing"],
    &["decolonising"],
    &["decolonizing"],
    &["decolonising"],
];

pub(crate) static ENTRY_DECOLORANTS_8581787138873386831: VariantsMap = [
    &["decolorants"],
    &["decolourants"],
    &["decolourants"],
    &["decolourants"],
];

pub(crate) static ENTRY_DECOLORANT_3559353327617165243: VariantsMap = [
    &["decolorant"],
    &["decolourant"],
    &["decolourant"],
    &["decolourant"],
];

pub(crate) static ENTRY_DECOLORATED_15668109642110621999: VariantsMap = [
    &["decolorated"],
    &["decolourated"],
    &["decolourated"],
    &["decolourated"],
];

pub(crate) static ENTRY_DECOLORATES_16816468260998969475: VariantsMap = [
    &["decolorates"],
    &["decolourates"],
    &["decolourates"],
    &["decolourates"],
];

pub(crate) static ENTRY_DECOLORATE_7324915820614623145: VariantsMap = [
    &["decolorate"],
    &["decolourate"],
    &["decolourate"],
    &["decolourate"],
];

pub(crate) static ENTRY_DECOLORATIONS_1487931213239331011: VariantsMap = [
    &["decolorations"],
    &["decolourations"],
    &["decolourations"],
    &["decolourations"],
];

pub(crate) static ENTRY_DECOLORATION_11009565715119639809: VariantsMap = [
    &["decoloration"],
    &["decolouration"],
    &["decolouration"],
    &["decolouration"],
];

pub(crate) static ENTRY_DECOLORED_4538268430939537427: VariantsMap = [
    &["decolored"],
    &["decoloured"],
    &["decoloured"],
    &["decoloured"],
];

pub(crate) static ENTRY_DECOLORIMETER_3508867565377467518: VariantsMap = [
    &["decolorimeter"],
    &["decolourimeter"],
    &["decolourimeter"],
    &["decolourimeter"],
];

pub(crate) static ENTRY_DECOLORING_1116088952225601804: VariantsMap = [
    &["decoloring"],
    &["decolouring"],
    &["decolouring"],
    &["decolouring"],
];

pub(crate) static ENTRY_DECOLORIZATIONS_3802618399074055478: VariantsMap = [
    &["decolorizations"],
    &["decolourisations"],
    &["decolourizations"],
    &["decolourisations"],
];

pub(crate) static ENTRY_DECOLORIZATION_16733480511994092682: VariantsMap = [
    &["decolorization"],
    &["decolourisation"],
    &["decolourization"],
    &["decolourisation"],
];

pub(crate) static ENTRY_DECOLORIZED_4114104346884333601: VariantsMap = [
    &["decolorized"],
    &["decolourised"],
    &["decolourized"],
    &["decolourised"],
];

pub(crate) static ENTRY_DECOLORIZERS_3539821653969419352: VariantsMap = [
    &["decolorizers"],
    &["decolourisers"],
    &["decolourizers"],
    &["decolourisers"],
];

pub(crate) static ENTRY_DECOLORIZER_16745583175877494200: VariantsMap = [
    &["decolorizer"],
    &["decolouriser"],
    &["decolourizer"],
    &["decolouriser"],
];

pub(crate) static ENTRY_DECOLORIZES_2799250970864932246: VariantsMap = [
    &["decolorizes"],
    &["decolourises"],
    &["decolourizes"],
    &["decolourises"],
];

pub(crate) static ENTRY_DECOLORIZE_15634240403993874308: VariantsMap = [
    &["decolorize"],
    &["decolourise"],
    &["decolourize"],
    &["decolourise"],
];

pub(crate) static ENTRY_DECOLORIZING_11469437894799461132: VariantsMap = [
    &["decolorizing"],
    &["decolourising"],
    &["decolourizing"],
    &["decolourising"],
];

pub(crate) static ENTRY_DECOLORS_11780774510706184579: VariantsMap = [
    &["decolors"],
    &["decolours"],
    &["decolours"],
    &["decolours"],
];

pub(crate) static ENTRY_DECOLOR_6014626123338999290: VariantsMap =
    [&["decolor"], &["decolour"], &["decolour"], &["decolour"]];

pub(crate) static ENTRY_DECRIMINALIZATIONS_12268289228613201569: VariantsMap = [
    &["decriminalizations"],
    &["decriminalisations"],
    &["decriminalizations"],
    &["decriminalisations"],
];

pub(crate) static ENTRY_DECRIMINALIZATION_10972189705541961663: VariantsMap = [
    &["decriminalization"],
    &["decriminalisation"],
    &["decriminalization"],
    &["decriminalisation"],
];

pub(crate) static ENTRY_DECRIMINALIZED_5536378597888996415: VariantsMap = [
    &["decriminalized"],
    &["decriminalised"],
    &["decriminalized"],
    &["decriminalised"],
];

pub(crate) static ENTRY_DECRIMINALIZES_6555315341160373102: VariantsMap = [
    &["decriminalizes"],
    &["decriminalises"],
    &["decriminalizes"],
    &["decriminalises"],
];

pub(crate) static ENTRY_DECRIMINALIZE_6677799413626987625: VariantsMap = [
    &["decriminalize"],
    &["decriminalise"],
    &["decriminalize"],
    &["decriminalise"],
];

pub(crate) static ENTRY_DECRIMINALIZING_6483531696781808568: VariantsMap = [
    &["decriminalizing"],
    &["decriminalising"],
    &["decriminalizing"],
    &["decriminalising"],
];

pub(crate) static ENTRY_DEDALIAN_8486751251745352405: VariantsMap = [
    &["dedalian"],
    &["daedalian"],
    &["daedalian"],
    &["daedalian"],
];

pub(crate) static ENTRY_DEDAL_5521769065882955150: VariantsMap =
    [&["dedal"], &["daedal"], &["daedal"], &["daedal"]];

pub(crate) static ENTRY_DEDRAMATIZED_12118161118064784971: VariantsMap = [
    &["dedramatized"],
    &["dedramatised"],
    &["dedramatized"],
    &["dedramatised"],
];

pub(crate) static ENTRY_DEDRAMATIZES_10320190471768337081: VariantsMap = [
    &["dedramatizes"],
    &["dedramatises"],
    &["dedramatizes"],
    &["dedramatises"],
];

pub(crate) static ENTRY_DEDRAMATIZE_17445126165727154559: VariantsMap = [
    &["dedramatize"],
    &["dedramatise"],
    &["dedramatize"],
    &["dedramatise"],
];

pub(crate) static ENTRY_DEDRAMATIZING_6204364643863458996: VariantsMap = [
    &["dedramatizing"],
    &["dedramatising"],
    &["dedramatizing"],
    &["dedramatising"],
];

pub(crate) static ENTRY_DEEMPHASIZATION_6353956261442847002: VariantsMap = [
    &["deemphasization"],
    &["deemphasisation"],
    &["deemphasization"],
    &["deemphasisation"],
];

pub(crate) static ENTRY_DEEMPHASIZED_12142584568291460608: VariantsMap = [
    &["deemphasized"],
    &["deemphasised"],
    &["deemphasized"],
    &["deemphasised"],
];

pub(crate) static ENTRY_DEEMPHASIZERS_7007912895593682783: VariantsMap = [
    &["deemphasizers"],
    &["deemphasisers"],
    &["deemphasizers"],
    &["deemphasisers"],
];

pub(crate) static ENTRY_DEEMPHASIZER_6108957853290475121: VariantsMap = [
    &["deemphasizer"],
    &["deemphasiser"],
    &["deemphasizer"],
    &["deemphasiser"],
];

pub(crate) static ENTRY_DEEMPHASIZES_13409957615967153812: VariantsMap = [
    &["deemphasizes"],
    &["deemphasises"],
    &["deemphasizes"],
    &["deemphasises"],
];

pub(crate) static ENTRY_DEEMPHASIZE_2081897672675351950: VariantsMap = [
    &["deemphasize"],
    &["deemphasise"],
    &["deemphasize"],
    &["deemphasise"],
];

pub(crate) static ENTRY_DEEMPHASIZING_1840968374820826426: VariantsMap = [
    &["deemphasizing"],
    &["deemphasising"],
    &["deemphasizing"],
    &["deemphasising"],
];

pub(crate) static ENTRY_DEENERGIZED_5896164931005823934: VariantsMap = [
    &["deenergized"],
    &["deenergised"],
    &["deenergized"],
    &["deenergised"],
];

pub(crate) static ENTRY_DEENERGIZER_16176360588388947490: VariantsMap = [
    &["deenergizer"],
    &["deenergiser"],
    &["deenergizer"],
    &["deenergiser"],
];

pub(crate) static ENTRY_DEENERGIZES_15613252110879695341: VariantsMap = [
    &["deenergizes"],
    &["deenergises"],
    &["deenergizes"],
    &["deenergises"],
];

pub(crate) static ENTRY_DEENERGIZE_8887834988706607224: VariantsMap = [
    &["deenergize"],
    &["deenergise"],
    &["deenergize"],
    &["deenergise"],
];

pub(crate) static ENTRY_DEENERGIZING_4306770013369809072: VariantsMap = [
    &["deenergizing"],
    &["deenergising"],
    &["deenergizing"],
    &["deenergising"],
];

pub(crate) static ENTRY_DEFEDATION_7684726192530482845: VariantsMap = [
    &["defedation"],
    &["defoedation"],
    &["defoedation"],
    &["defoedation"],
];

pub(crate) static ENTRY_DEFEMINIZATION_17125497262735349522: VariantsMap = [
    &["defeminization"],
    &["defeminisation"],
    &["defeminization"],
    &["defeminisation"],
];

pub(crate) static ENTRY_DEFEMINIZED_14147872800166298820: VariantsMap = [
    &["defeminized"],
    &["defeminised"],
    &["defeminized"],
    &["defeminised"],
];

pub(crate) static ENTRY_DEFEMINIZES_12654300795426353647: VariantsMap = [
    &["defeminizes"],
    &["defeminises"],
    &["defeminizes"],
    &["defeminises"],
];

pub(crate) static ENTRY_DEFEMINIZE_1452385300989253047: VariantsMap = [
    &["defeminize"],
    &["defeminise"],
    &["defeminize"],
    &["defeminise"],
];

pub(crate) static ENTRY_DEFEMINIZING_13788943719949840623: VariantsMap = [
    &["defeminizing"],
    &["defeminising"],
    &["defeminizing"],
    &["defeminising"],
];

pub(crate) static ENTRY_DEFENSED_10450678450925087448: VariantsMap =
    [&["defensed"], &["defenced"], &["defenced"], &["defenced"]];

pub(crate) static ENTRY_DEFENSELESSER_11231098921374350935: VariantsMap = [
    &["defenselesser"],
    &["defencelesser"],
    &["defencelesser"],
    &["defencelesser"],
];

pub(crate) static ENTRY_DEFENSELESSEST_11877359825751139498: VariantsMap = [
    &["defenselessest"],
    &["defencelessest"],
    &["defencelessest"],
    &["defencelessest"],
];

pub(crate) static ENTRY_DEFENSELESSLIER_9226167285723882730: VariantsMap = [
    &["defenselesslier"],
    &["defencelesslier"],
    &["defencelesslier"],
    &["defencelesslier"],
];

pub(crate) static ENTRY_DEFENSELESSLIEST_9146397922775201714: VariantsMap = [
    &["defenselessliest"],
    &["defencelessliest"],
    &["defencelessliest"],
    &["defencelessliest"],
];

pub(crate) static ENTRY_DEFENSELESSLY_11336139755398142135: VariantsMap = [
    &["defenselessly"],
    &["defencelessly"],
    &["defencelessly"],
    &["defencelessly"],
];

pub(crate) static ENTRY_DEFENSELESSNESSES_5028704575903983200: VariantsMap = [
    &["defenselessnesses"],
    &["defencelessnesses"],
    &["defencelessnesses"],
    &["defencelessnesses"],
];

pub(crate) static ENTRY_DEFENSELESSNESS_2531659609001850832: VariantsMap = [
    &["defenselessness"],
    &["defencelessness"],
    &["defencelessness"],
    &["defencelessness"],
];

pub(crate) static ENTRY_DEFENSELESS_18055933219220277884: VariantsMap = [
    &["defenseless"],
    &["defenceless"],
    &["defenceless"],
    &["defenceless"],
];

pub(crate) static ENTRY_DEFENSEMAN_8101448990231531201: VariantsMap = [
    &["defenseman"],
    &["defenceman"],
    &["defenceman"],
    &["defenceman"],
];

pub(crate) static ENTRY_DEFENSEMEN_14899097357539129070: VariantsMap = [
    &["defensemen"],
    &["defencemen"],
    &["defencemen"],
    &["defencemen"],
];

pub(crate) static ENTRY_DEFENSES_10286318404274050577: VariantsMap =
    [&["defenses"], &["defences"], &["defences"], &["defences"]];

pub(crate) static ENTRY_DEFENSE_6661070793019776368: VariantsMap =
    [&["defense"], &["defence"], &["defence"], &["defence"]];

pub(crate) static ENTRY_DEFENSING_10107917169615339119: VariantsMap = [
    &["defensing"],
    &["defencing"],
    &["defencing"],
    &["defencing"],
];

pub(crate) static ENTRY_DEFEUDALIZED_9788529944065992059: VariantsMap = [
    &["defeudalized"],
    &["defeudalised"],
    &["defeudalized"],
    &["defeudalised"],
];

pub(crate) static ENTRY_DEFEUDALIZES_8395303255870377128: VariantsMap = [
    &["defeudalizes"],
    &["defeudalises"],
    &["defeudalizes"],
    &["defeudalises"],
];

pub(crate) static ENTRY_DEFEUDALIZE_3615319173936225913: VariantsMap = [
    &["defeudalize"],
    &["defeudalise"],
    &["defeudalize"],
    &["defeudalise"],
];

pub(crate) static ENTRY_DEFEUDALIZING_16034778366842959566: VariantsMap = [
    &["defeudalizing"],
    &["defeudalising"],
    &["defeudalizing"],
    &["defeudalising"],
];

pub(crate) static ENTRY_DEFIBRINIZED_1290929009543001059: VariantsMap = [
    &["defibrinized"],
    &["defibrinised"],
    &["defibrinized"],
    &["defibrinised"],
];

pub(crate) static ENTRY_DEFIBRINIZES_2604624886224030465: VariantsMap = [
    &["defibrinizes"],
    &["defibrinises"],
    &["defibrinizes"],
    &["defibrinises"],
];

pub(crate) static ENTRY_DEFIBRINIZE_14420334367184791100: VariantsMap = [
    &["defibrinize"],
    &["defibrinise"],
    &["defibrinize"],
    &["defibrinise"],
];

pub(crate) static ENTRY_DEFIBRINIZING_14003929221742906824: VariantsMap = [
    &["defibrinizing"],
    &["defibrinising"],
    &["defibrinizing"],
    &["defibrinising"],
];

pub(crate) static ENTRY_DEFINITIZATIONS_5870566431659215392: VariantsMap = [
    &["definitizations"],
    &["definitisations"],
    &["definitizations"],
    &["definitisations"],
];

pub(crate) static ENTRY_DEFINITIZATION_16248589342393728527: VariantsMap = [
    &["definitization"],
    &["definitisation"],
    &["definitization"],
    &["definitisation"],
];

pub(crate) static ENTRY_DEFINITIZED_17126163171519985460: VariantsMap = [
    &["definitized"],
    &["definitised"],
    &["definitized"],
    &["definitised"],
];

pub(crate) static ENTRY_DEFINITIZES_1694150075299923326: VariantsMap = [
    &["definitizes"],
    &["definitises"],
    &["definitizes"],
    &["definitises"],
];

pub(crate) static ENTRY_DEFINITIZE_7690090636180942716: VariantsMap = [
    &["definitize"],
    &["definitise"],
    &["definitize"],
    &["definitise"],
];

pub(crate) static ENTRY_DEFINITIZING_9576972500061726353: VariantsMap = [
    &["definitizing"],
    &["definitising"],
    &["definitizing"],
    &["definitising"],
];

pub(crate) static ENTRY_DEFLECTIONIZATIONS_17596193550921436107: VariantsMap = [
    &["deflectionizations"],
    &["deflectionisations"],
    &["deflectionizations"],
    &["deflectionisations"],
];

pub(crate) static ENTRY_DEFLECTIONIZATION_5301497873748261232: VariantsMap = [
    &["deflectionization"],
    &["deflectionisation"],
    &["deflectionization"],
    &["deflectionisation"],
];

pub(crate) static ENTRY_DEFLECTIONIZES_304679022130280223: VariantsMap = [
    &["deflectionizes"],
    &["deflectionises"],
    &["deflectionizes"],
    &["deflectionises"],
];

pub(crate) static ENTRY_DEFLECTIONIZE_14639492675276732860: VariantsMap = [
    &["deflectionize"],
    &["deflectionise"],
    &["deflectionize"],
    &["deflectionise"],
];

pub(crate) static ENTRY_DEFORMALIZE_729735874124230446: VariantsMap = [
    &["deformalize"],
    &["deformalise"],
    &["deformalize"],
    &["deformalise"],
];

pub(crate) static ENTRY_DEFUNCTIONALIZATIONS_2498662966774747713: VariantsMap = [
    &["defunctionalizations"],
    &["defunctionalisations"],
    &["defunctionalizations"],
    &["defunctionalisations"],
];

pub(crate) static ENTRY_DEFUNCTIONALIZATION_6513191605029783649: VariantsMap = [
    &["defunctionalization"],
    &["defunctionalisation"],
    &["defunctionalization"],
    &["defunctionalisation"],
];

pub(crate) static ENTRY_DEFUNCTIONALIZES_8234850659392060612: VariantsMap = [
    &["defunctionalizes"],
    &["defunctionalises"],
    &["defunctionalizes"],
    &["defunctionalises"],
];

pub(crate) static ENTRY_DEFUNCTIONALIZE_10852668215621257147: VariantsMap = [
    &["defunctionalize"],
    &["defunctionalise"],
    &["defunctionalize"],
    &["defunctionalise"],
];

pub(crate) static ENTRY_DEGLYCEROLIZED_17745076794910422475: VariantsMap = [
    &["deglycerolized"],
    &["deglycerolised"],
    &["deglycerolized"],
    &["deglycerolised"],
];

pub(crate) static ENTRY_DEHUMANIZATIONS_12753893729327325578: VariantsMap = [
    &["dehumanizations"],
    &["dehumanisations"],
    &["dehumanizations"],
    &["dehumanisations"],
];

pub(crate) static ENTRY_DEHUMANIZATION_8203365336341231524: VariantsMap = [
    &["dehumanization"],
    &["dehumanisation"],
    &["dehumanization"],
    &["dehumanisation"],
];

pub(crate) static ENTRY_DEHUMANIZED_6478369645453909211: VariantsMap = [
    &["dehumanized"],
    &["dehumanised"],
    &["dehumanized"],
    &["dehumanised"],
];

pub(crate) static ENTRY_DEHUMANIZES_7224437139012646110: VariantsMap = [
    &["dehumanizes"],
    &["dehumanises"],
    &["dehumanizes"],
    &["dehumanises"],
];

pub(crate) static ENTRY_DEHUMANIZE_18142286574789231038: VariantsMap = [
    &["dehumanize"],
    &["dehumanise"],
    &["dehumanize"],
    &["dehumanise"],
];

pub(crate) static ENTRY_DEHUMANIZING_9897055991255710061: VariantsMap = [
    &["dehumanizing"],
    &["dehumanising"],
    &["dehumanizing"],
    &["dehumanising"],
];

pub(crate) static ENTRY_DEHYDROGENIZATION_7598177451677061196: VariantsMap = [
    &["dehydrogenization"],
    &["dehydrogenisation"],
    &["dehydrogenization"],
    &["dehydrogenisation"],
];

pub(crate) static ENTRY_DEHYDROGENIZED_13134561750473254133: VariantsMap = [
    &["dehydrogenized"],
    &["dehydrogenised"],
    &["dehydrogenized"],
    &["dehydrogenised"],
];

pub(crate) static ENTRY_DEHYDROGENIZER_8350907719907519200: VariantsMap = [
    &["dehydrogenizer"],
    &["dehydrogeniser"],
    &["dehydrogenizer"],
    &["dehydrogeniser"],
];

pub(crate) static ENTRY_DEHYDROGENIZE_15631606377798495147: VariantsMap = [
    &["dehydrogenize"],
    &["dehydrogenise"],
    &["dehydrogenize"],
    &["dehydrogenise"],
];

pub(crate) static ENTRY_DEHYDROGENIZING_9609271904194973996: VariantsMap = [
    &["dehydrogenizing"],
    &["dehydrogenising"],
    &["dehydrogenizing"],
    &["dehydrogenising"],
];

pub(crate) static ENTRY_DEHYPNOTIZATIONS_1374277010264346868: VariantsMap = [
    &["dehypnotizations"],
    &["dehypnotisations"],
    &["dehypnotizations"],
    &["dehypnotisations"],
];

pub(crate) static ENTRY_DEHYPNOTIZATION_11425386795669592923: VariantsMap = [
    &["dehypnotization"],
    &["dehypnotisation"],
    &["dehypnotization"],
    &["dehypnotisation"],
];

pub(crate) static ENTRY_DEHYPNOTIZED_4122447499004441152: VariantsMap = [
    &["dehypnotized"],
    &["dehypnotised"],
    &["dehypnotized"],
    &["dehypnotised"],
];

pub(crate) static ENTRY_DEHYPNOTIZES_4660291758322276947: VariantsMap = [
    &["dehypnotizes"],
    &["dehypnotises"],
    &["dehypnotizes"],
    &["dehypnotises"],
];

pub(crate) static ENTRY_DEHYPNOTIZE_3485990394993698329: VariantsMap = [
    &["dehypnotize"],
    &["dehypnotise"],
    &["dehypnotize"],
    &["dehypnotise"],
];

pub(crate) static ENTRY_DEHYPNOTIZING_9093004215936393024: VariantsMap = [
    &["dehypnotizing"],
    &["dehypnotising"],
    &["dehypnotizing"],
    &["dehypnotising"],
];

pub(crate) static ENTRY_DEINDUSTRIALIZATIONS_2772884714504552706: VariantsMap = [
    &["deindustrializations"],
    &["deindustrialisations"],
    &["deindustrializations"],
    &["deindustrialisations"],
];

pub(crate) static ENTRY_DEINDUSTRIALIZATION_6387275550903659107: VariantsMap = [
    &["deindustrialization"],
    &["deindustrialisation"],
    &["deindustrialization"],
    &["deindustrialisation"],
];

pub(crate) static ENTRY_DEINDUSTRIALIZED_16089090941805878059: VariantsMap = [
    &["deindustrialized"],
    &["deindustrialised"],
    &["deindustrialized"],
    &["deindustrialised"],
];

pub(crate) static ENTRY_DEINDUSTRIALIZES_4178419714956693675: VariantsMap = [
    &["deindustrializes"],
    &["deindustrialises"],
    &["deindustrializes"],
    &["deindustrialises"],
];

pub(crate) static ENTRY_DEINDUSTRIALIZE_1319190901834187810: VariantsMap = [
    &["deindustrialize"],
    &["deindustrialise"],
    &["deindustrialize"],
    &["deindustrialise"],
];

pub(crate) static ENTRY_DEINDUSTRIALIZING_499895641188650261: VariantsMap = [
    &["deindustrializing"],
    &["deindustrialising"],
    &["deindustrializing"],
    &["deindustrialising"],
];

pub(crate) static ENTRY_DEIONIZATION_8915428723312142234: VariantsMap = [
    &["deionization"],
    &["deionisation"],
    &["deionization"],
    &["deionisation"],
];

pub(crate) static ENTRY_DEIONIZED_10491202019791607626: VariantsMap = [
    &["deionized"],
    &["deionised"],
    &["deionized"],
    &["deionised"],
];

pub(crate) static ENTRY_DEIONIZES_10200275155305727895: VariantsMap = [
    &["deionizes"],
    &["deionises"],
    &["deionizes"],
    &["deionises"],
];

pub(crate) static ENTRY_DEIONIZE_338398712613893588: VariantsMap =
    [&["deionize"], &["deionise"], &["deionize"], &["deionise"]];

pub(crate) static ENTRY_DEIONIZING_16611163248873983172: VariantsMap = [
    &["deionizing"],
    &["deionising"],
    &["deionizing"],
    &["deionising"],
];

pub(crate) static ENTRY_DEKALITERS_740321635385073637: VariantsMap = [
    &["decaliter", "dekaliters"],
    &["decalitres"],
    &["decalitres"],
    &["decalitres"],
];

pub(crate) static ENTRY_DEKALITER_11207981744248149263: VariantsMap = [
    &["decaliter", "dekaliter"],
    &["decalitre"],
    &["decalitre"],
    &["decalitre"],
];

pub(crate) static ENTRY_DEKAMETERS_10451263896199436858: VariantsMap = [
    &["decameter", "dekameters"],
    &["decametres"],
    &["decametres"],
    &["decametres"],
];

pub(crate) static ENTRY_DEKAMETER_1569515849500939883: VariantsMap = [
    &["decameter", "dekameter"],
    &["decametre"],
    &["decametre"],
    &["decametre"],
];

pub(crate) static ENTRY_DELIMITIZES_5856258726008705246: VariantsMap = [
    &["delimitizes"],
    &["delimitises"],
    &["delimitizes"],
    &["delimitises"],
];

pub(crate) static ENTRY_DELIMITIZE_6280786742056797343: VariantsMap = [
    &["delimitize"],
    &["delimitise"],
    &["delimitize"],
    &["delimitise"],
];

pub(crate) static ENTRY_DELOCALIZATIONS_11207793221550956501: VariantsMap = [
    &["delocalizations"],
    &["delocalisations"],
    &["delocalizations"],
    &["delocalisations"],
];

pub(crate) static ENTRY_DELOCALIZATION_3872128840219390827: VariantsMap = [
    &["delocalization"],
    &["delocalisation"],
    &["delocalization"],
    &["delocalisation"],
];

pub(crate) static ENTRY_DELOCALIZED_17487743123281665827: VariantsMap = [
    &["delocalized"],
    &["delocalised"],
    &["delocalized"],
    &["delocalised"],
];

pub(crate) static ENTRY_DELOCALIZES_1352875521634188136: VariantsMap = [
    &["delocalizes"],
    &["delocalises"],
    &["delocalizes"],
    &["delocalises"],
];

pub(crate) static ENTRY_DELOCALIZE_2924961970509538366: VariantsMap = [
    &["delocalize"],
    &["delocalise"],
    &["delocalize"],
    &["delocalise"],
];

pub(crate) static ENTRY_DELOCALIZING_18066483905901400466: VariantsMap = [
    &["delocalizing"],
    &["delocalising"],
    &["delocalizing"],
    &["delocalising"],
];

pub(crate) static ENTRY_DELUSTER_5748786244898572324: VariantsMap =
    [&["deluster"], &["delustre"], &["delustre"], &["delustre"]];

pub(crate) static ENTRY_DEMAGNETIZABLER_5023249495266689114: VariantsMap = [
    &["demagnetizabler"],
    &["demagnetisabler"],
    &["demagnetizabler"],
    &["demagnetisabler"],
];

pub(crate) static ENTRY_DEMAGNETIZABLEST_12541438993123223292: VariantsMap = [
    &["demagnetizablest"],
    &["demagnetisablest"],
    &["demagnetizablest"],
    &["demagnetisablest"],
];

pub(crate) static ENTRY_DEMAGNETIZABLES_12807792172235133470: VariantsMap = [
    &["demagnetizables"],
    &["demagnetisables"],
    &["demagnetizables"],
    &["demagnetisables"],
];

pub(crate) static ENTRY_DEMAGNETIZABLE_18071482520159508890: VariantsMap = [
    &["demagnetizable"],
    &["demagnetisable"],
    &["demagnetizable"],
    &["demagnetisable"],
];

pub(crate) static ENTRY_DEMAGNETIZATIONS_6017739735415397589: VariantsMap = [
    &["demagnetizations"],
    &["demagnetisations"],
    &["demagnetizations"],
    &["demagnetisations"],
];

pub(crate) static ENTRY_DEMAGNETIZATION_8660626408268068192: VariantsMap = [
    &["demagnetization"],
    &["demagnetisation"],
    &["demagnetization"],
    &["demagnetisation"],
];

pub(crate) static ENTRY_DEMAGNETIZED_16278014960965990808: VariantsMap = [
    &["demagnetized"],
    &["demagnetised"],
    &["demagnetized"],
    &["demagnetised"],
];

pub(crate) static ENTRY_DEMAGNETIZERS_931034885365981384: VariantsMap = [
    &["demagnetizers"],
    &["demagnetisers"],
    &["demagnetizers"],
    &["demagnetisers"],
];

pub(crate) static ENTRY_DEMAGNETIZER_4728434350800689036: VariantsMap = [
    &["demagnetizer"],
    &["demagnetiser"],
    &["demagnetizer"],
    &["demagnetiser"],
];

pub(crate) static ENTRY_DEMAGNETIZES_677533597345689814: VariantsMap = [
    &["demagnetizes"],
    &["demagnetises"],
    &["demagnetizes"],
    &["demagnetises"],
];

pub(crate) static ENTRY_DEMAGNETIZE_14716676657435015384: VariantsMap = [
    &["demagnetize"],
    &["demagnetise"],
    &["demagnetize"],
    &["demagnetise"],
];

pub(crate) static ENTRY_DEMAGNETIZING_11214913343744584233: VariantsMap = [
    &["demagnetizing"],
    &["demagnetising"],
    &["demagnetizing"],
    &["demagnetising"],
];

pub(crate) static ENTRY_DEMAGOGUED_3536597591189504210: VariantsMap = [
    &["demagogued"],
    &["demagogued"],
    &["demagogued"],
    &["demagogued"],
];

pub(crate) static ENTRY_DEMAGOGUERY_1494206203290122461: VariantsMap = [
    &["demagoguery"],
    &["demagoguery"],
    &["demagoguery"],
    &["demagoguery"],
];

pub(crate) static ENTRY_DEMAGOGUES_15335780932382092242: VariantsMap = [
    &["demagogues"],
    &["demagogues"],
    &["demagogues"],
    &["demagogues"],
];

pub(crate) static ENTRY_DEMAGOGUE_8651813563125313987: VariantsMap = [
    &["demagogue"],
    &["demagogue"],
    &["demagogue"],
    &["demagogue"],
];

pub(crate) static ENTRY_DEMAGOGUING_15979024284168235826: VariantsMap = [
    &["demagoguing"],
    &["demagoguing"],
    &["demagoguing"],
    &["demagoguing"],
];

pub(crate) static ENTRY_DEMASCULINIZATION_213789906363297959: VariantsMap = [
    &["demasculinization"],
    &["demasculinisation"],
    &["demasculinization"],
    &["demasculinisation"],
];

pub(crate) static ENTRY_DEMASCULINIZED_12911696497389015826: VariantsMap = [
    &["demasculinized"],
    &["demasculinised"],
    &["demasculinized"],
    &["demasculinised"],
];

pub(crate) static ENTRY_DEMASCULINIZE_1597494522680282305: VariantsMap = [
    &["demasculinize"],
    &["demasculinise"],
    &["demasculinize"],
    &["demasculinise"],
];

pub(crate) static ENTRY_DEMASCULINIZING_1729668073021130975: VariantsMap = [
    &["demasculinizing"],
    &["demasculinising"],
    &["demasculinizing"],
    &["demasculinising"],
];

pub(crate) static ENTRY_DEMATERIALIZATIONS_9448622588126109210: VariantsMap = [
    &["dematerializations"],
    &["dematerialisations"],
    &["dematerializations"],
    &["dematerialisations"],
];

pub(crate) static ENTRY_DEMATERIALIZATION_6643468176116888919: VariantsMap = [
    &["dematerialization"],
    &["dematerialisation"],
    &["dematerialization"],
    &["dematerialisation"],
];

pub(crate) static ENTRY_DEMATERIALIZED_13253413423231441157: VariantsMap = [
    &["dematerialized"],
    &["dematerialised"],
    &["dematerialized"],
    &["dematerialised"],
];

pub(crate) static ENTRY_DEMATERIALIZES_5270284454646712513: VariantsMap = [
    &["dematerializes"],
    &["dematerialises"],
    &["dematerializes"],
    &["dematerialises"],
];

pub(crate) static ENTRY_DEMATERIALIZE_5188464319891499632: VariantsMap = [
    &["dematerialize"],
    &["dematerialise"],
    &["dematerialize"],
    &["dematerialise"],
];

pub(crate) static ENTRY_DEMATERIALIZING_4105956654256703819: VariantsMap = [
    &["dematerializing"],
    &["dematerialising"],
    &["dematerializing"],
    &["dematerialising"],
];

pub(crate) static ENTRY_DEMEANORS_7209163777589536912: VariantsMap = [
    &["demeanors"],
    &["demeanours"],
    &["demeanours"],
    &["demeanours"],
];

pub(crate) static ENTRY_DEMEANOR_16422703697064073325: VariantsMap = [
    &["demeanor"],
    &["demeanour"],
    &["demeanour"],
    &["demeanour"],
];

pub(crate) static ENTRY_DEMILITARIZATIONS_13863377781587784313: VariantsMap = [
    &["demilitarizations"],
    &["demilitarisations"],
    &["demilitarizations"],
    &["demilitarisations"],
];

pub(crate) static ENTRY_DEMILITARIZATION_8640733064988757472: VariantsMap = [
    &["demilitarization"],
    &["demilitarisation"],
    &["demilitarization"],
    &["demilitarisation"],
];

pub(crate) static ENTRY_DEMILITARIZED_4980413846043795380: VariantsMap = [
    &["demilitarized"],
    &["demilitarised"],
    &["demilitarized"],
    &["demilitarised"],
];

pub(crate) static ENTRY_DEMILITARIZES_1164840116130396010: VariantsMap = [
    &["demilitarizes"],
    &["demilitarises"],
    &["demilitarizes"],
    &["demilitarises"],
];

pub(crate) static ENTRY_DEMILITARIZE_5838068700068012783: VariantsMap = [
    &["demilitarize"],
    &["demilitarise"],
    &["demilitarize"],
    &["demilitarise"],
];

pub(crate) static ENTRY_DEMILITARIZING_994064454433057567: VariantsMap = [
    &["demilitarizing"],
    &["demilitarising"],
    &["demilitarizing"],
    &["demilitarising"],
];

pub(crate) static ENTRY_DEMILUSTER_18132679498143227517: VariantsMap = [
    &["demiluster"],
    &["demilustre"],
    &["demilustre"],
    &["demilustre"],
];

pub(crate) static ENTRY_DEMINERALIZATIONS_3572117260520975819: VariantsMap = [
    &["demineralizations"],
    &["demineralisations"],
    &["demineralizations"],
    &["demineralisations"],
];

pub(crate) static ENTRY_DEMINERALIZATION_3724123166587453242: VariantsMap = [
    &["demineralization"],
    &["demineralisation"],
    &["demineralization"],
    &["demineralisation"],
];

pub(crate) static ENTRY_DEMINERALIZED_5889760188783683563: VariantsMap = [
    &["demineralized"],
    &["demineralised"],
    &["demineralized"],
    &["demineralised"],
];

pub(crate) static ENTRY_DEMINERALIZER_5594003650129551989: VariantsMap = [
    &["demineralizer"],
    &["demineraliser"],
    &["demineralizer"],
    &["demineraliser"],
];

pub(crate) static ENTRY_DEMINERALIZES_7031323467048546237: VariantsMap = [
    &["demineralizes"],
    &["demineralises"],
    &["demineralizes"],
    &["demineralises"],
];

pub(crate) static ENTRY_DEMINERALIZE_11805613081665284275: VariantsMap = [
    &["demineralize"],
    &["demineralise"],
    &["demineralize"],
    &["demineralise"],
];

pub(crate) static ENTRY_DEMINERALIZING_17818456458860291247: VariantsMap = [
    &["demineralizing"],
    &["demineralising"],
    &["demineralizing"],
    &["demineralising"],
];

pub(crate) static ENTRY_DEMOBILIZATIONS_13060676951440773109: VariantsMap = [
    &["demobilizations"],
    &["demobilisations"],
    &["demobilizations"],
    &["demobilisations"],
];

pub(crate) static ENTRY_DEMOBILIZATION_1049482128993581914: VariantsMap = [
    &["demobilization"],
    &["demobilisation"],
    &["demobilization"],
    &["demobilisation"],
];

pub(crate) static ENTRY_DEMOBILIZED_17675606354573049345: VariantsMap = [
    &["demobilized"],
    &["demobilised"],
    &["demobilized"],
    &["demobilised"],
];

pub(crate) static ENTRY_DEMOBILIZES_10953083886563254885: VariantsMap = [
    &["demobilizes"],
    &["demobilises"],
    &["demobilizes"],
    &["demobilises"],
];

pub(crate) static ENTRY_DEMOBILIZE_14631658221062411664: VariantsMap = [
    &["demobilize"],
    &["demobilise"],
    &["demobilize"],
    &["demobilise"],
];

pub(crate) static ENTRY_DEMOBILIZING_12570129016674680770: VariantsMap = [
    &["demobilizing"],
    &["demobilising"],
    &["demobilizing"],
    &["demobilising"],
];

pub(crate) static ENTRY_DEMOCRATIZATIONS_3121981811677706660: VariantsMap = [
    &["democratizations"],
    &["democratisations"],
    &["democratizations"],
    &["democratisations"],
];

pub(crate) static ENTRY_DEMOCRATIZATION_14834678678990587615: VariantsMap = [
    &["democratization"],
    &["democratisation"],
    &["democratization"],
    &["democratisation"],
];

pub(crate) static ENTRY_DEMOCRATIZED_12561497189609834727: VariantsMap = [
    &["democratized"],
    &["democratised"],
    &["democratized"],
    &["democratised"],
];

pub(crate) static ENTRY_DEMOCRATIZER_7068896316951512081: VariantsMap = [
    &["democratizer"],
    &["democratiser"],
    &["democratizer"],
    &["democratiser"],
];

pub(crate) static ENTRY_DEMOCRATIZES_9683541385378161525: VariantsMap = [
    &["democratizes"],
    &["democratises"],
    &["democratizes"],
    &["democratises"],
];

pub(crate) static ENTRY_DEMOCRATIZE_14651228604547676688: VariantsMap = [
    &["democratize"],
    &["democratise"],
    &["democratize"],
    &["democratise"],
];

pub(crate) static ENTRY_DEMOCRATIZING_17328231163322967219: VariantsMap = [
    &["democratizing"],
    &["democratising"],
    &["democratizing"],
    &["democratising"],
];

pub(crate) static ENTRY_DEMONETIZATIONS_5789055765366818676: VariantsMap = [
    &["demonetizations"],
    &["demonetisations"],
    &["demonetizations"],
    &["demonetisations"],
];

pub(crate) static ENTRY_DEMONETIZATION_4518090358111490492: VariantsMap = [
    &["demonetization"],
    &["demonetisation"],
    &["demonetization"],
    &["demonetisation"],
];

pub(crate) static ENTRY_DEMONETIZED_9558772114869845360: VariantsMap = [
    &["demonetized"],
    &["demonetised"],
    &["demonetized"],
    &["demonetised"],
];

pub(crate) static ENTRY_DEMONETIZES_11169810391799810472: VariantsMap = [
    &["demonetizes"],
    &["demonetises"],
    &["demonetizes"],
    &["demonetises"],
];

pub(crate) static ENTRY_DEMONETIZE_13078441376893081927: VariantsMap = [
    &["demonetize"],
    &["demonetise"],
    &["demonetize"],
    &["demonetise"],
];

pub(crate) static ENTRY_DEMONETIZING_17201412552660846011: VariantsMap = [
    &["demonetizing"],
    &["demonetising"],
    &["demonetizing"],
    &["demonetising"],
];

pub(crate) static ENTRY_DEMONIAN_1193667978555747859: VariantsMap = [
    &["demonian"],
    &["daemonian"],
    &["daemonian"],
    &["daemonian"],
];

pub(crate) static ENTRY_DEMONIZATION_435935988767727254: VariantsMap = [
    &["demonization"],
    &["demonisation"],
    &["demonization"],
    &["demonisation"],
];

pub(crate) static ENTRY_DEMONIZED_7711881396852229241: VariantsMap = [
    &["demonized"],
    &["demonised"],
    &["demonized"],
    &["demonised"],
];

pub(crate) static ENTRY_DEMONIZES_6258438652449642743: VariantsMap = [
    &["demonizes"],
    &["demonises"],
    &["demonizes"],
    &["demonises"],
];

pub(crate) static ENTRY_DEMONIZE_13260611226384752739: VariantsMap =
    [&["demonize"], &["demonise"], &["demonize"], &["demonise"]];

pub(crate) static ENTRY_DEMONIZING_8343923659206792410: VariantsMap = [
    &["demonizing"],
    &["demonising"],
    &["demonizing"],
    &["demonising"],
];

pub(crate) static ENTRY_DEMORALIZATIONS_9043499224356783699: VariantsMap = [
    &["demoralizations"],
    &["demoralisations"],
    &["demoralizations"],
    &["demoralisations"],
];

pub(crate) static ENTRY_DEMORALIZATION_5556421705683237030: VariantsMap = [
    &["demoralization"],
    &["demoralisation"],
    &["demoralization"],
    &["demoralisation"],
];

pub(crate) static ENTRY_DEMORALIZED_11896518767543535927: VariantsMap = [
    &["demoralized"],
    &["demoralised"],
    &["demoralized"],
    &["demoralised"],
];

pub(crate) static ENTRY_DEMORALIZERS_9101020457936316129: VariantsMap = [
    &["demoralizers"],
    &["demoralisers"],
    &["demoralizers"],
    &["demoralisers"],
];

pub(crate) static ENTRY_DEMORALIZER_6308024706547373880: VariantsMap = [
    &["demoralizer"],
    &["demoraliser"],
    &["demoralizer"],
    &["demoraliser"],
];

pub(crate) static ENTRY_DEMORALIZES_17922317839176266819: VariantsMap = [
    &["demoralizes"],
    &["demoralises"],
    &["demoralizes"],
    &["demoralises"],
];

pub(crate) static ENTRY_DEMORALIZE_6209215674833141288: VariantsMap = [
    &["demoralize"],
    &["demoralise"],
    &["demoralize"],
    &["demoralise"],
];

pub(crate) static ENTRY_DEMORALIZINGLY_11418463351635146120: VariantsMap = [
    &["demoralizingly"],
    &["demoralisingly"],
    &["demoralizingly"],
    &["demoralisingly"],
];

pub(crate) static ENTRY_DEMORALIZING_7879881258206607673: VariantsMap = [
    &["demoralizing"],
    &["demoralising"],
    &["demoralizing"],
    &["demoralising"],
];

pub(crate) static ENTRY_DEMUTUALIZATIONS_6102922690573062369: VariantsMap = [
    &["demutualizations"],
    &["demutualisations"],
    &["demutualizations"],
    &["demutualisations"],
];

pub(crate) static ENTRY_DEMUTUALIZATION_18431681853700545646: VariantsMap = [
    &["demutualization"],
    &["demutualisation"],
    &["demutualization"],
    &["demutualisation"],
];

pub(crate) static ENTRY_DEMUTUALIZED_17042353852397685351: VariantsMap = [
    &["demutualized"],
    &["demutualised"],
    &["demutualized"],
    &["demutualised"],
];

pub(crate) static ENTRY_DEMUTUALIZES_15236673083951911035: VariantsMap = [
    &["demutualizes"],
    &["demutualises"],
    &["demutualizes"],
    &["demutualises"],
];

pub(crate) static ENTRY_DEMUTUALIZE_14231937422114961245: VariantsMap = [
    &["demutualize"],
    &["demutualise"],
    &["demutualize"],
    &["demutualise"],
];

pub(crate) static ENTRY_DEMUTUALIZING_13109066682270155313: VariantsMap = [
    &["demutualizing"],
    &["demutualising"],
    &["demutualizing"],
    &["demutualising"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZATIONS_11694452494871264603: VariantsMap = [
    &["demythologizations"],
    &["demythologisations"],
    &["demythologizations"],
    &["demythologisations"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZATION_9448051342581796983: VariantsMap = [
    &["demythologization"],
    &["demythologisation"],
    &["demythologization"],
    &["demythologisation"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZED_1548902620938435190: VariantsMap = [
    &["demythologized"],
    &["demythologised"],
    &["demythologized"],
    &["demythologised"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZER_2012883936376160479: VariantsMap = [
    &["demythologizer"],
    &["demythologiser"],
    &["demythologizer"],
    &["demythologiser"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZES_9084348299549456287: VariantsMap = [
    &["demythologizes"],
    &["demythologises"],
    &["demythologizes"],
    &["demythologises"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZE_16256850336374180662: VariantsMap = [
    &["demythologize"],
    &["demythologise"],
    &["demythologize"],
    &["demythologise"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZING_16424025398156147764: VariantsMap = [
    &["demythologizing"],
    &["demythologising"],
    &["demythologizing"],
    &["demythologising"],
];

pub(crate) static ENTRY_DENATIONALIZATIONS_15722416399546323549: VariantsMap = [
    &["denationalizations"],
    &["denationalisations"],
    &["denationalizations"],
    &["denationalisations"],
];

pub(crate) static ENTRY_DENATIONALIZATION_7729401217206590693: VariantsMap = [
    &["denationalization"],
    &["denationalisation"],
    &["denationalization"],
    &["denationalisation"],
];

pub(crate) static ENTRY_DENATIONALIZED_743884727286515814: VariantsMap = [
    &["denationalized"],
    &["denationalised"],
    &["denationalized"],
    &["denationalised"],
];

pub(crate) static ENTRY_DENATIONALIZES_810829978748210734: VariantsMap = [
    &["denationalizes"],
    &["denationalises"],
    &["denationalizes"],
    &["denationalises"],
];

pub(crate) static ENTRY_DENATIONALIZE_6717709717538962281: VariantsMap = [
    &["denationalize"],
    &["denationalise"],
    &["denationalize"],
    &["denationalise"],
];

pub(crate) static ENTRY_DENATIONALIZING_700744151576877592: VariantsMap = [
    &["denationalizing"],
    &["denationalising"],
    &["denationalizing"],
    &["denationalising"],
];

pub(crate) static ENTRY_DENATURALIZATIONS_8163203679079106549: VariantsMap = [
    &["denaturalizations"],
    &["denaturalisations"],
    &["denaturalizations"],
    &["denaturalisations"],
];

pub(crate) static ENTRY_DENATURALIZATION_971871507540742642: VariantsMap = [
    &["denaturalization"],
    &["denaturalisation"],
    &["denaturalization"],
    &["denaturalisation"],
];

pub(crate) static ENTRY_DENATURALIZED_12577789701438825587: VariantsMap = [
    &["denaturalized"],
    &["denaturalised"],
    &["denaturalized"],
    &["denaturalised"],
];

pub(crate) static ENTRY_DENATURALIZES_1101122283585879857: VariantsMap = [
    &["denaturalizes"],
    &["denaturalises"],
    &["denaturalizes"],
    &["denaturalises"],
];

pub(crate) static ENTRY_DENATURALIZE_13324203980568159303: VariantsMap = [
    &["denaturalize"],
    &["denaturalise"],
    &["denaturalize"],
    &["denaturalise"],
];

pub(crate) static ENTRY_DENATURALIZING_10692265626612469207: VariantsMap = [
    &["denaturalizing"],
    &["denaturalising"],
    &["denaturalizing"],
    &["denaturalising"],
];

pub(crate) static ENTRY_DENATURIZATIONS_6130073867652899556: VariantsMap = [
    &["denaturizations"],
    &["denaturisations"],
    &["denaturizations"],
    &["denaturisations"],
];

pub(crate) static ENTRY_DENATURIZATION_16327711323005388330: VariantsMap = [
    &["denaturization"],
    &["denaturisation"],
    &["denaturization"],
    &["denaturisation"],
];

pub(crate) static ENTRY_DENATURIZED_7728796726923631023: VariantsMap = [
    &["denaturized"],
    &["denaturised"],
    &["denaturized"],
    &["denaturised"],
];

pub(crate) static ENTRY_DENATURIZERS_8124812684792240271: VariantsMap = [
    &["denaturizers"],
    &["denaturisers"],
    &["denaturizers"],
    &["denaturisers"],
];

pub(crate) static ENTRY_DENATURIZER_5742972324535303084: VariantsMap = [
    &["denaturizer"],
    &["denaturiser"],
    &["denaturizer"],
    &["denaturiser"],
];

pub(crate) static ENTRY_DENATURIZES_8891761127410674874: VariantsMap = [
    &["denaturizes"],
    &["denaturises"],
    &["denaturizes"],
    &["denaturises"],
];

pub(crate) static ENTRY_DENATURIZE_8790862263166536662: VariantsMap = [
    &["denaturize"],
    &["denaturise"],
    &["denaturize"],
    &["denaturise"],
];

pub(crate) static ENTRY_DENATURIZING_10703544832870467506: VariantsMap = [
    &["denaturizing"],
    &["denaturising"],
    &["denaturizing"],
    &["denaturising"],
];

pub(crate) static ENTRY_DENICOTINIZE_8579575775799953548: VariantsMap = [
    &["denicotinize"],
    &["denicotinise"],
    &["denicotinize"],
    &["denicotinise"],
];

pub(crate) static ENTRY_DENIZENIZES_14830211105150512617: VariantsMap = [
    &["denizenizes"],
    &["denizenises"],
    &["denizenizes"],
    &["denizenises"],
];

pub(crate) static ENTRY_DENIZENIZE_17817911669092719598: VariantsMap = [
    &["denizenize"],
    &["denizenise"],
    &["denizenize"],
    &["denizenise"],
];

pub(crate) static ENTRY_DENOMINATIONALIZES_6379243336804749861: VariantsMap = [
    &["denominationalizes"],
    &["denominationalises"],
    &["denominationalizes"],
    &["denominationalises"],
];

pub(crate) static ENTRY_DENOMINATIONALIZE_10227188452058754943: VariantsMap = [
    &["denominationalize"],
    &["denominationalise"],
    &["denominationalize"],
    &["denominationalise"],
];

pub(crate) static ENTRY_DENORMALIZE_10985021775483702575: VariantsMap = [
    &["denormalize"],
    &["denormalise"],
    &["denormalize"],
    &["denormalise"],
];

pub(crate) static ENTRY_DENTALIZATIONS_14739673468733397726: VariantsMap = [
    &["dentalizations"],
    &["dentalisations"],
    &["dentalizations"],
    &["dentalisations"],
];

pub(crate) static ENTRY_DENTALIZATION_7950101487769456236: VariantsMap = [
    &["dentalization"],
    &["dentalisation"],
    &["dentalization"],
    &["dentalisation"],
];

pub(crate) static ENTRY_DENTALIZED_4287706936239846846: VariantsMap = [
    &["dentalized"],
    &["dentalised"],
    &["dentalized"],
    &["dentalised"],
];

pub(crate) static ENTRY_DENTALIZES_1046373883492057791: VariantsMap = [
    &["dentalizes"],
    &["dentalises"],
    &["dentalizes"],
    &["dentalises"],
];

pub(crate) static ENTRY_DENTALIZE_7399494862597532732: VariantsMap = [
    &["dentalize"],
    &["dentalise"],
    &["dentalize"],
    &["dentalise"],
];

pub(crate) static ENTRY_DENTALIZING_9457659412983759427: VariantsMap = [
    &["dentalizing"],
    &["dentalising"],
    &["dentalizing"],
    &["dentalising"],
];

pub(crate) static ENTRY_DENTINS_16363943754880560753: VariantsMap =
    [&["dentins"], &["dentines"], &["dentines"], &["dentines"]];

pub(crate) static ENTRY_DENTIN_357200140665913924: VariantsMap =
    [&["dentin"], &["dentine"], &["dentine"], &["dentine"]];

pub(crate) static ENTRY_DENUCLEARIZATIONS_14853943063749587480: VariantsMap = [
    &["denuclearizations"],
    &["denuclearisations"],
    &["denuclearizations"],
    &["denuclearisations"],
];

pub(crate) static ENTRY_DENUCLEARIZATION_3316678403334950773: VariantsMap = [
    &["denuclearization"],
    &["denuclearisation"],
    &["denuclearization"],
    &["denuclearisation"],
];

pub(crate) static ENTRY_DENUCLEARIZED_6796248104359598000: VariantsMap = [
    &["denuclearized"],
    &["denuclearised"],
    &["denuclearized"],
    &["denuclearised"],
];

pub(crate) static ENTRY_DENUCLEARIZES_18168803656441460141: VariantsMap = [
    &["denuclearizes"],
    &["denuclearises"],
    &["denuclearizes"],
    &["denuclearises"],
];

pub(crate) static ENTRY_DENUCLEARIZE_7087853246260766822: VariantsMap = [
    &["denuclearize"],
    &["denuclearise"],
    &["denuclearize"],
    &["denuclearise"],
];

pub(crate) static ENTRY_DENUCLEARIZING_12070807204335448918: VariantsMap = [
    &["denuclearizing"],
    &["denuclearising"],
    &["denuclearizing"],
    &["denuclearising"],
];

pub(crate) static ENTRY_DEODORIZATIONS_1611791796101503754: VariantsMap = [
    &["deodorizations"],
    &["deodorisations"],
    &["deodorizations"],
    &["deodorisations"],
];

pub(crate) static ENTRY_DEODORIZATION_15742635316130478344: VariantsMap = [
    &["deodorization"],
    &["deodorisation"],
    &["deodorization"],
    &["deodorisation"],
];

pub(crate) static ENTRY_DEODORIZED_18267764171132816135: VariantsMap = [
    &["deodorized"],
    &["deodorised"],
    &["deodorized"],
    &["deodorised"],
];

pub(crate) static ENTRY_DEODORIZERS_14070131912570234977: VariantsMap = [
    &["deodorizers"],
    &["deodorisers"],
    &["deodorizers"],
    &["deodorisers"],
];

pub(crate) static ENTRY_DEODORIZER_10856939399522550712: VariantsMap = [
    &["deodorizer"],
    &["deodoriser"],
    &["deodorizer"],
    &["deodoriser"],
];

pub(crate) static ENTRY_DEODORIZES_9011430423896385984: VariantsMap = [
    &["deodorizes"],
    &["deodorises"],
    &["deodorizes"],
    &["deodorises"],
];

pub(crate) static ENTRY_DEODORIZE_11113930164721287704: VariantsMap = [
    &["deodorize"],
    &["deodorise"],
    &["deodorize"],
    &["deodorise"],
];

pub(crate) static ENTRY_DEODORIZING_13167718500093382611: VariantsMap = [
    &["deodorizing"],
    &["deodorising"],
    &["deodorizing"],
    &["deodorising"],
];

pub(crate) static ENTRY_DEOXIDIZATIONS_1374490184286343040: VariantsMap = [
    &["deoxidizations"],
    &["deoxidisations"],
    &["deoxidizations"],
    &["deoxidisations"],
];

pub(crate) static ENTRY_DEOXIDIZATION_2952381442471631896: VariantsMap = [
    &["deoxidization"],
    &["deoxidisation"],
    &["deoxidization"],
    &["deoxidisation"],
];

pub(crate) static ENTRY_DEOXIDIZED_1342275632500355504: VariantsMap = [
    &["deoxidized"],
    &["deoxidised"],
    &["deoxidized"],
    &["deoxidised"],
];

pub(crate) static ENTRY_DEOXIDIZERS_2906487448450757563: VariantsMap = [
    &["deoxidizers"],
    &["deoxidisers"],
    &["deoxidizers"],
    &["deoxidisers"],
];

pub(crate) static ENTRY_DEOXIDIZER_553955836648748373: VariantsMap = [
    &["deoxidizer"],
    &["deoxidiser"],
    &["deoxidizer"],
    &["deoxidiser"],
];

pub(crate) static ENTRY_DEOXIDIZES_17882486098773443848: VariantsMap = [
    &["deoxidizes"],
    &["deoxidises"],
    &["deoxidizes"],
    &["deoxidises"],
];

pub(crate) static ENTRY_DEOXIDIZE_2568727168916119326: VariantsMap = [
    &["deoxidize"],
    &["deoxidise"],
    &["deoxidize"],
    &["deoxidise"],
];

pub(crate) static ENTRY_DEOXIDIZING_7425951821093112332: VariantsMap = [
    &["deoxidizing"],
    &["deoxidising"],
    &["deoxidizing"],
    &["deoxidising"],
];

pub(crate) static ENTRY_DEOXYGENIZED_9843329803418032730: VariantsMap = [
    &["deoxygenized"],
    &["deoxygenised"],
    &["deoxygenized"],
    &["deoxygenised"],
];

pub(crate) static ENTRY_DEOXYGENIZES_11294607905996274671: VariantsMap = [
    &["deoxygenizes"],
    &["deoxygenises"],
    &["deoxygenizes"],
    &["deoxygenises"],
];

pub(crate) static ENTRY_DEOXYGENIZE_615158521240619189: VariantsMap = [
    &["deoxygenize"],
    &["deoxygenise"],
    &["deoxygenize"],
    &["deoxygenise"],
];

pub(crate) static ENTRY_DEOXYGENIZING_13700570458079855816: VariantsMap = [
    &["deoxygenizing"],
    &["deoxygenising"],
    &["deoxygenizing"],
    &["deoxygenising"],
];

pub(crate) static ENTRY_DEPARTMENTALIZATIONS_12433036246957322206: VariantsMap = [
    &["departmentalizations"],
    &["departmentalisations"],
    &["departmentalizations"],
    &["departmentalisations"],
];

pub(crate) static ENTRY_DEPARTMENTALIZATION_16732736631808006231: VariantsMap = [
    &["departmentalization"],
    &["departmentalisation"],
    &["departmentalization"],
    &["departmentalisation"],
];

pub(crate) static ENTRY_DEPARTMENTALIZED_6440346371168938642: VariantsMap = [
    &["departmentalized"],
    &["departmentalised"],
    &["departmentalized"],
    &["departmentalised"],
];

pub(crate) static ENTRY_DEPARTMENTALIZES_5200360728452577607: VariantsMap = [
    &["departmentalizes"],
    &["departmentalises"],
    &["departmentalizes"],
    &["departmentalises"],
];

pub(crate) static ENTRY_DEPARTMENTALIZE_12544989001599465845: VariantsMap = [
    &["departmentalize"],
    &["departmentalise"],
    &["departmentalize"],
    &["departmentalise"],
];

pub(crate) static ENTRY_DEPARTMENTALIZING_14933842151249052929: VariantsMap = [
    &["departmentalizing"],
    &["departmentalising"],
    &["departmentalizing"],
    &["departmentalising"],
];

pub(crate) static ENTRY_DEPARTMENTIZATIONS_17612652463821022551: VariantsMap = [
    &["departmentizations"],
    &["departmentisations"],
    &["departmentizations"],
    &["departmentisations"],
];

pub(crate) static ENTRY_DEPARTMENTIZATION_9861192684661133651: VariantsMap = [
    &["departmentization"],
    &["departmentisation"],
    &["departmentization"],
    &["departmentisation"],
];

pub(crate) static ENTRY_DEPARTMENTIZES_12817610265677063578: VariantsMap = [
    &["departmentizes"],
    &["departmentises"],
    &["departmentizes"],
    &["departmentises"],
];

pub(crate) static ENTRY_DEPARTMENTIZE_5108687202401260993: VariantsMap = [
    &["departmentize"],
    &["departmentise"],
    &["departmentize"],
    &["departmentise"],
];

pub(crate) static ENTRY_DEPAUPERIZATION_5277909277167873828: VariantsMap = [
    &["depauperization"],
    &["depauperisation"],
    &["depauperization"],
    &["depauperisation"],
];

pub(crate) static ENTRY_DEPAUPERIZED_10522496344063518401: VariantsMap = [
    &["depauperized"],
    &["depauperised"],
    &["depauperized"],
    &["depauperised"],
];

pub(crate) static ENTRY_DEPAUPERIZES_7048735608776554840: VariantsMap = [
    &["depauperizes"],
    &["depauperises"],
    &["depauperizes"],
    &["depauperises"],
];

pub(crate) static ENTRY_DEPAUPERIZE_12233319978058773389: VariantsMap = [
    &["depauperize"],
    &["depauperise"],
    &["depauperize"],
    &["depauperise"],
];

pub(crate) static ENTRY_DEPAUPERIZING_1140611640524607577: VariantsMap = [
    &["depauperizing"],
    &["depauperising"],
    &["depauperizing"],
    &["depauperising"],
];

pub(crate) static ENTRY_DEPENDENCES_4898857694362268650: VariantsMap = [
    &["dependences"],
    &["dependences"],
    &["dependences"],
    &["dependences"],
];

pub(crate) static ENTRY_DEPENDENCE_2975032857660330940: VariantsMap = [
    &["dependence"],
    &["dependence"],
    &["dependence"],
    &["dependence"],
];

pub(crate) static ENTRY_DEPENDENTS_6484680412761939586: VariantsMap = [
    &["dependents"],
    &["dependants"],
    &["dependants"],
    &["dependants"],
];

pub(crate) static ENTRY_DEPENDENT_15548837712937438814: VariantsMap = [
    &["dependent"],
    &["dependant"],
    &["dependant"],
    &["dependant"],
];

pub(crate) static ENTRY_DEPERSONALIZATIONS_13800546258710189283: VariantsMap = [
    &["depersonalizations"],
    &["depersonalisations"],
    &["depersonalizations"],
    &["depersonalisations"],
];

pub(crate) static ENTRY_DEPERSONALIZATION_3798571196825324317: VariantsMap = [
    &["depersonalization"],
    &["depersonalisation"],
    &["depersonalization"],
    &["depersonalisation"],
];

pub(crate) static ENTRY_DEPERSONALIZED_4395700992531987338: VariantsMap = [
    &["depersonalized"],
    &["depersonalised"],
    &["depersonalized"],
    &["depersonalised"],
];

pub(crate) static ENTRY_DEPERSONALIZES_2561116931316488871: VariantsMap = [
    &["depersonalizes"],
    &["depersonalises"],
    &["depersonalizes"],
    &["depersonalises"],
];

pub(crate) static ENTRY_DEPERSONALIZE_6577935583661707932: VariantsMap = [
    &["depersonalize"],
    &["depersonalise"],
    &["depersonalize"],
    &["depersonalise"],
];

pub(crate) static ENTRY_DEPERSONALIZING_12778802923540312835: VariantsMap = [
    &["depersonalizing"],
    &["depersonalising"],
    &["depersonalizing"],
    &["depersonalising"],
];

pub(crate) static ENTRY_DEPOLARIZATIONS_16752636127743385337: VariantsMap = [
    &["depolarizations"],
    &["depolarisations"],
    &["depolarizations"],
    &["depolarisations"],
];

pub(crate) static ENTRY_DEPOLARIZATION_15774978100153361770: VariantsMap = [
    &["depolarization"],
    &["depolarisation"],
    &["depolarization"],
    &["depolarisation"],
];

pub(crate) static ENTRY_DEPOLARIZED_377191566140430593: VariantsMap = [
    &["depolarized"],
    &["depolarised"],
    &["depolarized"],
    &["depolarised"],
];

pub(crate) static ENTRY_DEPOLARIZERS_13304033375550399462: VariantsMap = [
    &["depolarizers"],
    &["depolarisers"],
    &["depolarizers"],
    &["depolarisers"],
];

pub(crate) static ENTRY_DEPOLARIZER_2090825138581959491: VariantsMap = [
    &["depolarizer"],
    &["depolariser"],
    &["depolarizer"],
    &["depolariser"],
];

pub(crate) static ENTRY_DEPOLARIZES_3226445999634432202: VariantsMap = [
    &["depolarizes"],
    &["depolarises"],
    &["depolarizes"],
    &["depolarises"],
];

pub(crate) static ENTRY_DEPOLARIZE_14265169874625051800: VariantsMap = [
    &["depolarize"],
    &["depolarise"],
    &["depolarize"],
    &["depolarise"],
];

pub(crate) static ENTRY_DEPOLARIZING_5347205347171321160: VariantsMap = [
    &["depolarizing"],
    &["depolarising"],
    &["depolarizing"],
    &["depolarising"],
];

pub(crate) static ENTRY_DEPOLITICIZATION_15265110179231465481: VariantsMap = [
    &["depoliticization"],
    &["depoliticisation"],
    &["depoliticization"],
    &["depoliticisation"],
];

pub(crate) static ENTRY_DEPOLITICIZED_17235888679911223431: VariantsMap = [
    &["depoliticized"],
    &["depoliticised"],
    &["depoliticized"],
    &["depoliticised"],
];

pub(crate) static ENTRY_DEPOLITICIZES_13700298543339019300: VariantsMap = [
    &["depoliticizes"],
    &["depoliticises"],
    &["depoliticizes"],
    &["depoliticises"],
];

pub(crate) static ENTRY_DEPOLITICIZE_7370960578004693927: VariantsMap = [
    &["depoliticize"],
    &["depoliticise"],
    &["depoliticize"],
    &["depoliticise"],
];

pub(crate) static ENTRY_DEPOLITICIZING_2647277921869165326: VariantsMap = [
    &["depoliticizing"],
    &["depoliticising"],
    &["depoliticizing"],
    &["depoliticising"],
];

pub(crate) static ENTRY_DEPOLYMERIZATIONS_11969399143532196145: VariantsMap = [
    &["depolymerizations"],
    &["depolymerisations"],
    &["depolymerizations"],
    &["depolymerisations"],
];

pub(crate) static ENTRY_DEPOLYMERIZATION_3633275984619877932: VariantsMap = [
    &["depolymerization"],
    &["depolymerisation"],
    &["depolymerization"],
    &["depolymerisation"],
];

pub(crate) static ENTRY_DEPOLYMERIZED_3571703505928412135: VariantsMap = [
    &["depolymerized"],
    &["depolymerised"],
    &["depolymerized"],
    &["depolymerised"],
];

pub(crate) static ENTRY_DEPOLYMERIZES_18366430796592539914: VariantsMap = [
    &["depolymerizes"],
    &["depolymerises"],
    &["depolymerizes"],
    &["depolymerises"],
];

pub(crate) static ENTRY_DEPOLYMERIZE_17116091341951567184: VariantsMap = [
    &["depolymerize"],
    &["depolymerise"],
    &["depolymerize"],
    &["depolymerise"],
];

pub(crate) static ENTRY_DEPOLYMERIZING_4657392775383874483: VariantsMap = [
    &["depolymerizing"],
    &["depolymerising"],
    &["depolymerizing"],
    &["depolymerising"],
];

pub(crate) static ENTRY_DEPRESSURIZATIONS_3229591287232610524: VariantsMap = [
    &["depressurizations"],
    &["depressurisations"],
    &["depressurizations"],
    &["depressurisations"],
];

pub(crate) static ENTRY_DEPRESSURIZATION_10217952263080064818: VariantsMap = [
    &["depressurization"],
    &["depressurisation"],
    &["depressurization"],
    &["depressurisation"],
];

pub(crate) static ENTRY_DEPRESSURIZED_4661479933134951890: VariantsMap = [
    &["depressurized"],
    &["depressurised"],
    &["depressurized"],
    &["depressurised"],
];

pub(crate) static ENTRY_DEPRESSURIZES_6344315569910956899: VariantsMap = [
    &["depressurizes"],
    &["depressurises"],
    &["depressurizes"],
    &["depressurises"],
];

pub(crate) static ENTRY_DEPRESSURIZE_4006202201627920697: VariantsMap = [
    &["depressurize"],
    &["depressurise"],
    &["depressurize"],
    &["depressurise"],
];

pub(crate) static ENTRY_DEPRESSURIZING_309386769136380221: VariantsMap = [
    &["depressurizing"],
    &["depressurising"],
    &["depressurizing"],
    &["depressurising"],
];

pub(crate) static ENTRY_DEPUTATIONIZES_18170818538991682534: VariantsMap = [
    &["deputationizes"],
    &["deputationises"],
    &["deputationizes"],
    &["deputationises"],
];

pub(crate) static ENTRY_DEPUTATIONIZE_11714259026529794497: VariantsMap = [
    &["deputationize"],
    &["deputationise"],
    &["deputationize"],
    &["deputationise"],
];

pub(crate) static ENTRY_DEPUTIZATION_11869337893120725807: VariantsMap = [
    &["deputization"],
    &["deputisation"],
    &["deputization"],
    &["deputisation"],
];

pub(crate) static ENTRY_DEPUTIZED_15591871669346119917: VariantsMap = [
    &["deputized"],
    &["deputised"],
    &["deputized"],
    &["deputised"],
];

pub(crate) static ENTRY_DEPUTIZES_16885595381873833095: VariantsMap = [
    &["deputizes"],
    &["deputises"],
    &["deputizes"],
    &["deputises"],
];

pub(crate) static ENTRY_DEPUTIZE_14708452402802592517: VariantsMap =
    [&["deputize"], &["deputise"], &["deputize"], &["deputise"]];

pub(crate) static ENTRY_DEPUTIZING_11731565191775615613: VariantsMap = [
    &["deputizing"],
    &["deputising"],
    &["deputizing"],
    &["deputising"],
];

pub(crate) static ENTRY_DERACIALIZED_4376882873641183994: VariantsMap = [
    &["deracialized"],
    &["deracialised"],
    &["deracialized"],
    &["deracialised"],
];

pub(crate) static ENTRY_DERACIALIZES_13294967594818824381: VariantsMap = [
    &["deracializes"],
    &["deracialises"],
    &["deracializes"],
    &["deracialises"],
];

pub(crate) static ENTRY_DERACIALIZE_9783084937607989481: VariantsMap = [
    &["deracialize"],
    &["deracialise"],
    &["deracialize"],
    &["deracialise"],
];

pub(crate) static ENTRY_DERACIALIZING_317834154241325652: VariantsMap = [
    &["deracializing"],
    &["deracialising"],
    &["deracializing"],
    &["deracialising"],
];

pub(crate) static ENTRY_DERATIONALIZATIONS_4307467050402784753: VariantsMap = [
    &["derationalizations"],
    &["derationalisations"],
    &["derationalizations"],
    &["derationalisations"],
];

pub(crate) static ENTRY_DERATIONALIZATION_3932130518301875356: VariantsMap = [
    &["derationalization"],
    &["derationalisation"],
    &["derationalization"],
    &["derationalisation"],
];

pub(crate) static ENTRY_DERATIONALIZES_11244440347288615996: VariantsMap = [
    &["derationalizes"],
    &["derationalises"],
    &["derationalizes"],
    &["derationalises"],
];

pub(crate) static ENTRY_DERATIONALIZE_15378847943662042149: VariantsMap = [
    &["derationalize"],
    &["derationalise"],
    &["derationalize"],
    &["derationalise"],
];

pub(crate) static ENTRY_DERATIZATIONS_2572923369998003352: VariantsMap = [
    &["deratizations"],
    &["deratisations"],
    &["deratizations"],
    &["deratisations"],
];

pub(crate) static ENTRY_DERATIZATION_13362911385856325847: VariantsMap = [
    &["deratization"],
    &["deratisation"],
    &["deratization"],
    &["deratisation"],
];

pub(crate) static ENTRY_DEREALIZATION_9432370619252273879: VariantsMap = [
    &["derealization"],
    &["derealisation"],
    &["derealization"],
    &["derealisation"],
];

pub(crate) static ENTRY_DERECOGNIZED_960138435617857980: VariantsMap = [
    &["derecognized"],
    &["derecognised"],
    &["derecognized"],
    &["derecognised"],
];

pub(crate) static ENTRY_DERECOGNIZES_11433993209056588186: VariantsMap = [
    &["derecognizes"],
    &["derecognises"],
    &["derecognizes"],
    &["derecognises"],
];

pub(crate) static ENTRY_DERECOGNIZE_2343806536593988088: VariantsMap = [
    &["derecognize"],
    &["derecognise"],
    &["derecognize"],
    &["derecognise"],
];

pub(crate) static ENTRY_DERECOGNIZING_8878118177062532050: VariantsMap = [
    &["derecognizing"],
    &["derecognising"],
    &["derecognizing"],
    &["derecognising"],
];

pub(crate) static ENTRY_DEREGULATIONIZES_6565341939253019114: VariantsMap = [
    &["deregulationizes"],
    &["deregulationises"],
    &["deregulationizes"],
    &["deregulationises"],
];

pub(crate) static ENTRY_DEREGULATIONIZE_17362959656302764932: VariantsMap = [
    &["deregulationize"],
    &["deregulationise"],
    &["deregulationize"],
    &["deregulationise"],
];

pub(crate) static ENTRY_DERELIGIONIZED_17203995608182086867: VariantsMap = [
    &["dereligionized"],
    &["dereligionised"],
    &["dereligionized"],
    &["dereligionised"],
];

pub(crate) static ENTRY_DERELIGIONIZES_4132296307299375253: VariantsMap = [
    &["dereligionizes"],
    &["dereligionises"],
    &["dereligionizes"],
    &["dereligionises"],
];

pub(crate) static ENTRY_DERELIGIONIZE_2435879930867823358: VariantsMap = [
    &["dereligionize"],
    &["dereligionise"],
    &["dereligionize"],
    &["dereligionise"],
];

pub(crate) static ENTRY_DERELIGIONIZING_284672108011662731: VariantsMap = [
    &["dereligionizing"],
    &["dereligionising"],
    &["dereligionizing"],
    &["dereligionising"],
];

pub(crate) static ENTRY_DERK_4188156948801172154: VariantsMap =
    [&["derk"], &["drek"], &["drek"], &["drek"]];

pub(crate) static ENTRY_DERMATORRHEA_13737380613591936019: VariantsMap = [
    &["dermatorrhea"],
    &["dermatorrhoea"],
    &["dermatorrhoea"],
    &["dermatorrhoea"],
];

pub(crate) static ENTRY_DERR_9116132351167601479: VariantsMap =
    [&["derr"], &["drer"], &["drer"], &["drer"]];

pub(crate) static ENTRY_DESACRALIZATIONS_12761956333453162715: VariantsMap = [
    &["desacralizations"],
    &["desacralisations"],
    &["desacralizations"],
    &["desacralisations"],
];

pub(crate) static ENTRY_DESACRALIZATION_6663446605605284221: VariantsMap = [
    &["desacralization"],
    &["desacralisation"],
    &["desacralization"],
    &["desacralisation"],
];

pub(crate) static ENTRY_DESACRALIZED_3102194836021935643: VariantsMap = [
    &["desacralized"],
    &["desacralised"],
    &["desacralized"],
    &["desacralised"],
];

pub(crate) static ENTRY_DESACRALIZES_17016027804952998366: VariantsMap = [
    &["desacralizes"],
    &["desacralises"],
    &["desacralizes"],
    &["desacralises"],
];

pub(crate) static ENTRY_DESACRALIZE_17692095792097093691: VariantsMap = [
    &["desacralize"],
    &["desacralise"],
    &["desacralize"],
    &["desacralise"],
];

pub(crate) static ENTRY_DESACRALIZING_8095563156338258250: VariantsMap = [
    &["desacralizing"],
    &["desacralising"],
    &["desacralizing"],
    &["desacralising"],
];

pub(crate) static ENTRY_DESALINIZATIONS_1947156449217935933: VariantsMap = [
    &["desalinizations"],
    &["desalinisations"],
    &["desalinizations"],
    &["desalinisations"],
];

pub(crate) static ENTRY_DESALINIZATION_18136851436548406134: VariantsMap = [
    &["desalinization"],
    &["desalinisation"],
    &["desalinization"],
    &["desalinisation"],
];

pub(crate) static ENTRY_DESALINIZED_787514518667266596: VariantsMap = [
    &["desalinized"],
    &["desalinised"],
    &["desalinized"],
    &["desalinised"],
];

pub(crate) static ENTRY_DESALINIZES_3392036422321879852: VariantsMap = [
    &["desalinizes"],
    &["desalinises"],
    &["desalinizes"],
    &["desalinises"],
];

pub(crate) static ENTRY_DESALINIZE_15580269981634714244: VariantsMap = [
    &["desalinize"],
    &["desalinise"],
    &["desalinize"],
    &["desalinise"],
];

pub(crate) static ENTRY_DESALINIZING_7600583977642503954: VariantsMap = [
    &["desalinizing"],
    &["desalinising"],
    &["desalinizing"],
    &["desalinising"],
];

pub(crate) static ENTRY_DESCENDANTS_15651999902366879600: VariantsMap = [
    &["descendants"],
    &["descendants"],
    &["descendants"],
    &["descendants"],
];

pub(crate) static ENTRY_DESENSITIZATIONS_2653162068724592823: VariantsMap = [
    &["desensitizations"],
    &["desensitisations"],
    &["desensitizations"],
    &["desensitisations"],
];

pub(crate) static ENTRY_DESENSITIZATION_6477425684013695224: VariantsMap = [
    &["desensitization"],
    &["desensitisation"],
    &["desensitization"],
    &["desensitisation"],
];

pub(crate) static ENTRY_DESENSITIZED_18060076779967037190: VariantsMap = [
    &["desensitized"],
    &["desensitised"],
    &["desensitized"],
    &["desensitised"],
];

pub(crate) static ENTRY_DESENSITIZERS_4492855637688265508: VariantsMap = [
    &["desensitizers"],
    &["desensitisers"],
    &["desensitizers"],
    &["desensitisers"],
];

pub(crate) static ENTRY_DESENSITIZER_17295084989835588516: VariantsMap = [
    &["desensitizer"],
    &["desensitiser"],
    &["desensitizer"],
    &["desensitiser"],
];

pub(crate) static ENTRY_DESENSITIZES_14085116376101022093: VariantsMap = [
    &["desensitizes"],
    &["desensitises"],
    &["desensitizes"],
    &["desensitises"],
];

pub(crate) static ENTRY_DESENSITIZE_7076278913280010375: VariantsMap = [
    &["desensitize"],
    &["desensitise"],
    &["desensitize"],
    &["desensitise"],
];

pub(crate) static ENTRY_DESENSITIZING_1861532716047418795: VariantsMap = [
    &["desensitizing"],
    &["desensitising"],
    &["desensitizing"],
    &["desensitising"],
];

pub(crate) static ENTRY_DESERTIZATIONS_13686869646615221507: VariantsMap = [
    &["desertizations"],
    &["desertisations"],
    &["desertizations"],
    &["desertisations"],
];

pub(crate) static ENTRY_DESERTIZATION_8322146084862234585: VariantsMap = [
    &["desertization"],
    &["desertisation"],
    &["desertization"],
    &["desertisation"],
];

pub(crate) static ENTRY_DESEXUALIZATIONS_13808942213186512101: VariantsMap = [
    &["desexualizations"],
    &["desexualisations"],
    &["desexualizations"],
    &["desexualisations"],
];

pub(crate) static ENTRY_DESEXUALIZATION_3533631506018024460: VariantsMap = [
    &["desexualization"],
    &["desexualisation"],
    &["desexualization"],
    &["desexualisation"],
];

pub(crate) static ENTRY_DESEXUALIZED_14697196652232596540: VariantsMap = [
    &["desexualized"],
    &["desexualised"],
    &["desexualized"],
    &["desexualised"],
];

pub(crate) static ENTRY_DESEXUALIZES_310153221369007273: VariantsMap = [
    &["desexualizes"],
    &["desexualises"],
    &["desexualizes"],
    &["desexualises"],
];

pub(crate) static ENTRY_DESEXUALIZE_1452349021755288588: VariantsMap = [
    &["desexualize"],
    &["desexualise"],
    &["desexualize"],
    &["desexualise"],
];

pub(crate) static ENTRY_DESEXUALIZING_12199543455593087481: VariantsMap = [
    &["desexualizing"],
    &["desexualising"],
    &["desexualizing"],
    &["desexualising"],
];

pub(crate) static ENTRY_DESILVERIZATIONS_3676328424316872989: VariantsMap = [
    &["desilverizations"],
    &["desilverisations"],
    &["desilverizations"],
    &["desilverisations"],
];

pub(crate) static ENTRY_DESILVERIZATION_9101345412818934981: VariantsMap = [
    &["desilverization"],
    &["desilverisation"],
    &["desilverization"],
    &["desilverisation"],
];

pub(crate) static ENTRY_DESILVERIZED_13381393077624925641: VariantsMap = [
    &["desilverized"],
    &["desilverised"],
    &["desilverized"],
    &["desilverised"],
];

pub(crate) static ENTRY_DESILVERIZES_12540224859423235308: VariantsMap = [
    &["desilverizes"],
    &["desilverises"],
    &["desilverizes"],
    &["desilverises"],
];

pub(crate) static ENTRY_DESILVERIZE_2584970706129191216: VariantsMap = [
    &["desilverize"],
    &["desilverise"],
    &["desilverize"],
    &["desilverise"],
];

pub(crate) static ENTRY_DESILVERIZING_17410306605308363953: VariantsMap = [
    &["desilverizing"],
    &["desilverising"],
    &["desilverizing"],
    &["desilverising"],
];

pub(crate) static ENTRY_DESPIRITUALIZATION_9166826348834973753: VariantsMap = [
    &["despiritualization"],
    &["despiritualisation"],
    &["despiritualization"],
    &["despiritualisation"],
];

pub(crate) static ENTRY_DESPIRITUALIZE_9957134782134537672: VariantsMap = [
    &["despiritualize"],
    &["despiritualise"],
    &["despiritualize"],
    &["despiritualise"],
];

pub(crate) static ENTRY_DESPOTIZES_11713728788148916724: VariantsMap = [
    &["despotizes"],
    &["despotises"],
    &["despotizes"],
    &["despotises"],
];

pub(crate) static ENTRY_DESPOTIZE_7723518336373467594: VariantsMap = [
    &["despotize"],
    &["despotise"],
    &["despotize"],
    &["despotise"],
];

pub(crate) static ENTRY_DESTABILIZATION_13317005930133883698: VariantsMap = [
    &["destabilization"],
    &["destabilisation"],
    &["destabilization"],
    &["destabilisation"],
];

pub(crate) static ENTRY_DESTABILIZED_798803001524481006: VariantsMap = [
    &["destabilized"],
    &["destabilised"],
    &["destabilized"],
    &["destabilised"],
];

pub(crate) static ENTRY_DESTABILIZERS_8507105907416838284: VariantsMap = [
    &["destabilizers"],
    &["destabilisers"],
    &["destabilizers"],
    &["destabilisers"],
];

pub(crate) static ENTRY_DESTABILIZER_10948885335030959608: VariantsMap = [
    &["destabilizer"],
    &["destabiliser"],
    &["destabilizer"],
    &["destabiliser"],
];

pub(crate) static ENTRY_DESTABILIZES_9175954977739946204: VariantsMap = [
    &["destabilizes"],
    &["destabilises"],
    &["destabilizes"],
    &["destabilises"],
];

pub(crate) static ENTRY_DESTABILIZE_6658582433887926026: VariantsMap = [
    &["destabilize"],
    &["destabilise"],
    &["destabilize"],
    &["destabilise"],
];

pub(crate) static ENTRY_DESTABILIZING_11313904175788895920: VariantsMap = [
    &["destabilizing"],
    &["destabilising"],
    &["destabilizing"],
    &["destabilising"],
];

pub(crate) static ENTRY_DESTALINIZED_17070618679462501180: VariantsMap = [
    &["destalinized"],
    &["destalinised"],
    &["destalinized"],
    &["destalinised"],
];

pub(crate) static ENTRY_DESTALINIZES_18175065567954168080: VariantsMap = [
    &["destalinizes"],
    &["destalinises"],
    &["destalinizes"],
    &["destalinises"],
];

pub(crate) static ENTRY_DESTALINIZE_12064490249878771919: VariantsMap = [
    &["destalinize"],
    &["destalinise"],
    &["destalinize"],
    &["destalinise"],
];

pub(crate) static ENTRY_DESTALINIZING_13590427920165160122: VariantsMap = [
    &["destalinizing"],
    &["destalinising"],
    &["destalinizing"],
    &["destalinising"],
];

pub(crate) static ENTRY_DESTERILIZE_11764632884497568500: VariantsMap = [
    &["desterilize"],
    &["desterilise"],
    &["desterilize"],
    &["desterilise"],
];

pub(crate) static ENTRY_DESTIGMATIZATION_7571753247806883930: VariantsMap = [
    &["destigmatization"],
    &["destigmatisation"],
    &["destigmatization"],
    &["destigmatisation"],
];

pub(crate) static ENTRY_DESULFURIZATIONS_2177003244823249071: VariantsMap = [
    &["desulfurizations"],
    &["desulphurisations"],
    &["desulphurizations"],
    &["desulphurisations"],
];

pub(crate) static ENTRY_DESULFURIZATION_7274801890477561400: VariantsMap = [
    &["desulfurization"],
    &["desulphurisation"],
    &["desulphurization"],
    &["desulphurisation"],
];

pub(crate) static ENTRY_DESULFURIZED_2406386063012452485: VariantsMap = [
    &["desulfurized"],
    &["desulphurised"],
    &["desulphurized"],
    &["desulphurised"],
];

pub(crate) static ENTRY_DESULFURIZER_6811111747434101705: VariantsMap = [
    &["desulfurizer"],
    &["desulfuriser"],
    &["desulfurizer"],
    &["desulfuriser"],
];

pub(crate) static ENTRY_DESULFURIZES_35072370079092901: VariantsMap = [
    &["desulfurizes"],
    &["desulphurises"],
    &["desulphurizes"],
    &["desulphurises"],
];

pub(crate) static ENTRY_DESULFURIZE_13186827014999009464: VariantsMap = [
    &["desulfurize"],
    &["desulphurise"],
    &["desulphurize"],
    &["desulphurise"],
];

pub(crate) static ENTRY_DESULFURIZING_15868123655289821047: VariantsMap = [
    &["desulfurizing"],
    &["desulphurising"],
    &["desulphurizing"],
    &["desulphurising"],
];

pub(crate) static ENTRY_DESULPHURIZERS_11557780828704734590: VariantsMap = [
    &["desulphurizers"],
    &["desulphurisers"],
    &["desulphurizers"],
    &["desulphurisers"],
];

pub(crate) static ENTRY_DESULPHURIZER_16216980596436245396: VariantsMap = [
    &["desulphurizer"],
    &["desulphuriser"],
    &["desulphurizer"],
    &["desulphuriser"],
];

pub(crate) static ENTRY_DESYNCHRONIZATIONS_16916238148674253682: VariantsMap = [
    &["desynchronizations"],
    &["desynchronisations"],
    &["desynchronizations"],
    &["desynchronisations"],
];

pub(crate) static ENTRY_DESYNCHRONIZATION_7571142988844086339: VariantsMap = [
    &["desynchronization"],
    &["desynchronisation"],
    &["desynchronization"],
    &["desynchronisation"],
];

pub(crate) static ENTRY_DESYNCHRONIZED_10677701267884215526: VariantsMap = [
    &["desynchronized"],
    &["desynchronised"],
    &["desynchronized"],
    &["desynchronised"],
];

pub(crate) static ENTRY_DESYNCHRONIZES_6662843521917179779: VariantsMap = [
    &["desynchronizes"],
    &["desynchronises"],
    &["desynchronizes"],
    &["desynchronises"],
];

pub(crate) static ENTRY_DESYNCHRONIZE_11372885649599375047: VariantsMap = [
    &["desynchronize"],
    &["desynchronise"],
    &["desynchronize"],
    &["desynchronise"],
];

pub(crate) static ENTRY_DESYNCHRONIZING_17223398467673868688: VariantsMap = [
    &["desynchronizing"],
    &["desynchronising"],
    &["desynchronizing"],
    &["desynchronising"],
];

pub(crate) static ENTRY_DETRIBALIZATIONS_10197716064139754204: VariantsMap = [
    &["detribalizations"],
    &["detribalisations"],
    &["detribalizations"],
    &["detribalisations"],
];

pub(crate) static ENTRY_DETRIBALIZATION_1652215190238627536: VariantsMap = [
    &["detribalization"],
    &["detribalisation"],
    &["detribalization"],
    &["detribalisation"],
];

pub(crate) static ENTRY_DETRIBALIZED_8262386414888942658: VariantsMap = [
    &["detribalized"],
    &["detribalised"],
    &["detribalized"],
    &["detribalised"],
];

pub(crate) static ENTRY_DETRIBALIZES_10964606572749162711: VariantsMap = [
    &["detribalizes"],
    &["detribalises"],
    &["detribalizes"],
    &["detribalises"],
];

pub(crate) static ENTRY_DETRIBALIZE_1614085836292794906: VariantsMap = [
    &["detribalize"],
    &["detribalise"],
    &["detribalize"],
    &["detribalise"],
];

pub(crate) static ENTRY_DETRIBALIZING_4078840495989197779: VariantsMap = [
    &["detribalizing"],
    &["detribalising"],
    &["detribalizing"],
    &["detribalising"],
];

pub(crate) static ENTRY_DEVALORIZATIONS_3733441228994839656: VariantsMap = [
    &["devalorizations"],
    &["devalorisations"],
    &["devalorizations"],
    &["devalorisations"],
];

pub(crate) static ENTRY_DEVALORIZATION_263183622783279423: VariantsMap = [
    &["devalorization"],
    &["devalorisation"],
    &["devalorization"],
    &["devalorisation"],
];

pub(crate) static ENTRY_DEVALORIZED_3035715402231659393: VariantsMap = [
    &["devalorized"],
    &["devalorised"],
    &["devalorized"],
    &["devalorised"],
];

pub(crate) static ENTRY_DEVALORIZES_11252089261618256450: VariantsMap = [
    &["devalorizes"],
    &["devalorises"],
    &["devalorizes"],
    &["devalorises"],
];

pub(crate) static ENTRY_DEVALORIZE_3441956694235575978: VariantsMap = [
    &["devalorize"],
    &["devalorise"],
    &["devalorize"],
    &["devalorise"],
];

pub(crate) static ENTRY_DEVALORIZING_576941735937016987: VariantsMap = [
    &["devalorizing"],
    &["devalorising"],
    &["devalorizing"],
    &["devalorising"],
];

pub(crate) static ENTRY_DEVA_17913294961213511390: VariantsMap =
    [&["deva"], &["daeva"], &["daeva"], &["daeva"]];

pub(crate) static ENTRY_DEVELED_2772420296503800249: VariantsMap =
    [&["develed"], &["develled"], &["develled"], &["develled"]];

pub(crate) static ENTRY_DEVELING_5035027030513600653: VariantsMap = [
    &["develing"],
    &["develling"],
    &["develling"],
    &["develling"],
];

pub(crate) static ENTRY_DEVILED_3048829577081044907: VariantsMap =
    [&["deviled"], &["devilled"], &["devilled"], &["devilled"]];

pub(crate) static ENTRY_DEVILING_2852485461150693530: VariantsMap = [
    &["deviling"],
    &["devilling"],
    &["devilling"],
    &["devilling"],
];

pub(crate) static ENTRY_DEVILIZES_2252795004975721973: VariantsMap = [
    &["devilizes"],
    &["devilises"],
    &["devilizes"],
    &["devilises"],
];

pub(crate) static ENTRY_DEVILIZE_1860871339294390376: VariantsMap =
    [&["devilize"], &["devilise"], &["devilize"], &["devilise"]];

pub(crate) static ENTRY_DEVITALIZATIONS_1168911391057981701: VariantsMap = [
    &["devitalizations"],
    &["devitalisations"],
    &["devitalizations"],
    &["devitalisations"],
];

pub(crate) static ENTRY_DEVITALIZATION_15852094530751489673: VariantsMap = [
    &["devitalization"],
    &["devitalisation"],
    &["devitalization"],
    &["devitalisation"],
];

pub(crate) static ENTRY_DEVITALIZED_2614953819800812061: VariantsMap = [
    &["devitalized"],
    &["devitalised"],
    &["devitalized"],
    &["devitalised"],
];

pub(crate) static ENTRY_DEVITALIZES_8740304697698136600: VariantsMap = [
    &["devitalizes"],
    &["devitalises"],
    &["devitalizes"],
    &["devitalises"],
];

pub(crate) static ENTRY_DEVITALIZE_5134304117244312868: VariantsMap = [
    &["devitalize"],
    &["devitalise"],
    &["devitalize"],
    &["devitalise"],
];

pub(crate) static ENTRY_DEVITALIZING_432513802469216184: VariantsMap = [
    &["devitalizing"],
    &["devitalising"],
    &["devitalizing"],
    &["devitalising"],
];

pub(crate) static ENTRY_DEVOCALIZATION_1702123344804371213: VariantsMap = [
    &["devocalization"],
    &["devocalisation"],
    &["devocalization"],
    &["devocalisation"],
];

pub(crate) static ENTRY_DEVOCALIZED_1211021425952943044: VariantsMap = [
    &["devocalized"],
    &["devocalised"],
    &["devocalized"],
    &["devocalised"],
];

pub(crate) static ENTRY_DEVOCALIZES_17642417100083990068: VariantsMap = [
    &["devocalizes"],
    &["devocalises"],
    &["devocalizes"],
    &["devocalises"],
];

pub(crate) static ENTRY_DEVOCALIZE_2685272297865524074: VariantsMap = [
    &["devocalize"],
    &["devocalise"],
    &["devocalize"],
    &["devocalise"],
];

pub(crate) static ENTRY_DEVOCALIZING_10482039920211385501: VariantsMap = [
    &["devocalizing"],
    &["devocalising"],
    &["devocalizing"],
    &["devocalising"],
];

pub(crate) static ENTRY_DEVOLATILIZATIONS_1986930233175031782: VariantsMap = [
    &["devolatilizations"],
    &["devolatilisations"],
    &["devolatilizations"],
    &["devolatilisations"],
];

pub(crate) static ENTRY_DEVOLATILIZATION_15274887322161140461: VariantsMap = [
    &["devolatilization"],
    &["devolatilisation"],
    &["devolatilization"],
    &["devolatilisation"],
];

pub(crate) static ENTRY_DEVOLATILIZED_13031211289203336444: VariantsMap = [
    &["devolatilized"],
    &["devolatilised"],
    &["devolatilized"],
    &["devolatilised"],
];

pub(crate) static ENTRY_DEVOLATILIZES_1833448326954504353: VariantsMap = [
    &["devolatilizes"],
    &["devolatilises"],
    &["devolatilizes"],
    &["devolatilises"],
];

pub(crate) static ENTRY_DEVOLATILIZE_6367186675206777835: VariantsMap = [
    &["devolatilize"],
    &["devolatilise"],
    &["devolatilize"],
    &["devolatilise"],
];

pub(crate) static ENTRY_DEVOLATILIZING_16426756662834727247: VariantsMap = [
    &["devolatilizing"],
    &["devolatilising"],
    &["devolatilizing"],
    &["devolatilising"],
];

pub(crate) static ENTRY_DIABOLIZATIONS_16583315643649032340: VariantsMap = [
    &["diabolizations"],
    &["diabolisations"],
    &["diabolizations"],
    &["diabolisations"],
];

pub(crate) static ENTRY_DIABOLIZATION_1363887125114685904: VariantsMap = [
    &["diabolization"],
    &["diabolisation"],
    &["diabolization"],
    &["diabolisation"],
];

pub(crate) static ENTRY_DIABOLIZED_11064715463315482252: VariantsMap = [
    &["diabolized"],
    &["diabolised"],
    &["diabolized"],
    &["diabolised"],
];

pub(crate) static ENTRY_DIABOLIZES_1852822825341821570: VariantsMap = [
    &["diabolizes"],
    &["diabolises"],
    &["diabolizes"],
    &["diabolises"],
];

pub(crate) static ENTRY_DIABOLIZE_7558206233001066545: VariantsMap = [
    &["diabolize"],
    &["diabolise"],
    &["diabolize"],
    &["diabolise"],
];

pub(crate) static ENTRY_DIABOLIZING_15636021241322694053: VariantsMap = [
    &["diabolizing"],
    &["diabolising"],
    &["diabolizing"],
    &["diabolising"],
];

pub(crate) static ENTRY_DIAGONALIZABLE_2762017719834849456: VariantsMap = [
    &["diagonalizable"],
    &["diagonalisable"],
    &["diagonalizable"],
    &["diagonalisable"],
];

pub(crate) static ENTRY_DIAGONALIZATION_6595403545220372020: VariantsMap = [
    &["diagonalization"],
    &["diagonalisation"],
    &["diagonalization"],
    &["diagonalisation"],
];

pub(crate) static ENTRY_DIAGONALIZED_17579955084907080650: VariantsMap = [
    &["diagonalized"],
    &["diagonalised"],
    &["diagonalized"],
    &["diagonalised"],
];

pub(crate) static ENTRY_DIAGONALIZES_15254037472689690498: VariantsMap = [
    &["diagonalizes"],
    &["diagonalises"],
    &["diagonalizes"],
    &["diagonalises"],
];

pub(crate) static ENTRY_DIAGONALIZE_17904977846869341160: VariantsMap = [
    &["diagonalize"],
    &["diagonalise"],
    &["diagonalize"],
    &["diagonalise"],
];

pub(crate) static ENTRY_DIAGONALIZING_13586424289506988897: VariantsMap = [
    &["diagonalizing"],
    &["diagonalising"],
    &["diagonalizing"],
    &["diagonalising"],
];

pub(crate) static ENTRY_DIALECTICIZES_6038135739665968964: VariantsMap = [
    &["dialecticizes"],
    &["dialecticises"],
    &["dialecticizes"],
    &["dialecticises"],
];

pub(crate) static ENTRY_DIALECTICIZE_12501453537726971128: VariantsMap = [
    &["dialecticize"],
    &["dialecticise"],
    &["dialecticize"],
    &["dialecticise"],
];

pub(crate) static ENTRY_DIALED_8624721026195652691: VariantsMap =
    [&["dialed"], &["dialled"], &["dialed"], &["dialled"]];

pub(crate) static ENTRY_DIALERS_106036826415288726: VariantsMap =
    [&["dialers"], &["diallers"], &["diallers"], &["diallers"]];

pub(crate) static ENTRY_DIALER_12144421429152334948: VariantsMap =
    [&["dialer"], &["dialler"], &["dialler"], &["dialler"]];

pub(crate) static ENTRY_DIALINGS_16812342776213308353: VariantsMap =
    [&["dialings"], &["diallings"], &["dialings"], &["diallings"]];

pub(crate) static ENTRY_DIALING_14894824825058184021: VariantsMap =
    [&["dialing"], &["dialling"], &["dialing"], &["dialling"]];

pub(crate) static ENTRY_DIALISTS_11507803815872945664: VariantsMap = [
    &["dialists"],
    &["diallists"],
    &["diallists"],
    &["diallists"],
];

pub(crate) static ENTRY_DIALIST_4516170084506307202: VariantsMap =
    [&["dialist"], &["diallist"], &["diallist"], &["diallist"]];

pub(crate) static ENTRY_DIALOGIZED_2130998845263727006: VariantsMap = [
    &["dialogized"],
    &["dialogised"],
    &["dialogized"],
    &["dialogised"],
];

pub(crate) static ENTRY_DIALOGIZES_15128492515715378027: VariantsMap = [
    &["dialogizes"],
    &["dialogises"],
    &["dialogizes"],
    &["dialogises"],
];

pub(crate) static ENTRY_DIALOGIZE_12108565015252354953: VariantsMap = [
    &["dialogize"],
    &["dialogise"],
    &["dialogize"],
    &["dialogise"],
];

pub(crate) static ENTRY_DIALOGIZING_16954032865785818920: VariantsMap = [
    &["dialogizing"],
    &["dialogising"],
    &["dialogizing"],
    &["dialogising"],
];

pub(crate) static ENTRY_DIALOGUED_6096361692015426802: VariantsMap = [
    &["dialogued"],
    &["dialogued"],
    &["dialogued"],
    &["dialogued"],
];

pub(crate) static ENTRY_DIALOGUES_11293834938019836177: VariantsMap = [
    &["dialogues"],
    &["dialogues"],
    &["dialogues"],
    &["dialogues"],
];

pub(crate) static ENTRY_DIALOGUING_11388291889533762516: VariantsMap = [
    &["dialoguing"],
    &["dialoguing"],
    &["dialoguing"],
    &["dialoguing"],
];

pub(crate) static ENTRY_DIALYZABILITIES_7999248871142067536: VariantsMap = [
    &["dialyzabilities"],
    &["dialysabilities"],
    &["dialysabilities"],
    &["dialysabilities"],
];

pub(crate) static ENTRY_DIALYZABILITY_6815030337453867720: VariantsMap = [
    &["dialyzability"],
    &["dialysability"],
    &["dialysability"],
    &["dialysability"],
];

pub(crate) static ENTRY_DIALYZABLER_15208921974675203583: VariantsMap = [
    &["dialyzabler"],
    &["dialysabler"],
    &["dialysabler"],
    &["dialysabler"],
];

pub(crate) static ENTRY_DIALYZABLEST_11000318458472685986: VariantsMap = [
    &["dialyzablest"],
    &["dialysablest"],
    &["dialysablest"],
    &["dialysablest"],
];

pub(crate) static ENTRY_DIALYZABLES_6376554827966008616: VariantsMap = [
    &["dialyzables"],
    &["dialysables"],
    &["dialysables"],
    &["dialysables"],
];

pub(crate) static ENTRY_DIALYZABLE_17385568374012534569: VariantsMap = [
    &["dialyzable"],
    &["dialysable"],
    &["dialysable"],
    &["dialysable"],
];

pub(crate) static ENTRY_DIALYZATES_13362126314458712842: VariantsMap = [
    &["dialyzates"],
    &["dialysates"],
    &["dialyzates"],
    &["dialysates"],
];

pub(crate) static ENTRY_DIALYZATE_2109777769298374812: VariantsMap = [
    &["dialyzate"],
    &["dialysate"],
    &["dialyzate"],
    &["dialysate"],
];

pub(crate) static ENTRY_DIALYZATION_7430305913509943439: VariantsMap = [
    &["dialyzation"],
    &["dialysation"],
    &["dialyzation"],
    &["dialysation"],
];

pub(crate) static ENTRY_DIALYZED_14166787736891210495: VariantsMap =
    [&["dialyzed"], &["dialysed"], &["dialyzed"], &["dialysed"]];

pub(crate) static ENTRY_DIALYZERS_11015093780016815012: VariantsMap = [
    &["dialyzers"],
    &["dialysers"],
    &["dialyzers"],
    &["dialysers"],
];

pub(crate) static ENTRY_DIALYZER_17215496811652992094: VariantsMap =
    [&["dialyzer"], &["dialyser"], &["dialyzer"], &["dialyser"]];

pub(crate) static ENTRY_DIALYZES_7300597766358786533: VariantsMap =
    [&["dialyzes"], &["dialyses"], &["dialyzes"], &["dialyses"]];

pub(crate) static ENTRY_DIALYZE_1688147137734168562: VariantsMap =
    [&["dialyze"], &["dialyse"], &["dialyze"], &["dialyse"]];

pub(crate) static ENTRY_DIALYZING_14844209232520540927: VariantsMap = [
    &["dialyzing"],
    &["dialysing"],
    &["dialyzing"],
    &["dialysing"],
];

pub(crate) static ENTRY_DIAMONDIZES_14251466086938482305: VariantsMap = [
    &["diamondizes"],
    &["diamondises"],
    &["diamondizes"],
    &["diamondises"],
];

pub(crate) static ENTRY_DIAMONDIZE_6182158864087976989: VariantsMap = [
    &["diamondize"],
    &["diamondise"],
    &["diamondize"],
    &["diamondise"],
];

pub(crate) static ENTRY_DIARIZED_14821458016432673364: VariantsMap =
    [&["diarized"], &["diarised"], &["diarized"], &["diarised"]];

pub(crate) static ENTRY_DIARIZES_4127995912600199105: VariantsMap =
    [&["diarizes"], &["diarises"], &["diarizes"], &["diarises"]];

pub(crate) static ENTRY_DIARIZE_2138954015204333925: VariantsMap =
    [&["diarize"], &["diarise"], &["diarize"], &["diarise"]];

pub(crate) static ENTRY_DIARIZING_12061227027012575105: VariantsMap = [
    &["diarizing"],
    &["diarising"],
    &["diarizing"],
    &["diarising"],
];

pub(crate) static ENTRY_DIARRHEALER_3006325160958144376: VariantsMap = [
    &["diarrhealer"],
    &["diarrhoealer"],
    &["diarrhealer"],
    &["diarrhoealer"],
];

pub(crate) static ENTRY_DIARRHEALEST_17262839018541832325: VariantsMap = [
    &["diarrhealest"],
    &["diarrhoealest"],
    &["diarrhealest"],
    &["diarrhoealest"],
];

pub(crate) static ENTRY_DIARRHEAL_13632347487774327311: VariantsMap = [
    &["diarrheal"],
    &["diarrhoeal"],
    &["diarrheal"],
    &["diarrhoeal"],
];

pub(crate) static ENTRY_DIARRHEAS_15185377414757726510: VariantsMap = [
    &["diarrheas"],
    &["diarrhoeas"],
    &["diarrheas"],
    &["diarrhoeas"],
];

pub(crate) static ENTRY_DIARRHEA_3911277028508716960: VariantsMap =
    [&["diarrhea"], &["diarrhoea"], &["diarrhea"], &["diarrhoea"]];

pub(crate) static ENTRY_DIARRHEICER_8223047862418714828: VariantsMap = [
    &["diarrheicer"],
    &["diarrhoeicer"],
    &["diarrhoeicer"],
    &["diarrhoeicer"],
];

pub(crate) static ENTRY_DIARRHEICEST_13997700102628135772: VariantsMap = [
    &["diarrheicest"],
    &["diarrhoeicest"],
    &["diarrhoeicest"],
    &["diarrhoeicest"],
];

pub(crate) static ENTRY_DIARRHEIC_12128447998005479433: VariantsMap = [
    &["diarrheic"],
    &["diarrhoeic"],
    &["diarrhoeic"],
    &["diarrhoeic"],
];

pub(crate) static ENTRY_DIARRHETICER_10689775787335384886: VariantsMap = [
    &["diarrheticer"],
    &["diarrhoeticer"],
    &["diarrhoeticer"],
    &["diarrhoeticer"],
];

pub(crate) static ENTRY_DIARRHETICEST_5068896754833432010: VariantsMap = [
    &["diarrheticest"],
    &["diarrhoeticest"],
    &["diarrhoeticest"],
    &["diarrhoeticest"],
];

pub(crate) static ENTRY_DIARRHETIC_7536154240592572346: VariantsMap = [
    &["diarrhetic"],
    &["diarrhoetic"],
    &["diarrhoetic"],
    &["diarrhoetic"],
];

pub(crate) static ENTRY_DICHOTOMIZATIONS_115773806968765381: VariantsMap = [
    &["dichotomizations"],
    &["dichotomisations"],
    &["dichotomizations"],
    &["dichotomisations"],
];

pub(crate) static ENTRY_DICHOTOMIZATION_14122718939310504058: VariantsMap = [
    &["dichotomization"],
    &["dichotomisation"],
    &["dichotomization"],
    &["dichotomisation"],
];

pub(crate) static ENTRY_DICHOTOMIZED_6365894040247689611: VariantsMap = [
    &["dichotomized"],
    &["dichotomised"],
    &["dichotomized"],
    &["dichotomised"],
];

pub(crate) static ENTRY_DICHOTOMIZES_6036836042986433362: VariantsMap = [
    &["dichotomizes"],
    &["dichotomises"],
    &["dichotomizes"],
    &["dichotomises"],
];

pub(crate) static ENTRY_DICHOTOMIZE_10272954486831643030: VariantsMap = [
    &["dichotomize"],
    &["dichotomise"],
    &["dichotomize"],
    &["dichotomise"],
];

pub(crate) static ENTRY_DICHOTOMIZING_12141393071288009958: VariantsMap = [
    &["dichotomizing"],
    &["dichotomising"],
    &["dichotomizing"],
    &["dichotomising"],
];

pub(crate) static ENTRY_DIENE_5289363052349288627: VariantsMap =
    [&["diene"], &["diaene"], &["diaene"], &["diaene"]];

pub(crate) static ENTRY_DIERETIC_12527602600898981533: VariantsMap = [
    &["dieretic"],
    &["diaeretic"],
    &["diaeretic"],
    &["diaeretic"],
];

pub(crate) static ENTRY_DIESELIZATIONS_14033775324353063673: VariantsMap = [
    &["dieselizations"],
    &["dieselisations"],
    &["dieselizations"],
    &["dieselisations"],
];

pub(crate) static ENTRY_DIESELIZATION_12398344399064585609: VariantsMap = [
    &["dieselization"],
    &["dieselisation"],
    &["dieselization"],
    &["dieselisation"],
];

pub(crate) static ENTRY_DIESELIZED_964526993351555906: VariantsMap = [
    &["dieselized"],
    &["dieselised"],
    &["dieselized"],
    &["dieselised"],
];

pub(crate) static ENTRY_DIESELIZES_14049322191860606720: VariantsMap = [
    &["dieselizes"],
    &["dieselises"],
    &["dieselizes"],
    &["dieselises"],
];

pub(crate) static ENTRY_DIESELIZE_11999686462945584292: VariantsMap = [
    &["dieselize"],
    &["dieselise"],
    &["dieselize"],
    &["dieselise"],
];

pub(crate) static ENTRY_DIESELIZING_11362563188776269281: VariantsMap = [
    &["dieselizing"],
    &["dieselising"],
    &["dieselizing"],
    &["dieselising"],
];

pub(crate) static ENTRY_DIESTROUS_5675936637008060315: VariantsMap = [
    &["diestrous"],
    &["dioestrous"],
    &["dioestrous"],
    &["dioestrous"],
];

pub(crate) static ENTRY_DIESTRUAL_3082735349669486152: VariantsMap = [
    &["diestrual"],
    &["dioestrual"],
    &["dioestrual"],
    &["dioestrual"],
];

pub(crate) static ENTRY_DIESTRUM_2386801088895051709: VariantsMap = [
    &["diestrum"],
    &["dioestrum"],
    &["dioestrum"],
    &["dioestrum"],
];

pub(crate) static ENTRY_DIESTRUSES_13285806073259462800: VariantsMap = [
    &["diestruses"],
    &["dioestruses"],
    &["dioestruses"],
    &["dioestruses"],
];

pub(crate) static ENTRY_DIESTRUS_16455941497852839497: VariantsMap = [
    &["diestrus"],
    &["dioestrus"],
    &["dioestrus"],
    &["dioestrus"],
];

pub(crate) static ENTRY_DIETHYLSTILBESTROL_7507155956542803846: VariantsMap = [
    &["diethylstilbestrol"],
    &["diethylstilboestrol"],
    &["diethylstilboestrol"],
    &["diethylstilboestrol"],
];

pub(crate) static ENTRY_DIFFERENTIALIZES_10101899794646797010: VariantsMap = [
    &["differentializes"],
    &["differentialises"],
    &["differentializes"],
    &["differentialises"],
];

pub(crate) static ENTRY_DIFFERENTIALIZE_12999555494326012749: VariantsMap = [
    &["differentialize"],
    &["differentialise"],
    &["differentialize"],
    &["differentialise"],
];

pub(crate) static ENTRY_DIGITALIZATIONS_569505163832283300: VariantsMap = [
    &["digitalizations"],
    &["digitalisations"],
    &["digitalizations"],
    &["digitalisations"],
];

pub(crate) static ENTRY_DIGITALIZATION_1880066254948558272: VariantsMap = [
    &["digitalization"],
    &["digitalisation"],
    &["digitalization"],
    &["digitalisation"],
];

pub(crate) static ENTRY_DIGITALIZED_10523465632142129010: VariantsMap = [
    &["digitalized"],
    &["digitalised"],
    &["digitalized"],
    &["digitalised"],
];

pub(crate) static ENTRY_DIGITALIZES_16738992677023261947: VariantsMap = [
    &["digitalizes"],
    &["digitalises"],
    &["digitalizes"],
    &["digitalises"],
];

pub(crate) static ENTRY_DIGITALIZE_641397969368171855: VariantsMap = [
    &["digitalize"],
    &["digitalise"],
    &["digitalize"],
    &["digitalise"],
];

pub(crate) static ENTRY_DIGITALIZING_5222161273491894931: VariantsMap = [
    &["digitalizing"],
    &["digitalising"],
    &["digitalizing"],
    &["digitalising"],
];

pub(crate) static ENTRY_DIGITIZATIONS_16075534772362552339: VariantsMap = [
    &["digitizations"],
    &["digitisations"],
    &["digitizations"],
    &["digitisations"],
];

pub(crate) static ENTRY_DIGITIZATION_16526021465569627029: VariantsMap = [
    &["digitization"],
    &["digitisation"],
    &["digitization"],
    &["digitisation"],
];

pub(crate) static ENTRY_DIGITIZED_9086015022851622383: VariantsMap = [
    &["digitized"],
    &["digitised"],
    &["digitized"],
    &["digitised"],
];

pub(crate) static ENTRY_DIGITIZERS_13765203491581800269: VariantsMap = [
    &["digitizers"],
    &["digitisers"],
    &["digitizers"],
    &["digitisers"],
];

pub(crate) static ENTRY_DIGITIZER_17878398947103509512: VariantsMap = [
    &["digitizer"],
    &["digitiser"],
    &["digitizer"],
    &["digitiser"],
];

pub(crate) static ENTRY_DIGITIZES_8019423972202149279: VariantsMap = [
    &["digitizes"],
    &["digitises"],
    &["digitizes"],
    &["digitises"],
];

pub(crate) static ENTRY_DIGITIZE_2409600049499220627: VariantsMap =
    [&["digitize"], &["digitise"], &["digitize"], &["digitise"]];

pub(crate) static ENTRY_DIGITIZING_18195991368262756258: VariantsMap = [
    &["digitizing"],
    &["digitising"],
    &["digitizing"],
    &["digitising"],
];

pub(crate) static ENTRY_DIMENSIONALIZATION_4356536298220232988: VariantsMap = [
    &["dimensionalization"],
    &["dimensionalisation"],
    &["dimensionalization"],
    &["dimensionalisation"],
];

pub(crate) static ENTRY_DIMENSIONALIZED_3184637022176586212: VariantsMap = [
    &["dimensionalized"],
    &["dimensionalised"],
    &["dimensionalized"],
    &["dimensionalised"],
];

pub(crate) static ENTRY_DIMENSIONALIZES_9848355598654843982: VariantsMap = [
    &["dimensionalizes"],
    &["dimensionalises"],
    &["dimensionalizes"],
    &["dimensionalises"],
];

pub(crate) static ENTRY_DIMENSIONALIZE_10901055311777106222: VariantsMap = [
    &["dimensionalize"],
    &["dimensionalise"],
    &["dimensionalize"],
    &["dimensionalise"],
];

pub(crate) static ENTRY_DIMENSIONALIZING_1752907837018030213: VariantsMap = [
    &["dimensionalizing"],
    &["dimensionalising"],
    &["dimensionalizing"],
    &["dimensionalising"],
];

pub(crate) static ENTRY_DIMERIZATIONS_17395979002092992362: VariantsMap = [
    &["dimerizations"],
    &["dimerisations"],
    &["dimerizations"],
    &["dimerisations"],
];

pub(crate) static ENTRY_DIMERIZATION_9938594401087459901: VariantsMap = [
    &["dimerization"],
    &["dimerisation"],
    &["dimerization"],
    &["dimerisation"],
];

pub(crate) static ENTRY_DIMERIZED_13111304572987660792: VariantsMap = [
    &["dimerized"],
    &["dimerised"],
    &["dimerized"],
    &["dimerised"],
];

pub(crate) static ENTRY_DIMERIZES_9744071354280045741: VariantsMap = [
    &["dimerizes"],
    &["dimerises"],
    &["dimerizes"],
    &["dimerises"],
];

pub(crate) static ENTRY_DIMERIZE_4390974169720571059: VariantsMap =
    [&["dimerize"], &["dimerise"], &["dimerize"], &["dimerise"]];

pub(crate) static ENTRY_DIMERIZING_13012922488510597897: VariantsMap = [
    &["dimerizing"],
    &["dimerising"],
    &["dimerizing"],
    &["dimerising"],
];

pub(crate) static ENTRY_DIMINUTIVIZES_10068123782291339418: VariantsMap = [
    &["diminutivizes"],
    &["diminutivises"],
    &["diminutivizes"],
    &["diminutivises"],
];

pub(crate) static ENTRY_DIMINUTIVIZE_2645195698550337493: VariantsMap = [
    &["diminutivize"],
    &["diminutivise"],
    &["diminutivize"],
    &["diminutivise"],
];

pub(crate) static ENTRY_DIOECIOUSLY_6346210130110835649: VariantsMap = [
    &["dioeciously"],
    &["dioeciously"],
    &["dioeciously"],
    &["dioeciously"],
];

pub(crate) static ENTRY_DIOECIOUS_755179665025369568: VariantsMap = [
    &["dioecious"],
    &["dioecious"],
    &["dioecious"],
    &["dioecious"],
];

pub(crate) static ENTRY_DIONIZE_13243585000792606440: VariantsMap =
    [&["dionize"], &["dionise"], &["dionize"], &["dionise"]];

pub(crate) static ENTRY_DIOPTERS_11469688744147601313: VariantsMap =
    [&["diopters"], &["dioptres"], &["dioptres"], &["dioptres"]];

pub(crate) static ENTRY_DIOPTER_16953349812175946912: VariantsMap =
    [&["diopter"], &["dioptre"], &["dioptre"], &["dioptre"]];

pub(crate) static ENTRY_DIPHTHONGIZATIONS_2030371554784749334: VariantsMap = [
    &["diphthongizations"],
    &["diphthongisations"],
    &["diphthongizations"],
    &["diphthongisations"],
];

pub(crate) static ENTRY_DIPHTHONGIZATION_17407501498744325663: VariantsMap = [
    &["diphthongization"],
    &["diphthongisation"],
    &["diphthongization"],
    &["diphthongisation"],
];

pub(crate) static ENTRY_DIPHTHONGIZED_13148843710594941732: VariantsMap = [
    &["diphthongized"],
    &["diphthongised"],
    &["diphthongized"],
    &["diphthongised"],
];

pub(crate) static ENTRY_DIPHTHONGIZES_13677092120190203653: VariantsMap = [
    &["diphthongizes"],
    &["diphthongises"],
    &["diphthongizes"],
    &["diphthongises"],
];

pub(crate) static ENTRY_DIPHTHONGIZE_10084557415323022414: VariantsMap = [
    &["diphthongize"],
    &["diphthongise"],
    &["diphthongize"],
    &["diphthongise"],
];

pub(crate) static ENTRY_DIPHTHONGIZING_11085495889059563585: VariantsMap = [
    &["diphthongizing"],
    &["diphthongising"],
    &["diphthongizing"],
    &["diphthongising"],
];

pub(crate) static ENTRY_DIPLE_7428584638928928919: VariantsMap =
    [&["diple"], &["diploe"], &["diploe"], &["diploe"]];

pub(crate) static ENTRY_DIPLOE_10703949518050648588: VariantsMap =
    [&["diploe"], &["diploae"], &["diploae"], &["diploae"]];

pub(crate) static ENTRY_DIPLOMATIZED_11523795488471592556: VariantsMap = [
    &["diplomatized"],
    &["diplomatised"],
    &["diplomatized"],
    &["diplomatised"],
];

pub(crate) static ENTRY_DIPLOMATIZES_14629626523715323067: VariantsMap = [
    &["diplomatizes"],
    &["diplomatises"],
    &["diplomatizes"],
    &["diplomatises"],
];

pub(crate) static ENTRY_DIPLOMATIZE_9472455919380322088: VariantsMap = [
    &["diplomatize"],
    &["diplomatise"],
    &["diplomatize"],
    &["diplomatise"],
];

pub(crate) static ENTRY_DIPLOMATIZING_2076281714855929811: VariantsMap = [
    &["diplomatizing"],
    &["diplomatising"],
    &["diplomatizing"],
    &["diplomatising"],
];

pub(crate) static ENTRY_DISANGULARIZES_8869019649269602071: VariantsMap = [
    &["disangularizes"],
    &["disangularises"],
    &["disangularizes"],
    &["disangularises"],
];

pub(crate) static ENTRY_DISANGULARIZE_13323240909851231875: VariantsMap = [
    &["disangularize"],
    &["disangularise"],
    &["disangularize"],
    &["disangularise"],
];

pub(crate) static ENTRY_DISAUTHORIZED_6840896542619235950: VariantsMap = [
    &["disauthorized"],
    &["disauthorised"],
    &["disauthorized"],
    &["disauthorised"],
];

pub(crate) static ENTRY_DISAUTHORIZES_12659924006813750384: VariantsMap = [
    &["disauthorizes"],
    &["disauthorises"],
    &["disauthorizes"],
    &["disauthorises"],
];

pub(crate) static ENTRY_DISAUTHORIZE_6190072065866456291: VariantsMap = [
    &["disauthorize"],
    &["disauthorise"],
    &["disauthorize"],
    &["disauthorise"],
];

pub(crate) static ENTRY_DISAUTHORIZING_17808569511505045100: VariantsMap = [
    &["disauthorizing"],
    &["disauthorising"],
    &["disauthorizing"],
    &["disauthorising"],
];

pub(crate) static ENTRY_DISBOWELED_6495042604775859773: VariantsMap = [
    &["disboweled"],
    &["disbowelled"],
    &["disbowelled"],
    &["disbowelled"],
];

pub(crate) static ENTRY_DISBOWELING_4226524984238944204: VariantsMap = [
    &["disboweling"],
    &["disbowelling"],
    &["disbowelling"],
    &["disbowelling"],
];

pub(crate) static ENTRY_DISCANONIZATIONS_17543892402167599721: VariantsMap = [
    &["discanonizations"],
    &["discanonisations"],
    &["discanonizations"],
    &["discanonisations"],
];

pub(crate) static ENTRY_DISCANONIZATION_15089376592937545269: VariantsMap = [
    &["discanonization"],
    &["discanonisation"],
    &["discanonization"],
    &["discanonisation"],
];

pub(crate) static ENTRY_DISCANONIZES_15186719030368110625: VariantsMap = [
    &["discanonizes"],
    &["discanonises"],
    &["discanonizes"],
    &["discanonises"],
];

pub(crate) static ENTRY_DISCANONIZE_13454483455213180202: VariantsMap = [
    &["discanonize"],
    &["discanonise"],
    &["discanonize"],
    &["discanonise"],
];

pub(crate) static ENTRY_DISCOLORATED_8704987430623829107: VariantsMap = [
    &["discolorated"],
    &["discolourated"],
    &["discolourated"],
    &["discolourated"],
];

pub(crate) static ENTRY_DISCOLORATE_15722048022558836335: VariantsMap = [
    &["discolorate"],
    &["discolourate"],
    &["discolourate"],
    &["discolourate"],
];

pub(crate) static ENTRY_DISCOLORATIONS_1674651272709360573: VariantsMap = [
    &["discolorations"],
    &["discolorations", "discolourations"],
    &["discolorations"],
    &["discolorations", "discolourations"],
];

pub(crate) static ENTRY_DISCOLORATION_1217061862280012422: VariantsMap = [
    &["discoloration"],
    &["discoloration", "discolouration"],
    &["discoloration"],
    &["discoloration", "discolouration"],
];

pub(crate) static ENTRY_DISCOLOREDNESS_2230982585028818030: VariantsMap = [
    &["discoloredness"],
    &["discolouredness"],
    &["discolouredness"],
    &["discolouredness"],
];

pub(crate) static ENTRY_DISCOLOREDS_7473250501334264517: VariantsMap = [
    &["discoloreds"],
    &["discoloureds"],
    &["discoloureds"],
    &["discoloureds"],
];

pub(crate) static ENTRY_DISCOLORED_16908798995974595866: VariantsMap = [
    &["discolored"],
    &["discoloured"],
    &["discoloured"],
    &["discoloured"],
];

pub(crate) static ENTRY_DISCOLORING_8629722440902022000: VariantsMap = [
    &["discoloring"],
    &["discolouring"],
    &["discolouring"],
    &["discolouring"],
];

pub(crate) static ENTRY_DISCOLORIZATIONS_3768143524495401586: VariantsMap = [
    &["discolorizations"],
    &["discolourisations"],
    &["discolourizations"],
    &["discolourisations"],
];

pub(crate) static ENTRY_DISCOLORIZATION_15335471267644592508: VariantsMap = [
    &["discolorization"],
    &["discolourisation"],
    &["discolourization"],
    &["discolourisation"],
];

pub(crate) static ENTRY_DISCOLORMENTS_8676018080341439978: VariantsMap = [
    &["discolorments"],
    &["discolourments"],
    &["discolourments"],
    &["discolourments"],
];

pub(crate) static ENTRY_DISCOLORMENT_6345690574258770117: VariantsMap = [
    &["discolorment"],
    &["discolourment"],
    &["discolourment"],
    &["discolourment"],
];

pub(crate) static ENTRY_DISCOLORS_3188891474327267925: VariantsMap = [
    &["discolors"],
    &["discolours"],
    &["discolours"],
    &["discolours"],
];

pub(crate) static ENTRY_DISCOLOR_2037841141685560590: VariantsMap = [
    &["discolor"],
    &["discolour"],
    &["discolour"],
    &["discolour"],
];

pub(crate) static ENTRY_DISCRETIZATION_11452971369238653426: VariantsMap = [
    &["discretization"],
    &["discretisation"],
    &["discretization"],
    &["discretisation"],
];

pub(crate) static ENTRY_DISCRETIZE_6297624588140855627: VariantsMap = [
    &["discretize"],
    &["discretise"],
    &["discretize"],
    &["discretise"],
];

pub(crate) static ENTRY_DISDENOMINATIONALIZES_5072175193852948543: VariantsMap = [
    &["disdenominationalizes"],
    &["disdenominationalises"],
    &["disdenominationalizes"],
    &["disdenominationalises"],
];

pub(crate) static ENTRY_DISDENOMINATIONALIZE_1834435332509515205: VariantsMap = [
    &["disdenominationalize"],
    &["disdenominationalise"],
    &["disdenominationalize"],
    &["disdenominationalise"],
];

pub(crate) static ENTRY_DISDIPLOMATIZES_3981084271285196916: VariantsMap = [
    &["disdiplomatizes"],
    &["disdiplomatises"],
    &["disdiplomatizes"],
    &["disdiplomatises"],
];

pub(crate) static ENTRY_DISDIPLOMATIZE_17465884571858136970: VariantsMap = [
    &["disdiplomatize"],
    &["disdiplomatise"],
    &["disdiplomatize"],
    &["disdiplomatise"],
];

pub(crate) static ENTRY_DISEMBOWELED_4919626984837066547: VariantsMap = [
    &["disemboweled"],
    &["disembowelled"],
    &["disembowelled"],
    &["disembowelled"],
];

pub(crate) static ENTRY_DISEMBOWELING_17785417677818928746: VariantsMap = [
    &["disemboweling"],
    &["disembowelling"],
    &["disembowelling"],
    &["disembowelling"],
];

pub(crate) static ENTRY_DISEQUALIZERS_5646916474154465014: VariantsMap = [
    &["disequalizers"],
    &["disequalisers"],
    &["disequalizers"],
    &["disequalisers"],
];

pub(crate) static ENTRY_DISEQUALIZER_1587016333056628979: VariantsMap = [
    &["disequalizer"],
    &["disequaliser"],
    &["disequalizer"],
    &["disequaliser"],
];

pub(crate) static ENTRY_DISEQUALIZES_11310592020717848131: VariantsMap = [
    &["disequalizes"],
    &["disequalises"],
    &["disequalizes"],
    &["disequalises"],
];

pub(crate) static ENTRY_DISEQUALIZE_11476330084724633640: VariantsMap = [
    &["disequalize"],
    &["disequalise"],
    &["disequalize"],
    &["disequalise"],
];

pub(crate) static ENTRY_DISFAVORED_6170594285770625316: VariantsMap = [
    &["disfavored"],
    &["disfavoured"],
    &["disfavoured"],
    &["disfavoured"],
];

pub(crate) static ENTRY_DISFAVORERS_17879567110832075503: VariantsMap = [
    &["disfavorers"],
    &["disfavourers"],
    &["disfavourers"],
    &["disfavourers"],
];

pub(crate) static ENTRY_DISFAVORER_16985801654708795790: VariantsMap = [
    &["disfavorer"],
    &["disfavourer"],
    &["disfavourer"],
    &["disfavourer"],
];

pub(crate) static ENTRY_DISFAVORING_8029210556789284619: VariantsMap = [
    &["disfavoring"],
    &["disfavouring"],
    &["disfavouring"],
    &["disfavouring"],
];

pub(crate) static ENTRY_DISFAVORS_7649343434045517378: VariantsMap = [
    &["disfavors"],
    &["disfavours"],
    &["disfavours"],
    &["disfavours"],
];

pub(crate) static ENTRY_DISFAVOR_11771334909061188611: VariantsMap = [
    &["disfavor"],
    &["disfavour"],
    &["disfavour"],
    &["disfavour"],
];

pub(crate) static ENTRY_DISHARMONIZED_12718766168972067120: VariantsMap = [
    &["disharmonized"],
    &["disharmonised"],
    &["disharmonized"],
    &["disharmonised"],
];

pub(crate) static ENTRY_DISHARMONIZES_2153201734651956091: VariantsMap = [
    &["disharmonizes"],
    &["disharmonises"],
    &["disharmonizes"],
    &["disharmonises"],
];

pub(crate) static ENTRY_DISHARMONIZE_15635806502203971041: VariantsMap = [
    &["disharmonize"],
    &["disharmonise"],
    &["disharmonize"],
    &["disharmonise"],
];

pub(crate) static ENTRY_DISHARMONIZING_13293257979178794218: VariantsMap = [
    &["disharmonizing"],
    &["disharmonising"],
    &["disharmonizing"],
    &["disharmonising"],
];

pub(crate) static ENTRY_DISHEVELED_870550093566288707: VariantsMap = [
    &["disheveled"],
    &["dishevelled"],
    &["dishevelled"],
    &["dishevelled"],
];

pub(crate) static ENTRY_DISHEVELER_2159675347135854964: VariantsMap = [
    &["disheveler"],
    &["disheveller"],
    &["disheveller"],
    &["disheveller"],
];

pub(crate) static ENTRY_DISHEVELING_6322833404479205492: VariantsMap = [
    &["disheveling"],
    &["dishevelling"],
    &["dishevelling"],
    &["dishevelling"],
];

pub(crate) static ENTRY_DISHONORABLENESSES_17639524963688776538: VariantsMap = [
    &["dishonorablenesses"],
    &["dishonourablenesses"],
    &["dishonourablenesses"],
    &["dishonourablenesses"],
];

pub(crate) static ENTRY_DISHONORABLENESS_10657592516833463167: VariantsMap = [
    &["dishonorableness"],
    &["dishonourableness"],
    &["dishonourableness"],
    &["dishonourableness"],
];

pub(crate) static ENTRY_DISHONORABLER_13799504522206021743: VariantsMap = [
    &["dishonorabler"],
    &["dishonourabler"],
    &["dishonourabler"],
    &["dishonourabler"],
];

pub(crate) static ENTRY_DISHONORABLEST_15156355191001228972: VariantsMap = [
    &["dishonorablest"],
    &["dishonourablest"],
    &["dishonourablest"],
    &["dishonourablest"],
];

pub(crate) static ENTRY_DISHONORABLES_16248754702342750197: VariantsMap = [
    &["dishonorables"],
    &["dishonourables"],
    &["dishonourables"],
    &["dishonourables"],
];

pub(crate) static ENTRY_DISHONORABLE_38080454965404032: VariantsMap = [
    &["dishonorable"],
    &["dishonourable"],
    &["dishonourable"],
    &["dishonourable"],
];

pub(crate) static ENTRY_DISHONORABLIER_1654116585736260216: VariantsMap = [
    &["dishonorablier"],
    &["dishonourablier"],
    &["dishonourablier"],
    &["dishonourablier"],
];

pub(crate) static ENTRY_DISHONORABLIEST_16101869312549419261: VariantsMap = [
    &["dishonorabliest"],
    &["dishonourabliest"],
    &["dishonourabliest"],
    &["dishonourabliest"],
];

pub(crate) static ENTRY_DISHONORABLIES_15514876857964789392: VariantsMap = [
    &["dishonorablies"],
    &["dishonourablies"],
    &["dishonourablies"],
    &["dishonourablies"],
];

pub(crate) static ENTRY_DISHONORABLY_7020648298729028040: VariantsMap = [
    &["dishonorably"],
    &["dishonourably"],
    &["dishonourably"],
    &["dishonourably"],
];

pub(crate) static ENTRY_DISHONORARY_3156010712966438359: VariantsMap = [
    &["dishonorary"],
    &["dishonourary"],
    &["dishonourary"],
    &["dishonourary"],
];

pub(crate) static ENTRY_DISHONORED_2157274559673536220: VariantsMap = [
    &["dishonored"],
    &["dishonoured"],
    &["dishonoured"],
    &["dishonoured"],
];

pub(crate) static ENTRY_DISHONORERS_18354990936256424099: VariantsMap = [
    &["dishonorers"],
    &["dishonourers"],
    &["dishonourers"],
    &["dishonourers"],
];

pub(crate) static ENTRY_DISHONORER_10838124284388158631: VariantsMap = [
    &["dishonorer"],
    &["dishonourer"],
    &["dishonourer"],
    &["dishonourer"],
];

pub(crate) static ENTRY_DISHONORING_2399726273028722915: VariantsMap = [
    &["dishonoring"],
    &["dishonouring"],
    &["dishonouring"],
    &["dishonouring"],
];

pub(crate) static ENTRY_DISHONORS_1597149550458150983: VariantsMap = [
    &["dishonors"],
    &["dishonours"],
    &["dishonours"],
    &["dishonours"],
];

pub(crate) static ENTRY_DISHONOR_11620713121077259513: VariantsMap = [
    &["dishonor"],
    &["dishonour"],
    &["dishonour"],
    &["dishonour"],
];

pub(crate) static ENTRY_DISHUMANIZES_492537464677045904: VariantsMap = [
    &["dishumanizes"],
    &["dishumanises"],
    &["dishumanizes"],
    &["dishumanises"],
];

pub(crate) static ENTRY_DISHUMANIZE_3651625213094865968: VariantsMap = [
    &["dishumanize"],
    &["dishumanise"],
    &["dishumanize"],
    &["dishumanise"],
];

pub(crate) static ENTRY_DISHUMORED_10529422865830482415: VariantsMap = [
    &["dishumored"],
    &["dishumoured"],
    &["dishumoured"],
    &["dishumoured"],
];

pub(crate) static ENTRY_DISHUMORS_12570733308231929375: VariantsMap = [
    &["dishumors"],
    &["dishumours"],
    &["dishumours"],
    &["dishumours"],
];

pub(crate) static ENTRY_DISHUMOR_8582767360144693186: VariantsMap = [
    &["dishumor"],
    &["dishumour"],
    &["dishumour"],
    &["dishumour"],
];

pub(crate) static ENTRY_DISILLUSIONIZED_2046602644783149604: VariantsMap = [
    &["disillusionized"],
    &["disillusionised"],
    &["disillusionized"],
    &["disillusionised"],
];

pub(crate) static ENTRY_DISILLUSIONIZERS_16679379308545646053: VariantsMap = [
    &["disillusionizers"],
    &["disillusionisers"],
    &["disillusionizers"],
    &["disillusionisers"],
];

pub(crate) static ENTRY_DISILLUSIONIZER_3198853356088724502: VariantsMap = [
    &["disillusionizer"],
    &["disillusioniser"],
    &["disillusionizer"],
    &["disillusioniser"],
];

pub(crate) static ENTRY_DISILLUSIONIZES_9587219142518614686: VariantsMap = [
    &["disillusionizes"],
    &["disillusionises"],
    &["disillusionizes"],
    &["disillusionises"],
];

pub(crate) static ENTRY_DISILLUSIONIZE_544284270568577104: VariantsMap = [
    &["disillusionize"],
    &["disillusionise"],
    &["disillusionize"],
    &["disillusionise"],
];

pub(crate) static ENTRY_DISILLUSIONIZING_2867093168312197564: VariantsMap = [
    &["disillusionizing"],
    &["disillusionising"],
    &["disillusionizing"],
    &["disillusionising"],
];

pub(crate) static ENTRY_DISINDIVIDUALIZED_8419880667851776580: VariantsMap = [
    &["disindividualized"],
    &["disindividualised"],
    &["disindividualized"],
    &["disindividualised"],
];

pub(crate) static ENTRY_DISINDIVIDUALIZES_4702939998891004702: VariantsMap = [
    &["disindividualizes"],
    &["disindividualises"],
    &["disindividualizes"],
    &["disindividualises"],
];

pub(crate) static ENTRY_DISINDIVIDUALIZE_3474275877211684124: VariantsMap = [
    &["disindividualize"],
    &["disindividualise"],
    &["disindividualize"],
    &["disindividualise"],
];

pub(crate) static ENTRY_DISINDIVIDUALIZING_17455766326632665129: VariantsMap = [
    &["disindividualizing"],
    &["disindividualising"],
    &["disindividualizing"],
    &["disindividualising"],
];

pub(crate) static ENTRY_DISINDUSTRIALIZATIONS_6170260318117555283: VariantsMap = [
    &["disindustrializations"],
    &["disindustrialisations"],
    &["disindustrializations"],
    &["disindustrialisations"],
];

pub(crate) static ENTRY_DISINDUSTRIALIZATION_17135590793569724945: VariantsMap = [
    &["disindustrialization"],
    &["disindustrialisation"],
    &["disindustrialization"],
    &["disindustrialisation"],
];

pub(crate) static ENTRY_DISINDUSTRIALIZED_5965260381139710218: VariantsMap = [
    &["disindustrialized"],
    &["disindustrialised"],
    &["disindustrialized"],
    &["disindustrialised"],
];

pub(crate) static ENTRY_DISINDUSTRIALIZES_15047921186004255745: VariantsMap = [
    &["disindustrializes"],
    &["disindustrialises"],
    &["disindustrializes"],
    &["disindustrialises"],
];

pub(crate) static ENTRY_DISINDUSTRIALIZE_3656465979526508744: VariantsMap = [
    &["disindustrialize"],
    &["disindustrialise"],
    &["disindustrialize"],
    &["disindustrialise"],
];

pub(crate) static ENTRY_DISINDUSTRIALIZING_14648192815944839417: VariantsMap = [
    &["disindustrializing"],
    &["disindustrialising"],
    &["disindustrializing"],
    &["disindustrialising"],
];

pub(crate) static ENTRY_DISLUSTER_13358247352773333676: VariantsMap = [
    &["disluster"],
    &["dislustre"],
    &["dislustre"],
    &["dislustre"],
];

pub(crate) static ENTRY_DISMALIZES_2605097482883819029: VariantsMap = [
    &["dismalizes"],
    &["dismalises"],
    &["dismalizes"],
    &["dismalises"],
];

pub(crate) static ENTRY_DISMALIZE_7994271907630309515: VariantsMap = [
    &["dismalize"],
    &["dismalise"],
    &["dismalize"],
    &["dismalise"],
];

pub(crate) static ENTRY_DISNATURALIZATIONS_9144315549620421227: VariantsMap = [
    &["disnaturalizations"],
    &["disnaturalisations"],
    &["disnaturalizations"],
    &["disnaturalisations"],
];

pub(crate) static ENTRY_DISNATURALIZATION_13759062101456967136: VariantsMap = [
    &["disnaturalization"],
    &["disnaturalisation"],
    &["disnaturalization"],
    &["disnaturalisation"],
];

pub(crate) static ENTRY_DISNATURALIZED_5139712538919037153: VariantsMap = [
    &["disnaturalized"],
    &["disnaturalised"],
    &["disnaturalized"],
    &["disnaturalised"],
];

pub(crate) static ENTRY_DISNATURALIZES_5656357318797234866: VariantsMap = [
    &["disnaturalizes"],
    &["disnaturalises"],
    &["disnaturalizes"],
    &["disnaturalises"],
];

pub(crate) static ENTRY_DISNATURALIZE_4631885449577103514: VariantsMap = [
    &["disnaturalize"],
    &["disnaturalise"],
    &["disnaturalize"],
    &["disnaturalise"],
];

pub(crate) static ENTRY_DISNATURALIZING_9697668056281067306: VariantsMap = [
    &["disnaturalizing"],
    &["disnaturalising"],
    &["disnaturalizing"],
    &["disnaturalising"],
];

pub(crate) static ENTRY_DISORGANIZATIONS_5594690456228431300: VariantsMap = [
    &["disorganizations"],
    &["disorganisations"],
    &["disorganizations"],
    &["disorganisations"],
];

pub(crate) static ENTRY_DISORGANIZATION_16996811069576322696: VariantsMap = [
    &["disorganization"],
    &["disorganisation"],
    &["disorganization"],
    &["disorganisation"],
];

pub(crate) static ENTRY_DISORGANIZED_8174306046630470447: VariantsMap = [
    &["disorganized"],
    &["disorganised"],
    &["disorganized"],
    &["disorganised"],
];

pub(crate) static ENTRY_DISORGANIZERS_14983162437093206464: VariantsMap = [
    &["disorganizers"],
    &["disorganisers"],
    &["disorganizers"],
    &["disorganisers"],
];

pub(crate) static ENTRY_DISORGANIZER_14173806118703512335: VariantsMap = [
    &["disorganizer"],
    &["disorganiser"],
    &["disorganizer"],
    &["disorganiser"],
];

pub(crate) static ENTRY_DISORGANIZES_2153949974040488529: VariantsMap = [
    &["disorganizes"],
    &["disorganises"],
    &["disorganizes"],
    &["disorganises"],
];

pub(crate) static ENTRY_DISORGANIZE_8532063637419651098: VariantsMap = [
    &["disorganize"],
    &["disorganise"],
    &["disorganize"],
    &["disorganise"],
];

pub(crate) static ENTRY_DISORGANIZING_9571942280468279076: VariantsMap = [
    &["disorganizing"],
    &["disorganising"],
    &["disorganizing"],
    &["disorganising"],
];

pub(crate) static ENTRY_DISOZONIZES_9388111209265427380: VariantsMap = [
    &["disozonizes"],
    &["disozonises"],
    &["disozonizes"],
    &["disozonises"],
];

pub(crate) static ENTRY_DISOZONIZE_16113533175672098111: VariantsMap = [
    &["disozonize"],
    &["disozonise"],
    &["disozonize"],
    &["disozonise"],
];

pub(crate) static ENTRY_DISPAPALIZES_7854705630224972621: VariantsMap = [
    &["dispapalizes"],
    &["dispapalises"],
    &["dispapalizes"],
    &["dispapalises"],
];

pub(crate) static ENTRY_DISPAPALIZE_12503394153284261888: VariantsMap = [
    &["dispapalize"],
    &["dispapalise"],
    &["dispapalize"],
    &["dispapalise"],
];

pub(crate) static ENTRY_DISPATCHED_15237234107206890876: VariantsMap = [
    &["dispatched"],
    &["dispatched"],
    &["dispatched"],
    &["dispatched"],
];

pub(crate) static ENTRY_DISPATCHES_6888853082053231509: VariantsMap = [
    &["dispatches"],
    &["dispatches"],
    &["dispatches"],
    &["dispatches"],
];

pub(crate) static ENTRY_DISPATCHING_14791196208532843181: VariantsMap = [
    &["dispatching"],
    &["dispatching"],
    &["dispatching"],
    &["dispatching"],
];

pub(crate) static ENTRY_DISPATCH_1411749765220275516: VariantsMap =
    [&["dispatch"], &["dispatch"], &["dispatch"], &["dispatch"]];

pub(crate) static ENTRY_DISPAUPERIZED_5072817155402454298: VariantsMap = [
    &["dispauperized"],
    &["dispauperised"],
    &["dispauperized"],
    &["dispauperised"],
];

pub(crate) static ENTRY_DISPAUPERIZES_4159908714944585355: VariantsMap = [
    &["dispauperizes"],
    &["dispauperises"],
    &["dispauperizes"],
    &["dispauperises"],
];

pub(crate) static ENTRY_DISPAUPERIZE_16571750003331073373: VariantsMap = [
    &["dispauperize"],
    &["dispauperise"],
    &["dispauperize"],
    &["dispauperise"],
];

pub(crate) static ENTRY_DISPAUPERIZING_9914663279704655258: VariantsMap = [
    &["dispauperizing"],
    &["dispauperising"],
    &["dispauperizing"],
    &["dispauperising"],
];

pub(crate) static ENTRY_DISPERSONALIZES_17310403051207524564: VariantsMap = [
    &["dispersonalizes"],
    &["dispersonalises"],
    &["dispersonalizes"],
    &["dispersonalises"],
];

pub(crate) static ENTRY_DISPERSONALIZE_4939920470701961719: VariantsMap = [
    &["dispersonalize"],
    &["dispersonalise"],
    &["dispersonalize"],
    &["dispersonalise"],
];

pub(crate) static ENTRY_DISPOPULARIZES_4469702792863907437: VariantsMap = [
    &["dispopularizes"],
    &["dispopularises"],
    &["dispopularizes"],
    &["dispopularises"],
];

pub(crate) static ENTRY_DISPOPULARIZE_13320474917175875266: VariantsMap = [
    &["dispopularize"],
    &["dispopularise"],
    &["dispopularize"],
    &["dispopularise"],
];

pub(crate) static ENTRY_DISREALIZES_15666216050063868100: VariantsMap = [
    &["disrealizes"],
    &["disrealises"],
    &["disrealizes"],
    &["disrealises"],
];

pub(crate) static ENTRY_DISREALIZE_10968259045804893585: VariantsMap = [
    &["disrealize"],
    &["disrealise"],
    &["disrealize"],
    &["disrealise"],
];

pub(crate) static ENTRY_DISSCEPTERS_4311122668006835706: VariantsMap = [
    &["disscepters"],
    &["dissceptres"],
    &["dissceptres"],
    &["dissceptres"],
];

pub(crate) static ENTRY_DISSCEPTER_15059488157685275579: VariantsMap = [
    &["disscepter"],
    &["dissceptre"],
    &["dissceptre"],
    &["dissceptre"],
];

pub(crate) static ENTRY_DISSEIZED_2079387468009637513: VariantsMap = [
    &["disseized"],
    &["disseised"],
    &["disseized"],
    &["disseised"],
];

pub(crate) static ENTRY_DISSEIZEE_6124208357466227860: VariantsMap = [
    &["disseizee"],
    &["disseisee"],
    &["disseizee"],
    &["disseisee"],
];

pub(crate) static ENTRY_DISSEIZES_14929980355877382152: VariantsMap = [
    &["disseizes"],
    &["disseises"],
    &["disseizes"],
    &["disseises"],
];

pub(crate) static ENTRY_DISSEIZE_11569356311223512234: VariantsMap =
    [&["disseize"], &["disseise"], &["disseize"], &["disseise"]];

pub(crate) static ENTRY_DISSEIZING_14239857670092493992: VariantsMap = [
    &["disseizing"],
    &["disseising"],
    &["disseizing"],
    &["disseising"],
];

pub(crate) static ENTRY_DISSEIZINS_2569940430990116237: VariantsMap = [
    &["disseizins"],
    &["disseisins"],
    &["disseisins"],
    &["disseisins"],
];

pub(crate) static ENTRY_DISSEIZIN_7901052414713980761: VariantsMap = [
    &["disseizin"],
    &["disseisin"],
    &["disseisin"],
    &["disseisin"],
];

pub(crate) static ENTRY_DISSEIZORS_2869738690076803680: VariantsMap = [
    &["disseizors"],
    &["disseisors"],
    &["disseisors"],
    &["disseisors"],
];

pub(crate) static ENTRY_DISSEIZOR_14475077887631074628: VariantsMap = [
    &["disseizor"],
    &["disseisor"],
    &["disseisor"],
    &["disseisor"],
];

pub(crate) static ENTRY_DISSENSUALIZES_16186087831493933183: VariantsMap = [
    &["dissensualizes"],
    &["dissensualises"],
    &["dissensualizes"],
    &["dissensualises"],
];

pub(crate) static ENTRY_DISSENSUALIZE_7244829030534674841: VariantsMap = [
    &["dissensualize"],
    &["dissensualise"],
    &["dissensualize"],
    &["dissensualise"],
];

pub(crate) static ENTRY_DISSOCIALIZED_7817550467475017912: VariantsMap = [
    &["dissocialized"],
    &["dissocialised"],
    &["dissocialized"],
    &["dissocialised"],
];

pub(crate) static ENTRY_DISSOCIALIZES_3807225651535481442: VariantsMap = [
    &["dissocializes"],
    &["dissocialises"],
    &["dissocializes"],
    &["dissocialises"],
];

pub(crate) static ENTRY_DISSOCIALIZE_3098839401536604100: VariantsMap = [
    &["dissocialize"],
    &["dissocialise"],
    &["dissocialize"],
    &["dissocialise"],
];

pub(crate) static ENTRY_DISSOCIALIZING_18099761030916777061: VariantsMap = [
    &["dissocializing"],
    &["dissocialising"],
    &["dissocializing"],
    &["dissocialising"],
];

pub(crate) static ENTRY_DISSYLLABIZED_13261189064508331736: VariantsMap = [
    &["dissyllabized"],
    &["dissyllabised"],
    &["dissyllabized"],
    &["dissyllabised"],
];

pub(crate) static ENTRY_DISSYLLABIZE_5360857095905079197: VariantsMap = [
    &["dissyllabize"],
    &["dissyllabise"],
    &["dissyllabize"],
    &["dissyllabise"],
];

pub(crate) static ENTRY_DISSYLLABIZING_6445596796049180767: VariantsMap = [
    &["dissyllabizing"],
    &["dissyllabising"],
    &["dissyllabizing"],
    &["dissyllabising"],
];

pub(crate) static ENTRY_DISSYMPATHIZES_14278393868885673403: VariantsMap = [
    &["dissympathizes"],
    &["dissympathises"],
    &["dissympathizes"],
    &["dissympathises"],
];

pub(crate) static ENTRY_DISSYMPATHIZE_16935057061240923894: VariantsMap = [
    &["dissympathize"],
    &["dissympathise"],
    &["dissympathize"],
    &["dissympathise"],
];

pub(crate) static ENTRY_DISTILLS_6330479058124863728: VariantsMap =
    [&["distills"], &["distils"], &["distills"], &["distils"]];

pub(crate) static ENTRY_DISTILL_72998375259612317: VariantsMap =
    [&["distill"], &["distil"], &["distill"], &["distil"]];

pub(crate) static ENTRY_DISUTILIZES_15486108534615553292: VariantsMap = [
    &["disutilizes"],
    &["disutilises"],
    &["disutilizes"],
    &["disutilises"],
];

pub(crate) static ENTRY_DISUTILIZE_5491879073193162565: VariantsMap = [
    &["disutilize"],
    &["disutilise"],
    &["disutilize"],
    &["disutilise"],
];

pub(crate) static ENTRY_DIVERSICOLORED_13604237391321254433: VariantsMap = [
    &["diversicolored"],
    &["diversicoloured"],
    &["diversicoloured"],
    &["diversicoloured"],
];

pub(crate) static ENTRY_DIVINISTER_16908631551602499711: VariantsMap = [
    &["divinister"],
    &["divinistre"],
    &["divinistre"],
    &["divinistre"],
];

pub(crate) static ENTRY_DIVINIZATIONS_13538291884563048141: VariantsMap = [
    &["divinizations"],
    &["divinisations"],
    &["divinizations"],
    &["divinisations"],
];

pub(crate) static ENTRY_DIVINIZATION_11972340056619369285: VariantsMap = [
    &["divinization"],
    &["divinisation"],
    &["divinization"],
    &["divinisation"],
];

pub(crate) static ENTRY_DIVINIZED_6811293569537741594: VariantsMap = [
    &["divinized"],
    &["divinised"],
    &["divinized"],
    &["divinised"],
];

pub(crate) static ENTRY_DIVINIZES_15547907663135588559: VariantsMap = [
    &["divinizes"],
    &["divinises"],
    &["divinizes"],
    &["divinises"],
];

pub(crate) static ENTRY_DIVINIZE_8792843604983197190: VariantsMap =
    [&["divinize"], &["divinise"], &["divinize"], &["divinise"]];

pub(crate) static ENTRY_DIVINIZING_10978447348346172564: VariantsMap = [
    &["divinizing"],
    &["divinising"],
    &["divinizing"],
    &["divinising"],
];

pub(crate) static ENTRY_DIVISIONALIZATIONS_15028430852200113799: VariantsMap = [
    &["divisionalizations"],
    &["divisionalisations"],
    &["divisionalizations"],
    &["divisionalisations"],
];

pub(crate) static ENTRY_DIVISIONALIZATION_6004413059534979150: VariantsMap = [
    &["divisionalization"],
    &["divisionalisation"],
    &["divisionalization"],
    &["divisionalisation"],
];

pub(crate) static ENTRY_DOCETE_18210621150940118199: VariantsMap =
    [&["docete"], &["docetae"], &["docetae"], &["docetae"]];

pub(crate) static ENTRY_DOCKIZATIONS_3062523957842125154: VariantsMap = [
    &["dockizations"],
    &["dockisations"],
    &["dockizations"],
    &["dockisations"],
];

pub(crate) static ENTRY_DOCKIZATION_2359063524793332046: VariantsMap = [
    &["dockization"],
    &["dockisation"],
    &["dockization"],
    &["dockisation"],
];

pub(crate) static ENTRY_DOCKIZED_3041614695023781078: VariantsMap =
    [&["dockized"], &["dockised"], &["dockized"], &["dockised"]];

pub(crate) static ENTRY_DOCKIZES_1001266725508279323: VariantsMap =
    [&["dockizes"], &["dockises"], &["dockizes"], &["dockises"]];

pub(crate) static ENTRY_DOCKIZE_3129922305769972728: VariantsMap =
    [&["dockize"], &["dockise"], &["dockize"], &["dockise"]];

pub(crate) static ENTRY_DOCKIZING_16895087588592694901: VariantsMap = [
    &["dockizing"],
    &["dockising"],
    &["dockizing"],
    &["dockising"],
];

pub(crate) static ENTRY_DOCTORIZATIONS_17824096614783886488: VariantsMap = [
    &["doctorizations"],
    &["doctorisations"],
    &["doctorizations"],
    &["doctorisations"],
];

pub(crate) static ENTRY_DOCTORIZATION_8095587565262451629: VariantsMap = [
    &["doctorization"],
    &["doctorisation"],
    &["doctorization"],
    &["doctorisation"],
];

pub(crate) static ENTRY_DOCTORIZES_2437264913148867517: VariantsMap = [
    &["doctorizes"],
    &["doctorises"],
    &["doctorizes"],
    &["doctorises"],
];

pub(crate) static ENTRY_DOCTORIZE_5270617854561441050: VariantsMap = [
    &["doctorize"],
    &["doctorise"],
    &["doctorize"],
    &["doctorise"],
];

pub(crate) static ENTRY_DOCTRINIZATIONS_11848559846665795864: VariantsMap = [
    &["doctrinizations"],
    &["doctrinisations"],
    &["doctrinizations"],
    &["doctrinisations"],
];

pub(crate) static ENTRY_DOCTRINIZATION_208993614488737715: VariantsMap = [
    &["doctrinization"],
    &["doctrinisation"],
    &["doctrinization"],
    &["doctrinisation"],
];

pub(crate) static ENTRY_DOCTRINIZES_5629972029764985513: VariantsMap = [
    &["doctrinizes"],
    &["doctrinises"],
    &["doctrinizes"],
    &["doctrinises"],
];

pub(crate) static ENTRY_DOCTRINIZE_6590461152234221617: VariantsMap = [
    &["doctrinize"],
    &["doctrinise"],
    &["doctrinize"],
    &["doctrinise"],
];

pub(crate) static ENTRY_DOCUMENTARIZATIONS_18171665198929635251: VariantsMap = [
    &["documentarizations"],
    &["documentarisations"],
    &["documentarizations"],
    &["documentarisations"],
];

pub(crate) static ENTRY_DOCUMENTARIZATION_6006296474311575553: VariantsMap = [
    &["documentarization"],
    &["documentarisation"],
    &["documentarization"],
    &["documentarisation"],
];

pub(crate) static ENTRY_DOCUMENTARIZED_10188551105211855695: VariantsMap = [
    &["documentarized"],
    &["documentarised"],
    &["documentarized"],
    &["documentarised"],
];

pub(crate) static ENTRY_DOCUMENTARIZES_5957801404549962940: VariantsMap = [
    &["documentarizes"],
    &["documentarises"],
    &["documentarizes"],
    &["documentarises"],
];

pub(crate) static ENTRY_DOCUMENTARIZE_7464249019029490374: VariantsMap = [
    &["documentarize"],
    &["documentarise"],
    &["documentarize"],
    &["documentarise"],
];

pub(crate) static ENTRY_DOCUMENTARIZING_3990677850725093411: VariantsMap = [
    &["documentarizing"],
    &["documentarising"],
    &["documentarizing"],
    &["documentarising"],
];

pub(crate) static ENTRY_DOCUMENTIZES_9883311938822654310: VariantsMap = [
    &["documentizes"],
    &["documentises"],
    &["documentizes"],
    &["documentises"],
];

pub(crate) static ENTRY_DOCUMENTIZE_4375971920660462713: VariantsMap = [
    &["documentize"],
    &["documentise"],
    &["documentize"],
    &["documentise"],
];

pub(crate) static ENTRY_DODONEAN_2630856114735687957: VariantsMap = [
    &["dodonean"],
    &["dodonaean"],
    &["dodonaean"],
    &["dodonaean"],
];

pub(crate) static ENTRY_DOGMATIZATIONS_13024880750897076624: VariantsMap = [
    &["dogmatizations"],
    &["dogmatisations"],
    &["dogmatizations"],
    &["dogmatisations"],
];

pub(crate) static ENTRY_DOGMATIZATION_11122345555081593564: VariantsMap = [
    &["dogmatization"],
    &["dogmatisation"],
    &["dogmatization"],
    &["dogmatisation"],
];

pub(crate) static ENTRY_DOGMATIZED_12823946452811271962: VariantsMap = [
    &["dogmatized"],
    &["dogmatised"],
    &["dogmatized"],
    &["dogmatised"],
];

pub(crate) static ENTRY_DOGMATIZERS_2555429245698465340: VariantsMap = [
    &["dogmatizers"],
    &["dogmatisers"],
    &["dogmatizers"],
    &["dogmatisers"],
];

pub(crate) static ENTRY_DOGMATIZER_17313290517364467144: VariantsMap = [
    &["dogmatizer"],
    &["dogmatiser"],
    &["dogmatizer"],
    &["dogmatiser"],
];

pub(crate) static ENTRY_DOGMATIZES_15001409429715187150: VariantsMap = [
    &["dogmatizes"],
    &["dogmatises"],
    &["dogmatizes"],
    &["dogmatises"],
];

pub(crate) static ENTRY_DOGMATIZE_4788814445794390818: VariantsMap = [
    &["dogmatize"],
    &["dogmatise"],
    &["dogmatize"],
    &["dogmatise"],
];

pub(crate) static ENTRY_DOGMATIZING_17332622864075797339: VariantsMap = [
    &["dogmatizing"],
    &["dogmatising"],
    &["dogmatizing"],
    &["dogmatising"],
];

pub(crate) static ENTRY_DOGNAPED_1802260907201390168: VariantsMap = [
    &["dognaped"],
    &["dognapped"],
    &["dognapped"],
    &["dognapped"],
];

pub(crate) static ENTRY_DOGNAPING_13937433132377991875: VariantsMap = [
    &["dognaping"],
    &["dognapping"],
    &["dognapping"],
    &["dognapping"],
];

pub(crate) static ENTRY_DOLLARIZATIONS_8202953595796740762: VariantsMap = [
    &["dollarizations"],
    &["dollarisations"],
    &["dollarizations"],
    &["dollarisations"],
];

pub(crate) static ENTRY_DOLLARIZATION_5698070921730819245: VariantsMap = [
    &["dollarization"],
    &["dollarisation"],
    &["dollarization"],
    &["dollarisation"],
];

pub(crate) static ENTRY_DOLOMITIZATIONS_14007837662999431947: VariantsMap = [
    &["dolomitizations"],
    &["dolomitisations"],
    &["dolomitizations"],
    &["dolomitisations"],
];

pub(crate) static ENTRY_DOLOMITIZATION_6461676350416833082: VariantsMap = [
    &["dolomitization"],
    &["dolomitisation"],
    &["dolomitization"],
    &["dolomitisation"],
];

pub(crate) static ENTRY_DOLOMITIZED_10868638513884715642: VariantsMap = [
    &["dolomitized"],
    &["dolomitised"],
    &["dolomitized"],
    &["dolomitised"],
];

pub(crate) static ENTRY_DOLOMITIZES_10827976409192397732: VariantsMap = [
    &["dolomitizes"],
    &["dolomitises"],
    &["dolomitizes"],
    &["dolomitises"],
];

pub(crate) static ENTRY_DOLOMITIZE_9046513132302198795: VariantsMap = [
    &["dolomitize"],
    &["dolomitise"],
    &["dolomitize"],
    &["dolomitise"],
];

pub(crate) static ENTRY_DOLOMITIZING_14905779901521480563: VariantsMap = [
    &["dolomitizing"],
    &["dolomitising"],
    &["dolomitizing"],
    &["dolomitising"],
];

pub(crate) static ENTRY_DOLORS_8418108938588101110: VariantsMap =
    [&["dolors"], &["dolours"], &["dolours"], &["dolours"]];

pub(crate) static ENTRY_DOLOR_11069244362262877679: VariantsMap =
    [&["dolor"], &["dolour"], &["dolour"], &["dolour"]];

pub(crate) static ENTRY_DOMESTICIZED_17677304649717392604: VariantsMap = [
    &["domesticized"],
    &["domesticised"],
    &["domesticized"],
    &["domesticised"],
];

pub(crate) static ENTRY_DOMESTICIZES_16200456902435581821: VariantsMap = [
    &["domesticizes"],
    &["domesticises"],
    &["domesticizes"],
    &["domesticises"],
];

pub(crate) static ENTRY_DOMESTICIZE_16723626797661011386: VariantsMap = [
    &["domesticize"],
    &["domesticise"],
    &["domesticize"],
    &["domesticise"],
];

pub(crate) static ENTRY_DOMESTICIZING_4071827736712466122: VariantsMap = [
    &["domesticizing"],
    &["domesticising"],
    &["domesticizing"],
    &["domesticising"],
];

pub(crate) static ENTRY_DOMINE_14388567529452539641: VariantsMap =
    [&["domine"], &["dominae"], &["dominae"], &["dominae"]];

pub(crate) static ENTRY_DORA_4500258709959937838: VariantsMap =
    [&["dora"], &["doura"], &["doura"], &["doura"]];

pub(crate) static ENTRY_DORICIZES_5990614349327139127: VariantsMap = [
    &["doricizes"],
    &["doricises"],
    &["doricizes"],
    &["doricises"],
];

pub(crate) static ENTRY_DORICIZE_11178351137047196779: VariantsMap =
    [&["doricize"], &["doricise"], &["doricize"], &["doricise"]];

pub(crate) static ENTRY_DORIZED_6250566204141865145: VariantsMap =
    [&["dorized"], &["dorised"], &["dorized"], &["dorised"]];

pub(crate) static ENTRY_DORIZES_109978163710471541: VariantsMap =
    [&["dorizes"], &["dorises"], &["dorizes"], &["dorises"]];

pub(crate) static ENTRY_DORIZE_3669118827894375489: VariantsMap =
    [&["dorize"], &["dorise"], &["dorize"], &["dorise"]];

pub(crate) static ENTRY_DORIZING_2573584499976703744: VariantsMap =
    [&["dorizing"], &["dorising"], &["dorizing"], &["dorising"]];

pub(crate) static ENTRY_DORYLINE_5269288463709196415: VariantsMap = [
    &["doryline"],
    &["dorylinae"],
    &["dorylinae"],
    &["dorylinae"],
];

pub(crate) static ENTRY_DOUGHNUTS_10463227561131847319: VariantsMap = [
    &["doughnuts"],
    &["doughnuts"],
    &["doughnuts"],
    &["doughnuts"],
];

pub(crate) static ENTRY_DOUGHNUT_18126283850351248332: VariantsMap =
    [&["doughnut"], &["doughnut"], &["doughnut"], &["doughnut"]];

pub(crate) static ENTRY_DOWELED_16727405833500660020: VariantsMap =
    [&["doweled"], &["dowelled"], &["dowelled"], &["dowelled"]];

pub(crate) static ENTRY_DOWELER_2002458985122762767: VariantsMap =
    [&["doweler"], &["doweller"], &["doweller"], &["doweller"]];

pub(crate) static ENTRY_DOWELING_1873186122978894197: VariantsMap = [
    &["doweling"],
    &["dowelling"],
    &["dowelling"],
    &["dowelling"],
];

pub(crate) static ENTRY_DOWNDRAFT_672818375102871084: VariantsMap = [
    &["downdraft"],
    &["downdraught"],
    &["downdraft"],
    &["downdraught"],
];

pub(crate) static ENTRY_DRACENACEAE_6277389963808616184: VariantsMap = [
    &["dracenaceae"],
    &["dracaenaceae"],
    &["dracaenaceae"],
    &["dracaenaceae"],
];

pub(crate) static ENTRY_DRACENAS_10822852860992428399: VariantsMap = [
    &["dracenas"],
    &["dracaenas"],
    &["dracaenas"],
    &["dracaenas"],
];

pub(crate) static ENTRY_DRACENA_13360613075941336461: VariantsMap =
    [&["dracena"], &["dracaena"], &["dracaena"], &["dracaena"]];

pub(crate) static ENTRY_DRAFTED_17845159112580457751: VariantsMap =
    [&["drafted"], &["drafted"], &["drafted"], &["drafted"]];

pub(crate) static ENTRY_DRAFTIER_10315157891310403943: VariantsMap = [
    &["draftier"],
    &["draughtier"],
    &["draftier"],
    &["draughtier"],
];

pub(crate) static ENTRY_DRAFTIEST_8211720032838927607: VariantsMap = [
    &["draftiest"],
    &["draughtiest"],
    &["draftiest"],
    &["draughtiest"],
];

pub(crate) static ENTRY_DRAFTILIER_7262684480559882840: VariantsMap = [
    &["draftilier"],
    &["draughtilier"],
    &["draftilier"],
    &["draughtilier"],
];

pub(crate) static ENTRY_DRAFTILIEST_9434728745324700875: VariantsMap = [
    &["draftiliest"],
    &["draughtiliest"],
    &["draftiliest"],
    &["draughtiliest"],
];

pub(crate) static ENTRY_DRAFTILY_16179502285729030019: VariantsMap = [
    &["draftily"],
    &["draughtily"],
    &["draftily"],
    &["draughtily"],
];

pub(crate) static ENTRY_DRAFTINESSES_2329357781885563418: VariantsMap = [
    &["draftinesses"],
    &["draughtinesses"],
    &["draftinesses"],
    &["draughtinesses"],
];

pub(crate) static ENTRY_DRAFTINESS_17583131269164652522: VariantsMap = [
    &["draftiness"],
    &["draughtiness"],
    &["draftiness"],
    &["draughtiness"],
];

pub(crate) static ENTRY_DRAFTING_9360381139157558092: VariantsMap =
    [&["drafting"], &["drafting"], &["drafting"], &["drafting"]];

pub(crate) static ENTRY_DRAFTSMANSHIPS_4161880617470266425: VariantsMap = [
    &["draftsmanships"],
    &["draughtsmanships"],
    &["draftsmanships"],
    &["draughtsmanships"],
];

pub(crate) static ENTRY_DRAFTSMANSHIP_15527745914295176647: VariantsMap = [
    &["draftsmanship"],
    &["draughtsmanship"],
    &["draftsmanship"],
    &["draughtsmanship"],
];

pub(crate) static ENTRY_DRAFTSMAN_6333936616453092304: VariantsMap = [
    &["draftsman"],
    &["draughtsman"],
    &["draftsman"],
    &["draughtsman"],
];

pub(crate) static ENTRY_DRAFTSMEN_7938842928790039444: VariantsMap = [
    &["draftsmen"],
    &["draughtsmen"],
    &["draftsmen"],
    &["draughtsmen"],
];

pub(crate) static ENTRY_DRAFTSPERSON_6409665226600621917: VariantsMap = [
    &["draftsperson"],
    &["draughtsperson"],
    &["draftsperson"],
    &["draughtsperson"],
];

pub(crate) static ENTRY_DRAFTSWOMAN_15962715217490874254: VariantsMap = [
    &["draftswoman"],
    &["draughtswoman"],
    &["draftswoman"],
    &["draughtswoman"],
];

pub(crate) static ENTRY_DRAFTSWOMEN_1853126005122534712: VariantsMap = [
    &["draftswomen"],
    &["draughtswomen"],
    &["draftswomen"],
    &["draughtswomen"],
];

pub(crate) static ENTRY_DRAFTY_1579846262644957016: VariantsMap =
    [&["drafty"], &["draughty"], &["drafty"], &["draughty"]];

pub(crate) static ENTRY_DRAGONIZED_17349000651376033189: VariantsMap = [
    &["dragonized"],
    &["dragonised"],
    &["dragonized"],
    &["dragonised"],
];

pub(crate) static ENTRY_DRAGONIZES_3000847053490583386: VariantsMap = [
    &["dragonizes"],
    &["dragonises"],
    &["dragonizes"],
    &["dragonises"],
];

pub(crate) static ENTRY_DRAGONIZE_8136430885978842972: VariantsMap = [
    &["dragonize"],
    &["dragonise"],
    &["dragonize"],
    &["dragonise"],
];

pub(crate) static ENTRY_DRAGONIZING_11862836114639182313: VariantsMap = [
    &["dragonizing"],
    &["dragonising"],
    &["dragonizing"],
    &["dragonising"],
];

pub(crate) static ENTRY_DRAMATIZABLER_23065206507012041: VariantsMap = [
    &["dramatizabler"],
    &["dramatisabler"],
    &["dramatizabler"],
    &["dramatisabler"],
];

pub(crate) static ENTRY_DRAMATIZABLEST_1714846433859302074: VariantsMap = [
    &["dramatizablest"],
    &["dramatisablest"],
    &["dramatizablest"],
    &["dramatisablest"],
];

pub(crate) static ENTRY_DRAMATIZABLES_17777717401779818485: VariantsMap = [
    &["dramatizables"],
    &["dramatisables"],
    &["dramatizables"],
    &["dramatisables"],
];

pub(crate) static ENTRY_DRAMATIZABLE_2049350738620399063: VariantsMap = [
    &["dramatizable"],
    &["dramatisable"],
    &["dramatizable"],
    &["dramatisable"],
];

pub(crate) static ENTRY_DRAMATIZATIONS_18020015640645554579: VariantsMap = [
    &["dramatizations"],
    &["dramatisations"],
    &["dramatizations"],
    &["dramatisations"],
];

pub(crate) static ENTRY_DRAMATIZATION_7793417852737015856: VariantsMap = [
    &["dramatization"],
    &["dramatisation"],
    &["dramatization"],
    &["dramatisation"],
];

pub(crate) static ENTRY_DRAMATIZED_1183366410074875762: VariantsMap = [
    &["dramatized"],
    &["dramatised"],
    &["dramatized"],
    &["dramatised"],
];

pub(crate) static ENTRY_DRAMATIZERS_4849393366081771993: VariantsMap = [
    &["dramatizers"],
    &["dramatisers"],
    &["dramatizers"],
    &["dramatisers"],
];

pub(crate) static ENTRY_DRAMATIZER_4338891229356955125: VariantsMap = [
    &["dramatizer"],
    &["dramatiser"],
    &["dramatizer"],
    &["dramatiser"],
];

pub(crate) static ENTRY_DRAMATIZES_17928119971239910049: VariantsMap = [
    &["dramatizes"],
    &["dramatises"],
    &["dramatizes"],
    &["dramatises"],
];

pub(crate) static ENTRY_DRAMATIZE_5576714162148854490: VariantsMap = [
    &["dramatize"],
    &["dramatise"],
    &["dramatize"],
    &["dramatise"],
];

pub(crate) static ENTRY_DRAMATIZING_17356943686393270091: VariantsMap = [
    &["dramatizing"],
    &["dramatising"],
    &["dramatizing"],
    &["dramatising"],
];

pub(crate) static ENTRY_DRAUGHTBOARDS_18406148555375655231: VariantsMap = [
    &["draughtboards"],
    &["draughtboards"],
    &["draughtboards"],
    &["draughtboards"],
];

pub(crate) static ENTRY_DRAUGHTBOARD_9322151322657814001: VariantsMap = [
    &["draughtboard"],
    &["draughtboard"],
    &["draughtboard"],
    &["draughtboard"],
];

pub(crate) static ENTRY_DREAMED_8816476032248430540: VariantsMap = [
    &["dreamed"],
    &["dreamed", "dreamt"],
    &["dreamed", "dreamt"],
    &["dreamed", "dreamt"],
];

pub(crate) static ENTRY_DRIVELED_10369632498060637218: VariantsMap = [
    &["driveled"],
    &["drivelled"],
    &["drivelled"],
    &["drivelled"],
];

pub(crate) static ENTRY_DRIVELERS_292810807634252006: VariantsMap = [
    &["drivelers"],
    &["drivellers"],
    &["drivellers"],
    &["drivellers"],
];

pub(crate) static ENTRY_DRIVELER_5677282658106600455: VariantsMap = [
    &["driveler"],
    &["driveller"],
    &["driveller"],
    &["driveller"],
];

pub(crate) static ENTRY_DRIVELING_9276931416261875171: VariantsMap = [
    &["driveling"],
    &["drivelling"],
    &["drivelling"],
    &["drivelling"],
];

pub(crate) static ENTRY_DUALIZATIONS_11089519285161275319: VariantsMap = [
    &["dualizations"],
    &["dualisations"],
    &["dualizations"],
    &["dualisations"],
];

pub(crate) static ENTRY_DUALIZATION_4073509101571037016: VariantsMap = [
    &["dualization"],
    &["dualisation"],
    &["dualization"],
    &["dualisation"],
];

pub(crate) static ENTRY_DUALIZES_10948073264088116504: VariantsMap =
    [&["dualizes"], &["dualises"], &["dualizes"], &["dualises"]];

pub(crate) static ENTRY_DUALIZE_7311697450297146384: VariantsMap =
    [&["dualize"], &["dualise"], &["dualize"], &["dualise"]];

pub(crate) static ENTRY_DUCTILIZES_13806063438403889486: VariantsMap = [
    &["ductilizes"],
    &["ductilises"],
    &["ductilizes"],
    &["ductilises"],
];

pub(crate) static ENTRY_DUCTILIZE_9087726193201443557: VariantsMap = [
    &["ductilize"],
    &["ductilise"],
    &["ductilize"],
    &["ductilise"],
];

pub(crate) static ENTRY_DUELED_9329917518038504527: VariantsMap =
    [&["dueled"], &["duelled"], &["duelled"], &["duelled"]];

pub(crate) static ENTRY_DUELERS_7359774943746748566: VariantsMap =
    [&["duelers"], &["duellers"], &["duellers"], &["duellers"]];

pub(crate) static ENTRY_DUELER_1881004460634174849: VariantsMap =
    [&["dueler"], &["dueller"], &["dueller"], &["dueller"]];

pub(crate) static ENTRY_DUELINGS_16266636898439940215: VariantsMap = [
    &["duelings"],
    &["duellings"],
    &["duellings"],
    &["duellings"],
];

pub(crate) static ENTRY_DUELING_517690675461305714: VariantsMap =
    [&["dueling"], &["duelling"], &["duelling"], &["duelling"]];

pub(crate) static ENTRY_DUELISTS_2315213851465914209: VariantsMap = [
    &["duelists"],
    &["duellists"],
    &["duellists"],
    &["duellists"],
];

pub(crate) static ENTRY_DUELIST_3617834640500550373: VariantsMap =
    [&["duelist"], &["duellist"], &["duellist"], &["duellist"]];

pub(crate) static ENTRY_DUER_1947794498627426590: VariantsMap =
    [&["duer"], &["dure"], &["dure"], &["dure"]];

pub(crate) static ENTRY_DYNAMIZED_16437663690590760619: VariantsMap = [
    &["dynamized"],
    &["dynamised"],
    &["dynamized"],
    &["dynamised"],
];

pub(crate) static ENTRY_DYNAMIZES_4847040906964920430: VariantsMap = [
    &["dynamizes"],
    &["dynamises"],
    &["dynamizes"],
    &["dynamises"],
];

pub(crate) static ENTRY_DYNAMIZE_974871700799051286: VariantsMap =
    [&["dynamize"], &["dynamise"], &["dynamize"], &["dynamise"]];

pub(crate) static ENTRY_DYNAMIZING_1200643737276779185: VariantsMap = [
    &["dynamizing"],
    &["dynamising"],
    &["dynamizing"],
    &["dynamising"],
];

pub(crate) static ENTRY_DYSESTHESIA_9627713140323890333: VariantsMap = [
    &["dysesthesia"],
    &["dysaesthesia"],
    &["dysaesthesia"],
    &["dysaesthesia"],
];

pub(crate) static ENTRY_DYSESTHETIC_7201077519433440244: VariantsMap = [
    &["dysesthetic"],
    &["dysaesthetic"],
    &["dysaesthetic"],
    &["dysaesthetic"],
];

pub(crate) static ENTRY_DYSMENORRHEAL_15355819888146380019: VariantsMap = [
    &["dysmenorrheal"],
    &["dysmenorrhoeal"],
    &["dysmenorrhoeal"],
    &["dysmenorrhoeal"],
];

pub(crate) static ENTRY_DYSMENORRHEAS_12513373498651023184: VariantsMap = [
    &["dysmenorrheas"],
    &["dysmenorrhoeas"],
    &["dysmenorrhoeas"],
    &["dysmenorrhoeas"],
];

pub(crate) static ENTRY_DYSMENORRHEA_854427638046307166: VariantsMap = [
    &["dysmenorrhea"],
    &["dysmenorrhoea"],
    &["dysmenorrhoea"],
    &["dysmenorrhoea"],
];

pub(crate) static ENTRY_DYSMENORRHEIC_11311229779411300652: VariantsMap = [
    &["dysmenorrheic"],
    &["dysmenorrhoeic"],
    &["dysmenorrhoeic"],
    &["dysmenorrhoeic"],
];

pub(crate) static ENTRY_DYSPNEAL_904353003353123023: VariantsMap = [
    &["dyspneal"],
    &["dyspnoeal"],
    &["dyspnoeal"],
    &["dyspnoeal"],
];

pub(crate) static ENTRY_DYSPNEAS_9210940115108150000: VariantsMap =
    [&["dyspneas"], &["dyspnoeas"], &["dyspneas"], &["dyspnoeas"]];

pub(crate) static ENTRY_DYSPNEA_8650571964047698387: VariantsMap =
    [&["dyspnea"], &["dyspnoea"], &["dyspnea"], &["dyspnoea"]];

pub(crate) static ENTRY_DYSPNEIC_5771134243752838640: VariantsMap = [
    &["dyspneic"],
    &["dyspnoeic"],
    &["dyspnoeic"],
    &["dyspnoeic"],
];

pub(crate) static ENTRY_EARLIERIZED_8859057113673352489: VariantsMap = [
    &["earlierized"],
    &["earlierised"],
    &["earlierized"],
    &["earlierised"],
];

pub(crate) static ENTRY_EARLIERIZES_6097960945758306246: VariantsMap = [
    &["earlierizes"],
    &["earlierises"],
    &["earlierizes"],
    &["earlierises"],
];

pub(crate) static ENTRY_EARLIERIZE_2454029968544836130: VariantsMap = [
    &["earlierize"],
    &["earlierise"],
    &["earlierize"],
    &["earlierise"],
];

pub(crate) static ENTRY_EARLIERIZING_3424145954088036470: VariantsMap = [
    &["earlierizing"],
    &["earlierising"],
    &["earlierizing"],
    &["earlierising"],
];

pub(crate) static ENTRY_EASTERNIZE_346663424765039993: VariantsMap = [
    &["easternize"],
    &["easternise"],
    &["easternize"],
    &["easternise"],
];

pub(crate) static ENTRY_EBIONIZED_4767603710174780767: VariantsMap = [
    &["ebionized"],
    &["ebionised"],
    &["ebionized"],
    &["ebionised"],
];

pub(crate) static ENTRY_EBIONIZES_8688860041619975472: VariantsMap = [
    &["ebionizes"],
    &["ebionises"],
    &["ebionizes"],
    &["ebionises"],
];

pub(crate) static ENTRY_EBIONIZE_13207197767862841625: VariantsMap =
    [&["ebionize"], &["ebionise"], &["ebionize"], &["ebionise"]];

pub(crate) static ENTRY_EBIONIZING_8449526340825632312: VariantsMap = [
    &["ebionizing"],
    &["ebionising"],
    &["ebionizing"],
    &["ebionising"],
];

pub(crate) static ENTRY_EBONIZATION_9459110214216310411: VariantsMap = [
    &["ebonization"],
    &["ebonisation"],
    &["ebonization"],
    &["ebonisation"],
];

pub(crate) static ENTRY_EBONIZED_2700368914274174610: VariantsMap =
    [&["ebonized"], &["ebonised"], &["ebonized"], &["ebonised"]];

pub(crate) static ENTRY_EBONIZES_6460531056601115454: VariantsMap =
    [&["ebonizes"], &["ebonises"], &["ebonizes"], &["ebonises"]];

pub(crate) static ENTRY_EBONIZE_6555944017551594352: VariantsMap =
    [&["ebonize"], &["ebonise"], &["ebonize"], &["ebonise"]];

pub(crate) static ENTRY_EBONIZING_3132402479188609625: VariantsMap = [
    &["ebonizing"],
    &["ebonising"],
    &["ebonizing"],
    &["ebonising"],
];

pub(crate) static ENTRY_ECCLESIASTICIZES_8360600305321731430: VariantsMap = [
    &["ecclesiasticizes"],
    &["ecclesiasticises"],
    &["ecclesiasticizes"],
    &["ecclesiasticises"],
];

pub(crate) static ENTRY_ECCLESIASTICIZE_10347749265631434353: VariantsMap = [
    &["ecclesiasticize"],
    &["ecclesiasticise"],
    &["ecclesiasticize"],
    &["ecclesiasticise"],
];

pub(crate) static ENTRY_ECHOIZED_10737085046643450160: VariantsMap =
    [&["echoized"], &["echoised"], &["echoized"], &["echoised"]];

pub(crate) static ENTRY_ECHOIZES_10397136139664473414: VariantsMap =
    [&["echoizes"], &["echoises"], &["echoizes"], &["echoises"]];

pub(crate) static ENTRY_ECHOIZE_5375579523966491386: VariantsMap =
    [&["echoize"], &["echoise"], &["echoize"], &["echoise"]];

pub(crate) static ENTRY_ECHOIZING_288199927771197334: VariantsMap = [
    &["echoizing"],
    &["echoising"],
    &["echoizing"],
    &["echoising"],
];

pub(crate) static ENTRY_ECLECTICIZES_12673848782293092933: VariantsMap = [
    &["eclecticizes"],
    &["eclecticises"],
    &["eclecticizes"],
    &["eclecticises"],
];

pub(crate) static ENTRY_ECLECTICIZE_13502059345443989224: VariantsMap = [
    &["eclecticize"],
    &["eclecticise"],
    &["eclecticize"],
    &["eclecticise"],
];

pub(crate) static ENTRY_ECOID_15394441758678226221: VariantsMap =
    [&["ecoid"], &["oecoid"], &["oecoid"], &["oecoid"]];

pub(crate) static ENTRY_ECONOMIZATIONS_934146159430176470: VariantsMap = [
    &["economizations"],
    &["economisations"],
    &["economizations"],
    &["economisations"],
];

pub(crate) static ENTRY_ECONOMIZATION_10728791833837936702: VariantsMap = [
    &["economization"],
    &["economisation"],
    &["economization"],
    &["economisation"],
];

pub(crate) static ENTRY_ECONOMIZED_7472643162983045891: VariantsMap = [
    &["economized"],
    &["economised"],
    &["economized"],
    &["economised"],
];

pub(crate) static ENTRY_ECONOMIZERS_11377293695267374301: VariantsMap = [
    &["economizers"],
    &["economisers"],
    &["economizers"],
    &["economisers"],
];

pub(crate) static ENTRY_ECONOMIZER_1145608432005541501: VariantsMap = [
    &["economizer"],
    &["economiser"],
    &["economizer"],
    &["economiser"],
];

pub(crate) static ENTRY_ECONOMIZES_15039806622307012464: VariantsMap = [
    &["economizes"],
    &["economises"],
    &["economizes"],
    &["economises"],
];

pub(crate) static ENTRY_ECONOMIZE_12047501793607810301: VariantsMap = [
    &["economize"],
    &["economise"],
    &["economize"],
    &["economise"],
];

pub(crate) static ENTRY_ECONOMIZING_9258997222217906936: VariantsMap = [
    &["economizing"],
    &["economising"],
    &["economizing"],
    &["economising"],
];

pub(crate) static ENTRY_ECOPHOBIA_5971973597118487121: VariantsMap = [
    &["ecophobia"],
    &["oecophobia"],
    &["oecophobia"],
    &["oecophobia"],
];

pub(crate) static ENTRY_ECSTASIZED_1854941639407331026: VariantsMap = [
    &["ecstasized"],
    &["ecstasised"],
    &["ecstasized"],
    &["ecstasised"],
];

pub(crate) static ENTRY_ECSTASIZES_13873477019720774589: VariantsMap = [
    &["ecstasizes"],
    &["ecstasises"],
    &["ecstasizes"],
    &["ecstasises"],
];

pub(crate) static ENTRY_ECSTASIZE_14049590323272222892: VariantsMap = [
    &["ecstasize"],
    &["ecstasise"],
    &["ecstasize"],
    &["ecstasise"],
];

pub(crate) static ENTRY_ECSTASIZING_6278162153824292928: VariantsMap = [
    &["ecstasizing"],
    &["ecstasising"],
    &["ecstasizing"],
    &["ecstasising"],
];

pub(crate) static ENTRY_ECSTATICIZES_16065796685331364725: VariantsMap = [
    &["ecstaticizes"],
    &["ecstaticises"],
    &["ecstaticizes"],
    &["ecstaticises"],
];

pub(crate) static ENTRY_ECSTATICIZE_13705022578144925366: VariantsMap = [
    &["ecstaticize"],
    &["ecstaticise"],
    &["ecstaticize"],
    &["ecstaticise"],
];

pub(crate) static ENTRY_ECTETHMOID_12099837169797274294: VariantsMap = [
    &["ectethmoid"],
    &["ectoethmoid"],
    &["ectoethmoid"],
    &["ectoethmoid"],
];

pub(crate) static ENTRY_ECTOCELIC_6998878818827985507: VariantsMap = [
    &["ectocelic"],
    &["ectocoelic"],
    &["ectocoelic"],
    &["ectocoelic"],
];

pub(crate) static ENTRY_ECUMENICALISM_16608780476444919974: VariantsMap = [
    &["ecumenicalism"],
    &["ecumenicalism"],
    &["ecumenicalism"],
    &["ecumenicalism"],
];

pub(crate) static ENTRY_ECUMENICITY_12037844523161670010: VariantsMap = [
    &["ecumenicity"],
    &["ecumenicity"],
    &["ecumenicity"],
    &["ecumenicity"],
];

pub(crate) static ENTRY_ECUMENIC_8234812006342728847: VariantsMap =
    [&["ecumenic"], &["ecumenic"], &["ecumenic"], &["ecumenic"]];

pub(crate) static ENTRY_ECUMENISM_1878909652524904058: VariantsMap = [
    &["ecumenism"],
    &["ecumenism"],
    &["ecumenism"],
    &["ecumenism"],
];

pub(crate) static ENTRY_ECUS_6730015734116715954: VariantsMap =
    [&["ecus"], &["oecus"], &["oecus"], &["oecus"]];

pub(crate) static ENTRY_EC_8754556227184431879: VariantsMap =
    [&["ec"], &["aec"], &["aec"], &["aec"]];

pub(crate) static ENTRY_EDEMAS_2647107175205211125: VariantsMap =
    [&["edemas"], &["oedemas"], &["edemas"], &["oedemas"]];

pub(crate) static ENTRY_EDEMATOSE_8946823576029811633: VariantsMap = [
    &["edematose"],
    &["oedematose"],
    &["edematose"],
    &["oedematose"],
];

pub(crate) static ENTRY_EDEMATOUS_6296161129737314269: VariantsMap = [
    &["edematous"],
    &["oedematous"],
    &["edematous"],
    &["oedematous"],
];

pub(crate) static ENTRY_EDEMA_6077775640730618555: VariantsMap =
    [&["edema"], &["oedema"], &["edema"], &["oedema"]];

pub(crate) static ENTRY_EDENIZATIONS_1883865383083433566: VariantsMap = [
    &["edenizations"],
    &["edenisations"],
    &["edenizations"],
    &["edenisations"],
];

pub(crate) static ENTRY_EDENIZATION_4357865095140457300: VariantsMap = [
    &["edenization"],
    &["edenisation"],
    &["edenization"],
    &["edenisation"],
];

pub(crate) static ENTRY_EDENIZES_668371311599264061: VariantsMap =
    [&["edenizes"], &["edenises"], &["edenizes"], &["edenises"]];

pub(crate) static ENTRY_EDENIZE_15838328178845287775: VariantsMap =
    [&["edenize"], &["edenise"], &["edenize"], &["edenise"]];

pub(crate) static ENTRY_EDICULE_900504125909275639: VariantsMap =
    [&["edicule"], &["aedicule"], &["aedicule"], &["aedicule"]];

pub(crate) static ENTRY_EDILITY_15442566410145406587: VariantsMap =
    [&["edility"], &["aedility"], &["aedility"], &["aedility"]];

pub(crate) static ENTRY_EDITORIALIZATIONS_18043149717600446569: VariantsMap = [
    &["editorializations"],
    &["editorialisations"],
    &["editorializations"],
    &["editorialisations"],
];

pub(crate) static ENTRY_EDITORIALIZATION_5806097145075247310: VariantsMap = [
    &["editorialization"],
    &["editorialisation"],
    &["editorialization"],
    &["editorialisation"],
];

pub(crate) static ENTRY_EDITORIALIZED_206766284852555978: VariantsMap = [
    &["editorialized"],
    &["editorialised"],
    &["editorialized"],
    &["editorialised"],
];

pub(crate) static ENTRY_EDITORIALIZER_13476720904730177780: VariantsMap = [
    &["editorializer"],
    &["editorialiser"],
    &["editorializer"],
    &["editorialiser"],
];

pub(crate) static ENTRY_EDITORIALIZES_7980175984307295032: VariantsMap = [
    &["editorializes"],
    &["editorialises"],
    &["editorializes"],
    &["editorialises"],
];

pub(crate) static ENTRY_EDITORIALIZE_14666089880239131679: VariantsMap = [
    &["editorialize"],
    &["editorialise"],
    &["editorialize"],
    &["editorialise"],
];

pub(crate) static ENTRY_EDITORIALIZING_6393585257106387800: VariantsMap = [
    &["editorializing"],
    &["editorialising"],
    &["editorializing"],
    &["editorialising"],
];

pub(crate) static ENTRY_EETION_14909833508202494568: VariantsMap =
    [&["eetion"], &["eaetion"], &["eaetion"], &["eaetion"]];

pub(crate) static ENTRY_EFFECTUALIZES_15433429353568095613: VariantsMap = [
    &["effectualizes"],
    &["effectualises"],
    &["effectualizes"],
    &["effectualises"],
];

pub(crate) static ENTRY_EFFECTUALIZE_16511416708524415811: VariantsMap = [
    &["effectualize"],
    &["effectualise"],
    &["effectualize"],
    &["effectualise"],
];

pub(crate) static ENTRY_EFFEMINATIZES_16307402669566024545: VariantsMap = [
    &["effeminatizes"],
    &["effeminatises"],
    &["effeminatizes"],
    &["effeminatises"],
];

pub(crate) static ENTRY_EFFEMINATIZE_4375919794746191: VariantsMap = [
    &["effeminatize"],
    &["effeminatise"],
    &["effeminatize"],
    &["effeminatise"],
];

pub(crate) static ENTRY_EFFEMINIZATION_7704851332662455069: VariantsMap = [
    &["effeminization"],
    &["effeminisation"],
    &["effeminization"],
    &["effeminisation"],
];

pub(crate) static ENTRY_EFFEMINIZED_1459056698758933158: VariantsMap = [
    &["effeminized"],
    &["effeminised"],
    &["effeminized"],
    &["effeminised"],
];

pub(crate) static ENTRY_EFFEMINIZES_2248031475942155787: VariantsMap = [
    &["effeminizes"],
    &["effeminises"],
    &["effeminizes"],
    &["effeminises"],
];

pub(crate) static ENTRY_EFFEMINIZE_3516173139622441926: VariantsMap = [
    &["effeminize"],
    &["effeminise"],
    &["effeminize"],
    &["effeminise"],
];

pub(crate) static ENTRY_EFFEMINIZING_13337240329061769635: VariantsMap = [
    &["effeminizing"],
    &["effeminising"],
    &["effeminizing"],
    &["effeminising"],
];

pub(crate) static ENTRY_EGER_15629290598343730410: VariantsMap =
    [&["eger"], &["egre"], &["egre"], &["egre"]];

pub(crate) static ENTRY_EGER_16805159729335837493: VariantsMap =
    [&["eger"], &["aeger"], &["aeger"], &["aeger"]];

pub(crate) static ENTRY_EGILOPS_2883782480068163532: VariantsMap =
    [&["egilops"], &["aegilops"], &["aegilops"], &["aegilops"]];

pub(crate) static ENTRY_EGLOGUE_4915760052338290285: VariantsMap =
    [&["eglogue"], &["aeglogue"], &["aeglogue"], &["aeglogue"]];

pub(crate) static ENTRY_EGOIZERS_3556769201390449943: VariantsMap =
    [&["egoizers"], &["egoisers"], &["egoizers"], &["egoisers"]];

pub(crate) static ENTRY_EGOIZER_7689719757825702876: VariantsMap =
    [&["egoizer"], &["egoiser"], &["egoizer"], &["egoiser"]];

pub(crate) static ENTRY_EGOIZES_6193803137404587336: VariantsMap =
    [&["egoizes"], &["egoises"], &["egoizes"], &["egoises"]];

pub(crate) static ENTRY_EGOIZE_8499095864183592640: VariantsMap =
    [&["egoize"], &["egoise"], &["egoize"], &["egoise"]];

pub(crate) static ENTRY_EGOPHONY_7733383031638246128: VariantsMap = [
    &["egophony"],
    &["aegophony"],
    &["aegophony"],
    &["aegophony"],
];

pub(crate) static ENTRY_EGOTIZED_9678276687619622634: VariantsMap =
    [&["egotized"], &["egotised"], &["egotized"], &["egotised"]];

pub(crate) static ENTRY_EGOTIZES_4049349000890516266: VariantsMap =
    [&["egotizes"], &["egotises"], &["egotizes"], &["egotises"]];

pub(crate) static ENTRY_EGOTIZE_14094436066901592528: VariantsMap =
    [&["egotize"], &["egotise"], &["egotize"], &["egotise"]];

pub(crate) static ENTRY_EGOTIZING_4391273872729111861: VariantsMap = [
    &["egotizing"],
    &["egotising"],
    &["egotizing"],
    &["egotising"],
];

pub(crate) static ENTRY_EGRITUDE_5267691897554984547: VariantsMap = [
    &["egritude"],
    &["aegritude"],
    &["aegritude"],
    &["aegritude"],
];

pub(crate) static ENTRY_EGYPTIANIZATIONS_5796667291802777291: VariantsMap = [
    &["egyptianizations"],
    &["egyptianisations"],
    &["egyptianizations"],
    &["egyptianisations"],
];

pub(crate) static ENTRY_EGYPTIANIZATION_9169883473524518038: VariantsMap = [
    &["egyptianization"],
    &["egyptianisation"],
    &["egyptianization"],
    &["egyptianisation"],
];

pub(crate) static ENTRY_EGYPTIANIZED_9083945329210201285: VariantsMap = [
    &["egyptianized"],
    &["egyptianised"],
    &["egyptianized"],
    &["egyptianised"],
];

pub(crate) static ENTRY_EGYPTIANIZES_14853969803249155648: VariantsMap = [
    &["egyptianizes"],
    &["egyptianises"],
    &["egyptianizes"],
    &["egyptianises"],
];

pub(crate) static ENTRY_EGYPTIANIZE_10867825058237937480: VariantsMap = [
    &["egyptianize"],
    &["egyptianise"],
    &["egyptianize"],
    &["egyptianise"],
];

pub(crate) static ENTRY_EGYPTIANIZING_7796226165055521595: VariantsMap = [
    &["egyptianizing"],
    &["egyptianising"],
    &["egyptianizing"],
    &["egyptianising"],
];

pub(crate) static ENTRY_EGYPTIZES_2702823690355724579: VariantsMap = [
    &["egyptizes"],
    &["egyptises"],
    &["egyptizes"],
    &["egyptises"],
];

pub(crate) static ENTRY_EGYPTIZE_16657751372698010888: VariantsMap =
    [&["egyptize"], &["egyptise"], &["egyptize"], &["egyptise"]];

pub(crate) static ENTRY_ELASTICIZATION_160079200382997172: VariantsMap = [
    &["elasticization"],
    &["elasticisation"],
    &["elasticization"],
    &["elasticisation"],
];

pub(crate) static ENTRY_ELASTICIZED_16378886949968944812: VariantsMap = [
    &["elasticized"],
    &["elasticised"],
    &["elasticized"],
    &["elasticised"],
];

pub(crate) static ENTRY_ELASTICIZERS_15895644091982847846: VariantsMap = [
    &["elasticizers"],
    &["elasticisers"],
    &["elasticizers"],
    &["elasticisers"],
];

pub(crate) static ENTRY_ELASTICIZER_12748442626833347246: VariantsMap = [
    &["elasticizer"],
    &["elasticiser"],
    &["elasticizer"],
    &["elasticiser"],
];

pub(crate) static ENTRY_ELASTICIZES_3546799323082756456: VariantsMap = [
    &["elasticizes"],
    &["elasticises"],
    &["elasticizes"],
    &["elasticises"],
];

pub(crate) static ENTRY_ELASTICIZE_7825987963400402736: VariantsMap = [
    &["elasticize"],
    &["elasticise"],
    &["elasticize"],
    &["elasticise"],
];

pub(crate) static ENTRY_ELASTICIZING_16851673773156446389: VariantsMap = [
    &["elasticizing"],
    &["elasticising"],
    &["elasticizing"],
    &["elasticising"],
];

pub(crate) static ENTRY_ELECTRICALIZES_6359890112921706019: VariantsMap = [
    &["electricalizes"],
    &["electricalises"],
    &["electricalizes"],
    &["electricalises"],
];

pub(crate) static ENTRY_ELECTRICALIZE_10408403277460728719: VariantsMap = [
    &["electricalize"],
    &["electricalise"],
    &["electricalize"],
    &["electricalise"],
];

pub(crate) static ENTRY_ELECTRICIZES_6484922314210733081: VariantsMap = [
    &["electricizes"],
    &["electricises"],
    &["electricizes"],
    &["electricises"],
];

pub(crate) static ENTRY_ELECTRICIZE_17179687470251507747: VariantsMap = [
    &["electricize"],
    &["electricise"],
    &["electricize"],
    &["electricise"],
];

pub(crate) static ENTRY_ELECTRIZATIONS_10691212371398243727: VariantsMap = [
    &["electrizations"],
    &["electrisations"],
    &["electrizations"],
    &["electrisations"],
];

pub(crate) static ENTRY_ELECTRIZATION_9585656186418990449: VariantsMap = [
    &["electrization"],
    &["electrisation"],
    &["electrization"],
    &["electrisation"],
];

pub(crate) static ENTRY_ELECTRIZED_6176912453252287333: VariantsMap = [
    &["electrized"],
    &["electrised"],
    &["electrized"],
    &["electrised"],
];

pub(crate) static ENTRY_ELECTRIZES_18179582404392857702: VariantsMap = [
    &["electrizes"],
    &["electrises"],
    &["electrizes"],
    &["electrises"],
];

pub(crate) static ENTRY_ELECTRIZE_560401629974373513: VariantsMap = [
    &["electrize"],
    &["electrise"],
    &["electrize"],
    &["electrise"],
];

pub(crate) static ENTRY_ELECTRIZING_17105866607588659371: VariantsMap = [
    &["electrizing"],
    &["electrising"],
    &["electrizing"],
    &["electrising"],
];

pub(crate) static ENTRY_ELECTROANESTHESIAS_14756922461417032532: VariantsMap = [
    &["electroanesthesias"],
    &["electroanaesthesias"],
    &["electroanaesthesias"],
    &["electroanaesthesias"],
];

pub(crate) static ENTRY_ELECTROANESTHESIA_6504800833252803660: VariantsMap = [
    &["electroanesthesia"],
    &["electroanaesthesia"],
    &["electroanaesthesia"],
    &["electroanaesthesia"],
];

pub(crate) static ENTRY_ELECTROCAUTERIZATIONS_11357157871973014701: VariantsMap = [
    &["electrocauterizations"],
    &["electrocauterisations"],
    &["electrocauterizations"],
    &["electrocauterisations"],
];

pub(crate) static ENTRY_ELECTROCAUTERIZATION_5127236476860396497: VariantsMap = [
    &["electrocauterization"],
    &["electrocauterisation"],
    &["electrocauterization"],
    &["electrocauterisation"],
];

pub(crate) static ENTRY_ELECTRODIALYZERS_16624393262625707016: VariantsMap = [
    &["electrodialyzers"],
    &["electrodialysers"],
    &["electrodialysers"],
    &["electrodialysers"],
];

pub(crate) static ENTRY_ELECTRODIALYZER_2854817148687643579: VariantsMap = [
    &["electrodialyzer"],
    &["electrodialyser"],
    &["electrodialyser"],
    &["electrodialyser"],
];

pub(crate) static ENTRY_ELECTRODIALYZES_16178135564832840236: VariantsMap = [
    &["electrodialyzes"],
    &["electrodialyses"],
    &["electrodialyses"],
    &["electrodialyses"],
];

pub(crate) static ENTRY_ELECTRODIALYZE_10875654835912350289: VariantsMap = [
    &["electrodialyze"],
    &["electrodialyse"],
    &["electrodialyse"],
    &["electrodialyse"],
];

pub(crate) static ENTRY_ELECTROGALVANIZES_187330993183406189: VariantsMap = [
    &["electrogalvanizes"],
    &["electrogalvanises"],
    &["electrogalvanizes"],
    &["electrogalvanises"],
];

pub(crate) static ENTRY_ELECTROGALVANIZE_11291453603581738430: VariantsMap = [
    &["electrogalvanize"],
    &["electrogalvanise"],
    &["electrogalvanize"],
    &["electrogalvanise"],
];

pub(crate) static ENTRY_ELECTROHOMEOPATHIES_8865376272828187594: VariantsMap = [
    &["electrohomeopathies"],
    &["electrohomeopathies"],
    &["electrohomeopathies"],
    &["electrohomeopathies"],
];

pub(crate) static ENTRY_ELECTROHOMEOPATHY_12788411585728630698: VariantsMap = [
    &["electrohomeopathy"],
    &["electrohomeopathy"],
    &["electrohomeopathy"],
    &["electrohomeopathy"],
];

pub(crate) static ENTRY_ELECTROLYZATION_3832545805391829369: VariantsMap = [
    &["electrolyzation"],
    &["electrolysation"],
    &["electrolyzation"],
    &["electrolysation"],
];

pub(crate) static ENTRY_ELECTROLYZED_17631117637534703380: VariantsMap = [
    &["electrolyzed"],
    &["electrolysed"],
    &["electrolysed"],
    &["electrolysed"],
];

pub(crate) static ENTRY_ELECTROLYZER_1088513950259369032: VariantsMap = [
    &["electrolyzer"],
    &["electrolyser"],
    &["electrolyzer"],
    &["electrolyser"],
];

pub(crate) static ENTRY_ELECTROLYZES_552328508973853187: VariantsMap = [
    &["electrolyzes"],
    &["electrolyses"],
    &["electrolyses"],
    &["electrolyses"],
];

pub(crate) static ENTRY_ELECTROLYZE_208176436728592713: VariantsMap = [
    &["electrolyze"],
    &["electrolyse"],
    &["electrolyse"],
    &["electrolyse"],
];

pub(crate) static ENTRY_ELECTROLYZING_9191100302500650799: VariantsMap = [
    &["electrolyzing"],
    &["electrolysing"],
    &["electrolysing"],
    &["electrolysing"],
];

pub(crate) static ENTRY_ELECTROMAGNETIZABLE_9977774661858435354: VariantsMap = [
    &["electromagnetizable"],
    &["electromagnetisable"],
    &["electromagnetizable"],
    &["electromagnetisable"],
];

pub(crate) static ENTRY_ELECTROTONIZES_9469818555172774628: VariantsMap = [
    &["electrotonizes"],
    &["electrotonises"],
    &["electrotonizes"],
    &["electrotonises"],
];

pub(crate) static ENTRY_ELECTROTONIZE_4239933396232760980: VariantsMap = [
    &["electrotonize"],
    &["electrotonise"],
    &["electrotonize"],
    &["electrotonise"],
];

pub(crate) static ENTRY_ELEGIZED_16680402250437818257: VariantsMap =
    [&["elegized"], &["elegised"], &["elegized"], &["elegised"]];

pub(crate) static ENTRY_ELEGIZES_18250546226667841408: VariantsMap =
    [&["elegizes"], &["elegises"], &["elegizes"], &["elegises"]];

pub(crate) static ENTRY_ELEGIZE_6148791844217028940: VariantsMap =
    [&["elegize"], &["elegise"], &["elegize"], &["elegise"]];

pub(crate) static ENTRY_ELEGIZING_9684027986507103857: VariantsMap = [
    &["elegizing"],
    &["elegising"],
    &["elegizing"],
    &["elegising"],
];

pub(crate) static ENTRY_ELEMENTALIZES_16767925982953522971: VariantsMap = [
    &["elementalizes"],
    &["elementalises"],
    &["elementalizes"],
    &["elementalises"],
];

pub(crate) static ENTRY_ELEMENTALIZE_1297402832087129943: VariantsMap = [
    &["elementalize"],
    &["elementalise"],
    &["elementalize"],
    &["elementalise"],
];

pub(crate) static ENTRY_ELEOBLAST_3123904554517439917: VariantsMap = [
    &["eleoblast"],
    &["elaeoblast"],
    &["elaeoblast"],
    &["elaeoblast"],
];

pub(crate) static ENTRY_ELEOLITE_8948279489308596906: VariantsMap = [
    &["eleolite"],
    &["elaeolite"],
    &["elaeolite"],
    &["elaeolite"],
];

pub(crate) static ENTRY_ELEOMARGARIC_378965269236780731: VariantsMap = [
    &["eleomargaric"],
    &["elaeomargaric"],
    &["elaeomargaric"],
    &["elaeomargaric"],
];

pub(crate) static ENTRY_ELEOMETER_1848423254942890620: VariantsMap = [
    &["eleometer"],
    &["elaeometer"],
    &["elaeometer"],
    &["elaeometer"],
];

pub(crate) static ENTRY_ELEOPTENE_18118099583187992103: VariantsMap = [
    &["eleoptene"],
    &["elaeoptene"],
    &["elaeoptene"],
    &["elaeoptene"],
];

pub(crate) static ENTRY_ELIZABETHANIZES_17522723128509514668: VariantsMap = [
    &["elizabethanizes"],
    &["elizabethanises"],
    &["elizabethanizes"],
    &["elizabethanises"],
];

pub(crate) static ENTRY_ELIZABETHANIZE_6611539784579172980: VariantsMap = [
    &["elizabethanize"],
    &["elizabethanise"],
    &["elizabethanize"],
    &["elizabethanise"],
];

pub(crate) static ENTRY_ELIZABETHVILLE_4390374012236621457: VariantsMap = [
    &["elizabethville"],
    &["elisabethville"],
    &["elizabethville"],
    &["elisabethville"],
];

pub(crate) static ENTRY_EMBEDMENTS_3554420096971369231: VariantsMap = [
    &["embedments"],
    &["embedments"],
    &["embedments"],
    &["embedments"],
];

pub(crate) static ENTRY_EMBEDMENT_4196454539976023920: VariantsMap = [
    &["embedment"],
    &["embedment"],
    &["embedment"],
    &["embedment"],
];

pub(crate) static ENTRY_EMBLEMATICIZES_4315173766129339478: VariantsMap = [
    &["emblematicizes"],
    &["emblematicises"],
    &["emblematicizes"],
    &["emblematicises"],
];

pub(crate) static ENTRY_EMBLEMATICIZE_14235385586885543722: VariantsMap = [
    &["emblematicize"],
    &["emblematicise"],
    &["emblematicize"],
    &["emblematicise"],
];

pub(crate) static ENTRY_EMBLEMATIZATION_15777403494926706772: VariantsMap = [
    &["emblematization"],
    &["emblematisation"],
    &["emblematization"],
    &["emblematisation"],
];

pub(crate) static ENTRY_EMBLEMATIZED_13094007365723895528: VariantsMap = [
    &["emblematized"],
    &["emblematised"],
    &["emblematized"],
    &["emblematised"],
];

pub(crate) static ENTRY_EMBLEMATIZES_6955351418847090060: VariantsMap = [
    &["emblematizes"],
    &["emblematises"],
    &["emblematizes"],
    &["emblematises"],
];

pub(crate) static ENTRY_EMBLEMATIZE_1598009610505106027: VariantsMap = [
    &["emblematize"],
    &["emblematise"],
    &["emblematize"],
    &["emblematise"],
];

pub(crate) static ENTRY_EMBLEMATIZING_9369922012211496667: VariantsMap = [
    &["emblematizing"],
    &["emblematising"],
    &["emblematizing"],
    &["emblematising"],
];

pub(crate) static ENTRY_EMBLEMIZED_7258595819534288479: VariantsMap = [
    &["emblemized"],
    &["emblemised"],
    &["emblemized"],
    &["emblemised"],
];

pub(crate) static ENTRY_EMBLEMIZES_12663015673488660950: VariantsMap = [
    &["emblemizes"],
    &["emblemises"],
    &["emblemizes"],
    &["emblemises"],
];

pub(crate) static ENTRY_EMBLEMIZE_12554539049583522901: VariantsMap = [
    &["emblemize"],
    &["emblemise"],
    &["emblemize"],
    &["emblemise"],
];

pub(crate) static ENTRY_EMBLEMIZING_14792173425346345877: VariantsMap = [
    &["emblemizing"],
    &["emblemising"],
    &["emblemizing"],
    &["emblemising"],
];

pub(crate) static ENTRY_EMBOLIZATION_15457463761636708838: VariantsMap = [
    &["embolization"],
    &["embolisation"],
    &["embolization"],
    &["embolisation"],
];

pub(crate) static ENTRY_EMBOWELED_9208239197748486767: VariantsMap = [
    &["emboweled"],
    &["embowelled"],
    &["embowelled"],
    &["embowelled"],
];

pub(crate) static ENTRY_EMBOWELING_5074912198762807484: VariantsMap = [
    &["emboweling"],
    &["embowelling"],
    &["embowelling"],
    &["embowelling"],
];

pub(crate) static ENTRY_EMOTIONALIZATIONS_16883692557939492571: VariantsMap = [
    &["emotionalizations"],
    &["emotionalisations"],
    &["emotionalizations"],
    &["emotionalisations"],
];

pub(crate) static ENTRY_EMOTIONALIZATION_15477138597694532834: VariantsMap = [
    &["emotionalization"],
    &["emotionalisation"],
    &["emotionalization"],
    &["emotionalisation"],
];

pub(crate) static ENTRY_EMOTIONALIZED_6884440531306026397: VariantsMap = [
    &["emotionalized"],
    &["emotionalised"],
    &["emotionalized"],
    &["emotionalised"],
];

pub(crate) static ENTRY_EMOTIONALIZES_16647510988271072305: VariantsMap = [
    &["emotionalizes"],
    &["emotionalises"],
    &["emotionalizes"],
    &["emotionalises"],
];

pub(crate) static ENTRY_EMOTIONALIZE_11024287246619149998: VariantsMap = [
    &["emotionalize"],
    &["emotionalise"],
    &["emotionalize"],
    &["emotionalise"],
];

pub(crate) static ENTRY_EMOTIONALIZING_8290060333843675227: VariantsMap = [
    &["emotionalizing"],
    &["emotionalising"],
    &["emotionalizing"],
    &["emotionalising"],
];

pub(crate) static ENTRY_EMOTIONIZES_2839160854420329462: VariantsMap = [
    &["emotionizes"],
    &["emotionises"],
    &["emotionizes"],
    &["emotionises"],
];

pub(crate) static ENTRY_EMOTIONIZE_11005352662349605744: VariantsMap = [
    &["emotionize"],
    &["emotionise"],
    &["emotionize"],
    &["emotionise"],
];

pub(crate) static ENTRY_EMPATHIZED_1551573131065246112: VariantsMap = [
    &["empathized"],
    &["empathised"],
    &["empathized"],
    &["empathised"],
];

pub(crate) static ENTRY_EMPATHIZES_14920809075846536428: VariantsMap = [
    &["empathizes"],
    &["empathises"],
    &["empathizes"],
    &["empathises"],
];

pub(crate) static ENTRY_EMPATHIZE_4851926761652344693: VariantsMap = [
    &["empathize"],
    &["empathise"],
    &["empathize"],
    &["empathise"],
];

pub(crate) static ENTRY_EMPATHIZING_5521634151158166341: VariantsMap = [
    &["empathizing"],
    &["empathising"],
    &["empathizing"],
    &["empathising"],
];

pub(crate) static ENTRY_EMPERIZED_13349527569229044403: VariantsMap = [
    &["emperized"],
    &["emperised"],
    &["emperized"],
    &["emperised"],
];

pub(crate) static ENTRY_EMPERIZES_14942780282521384085: VariantsMap = [
    &["emperizes"],
    &["emperises"],
    &["emperizes"],
    &["emperises"],
];

pub(crate) static ENTRY_EMPERIZE_10489148982923796097: VariantsMap =
    [&["emperize"], &["emperise"], &["emperize"], &["emperise"]];

pub(crate) static ENTRY_EMPERIZING_506176528649772751: VariantsMap = [
    &["emperizing"],
    &["emperising"],
    &["emperizing"],
    &["emperising"],
];

pub(crate) static ENTRY_EMPESTIC_3802757668760612665: VariantsMap = [
    &["empestic"],
    &["empaestic"],
    &["empaestic"],
    &["empaestic"],
];

pub(crate) static ENTRY_EMPHASIZED_11690096218388969918: VariantsMap = [
    &["emphasized"],
    &["emphasised"],
    &["emphasized"],
    &["emphasised"],
];

pub(crate) static ENTRY_EMPHASIZERS_244529511784884025: VariantsMap = [
    &["emphasizers"],
    &["emphasisers"],
    &["emphasizers"],
    &["emphasisers"],
];

pub(crate) static ENTRY_EMPHASIZER_17617770184095459158: VariantsMap = [
    &["emphasizer"],
    &["emphasiser"],
    &["emphasizer"],
    &["emphasiser"],
];

pub(crate) static ENTRY_EMPHASIZES_12089402216306749832: VariantsMap = [
    &["emphasizes"],
    &["emphasises"],
    &["emphasizes"],
    &["emphasises"],
];

pub(crate) static ENTRY_EMPHASIZE_1866717834630982104: VariantsMap = [
    &["emphasize"],
    &["emphasise"],
    &["emphasize"],
    &["emphasise"],
];

pub(crate) static ENTRY_EMPHASIZING_2120491803588767663: VariantsMap = [
    &["emphasizing"],
    &["emphasising"],
    &["emphasizing"],
    &["emphasising"],
];

pub(crate) static ENTRY_EMPLOYEES_17687744840650937952: VariantsMap = [
    &["employees"],
    &["employees"],
    &["employees"],
    &["employees"],
];

pub(crate) static ENTRY_EMPLOYEE_17424105370251049414: VariantsMap =
    [&["employee"], &["employee"], &["employee"], &["employee"]];

pub(crate) static ENTRY_EMPYREUMATIZED_14903751623654391789: VariantsMap = [
    &["empyreumatized"],
    &["empyreumatised"],
    &["empyreumatized"],
    &["empyreumatised"],
];

pub(crate) static ENTRY_EMPYREUMATIZES_18243085845799514916: VariantsMap = [
    &["empyreumatizes"],
    &["empyreumatises"],
    &["empyreumatizes"],
    &["empyreumatises"],
];

pub(crate) static ENTRY_EMPYREUMATIZE_1873770942588424273: VariantsMap = [
    &["empyreumatize"],
    &["empyreumatise"],
    &["empyreumatize"],
    &["empyreumatise"],
];

pub(crate) static ENTRY_EMPYREUMATIZING_9596349812094662524: VariantsMap = [
    &["empyreumatizing"],
    &["empyreumatising"],
    &["empyreumatizing"],
    &["empyreumatising"],
];

pub(crate) static ENTRY_EMULED_9191420579655492028: VariantsMap =
    [&["emuled"], &["aemuled"], &["aemuled"], &["aemuled"]];

pub(crate) static ENTRY_EMULES_16077893382767699411: VariantsMap =
    [&["emules"], &["aemules"], &["aemules"], &["aemules"]];

pub(crate) static ENTRY_EMULE_16137428121845795673: VariantsMap =
    [&["emule"], &["aemule"], &["aemule"], &["aemule"]];

pub(crate) static ENTRY_EMULING_10065143813695027214: VariantsMap =
    [&["emuling"], &["aemuling"], &["aemuling"], &["aemuling"]];

pub(crate) static ENTRY_EMULSIONIZED_15524766724556141082: VariantsMap = [
    &["emulsionized"],
    &["emulsionised"],
    &["emulsionized"],
    &["emulsionised"],
];

pub(crate) static ENTRY_EMULSIONIZES_276500337258574013: VariantsMap = [
    &["emulsionizes"],
    &["emulsionises"],
    &["emulsionizes"],
    &["emulsionises"],
];

pub(crate) static ENTRY_EMULSIONIZE_3792988642215500768: VariantsMap = [
    &["emulsionize"],
    &["emulsionise"],
    &["emulsionize"],
    &["emulsionise"],
];

pub(crate) static ENTRY_EMULSIONIZING_14852761818650320419: VariantsMap = [
    &["emulsionizing"],
    &["emulsionising"],
    &["emulsionizing"],
    &["emulsionising"],
];

pub(crate) static ENTRY_ENAMELED_11306849032588231949: VariantsMap = [
    &["enameled"],
    &["enamelled"],
    &["enamelled"],
    &["enamelled"],
];

pub(crate) static ENTRY_ENAMELERS_5158818097595900189: VariantsMap = [
    &["enamelers"],
    &["enamellers"],
    &["enamellers"],
    &["enamellers"],
];

pub(crate) static ENTRY_ENAMELER_2186265811744360882: VariantsMap = [
    &["enameler"],
    &["enameller"],
    &["enameller"],
    &["enameller"],
];

pub(crate) static ENTRY_ENAMELINGS_6194997663710852731: VariantsMap = [
    &["enamelings"],
    &["enamellings"],
    &["enamellings"],
    &["enamellings"],
];

pub(crate) static ENTRY_ENAMELING_13986001605744876872: VariantsMap = [
    &["enameling"],
    &["enamelling"],
    &["enamelling"],
    &["enamelling"],
];

pub(crate) static ENTRY_ENAMELISTS_5202782684465152663: VariantsMap = [
    &["enamelists"],
    &["enamellists"],
    &["enamellists"],
    &["enamellists"],
];

pub(crate) static ENTRY_ENAMELIST_16185279376392399957: VariantsMap = [
    &["enamelist"],
    &["enamellist"],
    &["enamellist"],
    &["enamellist"],
];

pub(crate) static ENTRY_ENAMOREDNESSES_18182856296907046300: VariantsMap = [
    &["enamorednesses"],
    &["enamourednesses"],
    &["enamourednesses"],
    &["enamourednesses"],
];

pub(crate) static ENTRY_ENAMOREDNESS_17627085162072768847: VariantsMap = [
    &["enamoredness"],
    &["enamouredness"],
    &["enamouredness"],
    &["enamouredness"],
];

pub(crate) static ENTRY_ENAMOREDS_1170610777553507807: VariantsMap = [
    &["enamoreds"],
    &["enamoureds"],
    &["enamoureds"],
    &["enamoureds"],
];

pub(crate) static ENTRY_ENAMORED_3978396704928569217: VariantsMap = [
    &["enamored"],
    &["enamoured"],
    &["enamoured"],
    &["enamoured"],
];

pub(crate) static ENTRY_ENAMORING_873141923636435610: VariantsMap = [
    &["enamoring"],
    &["enamouring"],
    &["enamouring"],
    &["enamouring"],
];

pub(crate) static ENTRY_ENAMORMENTS_17749223050502368158: VariantsMap = [
    &["enamorments"],
    &["enamourments"],
    &["enamourments"],
    &["enamourments"],
];

pub(crate) static ENTRY_ENAMORMENT_9258481715906385804: VariantsMap = [
    &["enamorment"],
    &["enamourment"],
    &["enamourment"],
    &["enamourment"],
];

pub(crate) static ENTRY_ENAMORS_15866647987432832950: VariantsMap =
    [&["enamors"], &["enamours"], &["enamours"], &["enamours"]];

pub(crate) static ENTRY_ENAMOR_18438712925910130607: VariantsMap =
    [&["enamor"], &["enamour"], &["enamour"], &["enamour"]];

pub(crate) static ENTRY_ENARBORS_16761278477457337471: VariantsMap = [
    &["enarbors"],
    &["enarbours"],
    &["enarbours"],
    &["enarbours"],
];

pub(crate) static ENTRY_ENARBOR_14803042454779304272: VariantsMap =
    [&["enarbor"], &["enarbour"], &["enarbour"], &["enarbour"]];

pub(crate) static ENTRY_ENCARNALIZATION_5687752002387237278: VariantsMap = [
    &["encarnalization"],
    &["encarnalisation"],
    &["encarnalization"],
    &["encarnalisation"],
];

pub(crate) static ENTRY_ENCARNALIZED_43232854316302843: VariantsMap = [
    &["encarnalized"],
    &["encarnalised"],
    &["encarnalized"],
    &["encarnalised"],
];

pub(crate) static ENTRY_ENCARNALIZES_9595852378322748330: VariantsMap = [
    &["encarnalizes"],
    &["encarnalises"],
    &["encarnalizes"],
    &["encarnalises"],
];

pub(crate) static ENTRY_ENCARNALIZE_10254990161920998569: VariantsMap = [
    &["encarnalize"],
    &["encarnalise"],
    &["encarnalize"],
    &["encarnalise"],
];

pub(crate) static ENTRY_ENCARNALIZING_7494160605597126310: VariantsMap = [
    &["encarnalizing"],
    &["encarnalising"],
    &["encarnalizing"],
    &["encarnalising"],
];

pub(crate) static ENTRY_ENCEPHALOCELE_14437482288349987680: VariantsMap = [
    &["encephalocele"],
    &["encephalocoele"],
    &["encephalocoele"],
    &["encephalocoele"],
];

pub(crate) static ENTRY_ENCLOSED_1563410036667921820: VariantsMap =
    [&["enclosed"], &["enclosed"], &["enclosed"], &["enclosed"]];

pub(crate) static ENTRY_ENCLOSES_18044907393387133378: VariantsMap =
    [&["encloses"], &["encloses"], &["encloses"], &["encloses"]];

pub(crate) static ENTRY_ENCLOSE_10842906381131425887: VariantsMap =
    [&["enclose"], &["enclose"], &["enclose"], &["enclose"]];

pub(crate) static ENTRY_ENCLOSING_16339276559305482445: VariantsMap = [
    &["enclosing"],
    &["enclosing"],
    &["enclosing"],
    &["enclosing"],
];

pub(crate) static ENTRY_ENCOLORED_17559904051696090004: VariantsMap = [
    &["encolored"],
    &["encoloured"],
    &["encoloured"],
    &["encoloured"],
];

pub(crate) static ENTRY_ENCOLORING_5903264657709891608: VariantsMap = [
    &["encoloring"],
    &["encolouring"],
    &["encolouring"],
    &["encolouring"],
];

pub(crate) static ENTRY_ENCOLORS_9671987002199252106: VariantsMap = [
    &["encolors"],
    &["encolours"],
    &["encolours"],
    &["encolours"],
];

pub(crate) static ENTRY_ENCOLOR_1643265642387039771: VariantsMap =
    [&["encolor"], &["encolour"], &["encolour"], &["encolour"]];

pub(crate) static ENTRY_ENDAMEBAE_730607999186797325: VariantsMap = [
    &["endamebae"],
    &["endamoebae"],
    &["endamoebae"],
    &["endamoebae"],
];

pub(crate) static ENTRY_ENDAMEBAS_3287493942507319830: VariantsMap = [
    &["endamebas"],
    &["endamoebas"],
    &["endamoebas"],
    &["endamoebas"],
];

pub(crate) static ENTRY_ENDAMEBA_538229332483664315: VariantsMap = [
    &["endameba"],
    &["endamoeba"],
    &["endamoeba"],
    &["endamoeba"],
];

pub(crate) static ENTRY_ENDAMEBIASIS_3671057505608809337: VariantsMap = [
    &["endamebiasis"],
    &["endamoebiasis"],
    &["endamoebiasis"],
    &["endamoebiasis"],
];

pub(crate) static ENTRY_ENDAMEBIC_10948407921673346288: VariantsMap = [
    &["endamebic"],
    &["endamoebic"],
    &["endamoebic"],
    &["endamoebic"],
];

pub(crate) static ENTRY_ENDEAVORED_8875983943474804048: VariantsMap = [
    &["endeavored"],
    &["endeavoured"],
    &["endeavoured"],
    &["endeavoured"],
];

pub(crate) static ENTRY_ENDEAVORERS_16041450900390640384: VariantsMap = [
    &["endeavorers"],
    &["endeavourers"],
    &["endeavourers"],
    &["endeavourers"],
];

pub(crate) static ENTRY_ENDEAVORER_14408798200130866711: VariantsMap = [
    &["endeavorer"],
    &["endeavourer"],
    &["endeavourer"],
    &["endeavourer"],
];

pub(crate) static ENTRY_ENDEAVORING_13456096223476863134: VariantsMap = [
    &["endeavoring"],
    &["endeavouring"],
    &["endeavouring"],
    &["endeavouring"],
];

pub(crate) static ENTRY_ENDEAVORS_4206263397240885183: VariantsMap = [
    &["endeavors"],
    &["endeavours"],
    &["endeavours"],
    &["endeavours"],
];

pub(crate) static ENTRY_ENDEAVOR_16478995020577429674: VariantsMap = [
    &["endeavor"],
    &["endeavour"],
    &["endeavour"],
    &["endeavour"],
];

pub(crate) static ENTRY_ENDERS_7291520445086932474: VariantsMap =
    [&["enders"], &["endres"], &["endres"], &["endres"]];

pub(crate) static ENTRY_ENEID_6327528208754564632: VariantsMap =
    [&["eneid"], &["aeneid"], &["aeneid"], &["aeneid"]];

pub(crate) static ENTRY_ENERGIZATION_5579130930501114053: VariantsMap = [
    &["energization"],
    &["energisation"],
    &["energization"],
    &["energisation"],
];

pub(crate) static ENTRY_ENERGIZED_8110447848594482786: VariantsMap = [
    &["energized"],
    &["energised"],
    &["energized"],
    &["energised"],
];

pub(crate) static ENTRY_ENERGIZERS_15921231264985096207: VariantsMap = [
    &["energizers"],
    &["energisers"],
    &["energizers"],
    &["energisers"],
];

pub(crate) static ENTRY_ENERGIZER_12727132395961026060: VariantsMap = [
    &["energizer"],
    &["energiser"],
    &["energizer"],
    &["energiser"],
];

pub(crate) static ENTRY_ENERGIZES_15882306341173011479: VariantsMap = [
    &["energizes"],
    &["energises"],
    &["energizes"],
    &["energises"],
];

pub(crate) static ENTRY_ENERGIZE_4079145480961428012: VariantsMap =
    [&["energize"], &["energise"], &["energize"], &["energise"]];

pub(crate) static ENTRY_ENERGIZING_14435058947853843369: VariantsMap = [
    &["energizing"],
    &["energising"],
    &["energizing"],
    &["energising"],
];

pub(crate) static ENTRY_ENGLISHIZES_10510834442254353928: VariantsMap = [
    &["englishizes"],
    &["englishises"],
    &["englishizes"],
    &["englishises"],
];

pub(crate) static ENTRY_ENGLISHIZE_6818310543798957094: VariantsMap = [
    &["englishize"],
    &["englishise"],
    &["englishize"],
    &["englishise"],
];

pub(crate) static ENTRY_ENGRANDIZEMENTS_4881165755382957512: VariantsMap = [
    &["engrandizements"],
    &["engrandisements"],
    &["engrandizements"],
    &["engrandisements"],
];

pub(crate) static ENTRY_ENGRANDIZEMENT_17013895899210266240: VariantsMap = [
    &["engrandizement"],
    &["engrandisement"],
    &["engrandizement"],
    &["engrandisement"],
];

pub(crate) static ENTRY_ENGRANDIZES_10684955241961233394: VariantsMap = [
    &["engrandizes"],
    &["engrandises"],
    &["engrandizes"],
    &["engrandises"],
];

pub(crate) static ENTRY_ENGRANDIZE_12152353911680916734: VariantsMap = [
    &["engrandize"],
    &["engrandise"],
    &["engrandize"],
    &["engrandise"],
];

pub(crate) static ENTRY_ENHARBOR_17888270651607624999: VariantsMap = [
    &["enharbor"],
    &["enharbour"],
    &["enharbour"],
    &["enharbour"],
];

pub(crate) static ENTRY_ENHEMOSPORE_14381240700671698538: VariantsMap = [
    &["enhemospore"],
    &["enhaemospore"],
    &["enhaemospore"],
    &["enhaemospore"],
];

pub(crate) static ENTRY_ENHYPOSTATIZED_11845916538515240368: VariantsMap = [
    &["enhypostatized"],
    &["enhypostatised"],
    &["enhypostatized"],
    &["enhypostatised"],
];

pub(crate) static ENTRY_ENHYPOSTATIZES_17623173339471208010: VariantsMap = [
    &["enhypostatizes"],
    &["enhypostatises"],
    &["enhypostatizes"],
    &["enhypostatises"],
];

pub(crate) static ENTRY_ENHYPOSTATIZE_5938376974603134783: VariantsMap = [
    &["enhypostatize"],
    &["enhypostatise"],
    &["enhypostatize"],
    &["enhypostatise"],
];

pub(crate) static ENTRY_ENHYPOSTATIZING_13884097298898705257: VariantsMap = [
    &["enhypostatizing"],
    &["enhypostatising"],
    &["enhypostatizing"],
    &["enhypostatising"],
];

pub(crate) static ENTRY_ENIGMATIZED_7309679394180552266: VariantsMap = [
    &["enigmatized"],
    &["enigmatised"],
    &["enigmatized"],
    &["enigmatised"],
];

pub(crate) static ENTRY_ENIGMATIZES_2459417653809898623: VariantsMap = [
    &["enigmatizes"],
    &["enigmatises"],
    &["enigmatizes"],
    &["enigmatises"],
];

pub(crate) static ENTRY_ENIGMATIZE_17621425390583894662: VariantsMap = [
    &["enigmatize"],
    &["enigmatise"],
    &["enigmatize"],
    &["enigmatise"],
];

pub(crate) static ENTRY_ENIGMATIZING_1060322619558821397: VariantsMap = [
    &["enigmatizing"],
    &["enigmatising"],
    &["enigmatizing"],
    &["enigmatising"],
];

pub(crate) static ENTRY_ENOCYTE_12666928362851607670: VariantsMap =
    [&["enocyte"], &["oenocyte"], &["oenocyte"], &["oenocyte"]];

pub(crate) static ENTRY_ENOLIC_7934123335578564140: VariantsMap =
    [&["enolic"], &["oenolic"], &["oenolic"], &["oenolic"]];

pub(crate) static ENTRY_ENOLIZATIONS_13082595730021629708: VariantsMap = [
    &["enolizations"],
    &["enolisations"],
    &["enolizations"],
    &["enolisations"],
];

pub(crate) static ENTRY_ENOLIZATION_9661716343807765013: VariantsMap = [
    &["enolization"],
    &["enolisation"],
    &["enolization"],
    &["enolisation"],
];

pub(crate) static ENTRY_ENOLIZES_18021851679044538057: VariantsMap =
    [&["enolizes"], &["enolises"], &["enolizes"], &["enolises"]];

pub(crate) static ENTRY_ENOLIZE_14567106179969001314: VariantsMap =
    [&["enolize"], &["enolise"], &["enolize"], &["enolise"]];

pub(crate) static ENTRY_ENOLOGICAL_11189078660498192658: VariantsMap = [
    &["enological"],
    &["oenological"],
    &["oenological"],
    &["oenological"],
];

pub(crate) static ENTRY_ENOLOGISTS_1989647851737964355: VariantsMap = [
    &["enologists"],
    &["oenologists"],
    &["oenologists"],
    &["oenologists"],
];

pub(crate) static ENTRY_ENOLOGIST_382673391921246993: VariantsMap = [
    &["enologist"],
    &["oenologist"],
    &["oenologist"],
    &["oenologist"],
];

pub(crate) static ENTRY_ENOMANIA_9115311181322537124: VariantsMap = [
    &["enomania"],
    &["oenomania"],
    &["oenomania"],
    &["oenomania"],
];

pub(crate) static ENTRY_ENROLLMENTS_6330348617051249235: VariantsMap = [
    &["enrollments"],
    &["enrolments"],
    &["enrolments"],
    &["enrolments"],
];

pub(crate) static ENTRY_ENROLLMENT_1944796353205798833: VariantsMap = [
    &["enrollment"],
    &["enrolment"],
    &["enrolment"],
    &["enrolment"],
];

pub(crate) static ENTRY_ENROLLS_11547415760061099613: VariantsMap =
    [&["enrolls"], &["enrols"], &["enrols"], &["enrols"]];

pub(crate) static ENTRY_ENROLL_9372041037495900233: VariantsMap =
    [&["enroll"], &["enrol"], &["enrol"], &["enrol"]];

pub(crate) static ENTRY_ENSEPULCHERRED_3341755300145508002: VariantsMap = [
    &["ensepulcherred"],
    &["ensepulchred"],
    &["ensepulchred"],
    &["ensepulchred"],
];

pub(crate) static ENTRY_ENSEPULCHERRING_14903067822159669845: VariantsMap = [
    &["ensepulcherring"],
    &["ensepulchring"],
    &["ensepulchring"],
    &["ensepulchring"],
];

pub(crate) static ENTRY_ENSEPULCHERS_13477964500524967198: VariantsMap = [
    &["ensepulchers"],
    &["ensepulchres"],
    &["ensepulchres"],
    &["ensepulchres"],
];

pub(crate) static ENTRY_ENSEPULCHER_14205007025959790046: VariantsMap = [
    &["ensepulcher"],
    &["ensepulchre"],
    &["ensepulchre"],
    &["ensepulchre"],
];

pub(crate) static ENTRY_ENSORCELED_10144591300662625203: VariantsMap = [
    &["ensorceled"],
    &["ensorcelled"],
    &["ensorcelled"],
    &["ensorcelled"],
];

pub(crate) static ENTRY_ENSORCELS_18278488126536104634: VariantsMap = [
    &["ensorcels"],
    &["ensorcells"],
    &["ensorcells"],
    &["ensorcells"],
];

pub(crate) static ENTRY_ENTAMEBAE_17080199760776134373: VariantsMap = [
    &["entamebae"],
    &["entamoebae"],
    &["entamoebae"],
    &["entamoebae"],
];

pub(crate) static ENTRY_ENTAMEBAS_2614159645596308673: VariantsMap = [
    &["entamebas"],
    &["entamoebas"],
    &["entamoebas"],
    &["entamoebas"],
];

pub(crate) static ENTRY_ENTAMEBA_515548781888900607: VariantsMap = [
    &["entameba"],
    &["entamoeba"],
    &["entamoeba"],
    &["entamoeba"],
];

pub(crate) static ENTRY_ENTAMEBIC_3962021291130275067: VariantsMap = [
    &["entamebic"],
    &["entamoebic"],
    &["entamoebic"],
    &["entamoebic"],
];

pub(crate) static ENTRY_ENTENDERS_16112813918437445311: VariantsMap = [
    &["entenders"],
    &["entendres"],
    &["entendres"],
    &["entendres"],
];

pub(crate) static ENTRY_ENTENDER_9608567180113806684: VariantsMap =
    [&["entender"], &["entendre"], &["entendre"], &["entendre"]];

pub(crate) static ENTRY_ENTEROCELES_3728084489892614221: VariantsMap = [
    &["enteroceles"],
    &["enterocoeles"],
    &["enterocoeles"],
    &["enterocoeles"],
];

pub(crate) static ENTRY_ENTEROCELE_4323995811417375774: VariantsMap = [
    &["enterocele"],
    &["enterocoele"],
    &["enterocoele"],
    &["enterocoele"],
];

pub(crate) static ENTRY_ENTHRALLED_11841948867063911915: VariantsMap = [
    &["enthralled"],
    &["enthralled"],
    &["enthralled"],
    &["enthralled"],
];

pub(crate) static ENTRY_ENTHRALLING_1804014087037406105: VariantsMap = [
    &["enthralling"],
    &["enthralling"],
    &["enthralling"],
    &["enthralling"],
];

pub(crate) static ENTRY_ENTHRALLMENTS_3346774299329360123: VariantsMap = [
    &["enthrallments"],
    &["enthralments"],
    &["enthrallments"],
    &["enthralments"],
];

pub(crate) static ENTRY_ENTHRALLMENT_7453407253455951045: VariantsMap = [
    &["enthrallment"],
    &["enthralment"],
    &["enthrallment"],
    &["enthralment"],
];

pub(crate) static ENTRY_ENTHRALLS_12657636057000965567: VariantsMap =
    [&["enthralls"], &["enthrals"], &["enthralls"], &["enthrals"]];

pub(crate) static ENTRY_ENTHRALLS_4931585169072696150: VariantsMap =
    [&["enthralls"], &["enthrals"], &["enthralls"], &["enthrals"]];

pub(crate) static ENTRY_ENTHRALL_4754864491654938416: VariantsMap =
    [&["enthrall"], &["enthral"], &["enthrall"], &["enthral"]];

pub(crate) static ENTRY_ENTHRALL_5942778214277993445: VariantsMap =
    [&["enthrall"], &["enthral"], &["enthrall"], &["enthral"]];

pub(crate) static ENTRY_ENTHRONIZATIONS_8870953496378498617: VariantsMap = [
    &["enthronizations"],
    &["enthronisations"],
    &["enthronizations"],
    &["enthronisations"],
];

pub(crate) static ENTRY_ENTHRONIZATION_12839918799425697218: VariantsMap = [
    &["enthronization"],
    &["enthronisation"],
    &["enthronization"],
    &["enthronisation"],
];

pub(crate) static ENTRY_ENTHRONIZED_15202186930780507191: VariantsMap = [
    &["enthronized"],
    &["enthronised"],
    &["enthronized"],
    &["enthronised"],
];

pub(crate) static ENTRY_ENTHRONIZES_6720645734371175864: VariantsMap = [
    &["enthronizes"],
    &["enthronises"],
    &["enthronizes"],
    &["enthronises"],
];

pub(crate) static ENTRY_ENTHRONIZE_4727702664279282103: VariantsMap = [
    &["enthronize"],
    &["enthronise"],
    &["enthronize"],
    &["enthronise"],
];

pub(crate) static ENTRY_ENTHRONIZING_17481510445049896156: VariantsMap = [
    &["enthronizing"],
    &["enthronising"],
    &["enthronizing"],
    &["enthronising"],
];

pub(crate) static ENTRY_ENTOCELE_6126697644906764247: VariantsMap = [
    &["entocele"],
    &["entocoele"],
    &["entocoele"],
    &["entocoele"],
];

pub(crate) static ENTRY_ENTOMOLOGIZED_15797986690606619972: VariantsMap = [
    &["entomologized"],
    &["entomologised"],
    &["entomologized"],
    &["entomologised"],
];

pub(crate) static ENTRY_ENTOMOLOGIZES_13434995600613447653: VariantsMap = [
    &["entomologizes"],
    &["entomologises"],
    &["entomologizes"],
    &["entomologises"],
];

pub(crate) static ENTRY_ENTOMOLOGIZE_18232561452819589143: VariantsMap = [
    &["entomologize"],
    &["entomologise"],
    &["entomologize"],
    &["entomologise"],
];

pub(crate) static ENTRY_ENTOMOLOGIZING_14730252224524443237: VariantsMap = [
    &["entomologizing"],
    &["entomologising"],
    &["entomologizing"],
    &["entomologising"],
];

pub(crate) static ENTRY_ENTRE_17653472184293381292: VariantsMap =
    [&["entre"], &["entrae"], &["entrae"], &["entrae"]];

pub(crate) static ENTRY_ENVAPORS_15378716003112840751: VariantsMap = [
    &["envapors"],
    &["envapours"],
    &["envapours"],
    &["envapours"],
];

pub(crate) static ENTRY_ENVAPOR_6902516124365331189: VariantsMap =
    [&["envapor"], &["envapour"], &["envapour"], &["envapour"]];

pub(crate) static ENTRY_ENVENOMIZATION_14570274555559878933: VariantsMap = [
    &["envenomization"],
    &["envenomisation"],
    &["envenomization"],
    &["envenomisation"],
];

pub(crate) static ENTRY_EOLIC_1257979122017004290: VariantsMap =
    [&["eolic"], &["aeolic"], &["aeolic"], &["aeolic"]];

pub(crate) static ENTRY_EOLIPILES_15636106136610023127: VariantsMap = [
    &["eolipiles"],
    &["aeolipiles"],
    &["aeolipiles"],
    &["aeolipiles"],
];

pub(crate) static ENTRY_EOLIPILE_525577760526182208: VariantsMap = [
    &["eolipile"],
    &["aeolipile"],
    &["aeolipile"],
    &["aeolipile"],
];

pub(crate) static ENTRY_EOLOTROPIC_10112988872948927516: VariantsMap = [
    &["eolotropic"],
    &["aeolotropic"],
    &["aeolotropic"],
    &["aeolotropic"],
];

pub(crate) static ENTRY_EONIAN_16940933942216477131: VariantsMap =
    [&["eonian"], &["aeonian"], &["aeonian"], &["aeonian"]];

pub(crate) static ENTRY_EONISMS_13164743036852291403: VariantsMap =
    [&["eonisms"], &["aeonisms"], &["aeonisms"], &["aeonisms"]];

pub(crate) static ENTRY_EONISM_977800046438629687: VariantsMap =
    [&["eonism"], &["aeonism"], &["aeonism"], &["aeonism"]];

pub(crate) static ENTRY_EOPALEOZOIC_17786993622475697950: VariantsMap = [
    &["eopaleozoic"],
    &["eopalaeozoic"],
    &["eopalaeozoic"],
    &["eopalaeozoic"],
];

pub(crate) static ENTRY_EPAULETS_15943230211605632990: VariantsMap = [
    &["epaulets"],
    &["epaulettes"],
    &["epaulettes"],
    &["epaulettes"],
];

pub(crate) static ENTRY_EPAULET_3626800389363536157: VariantsMap =
    [&["epaulet"], &["epaulette"], &["epaulette"], &["epaulette"]];

pub(crate) static ENTRY_EPENETIC_7137716037631214199: VariantsMap = [
    &["epenetic"],
    &["epaenetic"],
    &["epaenetic"],
    &["epaenetic"],
];

pub(crate) static ENTRY_EPHETE_5581169510134543821: VariantsMap =
    [&["ephete"], &["ephetae"], &["ephetae"], &["ephetae"]];

pub(crate) static ENTRY_EPICELE_16748330680925123266: VariantsMap =
    [&["epicele"], &["epicoele"], &["epicoele"], &["epicoele"]];

pub(crate) static ENTRY_EPICENTERS_6438256216831055083: VariantsMap = [
    &["epicenters"],
    &["epicentres"],
    &["epicentres"],
    &["epicentres"],
];

pub(crate) static ENTRY_EPICENTER_7128649262146588844: VariantsMap = [
    &["epicenter"],
    &["epicentre"],
    &["epicentre"],
    &["epicentre"],
];

pub(crate) static ENTRY_EPICURIZED_14620920279528356442: VariantsMap = [
    &["epicurized"],
    &["epicurised"],
    &["epicurized"],
    &["epicurised"],
];

pub(crate) static ENTRY_EPICURIZES_17067337675366526772: VariantsMap = [
    &["epicurizes"],
    &["epicurises"],
    &["epicurizes"],
    &["epicurises"],
];

pub(crate) static ENTRY_EPICURIZE_339384262497516913: VariantsMap = [
    &["epicurize"],
    &["epicurise"],
    &["epicurize"],
    &["epicurise"],
];

pub(crate) static ENTRY_EPICURIZING_7255147326820591762: VariantsMap = [
    &["epicurizing"],
    &["epicurising"],
    &["epicurizing"],
    &["epicurising"],
];

pub(crate) static ENTRY_EPIDOTIZATIONS_5009347331420792794: VariantsMap = [
    &["epidotizations"],
    &["epidotisations"],
    &["epidotizations"],
    &["epidotisations"],
];

pub(crate) static ENTRY_EPIDOTIZATION_14902775533250389672: VariantsMap = [
    &["epidotization"],
    &["epidotisation"],
    &["epidotization"],
    &["epidotisation"],
];

pub(crate) static ENTRY_EPIDOTIZED_12015327785750521988: VariantsMap = [
    &["epidotized"],
    &["epidotised"],
    &["epidotized"],
    &["epidotised"],
];

pub(crate) static ENTRY_EPIGEAL_8599954853833471823: VariantsMap =
    [&["epigeal"], &["epigaeal"], &["epigaeal"], &["epigaeal"]];

pub(crate) static ENTRY_EPIGEAN_7444574345322565680: VariantsMap =
    [&["epigean"], &["epigaean"], &["epigaean"], &["epigaean"]];

pub(crate) static ENTRY_EPIGEOUS_1843834689848177694: VariantsMap = [
    &["epigeous"],
    &["epigaeous"],
    &["epigaeous"],
    &["epigaeous"],
];

pub(crate) static ENTRY_EPIGRAMMATIZATION_14888377290593438046: VariantsMap = [
    &["epigrammatization"],
    &["epigrammatisation"],
    &["epigrammatization"],
    &["epigrammatisation"],
];

pub(crate) static ENTRY_EPIGRAMMATIZED_17832059231855016110: VariantsMap = [
    &["epigrammatized"],
    &["epigrammatised"],
    &["epigrammatized"],
    &["epigrammatised"],
];

pub(crate) static ENTRY_EPIGRAMMATIZER_11151770505267022085: VariantsMap = [
    &["epigrammatizer"],
    &["epigrammatiser"],
    &["epigrammatizer"],
    &["epigrammatiser"],
];

pub(crate) static ENTRY_EPIGRAMMATIZES_801021722587007665: VariantsMap = [
    &["epigrammatizes"],
    &["epigrammatises"],
    &["epigrammatizes"],
    &["epigrammatises"],
];

pub(crate) static ENTRY_EPIGRAMMATIZE_5360335231973147569: VariantsMap = [
    &["epigrammatize"],
    &["epigrammatise"],
    &["epigrammatize"],
    &["epigrammatise"],
];

pub(crate) static ENTRY_EPIGRAMMATIZING_11225062443581711736: VariantsMap = [
    &["epigrammatizing"],
    &["epigrammatising"],
    &["epigrammatizing"],
    &["epigrammatising"],
];

pub(crate) static ENTRY_EPILOGIZED_9239195598114046533: VariantsMap = [
    &["epilogized"],
    &["epilogised"],
    &["epilogized"],
    &["epilogised"],
];

pub(crate) static ENTRY_EPILOGIZES_1074466568803602851: VariantsMap = [
    &["epilogizes"],
    &["epilogises"],
    &["epilogizes"],
    &["epilogises"],
];

pub(crate) static ENTRY_EPILOGIZE_13701609820260659621: VariantsMap = [
    &["epilogize"],
    &["epilogise"],
    &["epilogize"],
    &["epilogise"],
];

pub(crate) static ENTRY_EPILOGIZING_13798823667465605797: VariantsMap = [
    &["epilogizing"],
    &["epilogising"],
    &["epilogizing"],
    &["epilogising"],
];

pub(crate) static ENTRY_EPILOGUES_9706718333805199018: VariantsMap = [
    &["epilogues"],
    &["epilogues"],
    &["epilogues"],
    &["epilogues"],
];

pub(crate) static ENTRY_EPILOGUE_8824676410841380805: VariantsMap =
    [&["epilogue"], &["epilogue"], &["epilogue"], &["epilogue"]];

pub(crate) static ENTRY_EPILOGUIZED_17415882164073599805: VariantsMap = [
    &["epiloguized"],
    &["epiloguised"],
    &["epiloguized"],
    &["epiloguised"],
];

pub(crate) static ENTRY_EPILOGUIZES_12828768269078689177: VariantsMap = [
    &["epiloguizes"],
    &["epiloguises"],
    &["epiloguizes"],
    &["epiloguises"],
];

pub(crate) static ENTRY_EPILOGUIZE_2814822517319878967: VariantsMap = [
    &["epiloguize"],
    &["epiloguise"],
    &["epiloguize"],
    &["epiloguise"],
];

pub(crate) static ENTRY_EPILOGUIZING_4023466930614167148: VariantsMap = [
    &["epiloguizing"],
    &["epiloguising"],
    &["epiloguizing"],
    &["epiloguising"],
];

pub(crate) static ENTRY_EPIMERIZED_13169037228696214197: VariantsMap = [
    &["epimerized"],
    &["epimerised"],
    &["epimerized"],
    &["epimerised"],
];

pub(crate) static ENTRY_EPIMERIZE_15635504935650611188: VariantsMap = [
    &["epimerize"],
    &["epimerise"],
    &["epimerize"],
    &["epimerise"],
];

pub(crate) static ENTRY_EPIMERIZING_14470580452174137969: VariantsMap = [
    &["epimerizing"],
    &["epimerising"],
    &["epimerizing"],
    &["epimerising"],
];

pub(crate) static ENTRY_EPIPHANIZED_15880624717553136731: VariantsMap = [
    &["epiphanized"],
    &["epiphanised"],
    &["epiphanized"],
    &["epiphanised"],
];

pub(crate) static ENTRY_EPIPHANIZE_3514685295925609873: VariantsMap = [
    &["epiphanize"],
    &["epiphanise"],
    &["epiphanize"],
    &["epiphanise"],
];

pub(crate) static ENTRY_EPIPHANIZING_15479258772051321334: VariantsMap = [
    &["epiphanizing"],
    &["epiphanising"],
    &["epiphanizing"],
    &["epiphanising"],
];

pub(crate) static ENTRY_EPISCOPALIANIZES_10851922256306811868: VariantsMap = [
    &["episcopalianizes"],
    &["episcopalianises"],
    &["episcopalianizes"],
    &["episcopalianises"],
];

pub(crate) static ENTRY_EPISCOPALIANIZE_9902792268985434315: VariantsMap = [
    &["episcopalianize"],
    &["episcopalianise"],
    &["episcopalianize"],
    &["episcopalianise"],
];

pub(crate) static ENTRY_EPISCOPIZED_4410075735309180027: VariantsMap = [
    &["episcopized"],
    &["episcopised"],
    &["episcopized"],
    &["episcopised"],
];

pub(crate) static ENTRY_EPISCOPIZES_9047505263363914109: VariantsMap = [
    &["episcopizes"],
    &["episcopises"],
    &["episcopizes"],
    &["episcopises"],
];

pub(crate) static ENTRY_EPISCOPIZE_14167118950866758417: VariantsMap = [
    &["episcopize"],
    &["episcopise"],
    &["episcopize"],
    &["episcopise"],
];

pub(crate) static ENTRY_EPISCOPIZING_1519487872102985080: VariantsMap = [
    &["episcopizing"],
    &["episcopising"],
    &["episcopizing"],
    &["episcopising"],
];

pub(crate) static ENTRY_EPISTOLIZED_14624347640913463510: VariantsMap = [
    &["epistolized"],
    &["epistolised"],
    &["epistolized"],
    &["epistolised"],
];

pub(crate) static ENTRY_EPISTOLIZES_9570789106235050585: VariantsMap = [
    &["epistolizes"],
    &["epistolises"],
    &["epistolizes"],
    &["epistolises"],
];

pub(crate) static ENTRY_EPISTOLIZE_9159157513900675893: VariantsMap = [
    &["epistolize"],
    &["epistolise"],
    &["epistolize"],
    &["epistolise"],
];

pub(crate) static ENTRY_EPISTOLIZING_17459192367753910246: VariantsMap = [
    &["epistolizing"],
    &["epistolising"],
    &["epistolizing"],
    &["epistolising"],
];

pub(crate) static ENTRY_EPITAPHIZES_14199461099300441433: VariantsMap = [
    &["epitaphizes"],
    &["epitaphises"],
    &["epitaphizes"],
    &["epitaphises"],
];

pub(crate) static ENTRY_EPITAPHIZE_18363407027834066446: VariantsMap = [
    &["epitaphize"],
    &["epitaphise"],
    &["epitaphize"],
    &["epitaphise"],
];

pub(crate) static ENTRY_EPITHETIZES_15067064448215298570: VariantsMap = [
    &["epithetizes"],
    &["epithetises"],
    &["epithetizes"],
    &["epithetises"],
];

pub(crate) static ENTRY_EPITHETIZE_17660717439429211067: VariantsMap = [
    &["epithetize"],
    &["epithetise"],
    &["epithetize"],
    &["epithetise"],
];

pub(crate) static ENTRY_EPITOMIZATIONS_6345699152655468434: VariantsMap = [
    &["epitomizations"],
    &["epitomisations"],
    &["epitomizations"],
    &["epitomisations"],
];

pub(crate) static ENTRY_EPITOMIZATION_10587528992127024576: VariantsMap = [
    &["epitomization"],
    &["epitomisation"],
    &["epitomization"],
    &["epitomisation"],
];

pub(crate) static ENTRY_EPITOMIZED_14066301984118681615: VariantsMap = [
    &["epitomized"],
    &["epitomised"],
    &["epitomized"],
    &["epitomised"],
];

pub(crate) static ENTRY_EPITOMIZERS_16815945095580680385: VariantsMap = [
    &["epitomizers"],
    &["epitomisers"],
    &["epitomizers"],
    &["epitomisers"],
];

pub(crate) static ENTRY_EPITOMIZER_11237451189121702511: VariantsMap = [
    &["epitomizer"],
    &["epitomiser"],
    &["epitomizer"],
    &["epitomiser"],
];

pub(crate) static ENTRY_EPITOMIZES_1913888595081252026: VariantsMap = [
    &["epitomizes"],
    &["epitomises"],
    &["epitomizes"],
    &["epitomises"],
];

pub(crate) static ENTRY_EPITOMIZE_798154534644964032: VariantsMap = [
    &["epitomize"],
    &["epitomise"],
    &["epitomize"],
    &["epitomise"],
];

pub(crate) static ENTRY_EPITOMIZING_8673529461190796371: VariantsMap = [
    &["epitomizing"],
    &["epitomising"],
    &["epitomizing"],
    &["epitomising"],
];

pub(crate) static ENTRY_EQUALED_9280544645272281486: VariantsMap =
    [&["equaled"], &["equalled"], &["equalled"], &["equalled"]];

pub(crate) static ENTRY_EQUALING_2200698246943537365: VariantsMap = [
    &["equaling"],
    &["equalling"],
    &["equalling"],
    &["equalling"],
];

pub(crate) static ENTRY_EQUALIZATIONS_17119813704324078034: VariantsMap = [
    &["equalizations"],
    &["equalisations"],
    &["equalizations"],
    &["equalisations"],
];

pub(crate) static ENTRY_EQUALIZATION_15703715989268616381: VariantsMap = [
    &["equalization"],
    &["equalisation"],
    &["equalization"],
    &["equalisation"],
];

pub(crate) static ENTRY_EQUALIZED_13933428330870564759: VariantsMap = [
    &["equalized"],
    &["equalised"],
    &["equalized"],
    &["equalised"],
];

pub(crate) static ENTRY_EQUALIZERS_55108374391593906: VariantsMap = [
    &["equalizers"],
    &["equalisers"],
    &["equalizers"],
    &["equalisers"],
];

pub(crate) static ENTRY_EQUALIZER_12962637525747924057: VariantsMap = [
    &["equalizer"],
    &["equaliser"],
    &["equalizer"],
    &["equaliser"],
];

pub(crate) static ENTRY_EQUALIZES_11036742568829365058: VariantsMap = [
    &["equalizes"],
    &["equalises"],
    &["equalizes"],
    &["equalises"],
];

pub(crate) static ENTRY_EQUALIZE_2295006139195864596: VariantsMap =
    [&["equalize"], &["equalise"], &["equalize"], &["equalise"]];

pub(crate) static ENTRY_EQUALIZINGS_754862697182198741: VariantsMap = [
    &["equalizings"],
    &["equalisings"],
    &["equalizings"],
    &["equalisings"],
];

pub(crate) static ENTRY_EQUALIZING_8520313871903824117: VariantsMap = [
    &["equalizing"],
    &["equalising"],
    &["equalizing"],
    &["equalising"],
];

pub(crate) static ENTRY_EQUESTRIANIZES_4839701417403750708: VariantsMap = [
    &["equestrianizes"],
    &["equestrianises"],
    &["equestrianizes"],
    &["equestrianises"],
];

pub(crate) static ENTRY_EQUESTRIANIZE_8079823547575699416: VariantsMap = [
    &["equestrianize"],
    &["equestrianise"],
    &["equestrianize"],
    &["equestrianise"],
];

pub(crate) static ENTRY_EQ_4118536122320847820: VariantsMap =
    [&["eq"], &["aeq"], &["aeq"], &["aeq"]];

pub(crate) static ENTRY_ERBIAS_13402989534594842592: VariantsMap =
    [&["erbias"], &["rebias"], &["rebias"], &["rebias"]];

pub(crate) static ENTRY_ERBIA_9464736826289357890: VariantsMap =
    [&["erbia"], &["rebia"], &["rebia"], &["rebia"]];

pub(crate) static ENTRY_ERGOTIZED_2227326095484778825: VariantsMap = [
    &["ergotized"],
    &["ergotised"],
    &["ergotized"],
    &["ergotised"],
];

pub(crate) static ENTRY_ERGOTIZES_8473870319873551180: VariantsMap = [
    &["ergotizes"],
    &["ergotises"],
    &["ergotizes"],
    &["ergotises"],
];

pub(crate) static ENTRY_ERGOTIZE_574806398622764721: VariantsMap =
    [&["ergotize"], &["ergotise"], &["ergotize"], &["ergotise"]];

pub(crate) static ENTRY_ERGOTIZING_1812522634071321138: VariantsMap = [
    &["ergotizing"],
    &["ergotising"],
    &["ergotizing"],
    &["ergotising"],
];

pub(crate) static ENTRY_ERICAL_8655189856383454932: VariantsMap =
    [&["erical"], &["aerical"], &["aerical"], &["aerical"]];

pub(crate) static ENTRY_ERIC_17025031939768003248: VariantsMap =
    [&["eric"], &["aeric"], &["aeric"], &["aeric"]];

pub(crate) static ENTRY_ERKE_8619846018234689500: VariantsMap =
    [&["erke"], &["reke"], &["reke"], &["reke"]];

pub(crate) static ENTRY_ERNEST_15293673726653605695: VariantsMap =
    [&["ernest"], &["renest"], &["renest"], &["renest"]];

pub(crate) static ENTRY_ERNES_5463728212363901261: VariantsMap =
    [&["ernes"], &["renes"], &["renes"], &["renes"]];

pub(crate) static ENTRY_ERNS_12150371209659416497: VariantsMap =
    [&["erns"], &["rens"], &["rens"], &["rens"]];

pub(crate) static ENTRY_ERN_104294260841087582: VariantsMap =
    [&["ern"], &["ren"], &["ren"], &["ren"]];

pub(crate) static ENTRY_EROGENESIS_4160838603281198154: VariantsMap = [
    &["erogenesis"],
    &["aerogenesis"],
    &["aerogenesis"],
    &["aerogenesis"],
];

pub(crate) static ENTRY_EROGENIC_3471326385946721331: VariantsMap = [
    &["erogenic"],
    &["aerogenic"],
    &["aerogenic"],
    &["aerogenic"],
];

pub(crate) static ENTRY_EROSE_3198202279341053863: VariantsMap =
    [&["erose"], &["aerose"], &["aerose"], &["aerose"]];

pub(crate) static ENTRY_EROS_3972390604755404559: VariantsMap =
    [&["eros"], &["aeros"], &["aeros"], &["aeros"]];

pub(crate) static ENTRY_EROTICIZATION_1842467549610586129: VariantsMap = [
    &["eroticization"],
    &["eroticisation"],
    &["eroticization"],
    &["eroticisation"],
];

pub(crate) static ENTRY_EROTICIZED_1132548628285760117: VariantsMap = [
    &["eroticized"],
    &["eroticised"],
    &["eroticized"],
    &["eroticised"],
];

pub(crate) static ENTRY_EROTICIZES_15223201339169694346: VariantsMap = [
    &["eroticizes"],
    &["eroticises"],
    &["eroticizes"],
    &["eroticises"],
];

pub(crate) static ENTRY_EROTICIZE_12872311394873552692: VariantsMap = [
    &["eroticize"],
    &["eroticise"],
    &["eroticize"],
    &["eroticise"],
];

pub(crate) static ENTRY_EROTICIZING_14473356132824862336: VariantsMap = [
    &["eroticizing"],
    &["eroticising"],
    &["eroticizing"],
    &["eroticising"],
];

pub(crate) static ENTRY_ERSES_7688907969133909794: VariantsMap =
    [&["erses"], &["reses"], &["reses"], &["reses"]];

pub(crate) static ENTRY_ERSH_7419460282608909511: VariantsMap =
    [&["ersh"], &["resh"], &["resh"], &["resh"]];

pub(crate) static ENTRY_ERT_16435602001912306536: VariantsMap =
    [&["ert"], &["ret"], &["ret"], &["ret"]];

pub(crate) static ENTRY_ERUGINOUS_14659575552896773213: VariantsMap = [
    &["eruginous"],
    &["aeruginous"],
    &["aeruginous"],
    &["aeruginous"],
];

pub(crate) static ENTRY_ERUGOS_8349991962965375484: VariantsMap =
    [&["erugos"], &["aerugos"], &["aerugos"], &["aerugos"]];

pub(crate) static ENTRY_ERUGO_5752272360915842141: VariantsMap =
    [&["erugo"], &["aerugo"], &["aerugo"], &["aerugo"]];

pub(crate) static ENTRY_ERVALENTAS_767903353833953973: VariantsMap = [
    &["ervalentas"],
    &["revalentas"],
    &["revalentas"],
    &["revalentas"],
];

pub(crate) static ENTRY_ERVALENTA_7976991325469128987: VariantsMap = [
    &["ervalenta"],
    &["revalenta"],
    &["revalenta"],
    &["revalenta"],
];

pub(crate) static ENTRY_ERYTHREAN_7272728649221707912: VariantsMap = [
    &["erythrean"],
    &["erythraean"],
    &["erythraean"],
    &["erythraean"],
];

pub(crate) static ENTRY_ERYTHREMIA_6911299021657199922: VariantsMap = [
    &["erythremia"],
    &["erythraemia"],
    &["erythraemia"],
    &["erythraemia"],
];

pub(crate) static ENTRY_ESCALADES_9736873074637956409: VariantsMap = [
    &["escalades"],
    &["escaladoes"],
    &["escaladoes"],
    &["escaladoes"],
];

pub(crate) static ENTRY_ESCHYNITE_2605089747859204015: VariantsMap = [
    &["eschynite"],
    &["aeschynite"],
    &["aeschynite"],
    &["aeschynite"],
];

pub(crate) static ENTRY_ESCULAPIAN_13519492358303592154: VariantsMap = [
    &["esculapian"],
    &["aesculapian"],
    &["aesculapian"],
    &["aesculapian"],
];

pub(crate) static ENTRY_ESCULETIN_672994155433346330: VariantsMap = [
    &["esculetin"],
    &["aesculetin"],
    &["aesculetin"],
    &["aesculetin"],
];

pub(crate) static ENTRY_ESCULIN_12107528280435336696: VariantsMap =
    [&["esculin"], &["aesculin"], &["aesculin"], &["aesculin"]];

pub(crate) static ENTRY_ESC_11648574405051320816: VariantsMap =
    [&["esc"], &["aesc"], &["aesc"], &["aesc"]];

pub(crate) static ENTRY_ESKIMOIZEDS_2972627145285856881: VariantsMap = [
    &["eskimoizeds"],
    &["eskimoiseds"],
    &["eskimoizeds"],
    &["eskimoiseds"],
];

pub(crate) static ENTRY_ESKIMOIZED_10184376049707311673: VariantsMap = [
    &["eskimoized"],
    &["eskimoised"],
    &["eskimoized"],
    &["eskimoised"],
];

pub(crate) static ENTRY_ESOPHAGAL_11568993434283087514: VariantsMap = [
    &["esophagal"],
    &["oesophagal"],
    &["oesophagal"],
    &["oesophagal"],
];

pub(crate) static ENTRY_ESOPHAGEAN_9494840858799849160: VariantsMap = [
    &["esophagean"],
    &["oesophagean"],
    &["oesophagean"],
    &["oesophagean"],
];

pub(crate) static ENTRY_ESOPHAGISMUS_12116284235422316328: VariantsMap = [
    &["esophagismus"],
    &["oesophagismus"],
    &["oesophagismus"],
    &["oesophagismus"],
];

pub(crate) static ENTRY_ESOPHAGISM_13497979405696032460: VariantsMap = [
    &["esophagism"],
    &["oesophagism"],
    &["oesophagism"],
    &["oesophagism"],
];

pub(crate) static ENTRY_ESOPHAGITIS_13843737924467364508: VariantsMap = [
    &["esophagitis"],
    &["oesophagitis"],
    &["oesophagitis"],
    &["oesophagitis"],
];

pub(crate) static ENTRY_ESOPHAGI_11954876978132806506: VariantsMap =
    [&["esophagi"], &["oesophagi"], &["esophagi"], &["oesophagi"]];

pub(crate) static ENTRY_ESOPHAGUS_17094499599237101062: VariantsMap = [
    &["esophagus"],
    &["oesophagus"],
    &["oesophagus"],
    &["oesophagus"],
];

pub(crate) static ENTRY_ESOP_12400930167674936381: VariantsMap =
    [&["esop"], &["aesop"], &["aesop"], &["aesop"]];

pub(crate) static ENTRY_ESSENIZES_14419866103970364748: VariantsMap = [
    &["essenizes"],
    &["essenises"],
    &["essenizes"],
    &["essenises"],
];

pub(crate) static ENTRY_ESSENIZE_18159451946304315226: VariantsMap =
    [&["essenize"], &["essenise"], &["essenize"], &["essenise"]];

pub(crate) static ENTRY_ESSENTIALIZES_7259234954513904851: VariantsMap = [
    &["essentializes"],
    &["essentialises"],
    &["essentializes"],
    &["essentialises"],
];

pub(crate) static ENTRY_ESSENTIALIZE_9743875167123692674: VariantsMap = [
    &["essentialize"],
    &["essentialise"],
    &["essentialize"],
    &["essentialise"],
];

pub(crate) static ENTRY_ESTERIZATIONS_1619303577440464586: VariantsMap = [
    &["esterizations"],
    &["esterisations"],
    &["esterizations"],
    &["esterisations"],
];

pub(crate) static ENTRY_ESTERIZATION_3456588518882788686: VariantsMap = [
    &["esterization"],
    &["esterisation"],
    &["esterization"],
    &["esterisation"],
];

pub(crate) static ENTRY_ESTERIZES_4040354113500129245: VariantsMap = [
    &["esterizes"],
    &["esterises"],
    &["esterizes"],
    &["esterises"],
];

pub(crate) static ENTRY_ESTERIZE_12877587379463570837: VariantsMap =
    [&["esterize"], &["esterise"], &["esterize"], &["esterise"]];

pub(crate) static ENTRY_ESTHESES_5781061020988119088: VariantsMap = [
    &["estheses"],
    &["aestheses"],
    &["aestheses"],
    &["aestheses"],
];

pub(crate) static ENTRY_ESTHESIAS_18077472499145709356: VariantsMap = [
    &["esthesias"],
    &["aesthesias"],
    &["aesthesias"],
    &["aesthesias"],
];

pub(crate) static ENTRY_ESTHESIA_5605519706169745255: VariantsMap = [
    &["esthesia"],
    &["aesthesia"],
    &["aesthesia"],
    &["aesthesia"],
];

pub(crate) static ENTRY_ESTHESIOGENIC_8568990898680713091: VariantsMap = [
    &["esthesiogenic"],
    &["aesthesiogenic"],
    &["aesthesiogenic"],
    &["aesthesiogenic"],
];

pub(crate) static ENTRY_ESTHESIOGENS_2539942402442311753: VariantsMap = [
    &["esthesiogens"],
    &["aesthesiogens"],
    &["aesthesiogens"],
    &["aesthesiogens"],
];

pub(crate) static ENTRY_ESTHESIOGEN_13850970942201599568: VariantsMap = [
    &["esthesiogen"],
    &["aesthesiogen"],
    &["aesthesiogen"],
    &["aesthesiogen"],
];

pub(crate) static ENTRY_ESTHESIS_17178990420713935317: VariantsMap = [
    &["esthesis"],
    &["aesthesis"],
    &["aesthesis"],
    &["aesthesis"],
];

pub(crate) static ENTRY_ESTHETICAL_7594838462752271800: VariantsMap = [
    &["esthetical"],
    &["aesthetical"],
    &["aesthetical"],
    &["aesthetical"],
];

pub(crate) static ENTRY_ESTHETICIANS_16857352085837156733: VariantsMap = [
    &["estheticians"],
    &["aestheticians"],
    &["aestheticians"],
    &["aestheticians"],
];

pub(crate) static ENTRY_ESTHETICIAN_6690642998636082700: VariantsMap = [
    &["esthetician"],
    &["aesthetician"],
    &["aesthetician"],
    &["aesthetician"],
];

pub(crate) static ENTRY_ESTIVAL_11802673568747360369: VariantsMap =
    [&["estival"], &["aestival"], &["aestival"], &["aestival"]];

pub(crate) static ENTRY_ESTIVATED_5948189904457603376: VariantsMap = [
    &["estivated"],
    &["aestivated"],
    &["aestivated"],
    &["aestivated"],
];

pub(crate) static ENTRY_ESTIVATES_8627334418178723288: VariantsMap = [
    &["estivates"],
    &["aestivates"],
    &["aestivates"],
    &["aestivates"],
];

pub(crate) static ENTRY_ESTIVATE_10836493401844257867: VariantsMap = [
    &["estivate"],
    &["aestivate"],
    &["aestivate"],
    &["aestivate"],
];

pub(crate) static ENTRY_ESTIVATING_9498433178617024784: VariantsMap = [
    &["estivating"],
    &["aestivating"],
    &["aestivating"],
    &["aestivating"],
];

pub(crate) static ENTRY_ESTIVATIONS_15940487245092349305: VariantsMap = [
    &["estivations"],
    &["aestivations"],
    &["aestivations"],
    &["aestivations"],
];

pub(crate) static ENTRY_ESTIVATION_6434066985142123064: VariantsMap = [
    &["estivation"],
    &["aestivation"],
    &["aestivation"],
    &["aestivation"],
];

pub(crate) static ENTRY_ESTIVATOR_1664787615112181438: VariantsMap = [
    &["estivator"],
    &["aestivator"],
    &["aestivator"],
    &["aestivator"],
];

pub(crate) static ENTRY_ESTIVE_4965384148538852144: VariantsMap =
    [&["estive"], &["aestive"], &["aestive"], &["aestive"]];

pub(crate) static ENTRY_ESTRADIOLS_6635571464074472879: VariantsMap = [
    &["estradiols"],
    &["oestradiols"],
    &["oestradiols"],
    &["oestradiols"],
];

pub(crate) static ENTRY_ESTRADIOL_31151792297264606: VariantsMap = [
    &["estradiol"],
    &["oestradiol"],
    &["oestradiol"],
    &["oestradiol"],
];

pub(crate) static ENTRY_ESTRAL_4263474669881304636: VariantsMap =
    [&["estral"], &["oestral"], &["oestral"], &["oestral"]];

pub(crate) static ENTRY_ESTRINS_17829170952547459464: VariantsMap =
    [&["estrins"], &["oestrins"], &["oestrins"], &["oestrins"]];

pub(crate) static ENTRY_ESTRIN_17130710844251925900: VariantsMap =
    [&["estrin"], &["oestrin"], &["oestrin"], &["oestrin"]];

pub(crate) static ENTRY_ESTRIOLS_1134091154686696143: VariantsMap = [
    &["estriols"],
    &["oestriols"],
    &["oestriols"],
    &["oestriols"],
];

pub(crate) static ENTRY_ESTRIOL_14358431962924162389: VariantsMap =
    [&["estriol"], &["oestriol"], &["oestriol"], &["oestriol"]];

pub(crate) static ENTRY_ESTROGENIC_3724956938647222280: VariantsMap = [
    &["estrogenic"],
    &["oestrogenic"],
    &["estrogenic"],
    &["oestrogenic"],
];

pub(crate) static ENTRY_ESTROGENS_11487970579706669068: VariantsMap = [
    &["estrogens"],
    &["oestrogens"],
    &["estrogens"],
    &["oestrogens"],
];

pub(crate) static ENTRY_ESTROGEN_10173348120996063533: VariantsMap =
    [&["estrogen"], &["oestrogen"], &["estrogen"], &["oestrogen"]];

pub(crate) static ENTRY_ESTRONES_10736858198614463395: VariantsMap = [
    &["estrones"],
    &["oestrones"],
    &["oestrones"],
    &["oestrones"],
];

pub(crate) static ENTRY_ESTRONE_9986540566043863893: VariantsMap =
    [&["estrone"], &["oestrone"], &["oestrone"], &["oestrone"]];

pub(crate) static ENTRY_ESTROUS_7878210273842809015: VariantsMap =
    [&["estrous"], &["oestrous"], &["estrous"], &["oestrous"]];

pub(crate) static ENTRY_ESTRUAL_8880059716302502408: VariantsMap =
    [&["estrual"], &["oestrual"], &["oestrual"], &["oestrual"]];

pub(crate) static ENTRY_ESTRUATE_16347180830721817630: VariantsMap = [
    &["estruate"],
    &["oestruate"],
    &["oestruate"],
    &["oestruate"],
];

pub(crate) static ENTRY_ESTRUATION_16723443098265001574: VariantsMap = [
    &["estruation"],
    &["oestruation"],
    &["oestruation"],
    &["oestruation"],
];

pub(crate) static ENTRY_ESTRUMS_7268966665464885989: VariantsMap =
    [&["estrums"], &["oestrums"], &["oestrums"], &["oestrums"]];

pub(crate) static ENTRY_ESTRUM_14101011195419605525: VariantsMap =
    [&["estrum"], &["oestrum"], &["oestrum"], &["oestrum"]];

pub(crate) static ENTRY_ESTRUSES_7947106804154830951: VariantsMap =
    [&["estruses"], &["oestruses"], &["estruses"], &["oestruses"]];

pub(crate) static ENTRY_ESTRUS_391811675946213924: VariantsMap =
    [&["estrus"], &["oestrus"], &["estrus"], &["oestrus"]];

pub(crate) static ENTRY_ESTUATE_5365503068852828289: VariantsMap =
    [&["estuate"], &["aestuate"], &["aestuate"], &["aestuate"]];

pub(crate) static ENTRY_ESTUOUS_10323897909821636581: VariantsMap =
    [&["estuous"], &["aestuous"], &["aestuous"], &["aestuous"]];

pub(crate) static ENTRY_ESTURE_10845028240222484807: VariantsMap =
    [&["esture"], &["aesture"], &["aesture"], &["aesture"]];

pub(crate) static ENTRY_ESTUS_3275119451126332640: VariantsMap =
    [&["estus"], &["aestus"], &["aestus"], &["aestus"]];

pub(crate) static ENTRY_ETERNALIZATIONS_12324801645258560585: VariantsMap = [
    &["eternalizations"],
    &["eternalisations"],
    &["eternalizations"],
    &["eternalisations"],
];

pub(crate) static ENTRY_ETERNALIZATION_4110507715995538457: VariantsMap = [
    &["eternalization"],
    &["eternalisation"],
    &["eternalization"],
    &["eternalisation"],
];

pub(crate) static ENTRY_ETERNALIZED_3895092792354325191: VariantsMap = [
    &["eternalized"],
    &["eternalised"],
    &["eternalized"],
    &["eternalised"],
];

pub(crate) static ENTRY_ETERNALIZES_10340106011591437418: VariantsMap = [
    &["eternalizes"],
    &["eternalises"],
    &["eternalizes"],
    &["eternalises"],
];

pub(crate) static ENTRY_ETERNALIZE_16866605418824842181: VariantsMap = [
    &["eternalize"],
    &["eternalise"],
    &["eternalize"],
    &["eternalise"],
];

pub(crate) static ENTRY_ETERNALIZING_3666087619740459810: VariantsMap = [
    &["eternalizing"],
    &["eternalising"],
    &["eternalizing"],
    &["eternalising"],
];

pub(crate) static ENTRY_ETERNIZATIONS_8191041802187544405: VariantsMap = [
    &["eternizations"],
    &["eternisations"],
    &["eternizations"],
    &["eternisations"],
];

pub(crate) static ENTRY_ETERNIZATION_14956756864369663492: VariantsMap = [
    &["eternization"],
    &["eternisation"],
    &["eternization"],
    &["eternisation"],
];

pub(crate) static ENTRY_ETERNIZED_13686686999560830605: VariantsMap = [
    &["eternized"],
    &["eternised"],
    &["eternized"],
    &["eternised"],
];

pub(crate) static ENTRY_ETERNIZES_11290183965659731900: VariantsMap = [
    &["eternizes"],
    &["eternises"],
    &["eternizes"],
    &["eternises"],
];

pub(crate) static ENTRY_ETERNIZE_11185630111475812769: VariantsMap =
    [&["eternize"], &["eternise"], &["eternize"], &["eternise"]];

pub(crate) static ENTRY_ETERNIZING_11205061293945003520: VariantsMap = [
    &["eternizing"],
    &["eternising"],
    &["eternizing"],
    &["eternising"],
];

pub(crate) static ENTRY_ETHELING_18173115252038941149: VariantsMap = [
    &["etheling"],
    &["aetheling"],
    &["aetheling"],
    &["aetheling"],
];

pub(crate) static ENTRY_ETHEREALIZATIONS_83785244619387097: VariantsMap = [
    &["etherealizations"],
    &["etherealisations"],
    &["etherealizations"],
    &["etherealisations"],
];

pub(crate) static ENTRY_ETHEREALIZATION_13082768097000267498: VariantsMap = [
    &["etherealization"],
    &["etherealisation"],
    &["etherealization"],
    &["etherealisation"],
];

pub(crate) static ENTRY_ETHEREALIZED_8598724633944495192: VariantsMap = [
    &["etherealized"],
    &["etherealised"],
    &["etherealized"],
    &["etherealised"],
];

pub(crate) static ENTRY_ETHEREALIZES_2996813688575204992: VariantsMap = [
    &["etherealizes"],
    &["etherealises"],
    &["etherealizes"],
    &["etherealises"],
];

pub(crate) static ENTRY_ETHEREALIZE_15643873766006860610: VariantsMap = [
    &["etherealize"],
    &["etherealise"],
    &["etherealize"],
    &["etherealise"],
];

pub(crate) static ENTRY_ETHEREALIZING_9763005237046272153: VariantsMap = [
    &["etherealizing"],
    &["etherealising"],
    &["etherealizing"],
    &["etherealising"],
];

pub(crate) static ENTRY_ETHERED_14211226607017083705: VariantsMap =
    [&["ethered"], &["aethered"], &["aethered"], &["aethered"]];

pub(crate) static ENTRY_ETHERIALIZATION_16353693822285712895: VariantsMap = [
    &["etherialization"],
    &["etherialisation"],
    &["etherialization"],
    &["etherialisation"],
];

pub(crate) static ENTRY_ETHERIALIZED_17886169690318510304: VariantsMap = [
    &["etherialized"],
    &["etherialised"],
    &["etherialized"],
    &["etherialised"],
];

pub(crate) static ENTRY_ETHERIALIZE_9662916742832206613: VariantsMap = [
    &["etherialize"],
    &["etherialise"],
    &["etherialize"],
    &["etherialise"],
];

pub(crate) static ENTRY_ETHERIALIZING_8415609041393721050: VariantsMap = [
    &["etherializing"],
    &["etherialising"],
    &["etherializing"],
    &["etherialising"],
];

pub(crate) static ENTRY_ETHERIC_10479002354969561160: VariantsMap =
    [&["etheric"], &["aetheric"], &["aetheric"], &["aetheric"]];

pub(crate) static ENTRY_ETHERIZATIONS_13335802035112138: VariantsMap = [
    &["etherizations"],
    &["etherisations"],
    &["etherizations"],
    &["etherisations"],
];

pub(crate) static ENTRY_ETHERIZATION_15509189480857162676: VariantsMap = [
    &["etherization"],
    &["etherisation"],
    &["etherization"],
    &["etherisation"],
];

pub(crate) static ENTRY_ETHERIZED_12616495300571811734: VariantsMap = [
    &["etherized"],
    &["etherised"],
    &["etherized"],
    &["etherised"],
];

pub(crate) static ENTRY_ETHERIZERS_6371393300060848641: VariantsMap = [
    &["etherizers"],
    &["etherisers"],
    &["etherizers"],
    &["etherisers"],
];

pub(crate) static ENTRY_ETHERIZER_17889160100693239960: VariantsMap = [
    &["etherizer"],
    &["etheriser"],
    &["etherizer"],
    &["etheriser"],
];

pub(crate) static ENTRY_ETHERIZES_13639595418596582424: VariantsMap = [
    &["etherizes"],
    &["etherises"],
    &["etherizes"],
    &["etherises"],
];

pub(crate) static ENTRY_ETHERIZE_7063818294001377173: VariantsMap =
    [&["etherize"], &["etherise"], &["etherize"], &["etherise"]];

pub(crate) static ENTRY_ETHERIZING_1369052890079428803: VariantsMap = [
    &["etherizing"],
    &["etherising"],
    &["etherizing"],
    &["etherising"],
];

pub(crate) static ENTRY_ETHICIZATION_16096230827577668151: VariantsMap = [
    &["ethicization"],
    &["ethicisation"],
    &["ethicization"],
    &["ethicisation"],
];

pub(crate) static ENTRY_ETHICIZED_3108258699595454839: VariantsMap = [
    &["ethicized"],
    &["ethicised"],
    &["ethicized"],
    &["ethicised"],
];

pub(crate) static ENTRY_ETHICIZES_16736624923762826452: VariantsMap = [
    &["ethicizes"],
    &["ethicises"],
    &["ethicizes"],
    &["ethicises"],
];

pub(crate) static ENTRY_ETHICIZE_16707329152141021939: VariantsMap =
    [&["ethicize"], &["ethicise"], &["ethicize"], &["ethicise"]];

pub(crate) static ENTRY_ETHICIZING_1886109304857970107: VariantsMap = [
    &["ethicizing"],
    &["ethicising"],
    &["ethicizing"],
    &["ethicising"],
];

pub(crate) static ENTRY_ETHNICIZES_960663240708525169: VariantsMap = [
    &["ethnicizes"],
    &["ethnicises"],
    &["ethnicizes"],
    &["ethnicises"],
];

pub(crate) static ENTRY_ETHNICIZE_12312081762720332735: VariantsMap = [
    &["ethnicize"],
    &["ethnicise"],
    &["ethnicize"],
    &["ethnicise"],
];

pub(crate) static ENTRY_ETIOGENIC_3830033599800632807: VariantsMap = [
    &["etiogenic"],
    &["aetiogenic"],
    &["aetiogenic"],
    &["aetiogenic"],
];

pub(crate) static ENTRY_ETIOLOGICALLY_1064612193650452227: VariantsMap = [
    &["etiologically"],
    &["aetiologically"],
    &["etiologically"],
    &["aetiologically"],
];

pub(crate) static ENTRY_ETIOLOGIST_7320826493575703902: VariantsMap = [
    &["etiologist"],
    &["aetiologist"],
    &["aetiologist"],
    &["aetiologist"],
];

pub(crate) static ENTRY_ETIOLOGUE_4428360053767153112: VariantsMap = [
    &["etiologue"],
    &["aetiologue"],
    &["aetiologue"],
    &["aetiologue"],
];

pub(crate) static ENTRY_ETIOLOGY_4658311861857715324: VariantsMap =
    [&["etiology"], &["aetiology"], &["etiology"], &["aetiology"]];

pub(crate) static ENTRY_ETIOPHYLLIN_7707186585402559694: VariantsMap = [
    &["etiophyllin"],
    &["aetiophyllin"],
    &["aetiophyllin"],
    &["aetiophyllin"],
];

pub(crate) static ENTRY_ETIOTROPICALLY_1085913366626989126: VariantsMap = [
    &["etiotropically"],
    &["aetiotropically"],
    &["aetiotropically"],
    &["aetiotropically"],
];

pub(crate) static ENTRY_ETIOTROPIC_18055180651114367254: VariantsMap = [
    &["etiotropic"],
    &["aetiotropic"],
    &["aetiotropic"],
    &["aetiotropic"],
];

pub(crate) static ENTRY_ETYMOLOGIZABLE_1283253131804877951: VariantsMap = [
    &["etymologizable"],
    &["etymologisable"],
    &["etymologizable"],
    &["etymologisable"],
];

pub(crate) static ENTRY_ETYMOLOGIZATION_15298692810390985104: VariantsMap = [
    &["etymologization"],
    &["etymologisation"],
    &["etymologization"],
    &["etymologisation"],
];

pub(crate) static ENTRY_ETYMOLOGIZED_2645595824075873147: VariantsMap = [
    &["etymologized"],
    &["etymologised"],
    &["etymologized"],
    &["etymologised"],
];

pub(crate) static ENTRY_ETYMOLOGIZES_13710053144878095709: VariantsMap = [
    &["etymologizes"],
    &["etymologises"],
    &["etymologizes"],
    &["etymologises"],
];

pub(crate) static ENTRY_ETYMOLOGIZE_11288336530403962791: VariantsMap = [
    &["etymologize"],
    &["etymologise"],
    &["etymologize"],
    &["etymologise"],
];

pub(crate) static ENTRY_ETYMOLOGIZING_1743090802525341227: VariantsMap = [
    &["etymologizing"],
    &["etymologising"],
    &["etymologizing"],
    &["etymologising"],
];

pub(crate) static ENTRY_ET_16709700743642230371: VariantsMap =
    [&["et"], &["aet"], &["aet"], &["aet"]];

pub(crate) static ENTRY_EUDEMONIA_18223617891572262880: VariantsMap = [
    &["eudemonia"],
    &["eudaemonia"],
    &["eudaemonia"],
    &["eudaemonia"],
];

pub(crate) static ENTRY_EUDEMONICS_12311044969757068160: VariantsMap = [
    &["eudemonics"],
    &["eudaemonics"],
    &["eudaemonics"],
    &["eudaemonics"],
];

pub(crate) static ENTRY_EUDEMONIC_18143957865317361790: VariantsMap = [
    &["eudemonic"],
    &["eudaemonic"],
    &["eudaemonic"],
    &["eudaemonic"],
];

pub(crate) static ENTRY_EUDEMONISMS_17240174868453336510: VariantsMap = [
    &["eudemonisms"],
    &["eudaemonisms"],
    &["eudaemonisms"],
    &["eudaemonisms"],
];

pub(crate) static ENTRY_EUDEMONISM_3198415778868906023: VariantsMap = [
    &["eudemonism"],
    &["eudaemonism"],
    &["eudaemonism"],
    &["eudaemonism"],
];

pub(crate) static ENTRY_EUDEMONISTICALLY_14824474640377417299: VariantsMap = [
    &["eudemonistically"],
    &["eudaemonistically"],
    &["eudaemonistically"],
    &["eudaemonistically"],
];

pub(crate) static ENTRY_EUDEMONISTICAL_17188010531930040532: VariantsMap = [
    &["eudemonistical"],
    &["eudaemonistical"],
    &["eudaemonistical"],
    &["eudaemonistical"],
];

pub(crate) static ENTRY_EUDEMONISTIC_1201869317686510728: VariantsMap = [
    &["eudemonistic"],
    &["eudaemonistic"],
    &["eudaemonistic"],
    &["eudaemonistic"],
];

pub(crate) static ENTRY_EUDEMONISTS_16625298983105767355: VariantsMap = [
    &["eudemonists"],
    &["eudaemonists"],
    &["eudaemonists"],
    &["eudaemonists"],
];

pub(crate) static ENTRY_EUDEMONIST_1610000011487064015: VariantsMap = [
    &["eudemonist"],
    &["eudaemonist"],
    &["eudaemonist"],
    &["eudaemonist"],
];

pub(crate) static ENTRY_EUDEMONS_11289948523164572570: VariantsMap = [
    &["eudemons"],
    &["eudaemons"],
    &["eudaemons"],
    &["eudaemons"],
];

pub(crate) static ENTRY_EUDEMONY_15219598488262475209: VariantsMap = [
    &["eudemony"],
    &["eudaemony"],
    &["eudaemony"],
    &["eudaemony"],
];

pub(crate) static ENTRY_EUDEMON_17986635969239112588: VariantsMap =
    [&["eudemon"], &["eudaemon"], &["eudaemon"], &["eudaemon"]];

pub(crate) static ENTRY_EUHEMERIZED_1257860755272726832: VariantsMap = [
    &["euhemerized"],
    &["euhemerised"],
    &["euhemerized"],
    &["euhemerised"],
];

pub(crate) static ENTRY_EUHEMERIZES_12953299966839264414: VariantsMap = [
    &["euhemerizes"],
    &["euhemerises"],
    &["euhemerizes"],
    &["euhemerises"],
];

pub(crate) static ENTRY_EUHEMERIZE_1873489264803474104: VariantsMap = [
    &["euhemerize"],
    &["euhemerise"],
    &["euhemerize"],
    &["euhemerise"],
];

pub(crate) static ENTRY_EUHEMERIZING_10612611578853640855: VariantsMap = [
    &["euhemerizing"],
    &["euhemerising"],
    &["euhemerizing"],
    &["euhemerising"],
];

pub(crate) static ENTRY_EULOGIZATIONS_9338629993379429591: VariantsMap = [
    &["eulogizations"],
    &["eulogisations"],
    &["eulogizations"],
    &["eulogisations"],
];

pub(crate) static ENTRY_EULOGIZATION_5947448978701222305: VariantsMap = [
    &["eulogization"],
    &["eulogisation"],
    &["eulogization"],
    &["eulogisation"],
];

pub(crate) static ENTRY_EULOGIZED_8728323980549981685: VariantsMap = [
    &["eulogized"],
    &["eulogised"],
    &["eulogized"],
    &["eulogised"],
];

pub(crate) static ENTRY_EULOGIZERS_10246860860507041023: VariantsMap = [
    &["eulogizers"],
    &["eulogisers"],
    &["eulogizers"],
    &["eulogisers"],
];

pub(crate) static ENTRY_EULOGIZER_10010536596440365165: VariantsMap = [
    &["eulogizer"],
    &["eulogiser"],
    &["eulogizer"],
    &["eulogiser"],
];

pub(crate) static ENTRY_EULOGIZES_3835732440821657383: VariantsMap = [
    &["eulogizes"],
    &["eulogises"],
    &["eulogizes"],
    &["eulogises"],
];

pub(crate) static ENTRY_EULOGIZE_5057583596298469791: VariantsMap =
    [&["eulogize"], &["eulogise"], &["eulogize"], &["eulogise"]];

pub(crate) static ENTRY_EULOGIZING_13191497739725600277: VariantsMap = [
    &["eulogizing"],
    &["eulogising"],
    &["eulogizing"],
    &["eulogising"],
];

pub(crate) static ENTRY_EUNUCHIZED_14146598531946186034: VariantsMap = [
    &["eunuchized"],
    &["eunuchised"],
    &["eunuchized"],
    &["eunuchised"],
];

pub(crate) static ENTRY_EUNUCHIZES_4246443737378485094: VariantsMap = [
    &["eunuchizes"],
    &["eunuchises"],
    &["eunuchizes"],
    &["eunuchises"],
];

pub(crate) static ENTRY_EUNUCHIZE_10259306639961171201: VariantsMap = [
    &["eunuchize"],
    &["eunuchise"],
    &["eunuchize"],
    &["eunuchise"],
];

pub(crate) static ENTRY_EUNUCHIZING_2192880783995883311: VariantsMap = [
    &["eunuchizing"],
    &["eunuchising"],
    &["eunuchizing"],
    &["eunuchising"],
];

pub(crate) static ENTRY_EUPHEMIZATION_4604811513238422771: VariantsMap = [
    &["euphemization"],
    &["euphemisation"],
    &["euphemization"],
    &["euphemisation"],
];

pub(crate) static ENTRY_EUPHEMIZED_384901376621156921: VariantsMap = [
    &["euphemized"],
    &["euphemised"],
    &["euphemized"],
    &["euphemised"],
];

pub(crate) static ENTRY_EUPHEMIZERS_3796382537388123060: VariantsMap = [
    &["euphemizers"],
    &["euphemisers"],
    &["euphemizers"],
    &["euphemisers"],
];

pub(crate) static ENTRY_EUPHEMIZER_9802165878126248247: VariantsMap = [
    &["euphemizer"],
    &["euphemiser"],
    &["euphemizer"],
    &["euphemiser"],
];

pub(crate) static ENTRY_EUPHEMIZES_17040532734112861700: VariantsMap = [
    &["euphemizes"],
    &["euphemises"],
    &["euphemizes"],
    &["euphemises"],
];

pub(crate) static ENTRY_EUPHEMIZE_6354436200580711971: VariantsMap = [
    &["euphemize"],
    &["euphemise"],
    &["euphemize"],
    &["euphemise"],
];

pub(crate) static ENTRY_EUPHEMIZING_12922673468625138298: VariantsMap = [
    &["euphemizing"],
    &["euphemising"],
    &["euphemizing"],
    &["euphemising"],
];

pub(crate) static ENTRY_EUPHONIZATION_13942576290061210615: VariantsMap = [
    &["euphonization"],
    &["euphonisation"],
    &["euphonization"],
    &["euphonisation"],
];

pub(crate) static ENTRY_EUPHONIZED_11998771033982272882: VariantsMap = [
    &["euphonized"],
    &["euphonised"],
    &["euphonized"],
    &["euphonised"],
];

pub(crate) static ENTRY_EUPHONIZES_8721809048241461661: VariantsMap = [
    &["euphonizes"],
    &["euphonises"],
    &["euphonizes"],
    &["euphonises"],
];

pub(crate) static ENTRY_EUPHONIZE_14344073934911523788: VariantsMap = [
    &["euphonize"],
    &["euphonise"],
    &["euphonize"],
    &["euphonise"],
];

pub(crate) static ENTRY_EUPHONIZING_7148830146393117295: VariantsMap = [
    &["euphonizing"],
    &["euphonising"],
    &["euphonizing"],
    &["euphonising"],
];

pub(crate) static ENTRY_EUPHUIZED_12869252973461985164: VariantsMap = [
    &["euphuized"],
    &["euphuised"],
    &["euphuized"],
    &["euphuised"],
];

pub(crate) static ENTRY_EUPHUIZES_13621859157470614114: VariantsMap = [
    &["euphuizes"],
    &["euphuises"],
    &["euphuizes"],
    &["euphuises"],
];

pub(crate) static ENTRY_EUPHUIZE_9755428435828216359: VariantsMap =
    [&["euphuize"], &["euphuise"], &["euphuize"], &["euphuise"]];

pub(crate) static ENTRY_EUPHUIZING_16039790140667819075: VariantsMap = [
    &["euphuizing"],
    &["euphuising"],
    &["euphuizing"],
    &["euphuising"],
];

pub(crate) static ENTRY_EUPNEAS_17276821144216069652: VariantsMap =
    [&["eupneas"], &["eupnoeas"], &["eupnoeas"], &["eupnoeas"]];

pub(crate) static ENTRY_EUPNEA_17746307000139664788: VariantsMap =
    [&["eupnea"], &["eupnoea"], &["eupnoea"], &["eupnoea"]];

pub(crate) static ENTRY_EUPNEIC_9681633279055795805: VariantsMap =
    [&["eupneic"], &["eupnoeic"], &["eupnoeic"], &["eupnoeic"]];

pub(crate) static ENTRY_EUROPEANIZATIONS_11732866676783163952: VariantsMap = [
    &["europeanizations"],
    &["europeanisations"],
    &["europeanizations"],
    &["europeanisations"],
];

pub(crate) static ENTRY_EUROPEANIZATION_18182188015643339370: VariantsMap = [
    &["europeanization"],
    &["europeanisation"],
    &["europeanization"],
    &["europeanisation"],
];

pub(crate) static ENTRY_EUROPEANIZED_5069713816195565465: VariantsMap = [
    &["europeanized"],
    &["europeanised"],
    &["europeanized"],
    &["europeanised"],
];

pub(crate) static ENTRY_EUROPEANIZES_15551253373119788515: VariantsMap = [
    &["europeanizes"],
    &["europeanises"],
    &["europeanizes"],
    &["europeanises"],
];

pub(crate) static ENTRY_EUROPEANIZE_7877119707137615478: VariantsMap = [
    &["europeanize"],
    &["europeanise"],
    &["europeanize"],
    &["europeanise"],
];

pub(crate) static ENTRY_EUROPEANIZING_2151542840584223646: VariantsMap = [
    &["europeanizing"],
    &["europeanising"],
    &["europeanizing"],
    &["europeanising"],
];

pub(crate) static ENTRY_EURYALE_6543953160332833947: VariantsMap =
    [&["euryale"], &["euryalae"], &["euryalae"], &["euryalae"]];

pub(crate) static ENTRY_EVANGELIZATIONS_13830601721028602369: VariantsMap = [
    &["evangelizations"],
    &["evangelisations"],
    &["evangelizations"],
    &["evangelisations"],
];

pub(crate) static ENTRY_EVANGELIZATION_95918260299241119: VariantsMap = [
    &["evangelization"],
    &["evangelisation"],
    &["evangelization"],
    &["evangelisation"],
];

pub(crate) static ENTRY_EVANGELIZED_17447599926020044651: VariantsMap = [
    &["evangelized"],
    &["evangelised"],
    &["evangelized"],
    &["evangelised"],
];

pub(crate) static ENTRY_EVANGELIZERS_13970259288304829321: VariantsMap = [
    &["evangelizers"],
    &["evangelisers"],
    &["evangelizers"],
    &["evangelisers"],
];

pub(crate) static ENTRY_EVANGELIZER_15719745451926752893: VariantsMap = [
    &["evangelizer"],
    &["evangeliser"],
    &["evangelizer"],
    &["evangeliser"],
];

pub(crate) static ENTRY_EVANGELIZES_6848716766820134553: VariantsMap = [
    &["evangelizes"],
    &["evangelises"],
    &["evangelizes"],
    &["evangelises"],
];

pub(crate) static ENTRY_EVANGELIZE_3816430481934936599: VariantsMap = [
    &["evangelize"],
    &["evangelise"],
    &["evangelize"],
    &["evangelise"],
];

pub(crate) static ENTRY_EVANGELIZING_9044162222729137139: VariantsMap = [
    &["evangelizing"],
    &["evangelising"],
    &["evangelizing"],
    &["evangelising"],
];

pub(crate) static ENTRY_EVENTUALIZED_16397818441261841688: VariantsMap = [
    &["eventualized"],
    &["eventualised"],
    &["eventualized"],
    &["eventualised"],
];

pub(crate) static ENTRY_EVENTUALIZES_9980302890707619422: VariantsMap = [
    &["eventualizes"],
    &["eventualises"],
    &["eventualizes"],
    &["eventualises"],
];

pub(crate) static ENTRY_EVENTUALIZE_16723569842023845082: VariantsMap = [
    &["eventualize"],
    &["eventualise"],
    &["eventualize"],
    &["eventualise"],
];

pub(crate) static ENTRY_EVENTUALIZING_16722303449748485140: VariantsMap = [
    &["eventualizing"],
    &["eventualising"],
    &["eventualizing"],
    &["eventualising"],
];

pub(crate) static ENTRY_EVILER_1511493183642407212: VariantsMap =
    [&["eviler"], &["eviller"], &["eviller"], &["eviller"]];

pub(crate) static ENTRY_EVILEST_13211136907355422438: VariantsMap =
    [&["evilest"], &["evillest"], &["evillest"], &["evillest"]];

pub(crate) static ENTRY_EVITERNAL_7722180848811514076: VariantsMap = [
    &["eviternal"],
    &["aeviternal"],
    &["aeviternal"],
    &["aeviternal"],
];

pub(crate) static ENTRY_EVOLUTIONIZES_9296464246749788558: VariantsMap = [
    &["evolutionizes"],
    &["evolutionises"],
    &["evolutionizes"],
    &["evolutionises"],
];

pub(crate) static ENTRY_EVOLUTIONIZE_8956862466662747203: VariantsMap = [
    &["evolutionize"],
    &["evolutionise"],
    &["evolutionize"],
    &["evolutionise"],
];

pub(crate) static ENTRY_EXCURSIONIZED_10549978358779313723: VariantsMap = [
    &["excursionized"],
    &["excursionised"],
    &["excursionized"],
    &["excursionised"],
];

pub(crate) static ENTRY_EXCURSIONIZES_14003180836324204514: VariantsMap = [
    &["excursionizes"],
    &["excursionises"],
    &["excursionizes"],
    &["excursionises"],
];

pub(crate) static ENTRY_EXCURSIONIZE_9010217601314344660: VariantsMap = [
    &["excursionize"],
    &["excursionise"],
    &["excursionize"],
    &["excursionise"],
];

pub(crate) static ENTRY_EXCURSIONIZING_3926415541732909964: VariantsMap = [
    &["excursionizing"],
    &["excursionising"],
    &["excursionizing"],
    &["excursionising"],
];

pub(crate) static ENTRY_EXESTUATE_10535524922051300239: VariantsMap = [
    &["exestuate"],
    &["exaestuate"],
    &["exaestuate"],
    &["exaestuate"],
];

pub(crate) static ENTRY_EXHIBITIONIZES_2334877825344301791: VariantsMap = [
    &["exhibitionizes"],
    &["exhibitionises"],
    &["exhibitionizes"],
    &["exhibitionises"],
];

pub(crate) static ENTRY_EXHIBITIONIZE_15056221307874731438: VariantsMap = [
    &["exhibitionize"],
    &["exhibitionise"],
    &["exhibitionize"],
    &["exhibitionise"],
];

pub(crate) static ENTRY_EXISTENTIALIZES_12344782442749191950: VariantsMap = [
    &["existentializes"],
    &["existentialises"],
    &["existentializes"],
    &["existentialises"],
];

pub(crate) static ENTRY_EXISTENTIALIZE_7178947692897315493: VariantsMap = [
    &["existentialize"],
    &["existentialise"],
    &["existentialize"],
    &["existentialise"],
];

pub(crate) static ENTRY_EXORCISED_7923013483761916535: VariantsMap = [
    &["exorcised"],
    &["exorcised"],
    &["exorcised"],
    &["exorcised"],
];

pub(crate) static ENTRY_EXORCISES_13003500046685598280: VariantsMap = [
    &["exorcises"],
    &["exorcises"],
    &["exorcises"],
    &["exorcises"],
];

pub(crate) static ENTRY_EXORCISE_6519813252766976149: VariantsMap =
    [&["exorcise"], &["exorcise"], &["exorcise"], &["exorcise"]];

pub(crate) static ENTRY_EXORCISING_7595159943765013984: VariantsMap = [
    &["exorcising"],
    &["exorcising"],
    &["exorcising"],
    &["exorcising"],
];

pub(crate) static ENTRY_EXORCIZATION_9973557591494255050: VariantsMap = [
    &["exorcization"],
    &["exorcisation"],
    &["exorcization"],
    &["exorcisation"],
];

pub(crate) static ENTRY_EXORCIZEMENT_4086232982854862407: VariantsMap = [
    &["exorcizement"],
    &["exorcisement"],
    &["exorcizement"],
    &["exorcisement"],
];

pub(crate) static ENTRY_EXORCIZERS_4060237431460252715: VariantsMap = [
    &["exorcizers"],
    &["exorcisers"],
    &["exorcizers"],
    &["exorcisers"],
];

pub(crate) static ENTRY_EXORCIZER_10990791238547945470: VariantsMap = [
    &["exorcizer"],
    &["exorciser"],
    &["exorcizer"],
    &["exorciser"],
];

pub(crate) static ENTRY_EXPERIMENTALIZED_16319238987251423636: VariantsMap = [
    &["experimentalized"],
    &["experimentalised"],
    &["experimentalized"],
    &["experimentalised"],
];

pub(crate) static ENTRY_EXPERIMENTALIZES_6488970464603492402: VariantsMap = [
    &["experimentalizes"],
    &["experimentalises"],
    &["experimentalizes"],
    &["experimentalises"],
];

pub(crate) static ENTRY_EXPERIMENTALIZE_10878270560966778384: VariantsMap = [
    &["experimentalize"],
    &["experimentalise"],
    &["experimentalize"],
    &["experimentalise"],
];

pub(crate) static ENTRY_EXPERIMENTALIZING_14626652674328972371: VariantsMap = [
    &["experimentalizing"],
    &["experimentalising"],
    &["experimentalizing"],
    &["experimentalising"],
];

pub(crate) static ENTRY_EXPERIMENTIZES_7968616202247451636: VariantsMap = [
    &["experimentizes"],
    &["experimentises"],
    &["experimentizes"],
    &["experimentises"],
];

pub(crate) static ENTRY_EXPERIMENTIZE_4938698649692716165: VariantsMap = [
    &["experimentize"],
    &["experimentise"],
    &["experimentize"],
    &["experimentise"],
];

pub(crate) static ENTRY_EXPERTIZED_14036001593273348525: VariantsMap = [
    &["expertized"],
    &["expertised"],
    &["expertized"],
    &["expertised"],
];

pub(crate) static ENTRY_EXPERTIZING_5977912727854152082: VariantsMap = [
    &["expertizing"],
    &["expertising"],
    &["expertizing"],
    &["expertising"],
];

pub(crate) static ENTRY_EXSICCATE_5753093181162139232: VariantsMap = [
    &["exsiccate"],
    &["exsiccatae"],
    &["exsiccatae"],
    &["exsiccatae"],
];

pub(crate) static ENTRY_EXTEMPORIZATIONS_484835912937984024: VariantsMap = [
    &["extemporizations"],
    &["extemporisations"],
    &["extemporizations"],
    &["extemporisations"],
];

pub(crate) static ENTRY_EXTEMPORIZATION_16495995827408513386: VariantsMap = [
    &["extemporization"],
    &["extemporisation"],
    &["extemporization"],
    &["extemporisation"],
];

pub(crate) static ENTRY_EXTEMPORIZED_8373892655121344093: VariantsMap = [
    &["extemporized"],
    &["extemporised"],
    &["extemporized"],
    &["extemporised"],
];

pub(crate) static ENTRY_EXTEMPORIZERS_15031267596464401937: VariantsMap = [
    &["extemporizers"],
    &["extemporisers"],
    &["extemporizers"],
    &["extemporisers"],
];

pub(crate) static ENTRY_EXTEMPORIZER_1000073776414629889: VariantsMap = [
    &["extemporizer"],
    &["extemporiser"],
    &["extemporizer"],
    &["extemporiser"],
];

pub(crate) static ENTRY_EXTEMPORIZES_10237434907700901719: VariantsMap = [
    &["extemporizes"],
    &["extemporises"],
    &["extemporizes"],
    &["extemporises"],
];

pub(crate) static ENTRY_EXTEMPORIZE_18100427440717892297: VariantsMap = [
    &["extemporize"],
    &["extemporise"],
    &["extemporize"],
    &["extemporise"],
];

pub(crate) static ENTRY_EXTEMPORIZING_3627576447114749026: VariantsMap = [
    &["extemporizing"],
    &["extemporising"],
    &["extemporizing"],
    &["extemporising"],
];

pub(crate) static ENTRY_EXTERIORIZATIONS_310117758835612277: VariantsMap = [
    &["exteriorizations"],
    &["exteriorisations"],
    &["exteriorizations"],
    &["exteriorisations"],
];

pub(crate) static ENTRY_EXTERIORIZATION_18119077159963528619: VariantsMap = [
    &["exteriorization"],
    &["exteriorisation"],
    &["exteriorization"],
    &["exteriorisation"],
];

pub(crate) static ENTRY_EXTERIORIZED_15754857071634888794: VariantsMap = [
    &["exteriorized"],
    &["exteriorised"],
    &["exteriorized"],
    &["exteriorised"],
];

pub(crate) static ENTRY_EXTERIORIZES_1503361879818597816: VariantsMap = [
    &["exteriorizes"],
    &["exteriorises"],
    &["exteriorizes"],
    &["exteriorises"],
];

pub(crate) static ENTRY_EXTERIORIZE_44904350820292310: VariantsMap = [
    &["exteriorize"],
    &["exteriorise"],
    &["exteriorize"],
    &["exteriorise"],
];

pub(crate) static ENTRY_EXTERIORIZING_13843149969846401653: VariantsMap = [
    &["exteriorizing"],
    &["exteriorising"],
    &["exteriorizing"],
    &["exteriorising"],
];

pub(crate) static ENTRY_EXTERNALIZATIONS_6813089105022337009: VariantsMap = [
    &["externalizations"],
    &["externalisations"],
    &["externalizations"],
    &["externalisations"],
];

pub(crate) static ENTRY_EXTERNALIZATION_9246128994925255934: VariantsMap = [
    &["externalization"],
    &["externalisation"],
    &["externalization"],
    &["externalisation"],
];

pub(crate) static ENTRY_EXTERNALIZED_9673243200936449099: VariantsMap = [
    &["externalized"],
    &["externalised"],
    &["externalized"],
    &["externalised"],
];

pub(crate) static ENTRY_EXTERNALIZES_2963526646467072454: VariantsMap = [
    &["externalizes"],
    &["externalises"],
    &["externalizes"],
    &["externalises"],
];

pub(crate) static ENTRY_EXTERNALIZE_1755256362900379852: VariantsMap = [
    &["externalize"],
    &["externalise"],
    &["externalize"],
    &["externalise"],
];

pub(crate) static ENTRY_EXTERNALIZING_13585703043209993488: VariantsMap = [
    &["externalizing"],
    &["externalising"],
    &["externalizing"],
    &["externalising"],
];

pub(crate) static ENTRY_EXTOLS_11917668525245354154: VariantsMap =
    [&["extols"], &["extols"], &["extols"], &["extols"]];

pub(crate) static ENTRY_EXTOL_6530203836420061929: VariantsMap =
    [&["extol"], &["extol"], &["extol"], &["extol"]];

pub(crate) static ENTRY_EXTROVERTED_3349811760540489416: VariantsMap = [
    &["extroverted"],
    &["extroverted"],
    &["extroverted"],
    &["extroverted"],
];

pub(crate) static ENTRY_EXTROVERTS_5855938022041084405: VariantsMap = [
    &["extroverts"],
    &["extroverts"],
    &["extroverts"],
    &["extroverts"],
];

pub(crate) static ENTRY_EXTROVERT_14223399491319457241: VariantsMap = [
    &["extrovert"],
    &["extrovert"],
    &["extrovert"],
    &["extrovert"],
];

pub(crate) static ENTRY_FABULIZED_17196297800190893705: VariantsMap = [
    &["fabulized"],
    &["fabulised"],
    &["fabulized"],
    &["fabulised"],
];

pub(crate) static ENTRY_FABULIZES_6694776625224319041: VariantsMap = [
    &["fabulizes"],
    &["fabulises"],
    &["fabulizes"],
    &["fabulises"],
];

pub(crate) static ENTRY_FABULIZE_14998259506216827665: VariantsMap =
    [&["fabulize"], &["fabulise"], &["fabulize"], &["fabulise"]];

pub(crate) static ENTRY_FABULIZING_1773624844947708020: VariantsMap = [
    &["fabulizing"],
    &["fabulising"],
    &["fabulizing"],
    &["fabulising"],
];

pub(crate) static ENTRY_FACSIMILIZES_12559845002197022283: VariantsMap = [
    &["facsimilizes"],
    &["facsimilises"],
    &["facsimilizes"],
    &["facsimilises"],
];

pub(crate) static ENTRY_FACSIMILIZE_3990097773408232192: VariantsMap = [
    &["facsimilize"],
    &["facsimilise"],
    &["facsimilize"],
    &["facsimilise"],
];

pub(crate) static ENTRY_FACTORIZATIONS_4638071637630345545: VariantsMap = [
    &["factorizations"],
    &["factorisations"],
    &["factorizations"],
    &["factorisations"],
];

pub(crate) static ENTRY_FACTORIZATION_5102971756633526494: VariantsMap = [
    &["factorization"],
    &["factorisation"],
    &["factorization"],
    &["factorisation"],
];

pub(crate) static ENTRY_FACTORIZED_3076385353944751316: VariantsMap = [
    &["factorized"],
    &["factorised"],
    &["factorized"],
    &["factorised"],
];

pub(crate) static ENTRY_FACTORIZES_6368168670047017262: VariantsMap = [
    &["factorizes"],
    &["factorises"],
    &["factorizes"],
    &["factorises"],
];

pub(crate) static ENTRY_FACTORIZE_6248620742291710594: VariantsMap = [
    &["factorize"],
    &["factorise"],
    &["factorize"],
    &["factorise"],
];

pub(crate) static ENTRY_FACTORIZING_10106476068343096154: VariantsMap = [
    &["factorizing"],
    &["factorising"],
    &["factorizing"],
    &["factorising"],
];

pub(crate) static ENTRY_FAENCE_17825379390909859682: VariantsMap =
    [&["faence"], &["faoence"], &["faoence"], &["faoence"]];

pub(crate) static ENTRY_FAGOTED_6374042289029783427: VariantsMap =
    [&["fagoted"], &["faggoted"], &["faggoted"], &["faggoted"]];

pub(crate) static ENTRY_FAGOTING_5494547696679224898: VariantsMap = [
    &["fagoting"],
    &["faggoting"],
    &["faggoting"],
    &["faggoting"],
];

pub(crate) static ENTRY_FAGOTS_14417121374438859878: VariantsMap =
    [&["fagots"], &["faggots"], &["faggots"], &["faggots"]];

pub(crate) static ENTRY_FAGOTS_15779386352352349090: VariantsMap = [
    &["faggots", "fagots"],
    &["faggots"],
    &["faggots"],
    &["faggots"],
];

pub(crate) static ENTRY_FAGOT_10151298035917845314: VariantsMap =
    [&["fagot"], &["faggot"], &["faggot"], &["faggot"]];

pub(crate) static ENTRY_FAGOT_7863482917477677576: VariantsMap =
    [&["faggot", "fagot"], &["faggot"], &["faggot"], &["faggot"]];

pub(crate) static ENTRY_FAITORS_14335612044167781406: VariantsMap =
    [&["faitors"], &["faitours"], &["faitours"], &["faitours"]];

pub(crate) static ENTRY_FAITOR_14801362899469576916: VariantsMap =
    [&["faitor"], &["faitour"], &["faitour"], &["faitour"]];

pub(crate) static ENTRY_FAMILIARIZATIONS_12640437606890487270: VariantsMap = [
    &["familiarizations"],
    &["familiarisations"],
    &["familiarizations"],
    &["familiarisations"],
];

pub(crate) static ENTRY_FAMILIARIZATION_12082687538774621170: VariantsMap = [
    &["familiarization"],
    &["familiarisation"],
    &["familiarization"],
    &["familiarisation"],
];

pub(crate) static ENTRY_FAMILIARIZED_15024414515945758936: VariantsMap = [
    &["familiarized"],
    &["familiarised"],
    &["familiarized"],
    &["familiarised"],
];

pub(crate) static ENTRY_FAMILIARIZERS_3971622733242915623: VariantsMap = [
    &["familiarizers"],
    &["familiarisers"],
    &["familiarizers"],
    &["familiarisers"],
];

pub(crate) static ENTRY_FAMILIARIZER_6464941598388506049: VariantsMap = [
    &["familiarizer"],
    &["familiariser"],
    &["familiarizer"],
    &["familiariser"],
];

pub(crate) static ENTRY_FAMILIARIZES_17026717100467495383: VariantsMap = [
    &["familiarizes"],
    &["familiarises"],
    &["familiarizes"],
    &["familiarises"],
];

pub(crate) static ENTRY_FAMILIARIZE_6242156019669273444: VariantsMap = [
    &["familiarize"],
    &["familiarise"],
    &["familiarize"],
    &["familiarise"],
];

pub(crate) static ENTRY_FAMILIARIZINGLY_5969515453181631796: VariantsMap = [
    &["familiarizingly"],
    &["familiarisingly"],
    &["familiarizingly"],
    &["familiarisingly"],
];

pub(crate) static ENTRY_FAMILIARIZING_8104674979842226150: VariantsMap = [
    &["familiarizing"],
    &["familiarising"],
    &["familiarizing"],
    &["familiarising"],
];

pub(crate) static ENTRY_FANATICIZED_7803305658591134019: VariantsMap = [
    &["fanaticized"],
    &["fanaticised"],
    &["fanaticized"],
    &["fanaticised"],
];

pub(crate) static ENTRY_FANATICIZES_15012541655389909830: VariantsMap = [
    &["fanaticizes"],
    &["fanaticises"],
    &["fanaticizes"],
    &["fanaticises"],
];

pub(crate) static ENTRY_FANATICIZE_10597130864549893912: VariantsMap = [
    &["fanaticize"],
    &["fanaticise"],
    &["fanaticize"],
    &["fanaticise"],
];

pub(crate) static ENTRY_FANATICIZING_17977710800766343799: VariantsMap = [
    &["fanaticizing"],
    &["fanaticising"],
    &["fanaticizing"],
    &["fanaticising"],
];

pub(crate) static ENTRY_FANTASIZED_15872386699233756433: VariantsMap = [
    &["fantasized"],
    &["fantasised"],
    &["fantasized"],
    &["fantasised"],
];

pub(crate) static ENTRY_FANTASIZER_13718445762964364656: VariantsMap = [
    &["fantasizer"],
    &["fantasiser"],
    &["fantasizer"],
    &["fantasiser"],
];

pub(crate) static ENTRY_FANTASIZES_4908779596089212975: VariantsMap = [
    &["fantasizes"],
    &["fantasises"],
    &["fantasizes"],
    &["fantasises"],
];

pub(crate) static ENTRY_FANTASIZE_14080369588189172386: VariantsMap = [
    &["fantasize"],
    &["fantasise"],
    &["fantasize"],
    &["fantasise"],
];

pub(crate) static ENTRY_FANTASIZING_4236358014599476998: VariantsMap = [
    &["fantasizing"],
    &["fantasising"],
    &["fantasizing"],
    &["fantasising"],
];

pub(crate) static ENTRY_FARADIZATIONS_15687190555969801215: VariantsMap = [
    &["faradizations"],
    &["faradisations"],
    &["faradizations"],
    &["faradisations"],
];

pub(crate) static ENTRY_FARADIZATION_205243435660491694: VariantsMap = [
    &["faradization"],
    &["faradisation"],
    &["faradization"],
    &["faradisation"],
];

pub(crate) static ENTRY_FARADIZED_8966502857650295265: VariantsMap = [
    &["faradized"],
    &["faradised"],
    &["faradized"],
    &["faradised"],
];

pub(crate) static ENTRY_FARADIZERS_16719521658589655925: VariantsMap = [
    &["faradizers"],
    &["faradisers"],
    &["faradizers"],
    &["faradisers"],
];

pub(crate) static ENTRY_FARADIZER_12338085475428655967: VariantsMap = [
    &["faradizer"],
    &["faradiser"],
    &["faradizer"],
    &["faradiser"],
];

pub(crate) static ENTRY_FARADIZES_15338843475283209863: VariantsMap = [
    &["faradizes"],
    &["faradises"],
    &["faradizes"],
    &["faradises"],
];

pub(crate) static ENTRY_FARADIZE_12209808126934904312: VariantsMap =
    [&["faradize"], &["faradise"], &["faradize"], &["faradise"]];

pub(crate) static ENTRY_FARADIZING_4001083035652834283: VariantsMap = [
    &["faradizing"],
    &["faradising"],
    &["faradizing"],
    &["faradising"],
];

pub(crate) static ENTRY_FASCIOLE_17263907576806304609: VariantsMap = [
    &["fasciole"],
    &["fasciolae"],
    &["fasciolae"],
    &["fasciolae"],
];

pub(crate) static ENTRY_FASCISTICIZATIONS_2142515311664578918: VariantsMap = [
    &["fascisticizations"],
    &["fascisticisations"],
    &["fascisticizations"],
    &["fascisticisations"],
];

pub(crate) static ENTRY_FASCISTICIZATION_10804431373403126406: VariantsMap = [
    &["fascisticization"],
    &["fascisticisation"],
    &["fascisticization"],
    &["fascisticisation"],
];

pub(crate) static ENTRY_FASCISTICIZES_12773262836291186621: VariantsMap = [
    &["fascisticizes"],
    &["fascisticises"],
    &["fascisticizes"],
    &["fascisticises"],
];

pub(crate) static ENTRY_FASCISTICIZE_14066142312502290880: VariantsMap = [
    &["fascisticize"],
    &["fascisticise"],
    &["fascisticize"],
    &["fascisticise"],
];

pub(crate) static ENTRY_FASCISTIZATIONS_15292377615911280827: VariantsMap = [
    &["fascistizations"],
    &["fascistisations"],
    &["fascistizations"],
    &["fascistisations"],
];

pub(crate) static ENTRY_FASCISTIZATION_5837081357565086170: VariantsMap = [
    &["fascistization"],
    &["fascistisation"],
    &["fascistization"],
    &["fascistisation"],
];

pub(crate) static ENTRY_FASCISTIZED_11585438620059337608: VariantsMap = [
    &["fascistized"],
    &["fascistised"],
    &["fascistized"],
    &["fascistised"],
];

pub(crate) static ENTRY_FASCISTIZES_8866762538747399972: VariantsMap = [
    &["fascistizes"],
    &["fascistises"],
    &["fascistizes"],
    &["fascistises"],
];

pub(crate) static ENTRY_FASCISTIZE_11561240909251618082: VariantsMap = [
    &["fascistize"],
    &["fascistise"],
    &["fascistize"],
    &["fascistise"],
];

pub(crate) static ENTRY_FASCISTIZING_8170964443515482096: VariantsMap = [
    &["fascistizing"],
    &["fascistising"],
    &["fascistizing"],
    &["fascistising"],
];

pub(crate) static ENTRY_FASHIONIZES_16455688786469638021: VariantsMap = [
    &["fashionizes"],
    &["fashionises"],
    &["fashionizes"],
    &["fashionises"],
];

pub(crate) static ENTRY_FASHIONIZE_165859306339703853: VariantsMap = [
    &["fashionize"],
    &["fashionise"],
    &["fashionize"],
    &["fashionise"],
];

pub(crate) static ENTRY_FATALIZES_14060725425108865277: VariantsMap = [
    &["fatalizes"],
    &["fatalises"],
    &["fatalizes"],
    &["fatalises"],
];

pub(crate) static ENTRY_FATALIZE_8908836302084517669: VariantsMap =
    [&["fatalize"], &["fatalise"], &["fatalize"], &["fatalise"]];

pub(crate) static ENTRY_FAVORABLENESSES_11975449432847156038: VariantsMap = [
    &["favorablenesses"],
    &["favourablenesses"],
    &["favourablenesses"],
    &["favourablenesses"],
];

pub(crate) static ENTRY_FAVORABLENESS_13318204817688701067: VariantsMap = [
    &["favorableness"],
    &["favourableness"],
    &["favourableness"],
    &["favourableness"],
];

pub(crate) static ENTRY_FAVORABLER_1666504773214810504: VariantsMap = [
    &["favorabler"],
    &["favourabler"],
    &["favourabler"],
    &["favourabler"],
];

pub(crate) static ENTRY_FAVORABLEST_7604212844361785683: VariantsMap = [
    &["favorablest"],
    &["favourablest"],
    &["favourablest"],
    &["favourablest"],
];

pub(crate) static ENTRY_FAVORABLES_9226020009295042529: VariantsMap = [
    &["favorables"],
    &["favourables"],
    &["favourables"],
    &["favourables"],
];

pub(crate) static ENTRY_FAVORABLE_3232743289071203492: VariantsMap = [
    &["favorable"],
    &["favourable"],
    &["favourable"],
    &["favourable"],
];

pub(crate) static ENTRY_FAVORABLIER_9313656689589060087: VariantsMap = [
    &["favorablier"],
    &["favourablier"],
    &["favourablier"],
    &["favourablier"],
];

pub(crate) static ENTRY_FAVORABLIEST_14028659737830856566: VariantsMap = [
    &["favorabliest"],
    &["favourabliest"],
    &["favourabliest"],
    &["favourabliest"],
];

pub(crate) static ENTRY_FAVORABLY_14208254678721843327: VariantsMap = [
    &["favorably"],
    &["favourably"],
    &["favourably"],
    &["favourably"],
];

pub(crate) static ENTRY_FAVOREDLIER_18006876556571648819: VariantsMap = [
    &["favoredlier"],
    &["favouredlier"],
    &["favouredlier"],
    &["favouredlier"],
];

pub(crate) static ENTRY_FAVOREDLIEST_11349830239360797566: VariantsMap = [
    &["favoredliest"],
    &["favouredliest"],
    &["favouredliest"],
    &["favouredliest"],
];

pub(crate) static ENTRY_FAVOREDLY_16123517779026995677: VariantsMap = [
    &["favoredly"],
    &["favouredly"],
    &["favouredly"],
    &["favouredly"],
];

pub(crate) static ENTRY_FAVOREDNESSES_15674786591317797795: VariantsMap = [
    &["favorednesses"],
    &["favourednesses"],
    &["favourednesses"],
    &["favourednesses"],
];

pub(crate) static ENTRY_FAVOREDNESS_683285836749751191: VariantsMap = [
    &["favoredness"],
    &["favouredness"],
    &["favouredness"],
    &["favouredness"],
];

pub(crate) static ENTRY_FAVOREDS_2145643335759443083: VariantsMap = [
    &["favoreds"],
    &["favoureds"],
    &["favoureds"],
    &["favoureds"],
];

pub(crate) static ENTRY_FAVORED_10193433870000535406: VariantsMap =
    [&["favored"], &["favoured"], &["favoured"], &["favoured"]];

pub(crate) static ENTRY_FAVORERS_1232734746388131459: VariantsMap = [
    &["favorers"],
    &["favourers"],
    &["favourers"],
    &["favourers"],
];

pub(crate) static ENTRY_FAVORER_1047334691871543829: VariantsMap =
    [&["favorer"], &["favourer"], &["favourer"], &["favourer"]];

pub(crate) static ENTRY_FAVORESS_15934392179881120848: VariantsMap = [
    &["favoress"],
    &["favouress"],
    &["favouress"],
    &["favouress"],
];

pub(crate) static ENTRY_FAVORINGLIER_13209309695763004912: VariantsMap = [
    &["favoringlier"],
    &["favouringlier"],
    &["favouringlier"],
    &["favouringlier"],
];

pub(crate) static ENTRY_FAVORINGLIEST_17037104130184778054: VariantsMap = [
    &["favoringliest"],
    &["favouringliest"],
    &["favouringliest"],
    &["favouringliest"],
];

pub(crate) static ENTRY_FAVORINGLY_6876525080994088190: VariantsMap = [
    &["favoringly"],
    &["favouringly"],
    &["favouringly"],
    &["favouringly"],
];

pub(crate) static ENTRY_FAVORINGS_11595257563255629951: VariantsMap = [
    &["favorings"],
    &["favourings"],
    &["favourings"],
    &["favourings"],
];

pub(crate) static ENTRY_FAVORING_10319622535862907770: VariantsMap = [
    &["favoring"],
    &["favouring"],
    &["favouring"],
    &["favouring"],
];

pub(crate) static ENTRY_FAVORITER_13507792634611311500: VariantsMap = [
    &["favoriter"],
    &["favouriter"],
    &["favouriter"],
    &["favouriter"],
];

pub(crate) static ENTRY_FAVORITEST_18081892094238130437: VariantsMap = [
    &["favoritest"],
    &["favouritest"],
    &["favouritest"],
    &["favouritest"],
];

pub(crate) static ENTRY_FAVORITES_16988681338183255120: VariantsMap = [
    &["favorites"],
    &["favourites"],
    &["favourites"],
    &["favourites"],
];

pub(crate) static ENTRY_FAVORITE_17454427683063934544: VariantsMap = [
    &["favorite"],
    &["favourite"],
    &["favourite"],
    &["favourite"],
];

pub(crate) static ENTRY_FAVORITISMS_1820158452140245407: VariantsMap = [
    &["favoritisms"],
    &["favouritisms"],
    &["favouritisms"],
    &["favouritisms"],
];

pub(crate) static ENTRY_FAVORITISM_16206254464455079260: VariantsMap = [
    &["favoritism"],
    &["favouritism"],
    &["favouritism"],
    &["favouritism"],
];

pub(crate) static ENTRY_FAVORLESSER_4904370564965283077: VariantsMap = [
    &["favorlesser"],
    &["favourlesser"],
    &["favourlesser"],
    &["favourlesser"],
];

pub(crate) static ENTRY_FAVORLESSEST_6184008116056797645: VariantsMap = [
    &["favorlessest"],
    &["favourlessest"],
    &["favourlessest"],
    &["favourlessest"],
];

pub(crate) static ENTRY_FAVORLESSES_16990574289794008026: VariantsMap = [
    &["favorlesses"],
    &["favourlesses"],
    &["favourlesses"],
    &["favourlesses"],
];

pub(crate) static ENTRY_FAVORLESS_8919204952537118702: VariantsMap = [
    &["favorless"],
    &["favourless"],
    &["favourless"],
    &["favourless"],
];

pub(crate) static ENTRY_FAVORS_3051235537214510517: VariantsMap =
    [&["favors"], &["favours"], &["favours"], &["favours"]];

pub(crate) static ENTRY_FAVOR_3275216426677362412: VariantsMap =
    [&["favor"], &["favour"], &["favour"], &["favour"]];

pub(crate) static ENTRY_FAYER_17774491643443055310: VariantsMap =
    [&["fayer"], &["fayre"], &["fayre"], &["fayre"]];

pub(crate) static ENTRY_FECALITH_9756122697556381424: VariantsMap =
    [&["fecalith"], &["faecalith"], &["fecalith"], &["faecalith"]];

pub(crate) static ENTRY_FECAL_12589305345141408090: VariantsMap =
    [&["fecal"], &["faecal"], &["fecal"], &["faecal"]];

pub(crate) static ENTRY_FECES_13271217083721614065: VariantsMap =
    [&["feces"], &["faeces"], &["feces"], &["faeces"]];

pub(crate) static ENTRY_FECULA_2736474945675440138: VariantsMap =
    [&["fecula"], &["faecula"], &["faecula"], &["faecula"]];

pub(crate) static ENTRY_FECULENCE_14580409871443771311: VariantsMap = [
    &["feculence"],
    &["faeculence"],
    &["faeculence"],
    &["faeculence"],
];

pub(crate) static ENTRY_FECUNDITATIS_9429833736788096175: VariantsMap = [
    &["fecunditatis"],
    &["foecunditatis"],
    &["foecunditatis"],
    &["foecunditatis"],
];

pub(crate) static ENTRY_FECUNDIZES_819255716151435756: VariantsMap = [
    &["fecundizes"],
    &["fecundises"],
    &["fecundizes"],
    &["fecundises"],
];

pub(crate) static ENTRY_FECUNDIZE_10410164415494311065: VariantsMap = [
    &["fecundize"],
    &["fecundise"],
    &["fecundize"],
    &["fecundise"],
];

pub(crate) static ENTRY_FEDARIES_1925286557832729703: VariantsMap = [
    &["fedaries"],
    &["foedaries"],
    &["foedaries"],
    &["foedaries"],
];

pub(crate) static ENTRY_FEDARIE_10275114146235963561: VariantsMap =
    [&["fedarie"], &["foedarie"], &["foedarie"], &["foedarie"]];

pub(crate) static ENTRY_FEDERALIZATIONS_16898914644507613247: VariantsMap = [
    &["federalizations"],
    &["federalisations"],
    &["federalizations"],
    &["federalisations"],
];

pub(crate) static ENTRY_FEDERALIZATION_2930003327175764780: VariantsMap = [
    &["federalization"],
    &["federalisation"],
    &["federalization"],
    &["federalisation"],
];

pub(crate) static ENTRY_FEDERALIZED_2097461935187515346: VariantsMap = [
    &["federalized"],
    &["federalised"],
    &["federalized"],
    &["federalised"],
];

pub(crate) static ENTRY_FEDERALIZES_16852170011006866629: VariantsMap = [
    &["federalizes"],
    &["federalises"],
    &["federalizes"],
    &["federalises"],
];

pub(crate) static ENTRY_FEDERALIZE_2707270304365088999: VariantsMap = [
    &["federalize"],
    &["federalise"],
    &["federalize"],
    &["federalise"],
];

pub(crate) static ENTRY_FEDERALIZING_13709518621335381978: VariantsMap = [
    &["federalizing"],
    &["federalising"],
    &["federalizing"],
    &["federalising"],
];

pub(crate) static ENTRY_FEDOR_9744386020932116298: VariantsMap =
    [&["fedor"], &["faedor"], &["faedor"], &["faedor"]];

pub(crate) static ENTRY_FEERS_12963342733000822691: VariantsMap =
    [&["feers"], &["feres"], &["feres"], &["feres"]];

pub(crate) static ENTRY_FEER_1952217434418698536: VariantsMap =
    [&["feer"], &["fere"], &["fere"], &["fere"]];

pub(crate) static ENTRY_FEMALIZES_5386306269066760275: VariantsMap = [
    &["femalizes"],
    &["femalises"],
    &["femalizes"],
    &["femalises"],
];

pub(crate) static ENTRY_FEMALIZE_5076396218269089909: VariantsMap =
    [&["femalize"], &["femalise"], &["femalize"], &["femalise"]];

pub(crate) static ENTRY_FEMINIZATIONS_10686352193044586448: VariantsMap = [
    &["feminizations"],
    &["feminisations"],
    &["feminizations"],
    &["feminisations"],
];

pub(crate) static ENTRY_FEMINIZATION_16468029640514579744: VariantsMap = [
    &["feminization"],
    &["feminisation"],
    &["feminization"],
    &["feminisation"],
];

pub(crate) static ENTRY_FEMINIZED_8252992945131834923: VariantsMap = [
    &["feminized"],
    &["feminised"],
    &["feminized"],
    &["feminised"],
];

pub(crate) static ENTRY_FEMINIZES_16698712700755007840: VariantsMap = [
    &["feminizes"],
    &["feminises"],
    &["feminizes"],
    &["feminises"],
];

pub(crate) static ENTRY_FEMINIZE_14041224965069375071: VariantsMap =
    [&["feminize"], &["feminise"], &["feminize"], &["feminise"]];

pub(crate) static ENTRY_FEMINIZING_15919362523885018840: VariantsMap = [
    &["feminizing"],
    &["feminising"],
    &["feminizing"],
    &["feminising"],
];

pub(crate) static ENTRY_FEMTOMETERS_10727604929130343624: VariantsMap = [
    &["femtometers"],
    &["femtometres"],
    &["femtometres"],
    &["femtometres"],
];

pub(crate) static ENTRY_FEMTOMETER_2397618503153495289: VariantsMap = [
    &["femtometer"],
    &["femtometre"],
    &["femtometre"],
    &["femtometre"],
];

pub(crate) static ENTRY_FERALIZED_9401556350923512546: VariantsMap = [
    &["feralized"],
    &["feralised"],
    &["feralized"],
    &["feralised"],
];

pub(crate) static ENTRY_FERD_14446691116670344833: VariantsMap =
    [&["ferd"], &["fred"], &["fred"], &["fred"]];

pub(crate) static ENTRY_FERIE_17564101729727564682: VariantsMap =
    [&["ferie"], &["feriae"], &["feriae"], &["feriae"]];

pub(crate) static ENTRY_FERITY_13311389916744452456: VariantsMap =
    [&["ferity"], &["freity"], &["freity"], &["freity"]];

pub(crate) static ENTRY_FERNEAU_15772716514172526627: VariantsMap =
    [&["ferneau"], &["freneau"], &["freneau"], &["freneau"]];

pub(crate) static ENTRY_FERRELED_9278515120825907819: VariantsMap = [
    &["ferreled"],
    &["ferrelled"],
    &["ferrelled"],
    &["ferrelled"],
];

pub(crate) static ENTRY_FERRELING_13455687359496969723: VariantsMap = [
    &["ferreling"],
    &["ferrelling"],
    &["ferrelling"],
    &["ferrelling"],
];

pub(crate) static ENTRY_FERRITIZATIONS_4005953214740177334: VariantsMap = [
    &["ferritizations"],
    &["ferritisations"],
    &["ferritizations"],
    &["ferritisations"],
];

pub(crate) static ENTRY_FERRITIZATION_14347190689825266865: VariantsMap = [
    &["ferritization"],
    &["ferritisation"],
    &["ferritization"],
    &["ferritisation"],
];

pub(crate) static ENTRY_FERTILIZABILITY_5571177015810750394: VariantsMap = [
    &["fertilizability"],
    &["fertilisability"],
    &["fertilizability"],
    &["fertilisability"],
];

pub(crate) static ENTRY_FERTILIZABLER_11059282997226454750: VariantsMap = [
    &["fertilizabler"],
    &["fertilisabler"],
    &["fertilizabler"],
    &["fertilisabler"],
];

pub(crate) static ENTRY_FERTILIZABLEST_5310132580923675289: VariantsMap = [
    &["fertilizablest"],
    &["fertilisablest"],
    &["fertilizablest"],
    &["fertilisablest"],
];

pub(crate) static ENTRY_FERTILIZABLES_727447058423532709: VariantsMap = [
    &["fertilizables"],
    &["fertilisables"],
    &["fertilizables"],
    &["fertilisables"],
];

pub(crate) static ENTRY_FERTILIZABLE_15315198919851330239: VariantsMap = [
    &["fertilizable"],
    &["fertilisable"],
    &["fertilizable"],
    &["fertilisable"],
];

pub(crate) static ENTRY_FERTILIZATIONALER_6618806786515013867: VariantsMap = [
    &["fertilizationaler"],
    &["fertilisationaler"],
    &["fertilizationaler"],
    &["fertilisationaler"],
];

pub(crate) static ENTRY_FERTILIZATIONALEST_8345282217735812123: VariantsMap = [
    &["fertilizationalest"],
    &["fertilisationalest"],
    &["fertilizationalest"],
    &["fertilisationalest"],
];

pub(crate) static ENTRY_FERTILIZATIONALS_18170848439858779127: VariantsMap = [
    &["fertilizationals"],
    &["fertilisationals"],
    &["fertilizationals"],
    &["fertilisationals"],
];

pub(crate) static ENTRY_FERTILIZATIONAL_16482273944934825327: VariantsMap = [
    &["fertilizational"],
    &["fertilisational"],
    &["fertilizational"],
    &["fertilisational"],
];

pub(crate) static ENTRY_FERTILIZATIONS_14053083959867550141: VariantsMap = [
    &["fertilizations"],
    &["fertilisations"],
    &["fertilizations"],
    &["fertilisations"],
];

pub(crate) static ENTRY_FERTILIZATION_4201619629518396111: VariantsMap = [
    &["fertilization"],
    &["fertilisation"],
    &["fertilization"],
    &["fertilisation"],
];

pub(crate) static ENTRY_FERTILIZED_13008162956323771867: VariantsMap = [
    &["fertilized"],
    &["fertilised"],
    &["fertilized"],
    &["fertilised"],
];

pub(crate) static ENTRY_FERTILIZERS_10709867916374165319: VariantsMap = [
    &["fertilizers"],
    &["fertilisers"],
    &["fertilizers"],
    &["fertilisers"],
];

pub(crate) static ENTRY_FERTILIZER_6815415387209233087: VariantsMap = [
    &["fertilizer"],
    &["fertiliser"],
    &["fertilizer"],
    &["fertiliser"],
];

pub(crate) static ENTRY_FERTILIZES_14381177978733680135: VariantsMap = [
    &["fertilizes"],
    &["fertilises"],
    &["fertilizes"],
    &["fertilises"],
];

pub(crate) static ENTRY_FERTILIZE_16309782255722600032: VariantsMap = [
    &["fertilize"],
    &["fertilise"],
    &["fertilize"],
    &["fertilise"],
];

pub(crate) static ENTRY_FERTILIZING_11080486546218839023: VariantsMap = [
    &["fertilizing"],
    &["fertilising"],
    &["fertilizing"],
    &["fertilising"],
];

pub(crate) static ENTRY_FERVORLESSES_3033145698325282698: VariantsMap = [
    &["fervorlesses"],
    &["fervourlesses"],
    &["fervourlesses"],
    &["fervourlesses"],
];

pub(crate) static ENTRY_FERVORLESS_17452353118355031409: VariantsMap = [
    &["fervorless"],
    &["fervourless"],
    &["fervourless"],
    &["fervourless"],
];

pub(crate) static ENTRY_FERVORS_6323083099093999272: VariantsMap =
    [&["fervors"], &["fervours"], &["fervours"], &["fervours"]];

pub(crate) static ENTRY_FERVOR_614815645528947396: VariantsMap =
    [&["fervor"], &["fervour"], &["fervour"], &["fervour"]];

pub(crate) static ENTRY_FETALISM_18283011397236157925: VariantsMap =
    [&["fetalism"], &["fetalism"], &["fetalism"], &["fetalism"]];

pub(crate) static ENTRY_FETAL_16307774344388919965: VariantsMap =
    [&["fetal"], &["fetal"], &["fetal"], &["fetal"]];

pub(crate) static ENTRY_FETATION_3755941875523282058: VariantsMap =
    [&["fetation"], &["fetation"], &["fetation"], &["fetation"]];

pub(crate) static ENTRY_FETICHIZED_2938251164879304848: VariantsMap = [
    &["fetichized"],
    &["fetichised"],
    &["fetichized"],
    &["fetichised"],
];

pub(crate) static ENTRY_FETICHIZES_14431439308759435147: VariantsMap = [
    &["fetichizes"],
    &["fetichises"],
    &["fetichizes"],
    &["fetichises"],
];

pub(crate) static ENTRY_FETICHIZE_6432031967305267018: VariantsMap = [
    &["fetichize"],
    &["fetichise"],
    &["fetichize"],
    &["fetichise"],
];

pub(crate) static ENTRY_FETICHIZING_18164181749916704128: VariantsMap = [
    &["fetichizing"],
    &["fetichising"],
    &["fetichizing"],
    &["fetichising"],
];

pub(crate) static ENTRY_FETICIDAL_4949929401672725612: VariantsMap = [
    &["feticidal"],
    &["feticidal"],
    &["feticidal"],
    &["feticidal"],
];

pub(crate) static ENTRY_FETICIDES_3169254784407521473: VariantsMap = [
    &["feticides"],
    &["feticides"],
    &["feticides"],
    &["feticides"],
];

pub(crate) static ENTRY_FETICIDE_15531271432046692445: VariantsMap =
    [&["feticide"], &["feticide"], &["feticide"], &["feticide"]];

pub(crate) static ENTRY_FETIDER_17182410576284038642: VariantsMap =
    [&["fetider"], &["fetider"], &["fetider"], &["fetider"]];

pub(crate) static ENTRY_FETIDEST_14215422447438146768: VariantsMap =
    [&["fetidest"], &["fetidest"], &["fetidest"], &["fetidest"]];

pub(crate) static ENTRY_FETID_2099281485779081953: VariantsMap =
    [&["fetid"], &["fetid"], &["fetid"], &["fetid"]];

pub(crate) static ENTRY_FETIFEROUS_13556662435387579595: VariantsMap = [
    &["fetiferous"],
    &["foetiferous"],
    &["foetiferous"],
    &["foetiferous"],
];

pub(crate) static ENTRY_FETIPAROUS_17812808700113336448: VariantsMap = [
    &["fetiparous"],
    &["foetiparous"],
    &["foetiparous"],
    &["foetiparous"],
];

pub(crate) static ENTRY_FETISHES_1240063895948325551: VariantsMap =
    [&["fetishes"], &["fetishes"], &["fetishes"], &["fetishes"]];

pub(crate) static ENTRY_FETISHIZATIONS_9301033175433278712: VariantsMap = [
    &["fetishizations"],
    &["fetishisations"],
    &["fetishizations"],
    &["fetishisations"],
];

pub(crate) static ENTRY_FETISHIZATION_4962686785593207593: VariantsMap = [
    &["fetishization"],
    &["fetishisation"],
    &["fetishization"],
    &["fetishisation"],
];

pub(crate) static ENTRY_FETISHIZED_12560577434053979687: VariantsMap = [
    &["fetishized"],
    &["fetishised"],
    &["fetishized"],
    &["fetishised"],
];

pub(crate) static ENTRY_FETISHIZES_3112865798662538909: VariantsMap = [
    &["fetishizes"],
    &["fetishises"],
    &["fetishizes"],
    &["fetishises"],
];

pub(crate) static ENTRY_FETISHIZE_6082865116524316715: VariantsMap = [
    &["fetishize"],
    &["fetishise"],
    &["fetishize"],
    &["fetishise"],
];

pub(crate) static ENTRY_FETISHIZING_3869827553555002799: VariantsMap = [
    &["fetishizing"],
    &["fetishising"],
    &["fetishizing"],
    &["fetishising"],
];

pub(crate) static ENTRY_FETISH_14617370190649429983: VariantsMap =
    [&["fetish"], &["fetish"], &["fetish"], &["fetish"]];

pub(crate) static ENTRY_FETORS_9158697288365525100: VariantsMap =
    [&["fetors"], &["foetors"], &["foetors"], &["foetors"]];

pub(crate) static ENTRY_FETOR_11492418604517658947: VariantsMap =
    [&["fetor"], &["foetor"], &["foetor"], &["foetor"]];

pub(crate) static ENTRY_FETOSCOPIES_11704594850300880722: VariantsMap = [
    &["fetoscopies"],
    &["foetoscopies"],
    &["foetoscopies"],
    &["foetoscopies"],
];

pub(crate) static ENTRY_FETOSCOPY_1200059214877142470: VariantsMap = [
    &["fetoscopy"],
    &["foetoscopy"],
    &["foetoscopy"],
    &["foetoscopy"],
];

pub(crate) static ENTRY_FETURE_5152410073967522436: VariantsMap =
    [&["feture"], &["foeture"], &["foeture"], &["foeture"]];

pub(crate) static ENTRY_FETUSES_7564330503533825550: VariantsMap =
    [&["fetuses"], &["fetuses"], &["fetuses"], &["fetuses"]];

pub(crate) static ENTRY_FETUS_2053571947879381898: VariantsMap =
    [&["fetus"], &["fetus"], &["fetus"], &["fetus"]];

pub(crate) static ENTRY_FEUDALIZABLES_13435612370533078763: VariantsMap = [
    &["feudalizables"],
    &["feudalisables"],
    &["feudalizables"],
    &["feudalisables"],
];

pub(crate) static ENTRY_FEUDALIZABLE_733725314620977609: VariantsMap = [
    &["feudalizable"],
    &["feudalisable"],
    &["feudalizable"],
    &["feudalisable"],
];

pub(crate) static ENTRY_FEUDALIZATIONS_4332973819048848881: VariantsMap = [
    &["feudalizations"],
    &["feudalisations"],
    &["feudalizations"],
    &["feudalisations"],
];

pub(crate) static ENTRY_FEUDALIZATION_13206467807460475478: VariantsMap = [
    &["feudalization"],
    &["feudalisation"],
    &["feudalization"],
    &["feudalisation"],
];

pub(crate) static ENTRY_FEUDALIZED_3960451703311684463: VariantsMap = [
    &["feudalized"],
    &["feudalised"],
    &["feudalized"],
    &["feudalised"],
];

pub(crate) static ENTRY_FEUDALIZES_9574302614295101534: VariantsMap = [
    &["feudalizes"],
    &["feudalises"],
    &["feudalizes"],
    &["feudalises"],
];

pub(crate) static ENTRY_FEUDALIZE_8804974376593972508: VariantsMap = [
    &["feudalize"],
    &["feudalise"],
    &["feudalize"],
    &["feudalise"],
];

pub(crate) static ENTRY_FEUDALIZING_15709230783384439087: VariantsMap = [
    &["feudalizing"],
    &["feudalising"],
    &["feudalizing"],
    &["feudalising"],
];

pub(crate) static ENTRY_FEUTER_9289342288875733939: VariantsMap =
    [&["feuter"], &["feutre"], &["feutre"], &["feutre"]];

pub(crate) static ENTRY_FE_11063702362937317781: VariantsMap =
    [&["fe"], &["fae"], &["fae"], &["fae"]];

pub(crate) static ENTRY_FIBERBOARDS_12731975045296410883: VariantsMap = [
    &["fiberboards"],
    &["fibreboards"],
    &["fibreboards"],
    &["fibreboards"],
];

pub(crate) static ENTRY_FIBERBOARD_9088608551824916909: VariantsMap = [
    &["fiberboard"],
    &["fibreboard"],
    &["fibreboard"],
    &["fibreboard"],
];

pub(crate) static ENTRY_FIBERED_3749994473310829181: VariantsMap =
    [&["fibered"], &["fibred"], &["fibred"], &["fibred"]];

pub(crate) static ENTRY_FIBERFILLS_6447949254246220216: VariantsMap = [
    &["fiberfills"],
    &["fibrefills"],
    &["fibrefills"],
    &["fibrefills"],
];

pub(crate) static ENTRY_FIBERFILL_13606310046445718422: VariantsMap = [
    &["fiberfill"],
    &["fibrefill"],
    &["fibrefill"],
    &["fibrefill"],
];

pub(crate) static ENTRY_FIBERGLASSES_3971392659490472340: VariantsMap = [
    &["fiberglasses"],
    &["fibreglasses"],
    &["fibreglasses"],
    &["fibreglasses"],
];

pub(crate) static ENTRY_FIBERGLASS_7810341362649925221: VariantsMap = [
    &["fiberglass"],
    &["fibreglass"],
    &["fibreglass"],
    &["fibreglass"],
];

pub(crate) static ENTRY_FIBERIZATION_6937225594278445561: VariantsMap = [
    &["fiberization"],
    &["fibrisation"],
    &["fibrization"],
    &["fibrisation"],
];

pub(crate) static ENTRY_FIBERIZED_3905865692011292572: VariantsMap =
    [&["fiberized"], &["fibrised"], &["fibrized"], &["fibrised"]];

pub(crate) static ENTRY_FIBERIZERS_11226216140488375203: VariantsMap = [
    &["fiberizers"],
    &["fibrisers"],
    &["fibrizers"],
    &["fibrisers"],
];

pub(crate) static ENTRY_FIBERIZER_15259065220998459171: VariantsMap =
    [&["fiberizer"], &["fibriser"], &["fibrizer"], &["fibriser"]];

pub(crate) static ENTRY_FIBERIZES_2275756906782580740: VariantsMap =
    [&["fiberizes"], &["fibrises"], &["fibrizes"], &["fibrises"]];

pub(crate) static ENTRY_FIBERIZE_10547163902572294158: VariantsMap =
    [&["fiberize"], &["fibrise"], &["fibrize"], &["fibrise"]];

pub(crate) static ENTRY_FIBERIZING_5446627689124345883: VariantsMap = [
    &["fiberizing"],
    &["fibrising"],
    &["fibrizing"],
    &["fibrising"],
];

pub(crate) static ENTRY_FIBERLESSER_4551498916657548546: VariantsMap = [
    &["fiberlesser"],
    &["fibrelesser"],
    &["fibrelesser"],
    &["fibrelesser"],
];

pub(crate) static ENTRY_FIBERLESSEST_14496238235310789976: VariantsMap = [
    &["fiberlessest"],
    &["fibrelessest"],
    &["fibrelessest"],
    &["fibrelessest"],
];

pub(crate) static ENTRY_FIBERLESSES_14283109333657558421: VariantsMap = [
    &["fiberlesses"],
    &["fibrelesses"],
    &["fibrelesses"],
    &["fibrelesses"],
];

pub(crate) static ENTRY_FIBERLESS_12969055159511376893: VariantsMap = [
    &["fiberless"],
    &["fibreless"],
    &["fibreless"],
    &["fibreless"],
];

pub(crate) static ENTRY_FIBERSCOPES_17873202834856042126: VariantsMap = [
    &["fiberscopes"],
    &["fibrescopes"],
    &["fibrescopes"],
    &["fibrescopes"],
];

pub(crate) static ENTRY_FIBERSCOPE_1314789335244812695: VariantsMap = [
    &["fiberscope"],
    &["fibrescope"],
    &["fibrescope"],
    &["fibrescope"],
];

pub(crate) static ENTRY_FIBERS_1646201480676499010: VariantsMap =
    [&["fibers"], &["fibres"], &["fibres"], &["fibres"]];

pub(crate) static ENTRY_FIBERWARE_4803374303826557107: VariantsMap = [
    &["fiberware"],
    &["fibreware"],
    &["fibreware"],
    &["fibreware"],
];

pub(crate) static ENTRY_FIBER_7952077420634658656: VariantsMap =
    [&["fiber"], &["fibre"], &["fibre"], &["fibre"]];

pub(crate) static ENTRY_FICTIONALIZATIONS_14516051539943227290: VariantsMap = [
    &["fictionalizations"],
    &["fictionalisations"],
    &["fictionalizations"],
    &["fictionalisations"],
];

pub(crate) static ENTRY_FICTIONALIZATION_5522094113122146310: VariantsMap = [
    &["fictionalization"],
    &["fictionalisation"],
    &["fictionalization"],
    &["fictionalisation"],
];

pub(crate) static ENTRY_FICTIONALIZED_15741748969425662890: VariantsMap = [
    &["fictionalized"],
    &["fictionalised"],
    &["fictionalized"],
    &["fictionalised"],
];

pub(crate) static ENTRY_FICTIONALIZES_13772431052894991620: VariantsMap = [
    &["fictionalizes"],
    &["fictionalises"],
    &["fictionalizes"],
    &["fictionalises"],
];

pub(crate) static ENTRY_FICTIONALIZE_16577222807187796806: VariantsMap = [
    &["fictionalize"],
    &["fictionalise"],
    &["fictionalize"],
    &["fictionalise"],
];

pub(crate) static ENTRY_FICTIONALIZING_1062972705175871031: VariantsMap = [
    &["fictionalizing"],
    &["fictionalising"],
    &["fictionalizing"],
    &["fictionalising"],
];

pub(crate) static ENTRY_FICTIONIZATIONS_9671751322318154200: VariantsMap = [
    &["fictionizations"],
    &["fictionisations"],
    &["fictionizations"],
    &["fictionisations"],
];

pub(crate) static ENTRY_FICTIONIZATION_14666995530197436361: VariantsMap = [
    &["fictionization"],
    &["fictionisation"],
    &["fictionization"],
    &["fictionisation"],
];

pub(crate) static ENTRY_FICTIONIZED_6877756002854005504: VariantsMap = [
    &["fictionized"],
    &["fictionised"],
    &["fictionized"],
    &["fictionised"],
];

pub(crate) static ENTRY_FICTIONIZES_725473241634804856: VariantsMap = [
    &["fictionizes"],
    &["fictionises"],
    &["fictionizes"],
    &["fictionises"],
];

pub(crate) static ENTRY_FICTIONIZE_17995007159313813172: VariantsMap = [
    &["fictionize"],
    &["fictionise"],
    &["fictionize"],
    &["fictionise"],
];

pub(crate) static ENTRY_FICTIONIZING_7115796450699434396: VariantsMap = [
    &["fictionizing"],
    &["fictionising"],
    &["fictionizing"],
    &["fictionising"],
];

pub(crate) static ENTRY_FIGURIZES_12804465356162412728: VariantsMap = [
    &["figurizes"],
    &["figurises"],
    &["figurizes"],
    &["figurises"],
];

pub(crate) static ENTRY_FIGURIZE_10842730720774474303: VariantsMap =
    [&["figurize"], &["figurise"], &["figurize"], &["figurise"]];

pub(crate) static ENTRY_FILMIZES_8443731642258725255: VariantsMap =
    [&["filmizes"], &["filmises"], &["filmizes"], &["filmises"]];

pub(crate) static ENTRY_FILMIZE_7748638805888929688: VariantsMap =
    [&["filmize"], &["filmise"], &["filmize"], &["filmise"]];

pub(crate) static ENTRY_FINALIZATIONS_8331454203854375513: VariantsMap = [
    &["finalizations"],
    &["finalisations"],
    &["finalizations"],
    &["finalisations"],
];

pub(crate) static ENTRY_FINALIZATION_1713663724954282799: VariantsMap = [
    &["finalization"],
    &["finalisation"],
    &["finalization"],
    &["finalisation"],
];

pub(crate) static ENTRY_FINALIZED_12365738080071899916: VariantsMap = [
    &["finalized"],
    &["finalised"],
    &["finalized"],
    &["finalised"],
];

pub(crate) static ENTRY_FINALIZES_10983321682404972812: VariantsMap = [
    &["finalizes"],
    &["finalises"],
    &["finalizes"],
    &["finalises"],
];

pub(crate) static ENTRY_FINALIZE_6361287847222643044: VariantsMap =
    [&["finalize"], &["finalise"], &["finalize"], &["finalise"]];

pub(crate) static ENTRY_FINALIZING_10636713064978874210: VariantsMap = [
    &["finalizing"],
    &["finalising"],
    &["finalizing"],
    &["finalising"],
];

pub(crate) static ENTRY_FINLANDIZATIONS_10327954352032319026: VariantsMap = [
    &["finlandizations"],
    &["finlandisations"],
    &["finlandizations"],
    &["finlandisations"],
];

pub(crate) static ENTRY_FINLANDIZATION_17456639156502306653: VariantsMap = [
    &["finlandization"],
    &["finlandisation"],
    &["finlandization"],
    &["finlandisation"],
];

pub(crate) static ENTRY_FISCALIZATIONS_15013088357283335917: VariantsMap = [
    &["fiscalizations"],
    &["fiscalisations"],
    &["fiscalizations"],
    &["fiscalisations"],
];

pub(crate) static ENTRY_FISCALIZATION_15214196836508290213: VariantsMap = [
    &["fiscalization"],
    &["fiscalisation"],
    &["fiscalization"],
    &["fiscalisation"],
];

pub(crate) static ENTRY_FISCALIZES_17651635012695062469: VariantsMap = [
    &["fiscalizes"],
    &["fiscalises"],
    &["fiscalizes"],
    &["fiscalises"],
];

pub(crate) static ENTRY_FISCALIZE_12383058975332866270: VariantsMap = [
    &["fiscalize"],
    &["fiscalise"],
    &["fiscalize"],
    &["fiscalise"],
];

pub(crate) static ENTRY_FLAMBOYANTIZES_3390037775777669851: VariantsMap = [
    &["flamboyantizes"],
    &["flamboyantises"],
    &["flamboyantizes"],
    &["flamboyantises"],
];

pub(crate) static ENTRY_FLAMBOYANTIZE_10739085749969945339: VariantsMap = [
    &["flamboyantize"],
    &["flamboyantise"],
    &["flamboyantize"],
    &["flamboyantise"],
];

pub(crate) static ENTRY_FLANNELED_3360043852230682699: VariantsMap = [
    &["flanneled"],
    &["flannelled"],
    &["flannelled"],
    &["flannelled"],
];

pub(crate) static ENTRY_FLANNELETTE_12069498104014004076: VariantsMap = [
    &["flannelette"],
    &["flannelette"],
    &["flannelette"],
    &["flannelette"],
];

pub(crate) static ENTRY_FLANNELING_4012495315920627349: VariantsMap = [
    &["flanneling"],
    &["flannelling"],
    &["flannelling"],
    &["flannelling"],
];

pub(crate) static ENTRY_FLAVORED_5627247048743299150: VariantsMap = [
    &["flavored"],
    &["flavoured"],
    &["flavoured"],
    &["flavoured"],
];

pub(crate) static ENTRY_FLAVORERS_11272413788636554077: VariantsMap = [
    &["flavorers"],
    &["flavourers"],
    &["flavourers"],
    &["flavourers"],
];

pub(crate) static ENTRY_FLAVORER_4047795277880865277: VariantsMap = [
    &["flavorer"],
    &["flavourer"],
    &["flavourer"],
    &["flavourer"],
];

pub(crate) static ENTRY_FLAVORFULER_6696273803305785559: VariantsMap = [
    &["flavorfuler"],
    &["flavourfuler"],
    &["flavourfuler"],
    &["flavourfuler"],
];

pub(crate) static ENTRY_FLAVORFULEST_11637668202952292143: VariantsMap = [
    &["flavorfulest"],
    &["flavourfulest"],
    &["flavourfulest"],
    &["flavourfulest"],
];

pub(crate) static ENTRY_FLAVORFULLIER_4653961700222736607: VariantsMap = [
    &["flavorfullier"],
    &["flavourfullier"],
    &["flavourfullier"],
    &["flavourfullier"],
];

pub(crate) static ENTRY_FLAVORFULLIEST_1942998500709732048: VariantsMap = [
    &["flavorfulliest"],
    &["flavourfulliest"],
    &["flavourfulliest"],
    &["flavourfulliest"],
];

pub(crate) static ENTRY_FLAVORFULLY_7477538950157672595: VariantsMap = [
    &["flavorfully"],
    &["flavourfully"],
    &["flavourfully"],
    &["flavourfully"],
];

pub(crate) static ENTRY_FLAVORFUL_5944085188485911509: VariantsMap = [
    &["flavorful"],
    &["flavourful"],
    &["flavourful"],
    &["flavourful"],
];

pub(crate) static ENTRY_FLAVORIER_14486196458812907070: VariantsMap = [
    &["flavorier"],
    &["flavourier"],
    &["flavourier"],
    &["flavourier"],
];

pub(crate) static ENTRY_FLAVORIEST_9321543981933061232: VariantsMap = [
    &["flavoriest"],
    &["flavouriest"],
    &["flavouriest"],
    &["flavouriest"],
];

pub(crate) static ENTRY_FLAVORINGS_4333914468476562312: VariantsMap = [
    &["flavorings"],
    &["flavourings"],
    &["flavourings"],
    &["flavourings"],
];

pub(crate) static ENTRY_FLAVORING_1040976265495793448: VariantsMap = [
    &["flavoring"],
    &["flavouring"],
    &["flavouring"],
    &["flavouring"],
];

pub(crate) static ENTRY_FLAVORLESSER_6704080193000679945: VariantsMap = [
    &["flavorlesser"],
    &["flavourlesser"],
    &["flavourlesser"],
    &["flavourlesser"],
];

pub(crate) static ENTRY_FLAVORLESSEST_5257507821497526035: VariantsMap = [
    &["flavorlessest"],
    &["flavourlessest"],
    &["flavourlessest"],
    &["flavourlessest"],
];

pub(crate) static ENTRY_FLAVORLESSES_328096443616320440: VariantsMap = [
    &["flavorlesses"],
    &["flavourlesses"],
    &["flavourlesses"],
    &["flavourlesses"],
];

pub(crate) static ENTRY_FLAVORLESS_11245042299561592850: VariantsMap = [
    &["flavorless"],
    &["flavourless"],
    &["flavourless"],
    &["flavourless"],
];

pub(crate) static ENTRY_FLAVOROUS_16069319827243586679: VariantsMap = [
    &["flavorous"],
    &["flavorous"],
    &["flavorous"],
    &["flavorous"],
];

pub(crate) static ENTRY_FLAVORSOMER_9283046503206827837: VariantsMap = [
    &["flavorsomer"],
    &["flavoursomer"],
    &["flavoursomer"],
    &["flavoursomer"],
];

pub(crate) static ENTRY_FLAVORSOMEST_15528669799121213414: VariantsMap = [
    &["flavorsomest"],
    &["flavoursomest"],
    &["flavoursomest"],
    &["flavoursomest"],
];

pub(crate) static ENTRY_FLAVORSOME_3715740836293625146: VariantsMap = [
    &["flavorsome"],
    &["flavoursome"],
    &["flavoursome"],
    &["flavoursome"],
];

pub(crate) static ENTRY_FLAVORS_7502432271130276472: VariantsMap =
    [&["flavors"], &["flavours"], &["flavours"], &["flavours"]];

pub(crate) static ENTRY_FLAVORY_5581256405708500009: VariantsMap =
    [&["flavory"], &["flavoury"], &["flavoury"], &["flavoury"]];

pub(crate) static ENTRY_FLAVOR_13147746738852786676: VariantsMap =
    [&["flavor"], &["flavour"], &["flavour"], &["flavour"]];

pub(crate) static ENTRY_FLEDGLINGS_13590009262290363932: VariantsMap = [
    &["fledglings"],
    &["fledglings"],
    &["fledglings"],
    &["fledglings"],
];

pub(crate) static ENTRY_FLEDGLING_7994074526705315877: VariantsMap = [
    &["fledgling"],
    &["fledgling"],
    &["fledgling"],
    &["fledgling"],
];

pub(crate) static ENTRY_FLETCHERIZED_13650083698674644519: VariantsMap = [
    &["fletcherized"],
    &["fletcherised"],
    &["fletcherized"],
    &["fletcherised"],
];

pub(crate) static ENTRY_FLETCHERIZES_11092269357737681439: VariantsMap = [
    &["fletcherizes"],
    &["fletcherises"],
    &["fletcherizes"],
    &["fletcherises"],
];

pub(crate) static ENTRY_FLETCHERIZE_2938326935179785107: VariantsMap = [
    &["fletcherize"],
    &["fletcherise"],
    &["fletcherize"],
    &["fletcherise"],
];

pub(crate) static ENTRY_FLETCHERIZING_2070710165649975625: VariantsMap = [
    &["fletcherizing"],
    &["fletcherising"],
    &["fletcherizing"],
    &["fletcherising"],
];

pub(crate) static ENTRY_FLORALIZES_9002365200591546886: VariantsMap = [
    &["floralizes"],
    &["floralises"],
    &["floralizes"],
    &["floralises"],
];

pub(crate) static ENTRY_FLORALIZE_1627350310190043452: VariantsMap = [
    &["floralize"],
    &["floralise"],
    &["floralize"],
    &["floralise"],
];

pub(crate) static ENTRY_FLORAMOR_16582942827359883333: VariantsMap = [
    &["floramor"],
    &["floramour"],
    &["floramour"],
    &["floramour"],
];

pub(crate) static ENTRY_FLUIDIZATIONS_5389462904710287795: VariantsMap = [
    &["fluidizations"],
    &["fluidisations"],
    &["fluidizations"],
    &["fluidisations"],
];

pub(crate) static ENTRY_FLUIDIZATION_11969565540843536522: VariantsMap = [
    &["fluidization"],
    &["fluidisation"],
    &["fluidization"],
    &["fluidisation"],
];

pub(crate) static ENTRY_FLUIDIZED_16610704945227594739: VariantsMap = [
    &["fluidized"],
    &["fluidised"],
    &["fluidized"],
    &["fluidised"],
];

pub(crate) static ENTRY_FLUIDIZERS_3958616063238696252: VariantsMap = [
    &["fluidizers"],
    &["fluidisers"],
    &["fluidizers"],
    &["fluidisers"],
];

pub(crate) static ENTRY_FLUIDIZER_11704131419355126038: VariantsMap = [
    &["fluidizer"],
    &["fluidiser"],
    &["fluidizer"],
    &["fluidiser"],
];

pub(crate) static ENTRY_FLUIDIZES_406786174709282531: VariantsMap = [
    &["fluidizes"],
    &["fluidises"],
    &["fluidizes"],
    &["fluidises"],
];

pub(crate) static ENTRY_FLUIDIZE_1455252710765083915: VariantsMap =
    [&["fluidize"], &["fluidise"], &["fluidize"], &["fluidise"]];

pub(crate) static ENTRY_FLUIDIZING_3867188207098201511: VariantsMap = [
    &["fluidizing"],
    &["fluidising"],
    &["fluidizing"],
    &["fluidising"],
];

pub(crate) static ENTRY_FLUORIDIZATIONS_11927169473008860358: VariantsMap = [
    &["fluoridizations"],
    &["fluoridisations"],
    &["fluoridizations"],
    &["fluoridisations"],
];

pub(crate) static ENTRY_FLUORIDIZATION_1280860877521174385: VariantsMap = [
    &["fluoridization"],
    &["fluoridisation"],
    &["fluoridization"],
    &["fluoridisation"],
];

pub(crate) static ENTRY_FLUORIDIZED_1588370394858922120: VariantsMap = [
    &["fluoridized"],
    &["fluoridised"],
    &["fluoridized"],
    &["fluoridised"],
];

pub(crate) static ENTRY_FLUORIDIZES_3296309858810834391: VariantsMap = [
    &["fluoridizes"],
    &["fluoridises"],
    &["fluoridizes"],
    &["fluoridises"],
];

pub(crate) static ENTRY_FLUORIDIZE_16455851797679281502: VariantsMap = [
    &["fluoridize"],
    &["fluoridise"],
    &["fluoridize"],
    &["fluoridise"],
];

pub(crate) static ENTRY_FLUORIDIZING_12894945638877400542: VariantsMap = [
    &["fluoridizing"],
    &["fluoridising"],
    &["fluoridizing"],
    &["fluoridising"],
];

pub(crate) static ENTRY_FLUTISTS_1304316840696127041: VariantsMap = [
    &["flutists"],
    &["flautists"],
    &["flautists", "flutists"],
    &["flautists"],
];

pub(crate) static ENTRY_FLUTIST_8416620116439104202: VariantsMap = [
    &["flutist"],
    &["flautist"],
    &["flautist", "flutist"],
    &["flautist"],
];

pub(crate) static ENTRY_FOCALIZATIONS_656464172871381508: VariantsMap = [
    &["focalizations"],
    &["focalisations"],
    &["focalizations"],
    &["focalisations"],
];

pub(crate) static ENTRY_FOCALIZATION_14563255569333889153: VariantsMap = [
    &["focalization"],
    &["focalisation"],
    &["focalization"],
    &["focalisation"],
];

pub(crate) static ENTRY_FOCALIZED_6456532754500655101: VariantsMap = [
    &["focalized"],
    &["focalised"],
    &["focalized"],
    &["focalised"],
];

pub(crate) static ENTRY_FOCALIZES_4692085235969656840: VariantsMap = [
    &["focalizes"],
    &["focalises"],
    &["focalizes"],
    &["focalises"],
];

pub(crate) static ENTRY_FOCALIZE_9001114145740139167: VariantsMap =
    [&["focalize"], &["focalise"], &["focalize"], &["focalise"]];

pub(crate) static ENTRY_FOCALIZING_4389775854829490698: VariantsMap = [
    &["focalizing"],
    &["focalising"],
    &["focalizing"],
    &["focalising"],
];

pub(crate) static ENTRY_FOGIES_5940521606153956705: VariantsMap =
    [&["fogies"], &["fogeys"], &["fogeys"], &["fogeys"]];

pub(crate) static ENTRY_FOGY_7754829639070054468: VariantsMap =
    [&["fogy"], &["fogey"], &["fogey"], &["fogey"]];

pub(crate) static ENTRY_FONTANELS_4866743522768096750: VariantsMap = [
    &["fontanels"],
    &["fontanelles"],
    &["fontanelles"],
    &["fontanelles"],
];

pub(crate) static ENTRY_FONTANEL_10062742686753308418: VariantsMap = [
    &["fontanel"],
    &["fontanelle"],
    &["fontanelle"],
    &["fontanelle"],
];

pub(crate) static ENTRY_FOOLHARDIZED_11630837856384924834: VariantsMap = [
    &["foolhardized"],
    &["foolhardised"],
    &["foolhardized"],
    &["foolhardised"],
];

pub(crate) static ENTRY_FOOLHARDIZES_11669778763770885098: VariantsMap = [
    &["foolhardizes"],
    &["foolhardises"],
    &["foolhardizes"],
    &["foolhardises"],
];

pub(crate) static ENTRY_FOOLHARDIZE_12653115974016256941: VariantsMap = [
    &["foolhardize"],
    &["foolhardise"],
    &["foolhardize"],
    &["foolhardise"],
];

pub(crate) static ENTRY_FOOLHARDIZING_237204071785291493: VariantsMap = [
    &["foolhardizing"],
    &["foolhardising"],
    &["foolhardizing"],
    &["foolhardising"],
];

pub(crate) static ENTRY_FORB_6126634977774856175: VariantsMap =
    [&["forb"], &["fourb"], &["fourb"], &["fourb"]];

pub(crate) static ENTRY_FORCHE_1402256314253192740: VariantsMap =
    [&["forche"], &["fourche"], &["fourche"], &["fourche"]];

pub(crate) static ENTRY_FOREIGNIZATIONS_15541407490261464144: VariantsMap = [
    &["foreignizations"],
    &["foreignisations"],
    &["foreignizations"],
    &["foreignisations"],
];

pub(crate) static ENTRY_FOREIGNIZATION_15293014747107118614: VariantsMap = [
    &["foreignization"],
    &["foreignisation"],
    &["foreignization"],
    &["foreignisation"],
];

pub(crate) static ENTRY_FOREIGNIZES_12119955402842918681: VariantsMap = [
    &["foreignizes"],
    &["foreignises"],
    &["foreignizes"],
    &["foreignises"],
];

pub(crate) static ENTRY_FOREIGNIZE_11198008980056672481: VariantsMap = [
    &["foreignize"],
    &["foreignise"],
    &["foreignize"],
    &["foreignise"],
];

pub(crate) static ENTRY_FOREJUDGMENTS_18086623748196401092: VariantsMap = [
    &["forejudgments"],
    &["forejudgements"],
    &["forejudgements"],
    &["forejudgements"],
];

pub(crate) static ENTRY_FOREJUDGMENT_9237290865507679025: VariantsMap = [
    &["forejudgment"],
    &["forejudgement"],
    &["forejudgement"],
    &["forejudgement"],
];

pub(crate) static ENTRY_FOREPRIZE_15696928659273283812: VariantsMap = [
    &["foreprize"],
    &["foreprise"],
    &["foreprize"],
    &["foreprise"],
];

pub(crate) static ENTRY_FORMALIZABLE_7585059673108358079: VariantsMap = [
    &["formalizable"],
    &["formalisable"],
    &["formalizable"],
    &["formalisable"],
];

pub(crate) static ENTRY_FORMALIZATIONS_8555578184919419751: VariantsMap = [
    &["formalizations"],
    &["formalisations"],
    &["formalizations"],
    &["formalisations"],
];

pub(crate) static ENTRY_FORMALIZATION_2591485126762882449: VariantsMap = [
    &["formalization"],
    &["formalisation"],
    &["formalization"],
    &["formalisation"],
];

pub(crate) static ENTRY_FORMALIZED_9806599668393286541: VariantsMap = [
    &["formalized"],
    &["formalised"],
    &["formalized"],
    &["formalised"],
];

pub(crate) static ENTRY_FORMALIZERS_4493481399447794615: VariantsMap = [
    &["formalizers"],
    &["formalisers"],
    &["formalizers"],
    &["formalisers"],
];

pub(crate) static ENTRY_FORMALIZER_4036745239171518381: VariantsMap = [
    &["formalizer"],
    &["formaliser"],
    &["formalizer"],
    &["formaliser"],
];

pub(crate) static ENTRY_FORMALIZES_15752365028447713270: VariantsMap = [
    &["formalizes"],
    &["formalises"],
    &["formalizes"],
    &["formalises"],
];

pub(crate) static ENTRY_FORMALIZE_1679468906044255450: VariantsMap = [
    &["formalize"],
    &["formalise"],
    &["formalize"],
    &["formalise"],
];

pub(crate) static ENTRY_FORMALIZING_5721392513252990643: VariantsMap = [
    &["formalizing"],
    &["formalising"],
    &["formalizing"],
    &["formalising"],
];

pub(crate) static ENTRY_FORME_8817057189260314567: VariantsMap =
    [&["forme"], &["formae"], &["formae"], &["formae"]];

pub(crate) static ENTRY_FORMICIDE_14400080074027357649: VariantsMap = [
    &["formicide"],
    &["formicidae"],
    &["formicidae"],
    &["formicidae"],
];

pub(crate) static ENTRY_FORMULARIZATIONS_9630465214768761062: VariantsMap = [
    &["formularizations"],
    &["formularisations"],
    &["formularizations"],
    &["formularisations"],
];

pub(crate) static ENTRY_FORMULARIZATION_4096021351742803243: VariantsMap = [
    &["formularization"],
    &["formularisation"],
    &["formularization"],
    &["formularisation"],
];

pub(crate) static ENTRY_FORMULARIZED_14755186046923001561: VariantsMap = [
    &["formularized"],
    &["formularised"],
    &["formularized"],
    &["formularised"],
];

pub(crate) static ENTRY_FORMULARIZERS_5805308029962586697: VariantsMap = [
    &["formularizers"],
    &["formularisers"],
    &["formularizers"],
    &["formularisers"],
];

pub(crate) static ENTRY_FORMULARIZER_13491153773141977702: VariantsMap = [
    &["formularizer"],
    &["formulariser"],
    &["formularizer"],
    &["formulariser"],
];

pub(crate) static ENTRY_FORMULARIZES_6077920602945622346: VariantsMap = [
    &["formularizes"],
    &["formularises"],
    &["formularizes"],
    &["formularises"],
];

pub(crate) static ENTRY_FORMULARIZE_16840729465120564209: VariantsMap = [
    &["formularize"],
    &["formularise"],
    &["formularize"],
    &["formularise"],
];

pub(crate) static ENTRY_FORMULARIZING_3458666980856017654: VariantsMap = [
    &["formularizing"],
    &["formularising"],
    &["formularizing"],
    &["formularising"],
];

pub(crate) static ENTRY_FORMULIZATIONS_7651203325038229389: VariantsMap = [
    &["formulizations"],
    &["formulisations"],
    &["formulizations"],
    &["formulisations"],
];

pub(crate) static ENTRY_FORMULIZATION_15762814181405703881: VariantsMap = [
    &["formulization"],
    &["formulisation"],
    &["formulization"],
    &["formulisation"],
];

pub(crate) static ENTRY_FORMULIZED_7061613765094184503: VariantsMap = [
    &["formulized"],
    &["formulised"],
    &["formulized"],
    &["formulised"],
];

pub(crate) static ENTRY_FORMULIZER_1938134547151236987: VariantsMap = [
    &["formulizer"],
    &["formuliser"],
    &["formulizer"],
    &["formuliser"],
];

pub(crate) static ENTRY_FORMULIZES_10074978617027689565: VariantsMap = [
    &["formulizes"],
    &["formulises"],
    &["formulizes"],
    &["formulises"],
];

pub(crate) static ENTRY_FORMULIZE_7249621384300709725: VariantsMap = [
    &["formulize"],
    &["formulise"],
    &["formulize"],
    &["formulise"],
];

pub(crate) static ENTRY_FORMULIZING_613748303971363524: VariantsMap = [
    &["formulizing"],
    &["formulising"],
    &["formulizing"],
    &["formulising"],
];

pub(crate) static ENTRY_FORUMIZES_12018353002631822802: VariantsMap = [
    &["forumizes"],
    &["forumises"],
    &["forumizes"],
    &["forumises"],
];

pub(crate) static ENTRY_FORUMIZE_8419530003404584902: VariantsMap =
    [&["forumize"], &["forumise"], &["forumize"], &["forumise"]];

pub(crate) static ENTRY_FOSSE_3258749641128695749: VariantsMap =
    [&["fosse"], &["fossae"], &["fossae"], &["fossae"]];

pub(crate) static ENTRY_FOSSILED_7388917284102970861: VariantsMap = [
    &["fossiled"],
    &["fossilled"],
    &["fossilled"],
    &["fossilled"],
];

pub(crate) static ENTRY_FOSSILIZABLER_18074000082058380580: VariantsMap = [
    &["fossilizabler"],
    &["fossilisabler"],
    &["fossilizabler"],
    &["fossilisabler"],
];

pub(crate) static ENTRY_FOSSILIZABLEST_8988007686369551192: VariantsMap = [
    &["fossilizablest"],
    &["fossilisablest"],
    &["fossilizablest"],
    &["fossilisablest"],
];

pub(crate) static ENTRY_FOSSILIZABLES_17849243195390470932: VariantsMap = [
    &["fossilizables"],
    &["fossilisables"],
    &["fossilizables"],
    &["fossilisables"],
];

pub(crate) static ENTRY_FOSSILIZABLE_18179987864109440980: VariantsMap = [
    &["fossilizable"],
    &["fossilisable"],
    &["fossilizable"],
    &["fossilisable"],
];

pub(crate) static ENTRY_FOSSILIZATIONS_13043864217790465526: VariantsMap = [
    &["fossilizations"],
    &["fossilisations"],
    &["fossilizations"],
    &["fossilisations"],
];

pub(crate) static ENTRY_FOSSILIZATION_8495765767484914666: VariantsMap = [
    &["fossilization"],
    &["fossilisation"],
    &["fossilization"],
    &["fossilisation"],
];

pub(crate) static ENTRY_FOSSILIZED_9532911763478840886: VariantsMap = [
    &["fossilized"],
    &["fossilised"],
    &["fossilized"],
    &["fossilised"],
];

pub(crate) static ENTRY_FOSSILIZES_1575017333804498872: VariantsMap = [
    &["fossilizes"],
    &["fossilises"],
    &["fossilizes"],
    &["fossilises"],
];

pub(crate) static ENTRY_FOSSILIZE_15956386341505137526: VariantsMap = [
    &["fossilize"],
    &["fossilise"],
    &["fossilize"],
    &["fossilise"],
];

pub(crate) static ENTRY_FOSSILIZING_12802087173792026745: VariantsMap = [
    &["fossilizing"],
    &["fossilising"],
    &["fossilizing"],
    &["fossilising"],
];

pub(crate) static ENTRY_FOSSULE_16030537484007901649: VariantsMap =
    [&["fossule"], &["fossulae"], &["fossulae"], &["fossulae"]];

pub(crate) static ENTRY_FOULDER_16108707272330673330: VariantsMap =
    [&["foulder"], &["fouldre"], &["fouldre"], &["fouldre"]];

pub(crate) static ENTRY_FOUTERS_2811207748622809965: VariantsMap =
    [&["fouters"], &["foutres"], &["foutres"], &["foutres"]];

pub(crate) static ENTRY_FOUTER_14629881838259893932: VariantsMap =
    [&["fouter"], &["foutre"], &["foutre"], &["foutre"]];

pub(crate) static ENTRY_FOVEOLE_15698905273647136338: VariantsMap =
    [&["foveole"], &["foveolae"], &["foveolae"], &["foveolae"]];

pub(crate) static ENTRY_FRACTIONALIZATIONS_13179689836045633268: VariantsMap = [
    &["fractionalizations"],
    &["fractionalisations"],
    &["fractionalizations"],
    &["fractionalisations"],
];

pub(crate) static ENTRY_FRACTIONALIZATION_16384909557987092874: VariantsMap = [
    &["fractionalization"],
    &["fractionalisation"],
    &["fractionalization"],
    &["fractionalisation"],
];

pub(crate) static ENTRY_FRACTIONALIZED_13769926033588137385: VariantsMap = [
    &["fractionalized"],
    &["fractionalised"],
    &["fractionalized"],
    &["fractionalised"],
];

pub(crate) static ENTRY_FRACTIONALIZES_17666163749894726979: VariantsMap = [
    &["fractionalizes"],
    &["fractionalises"],
    &["fractionalizes"],
    &["fractionalises"],
];

pub(crate) static ENTRY_FRACTIONALIZE_11145753951508722721: VariantsMap = [
    &["fractionalize"],
    &["fractionalise"],
    &["fractionalize"],
    &["fractionalise"],
];

pub(crate) static ENTRY_FRACTIONALIZING_18417565787016805561: VariantsMap = [
    &["fractionalizing"],
    &["fractionalising"],
    &["fractionalizing"],
    &["fractionalising"],
];

pub(crate) static ENTRY_FRACTIONIZATIONS_8008183611215290136: VariantsMap = [
    &["fractionizations"],
    &["fractionisations"],
    &["fractionizations"],
    &["fractionisations"],
];

pub(crate) static ENTRY_FRACTIONIZATION_11310553652346900287: VariantsMap = [
    &["fractionization"],
    &["fractionisation"],
    &["fractionization"],
    &["fractionisation"],
];

pub(crate) static ENTRY_FRACTIONIZED_9636630884367605738: VariantsMap = [
    &["fractionized"],
    &["fractionised"],
    &["fractionized"],
    &["fractionised"],
];

pub(crate) static ENTRY_FRACTIONIZES_1122151038872899386: VariantsMap = [
    &["fractionizes"],
    &["fractionises"],
    &["fractionizes"],
    &["fractionises"],
];

pub(crate) static ENTRY_FRACTIONIZE_17146847402825816377: VariantsMap = [
    &["fractionize"],
    &["fractionise"],
    &["fractionize"],
    &["fractionise"],
];

pub(crate) static ENTRY_FRACTIONIZING_7844279074827159878: VariantsMap = [
    &["fractionizing"],
    &["fractionising"],
    &["fractionizing"],
    &["fractionising"],
];

pub(crate) static ENTRY_FRAGMENTIZATION_11311522493510806007: VariantsMap = [
    &["fragmentization"],
    &["fragmentisation"],
    &["fragmentization"],
    &["fragmentisation"],
];

pub(crate) static ENTRY_FRAGMENTIZED_7624364982594162254: VariantsMap = [
    &["fragmentized"],
    &["fragmentised"],
    &["fragmentized"],
    &["fragmentised"],
];

pub(crate) static ENTRY_FRAGMENTIZER_11875792900792650033: VariantsMap = [
    &["fragmentizer"],
    &["fragmentiser"],
    &["fragmentizer"],
    &["fragmentiser"],
];

pub(crate) static ENTRY_FRAGMENTIZES_7273396024325138788: VariantsMap = [
    &["fragmentizes"],
    &["fragmentises"],
    &["fragmentizes"],
    &["fragmentises"],
];

pub(crate) static ENTRY_FRAGMENTIZE_11591563595037284264: VariantsMap = [
    &["fragmentize"],
    &["fragmentise"],
    &["fragmentize"],
    &["fragmentise"],
];

pub(crate) static ENTRY_FRAGMENTIZING_4493708054049080561: VariantsMap = [
    &["fragmentizing"],
    &["fragmentising"],
    &["fragmentizing"],
    &["fragmentising"],
];

pub(crate) static ENTRY_FRAMBESIAS_12235414527947368126: VariantsMap = [
    &["frambesias"],
    &["framboesias"],
    &["framboesias"],
    &["framboesias"],
];

pub(crate) static ENTRY_FRAMBESIA_5861085960963562398: VariantsMap = [
    &["frambesia"],
    &["framboesia"],
    &["framboesia"],
    &["framboesia"],
];

pub(crate) static ENTRY_FRANCIZES_4289708258444944079: VariantsMap = [
    &["francizes"],
    &["francises"],
    &["francizes"],
    &["francises"],
];

pub(crate) static ENTRY_FRANCIZE_13649175539545993519: VariantsMap =
    [&["francize"], &["francise"], &["francize"], &["francise"]];

pub(crate) static ENTRY_FRANKLINIZATIONS_12423021383400433032: VariantsMap = [
    &["franklinizations"],
    &["franklinisations"],
    &["franklinizations"],
    &["franklinisations"],
];

pub(crate) static ENTRY_FRANKLINIZATION_13025384598101464262: VariantsMap = [
    &["franklinization"],
    &["franklinisation"],
    &["franklinization"],
    &["franklinisation"],
];

pub(crate) static ENTRY_FRATERNIZATIONS_2264901292350066915: VariantsMap = [
    &["fraternizations"],
    &["fraternisations"],
    &["fraternizations"],
    &["fraternisations"],
];

pub(crate) static ENTRY_FRATERNIZATION_17491532297861507226: VariantsMap = [
    &["fraternization"],
    &["fraternisation"],
    &["fraternization"],
    &["fraternisation"],
];

pub(crate) static ENTRY_FRATERNIZED_40843362060401503: VariantsMap = [
    &["fraternized"],
    &["fraternised"],
    &["fraternized"],
    &["fraternised"],
];

pub(crate) static ENTRY_FRATERNIZERS_17211381996632496983: VariantsMap = [
    &["fraternizers"],
    &["fraternisers"],
    &["fraternizers"],
    &["fraternisers"],
];

pub(crate) static ENTRY_FRATERNIZER_8545635095936020045: VariantsMap = [
    &["fraternizer"],
    &["fraterniser"],
    &["fraternizer"],
    &["fraterniser"],
];

pub(crate) static ENTRY_FRATERNIZES_11999482520269062840: VariantsMap = [
    &["fraternizes"],
    &["fraternises"],
    &["fraternizes"],
    &["fraternises"],
];

pub(crate) static ENTRY_FRATERNIZE_6114828862653151704: VariantsMap = [
    &["fraternize"],
    &["fraternise"],
    &["fraternize"],
    &["fraternise"],
];

pub(crate) static ENTRY_FRATERNIZING_17486557641907645835: VariantsMap = [
    &["fraternizing"],
    &["fraternising"],
    &["fraternizing"],
    &["fraternising"],
];

pub(crate) static ENTRY_FRENA_9256148821059642646: VariantsMap =
    [&["frena"], &["fraena"], &["fraena"], &["fraena"]];

pub(crate) static ENTRY_FRENCHIZES_13171453204737829989: VariantsMap = [
    &["frenchizes"],
    &["frenchises"],
    &["frenchizes"],
    &["frenchises"],
];

pub(crate) static ENTRY_FRENCHIZE_5282928364010596499: VariantsMap = [
    &["frenchize"],
    &["frenchise"],
    &["frenchize"],
    &["frenchise"],
];

pub(crate) static ENTRY_FRENULAR_6156340314741914755: VariantsMap = [
    &["frenular"],
    &["fraenular"],
    &["fraenular"],
    &["fraenular"],
];

pub(crate) static ENTRY_FRENULA_17174405168241583244: VariantsMap =
    [&["frenula"], &["fraenula"], &["fraenula"], &["fraenula"]];

pub(crate) static ENTRY_FRENULUM_16387614517776586745: VariantsMap = [
    &["frenulum"],
    &["fraenulum"],
    &["fraenulum"],
    &["fraenulum"],
];

pub(crate) static ENTRY_FRENUMS_14492633245925017206: VariantsMap =
    [&["frenums"], &["fraenums"], &["fraenums"], &["fraenums"]];

pub(crate) static ENTRY_FRENUM_12416692539021246592: VariantsMap =
    [&["frenum"], &["fraenum"], &["fraenum"], &["fraenum"]];

pub(crate) static ENTRY_FRIBORG_14998222602089863011: VariantsMap =
    [&["friborg"], &["fribourg"], &["fribourg"], &["fribourg"]];

pub(crate) static ENTRY_FRICTIONIZES_13370622118045354659: VariantsMap = [
    &["frictionizes"],
    &["frictionises"],
    &["frictionizes"],
    &["frictionises"],
];

pub(crate) static ENTRY_FRICTIONIZE_13167776211997189353: VariantsMap = [
    &["frictionize"],
    &["frictionise"],
    &["frictionize"],
    &["frictionise"],
];

pub(crate) static ENTRY_FRIVOLED_10810709816607291145: VariantsMap = [
    &["frivoled"],
    &["frivolled"],
    &["frivolled"],
    &["frivolled"],
];

pub(crate) static ENTRY_FRIVOLERS_14649857547767057396: VariantsMap = [
    &["frivolers"],
    &["frivollers"],
    &["frivollers"],
    &["frivollers"],
];

pub(crate) static ENTRY_FRIVOLER_2817825932076218971: VariantsMap = [
    &["frivoler"],
    &["frivoller"],
    &["frivoller"],
    &["frivoller"],
];

pub(crate) static ENTRY_FRIVOLING_16952070309248351114: VariantsMap = [
    &["frivoling"],
    &["frivolling"],
    &["frivolling"],
    &["frivolling"],
];

pub(crate) static ENTRY_FRIZADO_7132644256144212836: VariantsMap =
    [&["frizado"], &["frisado"], &["frizado"], &["frisado"]];

pub(crate) static ENTRY_FRIZETTES_7971399902959741267: VariantsMap = [
    &["frizettes"],
    &["frisettes"],
    &["frizettes"],
    &["frisettes"],
];

pub(crate) static ENTRY_FRIZETTE_7935539353493442254: VariantsMap =
    [&["frizette"], &["frisette"], &["frizette"], &["frisette"]];

pub(crate) static ENTRY_FRIZE_18317112308802773864: VariantsMap =
    [&["frize"], &["frise"], &["frize"], &["frise"]];

pub(crate) static ENTRY_FUELED_1405501076484499618: VariantsMap =
    [&["fueled"], &["fuelled"], &["fuelled"], &["fuelled"]];

pub(crate) static ENTRY_FUELERS_14375576697530944446: VariantsMap =
    [&["fuelers"], &["fuellers"], &["fuellers"], &["fuellers"]];

pub(crate) static ENTRY_FUELER_15360085798704172702: VariantsMap =
    [&["fueler"], &["fueller"], &["fueller"], &["fueller"]];

pub(crate) static ENTRY_FUELING_13174491634544185979: VariantsMap =
    [&["fueling"], &["fuelling"], &["fuelling"], &["fuelling"]];

pub(crate) static ENTRY_FUELIZERS_319090579847564711: VariantsMap = [
    &["fuelizers"],
    &["fuelisers"],
    &["fuelizers"],
    &["fuelisers"],
];

pub(crate) static ENTRY_FUELIZER_197436267427694078: VariantsMap =
    [&["fuelizer"], &["fueliser"], &["fuelizer"], &["fueliser"]];

pub(crate) static ENTRY_FULFILLMENTS_1418454263886981690: VariantsMap = [
    &["fulfillments"],
    &["fulfilments"],
    &["fulfillments"],
    &["fulfilments"],
];

pub(crate) static ENTRY_FULFILLMENT_7148807446626431675: VariantsMap = [
    &["fulfillment"],
    &["fulfilment"],
    &["fulfillment"],
    &["fulfilment"],
];

pub(crate) static ENTRY_FULFILLS_3570272199614377288: VariantsMap =
    [&["fulfills"], &["fulfils"], &["fulfills"], &["fulfils"]];

pub(crate) static ENTRY_FULFILL_9378496470221325385: VariantsMap =
    [&["fulfill"], &["fulfil"], &["fulfill"], &["fulfil"]];

pub(crate) static ENTRY_FULGOROUS_7876443384003563272: VariantsMap = [
    &["fulgorous"],
    &["fulgourous"],
    &["fulgourous"],
    &["fulgourous"],
];

pub(crate) static ENTRY_FULGORS_6876524141780705677: VariantsMap =
    [&["fulgors"], &["fulgours"], &["fulgours"], &["fulgours"]];

pub(crate) static ENTRY_FULGOR_3603133681706621725: VariantsMap =
    [&["fulgor"], &["fulgour"], &["fulgour"], &["fulgour"]];

pub(crate) static ENTRY_FUNCTIONALIZES_8846469370790846555: VariantsMap = [
    &["functionalizes"],
    &["functionalises"],
    &["functionalizes"],
    &["functionalises"],
];

pub(crate) static ENTRY_FUNCTIONALIZE_5200513031891278249: VariantsMap = [
    &["functionalize"],
    &["functionalise"],
    &["functionalize"],
    &["functionalise"],
];

pub(crate) static ENTRY_FUNCTIONIZES_206660126975387910: VariantsMap = [
    &["functionizes"],
    &["functionises"],
    &["functionizes"],
    &["functionises"],
];

pub(crate) static ENTRY_FUNCTIONIZE_590437862985052700: VariantsMap = [
    &["functionize"],
    &["functionise"],
    &["functionize"],
    &["functionise"],
];

pub(crate) static ENTRY_FUNERALIZES_9727791744771513558: VariantsMap = [
    &["funeralizes"],
    &["funeralises"],
    &["funeralizes"],
    &["funeralises"],
];

pub(crate) static ENTRY_FUNERALIZE_6939628183239081771: VariantsMap = [
    &["funeralize"],
    &["funeralise"],
    &["funeralize"],
    &["funeralise"],
];

pub(crate) static ENTRY_FUNNELED_12440004640602776962: VariantsMap = [
    &["funneled"],
    &["funnelled"],
    &["funnelled"],
    &["funnelled"],
];

pub(crate) static ENTRY_FUNNELER_5464699882596191112: VariantsMap = [
    &["funneler"],
    &["funneller"],
    &["funneller"],
    &["funneller"],
];

pub(crate) static ENTRY_FUNNELING_3433367811767870104: VariantsMap = [
    &["funneling"],
    &["funnelling"],
    &["funnelling"],
    &["funnelling"],
];

pub(crate) static ENTRY_FURCULE_4500392567637304895: VariantsMap =
    [&["furcule"], &["furculae"], &["furculae"], &["furculae"]];

pub(crate) static ENTRY_FURIE_2816987526743473529: VariantsMap =
    [&["furie"], &["furiae"], &["furiae"], &["furiae"]];

pub(crate) static ENTRY_FURORS_11654983778967796186: VariantsMap =
    [&["furors"], &["furores"], &["furors"], &["furores"]];

pub(crate) static ENTRY_FUROR_9905139920010048702: VariantsMap =
    [&["furor"], &["furore"], &["furor"], &["furore"]];

pub(crate) static ENTRY_FUSED_16220222527302259642: VariantsMap =
    [&["fused"], &["fused"], &["fused"], &["fused"]];

pub(crate) static ENTRY_FUSES_6052488625673233414: VariantsMap =
    [&["fuses"], &["fuses"], &["fuses"], &["fuses"]];

pub(crate) static ENTRY_FUSE_13721350294892050426: VariantsMap =
    [&["fuse"], &["fuse"], &["fuse"], &["fuse"]];

pub(crate) static ENTRY_FUSING_4402212491712141583: VariantsMap =
    [&["fusing"], &["fusing"], &["fusing"], &["fusing"]];

pub(crate) static ENTRY_FUSTIANIZED_6857323956586456405: VariantsMap = [
    &["fustianized"],
    &["fustianised"],
    &["fustianized"],
    &["fustianised"],
];

pub(crate) static ENTRY_FUSTIANIZES_14263302384765637245: VariantsMap = [
    &["fustianizes"],
    &["fustianises"],
    &["fustianizes"],
    &["fustianises"],
];

pub(crate) static ENTRY_FUSTIANIZE_7532541978986663145: VariantsMap = [
    &["fustianize"],
    &["fustianise"],
    &["fustianize"],
    &["fustianise"],
];

pub(crate) static ENTRY_FUSTIANIZING_8877334472530223768: VariantsMap = [
    &["fustianizing"],
    &["fustianising"],
    &["fustianizing"],
    &["fustianising"],
];

pub(crate) static ENTRY_FUTILIZES_3019005313253578090: VariantsMap = [
    &["futilizes"],
    &["futilises"],
    &["futilizes"],
    &["futilises"],
];

pub(crate) static ENTRY_FUTILIZE_11119974740228332037: VariantsMap =
    [&["futilize"], &["futilise"], &["futilize"], &["futilise"]];

pub(crate) static ENTRY_FUTURIZES_15904912381443733442: VariantsMap = [
    &["futurizes"],
    &["futurises"],
    &["futurizes"],
    &["futurises"],
];

pub(crate) static ENTRY_FUTURIZE_440985091352933094: VariantsMap =
    [&["futurize"], &["futurise"], &["futurize"], &["futurise"]];

pub(crate) static ENTRY_GAELICIZATIONS_17696860649831504754: VariantsMap = [
    &["gaelicizations"],
    &["gaelicisations"],
    &["gaelicizations"],
    &["gaelicisations"],
];

pub(crate) static ENTRY_GAELICIZATION_4844070600760866038: VariantsMap = [
    &["gaelicization"],
    &["gaelicisation"],
    &["gaelicization"],
    &["gaelicisation"],
];

pub(crate) static ENTRY_GAELICIZED_15866795337678251270: VariantsMap = [
    &["gaelicized"],
    &["gaelicised"],
    &["gaelicized"],
    &["gaelicised"],
];

pub(crate) static ENTRY_GAELICIZES_17031855669643476498: VariantsMap = [
    &["gaelicizes"],
    &["gaelicises"],
    &["gaelicizes"],
    &["gaelicises"],
];

pub(crate) static ENTRY_GAELICIZE_1407556659501295001: VariantsMap = [
    &["gaelicize"],
    &["gaelicise"],
    &["gaelicize"],
    &["gaelicise"],
];

pub(crate) static ENTRY_GAELICIZING_12815210015437537089: VariantsMap = [
    &["gaelicizing"],
    &["gaelicising"],
    &["gaelicizing"],
    &["gaelicising"],
];

pub(crate) static ENTRY_GALACTORRHEAS_15234978692364003152: VariantsMap = [
    &["galactorrheas"],
    &["galactorrhoeas"],
    &["galactorrhoeas"],
    &["galactorrhoeas"],
];

pub(crate) static ENTRY_GALACTORRHEA_13861449240295747405: VariantsMap = [
    &["galactorrhea"],
    &["galactorrhoea"],
    &["galactorrhoea"],
    &["galactorrhoea"],
];

pub(crate) static ENTRY_GALACTOSEMIAS_992575803852959477: VariantsMap = [
    &["galactosemias"],
    &["galactosaemias"],
    &["galactosaemias"],
    &["galactosaemias"],
];

pub(crate) static ENTRY_GALACTOSEMIA_8989534188768018492: VariantsMap = [
    &["galactosemia"],
    &["galactosaemia"],
    &["galactosaemia"],
    &["galactosaemia"],
];

pub(crate) static ENTRY_GALEE_979378817344313906: VariantsMap =
    [&["galee"], &["galeae"], &["galeae"], &["galeae"]];

pub(crate) static ENTRY_GALLANTIZES_15362373933325224978: VariantsMap = [
    &["gallantizes"],
    &["gallantises"],
    &["gallantizes"],
    &["gallantises"],
];

pub(crate) static ENTRY_GALLANTIZE_11952937995017042016: VariantsMap = [
    &["gallantize"],
    &["gallantise"],
    &["gallantize"],
    &["gallantise"],
];

pub(crate) static ENTRY_GALLIARDIZE_6778063741977884289: VariantsMap = [
    &["galliardize"],
    &["galliardise"],
    &["galliardize"],
    &["galliardise"],
];

pub(crate) static ENTRY_GALLICIZATIONS_17628077438516611604: VariantsMap = [
    &["gallicizations"],
    &["gallicisations"],
    &["gallicizations"],
    &["gallicisations"],
];

pub(crate) static ENTRY_GALLICIZATION_9242388362936141521: VariantsMap = [
    &["gallicization"],
    &["gallicisation"],
    &["gallicization"],
    &["gallicisation"],
];

pub(crate) static ENTRY_GALLICIZED_2802912364772929047: VariantsMap = [
    &["gallicized"],
    &["gallicised"],
    &["gallicized"],
    &["gallicised"],
];

pub(crate) static ENTRY_GALLICIZER_5355064225731153450: VariantsMap = [
    &["gallicizer"],
    &["galliciser"],
    &["gallicizer"],
    &["galliciser"],
];

pub(crate) static ENTRY_GALLICIZES_2239235669702708730: VariantsMap = [
    &["gallicizes"],
    &["gallicises"],
    &["gallicizes"],
    &["gallicises"],
];

pub(crate) static ENTRY_GALLICIZE_18203286620435437022: VariantsMap = [
    &["gallicize"],
    &["gallicise"],
    &["gallicize"],
    &["gallicise"],
];

pub(crate) static ENTRY_GALLICIZING_6975607554354786209: VariantsMap = [
    &["gallicizing"],
    &["gallicising"],
    &["gallicizing"],
    &["gallicising"],
];

pub(crate) static ENTRY_GALLISIZED_15995593182854587948: VariantsMap = [
    &["gallisized"],
    &["gallisised"],
    &["gallisized"],
    &["gallisised"],
];

pub(crate) static ENTRY_GALLISIZES_7538536560398951325: VariantsMap = [
    &["gallisizes"],
    &["gallisises"],
    &["gallisizes"],
    &["gallisises"],
];

pub(crate) static ENTRY_GALLISIZE_15420643426503619914: VariantsMap = [
    &["gallisize"],
    &["gallisise"],
    &["gallisize"],
    &["gallisise"],
];

pub(crate) static ENTRY_GALLISIZING_7030944615053144646: VariantsMap = [
    &["gallisizing"],
    &["gallisising"],
    &["gallisizing"],
    &["gallisising"],
];

pub(crate) static ENTRY_GALLIZED_15522001731940226700: VariantsMap =
    [&["gallized"], &["gallised"], &["gallized"], &["gallised"]];

pub(crate) static ENTRY_GALLIZES_11429714912572540635: VariantsMap =
    [&["gallizes"], &["gallises"], &["gallizes"], &["gallises"]];

pub(crate) static ENTRY_GALLIZE_2458866677576798762: VariantsMap =
    [&["gallize"], &["gallise"], &["gallize"], &["gallise"]];

pub(crate) static ENTRY_GALLIZING_11621131501652178351: VariantsMap = [
    &["gallizing"],
    &["gallising"],
    &["gallizing"],
    &["gallising"],
];

pub(crate) static ENTRY_GALVANIZATIONS_94633790537656998: VariantsMap = [
    &["galvanizations"],
    &["galvanisations"],
    &["galvanizations"],
    &["galvanisations"],
];

pub(crate) static ENTRY_GALVANIZATION_5717361496948402685: VariantsMap = [
    &["galvanization"],
    &["galvanisation"],
    &["galvanization"],
    &["galvanisation"],
];

pub(crate) static ENTRY_GALVANIZED_6983753273153337994: VariantsMap = [
    &["galvanized"],
    &["galvanised"],
    &["galvanized"],
    &["galvanised"],
];

pub(crate) static ENTRY_GALVANIZERS_12527605368925810121: VariantsMap = [
    &["galvanizers"],
    &["galvanisers"],
    &["galvanizers"],
    &["galvanisers"],
];

pub(crate) static ENTRY_GALVANIZER_9294868075827996057: VariantsMap = [
    &["galvanizer"],
    &["galvaniser"],
    &["galvanizer"],
    &["galvaniser"],
];

pub(crate) static ENTRY_GALVANIZES_5332765103438806141: VariantsMap = [
    &["galvanizes"],
    &["galvanises"],
    &["galvanizes"],
    &["galvanises"],
];

pub(crate) static ENTRY_GALVANIZE_13754138134384178626: VariantsMap = [
    &["galvanize"],
    &["galvanise"],
    &["galvanize"],
    &["galvanise"],
];

pub(crate) static ENTRY_GALVANIZING_1108449218863508353: VariantsMap = [
    &["galvanizing"],
    &["galvanising"],
    &["galvanizing"],
    &["galvanising"],
];

pub(crate) static ENTRY_GAMBADES_2795034114389963904: VariantsMap = [
    &["gambades"],
    &["gambadoes"],
    &["gambadoes"],
    &["gambadoes"],
];

pub(crate) static ENTRY_GAMBOLED_4664830494285802567: VariantsMap = [
    &["gamboled"],
    &["gambolled"],
    &["gambolled"],
    &["gambolled"],
];

pub(crate) static ENTRY_GAMBOLING_15706579681008403067: VariantsMap = [
    &["gamboling"],
    &["gambolling"],
    &["gambolling"],
    &["gambolling"],
];

pub(crate) static ENTRY_GARGARIZED_9705368656504750107: VariantsMap = [
    &["gargarized"],
    &["gargarised"],
    &["gargarized"],
    &["gargarised"],
];

pub(crate) static ENTRY_GARGARIZES_480205376438599450: VariantsMap = [
    &["gargarizes"],
    &["gargarises"],
    &["gargarizes"],
    &["gargarises"],
];

pub(crate) static ENTRY_GARGARIZE_3473168342864934344: VariantsMap = [
    &["gargarize"],
    &["gargarise"],
    &["gargarize"],
    &["gargarise"],
];

pub(crate) static ENTRY_GARGARIZING_9383881113728329904: VariantsMap = [
    &["gargarizing"],
    &["gargarising"],
    &["gargarizing"],
    &["gargarising"],
];

pub(crate) static ENTRY_GARRULINE_11266272558421031577: VariantsMap = [
    &["garruline"],
    &["garrulinae"],
    &["garrulinae"],
    &["garrulinae"],
];

pub(crate) static ENTRY_GASES_3527587012732480671: VariantsMap =
    [&["gases"], &["gases"], &["gases"], &["gases"]];

pub(crate) static ENTRY_GASOLINES_1372889667055729574: VariantsMap = [
    &["gasolines"],
    &["gasolines"],
    &["gasolines"],
    &["gasolines"],
];

pub(crate) static ENTRY_GASOLINE_2174214619583348604: VariantsMap =
    [&["gasoline"], &["gasoline"], &["gasoline"], &["gasoline"]];

pub(crate) static ENTRY_GASTREAS_18033590203799166427: VariantsMap = [
    &["gastreas"],
    &["gastraeas"],
    &["gastraeas"],
    &["gastraeas"],
];

pub(crate) static ENTRY_GASTREA_1797131144605883399: VariantsMap =
    [&["gastrea"], &["gastraea"], &["gastraea"], &["gastraea"]];

pub(crate) static ENTRY_GASTROCELE_12395541434337095709: VariantsMap = [
    &["gastrocele"],
    &["gastrocoele"],
    &["gastrocoele"],
    &["gastrocoele"],
];

pub(crate) static ENTRY_GAUFERS_16074905635291767722: VariantsMap =
    [&["gaufers"], &["gaufres"], &["gaufres"], &["gaufres"]];

pub(crate) static ENTRY_GAUFER_15601008999281180791: VariantsMap =
    [&["gaufer"], &["gaufre"], &["gaufre"], &["gaufre"]];

pub(crate) static ENTRY_GAUFFER_313132899569716823: VariantsMap =
    [&["gauffer"], &["gauffre"], &["gauffre"], &["gauffre"]];

pub(crate) static ENTRY_GAVELED_2754242970907308344: VariantsMap =
    [&["gaveled"], &["gavelled"], &["gavelled"], &["gavelled"]];

pub(crate) static ENTRY_GAVELER_5299756916204132265: VariantsMap =
    [&["gaveler"], &["gaveller"], &["gaveller"], &["gaveller"]];

pub(crate) static ENTRY_GAVELING_2064376598913459154: VariantsMap = [
    &["gaveling"],
    &["gavelling"],
    &["gavelling"],
    &["gavelling"],
];

pub(crate) static ENTRY_GED_3160770251205469873: VariantsMap =
    [&["ged"], &["gaed"], &["gaed"], &["gaed"]];

pub(crate) static ENTRY_GELATINIZABILITIES_11843732787771445770: VariantsMap = [
    &["gelatinizabilities"],
    &["gelatinisabilities"],
    &["gelatinizabilities"],
    &["gelatinisabilities"],
];

pub(crate) static ENTRY_GELATINIZABILITY_5316896028355440686: VariantsMap = [
    &["gelatinizability"],
    &["gelatinisability"],
    &["gelatinizability"],
    &["gelatinisability"],
];

pub(crate) static ENTRY_GELATINIZABLES_16322119396476682092: VariantsMap = [
    &["gelatinizables"],
    &["gelatinisables"],
    &["gelatinizables"],
    &["gelatinisables"],
];

pub(crate) static ENTRY_GELATINIZABLE_11531656402349149191: VariantsMap = [
    &["gelatinizable"],
    &["gelatinisable"],
    &["gelatinizable"],
    &["gelatinisable"],
];

pub(crate) static ENTRY_GELATINIZATIONS_3461490016782968866: VariantsMap = [
    &["gelatinizations"],
    &["gelatinisations"],
    &["gelatinizations"],
    &["gelatinisations"],
];

pub(crate) static ENTRY_GELATINIZATION_10171589934060374244: VariantsMap = [
    &["gelatinization"],
    &["gelatinisation"],
    &["gelatinization"],
    &["gelatinisation"],
];

pub(crate) static ENTRY_GELATINIZED_3461761477823005775: VariantsMap = [
    &["gelatinized"],
    &["gelatinised"],
    &["gelatinized"],
    &["gelatinised"],
];

pub(crate) static ENTRY_GELATINIZERS_10767802126531471218: VariantsMap = [
    &["gelatinizers"],
    &["gelatinisers"],
    &["gelatinizers"],
    &["gelatinisers"],
];

pub(crate) static ENTRY_GELATINIZER_15651599974102221586: VariantsMap = [
    &["gelatinizer"],
    &["gelatiniser"],
    &["gelatinizer"],
    &["gelatiniser"],
];

pub(crate) static ENTRY_GELATINIZES_15322238107724094444: VariantsMap = [
    &["gelatinizes"],
    &["gelatinises"],
    &["gelatinizes"],
    &["gelatinises"],
];

pub(crate) static ENTRY_GELATINIZE_16970171286224203718: VariantsMap = [
    &["gelatinize"],
    &["gelatinise"],
    &["gelatinize"],
    &["gelatinise"],
];

pub(crate) static ENTRY_GELATINIZING_15953751603785988233: VariantsMap = [
    &["gelatinizing"],
    &["gelatinising"],
    &["gelatinizing"],
    &["gelatinising"],
];

pub(crate) static ENTRY_GELOFER_9829183028786462049: VariantsMap =
    [&["gelofer"], &["gelofre"], &["gelofre"], &["gelofre"]];

pub(crate) static ENTRY_GEMOLOGIES_10089052264640071050: VariantsMap = [
    &["gemologies"],
    &["gemmologies"],
    &["gemologies"],
    &["gemmologies"],
];

pub(crate) static ENTRY_GEMOLOGY_6361260868768825578: VariantsMap =
    [&["gemology"], &["gemmology"], &["gemology"], &["gemmology"]];

pub(crate) static ENTRY_GENEALOGIZED_12042020584202560965: VariantsMap = [
    &["genealogized"],
    &["genealogised"],
    &["genealogized"],
    &["genealogised"],
];

pub(crate) static ENTRY_GENEALOGIZES_17168583404877040399: VariantsMap = [
    &["genealogizes"],
    &["genealogises"],
    &["genealogizes"],
    &["genealogises"],
];

pub(crate) static ENTRY_GENEALOGIZE_12620268584199932329: VariantsMap = [
    &["genealogize"],
    &["genealogise"],
    &["genealogize"],
    &["genealogise"],
];

pub(crate) static ENTRY_GENEALOGIZING_5132448372195022070: VariantsMap = [
    &["genealogizing"],
    &["genealogising"],
    &["genealogizing"],
    &["genealogising"],
];

pub(crate) static ENTRY_GENERALIZABILITY_14379431587366972360: VariantsMap = [
    &["generalizability"],
    &["generalisability"],
    &["generalizability"],
    &["generalisability"],
];

pub(crate) static ENTRY_GENERALIZABLER_18102132003690783604: VariantsMap = [
    &["generalizabler"],
    &["generalisabler"],
    &["generalizabler"],
    &["generalisabler"],
];

pub(crate) static ENTRY_GENERALIZABLEST_11553065349222479768: VariantsMap = [
    &["generalizablest"],
    &["generalisablest"],
    &["generalizablest"],
    &["generalisablest"],
];

pub(crate) static ENTRY_GENERALIZABLES_154180711840966000: VariantsMap = [
    &["generalizables"],
    &["generalisables"],
    &["generalizables"],
    &["generalisables"],
];

pub(crate) static ENTRY_GENERALIZABLE_18295725543642075611: VariantsMap = [
    &["generalizable"],
    &["generalisable"],
    &["generalizable"],
    &["generalisable"],
];

pub(crate) static ENTRY_GENERALIZATIONAL_3161056560131790765: VariantsMap = [
    &["generalizational"],
    &["generalisational"],
    &["generalizational"],
    &["generalisational"],
];

pub(crate) static ENTRY_GENERALIZATIONS_2731364307838232099: VariantsMap = [
    &["generalizations"],
    &["generalisations"],
    &["generalizations"],
    &["generalisations"],
];

pub(crate) static ENTRY_GENERALIZATION_2013961301751158492: VariantsMap = [
    &["generalization"],
    &["generalisation"],
    &["generalization"],
    &["generalisation"],
];

pub(crate) static ENTRY_GENERALIZED_7165523126062259290: VariantsMap = [
    &["generalized"],
    &["generalised"],
    &["generalized"],
    &["generalised"],
];

pub(crate) static ENTRY_GENERALIZERS_16845345421553349857: VariantsMap = [
    &["generalizers"],
    &["generalisers"],
    &["generalizers"],
    &["generalisers"],
];

pub(crate) static ENTRY_GENERALIZER_10108415814272974359: VariantsMap = [
    &["generalizer"],
    &["generaliser"],
    &["generalizer"],
    &["generaliser"],
];

pub(crate) static ENTRY_GENERALIZES_4170424702375409863: VariantsMap = [
    &["generalizes"],
    &["generalises"],
    &["generalizes"],
    &["generalises"],
];

pub(crate) static ENTRY_GENERALIZE_7119013892575487093: VariantsMap = [
    &["generalize"],
    &["generalise"],
    &["generalize"],
    &["generalise"],
];

pub(crate) static ENTRY_GENERALIZING_1808553508228690165: VariantsMap = [
    &["generalizing"],
    &["generalising"],
    &["generalizing"],
    &["generalising"],
];

pub(crate) static ENTRY_GENIALIZED_1791020290394598690: VariantsMap = [
    &["genialized"],
    &["genialised"],
    &["genialized"],
    &["genialised"],
];

pub(crate) static ENTRY_GENIALIZES_1276462676939887760: VariantsMap = [
    &["genializes"],
    &["genialises"],
    &["genializes"],
    &["genialises"],
];

pub(crate) static ENTRY_GENIALIZE_11537483722321773336: VariantsMap = [
    &["genialize"],
    &["genialise"],
    &["genialize"],
    &["genialise"],
];

pub(crate) static ENTRY_GENIALIZING_2290635448853801652: VariantsMap = [
    &["genializing"],
    &["genialising"],
    &["genializing"],
    &["genialising"],
];

pub(crate) static ENTRY_GENTEELIZED_4414971612441032598: VariantsMap = [
    &["genteelized"],
    &["genteelised"],
    &["genteelized"],
    &["genteelised"],
];

pub(crate) static ENTRY_GENTEELIZES_17054840204815850898: VariantsMap = [
    &["genteelizes"],
    &["genteelises"],
    &["genteelizes"],
    &["genteelises"],
];

pub(crate) static ENTRY_GENTEELIZE_9903988894337114750: VariantsMap = [
    &["genteelize"],
    &["genteelise"],
    &["genteelize"],
    &["genteelise"],
];

pub(crate) static ENTRY_GENTEELIZING_6331688651248936908: VariantsMap = [
    &["genteelizing"],
    &["genteelising"],
    &["genteelizing"],
    &["genteelising"],
];

pub(crate) static ENTRY_GENTILIZATIONS_4535777487794529619: VariantsMap = [
    &["gentilizations"],
    &["gentilisations"],
    &["gentilizations"],
    &["gentilisations"],
];

pub(crate) static ENTRY_GENTILIZATION_2967799069574563693: VariantsMap = [
    &["gentilization"],
    &["gentilisation"],
    &["gentilization"],
    &["gentilisation"],
];

pub(crate) static ENTRY_GENTILIZED_15798295471925528719: VariantsMap = [
    &["gentilized"],
    &["gentilised"],
    &["gentilized"],
    &["gentilised"],
];

pub(crate) static ENTRY_GENTILIZES_10650533704141599278: VariantsMap = [
    &["gentilizes"],
    &["gentilises"],
    &["gentilizes"],
    &["gentilises"],
];

pub(crate) static ENTRY_GENTILIZE_2787391103676254332: VariantsMap = [
    &["gentilize"],
    &["gentilise"],
    &["gentilize"],
    &["gentilise"],
];

pub(crate) static ENTRY_GENTILIZING_4440287943707241933: VariantsMap = [
    &["gentilizing"],
    &["gentilising"],
    &["gentilizing"],
    &["gentilising"],
];

pub(crate) static ENTRY_GENTLEMANIZES_16940194571953457595: VariantsMap = [
    &["gentlemanizes"],
    &["gentlemanises"],
    &["gentlemanizes"],
    &["gentlemanises"],
];

pub(crate) static ENTRY_GENTLEMANIZE_14844186125575594131: VariantsMap = [
    &["gentlemanize"],
    &["gentlemanise"],
    &["gentlemanize"],
    &["gentlemanise"],
];

pub(crate) static ENTRY_GEODESIA_15004587233872373961: VariantsMap = [
    &["geodesia"],
    &["geodaesia"],
    &["geodaesia"],
    &["geodaesia"],
];

pub(crate) static ENTRY_GEOLOGIZED_14818288061091294770: VariantsMap = [
    &["geologized"],
    &["geologised"],
    &["geologized"],
    &["geologised"],
];

pub(crate) static ENTRY_GEOLOGIZES_8761505022080731433: VariantsMap = [
    &["geologizes"],
    &["geologises"],
    &["geologizes"],
    &["geologises"],
];

pub(crate) static ENTRY_GEOLOGIZE_11123257417328877516: VariantsMap = [
    &["geologize"],
    &["geologise"],
    &["geologize"],
    &["geologise"],
];

pub(crate) static ENTRY_GEOLOGIZING_9697520321475002890: VariantsMap = [
    &["geologizing"],
    &["geologising"],
    &["geologizing"],
    &["geologising"],
];

pub(crate) static ENTRY_GEOMETRICIZES_12860871121273916888: VariantsMap = [
    &["geometricizes"],
    &["geometricises"],
    &["geometricizes"],
    &["geometricises"],
];

pub(crate) static ENTRY_GEOMETRICIZE_6568047407572070557: VariantsMap = [
    &["geometricize"],
    &["geometricise"],
    &["geometricize"],
    &["geometricise"],
];

pub(crate) static ENTRY_GEOMETRIZATIONS_2014947061710926876: VariantsMap = [
    &["geometrizations"],
    &["geometrisations"],
    &["geometrizations"],
    &["geometrisations"],
];

pub(crate) static ENTRY_GEOMETRIZATION_6048827286641016156: VariantsMap = [
    &["geometrization"],
    &["geometrisation"],
    &["geometrization"],
    &["geometrisation"],
];

pub(crate) static ENTRY_GEOMETRIZED_9584717817506517773: VariantsMap = [
    &["geometrized"],
    &["geometrised"],
    &["geometrized"],
    &["geometrised"],
];

pub(crate) static ENTRY_GEOMETRIZES_3954498979112526923: VariantsMap = [
    &["geometrizes"],
    &["geometrises"],
    &["geometrizes"],
    &["geometrises"],
];

pub(crate) static ENTRY_GEOMETRIZE_17676461405396435621: VariantsMap = [
    &["geometrize"],
    &["geometrise"],
    &["geometrize"],
    &["geometrise"],
];

pub(crate) static ENTRY_GEOMETRIZING_13116207017987408289: VariantsMap = [
    &["geometrizing"],
    &["geometrising"],
    &["geometrizing"],
    &["geometrising"],
];

pub(crate) static ENTRY_GERENUK_5878790639893838830: VariantsMap =
    [&["gerenuk"], &["greenuk"], &["greenuk"], &["greenuk"]];

pub(crate) static ENTRY_GERMANIZATIONS_13849203249084570742: VariantsMap = [
    &["germanizations"],
    &["germanisations"],
    &["germanizations"],
    &["germanisations"],
];

pub(crate) static ENTRY_GERMANIZATION_2883408131349264299: VariantsMap = [
    &["germanization"],
    &["germanisation"],
    &["germanization"],
    &["germanisation"],
];

pub(crate) static ENTRY_GERMANIZED_319268402101247236: VariantsMap = [
    &["germanized"],
    &["germanised"],
    &["germanized"],
    &["germanised"],
];

pub(crate) static ENTRY_GERMANIZERS_2735174671441399165: VariantsMap = [
    &["germanizers"],
    &["germanisers"],
    &["germanizers"],
    &["germanisers"],
];

pub(crate) static ENTRY_GERMANIZER_6949268779695565000: VariantsMap = [
    &["germanizer"],
    &["germaniser"],
    &["germanizer"],
    &["germaniser"],
];

pub(crate) static ENTRY_GERMANIZES_13078334630601947229: VariantsMap = [
    &["germanizes"],
    &["germanises"],
    &["germanizes"],
    &["germanises"],
];

pub(crate) static ENTRY_GERMANIZE_8307775270233359640: VariantsMap = [
    &["germanize"],
    &["germanise"],
    &["germanize"],
    &["germanise"],
];

pub(crate) static ENTRY_GERMANIZING_17507553227341498972: VariantsMap = [
    &["germanizing"],
    &["germanising"],
    &["germanizing"],
    &["germanising"],
];

pub(crate) static ENTRY_GERNE_6398098570056353740: VariantsMap =
    [&["gerne"], &["grene"], &["grene"], &["grene"]];

pub(crate) static ENTRY_GERS_16671815364143402799: VariantsMap =
    [&["gers"], &["gres"], &["gres"], &["gres"]];

pub(crate) static ENTRY_GER_16895190685118522343: VariantsMap =
    [&["ger"], &["gre"], &["gre"], &["gre"]];

pub(crate) static ENTRY_GESSED_9634112193833828464: VariantsMap =
    [&["gessed"], &["gessoed"], &["gessoed"], &["gessoed"]];

pub(crate) static ENTRY_GESSES_2437319557909204547: VariantsMap =
    [&["gesses"], &["gessoes"], &["gessoes"], &["gessoes"]];

pub(crate) static ENTRY_GESTE_1005156404234659116: VariantsMap =
    [&["geste"], &["gestae"], &["gestae"], &["gestae"]];

pub(crate) static ENTRY_GES_12643481567446569340: VariantsMap =
    [&["ges"], &["goes"], &["goes"], &["goes"]];

pub(crate) static ENTRY_GETAE_3364151983605314101: VariantsMap =
    [&["getae"], &["goetae"], &["goetae"], &["goetae"]];

pub(crate) static ENTRY_GETZVILLE_9900952534801874442: VariantsMap = [
    &["getzville"],
    &["goetzville"],
    &["goetzville"],
    &["goetzville"],
];

pub(crate) static ENTRY_GETZ_6379956379813569580: VariantsMap =
    [&["getz"], &["goetz"], &["goetz"], &["goetz"]];

pub(crate) static ENTRY_GEY_14521748764899533154: VariantsMap =
    [&["gey"], &["goey"], &["goey"], &["goey"]];

pub(crate) static ENTRY_GE_1686355618410687291: VariantsMap =
    [&["ge"], &["gae"], &["gae"], &["gae"]];

pub(crate) static ENTRY_GE_1824382053019322407: VariantsMap =
    [&["ge"], &["goe"], &["goe"], &["goe"]];

pub(crate) static ENTRY_GHEBERS_1228305519613347380: VariantsMap =
    [&["ghebers"], &["ghebres"], &["ghebres"], &["ghebres"]];

pub(crate) static ENTRY_GHEBER_10923919185224261943: VariantsMap =
    [&["gheber"], &["ghebre"], &["ghebre"], &["ghebre"]];

pub(crate) static ENTRY_GHETTOIZATIONS_14465065685022919973: VariantsMap = [
    &["ghettoizations"],
    &["ghettoisations"],
    &["ghettoizations"],
    &["ghettoisations"],
];

pub(crate) static ENTRY_GHETTOIZATION_9347494697012841103: VariantsMap = [
    &["ghettoization"],
    &["ghettoisation"],
    &["ghettoization"],
    &["ghettoisation"],
];

pub(crate) static ENTRY_GHETTOIZED_15432712263833756702: VariantsMap = [
    &["ghettoized"],
    &["ghettoised"],
    &["ghettoized"],
    &["ghettoised"],
];

pub(crate) static ENTRY_GHETTOIZES_15179150910854310387: VariantsMap = [
    &["ghettoizes"],
    &["ghettoises"],
    &["ghettoizes"],
    &["ghettoises"],
];

pub(crate) static ENTRY_GHETTOIZE_3920432753121390069: VariantsMap = [
    &["ghettoize"],
    &["ghettoise"],
    &["ghettoize"],
    &["ghettoise"],
];

pub(crate) static ENTRY_GHETTOIZING_6347419295465163704: VariantsMap = [
    &["ghettoizing"],
    &["ghettoising"],
    &["ghettoizing"],
    &["ghettoising"],
];

pub(crate) static ENTRY_GIANTIZES_5379255686506063622: VariantsMap = [
    &["giantizes"],
    &["giantises"],
    &["giantizes"],
    &["giantises"],
];

pub(crate) static ENTRY_GIANTIZE_8830577708614030805: VariantsMap =
    [&["giantize"], &["giantise"], &["giantize"], &["giantise"]];

pub(crate) static ENTRY_GIGAGRAMS_13735334786282432453: VariantsMap = [
    &["gigagrams"],
    &["gigagrams"],
    &["gigagrams"],
    &["gigagrams"],
];

pub(crate) static ENTRY_GIGAGRAM_7417691256052791905: VariantsMap =
    [&["gigagram"], &["gigagram"], &["gigagram"], &["gigagram"]];

pub(crate) static ENTRY_GIGAMETERS_17403496110313778840: VariantsMap = [
    &["gigameters"],
    &["gigametres"],
    &["gigametres"],
    &["gigametres"],
];

pub(crate) static ENTRY_GIGAMETER_16808372513218698068: VariantsMap = [
    &["gigameter"],
    &["gigametre"],
    &["gigametre"],
    &["gigametre"],
];

pub(crate) static ENTRY_GIMBALED_16661584012551514273: VariantsMap = [
    &["gimbaled"],
    &["gimballed"],
    &["gimballed"],
    &["gimballed"],
];

pub(crate) static ENTRY_GIMBALING_2001739272630955218: VariantsMap = [
    &["gimbaling"],
    &["gimballing"],
    &["gimballing"],
    &["gimballing"],
];

pub(crate) static ENTRY_GLACIALIZES_15254428920934986178: VariantsMap = [
    &["glacializes"],
    &["glacialises"],
    &["glacializes"],
    &["glacialises"],
];

pub(crate) static ENTRY_GLACIALIZE_11661539622508415646: VariantsMap = [
    &["glacialize"],
    &["glacialise"],
    &["glacialize"],
    &["glacialise"],
];

pub(crate) static ENTRY_GLAMORIZATIONS_11025706385369300820: VariantsMap = [
    &["glamorizations"],
    &["glamorisations"],
    &["glamorizations"],
    &["glamorisations"],
];

pub(crate) static ENTRY_GLAMORIZATION_17390559971758126451: VariantsMap = [
    &["glamorization"],
    &["glamorisation"],
    &["glamorization"],
    &["glamorisation"],
];

pub(crate) static ENTRY_GLAMORIZED_14235641202752203193: VariantsMap = [
    &["glamorized"],
    &["glamorised"],
    &["glamorized"],
    &["glamorised"],
];

pub(crate) static ENTRY_GLAMORIZERS_8453946154216751074: VariantsMap = [
    &["glamorizers"],
    &["glamorisers"],
    &["glamorizers"],
    &["glamorisers"],
];

pub(crate) static ENTRY_GLAMORIZER_442849527990103618: VariantsMap = [
    &["glamorizer"],
    &["glamoriser"],
    &["glamorizer"],
    &["glamoriser"],
];

pub(crate) static ENTRY_GLAMORIZES_30562212031075527: VariantsMap = [
    &["glamorizes"],
    &["glamorises"],
    &["glamorizes"],
    &["glamorises"],
];

pub(crate) static ENTRY_GLAMORIZE_16872152441454086075: VariantsMap = [
    &["glamorize"],
    &["glamorise"],
    &["glamorize"],
    &["glamorise"],
];

pub(crate) static ENTRY_GLAMORIZING_2022801147073053480: VariantsMap = [
    &["glamorizing"],
    &["glamorising"],
    &["glamorizing"],
    &["glamorising"],
];

pub(crate) static ENTRY_GLAMORLESS_6110869941543847167: VariantsMap = [
    &["glamorless"],
    &["glamourless"],
    &["glamourless"],
    &["glamourless"],
];

pub(crate) static ENTRY_GLAMOROUSNESS_1477615640674820584: VariantsMap = [
    &["glamorousness"],
    &["glamorousness"],
    &["glamorousness"],
    &["glamorousness"],
];

pub(crate) static ENTRY_GLAMOROUS_16076170602432207668: VariantsMap = [
    &["glamorous"],
    &["glamorous"],
    &["glamorous"],
    &["glamorous"],
];

pub(crate) static ENTRY_GLAMOURED_12641645216907215470: VariantsMap = [
    &["glamoured"],
    &["glamoured"],
    &["glamoured"],
    &["glamoured"],
];

pub(crate) static ENTRY_GLAMOURING_8071112096581134588: VariantsMap = [
    &["glamouring"],
    &["glamouring"],
    &["glamouring"],
    &["glamouring"],
];

pub(crate) static ENTRY_GLAMOURS_5834129166696821991: VariantsMap =
    [&["glamours"], &["glamours"], &["glamours"], &["glamours"]];

pub(crate) static ENTRY_GLAMOUR_12012756924820660610: VariantsMap =
    [&["glamour"], &["glamour"], &["glamour"], &["glamour"]];

pub(crate) static ENTRY_GLAUCONITIZATIONS_1566737227533984902: VariantsMap = [
    &["glauconitizations"],
    &["glauconitisations"],
    &["glauconitizations"],
    &["glauconitisations"],
];

pub(crate) static ENTRY_GLAUCONITIZATION_17258720868513399337: VariantsMap = [
    &["glauconitization"],
    &["glauconitisation"],
    &["glauconitization"],
    &["glauconitisation"],
];

pub(crate) static ENTRY_GLEBE_5074401865696506801: VariantsMap =
    [&["glebe"], &["glebae"], &["glebae"], &["glebae"]];

pub(crate) static ENTRY_GLOBALIZATIONS_5052956206367697156: VariantsMap = [
    &["globalizations"],
    &["globalisations"],
    &["globalizations"],
    &["globalisations"],
];

pub(crate) static ENTRY_GLOBALIZATION_12699369965025909498: VariantsMap = [
    &["globalization"],
    &["globalisation"],
    &["globalization"],
    &["globalisation"],
];

pub(crate) static ENTRY_GLOBALIZED_6495417237922060299: VariantsMap = [
    &["globalized"],
    &["globalised"],
    &["globalized"],
    &["globalised"],
];

pub(crate) static ENTRY_GLOBALIZES_15478358400156150387: VariantsMap = [
    &["globalizes"],
    &["globalises"],
    &["globalizes"],
    &["globalises"],
];

pub(crate) static ENTRY_GLOBALIZE_3759893079231687276: VariantsMap = [
    &["globalize"],
    &["globalise"],
    &["globalize"],
    &["globalise"],
];

pub(crate) static ENTRY_GLOBALIZING_3545733493688582389: VariantsMap = [
    &["globalizing"],
    &["globalising"],
    &["globalizing"],
    &["globalising"],
];

pub(crate) static ENTRY_GLOBIGERINE_2405734374814364255: VariantsMap = [
    &["globigerine"],
    &["globigerinae"],
    &["globigerinae"],
    &["globigerinae"],
];

pub(crate) static ENTRY_GLOTTALIZATION_11392971986615366214: VariantsMap = [
    &["glottalization"],
    &["glottalisation"],
    &["glottalization"],
    &["glottalisation"],
];

pub(crate) static ENTRY_GLOTTALIZES_524293217691696666: VariantsMap = [
    &["glottalizes"],
    &["glottalises"],
    &["glottalizes"],
    &["glottalises"],
];

pub(crate) static ENTRY_GLOTTALIZE_17907399977543814184: VariantsMap = [
    &["glottalize"],
    &["glottalise"],
    &["glottalize"],
    &["glottalise"],
];

pub(crate) static ENTRY_GLUCEMIA_2529316768824479585: VariantsMap = [
    &["glucemia"],
    &["glucaemia"],
    &["glucaemia"],
    &["glucaemia"],
];

pub(crate) static ENTRY_GLUCOSEMIA_115924351177583586: VariantsMap = [
    &["glucosemia"],
    &["glucosaemia"],
    &["glucosaemia"],
    &["glucosaemia"],
];

pub(crate) static ENTRY_GLUTEAL_7146771961772255008: VariantsMap =
    [&["gluteal"], &["gluteal"], &["gluteal"], &["gluteal"]];

pub(crate) static ENTRY_GLUTEI_7369598864146530008: VariantsMap =
    [&["glutei"], &["glutaei"], &["glutaei"], &["glutaei"]];

pub(crate) static ENTRY_GLUTEUS_17400782784216365634: VariantsMap =
    [&["gluteus"], &["glutaeus"], &["glutaeus"], &["glutaeus"]];

pub(crate) static ENTRY_GLUTTONIZED_9137718586964556019: VariantsMap = [
    &["gluttonized"],
    &["gluttonised"],
    &["gluttonized"],
    &["gluttonised"],
];

pub(crate) static ENTRY_GLUTTONIZES_14463796411495767760: VariantsMap = [
    &["gluttonizes"],
    &["gluttonises"],
    &["gluttonizes"],
    &["gluttonises"],
];

pub(crate) static ENTRY_GLUTTONIZE_1551255015733249461: VariantsMap = [
    &["gluttonize"],
    &["gluttonise"],
    &["gluttonize"],
    &["gluttonise"],
];

pub(crate) static ENTRY_GLUTTONIZING_13071722447885495721: VariantsMap = [
    &["gluttonizing"],
    &["gluttonising"],
    &["gluttonizing"],
    &["gluttonising"],
];

pub(crate) static ENTRY_GLYCEMIA_16242341716012342356: VariantsMap = [
    &["glycemia"],
    &["glycaemia"],
    &["glycaemia"],
    &["glycaemia"],
];

pub(crate) static ENTRY_GLYCEMIC_13665133085585909129: VariantsMap = [
    &["glycemic"],
    &["glycaemic"],
    &["glycaemic"],
    &["glycaemic"],
];

pub(crate) static ENTRY_GLYCERINIZES_952982692568880676: VariantsMap = [
    &["glycerinizes"],
    &["glycerinises"],
    &["glycerinizes"],
    &["glycerinises"],
];

pub(crate) static ENTRY_GLYCERINIZE_2782882431705716101: VariantsMap = [
    &["glycerinize"],
    &["glycerinise"],
    &["glycerinize"],
    &["glycerinise"],
];

pub(crate) static ENTRY_GLYCERINS_10842297970680678300: VariantsMap = [
    &["glycerins"],
    &["glycerines"],
    &["glycerines"],
    &["glycerines"],
];

pub(crate) static ENTRY_GLYCERIN_6083208262382782239: VariantsMap = [
    &["glycerin"],
    &["glycerine"],
    &["glycerine"],
    &["glycerine"],
];

pub(crate) static ENTRY_GLYCEROLIZED_800457376227447393: VariantsMap = [
    &["glycerolized"],
    &["glycerolised"],
    &["glycerolized"],
    &["glycerolised"],
];

pub(crate) static ENTRY_GLYCEROLIZES_3740315663712429181: VariantsMap = [
    &["glycerolizes"],
    &["glycerolises"],
    &["glycerolizes"],
    &["glycerolises"],
];

pub(crate) static ENTRY_GLYCEROLIZE_14536989508087415076: VariantsMap = [
    &["glycerolize"],
    &["glycerolise"],
    &["glycerolize"],
    &["glycerolise"],
];

pub(crate) static ENTRY_GLYCOGENIZES_9362481468651756393: VariantsMap = [
    &["glycogenizes"],
    &["glycogenises"],
    &["glycogenizes"],
    &["glycogenises"],
];

pub(crate) static ENTRY_GLYCOGENIZE_15974845978276880617: VariantsMap = [
    &["glycogenize"],
    &["glycogenise"],
    &["glycogenize"],
    &["glycogenise"],
];

pub(crate) static ENTRY_GLYCOHEMIA_15342224868378622029: VariantsMap = [
    &["glycohemia"],
    &["glycohaemia"],
    &["glycohaemia"],
    &["glycohaemia"],
];

pub(crate) static ENTRY_GLYCOSEMIA_17576889605547296607: VariantsMap = [
    &["glycosemia"],
    &["glycosaemia"],
    &["glycosaemia"],
    &["glycosaemia"],
];

pub(crate) static ENTRY_GNOSTICIZED_2833607619405753217: VariantsMap = [
    &["gnosticized"],
    &["gnosticised"],
    &["gnosticized"],
    &["gnosticised"],
];

pub(crate) static ENTRY_GNOSTICIZERS_6416088953515594469: VariantsMap = [
    &["gnosticizers"],
    &["gnosticisers"],
    &["gnosticizers"],
    &["gnosticisers"],
];

pub(crate) static ENTRY_GNOSTICIZER_13549736729171636644: VariantsMap = [
    &["gnosticizer"],
    &["gnosticiser"],
    &["gnosticizer"],
    &["gnosticiser"],
];

pub(crate) static ENTRY_GNOSTICIZES_18176506546501435848: VariantsMap = [
    &["gnosticizes"],
    &["gnosticises"],
    &["gnosticizes"],
    &["gnosticises"],
];

pub(crate) static ENTRY_GNOSTICIZE_8298366457877404969: VariantsMap = [
    &["gnosticize"],
    &["gnosticise"],
    &["gnosticize"],
    &["gnosticise"],
];

pub(crate) static ENTRY_GNOSTICIZING_17078143553180201273: VariantsMap = [
    &["gnosticizing"],
    &["gnosticising"],
    &["gnosticizing"],
    &["gnosticising"],
];

pub(crate) static ENTRY_GODDIZES_10711930831789780733: VariantsMap =
    [&["goddizes"], &["goddises"], &["goddizes"], &["goddises"]];

pub(crate) static ENTRY_GODDIZE_12638634784459187474: VariantsMap =
    [&["goddize"], &["goddise"], &["goddize"], &["goddise"]];

pub(crate) static ENTRY_GOITERS_5380033633196816136: VariantsMap =
    [&["goiters"], &["goitres"], &["goitres"], &["goitres"]];

pub(crate) static ENTRY_GOITER_14429026844787476944: VariantsMap =
    [&["goiter"], &["goitre"], &["goitre"], &["goitre"]];

pub(crate) static ENTRY_GOLE_5489584880290326329: VariantsMap =
    [&["gole"], &["goloe"], &["goloe"], &["goloe"]];

pub(crate) static ENTRY_GOLIATHIZED_7371615732561488733: VariantsMap = [
    &["goliathized"],
    &["goliathised"],
    &["goliathized"],
    &["goliathised"],
];

pub(crate) static ENTRY_GOLIATHIZES_10251762427882918658: VariantsMap = [
    &["goliathizes"],
    &["goliathises"],
    &["goliathizes"],
    &["goliathises"],
];

pub(crate) static ENTRY_GOLIATHIZE_3207199351366822344: VariantsMap = [
    &["goliathize"],
    &["goliathise"],
    &["goliathize"],
    &["goliathise"],
];

pub(crate) static ENTRY_GOLIATHIZING_3247167634988452816: VariantsMap = [
    &["goliathizing"],
    &["goliathising"],
    &["goliathizing"],
    &["goliathising"],
];

pub(crate) static ENTRY_GOLOSHES_6685403831800870010: VariantsMap = [
    &["goloshes"],
    &["goloshoes"],
    &["goloshoes"],
    &["goloshoes"],
];

pub(crate) static ENTRY_GONORRHEALER_6558496656666898706: VariantsMap = [
    &["gonorrhealer"],
    &["gonorrhoealer"],
    &["gonorrhealer"],
    &["gonorrhoealer"],
];

pub(crate) static ENTRY_GONORRHEALEST_7101359392395224585: VariantsMap = [
    &["gonorrhealest"],
    &["gonorrhoealest"],
    &["gonorrhealest"],
    &["gonorrhoealest"],
];

pub(crate) static ENTRY_GONORRHEAL_1953933058900099744: VariantsMap = [
    &["gonorrheal"],
    &["gonorrhoeal"],
    &["gonorrheal"],
    &["gonorrhoeal"],
];

pub(crate) static ENTRY_GONORRHEAS_3200457042710401964: VariantsMap = [
    &["gonorrheas"],
    &["gonorrhoeas"],
    &["gonorrheas"],
    &["gonorrhoeas"],
];

pub(crate) static ENTRY_GONORRHEA_14553002728173647424: VariantsMap = [
    &["gonorrhea"],
    &["gonorrhoea"],
    &["gonorrhea"],
    &["gonorrhoea"],
];

pub(crate) static ENTRY_GONORRHEIC_11150089290859461093: VariantsMap = [
    &["gonorrheic"],
    &["gonorrhoeic"],
    &["gonorrheic"],
    &["gonorrhoeic"],
];

pub(crate) static ENTRY_GOODBYES_4328442898272974601: VariantsMap =
    [&["goodbyes"], &["goodbyes"], &["goodbyes"], &["goodbyes"]];

pub(crate) static ENTRY_GOODBYE_955015322523257602: VariantsMap =
    [&["goodbye"], &["goodbye"], &["goodbye"], &["goodbye"]];

pub(crate) static ENTRY_GORAMIES_10337124831051177070: VariantsMap = [
    &["goramies"],
    &["gouramies"],
    &["gouramies"],
    &["gouramies"],
];

pub(crate) static ENTRY_GORA_11814218514390079181: VariantsMap =
    [&["gora"], &["goura"], &["goura"], &["goura"]];

pub(crate) static ENTRY_GORGONIZED_17578232270564441154: VariantsMap = [
    &["gorgonized"],
    &["gorgonised"],
    &["gorgonized"],
    &["gorgonised"],
];

pub(crate) static ENTRY_GORGONIZES_5235778045234676926: VariantsMap = [
    &["gorgonizes"],
    &["gorgonises"],
    &["gorgonizes"],
    &["gorgonises"],
];

pub(crate) static ENTRY_GORGONIZE_7339952104907739670: VariantsMap = [
    &["gorgonize"],
    &["gorgonise"],
    &["gorgonize"],
    &["gorgonise"],
];

pub(crate) static ENTRY_GORGONIZING_11753481170900914529: VariantsMap = [
    &["gorgonizing"],
    &["gorgonising"],
    &["gorgonizing"],
    &["gorgonising"],
];

pub(crate) static ENTRY_GORMANDISMS_2350716439672562789: VariantsMap = [
    &["gormandisms"],
    &["gourmandisms"],
    &["gourmandisms"],
    &["gourmandisms"],
];

pub(crate) static ENTRY_GORMANDISM_8691357582554313830: VariantsMap = [
    &["gormandism"],
    &["gourmandism"],
    &["gourmandism"],
    &["gourmandism"],
];

pub(crate) static ENTRY_GORMANDIZED_18123314320901330563: VariantsMap = [
    &["gormandized"],
    &["gormandised"],
    &["gormandized"],
    &["gormandised"],
];

pub(crate) static ENTRY_GORMANDIZERS_9718907960263867951: VariantsMap = [
    &["gormandizers"],
    &["gormandisers"],
    &["gormandizers"],
    &["gormandisers"],
];

pub(crate) static ENTRY_GORMANDIZER_7967324301588641636: VariantsMap = [
    &["gormandizer"],
    &["gormandiser"],
    &["gormandizer"],
    &["gormandiser"],
];

pub(crate) static ENTRY_GORMANDIZES_2367633408225245450: VariantsMap = [
    &["gormandizes"],
    &["gormandises"],
    &["gormandizes"],
    &["gormandises"],
];

pub(crate) static ENTRY_GORMANDIZE_4048474911133469516: VariantsMap = [
    &["gormandize"],
    &["gormandise"],
    &["gormandize"],
    &["gormandise"],
];

pub(crate) static ENTRY_GORMANDIZINGS_10351566511774807493: VariantsMap = [
    &["gormandizings"],
    &["gormandisings"],
    &["gormandizings"],
    &["gormandisings"],
];

pub(crate) static ENTRY_GORMANDIZING_3190158527790286976: VariantsMap = [
    &["gormandizing"],
    &["gormandising"],
    &["gormandizing"],
    &["gormandising"],
];

pub(crate) static ENTRY_GOR_10234665398861859619: VariantsMap =
    [&["gor"], &["gour"], &["gour"], &["gour"]];

pub(crate) static ENTRY_GOSPELERS_5510274928883452290: VariantsMap = [
    &["gospelers"],
    &["gospellers"],
    &["gospellers"],
    &["gospellers"],
];

pub(crate) static ENTRY_GOSPELER_16178320832840793633: VariantsMap = [
    &["gospeler"],
    &["gospeller"],
    &["gospeller"],
    &["gospeller"],
];

pub(crate) static ENTRY_GOSPELIZED_6118230251869259140: VariantsMap = [
    &["gospelized"],
    &["gospelised"],
    &["gospelized"],
    &["gospelised"],
];

pub(crate) static ENTRY_GOSPELIZES_8351431571866342962: VariantsMap = [
    &["gospelizes"],
    &["gospelises"],
    &["gospelizes"],
    &["gospelises"],
];

pub(crate) static ENTRY_GOSPELIZE_8463793062364479872: VariantsMap = [
    &["gospelize"],
    &["gospelise"],
    &["gospelize"],
    &["gospelise"],
];

pub(crate) static ENTRY_GOSPELIZING_1522616819248499417: VariantsMap = [
    &["gospelizing"],
    &["gospelising"],
    &["gospelizing"],
    &["gospelising"],
];

pub(crate) static ENTRY_GOSPELLIZED_11952462176156283256: VariantsMap = [
    &["gospellized"],
    &["gospellised"],
    &["gospellized"],
    &["gospellised"],
];

pub(crate) static ENTRY_GOSPELLIZES_1146933159825487782: VariantsMap = [
    &["gospellizes"],
    &["gospellises"],
    &["gospellizes"],
    &["gospellises"],
];

pub(crate) static ENTRY_GOSPELLIZE_7948270018046384376: VariantsMap = [
    &["gospellize"],
    &["gospellise"],
    &["gospellize"],
    &["gospellise"],
];

pub(crate) static ENTRY_GOSPELLIZING_9061660358257705871: VariantsMap = [
    &["gospellizing"],
    &["gospellising"],
    &["gospellizing"],
    &["gospellising"],
];

pub(crate) static ENTRY_GOTHICIZED_11880161405473571941: VariantsMap = [
    &["gothicized"],
    &["gothicised"],
    &["gothicized"],
    &["gothicised"],
];

pub(crate) static ENTRY_GOTHICIZERS_6983380456533659804: VariantsMap = [
    &["gothicizers"],
    &["gothicisers"],
    &["gothicizers"],
    &["gothicisers"],
];

pub(crate) static ENTRY_GOTHICIZER_2689071523633726352: VariantsMap = [
    &["gothicizer"],
    &["gothiciser"],
    &["gothicizer"],
    &["gothiciser"],
];

pub(crate) static ENTRY_GOTHICIZES_6292706177931544569: VariantsMap = [
    &["gothicizes"],
    &["gothicises"],
    &["gothicizes"],
    &["gothicises"],
];

pub(crate) static ENTRY_GOTHICIZE_14957672080392530959: VariantsMap = [
    &["gothicize"],
    &["gothicise"],
    &["gothicize"],
    &["gothicise"],
];

pub(crate) static ENTRY_GOTHICIZING_13822856579122185612: VariantsMap = [
    &["gothicizing"],
    &["gothicising"],
    &["gothicizing"],
    &["gothicising"],
];

pub(crate) static ENTRY_GOURMANDIZED_9573100300470535877: VariantsMap = [
    &["gourmandized"],
    &["gourmandised"],
    &["gourmandized"],
    &["gourmandised"],
];

pub(crate) static ENTRY_GOURMANDIZES_3953018647595098599: VariantsMap = [
    &["gourmandizes"],
    &["gourmandises"],
    &["gourmandizes"],
    &["gourmandises"],
];

pub(crate) static ENTRY_GOURMANDIZE_7543527779362954128: VariantsMap = [
    &["gourmandize"],
    &["gourmandise"],
    &["gourmandize"],
    &["gourmandise"],
];

pub(crate) static ENTRY_GOURMANDIZING_13613830637929717449: VariantsMap = [
    &["gourmandizing"],
    &["gourmandising"],
    &["gourmandizing"],
    &["gourmandising"],
];

pub(crate) static ENTRY_GOVERNMENTALIZED_535639565110473785: VariantsMap = [
    &["governmentalized"],
    &["governmentalised"],
    &["governmentalized"],
    &["governmentalised"],
];

pub(crate) static ENTRY_GOVERNMENTALIZES_7078858643697476593: VariantsMap = [
    &["governmentalizes"],
    &["governmentalises"],
    &["governmentalizes"],
    &["governmentalises"],
];

pub(crate) static ENTRY_GOVERNMENTALIZE_12139326096501644734: VariantsMap = [
    &["governmentalize"],
    &["governmentalise"],
    &["governmentalize"],
    &["governmentalise"],
];

pub(crate) static ENTRY_GOVERNMENTALIZING_6416864298050708496: VariantsMap = [
    &["governmentalizing"],
    &["governmentalising"],
    &["governmentalizing"],
    &["governmentalising"],
];

pub(crate) static ENTRY_GOYESQUE_9513998646544349741: VariantsMap = [
    &["goyesque"],
    &["goyaesque"],
    &["goyaesque"],
    &["goyaesque"],
];

pub(crate) static ENTRY_GRAECIZED_12313346476953283931: VariantsMap = [
    &["graecized"],
    &["graecised"],
    &["graecized"],
    &["graecised"],
];

pub(crate) static ENTRY_GRAECIZES_3310961711255910918: VariantsMap = [
    &["graecizes"],
    &["graecises"],
    &["graecizes"],
    &["graecises"],
];

pub(crate) static ENTRY_GRAECIZE_926966918917595487: VariantsMap =
    [&["graecize"], &["graecise"], &["graecize"], &["graecise"]];

pub(crate) static ENTRY_GRAECIZING_3548832957287094505: VariantsMap = [
    &["graecizing"],
    &["graecising"],
    &["graecizing"],
    &["graecising"],
];

pub(crate) static ENTRY_GRAMMATICIZED_1825495211699211254: VariantsMap = [
    &["grammaticized"],
    &["grammaticised"],
    &["grammaticized"],
    &["grammaticised"],
];

pub(crate) static ENTRY_GRAMMATICIZES_14936594258820535817: VariantsMap = [
    &["grammaticizes"],
    &["grammaticises"],
    &["grammaticizes"],
    &["grammaticises"],
];

pub(crate) static ENTRY_GRAMMATICIZE_13927750396162050191: VariantsMap = [
    &["grammaticize"],
    &["grammaticise"],
    &["grammaticize"],
    &["grammaticise"],
];

pub(crate) static ENTRY_GRAMMATICIZING_692121205682654749: VariantsMap = [
    &["grammaticizing"],
    &["grammaticising"],
    &["grammaticizing"],
    &["grammaticising"],
];

pub(crate) static ENTRY_GRAMS_7239637483562572698: VariantsMap =
    [&["grams"], &["grams"], &["grams"], &["grams"]];

pub(crate) static ENTRY_GRAM_12153808189248219413: VariantsMap =
    [&["gram"], &["gram"], &["gram"], &["gram"]];

pub(crate) static ENTRY_GRANGERIZATIONS_964259139336744472: VariantsMap = [
    &["grangerizations"],
    &["grangerisations"],
    &["grangerizations"],
    &["grangerisations"],
];

pub(crate) static ENTRY_GRANGERIZATION_9648135893564549333: VariantsMap = [
    &["grangerization"],
    &["grangerisation"],
    &["grangerization"],
    &["grangerisation"],
];

pub(crate) static ENTRY_GRANGERIZED_17258742687972795253: VariantsMap = [
    &["grangerized"],
    &["grangerised"],
    &["grangerized"],
    &["grangerised"],
];

pub(crate) static ENTRY_GRANGERIZERS_8651613919277864726: VariantsMap = [
    &["grangerizers"],
    &["grangerisers"],
    &["grangerizers"],
    &["grangerisers"],
];

pub(crate) static ENTRY_GRANGERIZER_5049165606212077831: VariantsMap = [
    &["grangerizer"],
    &["grangeriser"],
    &["grangerizer"],
    &["grangeriser"],
];

pub(crate) static ENTRY_GRANGERIZES_10405739052106575692: VariantsMap = [
    &["grangerizes"],
    &["grangerises"],
    &["grangerizes"],
    &["grangerises"],
];

pub(crate) static ENTRY_GRANGERIZE_11480909331809274858: VariantsMap = [
    &["grangerize"],
    &["grangerise"],
    &["grangerize"],
    &["grangerise"],
];

pub(crate) static ENTRY_GRANGERIZING_14698907453901269575: VariantsMap = [
    &["grangerizing"],
    &["grangerising"],
    &["grangerizing"],
    &["grangerising"],
];

pub(crate) static ENTRY_GRANITIZATIONS_7558118776122917287: VariantsMap = [
    &["granitizations"],
    &["granitisations"],
    &["granitizations"],
    &["granitisations"],
];

pub(crate) static ENTRY_GRANITIZATION_1851229670882829451: VariantsMap = [
    &["granitization"],
    &["granitisation"],
    &["granitization"],
    &["granitisation"],
];

pub(crate) static ENTRY_GRANITIZED_1449233752463750138: VariantsMap = [
    &["granitized"],
    &["granitised"],
    &["granitized"],
    &["granitised"],
];

pub(crate) static ENTRY_GRANITIZES_5080962380592360311: VariantsMap = [
    &["granitizes"],
    &["granitises"],
    &["granitizes"],
    &["granitises"],
];

pub(crate) static ENTRY_GRANITIZE_18215727739855140563: VariantsMap = [
    &["granitize"],
    &["granitise"],
    &["granitize"],
    &["granitise"],
];

pub(crate) static ENTRY_GRANITIZING_9024106896826166145: VariantsMap = [
    &["granitizing"],
    &["granitising"],
    &["granitizing"],
    &["granitising"],
];

pub(crate) static ENTRY_GRANULITIZATIONS_12012456772504363468: VariantsMap = [
    &["granulitizations"],
    &["granulitisations"],
    &["granulitizations"],
    &["granulitisations"],
];

pub(crate) static ENTRY_GRANULITIZATION_15290542958063369460: VariantsMap = [
    &["granulitization"],
    &["granulitisation"],
    &["granulitization"],
    &["granulitisation"],
];

pub(crate) static ENTRY_GRANULIZES_15431459479870139428: VariantsMap = [
    &["granulizes"],
    &["granulises"],
    &["granulizes"],
    &["granulises"],
];

pub(crate) static ENTRY_GRANULIZE_7605163095922224765: VariantsMap = [
    &["granulize"],
    &["granulise"],
    &["granulize"],
    &["granulise"],
];

pub(crate) static ENTRY_GRAPHITIZABLE_4023736760922492467: VariantsMap = [
    &["graphitizable"],
    &["graphitisable"],
    &["graphitizable"],
    &["graphitisable"],
];

pub(crate) static ENTRY_GRAPHITIZATIONS_11033090213797442310: VariantsMap = [
    &["graphitizations"],
    &["graphitisations"],
    &["graphitizations"],
    &["graphitisations"],
];

pub(crate) static ENTRY_GRAPHITIZATION_2583924609541307295: VariantsMap = [
    &["graphitization"],
    &["graphitisation"],
    &["graphitization"],
    &["graphitisation"],
];

pub(crate) static ENTRY_GRAPHITIZED_6227783366697728706: VariantsMap = [
    &["graphitized"],
    &["graphitised"],
    &["graphitized"],
    &["graphitised"],
];

pub(crate) static ENTRY_GRAPHITIZES_4200881641591371190: VariantsMap = [
    &["graphitizes"],
    &["graphitises"],
    &["graphitizes"],
    &["graphitises"],
];

pub(crate) static ENTRY_GRAPHITIZE_820728043344395996: VariantsMap = [
    &["graphitize"],
    &["graphitise"],
    &["graphitize"],
    &["graphitise"],
];

pub(crate) static ENTRY_GRAPHITIZING_8705628871531345361: VariantsMap = [
    &["graphitizing"],
    &["graphitising"],
    &["graphitizing"],
    &["graphitising"],
];

pub(crate) static ENTRY_GRAVELED_2807681232939008308: VariantsMap = [
    &["graveled"],
    &["gravelled"],
    &["gravelled"],
    &["gravelled"],
];

pub(crate) static ENTRY_GRAVELING_10440686553850601055: VariantsMap = [
    &["graveling"],
    &["gravelling"],
    &["gravelling"],
    &["gravelling"],
];

pub(crate) static ENTRY_GRAYED_2126221854892912128: VariantsMap =
    [&["grayed"], &["greyed"], &["greyed"], &["greyed"]];

pub(crate) static ENTRY_GRAYER_16353903293922225810: VariantsMap =
    [&["grayer"], &["greyer"], &["greyer"], &["greyer"]];

pub(crate) static ENTRY_GRAYEST_9398546240809766238: VariantsMap =
    [&["grayest"], &["greyest"], &["greyest"], &["greyest"]];

pub(crate) static ENTRY_GRAYING_17334366481873759110: VariantsMap =
    [&["graying"], &["greying"], &["greying"], &["greying"]];

pub(crate) static ENTRY_GRAYISH_1156907900107349696: VariantsMap =
    [&["grayish"], &["greyish"], &["greyish"], &["greyish"]];

pub(crate) static ENTRY_GRAYNESS_14336126497721340945: VariantsMap =
    [&["grayness"], &["greyness"], &["greyness"], &["greyness"]];

pub(crate) static ENTRY_GRECIANIZES_11174673507196729238: VariantsMap = [
    &["grecianizes"],
    &["grecianises"],
    &["grecianizes"],
    &["grecianises"],
];

pub(crate) static ENTRY_GRECIANIZE_12105732338554948425: VariantsMap = [
    &["grecianize"],
    &["grecianise"],
    &["grecianize"],
    &["grecianise"],
];

pub(crate) static ENTRY_GRECIAN_14860038034904089388: VariantsMap =
    [&["grecian"], &["graecian"], &["graecian"], &["graecian"]];

pub(crate) static ENTRY_GRECISED_8365655558591252453: VariantsMap = [
    &["grecised"],
    &["graecised"],
    &["graecised"],
    &["graecised"],
];

pub(crate) static ENTRY_GRECISE_2532359423804381452: VariantsMap =
    [&["grecise"], &["graecise"], &["graecise"], &["graecise"]];

pub(crate) static ENTRY_GRECISING_10216329489666935575: VariantsMap = [
    &["grecising"],
    &["graecising"],
    &["graecising"],
    &["graecising"],
];

pub(crate) static ENTRY_GRECISMS_14469374135032380871: VariantsMap = [
    &["grecisms"],
    &["graecisms"],
    &["graecisms"],
    &["graecisms"],
];

pub(crate) static ENTRY_GRECISM_11998927259268433496: VariantsMap =
    [&["grecism"], &["graecism"], &["graecism"], &["graecism"]];

pub(crate) static ENTRY_GRECIZED_11474072803323083598: VariantsMap =
    [&["grecized"], &["grecised"], &["grecized"], &["grecised"]];

pub(crate) static ENTRY_GRECIZED_5137584389270183448: VariantsMap =
    [&["grecized"], &["grecised"], &["grecized"], &["grecised"]];

pub(crate) static ENTRY_GRECIZES_1632490107158427095: VariantsMap =
    [&["grecizes"], &["grecises"], &["grecizes"], &["grecises"]];

pub(crate) static ENTRY_GRECIZE_1961618991901266428: VariantsMap =
    [&["grecize"], &["grecise"], &["grecize"], &["grecise"]];

pub(crate) static ENTRY_GRECIZE_8007863070307700465: VariantsMap =
    [&["grecize"], &["grecise"], &["grecize"], &["grecise"]];

pub(crate) static ENTRY_GRECIZING_1729797461872700220: VariantsMap = [
    &["grecizing"],
    &["grecising"],
    &["grecizing"],
    &["grecising"],
];

pub(crate) static ENTRY_GRECIZING_8731072674304692212: VariantsMap = [
    &["grecizing"],
    &["grecising"],
    &["grecizing"],
    &["grecising"],
];

pub(crate) static ENTRY_GREEKIZES_6949350197314496533: VariantsMap = [
    &["greekizes"],
    &["greekises"],
    &["greekizes"],
    &["greekises"],
];

pub(crate) static ENTRY_GREEKIZE_15689792812774790072: VariantsMap =
    [&["greekize"], &["greekise"], &["greekize"], &["greekise"]];

pub(crate) static ENTRY_GREISENIZATIONS_6238511961327542361: VariantsMap = [
    &["greisenizations"],
    &["greisenisations"],
    &["greisenizations"],
    &["greisenisations"],
];

pub(crate) static ENTRY_GREISENIZATION_13825850823267727625: VariantsMap = [
    &["greisenization"],
    &["greisenisation"],
    &["greisenization"],
    &["greisenisation"],
];

pub(crate) static ENTRY_GREISENIZED_17732441181252344688: VariantsMap = [
    &["greisenized"],
    &["greisenised"],
    &["greisenized"],
    &["greisenised"],
];

pub(crate) static ENTRY_GREISENIZES_13261726167693334943: VariantsMap = [
    &["greisenizes"],
    &["greisenises"],
    &["greisenizes"],
    &["greisenises"],
];

pub(crate) static ENTRY_GREISENIZE_16424858506500854091: VariantsMap = [
    &["greisenize"],
    &["greisenise"],
    &["greisenize"],
    &["greisenise"],
];

pub(crate) static ENTRY_GREISENIZING_10722346677413921325: VariantsMap = [
    &["greisenizing"],
    &["greisenising"],
    &["greisenizing"],
    &["greisenising"],
];

pub(crate) static ENTRY_GRIZARD_17782998727447276529: VariantsMap =
    [&["grizard"], &["grisard"], &["grizard"], &["grisard"]];

pub(crate) static ENTRY_GRIZES_14846823474697979680: VariantsMap =
    [&["grizes"], &["grises"], &["grizes"], &["grises"]];

pub(crate) static ENTRY_GRIZE_16222725373368809072: VariantsMap =
    [&["grize"], &["grise"], &["grize"], &["grise"]];

pub(crate) static ENTRY_GROINED_2809452461899594102: VariantsMap =
    [&["groined"], &["groyned"], &["groyned"], &["groyned"]];

pub(crate) static ENTRY_GROINING_7538300092747501321: VariantsMap =
    [&["groining"], &["groyning"], &["groyning"], &["groyning"]];

pub(crate) static ENTRY_GROINS_7022214519428560367: VariantsMap =
    [&["groins"], &["groynes"], &["groynes"], &["groynes"]];

pub(crate) static ENTRY_GROIN_5340788760231681661: VariantsMap =
    [&["groin"], &["groyne"], &["groyne"], &["groyne"]];

pub(crate) static ENTRY_GROVELED_11655386549337225742: VariantsMap = [
    &["groveled"],
    &["grovelled"],
    &["grovelled"],
    &["grovelled"],
];

pub(crate) static ENTRY_GROVELERS_1063263311160407851: VariantsMap = [
    &["grovelers"],
    &["grovellers"],
    &["grovellers"],
    &["grovellers"],
];

pub(crate) static ENTRY_GROVELER_17000057584571165802: VariantsMap = [
    &["groveler"],
    &["groveller"],
    &["groveller"],
    &["groveller"],
];

pub(crate) static ENTRY_GROVELINGLIER_1214630554400703346: VariantsMap = [
    &["grovelinglier"],
    &["grovellinglier"],
    &["grovellinglier"],
    &["grovellinglier"],
];

pub(crate) static ENTRY_GROVELINGLIEST_11811119470500539386: VariantsMap = [
    &["grovelingliest"],
    &["grovellingliest"],
    &["grovellingliest"],
    &["grovellingliest"],
];

pub(crate) static ENTRY_GROVELINGLY_8701513157425366439: VariantsMap = [
    &["grovelingly"],
    &["grovellingly"],
    &["grovellingly"],
    &["grovellingly"],
];

pub(crate) static ENTRY_GROVELING_12072037399255827644: VariantsMap = [
    &["groveling"],
    &["grovelling"],
    &["grovelling"],
    &["grovelling"],
];

pub(crate) static ENTRY_GRUELED_11469179107855937094: VariantsMap =
    [&["grueled"], &["gruelled"], &["gruelled"], &["gruelled"]];

pub(crate) static ENTRY_GRUELERS_2726513939754824802: VariantsMap = [
    &["gruelers"],
    &["gruellers"],
    &["gruellers"],
    &["gruellers"],
];

pub(crate) static ENTRY_GRUELER_9066861558472330595: VariantsMap =
    [&["grueler"], &["grueller"], &["grueller"], &["grueller"]];

pub(crate) static ENTRY_GRUELINGLY_17624749743431370706: VariantsMap = [
    &["gruelingly"],
    &["gruellingly"],
    &["gruellingly"],
    &["gruellingly"],
];

pub(crate) static ENTRY_GRUELINGS_2606568893918528496: VariantsMap = [
    &["gruelings"],
    &["gruellings"],
    &["gruellings"],
    &["gruellings"],
];

pub(crate) static ENTRY_GRUELING_10540189782332096170: VariantsMap = [
    &["grueling"],
    &["gruelling"],
    &["gruelling"],
    &["gruelling"],
];

pub(crate) static ENTRY_GUEBERS_6286021004437496479: VariantsMap =
    [&["guebers"], &["guebres"], &["guebres"], &["guebres"]];

pub(crate) static ENTRY_GUEBER_15352407594453289171: VariantsMap =
    [&["gueber"], &["guebre"], &["guebre"], &["guebre"]];

pub(crate) static ENTRY_GUIZERS_2986544585266099405: VariantsMap =
    [&["guizers"], &["guisers"], &["guizers"], &["guisers"]];

pub(crate) static ENTRY_GUIZER_580820017456619679: VariantsMap =
    [&["guizer"], &["guiser"], &["guizer"], &["guiser"]];

pub(crate) static ENTRY_GULE_11860123527431622005: VariantsMap =
    [&["gule"], &["gulae"], &["gulae"], &["gulae"]];

pub(crate) static ENTRY_GUTTE_16752124103215891589: VariantsMap =
    [&["gutte"], &["guttae"], &["guttae"], &["guttae"]];

pub(crate) static ENTRY_GUTTULE_17990999550881257571: VariantsMap =
    [&["guttule"], &["guttulae"], &["guttulae"], &["guttulae"]];

pub(crate) static ENTRY_GUTTURALIZATIONS_6761955224769799830: VariantsMap = [
    &["gutturalizations"],
    &["gutturalisations"],
    &["gutturalizations"],
    &["gutturalisations"],
];

pub(crate) static ENTRY_GUTTURALIZATION_12853736513139068391: VariantsMap = [
    &["gutturalization"],
    &["gutturalisation"],
    &["gutturalization"],
    &["gutturalisation"],
];

pub(crate) static ENTRY_GUTTURALIZED_17598926382362141161: VariantsMap = [
    &["gutturalized"],
    &["gutturalised"],
    &["gutturalized"],
    &["gutturalised"],
];

pub(crate) static ENTRY_GUTTURALIZES_17434359303702224403: VariantsMap = [
    &["gutturalizes"],
    &["gutturalises"],
    &["gutturalizes"],
    &["gutturalises"],
];

pub(crate) static ENTRY_GUTTURALIZE_16045921878572260792: VariantsMap = [
    &["gutturalize"],
    &["gutturalise"],
    &["gutturalize"],
    &["gutturalise"],
];

pub(crate) static ENTRY_GUTTURALIZING_18344702995674578601: VariantsMap = [
    &["gutturalizing"],
    &["gutturalising"],
    &["gutturalizing"],
    &["gutturalising"],
];

pub(crate) static ENTRY_GYNECIC_11400947530619276843: VariantsMap =
    [&["gynecic"], &["gynaecic"], &["gynaecic"], &["gynaecic"]];

pub(crate) static ENTRY_GYNECOCRACIES_4146735725336382856: VariantsMap = [
    &["gynecocracies"],
    &["gynaecocracies"],
    &["gynaecocracies"],
    &["gynaecocracies"],
];

pub(crate) static ENTRY_GYNECOCRACY_12364327428525738345: VariantsMap = [
    &["gynecocracy"],
    &["gynaecocracy"],
    &["gynaecocracy"],
    &["gynaecocracy"],
];

pub(crate) static ENTRY_GYNECOCRATICER_11125263222450989759: VariantsMap = [
    &["gynecocraticer"],
    &["gynaecocraticer"],
    &["gynaecocraticer"],
    &["gynaecocraticer"],
];

pub(crate) static ENTRY_GYNECOCRATICEST_12037974266743513062: VariantsMap = [
    &["gynecocraticest"],
    &["gynaecocraticest"],
    &["gynaecocraticest"],
    &["gynaecocraticest"],
];

pub(crate) static ENTRY_GYNECOCRATIC_7409449360121943743: VariantsMap = [
    &["gynecocratic"],
    &["gynaecocratic"],
    &["gynaecocratic"],
    &["gynaecocratic"],
];

pub(crate) static ENTRY_GYNECOCRATS_17873741619796682189: VariantsMap = [
    &["gynecocrats"],
    &["gynaecocrats"],
    &["gynaecocrats"],
    &["gynaecocrats"],
];

pub(crate) static ENTRY_GYNECOCRAT_5136932759212429718: VariantsMap = [
    &["gynecocrat"],
    &["gynaecocrat"],
    &["gynaecocrat"],
    &["gynaecocrat"],
];

pub(crate) static ENTRY_GYNECOID_7912530212797782324: VariantsMap = [
    &["gynecoid"],
    &["gynaecoid"],
    &["gynaecoid"],
    &["gynaecoid"],
];

pub(crate) static ENTRY_GYNECOLOGICALER_5828237580949279739: VariantsMap = [
    &["gynecologicaler"],
    &["gynaecologicaler"],
    &["gynecologicaler"],
    &["gynaecologicaler"],
];

pub(crate) static ENTRY_GYNECOLOGICALEST_11608781569016296041: VariantsMap = [
    &["gynecologicalest"],
    &["gynaecologicalest"],
    &["gynecologicalest"],
    &["gynaecologicalest"],
];

pub(crate) static ENTRY_GYNECOLOGICALS_16704040688018194960: VariantsMap = [
    &["gynecologicals"],
    &["gynaecologicals"],
    &["gynecologicals"],
    &["gynaecologicals"],
];

pub(crate) static ENTRY_GYNECOLOGICAL_10068656459548202370: VariantsMap = [
    &["gynecological"],
    &["gynaecological"],
    &["gynecological"],
    &["gynaecological"],
];

pub(crate) static ENTRY_GYNECOLOGICER_12168946939743180099: VariantsMap = [
    &["gynecologicer"],
    &["gynaecologicer"],
    &["gynaecologicer"],
    &["gynaecologicer"],
];

pub(crate) static ENTRY_GYNECOLOGICEST_18236154890722287831: VariantsMap = [
    &["gynecologicest"],
    &["gynaecologicest"],
    &["gynaecologicest"],
    &["gynaecologicest"],
];

pub(crate) static ENTRY_GYNECOLOGICS_13595002505435197512: VariantsMap = [
    &["gynecologics"],
    &["gynaecologics"],
    &["gynaecologics"],
    &["gynaecologics"],
];

pub(crate) static ENTRY_GYNECOLOGIC_10610170504252042060: VariantsMap = [
    &["gynecologic"],
    &["gynaecologic"],
    &["gynaecologic"],
    &["gynaecologic"],
];

pub(crate) static ENTRY_GYNECOLOGIES_7633791099195262658: VariantsMap = [
    &["gynecologies"],
    &["gynaecologies"],
    &["gynecologies"],
    &["gynaecologies"],
];

pub(crate) static ENTRY_GYNECOLOGISTS_8430092894671465244: VariantsMap = [
    &["gynecologists"],
    &["gynaecologists"],
    &["gynecologists"],
    &["gynaecologists"],
];

pub(crate) static ENTRY_GYNECOLOGIST_2204758927405939841: VariantsMap = [
    &["gynecologist"],
    &["gynaecologist"],
    &["gynecologist"],
    &["gynaecologist"],
];

pub(crate) static ENTRY_GYNECOLOGY_6636046866210569760: VariantsMap = [
    &["gynecology"],
    &["gynaecology"],
    &["gynecology"],
    &["gynaecology"],
];

pub(crate) static ENTRY_GYNECOL_5663216141561132674: VariantsMap =
    [&["gynecol"], &["gynaecol"], &["gynaecol"], &["gynaecol"]];

pub(crate) static ENTRY_GYNECOMASTIAS_4871542087429003006: VariantsMap = [
    &["gynecomastias"],
    &["gynaecomastias"],
    &["gynecomastias"],
    &["gynaecomastias"],
];

pub(crate) static ENTRY_GYNECOMASTIA_14330546154000297664: VariantsMap = [
    &["gynecomastia"],
    &["gynaecomastia"],
    &["gynecomastia"],
    &["gynaecomastia"],
];

pub(crate) static ENTRY_GYNECOMASTY_18357916230291548808: VariantsMap = [
    &["gynecomasty"],
    &["gynaecomasty"],
    &["gynaecomasty"],
    &["gynaecomasty"],
];

pub(crate) static ENTRY_GYNECOMORPHOUS_16181722902078327778: VariantsMap = [
    &["gynecomorphous"],
    &["gynaecomorphous"],
    &["gynaecomorphous"],
    &["gynaecomorphous"],
];

pub(crate) static ENTRY_GYNECONITIS_10352018651930377014: VariantsMap = [
    &["gyneconitis"],
    &["gynaeconitis"],
    &["gynaeconitis"],
    &["gynaeconitis"],
];

pub(crate) static ENTRY_GYNEOCRACY_3724321183261322247: VariantsMap = [
    &["gyneocracy"],
    &["gynaeocracy"],
    &["gynaeocracy"],
    &["gynaeocracy"],
];

pub(crate) static ENTRY_GYNEOLATER_7201516700429061903: VariantsMap = [
    &["gyneolater"],
    &["gynaeolater"],
    &["gynaeolater"],
    &["gynaeolater"],
];

pub(crate) static ENTRY_GYNEOLATRY_7952197731609201219: VariantsMap = [
    &["gyneolatry"],
    &["gynaeolatry"],
    &["gynaeolatry"],
    &["gynaeolatry"],
];

pub(crate) static ENTRY_GYNE_11492145333652169582: VariantsMap =
    [&["gyne"], &["gynae"], &["gynae"], &["gynae"]];

pub(crate) static ENTRY_GYNOMONECIOUS_610910634720209122: VariantsMap = [
    &["gynomonecious"],
    &["gynomonoecious"],
    &["gynomonoecious"],
    &["gynomonoecious"],
];

pub(crate) static ENTRY_GYROSTABILIZATIONS_14377043501796299026: VariantsMap = [
    &["gyrostabilizations"],
    &["gyrostabilisations"],
    &["gyrostabilizations"],
    &["gyrostabilisations"],
];

pub(crate) static ENTRY_GYROSTABILIZATION_7833567575472897725: VariantsMap = [
    &["gyrostabilization"],
    &["gyrostabilisation"],
    &["gyrostabilization"],
    &["gyrostabilisation"],
];

pub(crate) static ENTRY_GYROSTABILIZERS_1151210600208488533: VariantsMap = [
    &["gyrostabilizers"],
    &["gyrostabilisers"],
    &["gyrostabilizers"],
    &["gyrostabilisers"],
];

pub(crate) static ENTRY_GYROSTABILIZER_5766982365169984991: VariantsMap = [
    &["gyrostabilizer"],
    &["gyrostabiliser"],
    &["gyrostabilizer"],
    &["gyrostabiliser"],
];

pub(crate) static ENTRY_HABITUALIZES_16212776537383243642: VariantsMap = [
    &["habitualizes"],
    &["habitualises"],
    &["habitualizes"],
    &["habitualises"],
];

pub(crate) static ENTRY_HABITUALIZE_4203840421950334477: VariantsMap = [
    &["habitualize"],
    &["habitualise"],
    &["habitualize"],
    &["habitualise"],
];

pub(crate) static ENTRY_HAMLETIZATIONS_8418036370581575950: VariantsMap = [
    &["hamletizations"],
    &["hamletisations"],
    &["hamletizations"],
    &["hamletisations"],
];

pub(crate) static ENTRY_HAMLETIZATION_7068220455675423527: VariantsMap = [
    &["hamletization"],
    &["hamletisation"],
    &["hamletization"],
    &["hamletisation"],
];

pub(crate) static ENTRY_HAMLETIZES_12242920833710714304: VariantsMap = [
    &["hamletizes"],
    &["hamletises"],
    &["hamletizes"],
    &["hamletises"],
];

pub(crate) static ENTRY_HAMLETIZE_16914726912103891937: VariantsMap = [
    &["hamletize"],
    &["hamletise"],
    &["hamletize"],
    &["hamletise"],
];

pub(crate) static ENTRY_HANDSELED_1601691335316168918: VariantsMap = [
    &["handseled"],
    &["handselled"],
    &["handselled"],
    &["handselled"],
];

pub(crate) static ENTRY_HANDSELING_12635054089707091230: VariantsMap = [
    &["handseling"],
    &["handselling"],
    &["handselling"],
    &["handselling"],
];

pub(crate) static ENTRY_HANOVERIANIZES_1060714123380568078: VariantsMap = [
    &["hanoverianizes"],
    &["hanoverianises"],
    &["hanoverianizes"],
    &["hanoverianises"],
];

pub(crate) static ENTRY_HANOVERIANIZE_12937441892704551309: VariantsMap = [
    &["hanoverianize"],
    &["hanoverianise"],
    &["hanoverianize"],
    &["hanoverianise"],
];

pub(crate) static ENTRY_HANOVERIZES_2912973620982216821: VariantsMap = [
    &["hanoverizes"],
    &["hanoverises"],
    &["hanoverizes"],
    &["hanoverises"],
];

pub(crate) static ENTRY_HANOVERIZE_1037492501562492246: VariantsMap = [
    &["hanoverize"],
    &["hanoverise"],
    &["hanoverize"],
    &["hanoverise"],
];

pub(crate) static ENTRY_HANSARDIZED_10211126682279113594: VariantsMap = [
    &["hansardized"],
    &["hansardised"],
    &["hansardized"],
    &["hansardised"],
];

pub(crate) static ENTRY_HANSARDIZES_10105974452213715690: VariantsMap = [
    &["hansardizes"],
    &["hansardises"],
    &["hansardizes"],
    &["hansardises"],
];

pub(crate) static ENTRY_HANSARDIZE_15841512842392553595: VariantsMap = [
    &["hansardize"],
    &["hansardise"],
    &["hansardize"],
    &["hansardise"],
];

pub(crate) static ENTRY_HANSARDIZING_3871451417190379754: VariantsMap = [
    &["hansardizing"],
    &["hansardising"],
    &["hansardizing"],
    &["hansardising"],
];

pub(crate) static ENTRY_HANSELED_10669977240917095178: VariantsMap = [
    &["hanseled"],
    &["hanselled"],
    &["hanselled"],
    &["hanselled"],
];

pub(crate) static ENTRY_HANSELING_17863717275762765019: VariantsMap = [
    &["hanseling"],
    &["hanselling"],
    &["hanselling"],
    &["hanselling"],
];

pub(crate) static ENTRY_HARBORAGES_15869490209413392347: VariantsMap = [
    &["harborages"],
    &["harbourages"],
    &["harbourages"],
    &["harbourages"],
];

pub(crate) static ENTRY_HARBORAGE_18081919961627336647: VariantsMap = [
    &["harborage"],
    &["harbourage"],
    &["harbourage"],
    &["harbourage"],
];

pub(crate) static ENTRY_HARBORED_3058577388408571447: VariantsMap = [
    &["harbored"],
    &["harboured"],
    &["harboured"],
    &["harboured"],
];

pub(crate) static ENTRY_HARBORERS_13449068087647702937: VariantsMap = [
    &["harborers"],
    &["harbourers"],
    &["harbourers"],
    &["harbourers"],
];

pub(crate) static ENTRY_HARBORER_12057721507680863886: VariantsMap = [
    &["harborer"],
    &["harbourer"],
    &["harbourer"],
    &["harbourer"],
];

pub(crate) static ENTRY_HARBORFUL_3026394863252792305: VariantsMap = [
    &["harborful"],
    &["harbourful"],
    &["harbourful"],
    &["harbourful"],
];

pub(crate) static ENTRY_HARBORING_4045224059910485868: VariantsMap = [
    &["harboring"],
    &["harbouring"],
    &["harbouring"],
    &["harbouring"],
];

pub(crate) static ENTRY_HARBORLESSER_7367286280433451753: VariantsMap = [
    &["harborlesser"],
    &["harbourlesser"],
    &["harbourlesser"],
    &["harbourlesser"],
];

pub(crate) static ENTRY_HARBORLESSEST_9587382522823705631: VariantsMap = [
    &["harborlessest"],
    &["harbourlessest"],
    &["harbourlessest"],
    &["harbourlessest"],
];

pub(crate) static ENTRY_HARBORLESSES_8784862775655562494: VariantsMap = [
    &["harborlesses"],
    &["harbourlesses"],
    &["harbourlesses"],
    &["harbourlesses"],
];

pub(crate) static ENTRY_HARBORLESS_17223712074031778563: VariantsMap = [
    &["harborless"],
    &["harbourless"],
    &["harbourless"],
    &["harbourless"],
];

pub(crate) static ENTRY_HARBOROUS_12367039363418754232: VariantsMap = [
    &["harborous"],
    &["harbourous"],
    &["harbourous"],
    &["harbourous"],
];

pub(crate) static ENTRY_HARBORSIDE_9189215847440263967: VariantsMap = [
    &["harborside"],
    &["harbourside"],
    &["harbourside"],
    &["harbourside"],
];

pub(crate) static ENTRY_HARBORS_17563481687131959756: VariantsMap =
    [&["harbors"], &["harbours"], &["harbours"], &["harbours"]];

pub(crate) static ENTRY_HARBORWARD_925016071949079689: VariantsMap = [
    &["harborward"],
    &["harbourward"],
    &["harbourward"],
    &["harbourward"],
];

pub(crate) static ENTRY_HARBOR_5806650173337038030: VariantsMap =
    [&["harbor"], &["harbour"], &["harbour"], &["harbour"]];

pub(crate) static ENTRY_HARMONIZABLER_7404427142026247092: VariantsMap = [
    &["harmonizabler"],
    &["harmonisabler"],
    &["harmonizabler"],
    &["harmonisabler"],
];

pub(crate) static ENTRY_HARMONIZABLEST_2322931221738260941: VariantsMap = [
    &["harmonizablest"],
    &["harmonisablest"],
    &["harmonizablest"],
    &["harmonisablest"],
];

pub(crate) static ENTRY_HARMONIZABLES_8899243318045925912: VariantsMap = [
    &["harmonizables"],
    &["harmonisables"],
    &["harmonizables"],
    &["harmonisables"],
];

pub(crate) static ENTRY_HARMONIZABLE_729301759379091227: VariantsMap = [
    &["harmonizable"],
    &["harmonisable"],
    &["harmonizable"],
    &["harmonisable"],
];

pub(crate) static ENTRY_HARMONIZATIONS_6188790709212492045: VariantsMap = [
    &["harmonizations"],
    &["harmonisations"],
    &["harmonizations"],
    &["harmonisations"],
];

pub(crate) static ENTRY_HARMONIZATION_13372020123799276914: VariantsMap = [
    &["harmonization"],
    &["harmonisation"],
    &["harmonization"],
    &["harmonisation"],
];

pub(crate) static ENTRY_HARMONIZED_10072567516328574029: VariantsMap = [
    &["harmonized"],
    &["harmonised"],
    &["harmonized"],
    &["harmonised"],
];

pub(crate) static ENTRY_HARMONIZERS_7428199368959927446: VariantsMap = [
    &["harmonizers"],
    &["harmonisers"],
    &["harmonizers"],
    &["harmonisers"],
];

pub(crate) static ENTRY_HARMONIZER_11613954086587370839: VariantsMap = [
    &["harmonizer"],
    &["harmoniser"],
    &["harmonizer"],
    &["harmoniser"],
];

pub(crate) static ENTRY_HARMONIZES_11674618683147479548: VariantsMap = [
    &["harmonizes"],
    &["harmonises"],
    &["harmonizes"],
    &["harmonises"],
];

pub(crate) static ENTRY_HARMONIZE_8848752875563823524: VariantsMap = [
    &["harmonize"],
    &["harmonise"],
    &["harmonize"],
    &["harmonise"],
];

pub(crate) static ENTRY_HARMONIZING_15304155413238255688: VariantsMap = [
    &["harmonizing"],
    &["harmonising"],
    &["harmonizing"],
    &["harmonising"],
];

pub(crate) static ENTRY_HARMOTHOE_1964350150618023866: VariantsMap = [
    &["harmothoe"],
    &["harmothoae"],
    &["harmothoae"],
    &["harmothoae"],
];

pub(crate) static ENTRY_HARVARDIZES_10339860156255664794: VariantsMap = [
    &["harvardizes"],
    &["harvardises"],
    &["harvardizes"],
    &["harvardises"],
];

pub(crate) static ENTRY_HARVARDIZE_16493875396723735413: VariantsMap = [
    &["harvardize"],
    &["harvardise"],
    &["harvardize"],
    &["harvardise"],
];

pub(crate) static ENTRY_HARVEYIZES_11140932716217956681: VariantsMap = [
    &["harveyizes"],
    &["harveyises"],
    &["harveyizes"],
    &["harveyises"],
];

pub(crate) static ENTRY_HARVEYIZE_1826440362127190508: VariantsMap = [
    &["harveyize"],
    &["harveyise"],
    &["harveyize"],
    &["harveyise"],
];

pub(crate) static ENTRY_HASIDEAN_14801716241755178634: VariantsMap = [
    &["hasidean"],
    &["hasidaean"],
    &["hasidaean"],
    &["hasidaean"],
];

pub(crate) static ENTRY_HASMONEANS_13743887271629822483: VariantsMap = [
    &["hasmoneans"],
    &["hasmonaeans"],
    &["hasmonaeans"],
    &["hasmonaeans"],
];

pub(crate) static ENTRY_HASMONEAN_14311223713885956483: VariantsMap = [
    &["hasmonean"],
    &["hasmonaean"],
    &["hasmonaean"],
    &["hasmonaean"],
];

pub(crate) static ENTRY_HATCHELED_1160531518767605341: VariantsMap = [
    &["hatcheled"],
    &["hatchelled"],
    &["hatchelled"],
    &["hatchelled"],
];

pub(crate) static ENTRY_HATCHELING_16333231487227219003: VariantsMap = [
    &["hatcheling"],
    &["hatchelling"],
    &["hatchelling"],
    &["hatchelling"],
];

pub(crate) static ENTRY_HATTIZES_15099511290428270020: VariantsMap =
    [&["hattizes"], &["hattises"], &["hattizes"], &["hattises"]];

pub(crate) static ENTRY_HATTIZE_17233718368280146103: VariantsMap =
    [&["hattize"], &["hattise"], &["hattize"], &["hattise"]];

pub(crate) static ENTRY_HAUSSMANNIZATIONS_13595920704368529011: VariantsMap = [
    &["haussmannizations"],
    &["haussmannisations"],
    &["haussmannizations"],
    &["haussmannisations"],
];

pub(crate) static ENTRY_HAUSSMANNIZATION_6579157371759620134: VariantsMap = [
    &["haussmannization"],
    &["haussmannisation"],
    &["haussmannization"],
    &["haussmannisation"],
];

pub(crate) static ENTRY_HAUSSMANNIZED_7571602618111456009: VariantsMap = [
    &["haussmannized"],
    &["haussmannised"],
    &["haussmannized"],
    &["haussmannised"],
];

pub(crate) static ENTRY_HAUSSMANNIZES_3919133269135566133: VariantsMap = [
    &["haussmannizes"],
    &["haussmannises"],
    &["haussmannizes"],
    &["haussmannises"],
];

pub(crate) static ENTRY_HAUSSMANNIZE_12521195846882016200: VariantsMap = [
    &["haussmannize"],
    &["haussmannise"],
    &["haussmannize"],
    &["haussmannise"],
];

pub(crate) static ENTRY_HAUSSMANNIZING_14415612566710014005: VariantsMap = [
    &["haussmannizing"],
    &["haussmannising"],
    &["haussmannizing"],
    &["haussmannising"],
];

pub(crate) static ENTRY_HAVIORED_8097855145736080224: VariantsMap = [
    &["haviored"],
    &["havioured"],
    &["havioured"],
    &["havioured"],
];

pub(crate) static ENTRY_HAVIORS_5444880612094961134: VariantsMap =
    [&["haviors"], &["haviours"], &["haviours"], &["haviours"]];

pub(crate) static ENTRY_HAVIOR_10199035616705557158: VariantsMap =
    [&["havior"], &["haviour"], &["haviour"], &["haviour"]];

pub(crate) static ENTRY_HAZARDIZES_17139324560601958900: VariantsMap = [
    &["hazardizes"],
    &["hazardises"],
    &["hazardizes"],
    &["hazardises"],
];

pub(crate) static ENTRY_HAZARDIZE_11333969271620915584: VariantsMap = [
    &["hazardize"],
    &["hazardise"],
    &["hazardize"],
    &["hazardise"],
];

pub(crate) static ENTRY_HEATHENIZATION_11110636948237254370: VariantsMap = [
    &["heathenization"],
    &["heathenisation"],
    &["heathenization"],
    &["heathenisation"],
];

pub(crate) static ENTRY_HEATHENIZED_11182183490559881321: VariantsMap = [
    &["heathenized"],
    &["heathenised"],
    &["heathenized"],
    &["heathenised"],
];

pub(crate) static ENTRY_HEATHENIZES_16990989076680612437: VariantsMap = [
    &["heathenizes"],
    &["heathenises"],
    &["heathenizes"],
    &["heathenises"],
];

pub(crate) static ENTRY_HEATHENIZE_11684551967371253714: VariantsMap = [
    &["heathenize"],
    &["heathenise"],
    &["heathenize"],
    &["heathenise"],
];

pub(crate) static ENTRY_HEATHENIZING_9668189960205339110: VariantsMap = [
    &["heathenizing"],
    &["heathenising"],
    &["heathenizing"],
    &["heathenising"],
];

pub(crate) static ENTRY_HEAVENIZES_16270636662518817293: VariantsMap = [
    &["heavenizes"],
    &["heavenises"],
    &["heavenizes"],
    &["heavenises"],
];

pub(crate) static ENTRY_HEAVENIZE_12981074350052381166: VariantsMap = [
    &["heavenize"],
    &["heavenise"],
    &["heavenize"],
    &["heavenise"],
];

pub(crate) static ENTRY_HEBRAICIZES_9558284926005653742: VariantsMap = [
    &["hebraicizes"],
    &["hebraicises"],
    &["hebraicizes"],
    &["hebraicises"],
];

pub(crate) static ENTRY_HEBRAICIZE_4514131522170985476: VariantsMap = [
    &["hebraicize"],
    &["hebraicise"],
    &["hebraicize"],
    &["hebraicise"],
];

pub(crate) static ENTRY_HEBRAIZATIONS_9122079239866871837: VariantsMap = [
    &["hebraizations"],
    &["hebraisations"],
    &["hebraizations"],
    &["hebraisations"],
];

pub(crate) static ENTRY_HEBRAIZATION_6999932964448487456: VariantsMap = [
    &["hebraization"],
    &["hebraisation"],
    &["hebraization"],
    &["hebraisation"],
];

pub(crate) static ENTRY_HEBRAIZED_15890797870447255830: VariantsMap = [
    &["hebraized"],
    &["hebraised"],
    &["hebraized"],
    &["hebraised"],
];

pub(crate) static ENTRY_HEBRAIZER_6789183935043085226: VariantsMap = [
    &["hebraizer"],
    &["hebraiser"],
    &["hebraizer"],
    &["hebraiser"],
];

pub(crate) static ENTRY_HEBRAIZES_8311891020625852527: VariantsMap = [
    &["hebraizes"],
    &["hebraises"],
    &["hebraizes"],
    &["hebraises"],
];

pub(crate) static ENTRY_HEBRAIZE_11806255597737775133: VariantsMap =
    [&["hebraize"], &["hebraise"], &["hebraize"], &["hebraise"]];

pub(crate) static ENTRY_HEBRAIZING_6478640508596731098: VariantsMap = [
    &["hebraizing"],
    &["hebraising"],
    &["hebraizing"],
    &["hebraising"],
];

pub(crate) static ENTRY_HECATEAN_17050327951336563792: VariantsMap = [
    &["hecatean"],
    &["hecataean"],
    &["hecataean"],
    &["hecataean"],
];

pub(crate) static ENTRY_HECTOGRAMS_12165348482753150057: VariantsMap = [
    &["hectograms"],
    &["hectograms"],
    &["hectograms"],
    &["hectograms"],
];

pub(crate) static ENTRY_HECTOGRAM_5003794503916308235: VariantsMap = [
    &["hectogram"],
    &["hectogram"],
    &["hectogram"],
    &["hectogram"],
];

pub(crate) static ENTRY_HECTOLITERS_10663113073214490065: VariantsMap = [
    &["hectoliters"],
    &["hectolitres"],
    &["hectolitres"],
    &["hectolitres"],
];

pub(crate) static ENTRY_HECTOLITER_11797212009084644420: VariantsMap = [
    &["hectoliter"],
    &["hectolitre"],
    &["hectolitre"],
    &["hectolitre"],
];

pub(crate) static ENTRY_HECTOMETERS_8178246137676970270: VariantsMap = [
    &["hectometers"],
    &["hectometres"],
    &["hectometres"],
    &["hectometres"],
];

pub(crate) static ENTRY_HECTOMETER_13063905498394725108: VariantsMap = [
    &["hectometer"],
    &["hectometre"],
    &["hectometre"],
    &["hectometre"],
];

pub(crate) static ENTRY_HED_5256048441648265391: VariantsMap =
    [&["hed"], &["haed"], &["haed"], &["haed"]];

pub(crate) static ENTRY_HEGELIANIZES_8605025952633908200: VariantsMap = [
    &["hegelianizes"],
    &["hegelianises"],
    &["hegelianizes"],
    &["hegelianises"],
];

pub(crate) static ENTRY_HEGELIANIZE_16578015590815155196: VariantsMap = [
    &["hegelianize"],
    &["hegelianise"],
    &["hegelianize"],
    &["hegelianise"],
];

pub(crate) static ENTRY_HEKATEAN_12026259618893411500: VariantsMap = [
    &["hekatean"],
    &["hekataean"],
    &["hekataean"],
    &["hekataean"],
];

pub(crate) static ENTRY_HELE_9666054502463899057: VariantsMap =
    [&["hele"], &["heloe"], &["heloe"], &["heloe"]];

pub(crate) static ENTRY_HELLED_574727018671827478: VariantsMap =
    [&["helled"], &["helloed"], &["helloed"], &["helloed"]];

pub(crate) static ENTRY_HELLENIZATIONS_8710172968727451939: VariantsMap = [
    &["hellenizations"],
    &["hellenisations"],
    &["hellenizations"],
    &["hellenisations"],
];

pub(crate) static ENTRY_HELLENIZATION_13783607174000789408: VariantsMap = [
    &["hellenization"],
    &["hellenisation"],
    &["hellenization"],
    &["hellenisation"],
];

pub(crate) static ENTRY_HELLENIZED_14906317295118144102: VariantsMap = [
    &["hellenized"],
    &["hellenised"],
    &["hellenized"],
    &["hellenised"],
];

pub(crate) static ENTRY_HELLENIZER_7915427692830284272: VariantsMap = [
    &["hellenizer"],
    &["helleniser"],
    &["hellenizer"],
    &["helleniser"],
];

pub(crate) static ENTRY_HELLENIZES_16596514924514097835: VariantsMap = [
    &["hellenizes"],
    &["hellenises"],
    &["hellenizes"],
    &["hellenises"],
];

pub(crate) static ENTRY_HELLENIZE_15853764160002328426: VariantsMap = [
    &["hellenize"],
    &["hellenise"],
    &["hellenize"],
    &["hellenise"],
];

pub(crate) static ENTRY_HELLENIZING_11296376674365030923: VariantsMap = [
    &["hellenizing"],
    &["hellenising"],
    &["hellenizing"],
    &["hellenising"],
];

pub(crate) static ENTRY_HEMACHROME_3729476956483251061: VariantsMap = [
    &["hemachrome"],
    &["haemachrome"],
    &["haemachrome"],
    &["haemachrome"],
];

pub(crate) static ENTRY_HEMACYTOMETER_7645968025995756392: VariantsMap = [
    &["hemacytometer"],
    &["haemacytometer"],
    &["haemacytometer"],
    &["haemacytometer"],
];

pub(crate) static ENTRY_HEMAD_17500113374481638242: VariantsMap =
    [&["hemad"], &["haemad"], &["haemad"], &["haemad"]];

pub(crate) static ENTRY_HEMAGGLUTINATED_3077985582864313404: VariantsMap = [
    &["hemagglutinated"],
    &["haemagglutinated"],
    &["haemagglutinated"],
    &["haemagglutinated"],
];

pub(crate) static ENTRY_HEMAGGLUTINATE_7259240567955031710: VariantsMap = [
    &["hemagglutinate"],
    &["haemagglutinate"],
    &["haemagglutinate"],
    &["haemagglutinate"],
];

pub(crate) static ENTRY_HEMAGGLUTINATING_8254766798057399155: VariantsMap = [
    &["hemagglutinating"],
    &["haemagglutinating"],
    &["haemagglutinating"],
    &["haemagglutinating"],
];

pub(crate) static ENTRY_HEMAGGLUTINATION_8886672716726419818: VariantsMap = [
    &["hemagglutination"],
    &["haemagglutination"],
    &["haemagglutination"],
    &["haemagglutination"],
];

pub(crate) static ENTRY_HEMAGGLUTINATIVE_303261690448078143: VariantsMap = [
    &["hemagglutinative"],
    &["haemagglutinative"],
    &["haemagglutinative"],
    &["haemagglutinative"],
];

pub(crate) static ENTRY_HEMAGGLUTININ_15923049545494135264: VariantsMap = [
    &["hemagglutinin"],
    &["haemagglutinin"],
    &["haemagglutinin"],
    &["haemagglutinin"],
];

pub(crate) static ENTRY_HEMAGOGUE_11741387198881455915: VariantsMap = [
    &["hemagogue"],
    &["haemagogue"],
    &["haemagogue"],
    &["haemagogue"],
];

pub(crate) static ENTRY_HEMAL_17441393171650814474: VariantsMap =
    [&["hemal"], &["haemal"], &["haemal"], &["haemal"]];

pub(crate) static ENTRY_HEMAMEBA_3568248103119765389: VariantsMap = [
    &["hemameba"],
    &["hemamoeba"],
    &["hemamoeba"],
    &["hemamoeba"],
];

pub(crate) static ENTRY_HEMANGIOMAS_3389015659974672405: VariantsMap = [
    &["hemangiomas"],
    &["haemangiomas"],
    &["haemangiomas"],
    &["haemangiomas"],
];

pub(crate) static ENTRY_HEMANGIOMATA_14171539534972503880: VariantsMap = [
    &["hemangiomata"],
    &["haemangiomata"],
    &["haemangiomata"],
    &["haemangiomata"],
];

pub(crate) static ENTRY_HEMANGIOMATOSIS_18422709517634643109: VariantsMap = [
    &["hemangiomatosis"],
    &["haemangiomatosis"],
    &["haemangiomatosis"],
    &["haemangiomatosis"],
];

pub(crate) static ENTRY_HEMANGIOMA_15185992059473862053: VariantsMap = [
    &["hemangioma"],
    &["haemangioma"],
    &["haemangioma"],
    &["haemangioma"],
];

pub(crate) static ENTRY_HEMAPOPHYSIS_5976691613656262020: VariantsMap = [
    &["hemapophysis"],
    &["haemapophysis"],
    &["haemapophysis"],
    &["haemapophysis"],
];

pub(crate) static ENTRY_HEMASPECTROSCOPE_16029860263959084403: VariantsMap = [
    &["hemaspectroscope"],
    &["haemaspectroscope"],
    &["haemaspectroscope"],
    &["haemaspectroscope"],
];

pub(crate) static ENTRY_HEMATAL_3473810694033526440: VariantsMap =
    [&["hematal"], &["haematal"], &["haematal"], &["haematal"]];

pub(crate) static ENTRY_HEMATEIN_10299149840045810913: VariantsMap = [
    &["hematein"],
    &["haematein"],
    &["haematein"],
    &["haematein"],
];

pub(crate) static ENTRY_HEMATEMESIS_9702571717419169155: VariantsMap = [
    &["hematemesis"],
    &["haematemesis"],
    &["haematemesis"],
    &["haematemesis"],
];

pub(crate) static ENTRY_HEMATHERMAL_5311148388316154601: VariantsMap = [
    &["hemathermal"],
    &["haemathermal"],
    &["haemathermal"],
    &["haemathermal"],
];

pub(crate) static ENTRY_HEMATHERMOUS_11665424966689074429: VariantsMap = [
    &["hemathermous"],
    &["haemathermous"],
    &["haemathermous"],
    &["haemathermous"],
];

pub(crate) static ENTRY_HEMATHERM_7916536178037640325: VariantsMap = [
    &["hematherm"],
    &["haematherm"],
    &["haematherm"],
    &["haematherm"],
];

pub(crate) static ENTRY_HEMATICS_2072799741740171039: VariantsMap = [
    &["hematics"],
    &["haematics"],
    &["haematics"],
    &["haematics"],
];

pub(crate) static ENTRY_HEMATIC_11297008998147653262: VariantsMap =
    [&["hematic"], &["haematic"], &["haematic"], &["haematic"]];

pub(crate) static ENTRY_HEMATID_3667205209302242194: VariantsMap =
    [&["hematid"], &["haematid"], &["haematid"], &["haematid"]];

pub(crate) static ENTRY_HEMATINICS_5405890465468753688: VariantsMap = [
    &["hematinics"],
    &["haematinics"],
    &["haematinics"],
    &["haematinics"],
];

pub(crate) static ENTRY_HEMATINIC_5947779393945499901: VariantsMap = [
    &["hematinic"],
    &["haematinic"],
    &["haematinic"],
    &["haematinic"],
];

pub(crate) static ENTRY_HEMATINS_5995391549674023251: VariantsMap = [
    &["hematins"],
    &["haematins"],
    &["haematins"],
    &["haematins"],
];

pub(crate) static ENTRY_HEMATIN_17310006637994072946: VariantsMap =
    [&["hematin"], &["haematin"], &["haematin"], &["haematin"]];

pub(crate) static ENTRY_HEMATITES_16432545135150625666: VariantsMap = [
    &["hematites"],
    &["haematites"],
    &["hematites"],
    &["haematites"],
];

pub(crate) static ENTRY_HEMATITE_14468869663106727324: VariantsMap =
    [&["hematite"], &["haematite"], &["hematite"], &["haematite"]];

pub(crate) static ENTRY_HEMATITIC_1011725836724738056: VariantsMap = [
    &["hematitic"],
    &["haematitic"],
    &["haematitic"],
    &["haematitic"],
];

pub(crate) static ENTRY_HEMATOBLASTS_15227166432548606675: VariantsMap = [
    &["hematoblasts"],
    &["haematoblasts"],
    &["haematoblasts"],
    &["haematoblasts"],
];

pub(crate) static ENTRY_HEMATOBLAST_11319499306489037671: VariantsMap = [
    &["hematoblast"],
    &["haematoblast"],
    &["haematoblast"],
    &["haematoblast"],
];

pub(crate) static ENTRY_HEMATOBRANCHIATE_2844231569938030599: VariantsMap = [
    &["hematobranchiate"],
    &["haematobranchiate"],
    &["haematobranchiate"],
    &["haematobranchiate"],
];

pub(crate) static ENTRY_HEMATOCELE_1972666202637019639: VariantsMap = [
    &["hematocele"],
    &["haematocele"],
    &["hematocele"],
    &["haematocele"],
];

pub(crate) static ENTRY_HEMATOCRITS_16251852522040291719: VariantsMap = [
    &["hematocrits"],
    &["haematocrits"],
    &["haematocrits"],
    &["haematocrits"],
];

pub(crate) static ENTRY_HEMATOCRIT_11776543127174567971: VariantsMap = [
    &["hematocrit"],
    &["haematocrit"],
    &["haematocrit"],
    &["haematocrit"],
];

pub(crate) static ENTRY_HEMATOCRYAL_4555256092073194861: VariantsMap = [
    &["hematocryal"],
    &["haematocryal"],
    &["haematocryal"],
    &["haematocryal"],
];

pub(crate) static ENTRY_HEMATOCYSTIS_7706855010020816013: VariantsMap = [
    &["hematocystis"],
    &["haematocystis"],
    &["haematocystis"],
    &["haematocystis"],
];

pub(crate) static ENTRY_HEMATOCYST_464557994908851606: VariantsMap = [
    &["hematocyst"],
    &["haematocyst"],
    &["haematocyst"],
    &["haematocyst"],
];

pub(crate) static ENTRY_HEMATOCYTE_2489259526058226349: VariantsMap = [
    &["hematocyte"],
    &["haematocyte"],
    &["haematocyte"],
    &["haematocyte"],
];

pub(crate) static ENTRY_HEMATOGENESES_2202464054562607490: VariantsMap = [
    &["hematogeneses"],
    &["haematogeneses"],
    &["haematogeneses"],
    &["haematogeneses"],
];

pub(crate) static ENTRY_HEMATOGENESIS_7325937725699823684: VariantsMap = [
    &["hematogenesis"],
    &["haematogenesis"],
    &["haematogenesis"],
    &["haematogenesis"],
];

pub(crate) static ENTRY_HEMATOGENOUS_7648472768292588686: VariantsMap = [
    &["hematogenous"],
    &["haematogenous"],
    &["haematogenous"],
    &["haematogenous"],
];

pub(crate) static ENTRY_HEMATOIDIN_5202724309086507251: VariantsMap = [
    &["hematoidin"],
    &["haematoidin"],
    &["haematoidin"],
    &["haematoidin"],
];

pub(crate) static ENTRY_HEMATOID_1808679171388326204: VariantsMap = [
    &["hematoid"],
    &["haematoid"],
    &["haematoid"],
    &["haematoid"],
];

pub(crate) static ENTRY_HEMATOLOGICAL_1312253959057451336: VariantsMap = [
    &["hematological"],
    &["haematological"],
    &["hematological"],
    &["haematological"],
];

pub(crate) static ENTRY_HEMATOLOGIC_18220046089117542599: VariantsMap = [
    &["hematologic"],
    &["haematologic"],
    &["hematologic"],
    &["haematologic"],
];

pub(crate) static ENTRY_HEMATOLOGIES_16189544558993565198: VariantsMap = [
    &["hematologies"],
    &["haematologies"],
    &["hematologies"],
    &["haematologies"],
];

pub(crate) static ENTRY_HEMATOLOGISTS_4782136239490629800: VariantsMap = [
    &["hematologists"],
    &["haematologists"],
    &["hematologists"],
    &["haematologists"],
];

pub(crate) static ENTRY_HEMATOLOGIST_14280007862665204292: VariantsMap = [
    &["hematologist"],
    &["haematologist"],
    &["hematologist"],
    &["haematologist"],
];

pub(crate) static ENTRY_HEMATOLOGY_15238707498752205552: VariantsMap = [
    &["hematology"],
    &["haematology"],
    &["hematology"],
    &["haematology"],
];

pub(crate) static ENTRY_HEMATOLYSIS_18079015402986824465: VariantsMap = [
    &["hematolysis"],
    &["haematolysis"],
    &["haematolysis"],
    &["haematolysis"],
];

pub(crate) static ENTRY_HEMATOMAS_908833652817460466: VariantsMap = [
    &["hematomas"],
    &["haematomas"],
    &["haematomas"],
    &["haematomas"],
];

pub(crate) static ENTRY_HEMATOMATA_17333608130883052853: VariantsMap = [
    &["hematomata"],
    &["haematomata"],
    &["haematomata"],
    &["haematomata"],
];

pub(crate) static ENTRY_HEMATOMA_15558161368313999362: VariantsMap = [
    &["hematoma"],
    &["haematoma"],
    &["haematoma"],
    &["haematoma"],
];

pub(crate) static ENTRY_HEMATOMETER_8659377563531118312: VariantsMap = [
    &["hematometer"],
    &["haematometer"],
    &["haematometer"],
    &["haematometer"],
];

pub(crate) static ENTRY_HEMATOPHYTE_7980419769606343875: VariantsMap = [
    &["hematophyte"],
    &["haematophyte"],
    &["haematophyte"],
    &["haematophyte"],
];

pub(crate) static ENTRY_HEMATOPOIESES_1762593598918477279: VariantsMap = [
    &["hematopoieses"],
    &["haematopoieses"],
    &["haematopoieses"],
    &["haematopoieses"],
];

pub(crate) static ENTRY_HEMATOPOIESIS_14957246204910848242: VariantsMap = [
    &["hematopoiesis"],
    &["haematopoiesis"],
    &["haematopoiesis"],
    &["haematopoiesis"],
];

pub(crate) static ENTRY_HEMATOPOIETIC_5636580279732200517: VariantsMap = [
    &["hematopoietic"],
    &["haematopoietic"],
    &["haematopoietic"],
    &["haematopoietic"],
];

pub(crate) static ENTRY_HEMATORRHACHIS_3244347879185405245: VariantsMap = [
    &["hematorrhachis"],
    &["haematorrhachis"],
    &["haematorrhachis"],
    &["haematorrhachis"],
];

pub(crate) static ENTRY_HEMATOSEPSIS_11620038395306762074: VariantsMap = [
    &["hematosepsis"],
    &["haematosepsis"],
    &["haematosepsis"],
    &["haematosepsis"],
];

pub(crate) static ENTRY_HEMATOSIN_9020358802336175805: VariantsMap = [
    &["hematosin"],
    &["haematosin"],
    &["haematosin"],
    &["haematosin"],
];

pub(crate) static ENTRY_HEMATOSIS_3383158544475611837: VariantsMap = [
    &["hematosis"],
    &["haematosis"],
    &["haematosis"],
    &["haematosis"],
];

pub(crate) static ENTRY_HEMATOTHERMAL_8194902579206605957: VariantsMap = [
    &["hematothermal"],
    &["haematothermal"],
    &["haematothermal"],
    &["haematothermal"],
];

pub(crate) static ENTRY_HEMATOXYLIC_15238360661772109231: VariantsMap = [
    &["hematoxylic"],
    &["haematoxylic"],
    &["haematoxylic"],
    &["haematoxylic"],
];

pub(crate) static ENTRY_HEMATOXYLINS_16418497755495172078: VariantsMap = [
    &["hematoxylins"],
    &["haematoxylins"],
    &["hematoxylins"],
    &["haematoxylins"],
];

pub(crate) static ENTRY_HEMATOXYLIN_6889865558698001812: VariantsMap = [
    &["hematoxylin"],
    &["haematoxylin"],
    &["hematoxylin"],
    &["haematoxylin"],
];

pub(crate) static ENTRY_HEMATOZOAL_5612358861578154128: VariantsMap = [
    &["hematozoal"],
    &["haematozoal"],
    &["haematozoal"],
    &["haematozoal"],
];

pub(crate) static ENTRY_HEMATOZOA_16310785411433507697: VariantsMap = [
    &["hematozoa"],
    &["haematozoa"],
    &["haematozoa"],
    &["haematozoa"],
];

pub(crate) static ENTRY_HEMATOZOIC_6811181829581742874: VariantsMap = [
    &["hematozoic"],
    &["haematozoic"],
    &["haematozoic"],
    &["haematozoic"],
];

pub(crate) static ENTRY_HEMATOZOON_9291195545747434433: VariantsMap = [
    &["hematozoon"],
    &["haematozoon"],
    &["haematozoon"],
    &["haematozoon"],
];

pub(crate) static ENTRY_HEMATOZZOA_17098302032357442259: VariantsMap = [
    &["hematozzoa"],
    &["haematozzoa"],
    &["haematozzoa"],
    &["haematozzoa"],
];

pub(crate) static ENTRY_HEMATURIAS_9554717110278540795: VariantsMap = [
    &["hematurias"],
    &["haematurias"],
    &["hematurias"],
    &["haematurias"],
];

pub(crate) static ENTRY_HEMATURIA_2017961132280396424: VariantsMap = [
    &["hematuria"],
    &["haematuria"],
    &["hematuria"],
    &["haematuria"],
];

pub(crate) static ENTRY_HEMERYTHRIN_1502730445847671207: VariantsMap = [
    &["hemerythrin"],
    &["hemoerythrin"],
    &["hemoerythrin"],
    &["hemoerythrin"],
];

pub(crate) static ENTRY_HEME_10581684147735415352: VariantsMap =
    [&["heme"], &["haem"], &["haem"], &["haem"]];

pub(crate) static ENTRY_HEMIC_10115849406341667247: VariantsMap =
    [&["hemic"], &["haemic"], &["haemic"], &["haemic"]];

pub(crate) static ENTRY_HEMIHYPESTHESIA_12771702401961338683: VariantsMap = [
    &["hemihypesthesia"],
    &["hemihypoesthesia"],
    &["hemihypoesthesia"],
    &["hemihypoesthesia"],
];

pub(crate) static ENTRY_HEMINS_1405124450165077449: VariantsMap =
    [&["hemins"], &["haemins"], &["haemins"], &["haemins"]];

pub(crate) static ENTRY_HEMIN_13635073169658330154: VariantsMap =
    [&["hemin"], &["haemin"], &["haemin"], &["haemin"]];

pub(crate) static ENTRY_HEMOBLAST_2649725051858088271: VariantsMap = [
    &["hemoblast"],
    &["haemoblast"],
    &["haemoblast"],
    &["haemoblast"],
];

pub(crate) static ENTRY_HEMOCHROMATOSES_10907072426647588457: VariantsMap = [
    &["hemochromatoses"],
    &["haemochromatoses"],
    &["haemochromatoses"],
    &["haemochromatoses"],
];

pub(crate) static ENTRY_HEMOCHROMATOSIS_12928559471676134380: VariantsMap = [
    &["hemochromatosis"],
    &["haemochromatosis"],
    &["haemochromatosis"],
    &["haemochromatosis"],
];

pub(crate) static ENTRY_HEMOCHROME_9228123554665839557: VariantsMap = [
    &["hemochrome"],
    &["haemochrome"],
    &["haemochrome"],
    &["haemochrome"],
];

pub(crate) static ENTRY_HEMOCOELS_6456260620954605946: VariantsMap = [
    &["hemocoels"],
    &["haemocoels"],
    &["haemocoels"],
    &["haemocoels"],
];

pub(crate) static ENTRY_HEMOCOEL_16919582459376619162: VariantsMap = [
    &["hemocoel"],
    &["haemocoel"],
    &["haemocoel"],
    &["haemocoel"],
];

pub(crate) static ENTRY_HEMOCONCENTRATION_13535154840039489558: VariantsMap = [
    &["hemoconcentration"],
    &["haemoconcentration"],
    &["haemoconcentration"],
    &["haemoconcentration"],
];

pub(crate) static ENTRY_HEMOCONIA_16736345270230227681: VariantsMap = [
    &["hemoconia"],
    &["haemoconia"],
    &["haemoconia"],
    &["haemoconia"],
];

pub(crate) static ENTRY_HEMOCYANINS_13211158798270421692: VariantsMap = [
    &["hemocyanins"],
    &["haemocyanins"],
    &["haemocyanins"],
    &["haemocyanins"],
];

pub(crate) static ENTRY_HEMOCYANIN_9642423587808035318: VariantsMap = [
    &["hemocyanin"],
    &["haemocyanin"],
    &["haemocyanin"],
    &["haemocyanin"],
];

pub(crate) static ENTRY_HEMOCYTES_11970486144013002814: VariantsMap = [
    &["hemocytes"],
    &["haemocytes"],
    &["haemocytes"],
    &["haemocytes"],
];

pub(crate) static ENTRY_HEMOCYTE_9056880844554795657: VariantsMap = [
    &["hemocyte"],
    &["haemocyte"],
    &["haemocyte"],
    &["haemocyte"],
];

pub(crate) static ENTRY_HEMOCYTOBLASTIC_2891142520537992931: VariantsMap = [
    &["hemocytoblastic"],
    &["haemocytoblastic"],
    &["haemocytoblastic"],
    &["haemocytoblastic"],
];

pub(crate) static ENTRY_HEMOCYTOBLAST_3749643051292331307: VariantsMap = [
    &["hemocytoblast"],
    &["haemocytoblast"],
    &["haemocytoblast"],
    &["haemocytoblast"],
];

pub(crate) static ENTRY_HEMOCYTOMETER_9911855835830563156: VariantsMap = [
    &["hemocytometer"],
    &["haemocytometer"],
    &["haemocytometer"],
    &["haemocytometer"],
];

pub(crate) static ENTRY_HEMODIALYSES_7416791187084499531: VariantsMap = [
    &["hemodialyses"],
    &["haemodialyses"],
    &["hemodialyses"],
    &["haemodialyses"],
];

pub(crate) static ENTRY_HEMODIALYSIS_2356269218981689445: VariantsMap = [
    &["hemodialysis"],
    &["haemodialysis"],
    &["hemodialysis"],
    &["haemodialysis"],
];

pub(crate) static ENTRY_HEMODILUTION_8908658927910101249: VariantsMap = [
    &["hemodilution"],
    &["haemodilution"],
    &["haemodilution"],
    &["haemodilution"],
];

pub(crate) static ENTRY_HEMODYNAMICS_13468985183469387770: VariantsMap = [
    &["hemodynamics"],
    &["haemodynamics"],
    &["haemodynamics"],
    &["haemodynamics"],
];

pub(crate) static ENTRY_HEMODYNAMIC_99687820226271458: VariantsMap = [
    &["hemodynamic"],
    &["haemodynamic"],
    &["haemodynamic"],
    &["haemodynamic"],
];

pub(crate) static ENTRY_HEMOFLAGELLATE_1909016951558476190: VariantsMap = [
    &["hemoflagellate"],
    &["haemoflagellate"],
    &["haemoflagellate"],
    &["haemoflagellate"],
];

pub(crate) static ENTRY_HEMOGLOBIC_12569293265233239479: VariantsMap = [
    &["hemoglobic"],
    &["haemoglobic"],
    &["haemoglobic"],
    &["haemoglobic"],
];

pub(crate) static ENTRY_HEMOGLOBINOPATHIES_14362809746066184976: VariantsMap = [
    &["hemoglobinopathies"],
    &["haemoglobinopathies"],
    &["haemoglobinopathies"],
    &["haemoglobinopathies"],
];

pub(crate) static ENTRY_HEMOGLOBINOPATHY_12649532936999683142: VariantsMap = [
    &["hemoglobinopathy"],
    &["haemoglobinopathy"],
    &["haemoglobinopathy"],
    &["haemoglobinopathy"],
];

pub(crate) static ENTRY_HEMOGLOBINOUS_1428697249377514098: VariantsMap = [
    &["hemoglobinous"],
    &["haemoglobinous"],
    &["haemoglobinous"],
    &["haemoglobinous"],
];

pub(crate) static ENTRY_HEMOGLOBINURIA_2281539742314619937: VariantsMap = [
    &["hemoglobinuria"],
    &["haemoglobinuria"],
    &["haemoglobinuria"],
    &["haemoglobinuria"],
];

pub(crate) static ENTRY_HEMOGLOBIN_7404896410383089627: VariantsMap = [
    &["hemoglobin"],
    &["haemoglobin"],
    &["hemoglobin"],
    &["haemoglobin"],
];

pub(crate) static ENTRY_HEMOGRAM_4160553122541107842: VariantsMap = [
    &["hemogram"],
    &["haemogram"],
    &["haemogram"],
    &["haemogram"],
];

pub(crate) static ENTRY_HEMOID_18441428178335197003: VariantsMap =
    [&["hemoid"], &["haemoid"], &["haemoid"], &["haemoid"]];

pub(crate) static ENTRY_HEMOLYSIN_4766300835176555554: VariantsMap = [
    &["hemolysin"],
    &["haemolysin"],
    &["haemolysin"],
    &["haemolysin"],
];

pub(crate) static ENTRY_HEMOLYSIS_6121455356135496493: VariantsMap = [
    &["hemolysis"],
    &["haemolysis"],
    &["hemolysis"],
    &["haemolysis"],
];

pub(crate) static ENTRY_HEMOLYTIC_15374482328757058560: VariantsMap = [
    &["hemolytic"],
    &["haemolytic"],
    &["haemolytic"],
    &["haemolytic"],
];

pub(crate) static ENTRY_HEMOMETER_3114013764107256805: VariantsMap = [
    &["hemometer"],
    &["haemometer"],
    &["haemometer"],
    &["haemometer"],
];

pub(crate) static ENTRY_HEMON_15552272331833168453: VariantsMap =
    [&["hemon"], &["haemon"], &["haemon"], &["haemon"]];

pub(crate) static ENTRY_HEMOPHILE_12901546318135530373: VariantsMap = [
    &["hemophile"],
    &["haemophile"],
    &["haemophile"],
    &["haemophile"],
];

pub(crate) static ENTRY_HEMOPHILIACS_1819791222881034020: VariantsMap = [
    &["hemophiliacs"],
    &["haemophiliacs"],
    &["hemophiliacs"],
    &["haemophiliacs"],
];

pub(crate) static ENTRY_HEMOPHILIAC_15127098181926005330: VariantsMap = [
    &["hemophiliac"],
    &["haemophiliac"],
    &["hemophiliac"],
    &["haemophiliac"],
];

pub(crate) static ENTRY_HEMOPHILIA_7379790116520405129: VariantsMap = [
    &["hemophilia"],
    &["haemophilia"],
    &["hemophilia"],
    &["haemophilia"],
];

pub(crate) static ENTRY_HEMOPHILIC_14674123167547417778: VariantsMap = [
    &["hemophilic"],
    &["haemophilic"],
    &["hemophilic"],
    &["haemophilic"],
];

pub(crate) static ENTRY_HEMOPOD_2878895326095181845: VariantsMap =
    [&["hemopod"], &["haemopod"], &["haemopod"], &["haemopod"]];

pub(crate) static ENTRY_HEMOPOIESIS_4521489762869246287: VariantsMap = [
    &["hemopoiesis"],
    &["haemopoiesis"],
    &["haemopoiesis"],
    &["haemopoiesis"],
];

pub(crate) static ENTRY_HEMOPTYSES_9711906895580892150: VariantsMap = [
    &["hemoptyses"],
    &["haemoptyses"],
    &["haemoptyses"],
    &["haemoptyses"],
];

pub(crate) static ENTRY_HEMOPTYSIS_6606896046225564524: VariantsMap = [
    &["hemoptysis"],
    &["haemoptysis"],
    &["haemoptysis"],
    &["haemoptysis"],
];

pub(crate) static ENTRY_HEMORRHAGED_3567508913732842236: VariantsMap = [
    &["hemorrhaged"],
    &["haemorrhaged"],
    &["hemorrhaged"],
    &["haemorrhaged"],
];

pub(crate) static ENTRY_HEMORRHAGES_11033424934560552856: VariantsMap = [
    &["hemorrhages"],
    &["haemorrhages"],
    &["hemorrhages"],
    &["haemorrhages"],
];

pub(crate) static ENTRY_HEMORRHAGE_13487833252665047802: VariantsMap = [
    &["hemorrhage"],
    &["haemorrhage"],
    &["hemorrhage"],
    &["haemorrhage"],
];

pub(crate) static ENTRY_HEMORRHAGING_14700849159949160924: VariantsMap = [
    &["hemorrhaging"],
    &["haemorrhaging"],
    &["hemorrhaging"],
    &["haemorrhaging"],
];

pub(crate) static ENTRY_HEMORRHOIDAL_10501532313574976310: VariantsMap = [
    &["hemorrhoidal"],
    &["haemorrhoidal"],
    &["hemorrhoidal"],
    &["haemorrhoidal"],
];

pub(crate) static ENTRY_HEMORRHOIDECTOMY_4750049726844559549: VariantsMap = [
    &["hemorrhoidectomy"],
    &["haemorrhoidectomy"],
    &["haemorrhoidectomy"],
    &["haemorrhoidectomy"],
];

pub(crate) static ENTRY_HEMORRHOIDS_13714329857736517214: VariantsMap = [
    &["hemorrhoids"],
    &["haemorrhoids"],
    &["hemorrhoids"],
    &["haemorrhoids"],
];

pub(crate) static ENTRY_HEMORRHOID_7766599523154289018: VariantsMap = [
    &["hemorrhoid"],
    &["haemorrhoid"],
    &["hemorrhoid"],
    &["haemorrhoid"],
];

pub(crate) static ENTRY_HEMOSPORIDIAN_16163775887165910953: VariantsMap = [
    &["hemosporidian"],
    &["haemosporidian"],
    &["haemosporidian"],
    &["haemosporidian"],
];

pub(crate) static ENTRY_HEMOSPORID_17787470410905331344: VariantsMap = [
    &["hemosporid"],
    &["haemosporid"],
    &["haemosporid"],
    &["haemosporid"],
];

pub(crate) static ENTRY_HEMOSTASES_17875899375851174427: VariantsMap = [
    &["hemostases"],
    &["haemostases"],
    &["haemostases"],
    &["haemostases"],
];

pub(crate) static ENTRY_HEMOSTASIA_2990592071271355209: VariantsMap = [
    &["hemostasia"],
    &["haemostasia"],
    &["haemostasia"],
    &["haemostasia"],
];

pub(crate) static ENTRY_HEMOSTASIS_10601607695856646551: VariantsMap = [
    &["hemostasis"],
    &["haemostasis"],
    &["haemostasis"],
    &["haemostasis"],
];

pub(crate) static ENTRY_HEMOSTATIC_11321860210181124752: VariantsMap = [
    &["hemostatic"],
    &["haemostatic"],
    &["haemostatic"],
    &["haemostatic"],
];

pub(crate) static ENTRY_HEMOTHORAX_6930101878147813840: VariantsMap = [
    &["hemothorax"],
    &["haemothorax"],
    &["haemothorax"],
    &["haemothorax"],
];

pub(crate) static ENTRY_HEMOTOXIC_9808851015011198385: VariantsMap = [
    &["hemotoxic"],
    &["haemotoxic"],
    &["haemotoxic"],
    &["haemotoxic"],
];

pub(crate) static ENTRY_HEMOTOXIN_12328861364395861819: VariantsMap = [
    &["hemotoxin"],
    &["haemotoxin"],
    &["haemotoxin"],
    &["haemotoxin"],
];

pub(crate) static ENTRY_HEPARINIZE_9400135191946821735: VariantsMap = [
    &["heparinize"],
    &["heparinise"],
    &["heparinize"],
    &["heparinise"],
];

pub(crate) static ENTRY_HEPATIZATIONS_3467705694436693139: VariantsMap = [
    &["hepatizations"],
    &["hepatisations"],
    &["hepatizations"],
    &["hepatisations"],
];

pub(crate) static ENTRY_HEPATIZATION_9072640861820695879: VariantsMap = [
    &["hepatization"],
    &["hepatisation"],
    &["hepatization"],
    &["hepatisation"],
];

pub(crate) static ENTRY_HEPATIZED_14001625043891502185: VariantsMap = [
    &["hepatized"],
    &["hepatised"],
    &["hepatized"],
    &["hepatised"],
];

pub(crate) static ENTRY_HEPATIZES_1714881038322610197: VariantsMap = [
    &["hepatizes"],
    &["hepatises"],
    &["hepatizes"],
    &["hepatises"],
];

pub(crate) static ENTRY_HEPATIZE_16744808070227801764: VariantsMap =
    [&["hepatize"], &["hepatise"], &["hepatize"], &["hepatise"]];

pub(crate) static ENTRY_HEPATIZING_4990710191594309212: VariantsMap = [
    &["hepatizing"],
    &["hepatising"],
    &["hepatizing"],
    &["hepatising"],
];

pub(crate) static ENTRY_HEPATORRHEA_16055155629543690649: VariantsMap = [
    &["hepatorrhea"],
    &["hepatorrhoea"],
    &["hepatorrhoea"],
    &["hepatorrhoea"],
];

pub(crate) static ENTRY_HERALDIZES_9625869039077628339: VariantsMap = [
    &["heraldizes"],
    &["heraldises"],
    &["heraldizes"],
    &["heraldises"],
];

pub(crate) static ENTRY_HERALDIZE_1299246729599142888: VariantsMap = [
    &["heraldize"],
    &["heraldise"],
    &["heraldize"],
    &["heraldise"],
];

pub(crate) static ENTRY_HERBORIZATIONS_15092465489013217159: VariantsMap = [
    &["herborizations"],
    &["herborisations"],
    &["herborizations"],
    &["herborisations"],
];

pub(crate) static ENTRY_HERBORIZATION_9694510769904043574: VariantsMap = [
    &["herborization"],
    &["herborisation"],
    &["herborization"],
    &["herborisation"],
];

pub(crate) static ENTRY_HERBORIZED_2101485275481463372: VariantsMap = [
    &["herborized"],
    &["herborised"],
    &["herborized"],
    &["herborised"],
];

pub(crate) static ENTRY_HERBORIZES_5862208448182471834: VariantsMap = [
    &["herborizes"],
    &["herborises"],
    &["herborizes"],
    &["herborises"],
];

pub(crate) static ENTRY_HERBORIZE_6087792157086937690: VariantsMap = [
    &["herborize"],
    &["herborise"],
    &["herborize"],
    &["herborise"],
];

pub(crate) static ENTRY_HERBORIZING_13693985247710999928: VariantsMap = [
    &["herborizing"],
    &["herborising"],
    &["herborizing"],
    &["herborising"],
];

pub(crate) static ENTRY_HEREDES_13554981120907052697: VariantsMap =
    [&["heredes"], &["haeredes"], &["haeredes"], &["haeredes"]];

pub(crate) static ENTRY_HERETICIZES_4776141255720716932: VariantsMap = [
    &["hereticizes"],
    &["hereticises"],
    &["hereticizes"],
    &["hereticises"],
];

pub(crate) static ENTRY_HERETICIZE_1833772869289401363: VariantsMap = [
    &["hereticize"],
    &["hereticise"],
    &["hereticize"],
    &["hereticise"],
];

pub(crate) static ENTRY_HEROINIZES_8533965791893198494: VariantsMap = [
    &["heroinizes"],
    &["heroinises"],
    &["heroinizes"],
    &["heroinises"],
];

pub(crate) static ENTRY_HEROINIZE_16854385387045389288: VariantsMap = [
    &["heroinize"],
    &["heroinise"],
    &["heroinize"],
    &["heroinise"],
];

pub(crate) static ENTRY_HEROIZATIONS_12643862966875221323: VariantsMap = [
    &["heroizations"],
    &["heroisations"],
    &["heroizations"],
    &["heroisations"],
];

pub(crate) static ENTRY_HEROIZATION_3743029117640967144: VariantsMap = [
    &["heroization"],
    &["heroisation"],
    &["heroization"],
    &["heroisation"],
];

pub(crate) static ENTRY_HEROIZED_8987274669079875509: VariantsMap =
    [&["heroized"], &["heroised"], &["heroized"], &["heroised"]];

pub(crate) static ENTRY_HEROIZES_1706830083011002298: VariantsMap =
    [&["heroizes"], &["heroises"], &["heroizes"], &["heroises"]];

pub(crate) static ENTRY_HEROIZE_10047540448061749836: VariantsMap =
    [&["heroize"], &["heroise"], &["heroize"], &["heroise"]];

pub(crate) static ENTRY_HEROIZING_8120983839711587732: VariantsMap = [
    &["heroizing"],
    &["heroising"],
    &["heroizing"],
    &["heroising"],
];

pub(crate) static ENTRY_HETERECIOUS_17020960417462354136: VariantsMap = [
    &["heterecious"],
    &["heteroecious"],
    &["heteroecious"],
    &["heteroecious"],
];

pub(crate) static ENTRY_HETERIC_12696738005922554091: VariantsMap =
    [&["heteric"], &["hetaeric"], &["hetaeric"], &["hetaeric"]];

pub(crate) static ENTRY_HETERISM_13266915073943432738: VariantsMap = [
    &["heterism"],
    &["hetaerism"],
    &["hetaerism"],
    &["hetaerism"],
];

pub(crate) static ENTRY_HETS_18190453795920851209: VariantsMap =
    [&["hets"], &["haets"], &["haets"], &["haets"]];

pub(crate) static ENTRY_HET_3711738254301522053: VariantsMap =
    [&["het"], &["haet"], &["haet"], &["haet"]];

pub(crate) static ENTRY_HEXACHLORETHANES_16683094668819210196: VariantsMap = [
    &["hexachlorethanes"],
    &["hexachloroethanes"],
    &["hexachloroethanes"],
    &["hexachloroethanes"],
];

pub(crate) static ENTRY_HEXACHLORETHANE_13880804086836995242: VariantsMap = [
    &["hexachlorethane"],
    &["hexachloroethane"],
    &["hexachloroethane"],
    &["hexachloroethane"],
];

pub(crate) static ENTRY_HEXAMETRIZED_13605811822316402905: VariantsMap = [
    &["hexametrized"],
    &["hexametrised"],
    &["hexametrized"],
    &["hexametrised"],
];

pub(crate) static ENTRY_HEXAMETRIZES_1813592333034482642: VariantsMap = [
    &["hexametrizes"],
    &["hexametrises"],
    &["hexametrizes"],
    &["hexametrises"],
];

pub(crate) static ENTRY_HEXAMETRIZE_5547414406662974434: VariantsMap = [
    &["hexametrize"],
    &["hexametrise"],
    &["hexametrize"],
    &["hexametrise"],
];

pub(crate) static ENTRY_HEXAMETRIZING_10582887862350659124: VariantsMap = [
    &["hexametrizing"],
    &["hexametrising"],
    &["hexametrizing"],
    &["hexametrising"],
];

pub(crate) static ENTRY_HEXESTROL_9909297945109173360: VariantsMap = [
    &["hexestrol"],
    &["hexoestrol"],
    &["hexoestrol"],
    &["hexoestrol"],
];

pub(crate) static ENTRY_HIBERNICIZED_18381403222365205426: VariantsMap = [
    &["hibernicized"],
    &["hibernicised"],
    &["hibernicized"],
    &["hibernicised"],
];

pub(crate) static ENTRY_HIBERNICIZES_8504841140657962943: VariantsMap = [
    &["hibernicizes"],
    &["hibernicises"],
    &["hibernicizes"],
    &["hibernicises"],
];

pub(crate) static ENTRY_HIBERNICIZE_3470806717863110401: VariantsMap = [
    &["hibernicize"],
    &["hibernicise"],
    &["hibernicize"],
    &["hibernicise"],
];

pub(crate) static ENTRY_HIBERNICIZING_12237920868399803779: VariantsMap = [
    &["hibernicizing"],
    &["hibernicising"],
    &["hibernicizing"],
    &["hibernicising"],
];

pub(crate) static ENTRY_HIBERNIZATIONS_5650569713694187831: VariantsMap = [
    &["hibernizations"],
    &["hibernisations"],
    &["hibernizations"],
    &["hibernisations"],
];

pub(crate) static ENTRY_HIBERNIZATION_3006579217265811606: VariantsMap = [
    &["hibernization"],
    &["hibernisation"],
    &["hibernization"],
    &["hibernisation"],
];

pub(crate) static ENTRY_HIBERNIZED_16602927325875706195: VariantsMap = [
    &["hibernized"],
    &["hibernised"],
    &["hibernized"],
    &["hibernised"],
];

pub(crate) static ENTRY_HIBERNIZES_7753606908031329667: VariantsMap = [
    &["hibernizes"],
    &["hibernises"],
    &["hibernizes"],
    &["hibernises"],
];

pub(crate) static ENTRY_HIBERNIZE_750212256722303375: VariantsMap = [
    &["hibernize"],
    &["hibernise"],
    &["hibernize"],
    &["hibernise"],
];

pub(crate) static ENTRY_HIBERNIZING_1183885855013493036: VariantsMap = [
    &["hibernizing"],
    &["hibernising"],
    &["hibernizing"],
    &["hibernising"],
];

pub(crate) static ENTRY_HICCUPED_10125331953329560167: VariantsMap =
    [&["hiccuped"], &["hiccuped"], &["hiccuped"], &["hiccuped"]];

pub(crate) static ENTRY_HICCUPING_14277666795637273542: VariantsMap = [
    &["hiccuping"],
    &["hiccuping"],
    &["hiccuping"],
    &["hiccuping"],
];

pub(crate) static ENTRY_HIERARCHIZED_16218874539182971788: VariantsMap = [
    &["hierarchized"],
    &["hierarchised"],
    &["hierarchized"],
    &["hierarchised"],
];

pub(crate) static ENTRY_HIERARCHIZE_16104584967271198045: VariantsMap = [
    &["hierarchize"],
    &["hierarchise"],
    &["hierarchize"],
    &["hierarchise"],
];

pub(crate) static ENTRY_HIERARCHIZING_8072837221828080257: VariantsMap = [
    &["hierarchizing"],
    &["hierarchising"],
    &["hierarchizing"],
    &["hierarchising"],
];

pub(crate) static ENTRY_HILLOED_11954365269279544751: VariantsMap =
    [&["hilloed"], &["hilloaed"], &["hilloaed"], &["hilloaed"]];

pub(crate) static ENTRY_HINDUIZED_1479360559613540500: VariantsMap = [
    &["hinduized"],
    &["hinduised"],
    &["hinduized"],
    &["hinduised"],
];

pub(crate) static ENTRY_HINDUIZES_8675577031524468618: VariantsMap = [
    &["hinduizes"],
    &["hinduises"],
    &["hinduizes"],
    &["hinduises"],
];

pub(crate) static ENTRY_HINDUIZE_1079507685818211649: VariantsMap =
    [&["hinduize"], &["hinduise"], &["hinduize"], &["hinduise"]];

pub(crate) static ENTRY_HINDUIZING_14941208918762953335: VariantsMap = [
    &["hinduizing"],
    &["hinduising"],
    &["hinduizing"],
    &["hinduising"],
];

pub(crate) static ENTRY_HIRSELED_18076009615056451805: VariantsMap = [
    &["hirseled"],
    &["hirselled"],
    &["hirselled"],
    &["hirselled"],
];

pub(crate) static ENTRY_HIRSELING_2556773690895991425: VariantsMap = [
    &["hirseling"],
    &["hirselling"],
    &["hirselling"],
    &["hirselling"],
];

pub(crate) static ENTRY_HISPANICIZATIONS_6144814973963714881: VariantsMap = [
    &["hispanicizations"],
    &["hispanicisations"],
    &["hispanicizations"],
    &["hispanicisations"],
];

pub(crate) static ENTRY_HISPANICIZATION_10179325605161634602: VariantsMap = [
    &["hispanicization"],
    &["hispanicisation"],
    &["hispanicization"],
    &["hispanicisation"],
];

pub(crate) static ENTRY_HISPANICIZED_13356089989930073997: VariantsMap = [
    &["hispanicized"],
    &["hispanicised"],
    &["hispanicized"],
    &["hispanicised"],
];

pub(crate) static ENTRY_HISPANICIZES_714224352915567074: VariantsMap = [
    &["hispanicizes"],
    &["hispanicises"],
    &["hispanicizes"],
    &["hispanicises"],
];

pub(crate) static ENTRY_HISPANICIZE_5569049257972807545: VariantsMap = [
    &["hispanicize"],
    &["hispanicise"],
    &["hispanicize"],
    &["hispanicise"],
];

pub(crate) static ENTRY_HISPANICIZING_4649080031779009424: VariantsMap = [
    &["hispanicizing"],
    &["hispanicising"],
    &["hispanicizing"],
    &["hispanicising"],
];

pub(crate) static ENTRY_HISPANIOLIZED_17671390796065364051: VariantsMap = [
    &["hispaniolized"],
    &["hispaniolised"],
    &["hispaniolized"],
    &["hispaniolised"],
];

pub(crate) static ENTRY_HISPANIOLIZES_9761019512121194277: VariantsMap = [
    &["hispaniolizes"],
    &["hispaniolises"],
    &["hispaniolizes"],
    &["hispaniolises"],
];

pub(crate) static ENTRY_HISPANIOLIZE_2714451964856493901: VariantsMap = [
    &["hispaniolize"],
    &["hispaniolise"],
    &["hispaniolize"],
    &["hispaniolise"],
];

pub(crate) static ENTRY_HISPANIOLIZING_2412049156656096282: VariantsMap = [
    &["hispaniolizing"],
    &["hispaniolising"],
    &["hispaniolizing"],
    &["hispaniolising"],
];

pub(crate) static ENTRY_HISTORICIZED_4477210962297319607: VariantsMap = [
    &["historicized"],
    &["historicised"],
    &["historicized"],
    &["historicised"],
];

pub(crate) static ENTRY_HISTORICIZES_4470232853457690850: VariantsMap = [
    &["historicizes"],
    &["historicises"],
    &["historicizes"],
    &["historicises"],
];

pub(crate) static ENTRY_HISTORICIZE_13738209779856267617: VariantsMap = [
    &["historicize"],
    &["historicise"],
    &["historicize"],
    &["historicise"],
];

pub(crate) static ENTRY_HISTORICIZING_4593407917384797019: VariantsMap = [
    &["historicizing"],
    &["historicising"],
    &["historicizing"],
    &["historicising"],
];

pub(crate) static ENTRY_HOLLYWOODIZED_15803046821319488532: VariantsMap = [
    &["hollywoodized"],
    &["hollywoodised"],
    &["hollywoodized"],
    &["hollywoodised"],
];

pub(crate) static ENTRY_HOLLYWOODIZES_4277134239348624276: VariantsMap = [
    &["hollywoodizes"],
    &["hollywoodises"],
    &["hollywoodizes"],
    &["hollywoodises"],
];

pub(crate) static ENTRY_HOLLYWOODIZE_3616601579568204910: VariantsMap = [
    &["hollywoodize"],
    &["hollywoodise"],
    &["hollywoodize"],
    &["hollywoodise"],
];

pub(crate) static ENTRY_HOLLYWOODIZING_6706537646076294291: VariantsMap = [
    &["hollywoodizing"],
    &["hollywoodising"],
    &["hollywoodizing"],
    &["hollywoodising"],
];

pub(crate) static ENTRY_HOMEOBLASTIC_116551251797444094: VariantsMap = [
    &["homeoblastic"],
    &["homeoblastic"],
    &["homeoblastic"],
    &["homeoblastic"],
];

pub(crate) static ENTRY_HOMEOBOX_17743046375220444429: VariantsMap =
    [&["homeobox"], &["homeobox"], &["homeobox"], &["homeobox"]];

pub(crate) static ENTRY_HOMEOCHROMATIC_10691375472279262101: VariantsMap = [
    &["homeochromatic"],
    &["homeochromatic"],
    &["homeochromatic"],
    &["homeochromatic"],
];

pub(crate) static ENTRY_HOMEOCHRONOUS_12681685748192342069: VariantsMap = [
    &["homeochronous"],
    &["homeochronous"],
    &["homeochronous"],
    &["homeochronous"],
];

pub(crate) static ENTRY_HOMEOCRYSTALLINE_8788492394679460167: VariantsMap = [
    &["homeocrystalline"],
    &["homeocrystalline"],
    &["homeocrystalline"],
    &["homeocrystalline"],
];

pub(crate) static ENTRY_HOMEOGENIC_4885190725568612904: VariantsMap = [
    &["homeogenic"],
    &["homeogenic"],
    &["homeogenic"],
    &["homeogenic"],
];

pub(crate) static ENTRY_HOMEOGENOUS_7245049588807987009: VariantsMap = [
    &["homeogenous"],
    &["homeogenous"],
    &["homeogenous"],
    &["homeogenous"],
];

pub(crate) static ENTRY_HOMEOID_13376838327554243707: VariantsMap =
    [&["homeoid"], &["homeoid"], &["homeoid"], &["homeoid"]];

pub(crate) static ENTRY_HOMEOKINESIS_1983100426040447559: VariantsMap = [
    &["homeokinesis"],
    &["homeokinesis"],
    &["homeokinesis"],
    &["homeokinesis"],
];

pub(crate) static ENTRY_HOMEOMERIC_15410476051343199567: VariantsMap = [
    &["homeomeric"],
    &["homeomeric"],
    &["homeomeric"],
    &["homeomeric"],
];

pub(crate) static ENTRY_HOMEOMERIES_15566208689977406588: VariantsMap = [
    &["homeomeries"],
    &["homeomeries"],
    &["homeomeries"],
    &["homeomeries"],
];

pub(crate) static ENTRY_HOMEOMEROUS_11515808442666977794: VariantsMap = [
    &["homeomerous"],
    &["homeomerous"],
    &["homeomerous"],
    &["homeomerous"],
];

pub(crate) static ENTRY_HOMEOMERY_8506899789125124263: VariantsMap = [
    &["homeomery"],
    &["homeomery"],
    &["homeomery"],
    &["homeomery"],
];

pub(crate) static ENTRY_HOMEOMORPHIC_16493293489759340224: VariantsMap = [
    &["homeomorphic"],
    &["homeomorphic"],
    &["homeomorphic"],
    &["homeomorphic"],
];

pub(crate) static ENTRY_HOMEOMORPHIES_7511914822948646959: VariantsMap = [
    &["homeomorphies"],
    &["homeomorphies"],
    &["homeomorphies"],
    &["homeomorphies"],
];

pub(crate) static ENTRY_HOMEOMORPHOUS_14653498815981894166: VariantsMap = [
    &["homeomorphous"],
    &["homeomorphous"],
    &["homeomorphous"],
    &["homeomorphous"],
];

pub(crate) static ENTRY_HOMEOMORPHS_15699536692310041526: VariantsMap = [
    &["homeomorphs"],
    &["homeomorphs"],
    &["homeomorphs"],
    &["homeomorphs"],
];

pub(crate) static ENTRY_HOMEOMORPHY_7278817926527493376: VariantsMap = [
    &["homeomorphy"],
    &["homeomorphy"],
    &["homeomorphy"],
    &["homeomorphy"],
];

pub(crate) static ENTRY_HOMEOMORPH_1041802269253692998: VariantsMap = [
    &["homeomorph"],
    &["homeomorph"],
    &["homeomorph"],
    &["homeomorph"],
];

pub(crate) static ENTRY_HOMEOPATHICALLIER_17068058788005394590: VariantsMap = [
    &["homeopathicallier"],
    &["homeopathicallier"],
    &["homeopathicallier"],
    &["homeopathicallier"],
];

pub(crate) static ENTRY_HOMEOPATHICALLIEST_2245363706876703938: VariantsMap = [
    &["homeopathicalliest"],
    &["homeopathicalliest"],
    &["homeopathicalliest"],
    &["homeopathicalliest"],
];

pub(crate) static ENTRY_HOMEOPATHICALLY_9973356241490765591: VariantsMap = [
    &["homeopathically"],
    &["homeopathically"],
    &["homeopathically"],
    &["homeopathically"],
];

pub(crate) static ENTRY_HOMEOPATHICER_15560122889304365087: VariantsMap = [
    &["homeopathicer"],
    &["homeopathicer"],
    &["homeopathicer"],
    &["homeopathicer"],
];

pub(crate) static ENTRY_HOMEOPATHICEST_13516270066115997921: VariantsMap = [
    &["homeopathicest"],
    &["homeopathicest"],
    &["homeopathicest"],
    &["homeopathicest"],
];

pub(crate) static ENTRY_HOMEOPATHICIAN_13772062524104826953: VariantsMap = [
    &["homeopathician"],
    &["homeopathician"],
    &["homeopathician"],
    &["homeopathician"],
];

pub(crate) static ENTRY_HOMEOPATHICITY_14961058671927167811: VariantsMap = [
    &["homeopathicity"],
    &["homeopathicity"],
    &["homeopathicity"],
    &["homeopathicity"],
];

pub(crate) static ENTRY_HOMEOPATHIC_1676669387100956776: VariantsMap = [
    &["homeopathic"],
    &["homeopathic"],
    &["homeopathic"],
    &["homeopathic"],
];

pub(crate) static ENTRY_HOMEOPATHIES_2232350069189750480: VariantsMap = [
    &["homeopathies"],
    &["homeopathies"],
    &["homeopathies"],
    &["homeopathies"],
];

pub(crate) static ENTRY_HOMEOPATHISTS_9064143144281892418: VariantsMap = [
    &["homeopathists"],
    &["homeopathists"],
    &["homeopathists"],
    &["homeopathists"],
];

pub(crate) static ENTRY_HOMEOPATHIST_2303562841958448149: VariantsMap = [
    &["homeopathist"],
    &["homeopathist"],
    &["homeopathist"],
    &["homeopathist"],
];

pub(crate) static ENTRY_HOMEOPATHS_4695543130932217571: VariantsMap = [
    &["homeopaths"],
    &["homeopaths"],
    &["homeopaths"],
    &["homeopaths"],
];

pub(crate) static ENTRY_HOMEOPATHY_72053453141065048: VariantsMap = [
    &["homeopathy"],
    &["homeopathy"],
    &["homeopathy"],
    &["homeopathy"],
];

pub(crate) static ENTRY_HOMEOPATH_5229181903591905312: VariantsMap = [
    &["homeopath"],
    &["homeopath"],
    &["homeopath"],
    &["homeopath"],
];

pub(crate) static ENTRY_HOMEOPHONY_18292965130704485386: VariantsMap = [
    &["homeophony"],
    &["homeophony"],
    &["homeophony"],
    &["homeophony"],
];

pub(crate) static ENTRY_HOMEOPLASIA_2298070151804770749: VariantsMap = [
    &["homeoplasia"],
    &["homeoplasia"],
    &["homeoplasia"],
    &["homeoplasia"],
];

pub(crate) static ENTRY_HOMEOPLASTIC_9441091798059156924: VariantsMap = [
    &["homeoplastic"],
    &["homeoplastic"],
    &["homeoplastic"],
    &["homeoplastic"],
];

pub(crate) static ENTRY_HOMEOPLASY_9267348127459854811: VariantsMap = [
    &["homeoplasy"],
    &["homeoplasy"],
    &["homeoplasy"],
    &["homeoplasy"],
];

pub(crate) static ENTRY_HOMEOPOLAR_14830052284176516344: VariantsMap = [
    &["homeopolar"],
    &["homeopolar"],
    &["homeopolar"],
    &["homeopolar"],
];

pub(crate) static ENTRY_HOMEOSES_11737725868417290715: VariantsMap =
    [&["homeoses"], &["homeoses"], &["homeoses"], &["homeoses"]];

pub(crate) static ENTRY_HOMEOSIS_810436539877800798: VariantsMap =
    [&["homeosis"], &["homeosis"], &["homeosis"], &["homeosis"]];

pub(crate) static ENTRY_HOMEOSTASES_16422707729244431228: VariantsMap = [
    &["homeostases"],
    &["homeostases"],
    &["homeostases"],
    &["homeostases"],
];

pub(crate) static ENTRY_HOMEOSTASIS_14104730469321046574: VariantsMap = [
    &["homeostasis"],
    &["homeostasis"],
    &["homeostasis"],
    &["homeostasis"],
];

pub(crate) static ENTRY_HOMEOSTATIC_16235185197438287529: VariantsMap = [
    &["homeostatic"],
    &["homeostatic"],
    &["homeostatic"],
    &["homeostatic"],
];

pub(crate) static ENTRY_HOMEOTELEUTONS_1760360029803513450: VariantsMap = [
    &["homeoteleutons"],
    &["homeoteleutons"],
    &["homeoteleutons"],
    &["homeoteleutons"],
];

pub(crate) static ENTRY_HOMEOTELEUTON_1150276415755322067: VariantsMap = [
    &["homeoteleuton"],
    &["homeoteleuton"],
    &["homeoteleuton"],
    &["homeoteleuton"],
];

pub(crate) static ENTRY_HOMEOTHERMAL_13603267069493942420: VariantsMap = [
    &["homeothermal"],
    &["homeothermal"],
    &["homeothermal"],
    &["homeothermal"],
];

pub(crate) static ENTRY_HOMEOTHERMIC_12410028191564372933: VariantsMap = [
    &["homeothermic"],
    &["homeothermic"],
    &["homeothermic"],
    &["homeothermic"],
];

pub(crate) static ENTRY_HOMEOTHERMOUS_5728789716135532723: VariantsMap = [
    &["homeothermous"],
    &["homeothermous"],
    &["homeothermous"],
    &["homeothermous"],
];

pub(crate) static ENTRY_HOMEOTIC_17162223258171300354: VariantsMap =
    [&["homeotic"], &["homeotic"], &["homeotic"], &["homeotic"]];

pub(crate) static ENTRY_HOMEOTYPE_10903969133007650443: VariantsMap = [
    &["homeotype"],
    &["homeotype"],
    &["homeotype"],
    &["homeotype"],
];

pub(crate) static ENTRY_HOMEOTYPICAL_3199435291743240536: VariantsMap = [
    &["homeotypical"],
    &["homeotypical"],
    &["homeotypical"],
    &["homeotypical"],
];

pub(crate) static ENTRY_HOMEOTYPIC_15533990626512993512: VariantsMap = [
    &["homeotypic"],
    &["homeotypic"],
    &["homeotypic"],
    &["homeotypic"],
];

pub(crate) static ENTRY_HOMEOZOIC_12767024647166837852: VariantsMap = [
    &["homeozoic"],
    &["homeozoic"],
    &["homeozoic"],
    &["homeozoic"],
];

pub(crate) static ENTRY_HOMINIZATION_8698022690719820562: VariantsMap = [
    &["hominization"],
    &["hominisation"],
    &["hominization"],
    &["hominisation"],
];

pub(crate) static ENTRY_HOMINIZED_3408013659776791571: VariantsMap = [
    &["hominized"],
    &["hominised"],
    &["hominized"],
    &["hominised"],
];

pub(crate) static ENTRY_HOMOGENIZATIONS_17792406420314111467: VariantsMap = [
    &["homogenizations"],
    &["homogenisations"],
    &["homogenizations"],
    &["homogenisations"],
];

pub(crate) static ENTRY_HOMOGENIZATION_4287750092569292868: VariantsMap = [
    &["homogenization"],
    &["homogenisation"],
    &["homogenization"],
    &["homogenisation"],
];

pub(crate) static ENTRY_HOMOGENIZED_1883548529710793939: VariantsMap = [
    &["homogenized"],
    &["homogenised"],
    &["homogenized"],
    &["homogenised"],
];

pub(crate) static ENTRY_HOMOGENIZERS_5505783736797997695: VariantsMap = [
    &["homogenizers"],
    &["homogenisers"],
    &["homogenizers"],
    &["homogenisers"],
];

pub(crate) static ENTRY_HOMOGENIZER_15311593186707876916: VariantsMap = [
    &["homogenizer"],
    &["homogeniser"],
    &["homogenizer"],
    &["homogeniser"],
];

pub(crate) static ENTRY_HOMOGENIZES_13436650567116217979: VariantsMap = [
    &["homogenizes"],
    &["homogenises"],
    &["homogenizes"],
    &["homogenises"],
];

pub(crate) static ENTRY_HOMOGENIZE_2370634469192321173: VariantsMap = [
    &["homogenize"],
    &["homogenise"],
    &["homogenize"],
    &["homogenise"],
];

pub(crate) static ENTRY_HOMOGENIZING_12711102365188412108: VariantsMap = [
    &["homogenizing"],
    &["homogenising"],
    &["homogenizing"],
    &["homogenising"],
];

pub(crate) static ENTRY_HOMOLOGIZATION_16886532379242854540: VariantsMap = [
    &["homologization"],
    &["homologisation"],
    &["homologization"],
    &["homologisation"],
];

pub(crate) static ENTRY_HOMOLOGIZED_14063866540046840119: VariantsMap = [
    &["homologized"],
    &["homologised"],
    &["homologized"],
    &["homologised"],
];

pub(crate) static ENTRY_HOMOLOGIZERS_2389120733785680363: VariantsMap = [
    &["homologizers"],
    &["homologisers"],
    &["homologizers"],
    &["homologisers"],
];

pub(crate) static ENTRY_HOMOLOGIZER_9348541694261802707: VariantsMap = [
    &["homologizer"],
    &["homologiser"],
    &["homologizer"],
    &["homologiser"],
];

pub(crate) static ENTRY_HOMOLOGIZES_14027542917284050646: VariantsMap = [
    &["homologizes"],
    &["homologises"],
    &["homologizes"],
    &["homologises"],
];

pub(crate) static ENTRY_HOMOLOGIZE_11175870910521621561: VariantsMap = [
    &["homologize"],
    &["homologise"],
    &["homologize"],
    &["homologise"],
];

pub(crate) static ENTRY_HOMOLOGIZING_11333343336294935163: VariantsMap = [
    &["homologizing"],
    &["homologising"],
    &["homologizing"],
    &["homologising"],
];

pub(crate) static ENTRY_HOMOLOGUES_16835140375228019862: VariantsMap = [
    &["homologues"],
    &["homologues"],
    &["homologues"],
    &["homologues"],
];

pub(crate) static ENTRY_HOMOLOGUE_3154994007582088030: VariantsMap = [
    &["homologue"],
    &["homologue"],
    &["homologue"],
    &["homologue"],
];

pub(crate) static ENTRY_HONORABILITIES_9405068382369759044: VariantsMap = [
    &["honorabilities"],
    &["honourabilities"],
    &["honourabilities"],
    &["honourabilities"],
];

pub(crate) static ENTRY_HONORABILITY_12035052376298826958: VariantsMap = [
    &["honorability"],
    &["honourability"],
    &["honourability"],
    &["honourability"],
];

pub(crate) static ENTRY_HONORABLENESSES_9431133268909004141: VariantsMap = [
    &["honorablenesses"],
    &["honourablenesses"],
    &["honourablenesses"],
    &["honourablenesses"],
];

pub(crate) static ENTRY_HONORABLENESS_15173649896519914801: VariantsMap = [
    &["honorableness"],
    &["honourableness"],
    &["honourableness"],
    &["honourableness"],
];

pub(crate) static ENTRY_HONORABLER_7881684582071414508: VariantsMap = [
    &["honorabler"],
    &["honourabler"],
    &["honourabler"],
    &["honourabler"],
];

pub(crate) static ENTRY_HONORABLESHIPS_10171277772968959220: VariantsMap = [
    &["honorableships"],
    &["honourableships"],
    &["honourableships"],
    &["honourableships"],
];

pub(crate) static ENTRY_HONORABLESHIP_541846460375714678: VariantsMap = [
    &["honorableship"],
    &["honourableship"],
    &["honourableship"],
    &["honourableship"],
];

pub(crate) static ENTRY_HONORABLEST_11032014460277721019: VariantsMap = [
    &["honorablest"],
    &["honourablest"],
    &["honourablest"],
    &["honourablest"],
];

pub(crate) static ENTRY_HONORABLES_1953687291526751468: VariantsMap = [
    &["honorables"],
    &["honourables"],
    &["honourables"],
    &["honourables"],
];

pub(crate) static ENTRY_HONORABLE_5267590017508289195: VariantsMap = [
    &["honorable"],
    &["honourable"],
    &["honourable"],
    &["honourable"],
];

pub(crate) static ENTRY_HONORABLIER_6189546938867907020: VariantsMap = [
    &["honorablier"],
    &["honourablier"],
    &["honourablier"],
    &["honourablier"],
];

pub(crate) static ENTRY_HONORABLIEST_12608350415220368236: VariantsMap = [
    &["honorabliest"],
    &["honourabliest"],
    &["honourabliest"],
    &["honourabliest"],
];

pub(crate) static ENTRY_HONORABLIES_15207939272996415718: VariantsMap = [
    &["honorablies"],
    &["honourablies"],
    &["honourablies"],
    &["honourablies"],
];

pub(crate) static ENTRY_HONORABLY_12699768841379405701: VariantsMap = [
    &["honorably"],
    &["honourably"],
    &["honourably"],
    &["honourably"],
];

pub(crate) static ENTRY_HONORED_11309103293723691238: VariantsMap =
    [&["honored"], &["honoured"], &["honoured"], &["honoured"]];

pub(crate) static ENTRY_HONOREES_7470068483735697619: VariantsMap = [
    &["honorees"],
    &["honourees"],
    &["honourees"],
    &["honourees"],
];

pub(crate) static ENTRY_HONOREE_17606335168000129607: VariantsMap =
    [&["honoree"], &["honouree"], &["honouree"], &["honouree"]];

pub(crate) static ENTRY_HONORERS_3170682135201203116: VariantsMap = [
    &["honorers"],
    &["honourers"],
    &["honourers"],
    &["honourers"],
];

pub(crate) static ENTRY_HONORER_11221021715751894613: VariantsMap =
    [&["honorer"], &["honourer"], &["honourer"], &["honourer"]];

pub(crate) static ENTRY_HONORING_8233222848637053479: VariantsMap = [
    &["honoring"],
    &["honouring"],
    &["honouring"],
    &["honouring"],
];

pub(crate) static ENTRY_HONORLESSER_15516332619067141447: VariantsMap = [
    &["honorlesser"],
    &["honourlesser"],
    &["honourlesser"],
    &["honourlesser"],
];

pub(crate) static ENTRY_HONORLESSEST_13284756641208288383: VariantsMap = [
    &["honorlessest"],
    &["honourlessest"],
    &["honourlessest"],
    &["honourlessest"],
];

pub(crate) static ENTRY_HONORLESSES_17714568716629301214: VariantsMap = [
    &["honorlesses"],
    &["honourlesses"],
    &["honourlesses"],
    &["honourlesses"],
];

pub(crate) static ENTRY_HONORLESS_5078983171515487979: VariantsMap = [
    &["honorless"],
    &["honourless"],
    &["honourless"],
    &["honourless"],
];

pub(crate) static ENTRY_HONORS_11917319892138194792: VariantsMap =
    [&["honors"], &["honours"], &["honours"], &["honours"]];

pub(crate) static ENTRY_HONOR_15399646154796433816: VariantsMap =
    [&["honor"], &["honour"], &["honour"], &["honour"]];

pub(crate) static ENTRY_HOODLUMIZES_4118588160754440363: VariantsMap = [
    &["hoodlumizes"],
    &["hoodlumises"],
    &["hoodlumizes"],
    &["hoodlumises"],
];

pub(crate) static ENTRY_HOODLUMIZE_6984933085091962905: VariantsMap = [
    &["hoodlumize"],
    &["hoodlumise"],
    &["hoodlumize"],
    &["hoodlumise"],
];

pub(crate) static ENTRY_HOOLIGANIZES_8800539654166191774: VariantsMap = [
    &["hooliganizes"],
    &["hooliganises"],
    &["hooliganizes"],
    &["hooliganises"],
];

pub(crate) static ENTRY_HOOLIGANIZE_12500916511980195978: VariantsMap = [
    &["hooliganize"],
    &["hooliganise"],
    &["hooliganize"],
    &["hooliganise"],
];

pub(crate) static ENTRY_HOOSIERIZES_1886781026111147436: VariantsMap = [
    &["hoosierizes"],
    &["hoosierises"],
    &["hoosierizes"],
    &["hoosierises"],
];

pub(crate) static ENTRY_HOOSIERIZE_14083736118237757739: VariantsMap = [
    &["hoosierize"],
    &["hoosierise"],
    &["hoosierize"],
    &["hoosierise"],
];

pub(crate) static ENTRY_HOOVERIZES_6952740409766921744: VariantsMap = [
    &["hooverizes"],
    &["hooverises"],
    &["hooverizes"],
    &["hooverises"],
];

pub(crate) static ENTRY_HOOVERIZE_14070528923375609155: VariantsMap = [
    &["hooverize"],
    &["hooverise"],
    &["hooverize"],
    &["hooverise"],
];

pub(crate) static ENTRY_HORE_3390393391903925430: VariantsMap =
    [&["hore"], &["horae"], &["horae"], &["horae"]];

pub(crate) static ENTRY_HORIZONTALIZATIONS_14542806755819602636: VariantsMap = [
    &["horizontalizations"],
    &["horizontalisations"],
    &["horizontalizations"],
    &["horizontalisations"],
];

pub(crate) static ENTRY_HORIZONTALIZATION_1854951276399796821: VariantsMap = [
    &["horizontalization"],
    &["horizontalisation"],
    &["horizontalization"],
    &["horizontalisation"],
];

pub(crate) static ENTRY_HORIZONTALIZES_480288781636427917: VariantsMap = [
    &["horizontalizes"],
    &["horizontalises"],
    &["horizontalizes"],
    &["horizontalises"],
];

pub(crate) static ENTRY_HORIZONTALIZE_4380057593065562287: VariantsMap = [
    &["horizontalize"],
    &["horizontalise"],
    &["horizontalize"],
    &["horizontalise"],
];

pub(crate) static ENTRY_HORMONIZES_4194755045782431350: VariantsMap = [
    &["hormonizes"],
    &["hormonises"],
    &["hormonizes"],
    &["hormonises"],
];

pub(crate) static ENTRY_HORMONIZE_13767090928132589394: VariantsMap = [
    &["hormonize"],
    &["hormonise"],
    &["hormonize"],
    &["hormonise"],
];

pub(crate) static ENTRY_HORRORIZES_18387092614244896707: VariantsMap = [
    &["horrorizes"],
    &["horrorises"],
    &["horrorizes"],
    &["horrorises"],
];

pub(crate) static ENTRY_HORRORIZE_2806837544429029157: VariantsMap = [
    &["horrorize"],
    &["horrorise"],
    &["horrorize"],
    &["horrorise"],
];

pub(crate) static ENTRY_HOSPITALIZATIONS_4719313081670515361: VariantsMap = [
    &["hospitalizations"],
    &["hospitalisations"],
    &["hospitalizations"],
    &["hospitalisations"],
];

pub(crate) static ENTRY_HOSPITALIZATION_5040452602598774204: VariantsMap = [
    &["hospitalization"],
    &["hospitalisation"],
    &["hospitalization"],
    &["hospitalisation"],
];

pub(crate) static ENTRY_HOSPITALIZED_7758414069821260041: VariantsMap = [
    &["hospitalized"],
    &["hospitalised"],
    &["hospitalized"],
    &["hospitalised"],
];

pub(crate) static ENTRY_HOSPITALIZES_5958151208692605706: VariantsMap = [
    &["hospitalizes"],
    &["hospitalises"],
    &["hospitalizes"],
    &["hospitalises"],
];

pub(crate) static ENTRY_HOSPITALIZE_13160741346544894903: VariantsMap = [
    &["hospitalize"],
    &["hospitalise"],
    &["hospitalize"],
    &["hospitalise"],
];

pub(crate) static ENTRY_HOSPITALIZING_10285779206835646544: VariantsMap = [
    &["hospitalizing"],
    &["hospitalising"],
    &["hospitalizing"],
    &["hospitalising"],
];

pub(crate) static ENTRY_HOSTILIZES_13937088386052302757: VariantsMap = [
    &["hostilizes"],
    &["hostilises"],
    &["hostilizes"],
    &["hostilises"],
];

pub(crate) static ENTRY_HOSTILIZE_14961635697224585108: VariantsMap = [
    &["hostilize"],
    &["hostilise"],
    &["hostilize"],
    &["hostilise"],
];

pub(crate) static ENTRY_HOTELIZATIONS_8489202423610554111: VariantsMap = [
    &["hotelizations"],
    &["hotelisations"],
    &["hotelizations"],
    &["hotelisations"],
];

pub(crate) static ENTRY_HOTELIZATION_2621800487749172229: VariantsMap = [
    &["hotelization"],
    &["hotelisation"],
    &["hotelization"],
    &["hotelisation"],
];

pub(crate) static ENTRY_HOTELIZES_16329539079245052960: VariantsMap = [
    &["hotelizes"],
    &["hotelises"],
    &["hotelizes"],
    &["hotelises"],
];

pub(crate) static ENTRY_HOTELIZE_16562047620597541376: VariantsMap =
    [&["hotelize"], &["hotelise"], &["hotelize"], &["hotelise"]];

pub(crate) static ENTRY_HOUSELED_16972580900287546401: VariantsMap = [
    &["houseled"],
    &["houselled"],
    &["houselled"],
    &["houselled"],
];

pub(crate) static ENTRY_HOUSELINGS_4554080295903689036: VariantsMap = [
    &["houselings"],
    &["housellings"],
    &["housellings"],
    &["housellings"],
];

pub(crate) static ENTRY_HOUSELING_14185027689441346891: VariantsMap = [
    &["houseling"],
    &["houselling"],
    &["houselling"],
    &["houselling"],
];

pub(crate) static ENTRY_HOVELED_2287662750830577737: VariantsMap =
    [&["hoveled"], &["hovelled"], &["hovelled"], &["hovelled"]];

pub(crate) static ENTRY_HOVELERS_8325626138781872872: VariantsMap = [
    &["hovelers"],
    &["hovellers"],
    &["hovellers"],
    &["hovellers"],
];

pub(crate) static ENTRY_HOVELER_14601501376595739029: VariantsMap =
    [&["hoveler"], &["hoveller"], &["hoveller"], &["hoveller"]];

pub(crate) static ENTRY_HOVELING_7608925720102783878: VariantsMap = [
    &["hoveling"],
    &["hovelling"],
    &["hovelling"],
    &["hovelling"],
];

pub(crate) static ENTRY_HUCKSTERIZES_11602253187655515741: VariantsMap = [
    &["hucksterizes"],
    &["hucksterises"],
    &["hucksterizes"],
    &["hucksterises"],
];

pub(crate) static ENTRY_HUCKSTERIZE_13066281932873001441: VariantsMap = [
    &["hucksterize"],
    &["hucksterise"],
    &["hucksterize"],
    &["hucksterise"],
];

pub(crate) static ENTRY_HUER_10747049949003885908: VariantsMap =
    [&["huer"], &["hure"], &["hure"], &["hure"]];

pub(crate) static ENTRY_HUMANITARIANIZES_14035572334353916626: VariantsMap = [
    &["humanitarianizes"],
    &["humanitarianises"],
    &["humanitarianizes"],
    &["humanitarianises"],
];

pub(crate) static ENTRY_HUMANITARIANIZE_15353412717570230575: VariantsMap = [
    &["humanitarianize"],
    &["humanitarianise"],
    &["humanitarianize"],
    &["humanitarianise"],
];

pub(crate) static ENTRY_HUMANIZATIONS_15582377768763436651: VariantsMap = [
    &["humanizations"],
    &["humanisations"],
    &["humanizations"],
    &["humanisations"],
];

pub(crate) static ENTRY_HUMANIZATION_15705527931514057427: VariantsMap = [
    &["humanization"],
    &["humanisation"],
    &["humanization"],
    &["humanisation"],
];

pub(crate) static ENTRY_HUMANIZED_6176873167717917443: VariantsMap = [
    &["humanized"],
    &["humanised"],
    &["humanized"],
    &["humanised"],
];

pub(crate) static ENTRY_HUMANIZERS_8923077805056759577: VariantsMap = [
    &["humanizers"],
    &["humanisers"],
    &["humanizers"],
    &["humanisers"],
];

pub(crate) static ENTRY_HUMANIZER_13992683254986422169: VariantsMap = [
    &["humanizer"],
    &["humaniser"],
    &["humanizer"],
    &["humaniser"],
];

pub(crate) static ENTRY_HUMANIZES_799641267605433339: VariantsMap = [
    &["humanizes"],
    &["humanises"],
    &["humanizes"],
    &["humanises"],
];

pub(crate) static ENTRY_HUMANIZE_12698260631072657271: VariantsMap =
    [&["humanize"], &["humanise"], &["humanize"], &["humanise"]];

pub(crate) static ENTRY_HUMANIZING_11718797637513438180: VariantsMap = [
    &["humanizing"],
    &["humanising"],
    &["humanizing"],
    &["humanising"],
];

pub(crate) static ENTRY_HUMORAL_9922553401713391974: VariantsMap =
    [&["humoral"], &["humoral"], &["humoral"], &["humoral"]];

pub(crate) static ENTRY_HUMORED_10786336881623276233: VariantsMap =
    [&["humored"], &["humoured"], &["humoured"], &["humoured"]];

pub(crate) static ENTRY_HUMORERS_9970467724151930844: VariantsMap = [
    &["humorers"],
    &["humourers"],
    &["humourers"],
    &["humourers"],
];

pub(crate) static ENTRY_HUMORER_7006391541848572245: VariantsMap =
    [&["humorer"], &["humourer"], &["humourer"], &["humourer"]];

pub(crate) static ENTRY_HUMORFUL_9341394925730313409: VariantsMap = [
    &["humorful"],
    &["humourful"],
    &["humourful"],
    &["humourful"],
];

pub(crate) static ENTRY_HUMORING_11392688200375000188: VariantsMap = [
    &["humoring"],
    &["humouring"],
    &["humouring"],
    &["humouring"],
];

pub(crate) static ENTRY_HUMORIZES_2488290093371657967: VariantsMap = [
    &["humorizes"],
    &["humorises"],
    &["humorizes"],
    &["humorises"],
];

pub(crate) static ENTRY_HUMORIZE_13039467990673202648: VariantsMap =
    [&["humorize"], &["humorise"], &["humorize"], &["humorise"]];

pub(crate) static ENTRY_HUMORLESSER_5799000569275879062: VariantsMap = [
    &["humorlesser"],
    &["humourlesser"],
    &["humourlesser"],
    &["humourlesser"],
];

pub(crate) static ENTRY_HUMORLESSEST_7303152498734358734: VariantsMap = [
    &["humorlessest"],
    &["humourlessest"],
    &["humourlessest"],
    &["humourlessest"],
];

pub(crate) static ENTRY_HUMORLESSES_1813588940197371446: VariantsMap = [
    &["humorlesses"],
    &["humourlesses"],
    &["humourlesses"],
    &["humourlesses"],
];

pub(crate) static ENTRY_HUMORLESSNESSES_14163478094240283512: VariantsMap = [
    &["humorlessnesses"],
    &["humourlessnesses"],
    &["humourlessnesses"],
    &["humourlessnesses"],
];

pub(crate) static ENTRY_HUMORLESSNESS_15579411466297936763: VariantsMap = [
    &["humorlessness"],
    &["humourlessness"],
    &["humourlessness"],
    &["humourlessness"],
];

pub(crate) static ENTRY_HUMORLESS_14939288701032885532: VariantsMap = [
    &["humorless"],
    &["humourless"],
    &["humourless"],
    &["humourless"],
];

pub(crate) static ENTRY_HUMORSOMENESS_15432803237613045742: VariantsMap = [
    &["humorsomeness"],
    &["humoursomeness"],
    &["humoursomeness"],
    &["humoursomeness"],
];

pub(crate) static ENTRY_HUMORSOME_10596220543381321499: VariantsMap = [
    &["humorsome"],
    &["humoursome"],
    &["humoursome"],
    &["humoursome"],
];

pub(crate) static ENTRY_HUMORS_3898460867445362619: VariantsMap =
    [&["humors"], &["humours"], &["humours"], &["humours"]];

pub(crate) static ENTRY_HUMOR_3738238959900212968: VariantsMap =
    [&["humor"], &["humour"], &["humour"], &["humour"]];

pub(crate) static ENTRY_HURRAHS_1533032267235892768: VariantsMap =
    [&["hurrahs"], &["hurrahs"], &["hurrahs"], &["hurrahs"]];

pub(crate) static ENTRY_HURRAH_8390607640434840198: VariantsMap =
    [&["hurrah"], &["hurrah"], &["hurrah"], &["hurrah"]];

pub(crate) static ENTRY_HURRICANIZES_14709272545639239012: VariantsMap = [
    &["hurricanizes"],
    &["hurricanises"],
    &["hurricanizes"],
    &["hurricanises"],
];

pub(crate) static ENTRY_HURRICANIZE_15900593187601705032: VariantsMap = [
    &["hurricanize"],
    &["hurricanise"],
    &["hurricanize"],
    &["hurricanise"],
];

pub(crate) static ENTRY_HYALINIZATIONS_17682006298999670485: VariantsMap = [
    &["hyalinizations"],
    &["hyalinisations"],
    &["hyalinizations"],
    &["hyalinisations"],
];

pub(crate) static ENTRY_HYALINIZATION_16929766893950103561: VariantsMap = [
    &["hyalinization"],
    &["hyalinisation"],
    &["hyalinization"],
    &["hyalinisation"],
];

pub(crate) static ENTRY_HYALINIZED_1966392632245301360: VariantsMap = [
    &["hyalinized"],
    &["hyalinised"],
    &["hyalinized"],
    &["hyalinised"],
];

pub(crate) static ENTRY_HYALINIZES_13813485450023194701: VariantsMap = [
    &["hyalinizes"],
    &["hyalinises"],
    &["hyalinizes"],
    &["hyalinises"],
];

pub(crate) static ENTRY_HYALINIZE_10280283688023876531: VariantsMap = [
    &["hyalinize"],
    &["hyalinise"],
    &["hyalinize"],
    &["hyalinise"],
];

pub(crate) static ENTRY_HYALINIZING_10561711059507010773: VariantsMap = [
    &["hyalinizing"],
    &["hyalinising"],
    &["hyalinizing"],
    &["hyalinising"],
];

pub(crate) static ENTRY_HYBRIDIZABLER_14819123538336949488: VariantsMap = [
    &["hybridizabler"],
    &["hybridisabler"],
    &["hybridizabler"],
    &["hybridisabler"],
];

pub(crate) static ENTRY_HYBRIDIZABLEST_10233706175812001084: VariantsMap = [
    &["hybridizablest"],
    &["hybridisablest"],
    &["hybridizablest"],
    &["hybridisablest"],
];

pub(crate) static ENTRY_HYBRIDIZABLES_17797450459897065062: VariantsMap = [
    &["hybridizables"],
    &["hybridisables"],
    &["hybridizables"],
    &["hybridisables"],
];

pub(crate) static ENTRY_HYBRIDIZABLE_15539830790317538897: VariantsMap = [
    &["hybridizable"],
    &["hybridisable"],
    &["hybridizable"],
    &["hybridisable"],
];

pub(crate) static ENTRY_HYBRIDIZATIONS_10283609484469810765: VariantsMap = [
    &["hybridizations"],
    &["hybridisations"],
    &["hybridizations"],
    &["hybridisations"],
];

pub(crate) static ENTRY_HYBRIDIZATION_4332178131605916168: VariantsMap = [
    &["hybridization"],
    &["hybridisation"],
    &["hybridization"],
    &["hybridisation"],
];

pub(crate) static ENTRY_HYBRIDIZED_7034214956457758537: VariantsMap = [
    &["hybridized"],
    &["hybridised"],
    &["hybridized"],
    &["hybridised"],
];

pub(crate) static ENTRY_HYBRIDIZERS_7357049388164342672: VariantsMap = [
    &["hybridizers"],
    &["hybridisers"],
    &["hybridizers"],
    &["hybridisers"],
];

pub(crate) static ENTRY_HYBRIDIZER_2748552798742818278: VariantsMap = [
    &["hybridizer"],
    &["hybridiser"],
    &["hybridizer"],
    &["hybridiser"],
];

pub(crate) static ENTRY_HYBRIDIZES_5507688108918127290: VariantsMap = [
    &["hybridizes"],
    &["hybridises"],
    &["hybridizes"],
    &["hybridises"],
];

pub(crate) static ENTRY_HYBRIDIZE_8248491254784836054: VariantsMap = [
    &["hybridize"],
    &["hybridise"],
    &["hybridize"],
    &["hybridise"],
];

pub(crate) static ENTRY_HYBRIDIZING_1851952307355033640: VariantsMap = [
    &["hybridizing"],
    &["hybridising"],
    &["hybridizing"],
    &["hybridising"],
];

pub(crate) static ENTRY_HYDREMIAS_15535936146594468577: VariantsMap = [
    &["hydremias"],
    &["hydraemias"],
    &["hydraemias"],
    &["hydraemias"],
];

pub(crate) static ENTRY_HYDREMIA_7034931649899021452: VariantsMap = [
    &["hydremia"],
    &["hydraemia"],
    &["hydraemia"],
    &["hydraemia"],
];

pub(crate) static ENTRY_HYDREMIC_14370893596020089811: VariantsMap = [
    &["hydremic"],
    &["hydraemic"],
    &["hydraemic"],
    &["hydraemic"],
];

pub(crate) static ENTRY_HYDROCELE_12890782663387310276: VariantsMap = [
    &["hydrocele"],
    &["hydrocoele"],
    &["hydrocoele"],
    &["hydrocoele"],
];

pub(crate) static ENTRY_HYDROGENIZATIONS_9839501985127249002: VariantsMap = [
    &["hydrogenizations"],
    &["hydrogenisations"],
    &["hydrogenizations"],
    &["hydrogenisations"],
];

pub(crate) static ENTRY_HYDROGENIZATION_6861190364962876775: VariantsMap = [
    &["hydrogenization"],
    &["hydrogenisation"],
    &["hydrogenization"],
    &["hydrogenisation"],
];

pub(crate) static ENTRY_HYDROGENIZED_14561092317743851347: VariantsMap = [
    &["hydrogenized"],
    &["hydrogenised"],
    &["hydrogenized"],
    &["hydrogenised"],
];

pub(crate) static ENTRY_HYDROGENIZES_13310822950999698482: VariantsMap = [
    &["hydrogenizes"],
    &["hydrogenises"],
    &["hydrogenizes"],
    &["hydrogenises"],
];

pub(crate) static ENTRY_HYDROGENIZE_8896845372338892854: VariantsMap = [
    &["hydrogenize"],
    &["hydrogenise"],
    &["hydrogenize"],
    &["hydrogenise"],
];

pub(crate) static ENTRY_HYDROGENIZING_658446219570799178: VariantsMap = [
    &["hydrogenizing"],
    &["hydrogenising"],
    &["hydrogenizing"],
    &["hydrogenising"],
];

pub(crate) static ENTRY_HYDROLIZE_5556407722330866199: VariantsMap = [
    &["hydrolize"],
    &["hydrolise"],
    &["hydrolize"],
    &["hydrolise"],
];

pub(crate) static ENTRY_HYDROLYZABLER_5507333977830072797: VariantsMap = [
    &["hydrolyzabler"],
    &["hydrolysabler"],
    &["hydrolyzabler"],
    &["hydrolysabler"],
];

pub(crate) static ENTRY_HYDROLYZABLEST_8915579809275139364: VariantsMap = [
    &["hydrolyzablest"],
    &["hydrolysablest"],
    &["hydrolyzablest"],
    &["hydrolysablest"],
];

pub(crate) static ENTRY_HYDROLYZABLES_5561576541070137183: VariantsMap = [
    &["hydrolyzables"],
    &["hydrolysables"],
    &["hydrolyzables"],
    &["hydrolysables"],
];

pub(crate) static ENTRY_HYDROLYZABLE_12528075959517847768: VariantsMap = [
    &["hydrolyzable"],
    &["hydrolysable"],
    &["hydrolyzable"],
    &["hydrolysable"],
];

pub(crate) static ENTRY_HYDROLYZATES_6542145074318638373: VariantsMap = [
    &["hydrolyzates"],
    &["hydrolysates"],
    &["hydrolyzates"],
    &["hydrolysates"],
];

pub(crate) static ENTRY_HYDROLYZATE_689293659933279867: VariantsMap = [
    &["hydrolyzate"],
    &["hydrolysate"],
    &["hydrolyzate"],
    &["hydrolysate"],
];

pub(crate) static ENTRY_HYDROLYZATION_1129190381404237761: VariantsMap = [
    &["hydrolyzation"],
    &["hydrolysation"],
    &["hydrolyzation"],
    &["hydrolysation"],
];

pub(crate) static ENTRY_HYDROLYZED_13508052463277306099: VariantsMap = [
    &["hydrolyzed"],
    &["hydrolysed"],
    &["hydrolyzed"],
    &["hydrolysed"],
];

pub(crate) static ENTRY_HYDROLYZER_5223552143056672994: VariantsMap = [
    &["hydrolyzer"],
    &["hydrolyser"],
    &["hydrolyzer"],
    &["hydrolyser"],
];

pub(crate) static ENTRY_HYDROLYZES_1708953578311006919: VariantsMap = [
    &["hydrolyzes"],
    &["hydrolyses"],
    &["hydrolyzes"],
    &["hydrolyses"],
];

pub(crate) static ENTRY_HYDROLYZE_14101715282298871514: VariantsMap = [
    &["hydrolyze"],
    &["hydrolyse"],
    &["hydrolyze"],
    &["hydrolyse"],
];

pub(crate) static ENTRY_HYDROLYZING_18045157705495274283: VariantsMap = [
    &["hydrolyzing"],
    &["hydrolysing"],
    &["hydrolyzing"],
    &["hydrolysing"],
];

pub(crate) static ENTRY_HYDRORRHEA_6093314805700249034: VariantsMap = [
    &["hydrorrhea"],
    &["hydrorrhoea"],
    &["hydrorrhoea"],
    &["hydrorrhoea"],
];

pub(crate) static ENTRY_HYDROXYLIZATIONS_2049257758926080378: VariantsMap = [
    &["hydroxylizations"],
    &["hydroxylisations"],
    &["hydroxylizations"],
    &["hydroxylisations"],
];

pub(crate) static ENTRY_HYDROXYLIZATION_13321261281242119975: VariantsMap = [
    &["hydroxylization"],
    &["hydroxylisation"],
    &["hydroxylization"],
    &["hydroxylisation"],
];

pub(crate) static ENTRY_HYDROXYLIZES_11944972790326564810: VariantsMap = [
    &["hydroxylizes"],
    &["hydroxylises"],
    &["hydroxylizes"],
    &["hydroxylises"],
];

pub(crate) static ENTRY_HYDROXYLIZE_6840189330452427589: VariantsMap = [
    &["hydroxylize"],
    &["hydroxylise"],
    &["hydroxylize"],
    &["hydroxylise"],
];

pub(crate) static ENTRY_HYENIC_7100169606816276173: VariantsMap =
    [&["hyenic"], &["hyaenic"], &["hyaenic"], &["hyaenic"]];

pub(crate) static ENTRY_HYGIENIZATIONS_12897154916673520999: VariantsMap = [
    &["hygienizations"],
    &["hygienisations"],
    &["hygienizations"],
    &["hygienisations"],
];

pub(crate) static ENTRY_HYGIENIZATION_1338761212726482109: VariantsMap = [
    &["hygienization"],
    &["hygienisation"],
    &["hygienization"],
    &["hygienisation"],
];

pub(crate) static ENTRY_HYGIENIZES_957059778120364333: VariantsMap = [
    &["hygienizes"],
    &["hygienises"],
    &["hygienizes"],
    &["hygienises"],
];

pub(crate) static ENTRY_HYGIENIZE_8360515227989834222: VariantsMap = [
    &["hygienize"],
    &["hygienise"],
    &["hygienize"],
    &["hygienise"],
];

pub(crate) static ENTRY_HYMENEAN_15041651575315743056: VariantsMap = [
    &["hymenean"],
    &["hymenaean"],
    &["hymenaean"],
    &["hymenaean"],
];

pub(crate) static ENTRY_HYPERBOLIZED_8135053452196902615: VariantsMap = [
    &["hyperbolized"],
    &["hyperbolised"],
    &["hyperbolized"],
    &["hyperbolised"],
];

pub(crate) static ENTRY_HYPERBOLIZES_11501290385346315262: VariantsMap = [
    &["hyperbolizes"],
    &["hyperbolises"],
    &["hyperbolizes"],
    &["hyperbolises"],
];

pub(crate) static ENTRY_HYPERBOLIZE_10617131659797415639: VariantsMap = [
    &["hyperbolize"],
    &["hyperbolise"],
    &["hyperbolize"],
    &["hyperbolise"],
];

pub(crate) static ENTRY_HYPERBOLIZING_2165490899143205915: VariantsMap = [
    &["hyperbolizing"],
    &["hyperbolising"],
    &["hyperbolizing"],
    &["hyperbolising"],
];

pub(crate) static ENTRY_HYPERCALCEMIAS_5408133520899563192: VariantsMap = [
    &["hypercalcemias"],
    &["hypercalcaemias"],
    &["hypercalcaemias"],
    &["hypercalcaemias"],
];

pub(crate) static ENTRY_HYPERCALCEMIA_13843206769388452645: VariantsMap = [
    &["hypercalcemia"],
    &["hypercalcaemia"],
    &["hypercalcaemia"],
    &["hypercalcaemia"],
];

pub(crate) static ENTRY_HYPERCALCINEMIA_13976366975495435303: VariantsMap = [
    &["hypercalcinemia"],
    &["hypercalcinaemia"],
    &["hypercalcinaemia"],
    &["hypercalcinaemia"],
];

pub(crate) static ENTRY_HYPERCATHARSISES_3652483176188389035: VariantsMap = [
    &["hypercatharsises"],
    &["hypercatharses"],
    &["hypercatharses"],
    &["hypercatharses"],
];

pub(crate) static ENTRY_HYPERCHLOREMIA_17565413549481257710: VariantsMap = [
    &["hyperchloremia"],
    &["hyperchloraemia"],
    &["hyperchloraemia"],
    &["hyperchloraemia"],
];

pub(crate) static ENTRY_HYPERCHOLESTEROLEMIAS_18411903243384849460: VariantsMap = [
    &["hypercholesterolemias"],
    &["hypercholesterolaemias"],
    &["hypercholesterolaemias"],
    &["hypercholesterolaemias"],
];

pub(crate) static ENTRY_HYPERCHOLESTEROLEMIA_4754609931003278536: VariantsMap = [
    &["hypercholesterolemia"],
    &["hypercholesterolaemia"],
    &["hypercholesterolaemia"],
    &["hypercholesterolaemia"],
];

pub(crate) static ENTRY_HYPERCIVILIZATIONS_16026626403207941950: VariantsMap = [
    &["hypercivilizations"],
    &["hypercivilisations"],
    &["hypercivilizations"],
    &["hypercivilisations"],
];

pub(crate) static ENTRY_HYPERCIVILIZATION_13591435940520562735: VariantsMap = [
    &["hypercivilization"],
    &["hypercivilisation"],
    &["hypercivilization"],
    &["hypercivilisation"],
];

pub(crate) static ENTRY_HYPERCIVILIZEDS_14031306534307147011: VariantsMap = [
    &["hypercivilizeds"],
    &["hyperciviliseds"],
    &["hypercivilizeds"],
    &["hyperciviliseds"],
];

pub(crate) static ENTRY_HYPERCIVILIZED_5448923133916718271: VariantsMap = [
    &["hypercivilized"],
    &["hypercivilised"],
    &["hypercivilized"],
    &["hypercivilised"],
];

pub(crate) static ENTRY_HYPERCRITICIZED_17847050966992957591: VariantsMap = [
    &["hypercriticized"],
    &["hypercriticised"],
    &["hypercriticized"],
    &["hypercriticised"],
];

pub(crate) static ENTRY_HYPERCRITICIZES_15577646304300312864: VariantsMap = [
    &["hypercriticizes"],
    &["hypercriticises"],
    &["hypercriticizes"],
    &["hypercriticises"],
];

pub(crate) static ENTRY_HYPERCRITICIZE_7153853318741720978: VariantsMap = [
    &["hypercriticize"],
    &["hypercriticise"],
    &["hypercriticize"],
    &["hypercriticise"],
];

pub(crate) static ENTRY_HYPERCRITICIZING_11659786261622400970: VariantsMap = [
    &["hypercriticizing"],
    &["hypercriticising"],
    &["hypercriticizing"],
    &["hypercriticising"],
];

pub(crate) static ENTRY_HYPERCRYESTHESIA_13272859349292800228: VariantsMap = [
    &["hypercryesthesia"],
    &["hypercryaesthesia"],
    &["hypercryaesthesia"],
    &["hypercryaesthesia"],
];

pub(crate) static ENTRY_HYPEREMIAS_6998648938587873401: VariantsMap = [
    &["hyperemias"],
    &["hyperaemias"],
    &["hyperaemias"],
    &["hyperaemias"],
];

pub(crate) static ENTRY_HYPEREMIA_12277248942196498109: VariantsMap = [
    &["hyperemia"],
    &["hyperaemia"],
    &["hyperaemia"],
    &["hyperaemia"],
];

pub(crate) static ENTRY_HYPEREMIC_570993563030938406: VariantsMap = [
    &["hyperemic"],
    &["hyperaemic"],
    &["hyperaemic"],
    &["hyperaemic"],
];

pub(crate) static ENTRY_HYPEREMPHASIZES_12026029947023914198: VariantsMap = [
    &["hyperemphasizes"],
    &["hyperemphasises"],
    &["hyperemphasizes"],
    &["hyperemphasises"],
];

pub(crate) static ENTRY_HYPEREMPHASIZE_6296306065623289212: VariantsMap = [
    &["hyperemphasize"],
    &["hyperemphasise"],
    &["hyperemphasize"],
    &["hyperemphasise"],
];

pub(crate) static ENTRY_HYPERESTHESIAS_14403575251595502945: VariantsMap = [
    &["hyperesthesias"],
    &["hyperaesthesias"],
    &["hyperaesthesias"],
    &["hyperaesthesias"],
];

pub(crate) static ENTRY_HYPERESTHESIA_4632423926913384933: VariantsMap = [
    &["hyperesthesia"],
    &["hyperaesthesia"],
    &["hyperaesthesia"],
    &["hyperaesthesia"],
];

pub(crate) static ENTRY_HYPERESTHETE_12422140998781729014: VariantsMap = [
    &["hyperesthete"],
    &["hyperaesthete"],
    &["hyperaesthete"],
    &["hyperaesthete"],
];

pub(crate) static ENTRY_HYPERESTHETICER_2523595003905077411: VariantsMap = [
    &["hyperestheticer"],
    &["hyperaestheticer"],
    &["hyperaestheticer"],
    &["hyperaestheticer"],
];

pub(crate) static ENTRY_HYPERESTHETICEST_15286134872893657494: VariantsMap = [
    &["hyperestheticest"],
    &["hyperaestheticest"],
    &["hyperaestheticest"],
    &["hyperaestheticest"],
];

pub(crate) static ENTRY_HYPERESTHETIC_18284481883670857002: VariantsMap = [
    &["hyperesthetic"],
    &["hyperaesthetic"],
    &["hyperaesthetic"],
    &["hyperaesthetic"],
];

pub(crate) static ENTRY_HYPERGLYCEMIC_9687962488251265608: VariantsMap = [
    &["hyperglycemic"],
    &["hyperglycaemic"],
    &["hyperglycaemic"],
    &["hyperglycaemic"],
];

pub(crate) static ENTRY_HYPERIMMUNIZATIONS_4951142413886672236: VariantsMap = [
    &["hyperimmunizations"],
    &["hyperimmunisations"],
    &["hyperimmunizations"],
    &["hyperimmunisations"],
];

pub(crate) static ENTRY_HYPERIMMUNIZATION_2495485152326430573: VariantsMap = [
    &["hyperimmunization"],
    &["hyperimmunisation"],
    &["hyperimmunization"],
    &["hyperimmunisation"],
];

pub(crate) static ENTRY_HYPERIMMUNIZES_12098415096912500474: VariantsMap = [
    &["hyperimmunizes"],
    &["hyperimmunises"],
    &["hyperimmunizes"],
    &["hyperimmunises"],
];

pub(crate) static ENTRY_HYPERIMMUNIZE_9019335689416385702: VariantsMap = [
    &["hyperimmunize"],
    &["hyperimmunise"],
    &["hyperimmunize"],
    &["hyperimmunise"],
];

pub(crate) static ENTRY_HYPERINSULINIZATIONS_9195485943946903403: VariantsMap = [
    &["hyperinsulinizations"],
    &["hyperinsulinisations"],
    &["hyperinsulinizations"],
    &["hyperinsulinisations"],
];

pub(crate) static ENTRY_HYPERINSULINIZATION_2999598606550891341: VariantsMap = [
    &["hyperinsulinization"],
    &["hyperinsulinisation"],
    &["hyperinsulinization"],
    &["hyperinsulinisation"],
];

pub(crate) static ENTRY_HYPERINSULINIZES_12978176799201291300: VariantsMap = [
    &["hyperinsulinizes"],
    &["hyperinsulinises"],
    &["hyperinsulinizes"],
    &["hyperinsulinises"],
];

pub(crate) static ENTRY_HYPERINSULINIZE_14913679736749969579: VariantsMap = [
    &["hyperinsulinize"],
    &["hyperinsulinise"],
    &["hyperinsulinize"],
    &["hyperinsulinise"],
];

pub(crate) static ENTRY_HYPERLIPEMIA_17092876738860011414: VariantsMap = [
    &["hyperlipemia"],
    &["hyperlipaemia"],
    &["hyperlipaemia"],
    &["hyperlipaemia"],
];

pub(crate) static ENTRY_HYPERLIPEMIC_43883570874153479: VariantsMap = [
    &["hyperlipemic"],
    &["hyperlipaemic"],
    &["hyperlipaemic"],
    &["hyperlipaemic"],
];

pub(crate) static ENTRY_HYPERLIPIDEMIA_11437229962186470279: VariantsMap = [
    &["hyperlipidemia"],
    &["hyperlipidaemia"],
    &["hyperlipidaemia"],
    &["hyperlipidaemia"],
];

pub(crate) static ENTRY_HYPERNATREMIA_15755713506919882473: VariantsMap = [
    &["hypernatremia"],
    &["hypernatraemia"],
    &["hypernatraemia"],
    &["hypernatraemia"],
];

pub(crate) static ENTRY_HYPEROXYGENIZES_1378354644160911943: VariantsMap = [
    &["hyperoxygenizes"],
    &["hyperoxygenises"],
    &["hyperoxygenizes"],
    &["hyperoxygenises"],
];

pub(crate) static ENTRY_HYPEROXYGENIZE_4509020112349763954: VariantsMap = [
    &["hyperoxygenize"],
    &["hyperoxygenise"],
    &["hyperoxygenize"],
    &["hyperoxygenise"],
];

pub(crate) static ENTRY_HYPERPARASITIZES_14079459076340974669: VariantsMap = [
    &["hyperparasitizes"],
    &["hyperparasitises"],
    &["hyperparasitizes"],
    &["hyperparasitises"],
];

pub(crate) static ENTRY_HYPERPARASITIZE_16105780322488378828: VariantsMap = [
    &["hyperparasitize"],
    &["hyperparasitise"],
    &["hyperparasitize"],
    &["hyperparasitise"],
];

pub(crate) static ENTRY_HYPERPNEA_11441677197331315893: VariantsMap = [
    &["hyperpnea"],
    &["hyperpnoea"],
    &["hyperpnoea"],
    &["hyperpnoea"],
];

pub(crate) static ENTRY_HYPERREALIZES_816890107094523513: VariantsMap = [
    &["hyperrealizes"],
    &["hyperrealises"],
    &["hyperrealizes"],
    &["hyperrealises"],
];

pub(crate) static ENTRY_HYPERREALIZE_555118691017631561: VariantsMap = [
    &["hyperrealize"],
    &["hyperrealise"],
    &["hyperrealize"],
    &["hyperrealise"],
];

pub(crate) static ENTRY_HYPERSENSITIZATIONS_14693900323393495348: VariantsMap = [
    &["hypersensitizations"],
    &["hypersensitisations"],
    &["hypersensitizations"],
    &["hypersensitisations"],
];

pub(crate) static ENTRY_HYPERSENSITIZATION_2559704586898281279: VariantsMap = [
    &["hypersensitization"],
    &["hypersensitisation"],
    &["hypersensitization"],
    &["hypersensitisation"],
];

pub(crate) static ENTRY_HYPERSENSITIZED_7944194294133330943: VariantsMap = [
    &["hypersensitized"],
    &["hypersensitised"],
    &["hypersensitized"],
    &["hypersensitised"],
];

pub(crate) static ENTRY_HYPERSENSITIZES_6762279008165528502: VariantsMap = [
    &["hypersensitizes"],
    &["hypersensitises"],
    &["hypersensitizes"],
    &["hypersensitises"],
];

pub(crate) static ENTRY_HYPERSENSITIZE_6280726783656545963: VariantsMap = [
    &["hypersensitize"],
    &["hypersensitise"],
    &["hypersensitize"],
    &["hypersensitise"],
];

pub(crate) static ENTRY_HYPERSENSITIZING_3535038257675270244: VariantsMap = [
    &["hypersensitizing"],
    &["hypersensitising"],
    &["hypersensitizing"],
    &["hypersensitising"],
];

pub(crate) static ENTRY_HYPERSPIRITUALIZINGS_14278575746904121990: VariantsMap = [
    &["hyperspiritualizings"],
    &["hyperspiritualisings"],
    &["hyperspiritualizings"],
    &["hyperspiritualisings"],
];

pub(crate) static ENTRY_HYPERSPIRITUALIZING_16460640116515835042: VariantsMap = [
    &["hyperspiritualizing"],
    &["hyperspiritualising"],
    &["hyperspiritualizing"],
    &["hyperspiritualising"],
];

pub(crate) static ENTRY_HYPERTHYROIDIZATIONS_1743064878801216887: VariantsMap = [
    &["hyperthyroidizations"],
    &["hyperthyroidisations"],
    &["hyperthyroidizations"],
    &["hyperthyroidisations"],
];

pub(crate) static ENTRY_HYPERTHYROIDIZATION_13217016915972693933: VariantsMap = [
    &["hyperthyroidization"],
    &["hyperthyroidisation"],
    &["hyperthyroidization"],
    &["hyperthyroidisation"],
];

pub(crate) static ENTRY_HYPERTHYROIDIZES_11754202158703775232: VariantsMap = [
    &["hyperthyroidizes"],
    &["hyperthyroidises"],
    &["hyperthyroidizes"],
    &["hyperthyroidises"],
];

pub(crate) static ENTRY_HYPERTHYROIDIZE_5417946722085898259: VariantsMap = [
    &["hyperthyroidize"],
    &["hyperthyroidise"],
    &["hyperthyroidize"],
    &["hyperthyroidise"],
];

pub(crate) static ENTRY_HYPERVITALIZATIONS_5318502760253977651: VariantsMap = [
    &["hypervitalizations"],
    &["hypervitalisations"],
    &["hypervitalizations"],
    &["hypervitalisations"],
];

pub(crate) static ENTRY_HYPERVITALIZATION_15336704625235287557: VariantsMap = [
    &["hypervitalization"],
    &["hypervitalisation"],
    &["hypervitalization"],
    &["hypervitalisation"],
];

pub(crate) static ENTRY_HYPERVITALIZES_3178121801376655810: VariantsMap = [
    &["hypervitalizes"],
    &["hypervitalises"],
    &["hypervitalizes"],
    &["hypervitalises"],
];

pub(crate) static ENTRY_HYPERVITALIZE_10124681016900035288: VariantsMap = [
    &["hypervitalize"],
    &["hypervitalise"],
    &["hypervitalize"],
    &["hypervitalise"],
];

pub(crate) static ENTRY_HYPESTHESIAS_1838024351778836132: VariantsMap = [
    &["hypesthesias"],
    &["hypaesthesias"],
    &["hypaesthesias"],
    &["hypaesthesias"],
];

pub(crate) static ENTRY_HYPESTHESIA_16196465189141300744: VariantsMap = [
    &["hypesthesia"],
    &["hypaesthesia"],
    &["hypaesthesia"],
    &["hypaesthesia"],
];

pub(crate) static ENTRY_HYPESTHESIC_16905452400970791194: VariantsMap = [
    &["hypesthesic"],
    &["hypaesthesic"],
    &["hypaesthesic"],
    &["hypaesthesic"],
];

pub(crate) static ENTRY_HYPETHRAL_14201019373187172019: VariantsMap = [
    &["hypethral"],
    &["hypaethral"],
    &["hypaethral"],
    &["hypaethral"],
];

pub(crate) static ENTRY_HYPHENIZATIONS_8540218098232685932: VariantsMap = [
    &["hyphenizations"],
    &["hyphenisations"],
    &["hyphenizations"],
    &["hyphenisations"],
];

pub(crate) static ENTRY_HYPHENIZATION_10017420697137470773: VariantsMap = [
    &["hyphenization"],
    &["hyphenisation"],
    &["hyphenization"],
    &["hyphenisation"],
];

pub(crate) static ENTRY_HYPHENIZED_14280183610433481117: VariantsMap = [
    &["hyphenized"],
    &["hyphenised"],
    &["hyphenized"],
    &["hyphenised"],
];

pub(crate) static ENTRY_HYPHENIZES_15047089195146038815: VariantsMap = [
    &["hyphenizes"],
    &["hyphenises"],
    &["hyphenizes"],
    &["hyphenises"],
];

pub(crate) static ENTRY_HYPHENIZE_15302714032482214487: VariantsMap = [
    &["hyphenize"],
    &["hyphenise"],
    &["hyphenize"],
    &["hyphenise"],
];

pub(crate) static ENTRY_HYPHENIZING_14826999785045511543: VariantsMap = [
    &["hyphenizing"],
    &["hyphenising"],
    &["hyphenizing"],
    &["hyphenising"],
];

pub(crate) static ENTRY_HYPNOIDIZED_8369898236853174546: VariantsMap = [
    &["hypnoidized"],
    &["hypnoidised"],
    &["hypnoidized"],
    &["hypnoidised"],
];

pub(crate) static ENTRY_HYPNOIDIZES_2097426277708644881: VariantsMap = [
    &["hypnoidizes"],
    &["hypnoidises"],
    &["hypnoidizes"],
    &["hypnoidises"],
];

pub(crate) static ENTRY_HYPNOIDIZE_879115482501125749: VariantsMap = [
    &["hypnoidize"],
    &["hypnoidise"],
    &["hypnoidize"],
    &["hypnoidise"],
];

pub(crate) static ENTRY_HYPNOIDIZING_6170044007311971095: VariantsMap = [
    &["hypnoidizing"],
    &["hypnoidising"],
    &["hypnoidizing"],
    &["hypnoidising"],
];

pub(crate) static ENTRY_HYPNOPEDIAS_9606774705113272510: VariantsMap = [
    &["hypnopedias"],
    &["hypnopaedias"],
    &["hypnopaedias"],
    &["hypnopaedias"],
];

pub(crate) static ENTRY_HYPNOPEDIA_15887285651417738221: VariantsMap = [
    &["hypnopedia"],
    &["hypnopaedia"],
    &["hypnopaedia"],
    &["hypnopaedia"],
];

pub(crate) static ENTRY_HYPNOTIZABILITIES_3555702283468310358: VariantsMap = [
    &["hypnotizabilities"],
    &["hypnotisabilities"],
    &["hypnotizabilities"],
    &["hypnotisabilities"],
];

pub(crate) static ENTRY_HYPNOTIZABILITY_3193312628696225164: VariantsMap = [
    &["hypnotizability"],
    &["hypnotisability"],
    &["hypnotizability"],
    &["hypnotisability"],
];

pub(crate) static ENTRY_HYPNOTIZABLER_16475549704606191881: VariantsMap = [
    &["hypnotizabler"],
    &["hypnotisabler"],
    &["hypnotizabler"],
    &["hypnotisabler"],
];

pub(crate) static ENTRY_HYPNOTIZABLEST_570003064636075490: VariantsMap = [
    &["hypnotizablest"],
    &["hypnotisablest"],
    &["hypnotizablest"],
    &["hypnotisablest"],
];

pub(crate) static ENTRY_HYPNOTIZABLES_15256571692608743267: VariantsMap = [
    &["hypnotizables"],
    &["hypnotisables"],
    &["hypnotizables"],
    &["hypnotisables"],
];

pub(crate) static ENTRY_HYPNOTIZABLE_1111458195931571372: VariantsMap = [
    &["hypnotizable"],
    &["hypnotisable"],
    &["hypnotizable"],
    &["hypnotisable"],
];

pub(crate) static ENTRY_HYPNOTIZATIONS_1603572274241018729: VariantsMap = [
    &["hypnotizations"],
    &["hypnotisations"],
    &["hypnotizations"],
    &["hypnotisations"],
];

pub(crate) static ENTRY_HYPNOTIZATION_7421948723228572667: VariantsMap = [
    &["hypnotization"],
    &["hypnotisation"],
    &["hypnotization"],
    &["hypnotisation"],
];

pub(crate) static ENTRY_HYPNOTIZED_3155367972836581303: VariantsMap = [
    &["hypnotized"],
    &["hypnotised"],
    &["hypnotized"],
    &["hypnotised"],
];

pub(crate) static ENTRY_HYPNOTIZERS_18259914050110653108: VariantsMap = [
    &["hypnotizers"],
    &["hypnotisers"],
    &["hypnotizers"],
    &["hypnotisers"],
];

pub(crate) static ENTRY_HYPNOTIZER_2163198826903259375: VariantsMap = [
    &["hypnotizer"],
    &["hypnotiser"],
    &["hypnotizer"],
    &["hypnotiser"],
];

pub(crate) static ENTRY_HYPNOTIZES_15369403272790064853: VariantsMap = [
    &["hypnotizes"],
    &["hypnotises"],
    &["hypnotizes"],
    &["hypnotises"],
];

pub(crate) static ENTRY_HYPNOTIZE_15259856905514903130: VariantsMap = [
    &["hypnotize"],
    &["hypnotise"],
    &["hypnotize"],
    &["hypnotise"],
];

pub(crate) static ENTRY_HYPNOTIZING_12709364564970055556: VariantsMap = [
    &["hypnotizing"],
    &["hypnotising"],
    &["hypnotizing"],
    &["hypnotising"],
];

pub(crate) static ENTRY_HYPOCENTERS_7336977377559114220: VariantsMap = [
    &["hypocenters"],
    &["hypocentres"],
    &["hypocentres"],
    &["hypocentres"],
];

pub(crate) static ENTRY_HYPOCENTER_313042704668341320: VariantsMap = [
    &["hypocenter"],
    &["hypocentre"],
    &["hypocentre"],
    &["hypocentre"],
];

pub(crate) static ENTRY_HYPOGEAL_16228427341032137597: VariantsMap = [
    &["hypogeal"],
    &["hypogaeal"],
    &["hypogaeal"],
    &["hypogaeal"],
];

pub(crate) static ENTRY_HYPOGEAN_817591283440453496: VariantsMap = [
    &["hypogean"],
    &["hypogaean"],
    &["hypogaean"],
    &["hypogaean"],
];

pub(crate) static ENTRY_HYPOGEA_5547650658352096585: VariantsMap =
    [&["hypogea"], &["hypogaea"], &["hypogaea"], &["hypogaea"]];

pub(crate) static ENTRY_HYPOGEIC_17994122167340611658: VariantsMap = [
    &["hypogeic"],
    &["hypogaeic"],
    &["hypogaeic"],
    &["hypogaeic"],
];

pub(crate) static ENTRY_HYPOGEOUS_18395587689172074500: VariantsMap = [
    &["hypogeous"],
    &["hypogaeous"],
    &["hypogaeous"],
    &["hypogaeous"],
];

pub(crate) static ENTRY_HYPOGEUM_692403338728273782: VariantsMap = [
    &["hypogeum"],
    &["hypogaeum"],
    &["hypogaeum"],
    &["hypogaeum"],
];

pub(crate) static ENTRY_HYPOMAGNESEMIAS_7320429522378376279: VariantsMap = [
    &["hypomagnesemias"],
    &["hypomagnesaemias"],
    &["hypomagnesaemias"],
    &["hypomagnesaemias"],
];

pub(crate) static ENTRY_HYPOMAGNESEMIA_13749607509052652094: VariantsMap = [
    &["hypomagnesemia"],
    &["hypomagnesaemia"],
    &["hypomagnesaemia"],
    &["hypomagnesaemia"],
];

pub(crate) static ENTRY_HYPOMENORRHEAS_12448521431273870133: VariantsMap = [
    &["hypomenorrheas"],
    &["hypomenorrhoeas"],
    &["hypomenorrhoeas"],
    &["hypomenorrhoeas"],
];

pub(crate) static ENTRY_HYPOMENORRHEA_4150580092110671155: VariantsMap = [
    &["hypomenorrhea"],
    &["hypomenorrhoea"],
    &["hypomenorrhoea"],
    &["hypomenorrhoea"],
];

pub(crate) static ENTRY_HYPOPHYSECTOMIZED_11810018005356862443: VariantsMap = [
    &["hypophysectomized"],
    &["hypophysectomised"],
    &["hypophysectomized"],
    &["hypophysectomised"],
];

pub(crate) static ENTRY_HYPOPHYSECTOMIZE_7441432223206368484: VariantsMap = [
    &["hypophysectomize"],
    &["hypophysectomise"],
    &["hypophysectomize"],
    &["hypophysectomise"],
];

pub(crate) static ENTRY_HYPOPNEA_8136477563229617115: VariantsMap = [
    &["hypopnea"],
    &["hypopnoea"],
    &["hypopnoea"],
    &["hypopnoea"],
];

pub(crate) static ENTRY_HYPOSENSITIZATION_15528129983330572518: VariantsMap = [
    &["hyposensitization"],
    &["hyposensitisation"],
    &["hyposensitization"],
    &["hyposensitisation"],
];

pub(crate) static ENTRY_HYPOSENSITIZE_5903465904740790285: VariantsMap = [
    &["hyposensitize"],
    &["hyposensitise"],
    &["hyposensitize"],
    &["hyposensitise"],
];

pub(crate) static ENTRY_HYPOSTASIZED_11672079523808552915: VariantsMap = [
    &["hypostasized"],
    &["hypostasised"],
    &["hypostasized"],
    &["hypostasised"],
];

pub(crate) static ENTRY_HYPOSTASIZES_12098952916923008604: VariantsMap = [
    &["hypostasizes"],
    &["hypostasises"],
    &["hypostasizes"],
    &["hypostasises"],
];

pub(crate) static ENTRY_HYPOSTASIZE_16100413099795742054: VariantsMap = [
    &["hypostasize"],
    &["hypostasise"],
    &["hypostasize"],
    &["hypostasise"],
];

pub(crate) static ENTRY_HYPOSTASIZING_8088482663168944782: VariantsMap = [
    &["hypostasizing"],
    &["hypostasising"],
    &["hypostasizing"],
    &["hypostasising"],
];

pub(crate) static ENTRY_HYPOSTATIZATIONS_6954932085574725526: VariantsMap = [
    &["hypostatizations"],
    &["hypostatisations"],
    &["hypostatizations"],
    &["hypostatisations"],
];

pub(crate) static ENTRY_HYPOSTATIZATION_11089927936491984161: VariantsMap = [
    &["hypostatization"],
    &["hypostatisation"],
    &["hypostatization"],
    &["hypostatisation"],
];

pub(crate) static ENTRY_HYPOSTATIZED_1632743900632980509: VariantsMap = [
    &["hypostatized"],
    &["hypostatised"],
    &["hypostatized"],
    &["hypostatised"],
];

pub(crate) static ENTRY_HYPOSTATIZES_6850133111163957406: VariantsMap = [
    &["hypostatizes"],
    &["hypostatises"],
    &["hypostatizes"],
    &["hypostatises"],
];

pub(crate) static ENTRY_HYPOSTATIZE_18306361123837315572: VariantsMap = [
    &["hypostatize"],
    &["hypostatise"],
    &["hypostatize"],
    &["hypostatise"],
];

pub(crate) static ENTRY_HYPOSTATIZING_7675432982784792920: VariantsMap = [
    &["hypostatizing"],
    &["hypostatising"],
    &["hypostatizing"],
    &["hypostatising"],
];

pub(crate) static ENTRY_HYPOTHESIZED_14110128970476142821: VariantsMap = [
    &["hypothesized"],
    &["hypothesised"],
    &["hypothesized"],
    &["hypothesised"],
];

pub(crate) static ENTRY_HYPOTHESIZERS_55820786179370701: VariantsMap = [
    &["hypothesizers"],
    &["hypothesisers"],
    &["hypothesizers"],
    &["hypothesisers"],
];

pub(crate) static ENTRY_HYPOTHESIZER_2472052824551896236: VariantsMap = [
    &["hypothesizer"],
    &["hypothesiser"],
    &["hypothesizer"],
    &["hypothesiser"],
];

pub(crate) static ENTRY_HYPOTHESIZES_3305988013143404614: VariantsMap = [
    &["hypothesizes"],
    &["hypothesises"],
    &["hypothesizes"],
    &["hypothesises"],
];

pub(crate) static ENTRY_HYPOTHESIZE_3825963791328606413: VariantsMap = [
    &["hypothesize"],
    &["hypothesise"],
    &["hypothesize"],
    &["hypothesise"],
];

pub(crate) static ENTRY_HYPOTHESIZING_7325923156843990124: VariantsMap = [
    &["hypothesizing"],
    &["hypothesising"],
    &["hypothesizing"],
    &["hypothesising"],
];

pub(crate) static ENTRY_HYPOTHETIZED_8186536952516454687: VariantsMap = [
    &["hypothetized"],
    &["hypothetised"],
    &["hypothetized"],
    &["hypothetised"],
];

pub(crate) static ENTRY_HYPOTHETIZES_5252732551677489496: VariantsMap = [
    &["hypothetizes"],
    &["hypothetises"],
    &["hypothetizes"],
    &["hypothetises"],
];

pub(crate) static ENTRY_HYPOTHETIZE_12616552221739079011: VariantsMap = [
    &["hypothetize"],
    &["hypothetise"],
    &["hypothetize"],
    &["hypothetise"],
];

pub(crate) static ENTRY_HYPOTHETIZING_12650785144462407190: VariantsMap = [
    &["hypothetizing"],
    &["hypothetising"],
    &["hypothetizing"],
    &["hypothetising"],
];

pub(crate) static ENTRY_HYPOXEMIAS_14672501546678381889: VariantsMap = [
    &["hypoxemias"],
    &["hypoxaemias"],
    &["hypoxaemias"],
    &["hypoxaemias"],
];

pub(crate) static ENTRY_HYPOXEMIA_17993402685193079339: VariantsMap = [
    &["hypoxemia"],
    &["hypoxaemia"],
    &["hypoxaemia"],
    &["hypoxaemia"],
];

pub(crate) static ENTRY_HYPOXEMIC_17342712296732938343: VariantsMap = [
    &["hypoxemic"],
    &["hypoxaemic"],
    &["hypoxaemic"],
    &["hypoxaemic"],
];

pub(crate) static ENTRY_HYSTERECTOMIZED_8515162559842878159: VariantsMap = [
    &["hysterectomized"],
    &["hysterectomised"],
    &["hysterectomized"],
    &["hysterectomised"],
];

pub(crate) static ENTRY_HYSTERECTOMIZES_12491381132060525295: VariantsMap = [
    &["hysterectomizes"],
    &["hysterectomises"],
    &["hysterectomizes"],
    &["hysterectomises"],
];

pub(crate) static ENTRY_HYSTERECTOMIZE_8681246009628031525: VariantsMap = [
    &["hysterectomize"],
    &["hysterectomise"],
    &["hysterectomize"],
    &["hysterectomise"],
];

pub(crate) static ENTRY_HYSTERECTOMIZING_6176446475438696766: VariantsMap = [
    &["hysterectomizing"],
    &["hysterectomising"],
    &["hysterectomizing"],
    &["hysterectomising"],
];

pub(crate) static ENTRY_ICHNEUMONIZEDS_224406158324301972: VariantsMap = [
    &["ichneumonizeds"],
    &["ichneumoniseds"],
    &["ichneumonizeds"],
    &["ichneumoniseds"],
];

pub(crate) static ENTRY_ICHNEUMONIZED_14580421766806791127: VariantsMap = [
    &["ichneumonized"],
    &["ichneumonised"],
    &["ichneumonized"],
    &["ichneumonised"],
];

pub(crate) static ENTRY_ICHORRHEA_3856500369693916341: VariantsMap = [
    &["ichorrhea"],
    &["ichorrhoea"],
    &["ichorrhoea"],
    &["ichorrhoea"],
];

pub(crate) static ENTRY_ICHORRHEMIA_5590679225774569274: VariantsMap = [
    &["ichorrhemia"],
    &["ichorrhaemia"],
    &["ichorrhaemia"],
    &["ichorrhaemia"],
];

pub(crate) static ENTRY_ICONIZED_6721332614366408866: VariantsMap =
    [&["iconized"], &["iconised"], &["iconized"], &["iconised"]];

pub(crate) static ENTRY_ICONIZES_18252899495281313317: VariantsMap =
    [&["iconizes"], &["iconises"], &["iconizes"], &["iconises"]];

pub(crate) static ENTRY_ICONIZE_11215091059030087912: VariantsMap =
    [&["iconize"], &["iconise"], &["iconize"], &["iconise"]];

pub(crate) static ENTRY_ICONIZING_13309072660625193134: VariantsMap = [
    &["iconizing"],
    &["iconising"],
    &["iconizing"],
    &["iconising"],
];

pub(crate) static ENTRY_IDEALIZATIONS_3729750012626226945: VariantsMap = [
    &["idealizations"],
    &["idealisations"],
    &["idealizations"],
    &["idealisations"],
];

pub(crate) static ENTRY_IDEALIZATION_13571578580847994239: VariantsMap = [
    &["idealization"],
    &["idealisation"],
    &["idealization"],
    &["idealisation"],
];

pub(crate) static ENTRY_IDEALIZED_5103962997156504752: VariantsMap = [
    &["idealized"],
    &["idealised"],
    &["idealized"],
    &["idealised"],
];

pub(crate) static ENTRY_IDEALIZERS_13463195698737940264: VariantsMap = [
    &["idealizers"],
    &["idealisers"],
    &["idealizers"],
    &["idealisers"],
];

pub(crate) static ENTRY_IDEALIZER_12565075479493888894: VariantsMap = [
    &["idealizer"],
    &["idealiser"],
    &["idealizer"],
    &["idealiser"],
];

pub(crate) static ENTRY_IDEALIZES_17744034669185196667: VariantsMap = [
    &["idealizes"],
    &["idealises"],
    &["idealizes"],
    &["idealises"],
];

pub(crate) static ENTRY_IDEALIZE_10907881421979440742: VariantsMap =
    [&["idealize"], &["idealise"], &["idealize"], &["idealise"]];

pub(crate) static ENTRY_IDEALIZING_1544218102413826617: VariantsMap = [
    &["idealizing"],
    &["idealising"],
    &["idealizing"],
    &["idealising"],
];

pub(crate) static ENTRY_IDEAN_11620335570699525177: VariantsMap =
    [&["idean"], &["idaean"], &["idaean"], &["idaean"]];

pub(crate) static ENTRY_IDEA_1183701720980357352: VariantsMap =
    [&["idea"], &["idaea"], &["idaea"], &["idaea"]];

pub(crate) static ENTRY_IDEOLOGIZED_14733634681578557936: VariantsMap = [
    &["ideologized"],
    &["ideologised"],
    &["ideologized"],
    &["ideologised"],
];

pub(crate) static ENTRY_IDEOLOGIZE_6285081699594159906: VariantsMap = [
    &["ideologize"],
    &["ideologise"],
    &["ideologize"],
    &["ideologise"],
];

pub(crate) static ENTRY_IDEOLOGIZING_15450303981107523469: VariantsMap = [
    &["ideologizing"],
    &["ideologising"],
    &["ideologizing"],
    &["ideologising"],
];

pub(crate) static ENTRY_IDIOTIZED_6771429521996563043: VariantsMap = [
    &["idiotized"],
    &["idiotised"],
    &["idiotized"],
    &["idiotised"],
];

pub(crate) static ENTRY_IDIOTIZES_12814032023791935267: VariantsMap = [
    &["idiotizes"],
    &["idiotises"],
    &["idiotizes"],
    &["idiotises"],
];

pub(crate) static ENTRY_IDIOTIZE_12917906860396891070: VariantsMap =
    [&["idiotize"], &["idiotise"], &["idiotize"], &["idiotise"]];

pub(crate) static ENTRY_IDIOTIZING_5961105820849234369: VariantsMap = [
    &["idiotizing"],
    &["idiotising"],
    &["idiotizing"],
    &["idiotising"],
];

pub(crate) static ENTRY_IDOLASTER_1606884119199496212: VariantsMap = [
    &["idolaster"],
    &["idolastre"],
    &["idolastre"],
    &["idolastre"],
];

pub(crate) static ENTRY_IDOLATRIZED_10874059237199920636: VariantsMap = [
    &["idolatrized"],
    &["idolatrised"],
    &["idolatrized"],
    &["idolatrised"],
];

pub(crate) static ENTRY_IDOLATRIZER_9734451679415511293: VariantsMap = [
    &["idolatrizer"],
    &["idolatriser"],
    &["idolatrizer"],
    &["idolatriser"],
];

pub(crate) static ENTRY_IDOLATRIZES_16288993125152158763: VariantsMap = [
    &["idolatrizes"],
    &["idolatrises"],
    &["idolatrizes"],
    &["idolatrises"],
];

pub(crate) static ENTRY_IDOLATRIZE_17980797854680013339: VariantsMap = [
    &["idolatrize"],
    &["idolatrise"],
    &["idolatrize"],
    &["idolatrise"],
];

pub(crate) static ENTRY_IDOLATRIZING_1695347286696911693: VariantsMap = [
    &["idolatrizing"],
    &["idolatrising"],
    &["idolatrizing"],
    &["idolatrising"],
];

pub(crate) static ENTRY_IDOLIZATIONS_4690624939733294253: VariantsMap = [
    &["idolizations"],
    &["idolisations"],
    &["idolizations"],
    &["idolisations"],
];

pub(crate) static ENTRY_IDOLIZATION_15105118948886829092: VariantsMap = [
    &["idolization"],
    &["idolisation"],
    &["idolization"],
    &["idolisation"],
];

pub(crate) static ENTRY_IDOLIZED_3011013183847203085: VariantsMap =
    [&["idolized"], &["idolised"], &["idolized"], &["idolised"]];

pub(crate) static ENTRY_IDOLIZERS_3155462085555547150: VariantsMap = [
    &["idolizers"],
    &["idolisers"],
    &["idolizers"],
    &["idolisers"],
];

pub(crate) static ENTRY_IDOLIZER_6262630986106221245: VariantsMap =
    [&["idolizer"], &["idoliser"], &["idolizer"], &["idoliser"]];

pub(crate) static ENTRY_IDOLIZES_7288494209899528996: VariantsMap =
    [&["idolizes"], &["idolises"], &["idolizes"], &["idolises"]];

pub(crate) static ENTRY_IDOLIZE_8242557763652368312: VariantsMap =
    [&["idolize"], &["idolise"], &["idolize"], &["idolise"]];

pub(crate) static ENTRY_IDOLIZING_5172443194465202077: VariantsMap = [
    &["idolizing"],
    &["idolising"],
    &["idolizing"],
    &["idolising"],
];

pub(crate) static ENTRY_IDUMEANS_18228820638132012965: VariantsMap = [
    &["idumeans"],
    &["idumaeans"],
    &["idumaeans"],
    &["idumaeans"],
];

pub(crate) static ENTRY_IDUMEAN_5255599416439761824: VariantsMap =
    [&["idumean"], &["idumaean"], &["idumaean"], &["idumaean"]];

pub(crate) static ENTRY_IDUMEA_17899406367831340010: VariantsMap =
    [&["idumea"], &["idumaea"], &["idumaea"], &["idumaea"]];

pub(crate) static ENTRY_IER_15235430992881202856: VariantsMap =
    [&["ier"], &["ire"], &["ire"], &["ire"]];

pub(crate) static ENTRY_ILEOCECAL_16522185353890210636: VariantsMap = [
    &["ileocecal"],
    &["ileocaecal"],
    &["ileocaecal"],
    &["ileocaecal"],
];

pub(crate) static ENTRY_ILIADIZES_6394336660130229939: VariantsMap = [
    &["iliadizes"],
    &["iliadises"],
    &["iliadizes"],
    &["iliadises"],
];

pub(crate) static ENTRY_ILIADIZE_14724051555313125629: VariantsMap =
    [&["iliadize"], &["iliadise"], &["iliadize"], &["iliadise"]];

pub(crate) static ENTRY_ILLEGALIZATIONS_13407750311781863370: VariantsMap = [
    &["illegalizations"],
    &["illegalisations"],
    &["illegalizations"],
    &["illegalisations"],
];

pub(crate) static ENTRY_ILLEGALIZATION_5065614305999469096: VariantsMap = [
    &["illegalization"],
    &["illegalisation"],
    &["illegalization"],
    &["illegalisation"],
];

pub(crate) static ENTRY_ILLEGALIZED_1320492579784200491: VariantsMap = [
    &["illegalized"],
    &["illegalised"],
    &["illegalized"],
    &["illegalised"],
];

pub(crate) static ENTRY_ILLEGALIZES_11275140355726748310: VariantsMap = [
    &["illegalizes"],
    &["illegalises"],
    &["illegalizes"],
    &["illegalises"],
];

pub(crate) static ENTRY_ILLEGALIZE_17263792211302709645: VariantsMap = [
    &["illegalize"],
    &["illegalise"],
    &["illegalize"],
    &["illegalise"],
];

pub(crate) static ENTRY_ILLEGALIZING_7477590631836755179: VariantsMap = [
    &["illegalizing"],
    &["illegalising"],
    &["illegalizing"],
    &["illegalising"],
];

pub(crate) static ENTRY_ILLEGITIMATIZED_7171891093799492298: VariantsMap = [
    &["illegitimatized"],
    &["illegitimatised"],
    &["illegitimatized"],
    &["illegitimatised"],
];

pub(crate) static ENTRY_ILLEGITIMATIZES_2052102366472178705: VariantsMap = [
    &["illegitimatizes"],
    &["illegitimatises"],
    &["illegitimatizes"],
    &["illegitimatises"],
];

pub(crate) static ENTRY_ILLEGITIMATIZE_17918774402943591962: VariantsMap = [
    &["illegitimatize"],
    &["illegitimatise"],
    &["illegitimatize"],
    &["illegitimatise"],
];

pub(crate) static ENTRY_ILLEGITIMATIZING_17784745931325324901: VariantsMap = [
    &["illegitimatizing"],
    &["illegitimatising"],
    &["illegitimatizing"],
    &["illegitimatising"],
];

pub(crate) static ENTRY_ILLIBERALIZED_6707533947713890737: VariantsMap = [
    &["illiberalized"],
    &["illiberalised"],
    &["illiberalized"],
    &["illiberalised"],
];

pub(crate) static ENTRY_ILLIBERALIZES_4937030393518036499: VariantsMap = [
    &["illiberalizes"],
    &["illiberalises"],
    &["illiberalizes"],
    &["illiberalises"],
];

pub(crate) static ENTRY_ILLIBERALIZE_6577399060213673218: VariantsMap = [
    &["illiberalize"],
    &["illiberalise"],
    &["illiberalize"],
    &["illiberalise"],
];

pub(crate) static ENTRY_ILLIBERALIZING_13464989021623401848: VariantsMap = [
    &["illiberalizing"],
    &["illiberalising"],
    &["illiberalizing"],
    &["illiberalising"],
];

pub(crate) static ENTRY_ILLUMINIZES_16019239520986572742: VariantsMap = [
    &["illuminizes"],
    &["illuminises"],
    &["illuminizes"],
    &["illuminises"],
];

pub(crate) static ENTRY_ILLUMINIZE_14457097272904324504: VariantsMap = [
    &["illuminize"],
    &["illuminise"],
    &["illuminize"],
    &["illuminise"],
];

pub(crate) static ENTRY_IMER_11358538646216832658: VariantsMap =
    [&["imer"], &["imre"], &["imre"], &["imre"]];

pub(crate) static ENTRY_IMMATERIALIZATION_8380883612637374324: VariantsMap = [
    &["immaterialization"],
    &["immaterialisation"],
    &["immaterialization"],
    &["immaterialisation"],
];

pub(crate) static ENTRY_IMMATERIALIZED_16945821848352162336: VariantsMap = [
    &["immaterialized"],
    &["immaterialised"],
    &["immaterialized"],
    &["immaterialised"],
];

pub(crate) static ENTRY_IMMATERIALIZES_6651277863813618111: VariantsMap = [
    &["immaterializes"],
    &["immaterialises"],
    &["immaterializes"],
    &["immaterialises"],
];

pub(crate) static ENTRY_IMMATERIALIZE_14298505658374117395: VariantsMap = [
    &["immaterialize"],
    &["immaterialise"],
    &["immaterialize"],
    &["immaterialise"],
];

pub(crate) static ENTRY_IMMATERIALIZING_5412215182771884286: VariantsMap = [
    &["immaterializing"],
    &["immaterialising"],
    &["immaterializing"],
    &["immaterialising"],
];

pub(crate) static ENTRY_IMMISERIZATIONS_11180702474698433176: VariantsMap = [
    &["immiserizations"],
    &["immiserisations"],
    &["immiserizations"],
    &["immiserisations"],
];

pub(crate) static ENTRY_IMMISERIZATION_1212978393167876038: VariantsMap = [
    &["immiserization"],
    &["immiserisation"],
    &["immiserization"],
    &["immiserisation"],
];

pub(crate) static ENTRY_IMMISERIZED_10641322361888904268: VariantsMap = [
    &["immiserized"],
    &["immiserised"],
    &["immiserized"],
    &["immiserised"],
];

pub(crate) static ENTRY_IMMISERIZES_17351381594017861987: VariantsMap = [
    &["immiserizes"],
    &["immiserises"],
    &["immiserizes"],
    &["immiserises"],
];

pub(crate) static ENTRY_IMMISERIZE_11661578537191697492: VariantsMap = [
    &["immiserize"],
    &["immiserise"],
    &["immiserize"],
    &["immiserise"],
];

pub(crate) static ENTRY_IMMISERIZING_79621541282531560: VariantsMap = [
    &["immiserizing"],
    &["immiserising"],
    &["immiserizing"],
    &["immiserising"],
];

pub(crate) static ENTRY_IMMOBILIZATIONS_11913395493106272461: VariantsMap = [
    &["immobilizations"],
    &["immobilisations"],
    &["immobilizations"],
    &["immobilisations"],
];

pub(crate) static ENTRY_IMMOBILIZATION_11535874786657183681: VariantsMap = [
    &["immobilization"],
    &["immobilisation"],
    &["immobilization"],
    &["immobilisation"],
];

pub(crate) static ENTRY_IMMOBILIZED_2218449348429448480: VariantsMap = [
    &["immobilized"],
    &["immobilised"],
    &["immobilized"],
    &["immobilised"],
];

pub(crate) static ENTRY_IMMOBILIZERS_3641715443719698453: VariantsMap = [
    &["immobilizers"],
    &["immobilisers"],
    &["immobilizers"],
    &["immobilisers"],
];

pub(crate) static ENTRY_IMMOBILIZER_2052176910993424670: VariantsMap = [
    &["immobilizer"],
    &["immobiliser"],
    &["immobilizer"],
    &["immobiliser"],
];

pub(crate) static ENTRY_IMMOBILIZES_3228156254989919907: VariantsMap = [
    &["immobilizes"],
    &["immobilises"],
    &["immobilizes"],
    &["immobilises"],
];

pub(crate) static ENTRY_IMMOBILIZE_409138148493531223: VariantsMap = [
    &["immobilize"],
    &["immobilise"],
    &["immobilize"],
    &["immobilise"],
];

pub(crate) static ENTRY_IMMOBILIZING_16170310105570993627: VariantsMap = [
    &["immobilizing"],
    &["immobilising"],
    &["immobilizing"],
    &["immobilising"],
];

pub(crate) static ENTRY_IMMORALIZED_14794307099201904380: VariantsMap = [
    &["immoralized"],
    &["immoralised"],
    &["immoralized"],
    &["immoralised"],
];

pub(crate) static ENTRY_IMMORALIZES_10642942003506554241: VariantsMap = [
    &["immoralizes"],
    &["immoralises"],
    &["immoralizes"],
    &["immoralises"],
];

pub(crate) static ENTRY_IMMORALIZE_6360519991935141046: VariantsMap = [
    &["immoralize"],
    &["immoralise"],
    &["immoralize"],
    &["immoralise"],
];

pub(crate) static ENTRY_IMMORALIZING_16713408483837116926: VariantsMap = [
    &["immoralizing"],
    &["immoralising"],
    &["immoralizing"],
    &["immoralising"],
];

pub(crate) static ENTRY_IMMORTALIZABLER_9804560428950355369: VariantsMap = [
    &["immortalizabler"],
    &["immortalisabler"],
    &["immortalizabler"],
    &["immortalisabler"],
];

pub(crate) static ENTRY_IMMORTALIZABLEST_10465023541515947294: VariantsMap = [
    &["immortalizablest"],
    &["immortalisablest"],
    &["immortalizablest"],
    &["immortalisablest"],
];

pub(crate) static ENTRY_IMMORTALIZABLES_5485137714027314044: VariantsMap = [
    &["immortalizables"],
    &["immortalisables"],
    &["immortalizables"],
    &["immortalisables"],
];

pub(crate) static ENTRY_IMMORTALIZABLE_4987032698605112948: VariantsMap = [
    &["immortalizable"],
    &["immortalisable"],
    &["immortalizable"],
    &["immortalisable"],
];

pub(crate) static ENTRY_IMMORTALIZATIONS_13947110718243595455: VariantsMap = [
    &["immortalizations"],
    &["immortalisations"],
    &["immortalizations"],
    &["immortalisations"],
];

pub(crate) static ENTRY_IMMORTALIZATION_10488407014653410612: VariantsMap = [
    &["immortalization"],
    &["immortalisation"],
    &["immortalization"],
    &["immortalisation"],
];

pub(crate) static ENTRY_IMMORTALIZED_13104274410574807419: VariantsMap = [
    &["immortalized"],
    &["immortalised"],
    &["immortalized"],
    &["immortalised"],
];

pub(crate) static ENTRY_IMMORTALIZERS_18081771581509933059: VariantsMap = [
    &["immortalizers"],
    &["immortalisers"],
    &["immortalizers"],
    &["immortalisers"],
];

pub(crate) static ENTRY_IMMORTALIZER_17669586674033110270: VariantsMap = [
    &["immortalizer"],
    &["immortaliser"],
    &["immortalizer"],
    &["immortaliser"],
];

pub(crate) static ENTRY_IMMORTALIZES_5576583787201540554: VariantsMap = [
    &["immortalizes"],
    &["immortalises"],
    &["immortalizes"],
    &["immortalises"],
];

pub(crate) static ENTRY_IMMORTALIZE_709590795785947525: VariantsMap = [
    &["immortalize"],
    &["immortalise"],
    &["immortalize"],
    &["immortalise"],
];

pub(crate) static ENTRY_IMMORTALIZING_5453074279253364520: VariantsMap = [
    &["immortalizing"],
    &["immortalising"],
    &["immortalizing"],
    &["immortalising"],
];

pub(crate) static ENTRY_IMMUNIZATIONS_6777054902061161290: VariantsMap = [
    &["immunizations"],
    &["immunisations"],
    &["immunizations"],
    &["immunisations"],
];

pub(crate) static ENTRY_IMMUNIZATION_41859105662498323: VariantsMap = [
    &["immunization"],
    &["immunisation"],
    &["immunization"],
    &["immunisation"],
];

pub(crate) static ENTRY_IMMUNIZED_14708964453824556295: VariantsMap = [
    &["immunized"],
    &["immunised"],
    &["immunized"],
    &["immunised"],
];

pub(crate) static ENTRY_IMMUNIZER_397316735795648135: VariantsMap = [
    &["immunizer"],
    &["immuniser"],
    &["immunizer"],
    &["immuniser"],
];

pub(crate) static ENTRY_IMMUNIZES_4888824548752332625: VariantsMap = [
    &["immunizes"],
    &["immunises"],
    &["immunizes"],
    &["immunises"],
];

pub(crate) static ENTRY_IMMUNIZE_7761802139818992811: VariantsMap =
    [&["immunize"], &["immunise"], &["immunize"], &["immunise"]];

pub(crate) static ENTRY_IMMUNIZING_12247538481370716233: VariantsMap = [
    &["immunizing"],
    &["immunising"],
    &["immunizing"],
    &["immunising"],
];

pub(crate) static ENTRY_IMPACTIONIZES_3797144053702390759: VariantsMap = [
    &["impactionizes"],
    &["impactionises"],
    &["impactionizes"],
    &["impactionises"],
];

pub(crate) static ENTRY_IMPACTIONIZE_6659733183241501977: VariantsMap = [
    &["impactionize"],
    &["impactionise"],
    &["impactionize"],
    &["impactionise"],
];

pub(crate) static ENTRY_IMPANELED_5408518347675931541: VariantsMap = [
    &["impaneled"],
    &["impanelled"],
    &["empanelled"],
    &["impanelled"],
];

pub(crate) static ENTRY_IMPANELING_2814603235256758547: VariantsMap = [
    &["impaneling"],
    &["impanelling"],
    &["empanelling"],
    &["impanelling"],
];

pub(crate) static ENTRY_IMPASTED_17189632727971693462: VariantsMap = [
    &["impasted"],
    &["impastoed"],
    &["impastoed"],
    &["impastoed"],
];

pub(crate) static ENTRY_IMPERIALIZATIONS_7589841721847748726: VariantsMap = [
    &["imperializations"],
    &["imperialisations"],
    &["imperializations"],
    &["imperialisations"],
];

pub(crate) static ENTRY_IMPERIALIZATION_11626604416338067521: VariantsMap = [
    &["imperialization"],
    &["imperialisation"],
    &["imperialization"],
    &["imperialisation"],
];

pub(crate) static ENTRY_IMPERIALIZED_6901045873287587401: VariantsMap = [
    &["imperialized"],
    &["imperialised"],
    &["imperialized"],
    &["imperialised"],
];

pub(crate) static ENTRY_IMPERIALIZES_17659651406501700766: VariantsMap = [
    &["imperializes"],
    &["imperialises"],
    &["imperializes"],
    &["imperialises"],
];

pub(crate) static ENTRY_IMPERIALIZE_4756932431788884861: VariantsMap = [
    &["imperialize"],
    &["imperialise"],
    &["imperialize"],
    &["imperialise"],
];

pub(crate) static ENTRY_IMPERIALIZING_12509349088788350886: VariantsMap = [
    &["imperializing"],
    &["imperialising"],
    &["imperializing"],
    &["imperialising"],
];

pub(crate) static ENTRY_IMPERILED_8444551636021682618: VariantsMap = [
    &["imperiled"],
    &["imperilled"],
    &["imperilled"],
    &["imperilled"],
];

pub(crate) static ENTRY_IMPERILING_4650244730518368073: VariantsMap = [
    &["imperiling"],
    &["imperilling"],
    &["imperilling"],
    &["imperilling"],
];

pub(crate) static ENTRY_IMPERSCRIPTIBLE_7856896163677005608: VariantsMap = [
    &["imperscriptible"],
    &["imprescriptible"],
    &["imprescriptible"],
    &["imprescriptible"],
];

pub(crate) static ENTRY_IMPERSONALIZATIONS_3405968491722535892: VariantsMap = [
    &["impersonalizations"],
    &["impersonalisations"],
    &["impersonalizations"],
    &["impersonalisations"],
];

pub(crate) static ENTRY_IMPERSONALIZATION_14849806748268928930: VariantsMap = [
    &["impersonalization"],
    &["impersonalisation"],
    &["impersonalization"],
    &["impersonalisation"],
];

pub(crate) static ENTRY_IMPERSONALIZED_15300682061313699483: VariantsMap = [
    &["impersonalized"],
    &["impersonalised"],
    &["impersonalized"],
    &["impersonalised"],
];

pub(crate) static ENTRY_IMPERSONALIZES_7941945459626836659: VariantsMap = [
    &["impersonalizes"],
    &["impersonalises"],
    &["impersonalizes"],
    &["impersonalises"],
];

pub(crate) static ENTRY_IMPERSONALIZE_14038642006477198579: VariantsMap = [
    &["impersonalize"],
    &["impersonalise"],
    &["impersonalize"],
    &["impersonalise"],
];

pub(crate) static ENTRY_IMPERSONALIZING_16023910359670403281: VariantsMap = [
    &["impersonalizing"],
    &["impersonalising"],
    &["impersonalizing"],
    &["impersonalising"],
];

pub(crate) static ENTRY_IMPROVIZATORIZES_16215791512694135642: VariantsMap = [
    &["improvizatorizes"],
    &["improvisatorises"],
    &["improvisatorizes"],
    &["improvisatorises"],
];

pub(crate) static ENTRY_IMPROVIZATORIZE_8480332828250113268: VariantsMap = [
    &["improvizatorize"],
    &["improvisatorise"],
    &["improvisatorize"],
    &["improvisatorise"],
];

pub(crate) static ENTRY_INCARNALIZED_16198812654340664293: VariantsMap = [
    &["incarnalized"],
    &["incarnalised"],
    &["incarnalized"],
    &["incarnalised"],
];

pub(crate) static ENTRY_INCARNALIZE_7292849573624396827: VariantsMap = [
    &["incarnalize"],
    &["incarnalise"],
    &["incarnalize"],
    &["incarnalise"],
];

pub(crate) static ENTRY_INCARNALIZING_7229408943846118357: VariantsMap = [
    &["incarnalizing"],
    &["incarnalising"],
    &["incarnalizing"],
    &["incarnalising"],
];

pub(crate) static ENTRY_INCENTERS_17129252522264689574: VariantsMap = [
    &["incenters"],
    &["incentres"],
    &["incentres"],
    &["incentres"],
];

pub(crate) static ENTRY_INCENTER_9810686460356413191: VariantsMap =
    [&["incenter"], &["incentre"], &["incentre"], &["incentre"]];

pub(crate) static ENTRY_INCENTIVIZATIONS_4037716705715303421: VariantsMap = [
    &["incentivizations"],
    &["incentivisations"],
    &["incentivizations"],
    &["incentivisations"],
];

pub(crate) static ENTRY_INCENTIVIZATION_14381857720793942653: VariantsMap = [
    &["incentivization"],
    &["incentivisation"],
    &["incentivization"],
    &["incentivisation"],
];

pub(crate) static ENTRY_INCENTIVIZED_16632919930346554292: VariantsMap = [
    &["incentivized"],
    &["incentivised"],
    &["incentivized"],
    &["incentivised"],
];

pub(crate) static ENTRY_INCENTIVIZES_8999169043411056754: VariantsMap = [
    &["incentivizes"],
    &["incentivises"],
    &["incentivizes"],
    &["incentivises"],
];

pub(crate) static ENTRY_INCENTIVIZE_16078554441117960885: VariantsMap = [
    &["incentivize"],
    &["incentivise"],
    &["incentivize"],
    &["incentivise"],
];

pub(crate) static ENTRY_INCENTIVIZING_2171837523441254972: VariantsMap = [
    &["incentivizing"],
    &["incentivising"],
    &["incentivizing"],
    &["incentivising"],
];

pub(crate) static ENTRY_INCERATE_18445841595936741392: VariantsMap =
    [&["incerate"], &["increate"], &["increate"], &["increate"]];

pub(crate) static ENTRY_INCOGNIZABLE_10885527175806322091: VariantsMap = [
    &["incognizable"],
    &["incognisable"],
    &["incognizable"],
    &["incognisable"],
];

pub(crate) static ENTRY_INCOGNIZANCES_15070962290717221665: VariantsMap = [
    &["incognizances"],
    &["incognisances"],
    &["incognizances"],
    &["incognisances"],
];

pub(crate) static ENTRY_INCOGNIZANCE_8307360386742125799: VariantsMap = [
    &["incognizance"],
    &["incognisance"],
    &["incognizance"],
    &["incognisance"],
];

pub(crate) static ENTRY_INCOGNIZANT_15888512407120483355: VariantsMap = [
    &["incognizant"],
    &["incognisant"],
    &["incognizant"],
    &["incognisant"],
];

pub(crate) static ENTRY_INDIANIZATION_1716413238822798201: VariantsMap = [
    &["indianization"],
    &["indianisation"],
    &["indianization"],
    &["indianisation"],
];

pub(crate) static ENTRY_INDIANIZED_6681655339922669663: VariantsMap = [
    &["indianized"],
    &["indianised"],
    &["indianized"],
    &["indianised"],
];

pub(crate) static ENTRY_INDIANIZES_451682467374866405: VariantsMap = [
    &["indianizes"],
    &["indianises"],
    &["indianizes"],
    &["indianises"],
];

pub(crate) static ENTRY_INDIANIZE_15318260537100967280: VariantsMap = [
    &["indianize"],
    &["indianise"],
    &["indianize"],
    &["indianise"],
];

pub(crate) static ENTRY_INDIANIZING_17001518438969414024: VariantsMap = [
    &["indianizing"],
    &["indianising"],
    &["indianizing"],
    &["indianising"],
];

pub(crate) static ENTRY_INDIGENE_4819583243782851729: VariantsMap = [
    &["indigene"],
    &["indigenae"],
    &["indigenae"],
    &["indigenae"],
];

pub(crate) static ENTRY_INDIGENIZATIONS_13844088182117443972: VariantsMap = [
    &["indigenizations"],
    &["indigenisations"],
    &["indigenizations"],
    &["indigenisations"],
];

pub(crate) static ENTRY_INDIGENIZATION_12186530112926947999: VariantsMap = [
    &["indigenization"],
    &["indigenisation"],
    &["indigenization"],
    &["indigenisation"],
];

pub(crate) static ENTRY_INDIGENIZED_12785276256883238057: VariantsMap = [
    &["indigenized"],
    &["indigenised"],
    &["indigenized"],
    &["indigenised"],
];

pub(crate) static ENTRY_INDIGENIZES_6885065470536932314: VariantsMap = [
    &["indigenizes"],
    &["indigenises"],
    &["indigenizes"],
    &["indigenises"],
];

pub(crate) static ENTRY_INDIGENIZE_7645648345209455462: VariantsMap = [
    &["indigenize"],
    &["indigenise"],
    &["indigenize"],
    &["indigenise"],
];

pub(crate) static ENTRY_INDIGENIZING_14409860332630821709: VariantsMap = [
    &["indigenizing"],
    &["indigenising"],
    &["indigenizing"],
    &["indigenising"],
];

pub(crate) static ENTRY_INDIVIDUALIZATIONS_16008274701567236397: VariantsMap = [
    &["individualizations"],
    &["individualisations"],
    &["individualizations"],
    &["individualisations"],
];

pub(crate) static ENTRY_INDIVIDUALIZATION_12161892009800116926: VariantsMap = [
    &["individualization"],
    &["individualisation"],
    &["individualization"],
    &["individualisation"],
];

pub(crate) static ENTRY_INDIVIDUALIZED_12615286571022762701: VariantsMap = [
    &["individualized"],
    &["individualised"],
    &["individualized"],
    &["individualised"],
];

pub(crate) static ENTRY_INDIVIDUALIZERS_2446587753454807307: VariantsMap = [
    &["individualizers"],
    &["individualisers"],
    &["individualizers"],
    &["individualisers"],
];

pub(crate) static ENTRY_INDIVIDUALIZER_10202329538410288235: VariantsMap = [
    &["individualizer"],
    &["individualiser"],
    &["individualizer"],
    &["individualiser"],
];

pub(crate) static ENTRY_INDIVIDUALIZES_5313824086917745418: VariantsMap = [
    &["individualizes"],
    &["individualises"],
    &["individualizes"],
    &["individualises"],
];

pub(crate) static ENTRY_INDIVIDUALIZE_14128117353720123820: VariantsMap = [
    &["individualize"],
    &["individualise"],
    &["individualize"],
    &["individualise"],
];

pub(crate) static ENTRY_INDIVIDUALIZINGLY_7651768127321435917: VariantsMap = [
    &["individualizingly"],
    &["individualisingly"],
    &["individualizingly"],
    &["individualisingly"],
];

pub(crate) static ENTRY_INDIVIDUALIZING_15464150109564265891: VariantsMap = [
    &["individualizing"],
    &["individualising"],
    &["individualizing"],
    &["individualising"],
];

pub(crate) static ENTRY_INDRAFTS_9423407568172028790: VariantsMap = [
    &["indrafts"],
    &["indraughts"],
    &["indrafts"],
    &["indraughts"],
];

pub(crate) static ENTRY_INDRAFT_1882858010909385258: VariantsMap =
    [&["indraft"], &["indraught"], &["indraft"], &["indraught"]];

pub(crate) static ENTRY_INDUSTRIALIZATIONS_17597998929798495645: VariantsMap = [
    &["industrializations"],
    &["industrialisations"],
    &["industrializations"],
    &["industrialisations"],
];

pub(crate) static ENTRY_INDUSTRIALIZATION_350753450895865005: VariantsMap = [
    &["industrialization"],
    &["industrialisation"],
    &["industrialization"],
    &["industrialisation"],
];

pub(crate) static ENTRY_INDUSTRIALIZED_9347966852221416739: VariantsMap = [
    &["industrialized"],
    &["industrialised"],
    &["industrialized"],
    &["industrialised"],
];

pub(crate) static ENTRY_INDUSTRIALIZES_17591656646172403685: VariantsMap = [
    &["industrializes"],
    &["industrialises"],
    &["industrializes"],
    &["industrialises"],
];

pub(crate) static ENTRY_INDUSTRIALIZE_9725131420784308416: VariantsMap = [
    &["industrialize"],
    &["industrialise"],
    &["industrialize"],
    &["industrialise"],
];

pub(crate) static ENTRY_INDUSTRIALIZING_3256987218630221135: VariantsMap = [
    &["industrializing"],
    &["industrialising"],
    &["industrializing"],
    &["industrialising"],
];

pub(crate) static ENTRY_INESTHETIC_4642492739468968957: VariantsMap = [
    &["inesthetic"],
    &["inaesthetic"],
    &["inaesthetic"],
    &["inaesthetic"],
];

pub(crate) static ENTRY_INFAMIZED_8686570708963178953: VariantsMap = [
    &["infamized"],
    &["infamised"],
    &["infamized"],
    &["infamised"],
];

pub(crate) static ENTRY_INFAMIZES_12652390020335388371: VariantsMap = [
    &["infamizes"],
    &["infamises"],
    &["infamizes"],
    &["infamises"],
];

pub(crate) static ENTRY_INFAMIZE_18394174721818129022: VariantsMap =
    [&["infamize"], &["infamise"], &["infamize"], &["infamise"]];

pub(crate) static ENTRY_INFAMIZING_13586882845116750692: VariantsMap = [
    &["infamizing"],
    &["infamising"],
    &["infamizing"],
    &["infamising"],
];

pub(crate) static ENTRY_INFAMONIZED_10035723014416988237: VariantsMap = [
    &["infamonized"],
    &["infamonised"],
    &["infamonized"],
    &["infamonised"],
];

pub(crate) static ENTRY_INFAMONIZES_11901093378762506596: VariantsMap = [
    &["infamonizes"],
    &["infamonises"],
    &["infamonizes"],
    &["infamonises"],
];

pub(crate) static ENTRY_INFAMONIZE_11667946505084232707: VariantsMap = [
    &["infamonize"],
    &["infamonise"],
    &["infamonize"],
    &["infamonise"],
];

pub(crate) static ENTRY_INFAMONIZING_1761524099304748028: VariantsMap = [
    &["infamonizing"],
    &["infamonising"],
    &["infamonizing"],
    &["infamonising"],
];

pub(crate) static ENTRY_INFERE_5312705532266488477: VariantsMap =
    [&["infere"], &["infree"], &["infree"], &["infree"]];

pub(crate) static ENTRY_INFERIORIZES_13036000105274936197: VariantsMap = [
    &["inferiorizes"],
    &["inferiorises"],
    &["inferiorizes"],
    &["inferiorises"],
];

pub(crate) static ENTRY_INFERIORIZE_11223909632506235818: VariantsMap = [
    &["inferiorize"],
    &["inferiorise"],
    &["inferiorize"],
    &["inferiorise"],
];

pub(crate) static ENTRY_INFERNALIZES_7151282121739105899: VariantsMap = [
    &["infernalizes"],
    &["infernalises"],
    &["infernalizes"],
    &["infernalises"],
];

pub(crate) static ENTRY_INFERNALIZE_10062329537653335936: VariantsMap = [
    &["infernalize"],
    &["infernalise"],
    &["infernalize"],
    &["infernalise"],
];

pub(crate) static ENTRY_INFIDELIZES_2918972068143693835: VariantsMap = [
    &["infidelizes"],
    &["infidelises"],
    &["infidelizes"],
    &["infidelises"],
];

pub(crate) static ENTRY_INFIDELIZE_13385979360953022316: VariantsMap = [
    &["infidelize"],
    &["infidelise"],
    &["infidelize"],
    &["infidelise"],
];

pub(crate) static ENTRY_INFINITIZES_4515016592588905048: VariantsMap = [
    &["infinitizes"],
    &["infinitises"],
    &["infinitizes"],
    &["infinitises"],
];

pub(crate) static ENTRY_INFINITIZE_6261338332347990433: VariantsMap = [
    &["infinitize"],
    &["infinitise"],
    &["infinitize"],
    &["infinitise"],
];

pub(crate) static ENTRY_INFLECTIONS_16947371245746328476: VariantsMap = [
    &["inflections"],
    &["inflections", "inflexions"],
    &["inflections"],
    &["inflections", "inflexions"],
];

pub(crate) static ENTRY_INFLECTION_18277295203675481446: VariantsMap = [
    &["inflection"],
    &["inflection", "inflexion"],
    &["inflection"],
    &["inflection", "inflexion"],
];

pub(crate) static ENTRY_INFORMALIZES_18331346153817933485: VariantsMap = [
    &["informalizes"],
    &["informalises"],
    &["informalizes"],
    &["informalises"],
];

pub(crate) static ENTRY_INFORMALIZE_17940073891680185003: VariantsMap = [
    &["informalize"],
    &["informalise"],
    &["informalize"],
    &["informalise"],
];

pub(crate) static ENTRY_INGVEONIC_413063112298926439: VariantsMap = [
    &["ingveonic"],
    &["ingvaeonic"],
    &["ingvaeonic"],
    &["ingvaeonic"],
];

pub(crate) static ENTRY_INGWEONIC_16714590859602524090: VariantsMap = [
    &["ingweonic"],
    &["ingwaeonic"],
    &["ingwaeonic"],
    &["ingwaeonic"],
];

pub(crate) static ENTRY_INHUMANIZES_6552273656617294035: VariantsMap = [
    &["inhumanizes"],
    &["inhumanises"],
    &["inhumanizes"],
    &["inhumanises"],
];

pub(crate) static ENTRY_INHUMANIZE_3302484678912696855: VariantsMap = [
    &["inhumanize"],
    &["inhumanise"],
    &["inhumanize"],
    &["inhumanise"],
];

pub(crate) static ENTRY_INITIALED_15902103209860719864: VariantsMap = [
    &["initialed"],
    &["initialled"],
    &["initialled"],
    &["initialled"],
];

pub(crate) static ENTRY_INITIALERS_14216906570899119339: VariantsMap = [
    &["initialers"],
    &["initiallers"],
    &["initiallers"],
    &["initiallers"],
];

pub(crate) static ENTRY_INITIALER_5954000900659273870: VariantsMap = [
    &["initialer"],
    &["initialler"],
    &["initialler"],
    &["initialler"],
];

pub(crate) static ENTRY_INITIALING_12788057999224789960: VariantsMap = [
    &["initialing"],
    &["initialling"],
    &["initialling"],
    &["initialling"],
];

pub(crate) static ENTRY_INITIALIZABLE_13567465264773221447: VariantsMap = [
    &["initializable"],
    &["initialisable"],
    &["initializable"],
    &["initialisable"],
];

pub(crate) static ENTRY_INITIALIZATIONS_11293364423346468549: VariantsMap = [
    &["initializations"],
    &["initialisations"],
    &["initializations"],
    &["initialisations"],
];

pub(crate) static ENTRY_INITIALIZATION_590649834113769182: VariantsMap = [
    &["initialization"],
    &["initialisation"],
    &["initialization"],
    &["initialisation"],
];

pub(crate) static ENTRY_INITIALIZED_15301195923117397100: VariantsMap = [
    &["initialized"],
    &["initialised"],
    &["initialized"],
    &["initialised"],
];

pub(crate) static ENTRY_INITIALIZERS_11909320122902748010: VariantsMap = [
    &["initializers"],
    &["initialisers"],
    &["initializers"],
    &["initialisers"],
];

pub(crate) static ENTRY_INITIALIZER_15184707483335003268: VariantsMap = [
    &["initializer"],
    &["initialiser"],
    &["initializer"],
    &["initialiser"],
];

pub(crate) static ENTRY_INITIALIZES_18102819297915065203: VariantsMap = [
    &["initializes"],
    &["initialises"],
    &["initializes"],
    &["initialises"],
];

pub(crate) static ENTRY_INITIALIZE_12324019979030561655: VariantsMap = [
    &["initialize"],
    &["initialise"],
    &["initialize"],
    &["initialise"],
];

pub(crate) static ENTRY_INITIALIZING_12464707441303468819: VariantsMap = [
    &["initializing"],
    &["initialising"],
    &["initializing"],
    &["initialising"],
];

pub(crate) static ENTRY_INORGANIZATIONS_11391650383722001073: VariantsMap = [
    &["inorganizations"],
    &["inorganisations"],
    &["inorganizations"],
    &["inorganisations"],
];

pub(crate) static ENTRY_INORGANIZATION_6464080564328640776: VariantsMap = [
    &["inorganization"],
    &["inorganisation"],
    &["inorganization"],
    &["inorganisation"],
];

pub(crate) static ENTRY_INORGANIZED_11950679744367883661: VariantsMap = [
    &["inorganized"],
    &["inorganised"],
    &["inorganized"],
    &["inorganised"],
];

pub(crate) static ENTRY_INQUIRED_859881660768366050: VariantsMap = [
    &["inquired"],
    &["enquired", "inquired"],
    &["inquired"],
    &["enquired", "inquired"],
];

pub(crate) static ENTRY_INQUIRES_15638770793218138085: VariantsMap = [
    &["inquires"],
    &["enquires", "inquires"],
    &["inquires"],
    &["enquires", "inquires"],
];

pub(crate) static ENTRY_INQUIRE_9931226624157807030: VariantsMap = [
    &["inquire"],
    &["enquire", "inquire"],
    &["inquire"],
    &["enquire", "inquire"],
];

pub(crate) static ENTRY_INQUIRIES_14785300041968074867: VariantsMap = [
    &["inquiries"],
    &["enquiries", "inquiries"],
    &["inquiries"],
    &["enquiries", "inquiries"],
];

pub(crate) static ENTRY_INQUIRING_8930995414308740890: VariantsMap = [
    &["inquiring"],
    &["enquiring", "inquiring"],
    &["inquiring"],
    &["enquiring", "inquiring"],
];

pub(crate) static ENTRY_INQUIRY_8834861104825329029: VariantsMap = [
    &["inquiry"],
    &["enquiry", "inquiry"],
    &["inquiry"],
    &["enquiry", "inquiry"],
];

pub(crate) static ENTRY_INSOLUBILIZATION_2468206011000375939: VariantsMap = [
    &["insolubilization"],
    &["insolubilisation"],
    &["insolubilization"],
    &["insolubilisation"],
];

pub(crate) static ENTRY_INSOLUBILIZED_8213269300954716710: VariantsMap = [
    &["insolubilized"],
    &["insolubilised"],
    &["insolubilized"],
    &["insolubilised"],
];

pub(crate) static ENTRY_INSOLUBILIZES_6981064901436679943: VariantsMap = [
    &["insolubilizes"],
    &["insolubilises"],
    &["insolubilizes"],
    &["insolubilises"],
];

pub(crate) static ENTRY_INSOLUBILIZE_11207340293843755530: VariantsMap = [
    &["insolubilize"],
    &["insolubilise"],
    &["insolubilize"],
    &["insolubilise"],
];

pub(crate) static ENTRY_INSOLUBILIZING_6097839015347270218: VariantsMap = [
    &["insolubilizing"],
    &["insolubilising"],
    &["insolubilizing"],
    &["insolubilising"],
];

pub(crate) static ENTRY_INSTALLMENTS_12858268561173152905: VariantsMap = [
    &["installments"],
    &["instalments"],
    &["instalments"],
    &["instalments"],
];

pub(crate) static ENTRY_INSTALLMENT_12886693295291815493: VariantsMap = [
    &["installment"],
    &["instalment"],
    &["instalment"],
    &["instalment"],
];

pub(crate) static ENTRY_INSTALLS_3461768427562416254: VariantsMap =
    [&["installs"], &["installs"], &["installs"], &["installs"]];

pub(crate) static ENTRY_INSTALL_15816930015169857728: VariantsMap =
    [&["install"], &["install"], &["install"], &["install"]];

pub(crate) static ENTRY_INSTILLS_5925820004112489897: VariantsMap =
    [&["instills"], &["instils"], &["instills"], &["instils"]];

pub(crate) static ENTRY_INSTILL_818656269309790815: VariantsMap =
    [&["instill"], &["instil"], &["instill"], &["instil"]];

pub(crate) static ENTRY_INSTITUTIONALIZATIONS_9914961461183238934: VariantsMap = [
    &["institutionalizations"],
    &["institutionalisations"],
    &["institutionalizations"],
    &["institutionalisations"],
];

pub(crate) static ENTRY_INSTITUTIONALIZATION_16914483925074067352: VariantsMap = [
    &["institutionalization"],
    &["institutionalisation"],
    &["institutionalization"],
    &["institutionalisation"],
];

pub(crate) static ENTRY_INSTITUTIONALIZED_7693436138088669527: VariantsMap = [
    &["institutionalized"],
    &["institutionalised"],
    &["institutionalized"],
    &["institutionalised"],
];

pub(crate) static ENTRY_INSTITUTIONALIZES_14636735774131912950: VariantsMap = [
    &["institutionalizes"],
    &["institutionalises"],
    &["institutionalizes"],
    &["institutionalises"],
];

pub(crate) static ENTRY_INSTITUTIONALIZE_17179024303922716440: VariantsMap = [
    &["institutionalize"],
    &["institutionalise"],
    &["institutionalize"],
    &["institutionalise"],
];

pub(crate) static ENTRY_INSTITUTIONALIZING_16851706637198417031: VariantsMap = [
    &["institutionalizing"],
    &["institutionalising"],
    &["institutionalizing"],
    &["institutionalising"],
];

pub(crate) static ENTRY_INSTITUTIONIZES_14238203048319257623: VariantsMap = [
    &["institutionizes"],
    &["institutionises"],
    &["institutionizes"],
    &["institutionises"],
];

pub(crate) static ENTRY_INSTITUTIONIZE_7513388810568141965: VariantsMap = [
    &["institutionize"],
    &["institutionise"],
    &["institutionize"],
    &["institutionise"],
];

pub(crate) static ENTRY_INSTRUMENTALIZES_4326655277485916636: VariantsMap = [
    &["instrumentalizes"],
    &["instrumentalises"],
    &["instrumentalizes"],
    &["instrumentalises"],
];

pub(crate) static ENTRY_INSTRUMENTALIZE_10032785258018795465: VariantsMap = [
    &["instrumentalize"],
    &["instrumentalise"],
    &["instrumentalize"],
    &["instrumentalise"],
];

pub(crate) static ENTRY_INSULARIZES_14593326132116957735: VariantsMap = [
    &["insularizes"],
    &["insularises"],
    &["insularizes"],
    &["insularises"],
];

pub(crate) static ENTRY_INSULARIZE_5847883247395880273: VariantsMap = [
    &["insularize"],
    &["insularise"],
    &["insularize"],
    &["insularise"],
];

pub(crate) static ENTRY_INSURRECTIONIZED_6658943096112240684: VariantsMap = [
    &["insurrectionized"],
    &["insurrectionised"],
    &["insurrectionized"],
    &["insurrectionised"],
];

pub(crate) static ENTRY_INSURRECTIONIZES_2098678701227756077: VariantsMap = [
    &["insurrectionizes"],
    &["insurrectionises"],
    &["insurrectionizes"],
    &["insurrectionises"],
];

pub(crate) static ENTRY_INSURRECTIONIZE_15791518478893150782: VariantsMap = [
    &["insurrectionize"],
    &["insurrectionise"],
    &["insurrectionize"],
    &["insurrectionise"],
];

pub(crate) static ENTRY_INSURRECTIONIZING_9166144284813042774: VariantsMap = [
    &["insurrectionizing"],
    &["insurrectionising"],
    &["insurrectionizing"],
    &["insurrectionising"],
];

pub(crate) static ENTRY_INTEGRALIZATIONS_5667120705219825596: VariantsMap = [
    &["integralizations"],
    &["integralisations"],
    &["integralizations"],
    &["integralisations"],
];

pub(crate) static ENTRY_INTEGRALIZATION_6109417690368879082: VariantsMap = [
    &["integralization"],
    &["integralisation"],
    &["integralization"],
    &["integralisation"],
];

pub(crate) static ENTRY_INTEGRALIZES_9034345402956567798: VariantsMap = [
    &["integralizes"],
    &["integralises"],
    &["integralizes"],
    &["integralises"],
];

pub(crate) static ENTRY_INTEGRALIZE_4916756234988815852: VariantsMap = [
    &["integralize"],
    &["integralise"],
    &["integralize"],
    &["integralise"],
];

pub(crate) static ENTRY_INTELLECTUALIZATIONS_4063570221687495690: VariantsMap = [
    &["intellectualizations"],
    &["intellectualisations"],
    &["intellectualizations"],
    &["intellectualisations"],
];

pub(crate) static ENTRY_INTELLECTUALIZATION_5603740918704433815: VariantsMap = [
    &["intellectualization"],
    &["intellectualisation"],
    &["intellectualization"],
    &["intellectualisation"],
];

pub(crate) static ENTRY_INTELLECTUALIZED_1369730666677628659: VariantsMap = [
    &["intellectualized"],
    &["intellectualised"],
    &["intellectualized"],
    &["intellectualised"],
];

pub(crate) static ENTRY_INTELLECTUALIZERS_5257248536965240227: VariantsMap = [
    &["intellectualizers"],
    &["intellectualisers"],
    &["intellectualizers"],
    &["intellectualisers"],
];

pub(crate) static ENTRY_INTELLECTUALIZER_18038380741729552808: VariantsMap = [
    &["intellectualizer"],
    &["intellectualiser"],
    &["intellectualizer"],
    &["intellectualiser"],
];

pub(crate) static ENTRY_INTELLECTUALIZES_7905351319809097487: VariantsMap = [
    &["intellectualizes"],
    &["intellectualises"],
    &["intellectualizes"],
    &["intellectualises"],
];

pub(crate) static ENTRY_INTELLECTUALIZE_11938342110187123902: VariantsMap = [
    &["intellectualize"],
    &["intellectualise"],
    &["intellectualize"],
    &["intellectualise"],
];

pub(crate) static ENTRY_INTELLECTUALIZING_11651251432471897085: VariantsMap = [
    &["intellectualizing"],
    &["intellectualising"],
    &["intellectualizing"],
    &["intellectualising"],
];

pub(crate) static ENTRY_INTERCIVILIZATIONS_3542228287854093291: VariantsMap = [
    &["intercivilizations"],
    &["intercivilisations"],
    &["intercivilizations"],
    &["intercivilisations"],
];

pub(crate) static ENTRY_INTERCIVILIZATION_6730243652879059378: VariantsMap = [
    &["intercivilization"],
    &["intercivilisation"],
    &["intercivilization"],
    &["intercivilisation"],
];

pub(crate) static ENTRY_INTERCOLONIZATIONS_3566824182005074807: VariantsMap = [
    &["intercolonizations"],
    &["intercolonisations"],
    &["intercolonizations"],
    &["intercolonisations"],
];

pub(crate) static ENTRY_INTERCOLONIZATION_17649422504500509174: VariantsMap = [
    &["intercolonization"],
    &["intercolonisation"],
    &["intercolonization"],
    &["intercolonisation"],
];

pub(crate) static ENTRY_INTERCRYSTALLIZATIONS_17753756237124408594: VariantsMap = [
    &["intercrystallizations"],
    &["intercrystallisations"],
    &["intercrystallizations"],
    &["intercrystallisations"],
];

pub(crate) static ENTRY_INTERCRYSTALLIZATION_12999096268518190465: VariantsMap = [
    &["intercrystallization"],
    &["intercrystallisation"],
    &["intercrystallization"],
    &["intercrystallisation"],
];

pub(crate) static ENTRY_INTERCRYSTALLIZES_11383858119955128987: VariantsMap = [
    &["intercrystallizes"],
    &["intercrystallises"],
    &["intercrystallizes"],
    &["intercrystallises"],
];

pub(crate) static ENTRY_INTERCRYSTALLIZE_14628274758100113148: VariantsMap = [
    &["intercrystallize"],
    &["intercrystallise"],
    &["intercrystallize"],
    &["intercrystallise"],
];

pub(crate) static ENTRY_INTERHEMAL_15034494580751452155: VariantsMap = [
    &["interhemal"],
    &["interhaemal"],
    &["interhaemal"],
    &["interhaemal"],
];

pub(crate) static ENTRY_INTERHYBRIDIZES_497894455147107388: VariantsMap = [
    &["interhybridizes"],
    &["interhybridises"],
    &["interhybridizes"],
    &["interhybridises"],
];

pub(crate) static ENTRY_INTERHYBRIDIZE_668520718186808081: VariantsMap = [
    &["interhybridize"],
    &["interhybridise"],
    &["interhybridize"],
    &["interhybridise"],
];

pub(crate) static ENTRY_INTERIORIZATION_17483234302135311883: VariantsMap = [
    &["interiorization"],
    &["interiorisation"],
    &["interiorization"],
    &["interiorisation"],
];

pub(crate) static ENTRY_INTERIORIZED_6788051806688856581: VariantsMap = [
    &["interiorized"],
    &["interiorised"],
    &["interiorized"],
    &["interiorised"],
];

pub(crate) static ENTRY_INTERIORIZES_7201579775546454896: VariantsMap = [
    &["interiorizes"],
    &["interiorises"],
    &["interiorizes"],
    &["interiorises"],
];

pub(crate) static ENTRY_INTERIORIZE_1278621744135628260: VariantsMap = [
    &["interiorize"],
    &["interiorise"],
    &["interiorize"],
    &["interiorise"],
];

pub(crate) static ENTRY_INTERIORIZING_4906116630681746350: VariantsMap = [
    &["interiorizing"],
    &["interiorising"],
    &["interiorizing"],
    &["interiorising"],
];

pub(crate) static ENTRY_INTERJECTIONALIZED_3066085716805350356: VariantsMap = [
    &["interjectionalized"],
    &["interjectionalised"],
    &["interjectionalized"],
    &["interjectionalised"],
];

pub(crate) static ENTRY_INTERJECTIONALIZES_4573160062771210721: VariantsMap = [
    &["interjectionalizes"],
    &["interjectionalises"],
    &["interjectionalizes"],
    &["interjectionalises"],
];

pub(crate) static ENTRY_INTERJECTIONALIZE_13118177918009055653: VariantsMap = [
    &["interjectionalize"],
    &["interjectionalise"],
    &["interjectionalize"],
    &["interjectionalise"],
];

pub(crate) static ENTRY_INTERJECTIONALIZING_5359472829969423658: VariantsMap = [
    &["interjectionalizing"],
    &["interjectionalising"],
    &["interjectionalizing"],
    &["interjectionalising"],
];

pub(crate) static ENTRY_INTERJECTIONIZES_11959393792338129862: VariantsMap = [
    &["interjectionizes"],
    &["interjectionises"],
    &["interjectionizes"],
    &["interjectionises"],
];

pub(crate) static ENTRY_INTERJECTIONIZE_9169632213587887120: VariantsMap = [
    &["interjectionize"],
    &["interjectionise"],
    &["interjectionize"],
    &["interjectionise"],
];

pub(crate) static ENTRY_INTERJUDGMENTS_2098512032698607985: VariantsMap = [
    &["interjudgments"],
    &["interjudgements"],
    &["interjudgements"],
    &["interjudgements"],
];

pub(crate) static ENTRY_INTERJUDGMENT_1640083221699385249: VariantsMap = [
    &["interjudgment"],
    &["interjudgement"],
    &["interjudgement"],
    &["interjudgement"],
];

pub(crate) static ENTRY_INTERNALIZATIONS_5057687877137841458: VariantsMap = [
    &["internalizations"],
    &["internalisations"],
    &["internalizations"],
    &["internalisations"],
];

pub(crate) static ENTRY_INTERNALIZATION_603288853246606634: VariantsMap = [
    &["internalization"],
    &["internalisation"],
    &["internalization"],
    &["internalisation"],
];

pub(crate) static ENTRY_INTERNALIZED_16309550961213758253: VariantsMap = [
    &["internalized"],
    &["internalised"],
    &["internalized"],
    &["internalised"],
];

pub(crate) static ENTRY_INTERNALIZES_13136383420864185970: VariantsMap = [
    &["internalizes"],
    &["internalises"],
    &["internalizes"],
    &["internalises"],
];

pub(crate) static ENTRY_INTERNALIZE_3793676571111920632: VariantsMap = [
    &["internalize"],
    &["internalise"],
    &["internalize"],
    &["internalise"],
];

pub(crate) static ENTRY_INTERNALIZING_13806294993771050282: VariantsMap = [
    &["internalizing"],
    &["internalising"],
    &["internalizing"],
    &["internalising"],
];

pub(crate) static ENTRY_INTERNATIONALIZATIONS_6708926163950225930: VariantsMap = [
    &["internationalizations"],
    &["internationalisations"],
    &["internationalizations"],
    &["internationalisations"],
];

pub(crate) static ENTRY_INTERNATIONALIZATION_6644139225428402812: VariantsMap = [
    &["internationalization"],
    &["internationalisation"],
    &["internationalization"],
    &["internationalisation"],
];

pub(crate) static ENTRY_INTERNATIONALIZED_12532701823222614624: VariantsMap = [
    &["internationalized"],
    &["internationalised"],
    &["internationalized"],
    &["internationalised"],
];

pub(crate) static ENTRY_INTERNATIONALIZES_3638667411109828830: VariantsMap = [
    &["internationalizes"],
    &["internationalises"],
    &["internationalizes"],
    &["internationalises"],
];

pub(crate) static ENTRY_INTERNATIONALIZE_10844257627404265374: VariantsMap = [
    &["internationalize"],
    &["internationalise"],
    &["internationalize"],
    &["internationalise"],
];

pub(crate) static ENTRY_INTERNATIONALIZING_1991011473935504392: VariantsMap = [
    &["internationalizing"],
    &["internationalising"],
    &["internationalizing"],
    &["internationalising"],
];

pub(crate) static ENTRY_INTERORGANIZATIONAL_7529374351884504219: VariantsMap = [
    &["interorganizational"],
    &["interorganisational"],
    &["interorganizational"],
    &["interorganisational"],
];

pub(crate) static ENTRY_INTIME_5742590895735721416: VariantsMap =
    [&["intime"], &["intimae"], &["intimae"], &["intimae"]];

pub(crate) static ENTRY_INTRAORGANIZATIONS_17967234739758363124: VariantsMap = [
    &["intraorganizations"],
    &["intraorganisations"],
    &["intraorganizations"],
    &["intraorganisations"],
];

pub(crate) static ENTRY_INTRAORGANIZATION_16469167469278073028: VariantsMap = [
    &["intraorganization"],
    &["intraorganisation"],
    &["intraorganization"],
    &["intraorganisation"],
];

pub(crate) static ENTRY_INVIGOR_819999460986594740: VariantsMap =
    [&["invigor"], &["invigour"], &["invigour"], &["invigour"]];

pub(crate) static ENTRY_IODIZATION_7852412987887174351: VariantsMap = [
    &["iodization"],
    &["iodisation"],
    &["iodization"],
    &["iodisation"],
];

pub(crate) static ENTRY_IODIZED_5589078459430909426: VariantsMap =
    [&["iodized"], &["iodised"], &["iodized"], &["iodised"]];

pub(crate) static ENTRY_IODIZERS_1535695457797432568: VariantsMap =
    [&["iodizers"], &["iodisers"], &["iodizers"], &["iodisers"]];

pub(crate) static ENTRY_IODIZER_1540933078597474373: VariantsMap =
    [&["iodizer"], &["iodiser"], &["iodizer"], &["iodiser"]];

pub(crate) static ENTRY_IODIZES_6118120030788983283: VariantsMap =
    [&["iodizes"], &["iodises"], &["iodizes"], &["iodises"]];

pub(crate) static ENTRY_IODIZE_1306425172808849701: VariantsMap =
    [&["iodize"], &["iodise"], &["iodize"], &["iodise"]];

pub(crate) static ENTRY_IODIZING_930016750218813133: VariantsMap =
    [&["iodizing"], &["iodising"], &["iodizing"], &["iodising"]];

pub(crate) static ENTRY_IONICIZATIONS_1024474224969699416: VariantsMap = [
    &["ionicizations"],
    &["ionicisations"],
    &["ionicizations"],
    &["ionicisations"],
];

pub(crate) static ENTRY_IONICIZATION_8114160155312209553: VariantsMap = [
    &["ionicization"],
    &["ionicisation"],
    &["ionicization"],
    &["ionicisation"],
];

pub(crate) static ENTRY_IONICIZED_10948195635909827159: VariantsMap = [
    &["ionicized"],
    &["ionicised"],
    &["ionicized"],
    &["ionicised"],
];

pub(crate) static ENTRY_IONICIZES_12301869180645911206: VariantsMap = [
    &["ionicizes"],
    &["ionicises"],
    &["ionicizes"],
    &["ionicises"],
];

pub(crate) static ENTRY_IONICIZE_17749931681916567842: VariantsMap =
    [&["ionicize"], &["ionicise"], &["ionicize"], &["ionicise"]];

pub(crate) static ENTRY_IONICIZING_9793219008400567780: VariantsMap = [
    &["ionicizing"],
    &["ionicising"],
    &["ionicizing"],
    &["ionicising"],
];

pub(crate) static ENTRY_IONIZABLER_16464484515284442321: VariantsMap = [
    &["ionizabler"],
    &["ionisabler"],
    &["ionizabler"],
    &["ionisabler"],
];

pub(crate) static ENTRY_IONIZABLEST_11814301960561543823: VariantsMap = [
    &["ionizablest"],
    &["ionisablest"],
    &["ionizablest"],
    &["ionisablest"],
];

pub(crate) static ENTRY_IONIZABLES_8313950107455257059: VariantsMap = [
    &["ionizables"],
    &["ionisables"],
    &["ionizables"],
    &["ionisables"],
];

pub(crate) static ENTRY_IONIZABLE_2644993999701298176: VariantsMap = [
    &["ionizable"],
    &["ionisable"],
    &["ionizable"],
    &["ionisable"],
];

pub(crate) static ENTRY_IONIZATIONS_13158526918879542436: VariantsMap = [
    &["ionizations"],
    &["ionisations"],
    &["ionizations"],
    &["ionisations"],
];

pub(crate) static ENTRY_IONIZATION_8191072411043319491: VariantsMap = [
    &["ionization"],
    &["ionisation"],
    &["ionization"],
    &["ionisation"],
];

pub(crate) static ENTRY_IONIZED_2589085332884313053: VariantsMap =
    [&["ionized"], &["ionised"], &["ionized"], &["ionised"]];

pub(crate) static ENTRY_IONIZERS_17432893927149158571: VariantsMap =
    [&["ionizers"], &["ionizers"], &["ionizers"], &["ionizers"]];

pub(crate) static ENTRY_IONIZER_16865151505607853304: VariantsMap =
    [&["ionizer"], &["ionizer"], &["ionizer"], &["ionizer"]];

pub(crate) static ENTRY_IONIZES_10700550406719206692: VariantsMap =
    [&["ionizes"], &["ionises"], &["ionizes"], &["ionises"]];

pub(crate) static ENTRY_IONIZE_7165534751673675076: VariantsMap =
    [&["ionize"], &["ionise"], &["ionize"], &["ionise"]];

pub(crate) static ENTRY_IONIZINGS_654410480601582690: VariantsMap = [
    &["ionizings"],
    &["ionisings"],
    &["ionizings"],
    &["ionisings"],
];

pub(crate) static ENTRY_IONIZING_6475308404816427379: VariantsMap =
    [&["ionizing"], &["ionising"], &["ionizing"], &["ionising"]];

pub(crate) static ENTRY_IONIZIONS_997469529664998632: VariantsMap = [
    &["ionizions"],
    &["ionisions"],
    &["ionizions"],
    &["ionisions"],
];

pub(crate) static ENTRY_IONIZION_9972155122605885625: VariantsMap =
    [&["ionizion"], &["ionision"], &["ionizion"], &["ionision"]];

pub(crate) static ENTRY_IPHINOE_10820574830726341241: VariantsMap =
    [&["iphinoe"], &["iphinoae"], &["iphinoae"], &["iphinoae"]];

pub(crate) static ENTRY_IPOMEA_6176464903246802743: VariantsMap =
    [&["ipomea"], &["ipomoea"], &["ipomoea"], &["ipomoea"]];

pub(crate) static ENTRY_IRANIZES_68228530325041736: VariantsMap =
    [&["iranizes"], &["iranises"], &["iranizes"], &["iranises"]];

pub(crate) static ENTRY_IRANIZE_16097053982564268585: VariantsMap =
    [&["iranize"], &["iranise"], &["iranize"], &["iranise"]];

pub(crate) static ENTRY_IRICIZED_3558520207738706190: VariantsMap =
    [&["iricized"], &["iricised"], &["iricized"], &["iricised"]];

pub(crate) static ENTRY_IRICIZE_13420716537315253439: VariantsMap =
    [&["iricize"], &["iricise"], &["iricize"], &["iricise"]];

pub(crate) static ENTRY_IRICIZING_6592551583850585470: VariantsMap = [
    &["iricizing"],
    &["iricising"],
    &["iricizing"],
    &["iricising"],
];

pub(crate) static ENTRY_IRIDECTOMIZED_5854155027181535016: VariantsMap = [
    &["iridectomized"],
    &["iridectomised"],
    &["iridectomized"],
    &["iridectomised"],
];

pub(crate) static ENTRY_IRIDECTOMIZE_14800091260065604008: VariantsMap = [
    &["iridectomize"],
    &["iridectomise"],
    &["iridectomize"],
    &["iridectomise"],
];

pub(crate) static ENTRY_IRIDECTOMIZING_8902043056320366009: VariantsMap = [
    &["iridectomizing"],
    &["iridectomising"],
    &["iridectomizing"],
    &["iridectomising"],
];

pub(crate) static ENTRY_IRIDIZATIONS_4735971979530479099: VariantsMap = [
    &["iridizations"],
    &["iridisations"],
    &["iridizations"],
    &["iridisations"],
];

pub(crate) static ENTRY_IRIDIZATION_7181298283830728332: VariantsMap = [
    &["iridization"],
    &["iridisation"],
    &["iridization"],
    &["iridisation"],
];

pub(crate) static ENTRY_IRIDIZED_8119592807478143588: VariantsMap =
    [&["iridized"], &["iridised"], &["iridized"], &["iridised"]];

pub(crate) static ENTRY_IRIDIZES_7904221985039237377: VariantsMap =
    [&["iridizes"], &["iridises"], &["iridizes"], &["iridises"]];

pub(crate) static ENTRY_IRIDIZE_6299505185614291769: VariantsMap =
    [&["iridize"], &["iridise"], &["iridize"], &["iridise"]];

pub(crate) static ENTRY_IRIDIZING_9856895728412037323: VariantsMap = [
    &["iridizing"],
    &["iridising"],
    &["iridizing"],
    &["iridising"],
];

pub(crate) static ENTRY_IRISHIZED_16512539711227053972: VariantsMap = [
    &["irishized"],
    &["irishised"],
    &["irishized"],
    &["irishised"],
];

pub(crate) static ENTRY_IRISHIZES_17227074225879136075: VariantsMap = [
    &["irishizes"],
    &["irishises"],
    &["irishizes"],
    &["irishises"],
];

pub(crate) static ENTRY_IRISHIZE_8208979161436390733: VariantsMap =
    [&["irishize"], &["irishise"], &["irishize"], &["irishise"]];

pub(crate) static ENTRY_IRISHIZING_6073346360037358565: VariantsMap = [
    &["irishizing"],
    &["irishising"],
    &["irishizing"],
    &["irishising"],
];

pub(crate) static ENTRY_IRONIZED_12346354122830372870: VariantsMap =
    [&["ironized"], &["ironised"], &["ironized"], &["ironised"]];

pub(crate) static ENTRY_IRONIZES_13827125916393146079: VariantsMap =
    [&["ironizes"], &["ironises"], &["ironizes"], &["ironises"]];

pub(crate) static ENTRY_IRONIZE_17130349938134447427: VariantsMap =
    [&["ironize"], &["ironise"], &["ironize"], &["ironise"]];

pub(crate) static ENTRY_IRONIZING_1675961958393611973: VariantsMap = [
    &["ironizing"],
    &["ironising"],
    &["ironizing"],
    &["ironising"],
];

pub(crate) static ENTRY_IRRATIONALIZED_4894371714487406565: VariantsMap = [
    &["irrationalized"],
    &["irrationalised"],
    &["irrationalized"],
    &["irrationalised"],
];

pub(crate) static ENTRY_IRRATIONALIZES_11632524485207866679: VariantsMap = [
    &["irrationalizes"],
    &["irrationalises"],
    &["irrationalizes"],
    &["irrationalises"],
];

pub(crate) static ENTRY_IRRATIONALIZE_4790151684217192380: VariantsMap = [
    &["irrationalize"],
    &["irrationalise"],
    &["irrationalize"],
    &["irrationalise"],
];

pub(crate) static ENTRY_IRRATIONALIZING_9204654902470879187: VariantsMap = [
    &["irrationalizing"],
    &["irrationalising"],
    &["irrationalizing"],
    &["irrationalising"],
];

pub(crate) static ENTRY_IRREALIZABLE_15796792683122916865: VariantsMap = [
    &["irrealizable"],
    &["irrealisable"],
    &["irrealizable"],
    &["irrealisable"],
];

pub(crate) static ENTRY_IRRECOGNIZABLE_3060885004389452161: VariantsMap = [
    &["irrecognizable"],
    &["irrecognisable"],
    &["irrecognizable"],
    &["irrecognisable"],
];

pub(crate) static ENTRY_IRREGULARIZES_4400387657632970784: VariantsMap = [
    &["irregularizes"],
    &["irregularises"],
    &["irregularizes"],
    &["irregularises"],
];

pub(crate) static ENTRY_IRREGULARIZE_5521004822910043625: VariantsMap = [
    &["irregularize"],
    &["irregularise"],
    &["irregularize"],
    &["irregularise"],
];

pub(crate) static ENTRY_ISCHEMIAS_9916394730153752763: VariantsMap = [
    &["ischemias"],
    &["ischaemias"],
    &["ischemias"],
    &["ischaemias"],
];

pub(crate) static ENTRY_ISCHEMIA_10554201921415637717: VariantsMap =
    [&["ischemia"], &["ischaemia"], &["ischemia"], &["ischaemia"]];

pub(crate) static ENTRY_ISCHEMIC_2442996153770242671: VariantsMap =
    [&["ischemic"], &["ischaemic"], &["ischemic"], &["ischaemic"]];

pub(crate) static ENTRY_ISLAMICIZED_18380651844723736945: VariantsMap = [
    &["islamicized"],
    &["islamicised"],
    &["islamicized"],
    &["islamicised"],
];

pub(crate) static ENTRY_ISLAMICIZES_6531803858717004235: VariantsMap = [
    &["islamicizes"],
    &["islamicises"],
    &["islamicizes"],
    &["islamicises"],
];

pub(crate) static ENTRY_ISLAMICIZE_7735780420905674726: VariantsMap = [
    &["islamicize"],
    &["islamicise"],
    &["islamicize"],
    &["islamicise"],
];

pub(crate) static ENTRY_ISLAMICIZING_15651039107985160416: VariantsMap = [
    &["islamicizing"],
    &["islamicising"],
    &["islamicizing"],
    &["islamicising"],
];

pub(crate) static ENTRY_ISLAMIZATIONS_9381105898108737278: VariantsMap = [
    &["islamizations"],
    &["islamisations"],
    &["islamizations"],
    &["islamisations"],
];

pub(crate) static ENTRY_ISLAMIZATION_5161145827363720674: VariantsMap = [
    &["islamization"],
    &["islamisation"],
    &["islamization"],
    &["islamisation"],
];

pub(crate) static ENTRY_ISLAMIZED_15758879196999391070: VariantsMap = [
    &["islamized"],
    &["islamised"],
    &["islamized"],
    &["islamised"],
];

pub(crate) static ENTRY_ISLAMIZES_367713927834001617: VariantsMap = [
    &["islamizes"],
    &["islamises"],
    &["islamizes"],
    &["islamises"],
];

pub(crate) static ENTRY_ISLAMIZE_10031573866824775797: VariantsMap =
    [&["islamize"], &["islamise"], &["islamize"], &["islamise"]];

pub(crate) static ENTRY_ISLAMIZING_18257296169100318444: VariantsMap = [
    &["islamizing"],
    &["islamising"],
    &["islamizing"],
    &["islamising"],
];

pub(crate) static ENTRY_ISOCHRONIZATION_6483472804939717463: VariantsMap = [
    &["isochronization"],
    &["isochronisation"],
    &["isochronization"],
    &["isochronisation"],
];

pub(crate) static ENTRY_ISOCHRONIZED_2637250779429085922: VariantsMap = [
    &["isochronized"],
    &["isochronised"],
    &["isochronized"],
    &["isochronised"],
];

pub(crate) static ENTRY_ISOCHRONIZES_1872858779043339096: VariantsMap = [
    &["isochronizes"],
    &["isochronises"],
    &["isochronizes"],
    &["isochronises"],
];

pub(crate) static ENTRY_ISOCHRONIZE_14918820840136762657: VariantsMap = [
    &["isochronize"],
    &["isochronise"],
    &["isochronize"],
    &["isochronise"],
];

pub(crate) static ENTRY_ISOCHRONIZING_8854802670752531573: VariantsMap = [
    &["isochronizing"],
    &["isochronising"],
    &["isochronizing"],
    &["isochronising"],
];

pub(crate) static ENTRY_ISOIMMUNIZATIONS_4834172440028031413: VariantsMap = [
    &["isoimmunizations"],
    &["isoimmunisations"],
    &["isoimmunizations"],
    &["isoimmunisations"],
];

pub(crate) static ENTRY_ISOIMMUNIZATION_6552840998782404550: VariantsMap = [
    &["isoimmunization"],
    &["isoimmunisation"],
    &["isoimmunization"],
    &["isoimmunisation"],
];

pub(crate) static ENTRY_ISOIMMUNIZES_1487221929616437869: VariantsMap = [
    &["isoimmunizes"],
    &["isoimmunises"],
    &["isoimmunizes"],
    &["isoimmunises"],
];

pub(crate) static ENTRY_ISOIMMUNIZE_8748728447679167149: VariantsMap = [
    &["isoimmunize"],
    &["isoimmunise"],
    &["isoimmunize"],
    &["isoimmunise"],
];

pub(crate) static ENTRY_ISOMERIZATIONS_15721561442741022660: VariantsMap = [
    &["isomerizations"],
    &["isomerisations"],
    &["isomerizations"],
    &["isomerisations"],
];

pub(crate) static ENTRY_ISOMERIZATION_3238007314114624559: VariantsMap = [
    &["isomerization"],
    &["isomerisation"],
    &["isomerization"],
    &["isomerisation"],
];

pub(crate) static ENTRY_ISOMERIZED_1507665941808946263: VariantsMap = [
    &["isomerized"],
    &["isomerised"],
    &["isomerized"],
    &["isomerised"],
];

pub(crate) static ENTRY_ISOMERIZES_13699385029679805302: VariantsMap = [
    &["isomerizes"],
    &["isomerises"],
    &["isomerizes"],
    &["isomerises"],
];

pub(crate) static ENTRY_ISOMERIZE_16508288804812196036: VariantsMap = [
    &["isomerize"],
    &["isomerise"],
    &["isomerize"],
    &["isomerise"],
];

pub(crate) static ENTRY_ISOMERIZING_15692416232400028339: VariantsMap = [
    &["isomerizing"],
    &["isomerising"],
    &["isomerizing"],
    &["isomerising"],
];

pub(crate) static ENTRY_ISRAELITIZES_11908037988878925722: VariantsMap = [
    &["israelitizes"],
    &["israelitises"],
    &["israelitizes"],
    &["israelitises"],
];

pub(crate) static ENTRY_ISRAELITIZE_3246052146927689302: VariantsMap = [
    &["israelitize"],
    &["israelitise"],
    &["israelitize"],
    &["israelitise"],
];

pub(crate) static ENTRY_ITALIANIZATIONS_10474942165716231128: VariantsMap = [
    &["italianizations"],
    &["italianisations"],
    &["italianizations"],
    &["italianisations"],
];

pub(crate) static ENTRY_ITALIANIZATION_14250016015990552361: VariantsMap = [
    &["italianization"],
    &["italianisation"],
    &["italianization"],
    &["italianisation"],
];

pub(crate) static ENTRY_ITALIANIZED_10760695417857256941: VariantsMap = [
    &["italianized"],
    &["italianised"],
    &["italianized"],
    &["italianised"],
];

pub(crate) static ENTRY_ITALIANIZERS_11063192194163579764: VariantsMap = [
    &["italianizers"],
    &["italianisers"],
    &["italianizers"],
    &["italianisers"],
];

pub(crate) static ENTRY_ITALIANIZER_2672999761166439124: VariantsMap = [
    &["italianizer"],
    &["italianiser"],
    &["italianizer"],
    &["italianiser"],
];

pub(crate) static ENTRY_ITALIANIZES_8123053655370321631: VariantsMap = [
    &["italianizes"],
    &["italianises"],
    &["italianizes"],
    &["italianises"],
];

pub(crate) static ENTRY_ITALIANIZE_7918264133057804472: VariantsMap = [
    &["italianize"],
    &["italianise"],
    &["italianize"],
    &["italianise"],
];

pub(crate) static ENTRY_ITALIANIZING_2433552009640661421: VariantsMap = [
    &["italianizing"],
    &["italianising"],
    &["italianizing"],
    &["italianising"],
];

pub(crate) static ENTRY_ITALICIZATIONS_8504692545843995442: VariantsMap = [
    &["italicizations"],
    &["italicisations"],
    &["italicizations"],
    &["italicisations"],
];

pub(crate) static ENTRY_ITALICIZATION_7637072269958036418: VariantsMap = [
    &["italicization"],
    &["italicisation"],
    &["italicization"],
    &["italicisation"],
];

pub(crate) static ENTRY_ITALICIZED_18008158115597569175: VariantsMap = [
    &["italicized"],
    &["italicised"],
    &["italicized"],
    &["italicised"],
];

pub(crate) static ENTRY_ITALICIZES_14940618929368461253: VariantsMap = [
    &["italicizes"],
    &["italicises"],
    &["italicizes"],
    &["italicises"],
];

pub(crate) static ENTRY_ITALICIZE_13351991321688846658: VariantsMap = [
    &["italicize"],
    &["italicise"],
    &["italicize"],
    &["italicise"],
];

pub(crate) static ENTRY_ITALICIZING_14716378013800458429: VariantsMap = [
    &["italicizing"],
    &["italicising"],
    &["italicizing"],
    &["italicising"],
];

pub(crate) static ENTRY_ITEMIZATIONS_6647254086503275130: VariantsMap = [
    &["itemizations"],
    &["itemisations"],
    &["itemizations"],
    &["itemisations"],
];

pub(crate) static ENTRY_ITEMIZATION_2083084966275745571: VariantsMap = [
    &["itemization"],
    &["itemisation"],
    &["itemization"],
    &["itemisation"],
];

pub(crate) static ENTRY_ITEMIZED_72220609705553029: VariantsMap =
    [&["itemized"], &["itemised"], &["itemized"], &["itemised"]];

pub(crate) static ENTRY_ITEMIZERS_15813642202533812081: VariantsMap = [
    &["itemizers"],
    &["itemisers"],
    &["itemizers"],
    &["itemisers"],
];

pub(crate) static ENTRY_ITEMIZER_7796142704743741765: VariantsMap =
    [&["itemizer"], &["itemiser"], &["itemizer"], &["itemiser"]];

pub(crate) static ENTRY_ITEMIZES_9916875436104019879: VariantsMap =
    [&["itemizes"], &["itemises"], &["itemizes"], &["itemises"]];

pub(crate) static ENTRY_ITEMIZE_1075679219292232313: VariantsMap =
    [&["itemize"], &["itemise"], &["itemize"], &["itemise"]];

pub(crate) static ENTRY_ITEMIZING_2983331397312369622: VariantsMap = [
    &["itemizing"],
    &["itemising"],
    &["itemizing"],
    &["itemising"],
];

pub(crate) static ENTRY_ITUREANS_10856642442618574214: VariantsMap = [
    &["itureans"],
    &["ituraeans"],
    &["ituraeans"],
    &["ituraeans"],
];

pub(crate) static ENTRY_ITUREAN_913167053546568742: VariantsMap =
    [&["iturean"], &["ituraean"], &["ituraean"], &["ituraean"]];

pub(crate) static ENTRY_IZING_17568077577465584284: VariantsMap =
    [&["izing"], &["ising"], &["izing"], &["ising"]];

pub(crate) static ENTRY_JACOBEAN_11417760184890412965: VariantsMap = [
    &["jacobean"],
    &["jacobaean"],
    &["jacobaean"],
    &["jacobaean"],
];

pub(crate) static ENTRY_JACOBINIZATION_12620112081606324932: VariantsMap = [
    &["jacobinization"],
    &["jacobinisation"],
    &["jacobinization"],
    &["jacobinisation"],
];

pub(crate) static ENTRY_JACOBINIZED_16734740525018333391: VariantsMap = [
    &["jacobinized"],
    &["jacobinised"],
    &["jacobinized"],
    &["jacobinised"],
];

pub(crate) static ENTRY_JACOBINIZES_12439906396616333709: VariantsMap = [
    &["jacobinizes"],
    &["jacobinises"],
    &["jacobinizes"],
    &["jacobinises"],
];

pub(crate) static ENTRY_JACOBINIZE_5488043839092421303: VariantsMap = [
    &["jacobinize"],
    &["jacobinise"],
    &["jacobinize"],
    &["jacobinise"],
];

pub(crate) static ENTRY_JACOBINIZING_5827891129505509789: VariantsMap = [
    &["jacobinizing"],
    &["jacobinising"],
    &["jacobinizing"],
    &["jacobinising"],
];

pub(crate) static ENTRY_JAILBIRDS_6287442130171297097: VariantsMap = [
    &["jailbirds"],
    &["jailbirds"],
    &["jailbirds"],
    &["jailbirds"],
];

pub(crate) static ENTRY_JAILBIRD_1212632149307874383: VariantsMap =
    [&["jailbird"], &["jailbird"], &["jailbird"], &["jailbird"]];

pub(crate) static ENTRY_JAILBREAKS_17258526740881807361: VariantsMap = [
    &["jailbreaks"],
    &["jailbreaks"],
    &["jailbreaks"],
    &["jailbreaks"],
];

pub(crate) static ENTRY_JAILBREAK_4699850190274924246: VariantsMap = [
    &["jailbreak"],
    &["jailbreak"],
    &["jailbreak"],
    &["jailbreak"],
];

pub(crate) static ENTRY_JAILED_1125764234507810906: VariantsMap =
    [&["jailed"], &["jailed"], &["jailed"], &["jailed"]];

pub(crate) static ENTRY_JAILERS_15685267405324816915: VariantsMap =
    [&["jailers"], &["jailers"], &["jailers"], &["jailers"]];

pub(crate) static ENTRY_JAILER_16794396359446182049: VariantsMap =
    [&["jailer"], &["jailer"], &["jailer"], &["jailer"]];

pub(crate) static ENTRY_JAILING_1957609231097707934: VariantsMap =
    [&["jailing"], &["jailing"], &["jailing"], &["jailing"]];

pub(crate) static ENTRY_JAILS_3678144083221559157: VariantsMap =
    [&["jails"], &["jails"], &["jails"], &["jails"]];

pub(crate) static ENTRY_JAIL_9355766415908209672: VariantsMap =
    [&["jail"], &["jail"], &["jail"], &["jail"]];

pub(crate) static ENTRY_JANIZARIES_6121939418222984809: VariantsMap = [
    &["janizaries"],
    &["janisaries"],
    &["janizaries"],
    &["janisaries"],
];

pub(crate) static ENTRY_JANIZARY_16123637942103352791: VariantsMap =
    [&["janizary"], &["janisary"], &["janizary"], &["janisary"]];

pub(crate) static ENTRY_JAPANIZATIONS_10733258963864816943: VariantsMap = [
    &["japanizations"],
    &["japanisations"],
    &["japanizations"],
    &["japanisations"],
];

pub(crate) static ENTRY_JAPANIZATION_6491057515566715056: VariantsMap = [
    &["japanization"],
    &["japanisation"],
    &["japanization"],
    &["japanisation"],
];

pub(crate) static ENTRY_JAPANIZED_16699065610857482639: VariantsMap = [
    &["japanized"],
    &["japanised"],
    &["japanized"],
    &["japanised"],
];

pub(crate) static ENTRY_JAPANIZES_14638537624267830566: VariantsMap = [
    &["japanizes"],
    &["japanises"],
    &["japanizes"],
    &["japanises"],
];

pub(crate) static ENTRY_JAPANIZE_2996326662592191647: VariantsMap =
    [&["japanize"], &["japanise"], &["japanize"], &["japanise"]];

pub(crate) static ENTRY_JAPANIZING_3419333967684428117: VariantsMap = [
    &["japanizing"],
    &["japanising"],
    &["japanizing"],
    &["japanising"],
];

pub(crate) static ENTRY_JARGONIZATIONS_6985667935933000202: VariantsMap = [
    &["jargonizations"],
    &["jargonisations"],
    &["jargonizations"],
    &["jargonisations"],
];

pub(crate) static ENTRY_JARGONIZATION_13803541119877702185: VariantsMap = [
    &["jargonization"],
    &["jargonisation"],
    &["jargonization"],
    &["jargonisation"],
];

pub(crate) static ENTRY_JARGONIZED_15791162347082638293: VariantsMap = [
    &["jargonized"],
    &["jargonised"],
    &["jargonized"],
    &["jargonised"],
];

pub(crate) static ENTRY_JARGONIZES_4998631633267950571: VariantsMap = [
    &["jargonizes"],
    &["jargonises"],
    &["jargonizes"],
    &["jargonises"],
];

pub(crate) static ENTRY_JARGONIZE_17586054368036140712: VariantsMap = [
    &["jargonize"],
    &["jargonise"],
    &["jargonize"],
    &["jargonise"],
];

pub(crate) static ENTRY_JARGONIZING_4259002532402415391: VariantsMap = [
    &["jargonizing"],
    &["jargonising"],
    &["jargonizing"],
    &["jargonising"],
];

pub(crate) static ENTRY_JASPERIZED_9097196520965048273: VariantsMap = [
    &["jasperized"],
    &["jasperised"],
    &["jasperized"],
    &["jasperised"],
];

pub(crate) static ENTRY_JASPERIZES_9601062795594168200: VariantsMap = [
    &["jasperizes"],
    &["jasperises"],
    &["jasperizes"],
    &["jasperises"],
];

pub(crate) static ENTRY_JASPERIZE_15228065557735283312: VariantsMap = [
    &["jasperize"],
    &["jasperise"],
    &["jasperize"],
    &["jasperise"],
];

pub(crate) static ENTRY_JASPERIZING_15834223553296081409: VariantsMap = [
    &["jasperizing"],
    &["jasperising"],
    &["jasperizing"],
    &["jasperising"],
];

pub(crate) static ENTRY_JEOPARDIZATION_8233628518568267550: VariantsMap = [
    &["jeopardization"],
    &["jeopardisation"],
    &["jeopardization"],
    &["jeopardisation"],
];

pub(crate) static ENTRY_JEOPARDIZED_4290897290667261086: VariantsMap = [
    &["jeopardized"],
    &["jeopardised"],
    &["jeopardized"],
    &["jeopardised"],
];

pub(crate) static ENTRY_JEOPARDIZES_1770057888942412589: VariantsMap = [
    &["jeopardizes"],
    &["jeopardises"],
    &["jeopardizes"],
    &["jeopardises"],
];

pub(crate) static ENTRY_JEOPARDIZE_7563132171286021122: VariantsMap = [
    &["jeopardize"],
    &["jeopardise"],
    &["jeopardize"],
    &["jeopardise"],
];

pub(crate) static ENTRY_JEOPARDIZING_11478877839793401266: VariantsMap = [
    &["jeopardizing"],
    &["jeopardising"],
    &["jeopardizing"],
    &["jeopardising"],
];

pub(crate) static ENTRY_JESUITIZATION_12076627418335111216: VariantsMap = [
    &["jesuitization"],
    &["jesuitisation"],
    &["jesuitization"],
    &["jesuitisation"],
];

pub(crate) static ENTRY_JESUITIZED_5064316526791201394: VariantsMap = [
    &["jesuitized"],
    &["jesuitised"],
    &["jesuitized"],
    &["jesuitised"],
];

pub(crate) static ENTRY_JESUITIZES_8149561683144943800: VariantsMap = [
    &["jesuitizes"],
    &["jesuitises"],
    &["jesuitizes"],
    &["jesuitises"],
];

pub(crate) static ENTRY_JESUITIZE_14648103267389726386: VariantsMap = [
    &["jesuitize"],
    &["jesuitise"],
    &["jesuitize"],
    &["jesuitise"],
];

pub(crate) static ENTRY_JESUITIZING_1670456186993799400: VariantsMap = [
    &["jesuitizing"],
    &["jesuitising"],
    &["jesuitizing"],
    &["jesuitising"],
];

pub(crate) static ENTRY_JEWELED_1164673326064560766: VariantsMap =
    [&["jeweled"], &["jewelled"], &["jewelled"], &["jewelled"]];

pub(crate) static ENTRY_JEWELERS_4919007304834585018: VariantsMap = [
    &["jewelers"],
    &["jewellers"],
    &["jewellers"],
    &["jewellers"],
];

pub(crate) static ENTRY_JEWELER_11683392478209510720: VariantsMap =
    [&["jeweler"], &["jeweller"], &["jeweller"], &["jeweller"]];

pub(crate) static ENTRY_JEWELING_17397805769460286766: VariantsMap = [
    &["jeweling"],
    &["jewelling"],
    &["jewelling"],
    &["jewelling"],
];

pub(crate) static ENTRY_JEWELRY_1265691138331552301: VariantsMap =
    [&["jewelry"], &["jewellery"], &["jewellery"], &["jewellery"]];

pub(crate) static ENTRY_JOKEY_1401133516029317070: VariantsMap =
    [&["jokey"], &["jokey"], &["jokey"], &["jokey"]];

pub(crate) static ENTRY_JONATHANIZATIONS_9684819613638525720: VariantsMap = [
    &["jonathanizations"],
    &["jonathanisations"],
    &["jonathanizations"],
    &["jonathanisations"],
];

pub(crate) static ENTRY_JONATHANIZATION_349407157278376320: VariantsMap = [
    &["jonathanization"],
    &["jonathanisation"],
    &["jonathanization"],
    &["jonathanisation"],
];

pub(crate) static ENTRY_JORS_13869203658420639286: VariantsMap =
    [&["jors"], &["jours"], &["jours"], &["jours"]];

pub(crate) static ENTRY_JOR_4372776148473778988: VariantsMap =
    [&["jor"], &["jour"], &["jour"], &["jour"]];

pub(crate) static ENTRY_JOURNALIZATIONS_8360098568590750822: VariantsMap = [
    &["journalizations"],
    &["journalisations"],
    &["journalizations"],
    &["journalisations"],
];

pub(crate) static ENTRY_JOURNALIZATION_13869741869452298927: VariantsMap = [
    &["journalization"],
    &["journalisation"],
    &["journalization"],
    &["journalisation"],
];

pub(crate) static ENTRY_JOURNALIZED_8816090977822832287: VariantsMap = [
    &["journalized"],
    &["journalised"],
    &["journalized"],
    &["journalised"],
];

pub(crate) static ENTRY_JOURNALIZERS_6645590336287424690: VariantsMap = [
    &["journalizers"],
    &["journalisers"],
    &["journalizers"],
    &["journalisers"],
];

pub(crate) static ENTRY_JOURNALIZER_16230238068690488425: VariantsMap = [
    &["journalizer"],
    &["journaliser"],
    &["journalizer"],
    &["journaliser"],
];

pub(crate) static ENTRY_JOURNALIZES_12274656852355418094: VariantsMap = [
    &["journalizes"],
    &["journalises"],
    &["journalizes"],
    &["journalises"],
];

pub(crate) static ENTRY_JOURNALIZE_7557433468559833421: VariantsMap = [
    &["journalize"],
    &["journalise"],
    &["journalize"],
    &["journalise"],
];

pub(crate) static ENTRY_JOURNALIZING_2527188867008816103: VariantsMap = [
    &["journalizing"],
    &["journalising"],
    &["journalizing"],
    &["journalising"],
];

pub(crate) static ENTRY_JOVIALIZES_16003736818573545855: VariantsMap = [
    &["jovializes"],
    &["jovialises"],
    &["jovializes"],
    &["jovialises"],
];

pub(crate) static ENTRY_JOVIALIZE_6055513817327603369: VariantsMap = [
    &["jovialize"],
    &["jovialise"],
    &["jovialize"],
    &["jovialise"],
];

pub(crate) static ENTRY_JUDAIZATION_8802637711012973186: VariantsMap = [
    &["judaization"],
    &["judaisation"],
    &["judaization"],
    &["judaisation"],
];

pub(crate) static ENTRY_JUDAIZED_11097537345612695567: VariantsMap =
    [&["judaized"], &["judaised"], &["judaized"], &["judaised"]];

pub(crate) static ENTRY_JUDAIZER_9074198258934684563: VariantsMap =
    [&["judaizer"], &["judaiser"], &["judaizer"], &["judaiser"]];

pub(crate) static ENTRY_JUDAIZE_12262219091800711286: VariantsMap =
    [&["judaize"], &["judaise"], &["judaize"], &["judaise"]];

pub(crate) static ENTRY_JUDAIZING_3118358796769865883: VariantsMap = [
    &["judaizing"],
    &["judaising"],
    &["judaizing"],
    &["judaising"],
];

pub(crate) static ENTRY_JUDEANS_9104141413565020951: VariantsMap =
    [&["judeans"], &["judaeans"], &["judaeans"], &["judaeans"]];

pub(crate) static ENTRY_JUDEAN_941286922202375422: VariantsMap =
    [&["judean"], &["judaean"], &["judaean"], &["judaean"]];

pub(crate) static ENTRY_JUDEOPHOBIA_5648063668971673358: VariantsMap = [
    &["judeophobia"],
    &["judaeophobia"],
    &["judaeophobia"],
    &["judaeophobia"],
];

pub(crate) static ENTRY_JUDGMENTS_3887014541133672054: VariantsMap = [
    &["judgments"],
    &["judgements"],
    &["judgments"],
    &["judgements"],
];

pub(crate) static ENTRY_JUDGMENT_16033544137863724757: VariantsMap =
    [&["judgment"], &["judgement"], &["judgment"], &["judgement"]];

pub(crate) static ENTRY_JUDICIALIZES_2293404910703458939: VariantsMap = [
    &["judicializes"],
    &["judicialises"],
    &["judicializes"],
    &["judicialises"],
];

pub(crate) static ENTRY_JUDICIALIZE_2368190414477914253: VariantsMap = [
    &["judicialize"],
    &["judicialise"],
    &["judicialize"],
    &["judicialise"],
];

pub(crate) static ENTRY_JULIDE_528656478496277011: VariantsMap =
    [&["julide"], &["julidae"], &["julidae"], &["julidae"]];

pub(crate) static ENTRY_JUMBOIZED_18212256537106696792: VariantsMap = [
    &["jumboized"],
    &["jumboised"],
    &["jumboized"],
    &["jumboised"],
];

pub(crate) static ENTRY_JUMBOIZES_2354824516718999834: VariantsMap = [
    &["jumboizes"],
    &["jumboises"],
    &["jumboizes"],
    &["jumboises"],
];

pub(crate) static ENTRY_JUMBOIZE_7712117084015749654: VariantsMap =
    [&["jumboize"], &["jumboise"], &["jumboize"], &["jumboise"]];

pub(crate) static ENTRY_JUMBOIZING_11206648409875659758: VariantsMap = [
    &["jumboizing"],
    &["jumboising"],
    &["jumboizing"],
    &["jumboising"],
];

pub(crate) static ENTRY_JUVENILIZES_1699288187481999237: VariantsMap = [
    &["juvenilizes"],
    &["juvenilises"],
    &["juvenilizes"],
    &["juvenilises"],
];

pub(crate) static ENTRY_JUVENILIZE_10243628665762694787: VariantsMap = [
    &["juvenilize"],
    &["juvenilise"],
    &["juvenilize"],
    &["juvenilise"],
];

pub(crate) static ENTRY_KANE_6625073156856396398: VariantsMap =
    [&["kane"], &["kanae"], &["kanae"], &["kanae"]];

pub(crate) static ENTRY_KAOLINIZATIONS_6857713841926809034: VariantsMap = [
    &["kaolinizations"],
    &["kaolinisations"],
    &["kaolinizations"],
    &["kaolinisations"],
];

pub(crate) static ENTRY_KAOLINIZATION_3243954716236483625: VariantsMap = [
    &["kaolinization"],
    &["kaolinisation"],
    &["kaolinization"],
    &["kaolinisation"],
];

pub(crate) static ENTRY_KAOLINIZED_6353288544737897076: VariantsMap = [
    &["kaolinized"],
    &["kaolinised"],
    &["kaolinized"],
    &["kaolinised"],
];

pub(crate) static ENTRY_KAOLINIZES_14280727638122409305: VariantsMap = [
    &["kaolinizes"],
    &["kaolinises"],
    &["kaolinizes"],
    &["kaolinises"],
];

pub(crate) static ENTRY_KAOLINIZE_1540770554993870553: VariantsMap = [
    &["kaolinize"],
    &["kaolinise"],
    &["kaolinize"],
    &["kaolinise"],
];

pub(crate) static ENTRY_KAOLINIZING_16455578064118109141: VariantsMap = [
    &["kaolinizing"],
    &["kaolinising"],
    &["kaolinizing"],
    &["kaolinising"],
];

pub(crate) static ENTRY_KED_7992567477889895157: VariantsMap =
    [&["ked"], &["kaed"], &["kaed"], &["kaed"]];

pub(crate) static ENTRY_KEIZER_16279072195491513044: VariantsMap =
    [&["keizer"], &["keiser"], &["keizer"], &["keiser"]];

pub(crate) static ENTRY_KELLIA_18207542001610745483: VariantsMap =
    [&["kellia"], &["koellia"], &["koellia"], &["koellia"]];

pub(crate) static ENTRY_KEMBED_5455940632308636783: VariantsMap =
    [&["kembed"], &["kemboed"], &["kemboed"], &["kemboed"]];

pub(crate) static ENTRY_KENNELED_7097387362453255328: VariantsMap = [
    &["kenneled"],
    &["kennelled"],
    &["kennelled"],
    &["kennelled"],
];

pub(crate) static ENTRY_KENNELING_3222702508854487680: VariantsMap = [
    &["kenneling"],
    &["kennelling"],
    &["kennelling"],
    &["kennelling"],
];

pub(crate) static ENTRY_KEPPEL_3250945561966438026: VariantsMap =
    [&["keppel"], &["koeppel"], &["koeppel"], &["koeppel"]];

pub(crate) static ENTRY_KERATINIZATIONS_11148703562572717517: VariantsMap = [
    &["keratinizations"],
    &["keratinisations"],
    &["keratinizations"],
    &["keratinisations"],
];

pub(crate) static ENTRY_KERATINIZATION_9287269898372096209: VariantsMap = [
    &["keratinization"],
    &["keratinisation"],
    &["keratinization"],
    &["keratinisation"],
];

pub(crate) static ENTRY_KERATINIZED_9532404537119161326: VariantsMap = [
    &["keratinized"],
    &["keratinised"],
    &["keratinized"],
    &["keratinised"],
];

pub(crate) static ENTRY_KERATINIZES_6869237603626021135: VariantsMap = [
    &["keratinizes"],
    &["keratinises"],
    &["keratinizes"],
    &["keratinises"],
];

pub(crate) static ENTRY_KERATINIZE_5854314817304010708: VariantsMap = [
    &["keratinize"],
    &["keratinise"],
    &["keratinize"],
    &["keratinise"],
];

pub(crate) static ENTRY_KERATINIZING_6928540492051600473: VariantsMap = [
    &["keratinizing"],
    &["keratinising"],
    &["keratinizing"],
    &["keratinising"],
];

pub(crate) static ENTRY_KERIN_11573832134730158699: VariantsMap =
    [&["kerin"], &["krein"], &["krein"], &["krein"]];

pub(crate) static ENTRY_KERNELED_16844207359376744747: VariantsMap = [
    &["kerneled"],
    &["kernelled"],
    &["kernelled"],
    &["kernelled"],
];

pub(crate) static ENTRY_KERNELING_12862192556676476135: VariantsMap = [
    &["kerneling"],
    &["kernelling"],
    &["kernelling"],
    &["kernelling"],
];

pub(crate) static ENTRY_KEROSENES_9607995162491837420: VariantsMap = [
    &["kerosenes"],
    &["kerosenes"],
    &["kerosenes"],
    &["kerosenes"],
];

pub(crate) static ENTRY_KEROSENE_5237608390797685560: VariantsMap =
    [&["kerosene"], &["kerosene"], &["kerosene"], &["kerosene"]];

pub(crate) static ENTRY_KETONEMIA_12805799450504016636: VariantsMap = [
    &["ketonemia"],
    &["ketonaemia"],
    &["ketonaemia"],
    &["ketonaemia"],
];

pub(crate) static ENTRY_KETONIZATIONS_14849157462001694089: VariantsMap = [
    &["ketonizations"],
    &["ketonisations"],
    &["ketonizations"],
    &["ketonisations"],
];

pub(crate) static ENTRY_KETONIZATION_13151004879407765304: VariantsMap = [
    &["ketonization"],
    &["ketonisation"],
    &["ketonization"],
    &["ketonisation"],
];

pub(crate) static ENTRY_KETONIZES_13135406478710592228: VariantsMap = [
    &["ketonizes"],
    &["ketonises"],
    &["ketonizes"],
    &["ketonises"],
];

pub(crate) static ENTRY_KETONIZE_456616172246125509: VariantsMap =
    [&["ketonize"], &["ketonise"], &["ketonize"], &["ketonise"]];

pub(crate) static ENTRY_KIDNAPPED_9540389708046051348: VariantsMap = [
    &["kidnapped"],
    &["kidnapped"],
    &["kidnapped"],
    &["kidnapped"],
];

pub(crate) static ENTRY_KIDNAPPERS_9985029854330453394: VariantsMap = [
    &["kidnappers"],
    &["kidnappers"],
    &["kidnappers"],
    &["kidnappers"],
];

pub(crate) static ENTRY_KIDNAPPER_13085195688301237337: VariantsMap = [
    &["kidnapper"],
    &["kidnapper"],
    &["kidnapper"],
    &["kidnapper"],
];

pub(crate) static ENTRY_KIDNAPPING_70511558429659: VariantsMap = [
    &["kidnapping"],
    &["kidnapping"],
    &["kidnapping"],
    &["kidnapping"],
];

pub(crate) static ENTRY_KILOGRAMS_12915102141657973507: VariantsMap = [
    &["kilograms"],
    &["kilograms"],
    &["kilograms"],
    &["kilograms"],
];

pub(crate) static ENTRY_KILOGRAM_7939130248079190868: VariantsMap =
    [&["kilogram"], &["kilogram"], &["kilogram"], &["kilogram"]];

pub(crate) static ENTRY_KILOLITERS_7196014977999441896: VariantsMap = [
    &["kiloliters"],
    &["kilolitres"],
    &["kilolitres"],
    &["kilolitres"],
];

pub(crate) static ENTRY_KILOLITER_8811985426912090253: VariantsMap = [
    &["kiloliter"],
    &["kilolitre"],
    &["kilolitre"],
    &["kilolitre"],
];

pub(crate) static ENTRY_KILOMETERS_7517136324284687795: VariantsMap = [
    &["kilometers"],
    &["kilometres"],
    &["kilometres"],
    &["kilometres"],
];

pub(crate) static ENTRY_KILOMETER_3916092874457639239: VariantsMap = [
    &["kilometer"],
    &["kilometre"],
    &["kilometre"],
    &["kilometre"],
];

pub(crate) static ENTRY_KINDERGARTNERS_5091309540324859208: VariantsMap = [
    &["kindergartners"],
    &["kindergarteners"],
    &["kindergartners"],
    &["kindergarteners"],
];

pub(crate) static ENTRY_KINDERGARTNER_13742901016370510532: VariantsMap = [
    &["kindergartner"],
    &["kindergartener"],
    &["kindergartner"],
    &["kindergartener"],
];

pub(crate) static ENTRY_KINESTHESES_15991774592082202202: VariantsMap = [
    &["kinestheses"],
    &["kinaestheses"],
    &["kinaestheses"],
    &["kinaestheses"],
];

pub(crate) static ENTRY_KINESTHESIAS_5509168349661428667: VariantsMap = [
    &["kinesthesias"],
    &["kinaesthesias"],
    &["kinesthesias"],
    &["kinaesthesias"],
];

pub(crate) static ENTRY_KINESTHESIA_4063943003598390788: VariantsMap = [
    &["kinesthesia"],
    &["kinaesthesia"],
    &["kinesthesia"],
    &["kinaesthesia"],
];

pub(crate) static ENTRY_KINESTHESIS_13862880956607670027: VariantsMap = [
    &["kinesthesis"],
    &["kinaesthesis"],
    &["kinaesthesis"],
    &["kinaesthesis"],
];

pub(crate) static ENTRY_KINESTHETICALLIER_8649272125040776816: VariantsMap = [
    &["kinestheticallier"],
    &["kinaestheticallier"],
    &["kinaestheticallier"],
    &["kinaestheticallier"],
];

pub(crate) static ENTRY_KINESTHETICALLIEST_16611528420519039262: VariantsMap = [
    &["kinestheticalliest"],
    &["kinaestheticalliest"],
    &["kinaestheticalliest"],
    &["kinaestheticalliest"],
];

pub(crate) static ENTRY_KINESTHETICALLY_6590308132254918624: VariantsMap = [
    &["kinesthetically"],
    &["kinaesthetically"],
    &["kinaesthetically"],
    &["kinaesthetically"],
];

pub(crate) static ENTRY_KINESTHETICER_10688483926829306448: VariantsMap = [
    &["kinestheticer"],
    &["kinaestheticer"],
    &["kinestheticer"],
    &["kinaestheticer"],
];

pub(crate) static ENTRY_KINESTHETICEST_17532483346165398356: VariantsMap = [
    &["kinestheticest"],
    &["kinaestheticest"],
    &["kinestheticest"],
    &["kinaestheticest"],
];

pub(crate) static ENTRY_KINESTHETICS_8164390027509303384: VariantsMap = [
    &["kinesthetics"],
    &["kinaesthetics"],
    &["kinesthetics"],
    &["kinaesthetics"],
];

pub(crate) static ENTRY_KINESTHETIC_12696136530393551560: VariantsMap = [
    &["kinesthetic"],
    &["kinaesthetic"],
    &["kinesthetic"],
    &["kinaesthetic"],
];

pub(crate) static ENTRY_KOSSEAN_16378574701214617146: VariantsMap =
    [&["kossean"], &["kossaean"], &["kossaean"], &["kossaean"]];

pub(crate) static ENTRY_KYANIZED_7491403161764420741: VariantsMap =
    [&["kyanized"], &["kyanised"], &["kyanized"], &["kyanised"]];

pub(crate) static ENTRY_KYANIZES_9819131922262272623: VariantsMap =
    [&["kyanizes"], &["kyanises"], &["kyanizes"], &["kyanises"]];

pub(crate) static ENTRY_KYANIZE_18259022762044268711: VariantsMap =
    [&["kyanize"], &["kyanise"], &["kyanize"], &["kyanise"]];

pub(crate) static ENTRY_KYANIZING_1109891397394364587: VariantsMap = [
    &["kyanizing"],
    &["kyanising"],
    &["kyanizing"],
    &["kyanising"],
];

pub(crate) static ENTRY_KYLES_10195640480009922922: VariantsMap =
    [&["kyles"], &["kyles"], &["kyles"], &["kyles"]];

pub(crate) static ENTRY_LABELABLE_11309838925293352839: VariantsMap = [
    &["labelable"],
    &["labellable"],
    &["labellable"],
    &["labellable"],
];

pub(crate) static ENTRY_LABELED_2907482757768957656: VariantsMap =
    [&["labeled"], &["labelled"], &["labelled"], &["labelled"]];

pub(crate) static ENTRY_LABELERS_11132772436034449864: VariantsMap = [
    &["labelers"],
    &["labellers"],
    &["labellers"],
    &["labellers"],
];

pub(crate) static ENTRY_LABELER_4919831389912264778: VariantsMap =
    [&["labeler"], &["labeller"], &["labeller"], &["labeller"]];

pub(crate) static ENTRY_LABELING_17714047580259532785: VariantsMap = [
    &["labeling"],
    &["labelling"],
    &["labelling"],
    &["labelling"],
];

pub(crate) static ENTRY_LABIALIZATIONS_3690953183947628889: VariantsMap = [
    &["labializations"],
    &["labialisations"],
    &["labializations"],
    &["labialisations"],
];

pub(crate) static ENTRY_LABIALIZATION_16946285945330796012: VariantsMap = [
    &["labialization"],
    &["labialisation"],
    &["labialization"],
    &["labialisation"],
];

pub(crate) static ENTRY_LABIALIZED_13758824402379981127: VariantsMap = [
    &["labialized"],
    &["labialised"],
    &["labialized"],
    &["labialised"],
];

pub(crate) static ENTRY_LABIALIZES_4066346379039880965: VariantsMap = [
    &["labializes"],
    &["labialises"],
    &["labializes"],
    &["labialises"],
];

pub(crate) static ENTRY_LABIALIZE_12309708431223536784: VariantsMap = [
    &["labialize"],
    &["labialise"],
    &["labialize"],
    &["labialise"],
];

pub(crate) static ENTRY_LABIALIZING_12581521144967923205: VariantsMap = [
    &["labializing"],
    &["labialising"],
    &["labializing"],
    &["labialising"],
];

pub(crate) static ENTRY_LABIATE_12523802628618211305: VariantsMap =
    [&["labiate"], &["labiatae"], &["labiatae"], &["labiatae"]];

pub(crate) static ENTRY_LABILIZATIONS_15897276050196647391: VariantsMap = [
    &["labilizations"],
    &["labilisations"],
    &["labilizations"],
    &["labilisations"],
];

pub(crate) static ENTRY_LABILIZATION_14178990427823362817: VariantsMap = [
    &["labilization"],
    &["labilisation"],
    &["labilization"],
    &["labilisation"],
];

pub(crate) static ENTRY_LABILIZES_7830834372804891715: VariantsMap = [
    &["labilizes"],
    &["labilises"],
    &["labilizes"],
    &["labilises"],
];

pub(crate) static ENTRY_LABILIZE_18267732551973725200: VariantsMap =
    [&["labilize"], &["labilise"], &["labilize"], &["labilise"]];

pub(crate) static ENTRY_LABIOVELARIZATION_1388406139771404548: VariantsMap = [
    &["labiovelarization"],
    &["labiovelarisation"],
    &["labiovelarization"],
    &["labiovelarisation"],
];

pub(crate) static ENTRY_LABIOVELARIZED_10933318847370841173: VariantsMap = [
    &["labiovelarized"],
    &["labiovelarised"],
    &["labiovelarized"],
    &["labiovelarised"],
];

pub(crate) static ENTRY_LABIOVELARIZE_14686339236476089437: VariantsMap = [
    &["labiovelarize"],
    &["labiovelarise"],
    &["labiovelarize"],
    &["labiovelarise"],
];

pub(crate) static ENTRY_LABIOVELARIZING_17700134289778983903: VariantsMap = [
    &["labiovelarizing"],
    &["labiovelarising"],
    &["labiovelarizing"],
    &["labiovelarising"],
];

pub(crate) static ENTRY_LABORABILITIES_1374782393231225439: VariantsMap = [
    &["laborabilities"],
    &["labourabilities"],
    &["labourabilities"],
    &["labourabilities"],
];

pub(crate) static ENTRY_LABORABILITY_17263103500142200166: VariantsMap = [
    &["laborability"],
    &["labourability"],
    &["labourability"],
    &["labourability"],
];

pub(crate) static ENTRY_LABORABLES_14898437790918563748: VariantsMap = [
    &["laborables"],
    &["labourables"],
    &["labourables"],
    &["labourables"],
];

pub(crate) static ENTRY_LABORABLE_5069469180400777649: VariantsMap = [
    &["laborable"],
    &["labourable"],
    &["labourable"],
    &["labourable"],
];

pub(crate) static ENTRY_LABORAGE_4470460124023370902: VariantsMap = [
    &["laborage"],
    &["labourage"],
    &["labourage"],
    &["labourage"],
];

pub(crate) static ENTRY_LABOREDLIER_15605691085469605442: VariantsMap = [
    &["laboredlier"],
    &["labouredlier"],
    &["labouredlier"],
    &["labouredlier"],
];

pub(crate) static ENTRY_LABOREDLIEST_10831075536431765156: VariantsMap = [
    &["laboredliest"],
    &["labouredliest"],
    &["labouredliest"],
    &["labouredliest"],
];

pub(crate) static ENTRY_LABOREDLY_6315030411151395853: VariantsMap = [
    &["laboredly"],
    &["labouredly"],
    &["labouredly"],
    &["labouredly"],
];

pub(crate) static ENTRY_LABOREDNESSES_12342351621411660244: VariantsMap = [
    &["laborednesses"],
    &["labourednesses"],
    &["labourednesses"],
    &["labourednesses"],
];

pub(crate) static ENTRY_LABOREDNESS_16418548514930234153: VariantsMap = [
    &["laboredness"],
    &["labouredness"],
    &["labouredness"],
    &["labouredness"],
];

pub(crate) static ENTRY_LABORED_15774914145750785155: VariantsMap =
    [&["labored"], &["laboured"], &["laboured"], &["laboured"]];

pub(crate) static ENTRY_LABORERS_7225219841972156021: VariantsMap = [
    &["laborers"],
    &["labourers"],
    &["labourers"],
    &["labourers"],
];

pub(crate) static ENTRY_LABORER_7780947282825536960: VariantsMap =
    [&["laborer"], &["labourer"], &["labourer"], &["labourer"]];

pub(crate) static ENTRY_LABORESS_13512364236747691122: VariantsMap = [
    &["laboress"],
    &["labouress"],
    &["labouress"],
    &["labouress"],
];

pub(crate) static ENTRY_LABORHOODS_5939892886551357822: VariantsMap = [
    &["laborhoods"],
    &["labourhoods"],
    &["labourhoods"],
    &["labourhoods"],
];

pub(crate) static ENTRY_LABORHOOD_12273635658052810449: VariantsMap = [
    &["laborhood"],
    &["labourhood"],
    &["labourhood"],
    &["labourhood"],
];

pub(crate) static ENTRY_LABORINGLIER_3681973244253020451: VariantsMap = [
    &["laboringlier"],
    &["labouringlier"],
    &["labouringlier"],
    &["labouringlier"],
];

pub(crate) static ENTRY_LABORINGLIEST_2311322561763860722: VariantsMap = [
    &["laboringliest"],
    &["labouringliest"],
    &["labouringliest"],
    &["labouringliest"],
];

pub(crate) static ENTRY_LABORINGLY_9186457281954627517: VariantsMap = [
    &["laboringly"],
    &["labouringly"],
    &["labouringly"],
    &["labouringly"],
];

pub(crate) static ENTRY_LABORINGS_3319891939721158320: VariantsMap = [
    &["laborings"],
    &["labourings"],
    &["labourings"],
    &["labourings"],
];

pub(crate) static ENTRY_LABORING_3043303013162659642: VariantsMap = [
    &["laboring"],
    &["labouring"],
    &["labouring"],
    &["labouring"],
];

pub(crate) static ENTRY_LABORISMS_4894710309638301654: VariantsMap = [
    &["laborisms"],
    &["labourisms"],
    &["labourisms"],
    &["labourisms"],
];

pub(crate) static ENTRY_LABORISM_9169767374341726690: VariantsMap = [
    &["laborism"],
    &["labourism"],
    &["labourism"],
    &["labourism"],
];

pub(crate) static ENTRY_LABORISTS_1797088670353430016: VariantsMap = [
    &["laborists"],
    &["labourists"],
    &["labourists"],
    &["labourists"],
];

pub(crate) static ENTRY_LABORIST_6895625282299523587: VariantsMap = [
    &["laborist"],
    &["labourist"],
    &["labourist"],
    &["labourist"],
];

pub(crate) static ENTRY_LABORITES_3700701955751769058: VariantsMap = [
    &["laborites"],
    &["labourites"],
    &["labourites"],
    &["labourites"],
];

pub(crate) static ENTRY_LABORITE_7167481098941329940: VariantsMap = [
    &["laborite"],
    &["labourite"],
    &["labourite"],
    &["labourite"],
];

pub(crate) static ENTRY_LABORLESSER_3135471279426545229: VariantsMap = [
    &["laborlesser"],
    &["labourlesser"],
    &["labourlesser"],
    &["labourlesser"],
];

pub(crate) static ENTRY_LABORLESSEST_4185090035161099000: VariantsMap = [
    &["laborlessest"],
    &["labourlessest"],
    &["labourlessest"],
    &["labourlessest"],
];

pub(crate) static ENTRY_LABORLESSES_1394050995892673233: VariantsMap = [
    &["laborlesses"],
    &["labourlesses"],
    &["labourlesses"],
    &["labourlesses"],
];

pub(crate) static ENTRY_LABORLESS_12212925688273781595: VariantsMap = [
    &["laborless"],
    &["labourless"],
    &["labourless"],
    &["labourless"],
];

pub(crate) static ENTRY_LABORSAVING_1772095626926060960: VariantsMap = [
    &["laborsaving"],
    &["laboursaving"],
    &["laboursaving"],
    &["laboursaving"],
];

pub(crate) static ENTRY_LABORSOMELY_10662246512612016198: VariantsMap = [
    &["laborsomely"],
    &["laboursomely"],
    &["laboursomely"],
    &["laboursomely"],
];

pub(crate) static ENTRY_LABORSOME_10538594555629318753: VariantsMap = [
    &["laborsome"],
    &["laboursome"],
    &["laboursome"],
    &["laboursome"],
];

pub(crate) static ENTRY_LABORS_911770229695768884: VariantsMap =
    [&["labors"], &["labours"], &["labours"], &["labours"]];

pub(crate) static ENTRY_LABOR_17181769129422624469: VariantsMap =
    [&["labor"], &["labour"], &["labour"], &["labour"]];

pub(crate) static ENTRY_LACKLUSTERRER_1131236613295912206: VariantsMap = [
    &["lacklusterrer"],
    &["lacklustrer"],
    &["lacklustrer"],
    &["lacklustrer"],
];

pub(crate) static ENTRY_LACKLUSTERREST_12506726696603302121: VariantsMap = [
    &["lacklusterrest"],
    &["lacklustrest"],
    &["lacklustrest"],
    &["lacklustrest"],
];

pub(crate) static ENTRY_LACKLUSTERS_6612944023946392488: VariantsMap = [
    &["lacklusters"],
    &["lacklustres"],
    &["lacklustres"],
    &["lacklustres"],
];

pub(crate) static ENTRY_LACKLUSTER_1715256487006561661: VariantsMap = [
    &["lackluster"],
    &["lacklustre"],
    &["lacklustre"],
    &["lacklustre"],
];

pub(crate) static ENTRY_LACONIZED_8218300631285017302: VariantsMap = [
    &["laconized"],
    &["laconised"],
    &["laconized"],
    &["laconised"],
];

pub(crate) static ENTRY_LACONIZES_17382503982714857689: VariantsMap = [
    &["laconizes"],
    &["laconises"],
    &["laconizes"],
    &["laconises"],
];

pub(crate) static ENTRY_LACONIZE_6822591394552566079: VariantsMap =
    [&["laconize"], &["laconise"], &["laconize"], &["laconise"]];

pub(crate) static ENTRY_LACONIZING_6708174531909727302: VariantsMap = [
    &["laconizing"],
    &["laconising"],
    &["laconizing"],
    &["laconising"],
];

pub(crate) static ENTRY_LACTONIZED_17165917184156525672: VariantsMap = [
    &["lactonized"],
    &["lactonised"],
    &["lactonized"],
    &["lactonised"],
];

pub(crate) static ENTRY_LAICIZATIONS_9749455722701689807: VariantsMap = [
    &["laicizations"],
    &["laicisations"],
    &["laicizations"],
    &["laicisations"],
];

pub(crate) static ENTRY_LAICIZATION_2887235584180290305: VariantsMap = [
    &["laicization"],
    &["laicisation"],
    &["laicization"],
    &["laicisation"],
];

pub(crate) static ENTRY_LAICIZED_80445541934935273: VariantsMap =
    [&["laicized"], &["laicised"], &["laicized"], &["laicised"]];

pub(crate) static ENTRY_LAICIZES_869459089127458605: VariantsMap =
    [&["laicizes"], &["laicises"], &["laicizes"], &["laicises"]];

pub(crate) static ENTRY_LAICIZE_3572230327046139216: VariantsMap =
    [&["laicize"], &["laicise"], &["laicize"], &["laicise"]];

pub(crate) static ENTRY_LAICIZING_5309366367065705343: VariantsMap = [
    &["laicizing"],
    &["laicising"],
    &["laicizing"],
    &["laicising"],
];

pub(crate) static ENTRY_LAIRIZED_8262896078331257561: VariantsMap =
    [&["lairized"], &["lairised"], &["lairized"], &["lairised"]];

pub(crate) static ENTRY_LAIRIZES_6832372099048999658: VariantsMap =
    [&["lairizes"], &["lairises"], &["lairizes"], &["lairises"]];

pub(crate) static ENTRY_LAIRIZE_11275089526752116396: VariantsMap =
    [&["lairize"], &["lairise"], &["lairize"], &["lairise"]];

pub(crate) static ENTRY_LAIRIZING_14359538361305990417: VariantsMap = [
    &["lairizing"],
    &["lairising"],
    &["lairizing"],
    &["lairising"],
];

pub(crate) static ENTRY_LAMINARIZED_9391732749259987656: VariantsMap = [
    &["laminarized"],
    &["laminarised"],
    &["laminarized"],
    &["laminarised"],
];

pub(crate) static ENTRY_LAMINARIZES_14331963672679618224: VariantsMap = [
    &["laminarizes"],
    &["laminarises"],
    &["laminarizes"],
    &["laminarises"],
];

pub(crate) static ENTRY_LAMINARIZE_10415015838430956455: VariantsMap = [
    &["laminarize"],
    &["laminarise"],
    &["laminarize"],
    &["laminarise"],
];

pub(crate) static ENTRY_LAMINARIZING_305451454544009037: VariantsMap = [
    &["laminarizing"],
    &["laminarising"],
    &["laminarizing"],
    &["laminarising"],
];

pub(crate) static ENTRY_LANDER_5172285837554925117: VariantsMap =
    [&["lander"], &["landre"], &["landre"], &["landre"]];

pub(crate) static ENTRY_LAOTHOE_18001361801867503785: VariantsMap =
    [&["laothoe"], &["laothoae"], &["laothoae"], &["laothoae"]];

pub(crate) static ENTRY_LAPELED_3487021672158426687: VariantsMap =
    [&["lapeled"], &["lapelled"], &["lapelled"], &["lapelled"]];

pub(crate) static ENTRY_LASAGNAS_12563561930970116687: VariantsMap =
    [&["lasagnas"], &["lasagnes"], &["lasagnes"], &["lasagnes"]];

pub(crate) static ENTRY_LASAGNA_15470141710854379425: VariantsMap =
    [&["lasagna"], &["lasagne"], &["lasagne"], &["lasagne"]];

pub(crate) static ENTRY_LASTER_3064111799341855772: VariantsMap =
    [&["laster"], &["lastre"], &["lastre"], &["lastre"]];

pub(crate) static ENTRY_LATENTIZES_15097043595238247759: VariantsMap = [
    &["latentizes"],
    &["latentises"],
    &["latentizes"],
    &["latentises"],
];

pub(crate) static ENTRY_LATENTIZE_2695337996205954263: VariantsMap = [
    &["latentize"],
    &["latentise"],
    &["latentize"],
    &["latentise"],
];

pub(crate) static ENTRY_LATERALIZATIONS_17363642925358429016: VariantsMap = [
    &["lateralizations"],
    &["lateralisations"],
    &["lateralizations"],
    &["lateralisations"],
];

pub(crate) static ENTRY_LATERALIZATION_17558345836104634444: VariantsMap = [
    &["lateralization"],
    &["lateralisation"],
    &["lateralization"],
    &["lateralisation"],
];

pub(crate) static ENTRY_LATERALIZES_4067647162402607589: VariantsMap = [
    &["lateralizes"],
    &["lateralises"],
    &["lateralizes"],
    &["lateralises"],
];

pub(crate) static ENTRY_LATERALIZE_18084168395528697129: VariantsMap = [
    &["lateralize"],
    &["lateralise"],
    &["lateralize"],
    &["lateralise"],
];

pub(crate) static ENTRY_LATERIZATIONS_2970297049045009789: VariantsMap = [
    &["laterizations"],
    &["laterisations"],
    &["laterizations"],
    &["laterisations"],
];

pub(crate) static ENTRY_LATERIZATION_6646665995805461681: VariantsMap = [
    &["laterization"],
    &["laterisation"],
    &["laterization"],
    &["laterisation"],
];

pub(crate) static ENTRY_LATINIZATIONS_6858424540483628997: VariantsMap = [
    &["latinizations"],
    &["latinisations"],
    &["latinizations"],
    &["latinisations"],
];

pub(crate) static ENTRY_LATINIZATION_11972451538371752217: VariantsMap = [
    &["latinization"],
    &["latinisation"],
    &["latinization"],
    &["latinisation"],
];

pub(crate) static ENTRY_LATINIZED_10581307786903570003: VariantsMap = [
    &["latinized"],
    &["latinised"],
    &["latinized"],
    &["latinised"],
];

pub(crate) static ENTRY_LATINIZERS_5094806879295804549: VariantsMap = [
    &["latinizers"],
    &["latinisers"],
    &["latinizers"],
    &["latinisers"],
];

pub(crate) static ENTRY_LATINIZER_2919331145534061159: VariantsMap = [
    &["latinizer"],
    &["latiniser"],
    &["latinizer"],
    &["latiniser"],
];

pub(crate) static ENTRY_LATINIZES_9202029225723708964: VariantsMap = [
    &["latinizes"],
    &["latinises"],
    &["latinizes"],
    &["latinises"],
];

pub(crate) static ENTRY_LATINIZE_10995098395307448983: VariantsMap =
    [&["latinize"], &["latinise"], &["latinize"], &["latinise"]];

pub(crate) static ENTRY_LATINIZING_12540759379841466342: VariantsMap = [
    &["latinizing"],
    &["latinising"],
    &["latinizing"],
    &["latinising"],
];

pub(crate) static ENTRY_LAURELED_15840646900598636325: VariantsMap = [
    &["laureled"],
    &["laurelled"],
    &["laurelled"],
    &["laurelled"],
];

pub(crate) static ENTRY_LAURELING_8509761833120787483: VariantsMap = [
    &["laureling"],
    &["laurelling"],
    &["laurelling"],
    &["laurelling"],
];

pub(crate) static ENTRY_LAURE_622623340727413197: VariantsMap =
    [&["laure"], &["laurae"], &["laurae"], &["laurae"]];

pub(crate) static ENTRY_LAVOLTED_1448117024048447761: VariantsMap = [
    &["lavolted"],
    &["lavoltaed"],
    &["lavoltaed"],
    &["lavoltaed"],
];

pub(crate) static ENTRY_LEARNED_16553251450375188122: VariantsMap = [
    &["learned"],
    &["learned", "learnt"],
    &["learned"],
    &["learned", "learnt"],
];

pub(crate) static ENTRY_LEATHERIZES_9057823714991730746: VariantsMap = [
    &["leatherizes"],
    &["leatherises"],
    &["leatherizes"],
    &["leatherises"],
];

pub(crate) static ENTRY_LEATHERIZE_2217890266002074192: VariantsMap = [
    &["leatherize"],
    &["leatherise"],
    &["leatherize"],
    &["leatherise"],
];

pub(crate) static ENTRY_LEGALIZATIONS_7369809481070839600: VariantsMap = [
    &["legalizations"],
    &["legalisations"],
    &["legalizations"],
    &["legalisations"],
];

pub(crate) static ENTRY_LEGALIZATION_14069720183344579391: VariantsMap = [
    &["legalization"],
    &["legalisation"],
    &["legalization"],
    &["legalisation"],
];

pub(crate) static ENTRY_LEGALIZED_4279297604105669391: VariantsMap = [
    &["legalized"],
    &["legalised"],
    &["legalized"],
    &["legalised"],
];

pub(crate) static ENTRY_LEGALIZES_15551841073682264464: VariantsMap = [
    &["legalizes"],
    &["legalises"],
    &["legalizes"],
    &["legalises"],
];

pub(crate) static ENTRY_LEGALIZE_6090443744031107422: VariantsMap =
    [&["legalize"], &["legalise"], &["legalize"], &["legalise"]];

pub(crate) static ENTRY_LEGALIZING_14672145239610477044: VariantsMap = [
    &["legalizing"],
    &["legalising"],
    &["legalizing"],
    &["legalising"],
];

pub(crate) static ENTRY_LEGGINGS_18074923807625757810: VariantsMap =
    [&["leggings"], &["leggings"], &["leggings"], &["leggings"]];

pub(crate) static ENTRY_LEGGING_8791551298779124491: VariantsMap =
    [&["legging"], &["legging"], &["legging"], &["legging"]];

pub(crate) static ENTRY_LEGITIMATIZED_15566517598534152764: VariantsMap = [
    &["legitimatized"],
    &["legitimatised"],
    &["legitimatized"],
    &["legitimatised"],
];

pub(crate) static ENTRY_LEGITIMATIZES_6190809963882788044: VariantsMap = [
    &["legitimatizes"],
    &["legitimatises"],
    &["legitimatizes"],
    &["legitimatises"],
];

pub(crate) static ENTRY_LEGITIMATIZE_8617242106801927773: VariantsMap = [
    &["legitimatize"],
    &["legitimatise"],
    &["legitimatize"],
    &["legitimatise"],
];

pub(crate) static ENTRY_LEGITIMATIZING_9528793826013606812: VariantsMap = [
    &["legitimatizing"],
    &["legitimatising"],
    &["legitimatizing"],
    &["legitimatising"],
];

pub(crate) static ENTRY_LEGITIMIZATIONS_11689914768775001401: VariantsMap = [
    &["legitimizations"],
    &["legitimisations"],
    &["legitimizations"],
    &["legitimisations"],
];

pub(crate) static ENTRY_LEGITIMIZATION_522172373867492649: VariantsMap = [
    &["legitimization"],
    &["legitimisation"],
    &["legitimization"],
    &["legitimisation"],
];

pub(crate) static ENTRY_LEGITIMIZED_7050352751899263729: VariantsMap = [
    &["legitimized"],
    &["legitimised"],
    &["legitimized"],
    &["legitimised"],
];

pub(crate) static ENTRY_LEGITIMIZER_16722148956241410759: VariantsMap = [
    &["legitimizer"],
    &["legitimiser"],
    &["legitimizer"],
    &["legitimiser"],
];

pub(crate) static ENTRY_LEGITIMIZES_15916033610846937765: VariantsMap = [
    &["legitimizes"],
    &["legitimises"],
    &["legitimizes"],
    &["legitimises"],
];

pub(crate) static ENTRY_LEGITIMIZE_162184278793564767: VariantsMap = [
    &["legitimize"],
    &["legitimise"],
    &["legitimize"],
    &["legitimise"],
];

pub(crate) static ENTRY_LEGITIMIZING_15403346656705937661: VariantsMap = [
    &["legitimizing"],
    &["legitimising"],
    &["legitimizing"],
    &["legitimising"],
];

pub(crate) static ENTRY_LEGUMINOSE_8808168821933801590: VariantsMap = [
    &["leguminose"],
    &["leguminosae"],
    &["leguminosae"],
    &["leguminosae"],
];

pub(crate) static ENTRY_LEMMATIZED_14288427773628086779: VariantsMap = [
    &["lemmatized"],
    &["lemmatised"],
    &["lemmatized"],
    &["lemmatised"],
];

pub(crate) static ENTRY_LEMMATIZES_11283410282156755354: VariantsMap = [
    &["lemmatizes"],
    &["lemmatises"],
    &["lemmatizes"],
    &["lemmatises"],
];

pub(crate) static ENTRY_LEMMATIZE_3841787910701358704: VariantsMap = [
    &["lemmatize"],
    &["lemmatise"],
    &["lemmatize"],
    &["lemmatise"],
];

pub(crate) static ENTRY_LEMMATIZING_11232648392129845696: VariantsMap = [
    &["lemmatizing"],
    &["lemmatising"],
    &["lemmatizing"],
    &["lemmatising"],
];

pub(crate) static ENTRY_LEPORIDE_9827185229783949880: VariantsMap = [
    &["leporide"],
    &["leporidae"],
    &["leporidae"],
    &["leporidae"],
];

pub(crate) static ENTRY_LEPTOSPIRE_911064414787372389: VariantsMap = [
    &["leptospire"],
    &["leptospirae"],
    &["leptospirae"],
    &["leptospirae"],
];

pub(crate) static ENTRY_LERNEAN_17960475636997592381: VariantsMap =
    [&["lernean"], &["lernaean"], &["lernaean"], &["lernaean"]];

pub(crate) static ENTRY_LESSES_13624938550715380684: VariantsMap =
    [&["lesses"], &["loesses"], &["loesses"], &["loesses"]];

pub(crate) static ENTRY_LETHALIZES_7714094041494904740: VariantsMap = [
    &["lethalizes"],
    &["lethalises"],
    &["lethalizes"],
    &["lethalises"],
];

pub(crate) static ENTRY_LETHALIZE_18211752301676352640: VariantsMap = [
    &["lethalize"],
    &["lethalise"],
    &["lethalize"],
    &["lethalise"],
];

pub(crate) static ENTRY_LETHARGIZED_9033916729242357207: VariantsMap = [
    &["lethargized"],
    &["lethargised"],
    &["lethargized"],
    &["lethargised"],
];

pub(crate) static ENTRY_LETHARGIZES_16077924589554016377: VariantsMap = [
    &["lethargizes"],
    &["lethargises"],
    &["lethargizes"],
    &["lethargises"],
];

pub(crate) static ENTRY_LETHARGIZE_9265082133850549111: VariantsMap = [
    &["lethargize"],
    &["lethargise"],
    &["lethargize"],
    &["lethargise"],
];

pub(crate) static ENTRY_LETHARGIZING_1161802722753837372: VariantsMap = [
    &["lethargizing"],
    &["lethargising"],
    &["lethargizing"],
    &["lethargising"],
];

pub(crate) static ENTRY_LEUCEMIAS_16840418369070866410: VariantsMap = [
    &["leucemias"],
    &["leucaemias"],
    &["leucaemias"],
    &["leucaemias"],
];

pub(crate) static ENTRY_LEUCEMIA_14689435826769411039: VariantsMap = [
    &["leucemia"],
    &["leucaemia"],
    &["leucaemia"],
    &["leucaemia"],
];

pub(crate) static ENTRY_LEUCEMIC_2632666506755750809: VariantsMap = [
    &["leucemic"],
    &["leucaemic"],
    &["leucaemic"],
    &["leucaemic"],
];

pub(crate) static ENTRY_LEUCHEMIA_13269968985976597970: VariantsMap = [
    &["leuchemia"],
    &["leuchaemia"],
    &["leuchaemia"],
    &["leuchaemia"],
];

pub(crate) static ENTRY_LEUCOCYTHEMIA_13875285091096996286: VariantsMap = [
    &["leucocythemia"],
    &["leucocythaemia"],
    &["leucocythaemia"],
    &["leucocythaemia"],
];

pub(crate) static ENTRY_LEUCOCYTHEMIC_15817224799610378261: VariantsMap = [
    &["leucocythemic"],
    &["leucocythaemic"],
    &["leucocythaemic"],
    &["leucocythaemic"],
];

pub(crate) static ENTRY_LEUCORRHEAL_13098489145195233918: VariantsMap = [
    &["leucorrheal"],
    &["leucorrhoeal"],
    &["leucorrhoeal"],
    &["leucorrhoeal"],
];

pub(crate) static ENTRY_LEUCORRHEAS_1620289807160644540: VariantsMap = [
    &["leucorrheas"],
    &["leucorrhoeas"],
    &["leucorrhoeas"],
    &["leucorrhoeas"],
];

pub(crate) static ENTRY_LEUCORRHEA_8655224531402171021: VariantsMap = [
    &["leucorrhea"],
    &["leucorrhoea"],
    &["leucorrhoea"],
    &["leucorrhoea"],
];

pub(crate) static ENTRY_LEUCOTHOE_17096848524130048559: VariantsMap = [
    &["leucothoe"],
    &["leucothoae"],
    &["leucothoae"],
    &["leucothoae"],
];

pub(crate) static ENTRY_LEUKEMIAS_9099411686641435250: VariantsMap = [
    &["leukemias"],
    &["leukaemias"],
    &["leukemias"],
    &["leukaemias"],
];

pub(crate) static ENTRY_LEUKEMIA_18308238259623845158: VariantsMap =
    [&["leukemia"], &["leukaemia"], &["leukemia"], &["leukaemia"]];

pub(crate) static ENTRY_LEUKEMOGENESES_1067450160751314209: VariantsMap = [
    &["leukemogeneses"],
    &["leukaemogeneses"],
    &["leukaemogeneses"],
    &["leukaemogeneses"],
];

pub(crate) static ENTRY_LEUKEMOGENESIS_14406918803510337444: VariantsMap = [
    &["leukemogenesis"],
    &["leukaemogenesis"],
    &["leukaemogenesis"],
    &["leukaemogenesis"],
];

pub(crate) static ENTRY_LEUKORRHEAL_15536707376609629975: VariantsMap = [
    &["leukorrheal"],
    &["leukorrhoeal"],
    &["leukorrhoeal"],
    &["leukorrhoeal"],
];

pub(crate) static ENTRY_LEUKORRHEA_2110491188090132168: VariantsMap = [
    &["leukorrhea"],
    &["leukorrhoea"],
    &["leukorrhoea"],
    &["leukorrhoea"],
];

pub(crate) static ENTRY_LEVELED_17710552579875587899: VariantsMap =
    [&["leveled"], &["levelled"], &["levelled"], &["levelled"]];

pub(crate) static ENTRY_LEVELERS_7665258852948284339: VariantsMap = [
    &["levelers"],
    &["levellers"],
    &["levellers"],
    &["levellers"],
];

pub(crate) static ENTRY_LEVELER_16958859746569115537: VariantsMap =
    [&["leveler"], &["leveller"], &["leveller"], &["leveller"]];

pub(crate) static ENTRY_LEVELEST_13356524148042532014: VariantsMap = [
    &["levelest"],
    &["levellest"],
    &["levellest"],
    &["levellest"],
];

pub(crate) static ENTRY_LEVELING_498798874102170149: VariantsMap = [
    &["leveling"],
    &["levelling"],
    &["levelling"],
    &["levelling"],
];

pub(crate) static ENTRY_LEVIGATED_10802119287360824756: VariantsMap = [
    &["levigated"],
    &["laevigated"],
    &["laevigated"],
    &["laevigated"],
];

pub(crate) static ENTRY_LEVIGATES_6464705000016558190: VariantsMap = [
    &["levigates"],
    &["laevigates"],
    &["laevigates"],
    &["laevigates"],
];

pub(crate) static ENTRY_LEVIGATE_2400835299858697154: VariantsMap = [
    &["levigate"],
    &["laevigate"],
    &["laevigate"],
    &["laevigate"],
];

pub(crate) static ENTRY_LEVIGATING_6360151110328481309: VariantsMap = [
    &["levigating"],
    &["laevigating"],
    &["laevigating"],
    &["laevigating"],
];

pub(crate) static ENTRY_LEVODUCTION_18380734240213929282: VariantsMap = [
    &["levoduction"],
    &["laevoduction"],
    &["laevoduction"],
    &["laevoduction"],
];

pub(crate) static ENTRY_LEVOGYRATE_226194661300355280: VariantsMap = [
    &["levogyrate"],
    &["laevogyrate"],
    &["laevogyrate"],
    &["laevogyrate"],
];

pub(crate) static ENTRY_LEVOGYRE_4490889198290332005: VariantsMap = [
    &["levogyre"],
    &["laevogyre"],
    &["laevogyre"],
    &["laevogyre"],
];

pub(crate) static ENTRY_LEVOGYROUS_10758046066790011317: VariantsMap = [
    &["levogyrous"],
    &["laevogyrous"],
    &["laevogyrous"],
    &["laevogyrous"],
];

pub(crate) static ENTRY_LEVOLACTIC_12858385479851123350: VariantsMap = [
    &["levolactic"],
    &["laevolactic"],
    &["laevolactic"],
    &["laevolactic"],
];

pub(crate) static ENTRY_LEVOROTATIONS_5775096129907291037: VariantsMap = [
    &["levorotations"],
    &["laevorotations"],
    &["laevorotations"],
    &["laevorotations"],
];

pub(crate) static ENTRY_LEVOROTATION_7598609812036201504: VariantsMap = [
    &["levorotation"],
    &["laevorotation"],
    &["laevorotation"],
    &["laevorotation"],
];

pub(crate) static ENTRY_LEVOROTATORY_14202301941084413862: VariantsMap = [
    &["levorotatory"],
    &["laevorotatory"],
    &["laevorotatory"],
    &["laevorotatory"],
];

pub(crate) static ENTRY_LEVOTARTARIC_16315854471180603290: VariantsMap = [
    &["levotartaric"],
    &["laevotartaric"],
    &["laevotartaric"],
    &["laevotartaric"],
];

pub(crate) static ENTRY_LEVOVERSION_11776416338568601974: VariantsMap = [
    &["levoversion"],
    &["laevoversion"],
    &["laevoversion"],
    &["laevoversion"],
];

pub(crate) static ENTRY_LEVO_5922397168831753216: VariantsMap =
    [&["levo"], &["laevo"], &["laevo"], &["laevo"]];

pub(crate) static ENTRY_LEVULIN_14669868077101221588: VariantsMap =
    [&["levulin"], &["laevulin"], &["laevulin"], &["laevulin"]];

pub(crate) static ENTRY_LEVULOSES_15600695600027321495: VariantsMap = [
    &["levuloses"],
    &["laevuloses"],
    &["laevuloses"],
    &["laevuloses"],
];

pub(crate) static ENTRY_LEVULOSE_12367098880168512961: VariantsMap = [
    &["levulose"],
    &["laevulose"],
    &["laevulose"],
    &["laevulose"],
];

pub(crate) static ENTRY_LEXICALIZATIONS_6221466785295251109: VariantsMap = [
    &["lexicalizations"],
    &["lexicalisations"],
    &["lexicalizations"],
    &["lexicalisations"],
];

pub(crate) static ENTRY_LEXICALIZATION_12107898383962927204: VariantsMap = [
    &["lexicalization"],
    &["lexicalisation"],
    &["lexicalization"],
    &["lexicalisation"],
];

pub(crate) static ENTRY_LEXICONIZES_6339779794516589643: VariantsMap = [
    &["lexiconizes"],
    &["lexiconises"],
    &["lexiconizes"],
    &["lexiconises"],
];

pub(crate) static ENTRY_LEXICONIZE_5459057741155956257: VariantsMap = [
    &["lexiconize"],
    &["lexiconise"],
    &["lexiconize"],
    &["lexiconise"],
];

pub(crate) static ENTRY_LIBELANTS_13936281424806279736: VariantsMap = [
    &["libelants"],
    &["libellants"],
    &["libellants"],
    &["libellants"],
];

pub(crate) static ENTRY_LIBELANT_8960950444204079644: VariantsMap = [
    &["libelant"],
    &["libellant"],
    &["libellant"],
    &["libellant"],
];

pub(crate) static ENTRY_LIBELED_8051675010294297382: VariantsMap =
    [&["libeled"], &["libelled"], &["libelled"], &["libelled"]];

pub(crate) static ENTRY_LIBELEES_11461283383597147410: VariantsMap = [
    &["libelees"],
    &["libellees"],
    &["libellees"],
    &["libellees"],
];

pub(crate) static ENTRY_LIBELEE_8501691415848872731: VariantsMap =
    [&["libelee"], &["libellee"], &["libellee"], &["libellee"]];

pub(crate) static ENTRY_LIBELERS_847096387317740162: VariantsMap = [
    &["libelers"],
    &["libellers"],
    &["libellers"],
    &["libellers"],
];

pub(crate) static ENTRY_LIBELER_24227560685436157: VariantsMap =
    [&["libeler"], &["libeller"], &["libeller"], &["libeller"]];

pub(crate) static ENTRY_LIBELING_928273583787085556: VariantsMap = [
    &["libeling"],
    &["libelling"],
    &["libelling"],
    &["libelling"],
];

pub(crate) static ENTRY_LIBELOUSER_4863053355167467915: VariantsMap = [
    &["libelouser"],
    &["libellouser"],
    &["libellouser"],
    &["libellouser"],
];

pub(crate) static ENTRY_LIBELOUSEST_3829700018638160477: VariantsMap = [
    &["libelousest"],
    &["libellousest"],
    &["libellousest"],
    &["libellousest"],
];

pub(crate) static ENTRY_LIBELOUSLIER_6398255068664852216: VariantsMap = [
    &["libelouslier"],
    &["libellouslier"],
    &["libellouslier"],
    &["libellouslier"],
];

pub(crate) static ENTRY_LIBELOUSLIEST_6285056826991660688: VariantsMap = [
    &["libelousliest"],
    &["libellousliest"],
    &["libellousliest"],
    &["libellousliest"],
];

pub(crate) static ENTRY_LIBELOUSLY_7818112032230270971: VariantsMap = [
    &["libelously"],
    &["libellously"],
    &["libellously"],
    &["libellously"],
];

pub(crate) static ENTRY_LIBELOUS_17927467531006981983: VariantsMap = [
    &["libelous"],
    &["libellous"],
    &["libellous"],
    &["libellous"],
];

pub(crate) static ENTRY_LIBERALIZATIONS_10234274833724631870: VariantsMap = [
    &["liberalizations"],
    &["liberalisations"],
    &["liberalizations"],
    &["liberalisations"],
];

pub(crate) static ENTRY_LIBERALIZATION_6402945837364985631: VariantsMap = [
    &["liberalization"],
    &["liberalisation"],
    &["liberalization"],
    &["liberalisation"],
];

pub(crate) static ENTRY_LIBERALIZED_7103715465503664043: VariantsMap = [
    &["liberalized"],
    &["liberalised"],
    &["liberalized"],
    &["liberalised"],
];

pub(crate) static ENTRY_LIBERALIZERS_17607581360244717241: VariantsMap = [
    &["liberalizers"],
    &["liberalisers"],
    &["liberalizers"],
    &["liberalisers"],
];

pub(crate) static ENTRY_LIBERALIZER_6703544626598968567: VariantsMap = [
    &["liberalizer"],
    &["liberaliser"],
    &["liberalizer"],
    &["liberaliser"],
];

pub(crate) static ENTRY_LIBERALIZES_2300482275642251125: VariantsMap = [
    &["liberalizes"],
    &["liberalises"],
    &["liberalizes"],
    &["liberalises"],
];

pub(crate) static ENTRY_LIBERALIZE_76622256595054540: VariantsMap = [
    &["liberalize"],
    &["liberalise"],
    &["liberalize"],
    &["liberalise"],
];

pub(crate) static ENTRY_LIBERALIZING_1078842496046790451: VariantsMap = [
    &["liberalizing"],
    &["liberalising"],
    &["liberalizing"],
    &["liberalising"],
];

pub(crate) static ENTRY_LICENSED_17867087688345174857: VariantsMap =
    [&["licensed"], &["licensed"], &["licensed"], &["licensed"]];

pub(crate) static ENTRY_LICENSELESSES_11029823360818305074: VariantsMap = [
    &["licenselesses"],
    &["licencelesses"],
    &["licencelesses"],
    &["licencelesses"],
];

pub(crate) static ENTRY_LICENSELESS_7633778334307651396: VariantsMap = [
    &["licenseless"],
    &["licenceless"],
    &["licenceless"],
    &["licenceless"],
];

pub(crate) static ENTRY_LICENSES_16200011703717675342: VariantsMap =
    [&["licenses"], &["licenses"], &["licenses"], &["licenses"]];

pub(crate) static ENTRY_LICENSES_6688982061827133578: VariantsMap =
    [&["licenses"], &["licences"], &["licences"], &["licences"]];

pub(crate) static ENTRY_LICENSE_15235558001562153549: VariantsMap =
    [&["license"], &["license"], &["license"], &["license"]];

pub(crate) static ENTRY_LICENSE_8420547614103398896: VariantsMap =
    [&["license"], &["licence"], &["licence"], &["licence"]];

pub(crate) static ENTRY_LICENSING_17752252713375594291: VariantsMap = [
    &["licensing"],
    &["licensing"],
    &["licensing"],
    &["licensing"],
];

pub(crate) static ENTRY_LICHENIZATIONS_10191010088103528457: VariantsMap = [
    &["lichenizations"],
    &["lichenisations"],
    &["lichenizations"],
    &["lichenisations"],
];

pub(crate) static ENTRY_LICHENIZATION_16602922256985188930: VariantsMap = [
    &["lichenization"],
    &["lichenisation"],
    &["lichenization"],
    &["lichenisation"],
];

pub(crate) static ENTRY_LICHENIZED_10897910005345906260: VariantsMap = [
    &["lichenized"],
    &["lichenised"],
    &["lichenized"],
    &["lichenised"],
];

pub(crate) static ENTRY_LICHENIZES_11945949698824431881: VariantsMap = [
    &["lichenizes"],
    &["lichenises"],
    &["lichenizes"],
    &["lichenises"],
];

pub(crate) static ENTRY_LICHENIZE_4425261476550376752: VariantsMap = [
    &["lichenize"],
    &["lichenise"],
    &["lichenize"],
    &["lichenise"],
];

pub(crate) static ENTRY_LICHENIZING_11834102144389393809: VariantsMap = [
    &["lichenizing"],
    &["lichenising"],
    &["lichenizing"],
    &["lichenising"],
];

pub(crate) static ENTRY_LICORICE_12446341221870515605: VariantsMap =
    [&["licorice"], &["liquorice"], &["licorice"], &["licorice"]];

pub(crate) static ENTRY_LIGNITIZES_5039328976756916694: VariantsMap = [
    &["lignitizes"],
    &["lignitises"],
    &["lignitizes"],
    &["lignitises"],
];

pub(crate) static ENTRY_LIGNITIZE_15441220670264044611: VariantsMap = [
    &["lignitize"],
    &["lignitise"],
    &["lignitize"],
    &["lignitise"],
];

pub(crate) static ENTRY_LIGNOSE_16716408399558241514: VariantsMap =
    [&["lignose"], &["lignosae"], &["lignosae"], &["lignosae"]];

pub(crate) static ENTRY_LIGULE_17419746601256779929: VariantsMap =
    [&["ligule"], &["ligulae"], &["ligulae"], &["ligulae"]];

pub(crate) static ENTRY_LIKABILITIES_11415080682327614883: VariantsMap = [
    &["likabilities"],
    &["likeabilities"],
    &["likeabilities"],
    &["likeabilities"],
];

pub(crate) static ENTRY_LIKABILITY_14107426908958456352: VariantsMap = [
    &["likability"],
    &["likeability"],
    &["likeability"],
    &["likeability"],
];

pub(crate) static ENTRY_LIKABLENESSES_7732487243731741508: VariantsMap = [
    &["likablenesses"],
    &["likeablenesses"],
    &["likeablenesses"],
    &["likeablenesses"],
];

pub(crate) static ENTRY_LIKABLENESS_3894991900618167051: VariantsMap = [
    &["likableness"],
    &["likeableness"],
    &["likeableness"],
    &["likeableness"],
];

pub(crate) static ENTRY_LILLIPUTIANIZES_13473199246879296691: VariantsMap = [
    &["lilliputianizes"],
    &["lilliputianises"],
    &["lilliputianizes"],
    &["lilliputianises"],
];

pub(crate) static ENTRY_LILLIPUTIANIZE_13908672200948916679: VariantsMap = [
    &["lilliputianize"],
    &["lilliputianise"],
    &["lilliputianize"],
    &["lilliputianise"],
];

pub(crate) static ENTRY_LINEARIZABLE_11483091511283516869: VariantsMap = [
    &["linearizable"],
    &["linearisable"],
    &["linearizable"],
    &["linearisable"],
];

pub(crate) static ENTRY_LINEARIZATIONS_5220379832227897986: VariantsMap = [
    &["linearizations"],
    &["linearisations"],
    &["linearizations"],
    &["linearisations"],
];

pub(crate) static ENTRY_LINEARIZATION_8131042847425051698: VariantsMap = [
    &["linearization"],
    &["linearisation"],
    &["linearization"],
    &["linearisation"],
];

pub(crate) static ENTRY_LINEARIZED_6277814411607786019: VariantsMap = [
    &["linearized"],
    &["linearised"],
    &["linearized"],
    &["linearised"],
];

pub(crate) static ENTRY_LINEARIZES_9623143888404969081: VariantsMap = [
    &["linearizes"],
    &["linearises"],
    &["linearizes"],
    &["linearises"],
];

pub(crate) static ENTRY_LINEARIZE_6585591481529371953: VariantsMap = [
    &["linearize"],
    &["linearise"],
    &["linearize"],
    &["linearise"],
];

pub(crate) static ENTRY_LINEARIZING_7681767987068150150: VariantsMap = [
    &["linearizing"],
    &["linearising"],
    &["linearizing"],
    &["linearising"],
];

pub(crate) static ENTRY_LINEARIZION_2343569753841986772: VariantsMap = [
    &["linearizion"],
    &["linearision"],
    &["linearizion"],
    &["linearision"],
];

pub(crate) static ENTRY_LINENIZERS_4682205318738287968: VariantsMap = [
    &["linenizers"],
    &["linenisers"],
    &["linenizers"],
    &["linenisers"],
];

pub(crate) static ENTRY_LINENIZER_15888082626595375875: VariantsMap = [
    &["linenizer"],
    &["lineniser"],
    &["linenizer"],
    &["lineniser"],
];

pub(crate) static ENTRY_LINENIZES_5878071266025614362: VariantsMap = [
    &["linenizes"],
    &["linenises"],
    &["linenizes"],
    &["linenises"],
];

pub(crate) static ENTRY_LINENIZE_9065767214529230252: VariantsMap =
    [&["linenize"], &["linenise"], &["linenize"], &["linenise"]];

pub(crate) static ENTRY_LINGE_8045238778052659774: VariantsMap =
    [&["linge"], &["lingoe"], &["lingoe"], &["lingoe"]];

pub(crate) static ENTRY_LINGUALIZES_4441987696052706342: VariantsMap = [
    &["lingualizes"],
    &["lingualises"],
    &["lingualizes"],
    &["lingualises"],
];

pub(crate) static ENTRY_LINGUALIZE_14645339856071004715: VariantsMap = [
    &["lingualize"],
    &["lingualise"],
    &["lingualize"],
    &["lingualise"],
];

pub(crate) static ENTRY_LIONIZABLES_9433482512989969384: VariantsMap = [
    &["lionizables"],
    &["lionisables"],
    &["lionizables"],
    &["lionisables"],
];

pub(crate) static ENTRY_LIONIZABLE_5990738091543549203: VariantsMap = [
    &["lionizable"],
    &["lionisable"],
    &["lionizable"],
    &["lionisable"],
];

pub(crate) static ENTRY_LIONIZATIONS_16641459291019877558: VariantsMap = [
    &["lionizations"],
    &["lionisations"],
    &["lionizations"],
    &["lionisations"],
];

pub(crate) static ENTRY_LIONIZATION_7835868583533630314: VariantsMap = [
    &["lionization"],
    &["lionisation"],
    &["lionization"],
    &["lionisation"],
];

pub(crate) static ENTRY_LIONIZED_10011915111141731981: VariantsMap =
    [&["lionized"], &["lionised"], &["lionized"], &["lionised"]];

pub(crate) static ENTRY_LIONIZERS_10333415518245099706: VariantsMap = [
    &["lionizers"],
    &["lionisers"],
    &["lionizers"],
    &["lionisers"],
];

pub(crate) static ENTRY_LIONIZER_8892928801781639667: VariantsMap =
    [&["lionizer"], &["lioniser"], &["lionizer"], &["lioniser"]];

pub(crate) static ENTRY_LIONIZES_5684603994471877067: VariantsMap =
    [&["lionizes"], &["lionises"], &["lionizes"], &["lionises"]];

pub(crate) static ENTRY_LIONIZE_18412797134322626457: VariantsMap =
    [&["lionize"], &["lionise"], &["lionize"], &["lionise"]];

pub(crate) static ENTRY_LIONIZING_9945396776786882247: VariantsMap = [
    &["lionizing"],
    &["lionising"],
    &["lionizing"],
    &["lionising"],
];

pub(crate) static ENTRY_LIPEMIA_1266751727291630439: VariantsMap =
    [&["lipemia"], &["lipaemia"], &["lipaemia"], &["lipaemia"]];

pub(crate) static ENTRY_LIPEMIC_15466993613552317186: VariantsMap =
    [&["lipemic"], &["lipaemic"], &["lipaemic"], &["lipaemic"]];

pub(crate) static ENTRY_LIPOIDEMIA_14140069918960585906: VariantsMap = [
    &["lipoidemia"],
    &["lipoidaemia"],
    &["lipoidaemia"],
    &["lipoidaemia"],
];

pub(crate) static ENTRY_LIQUEFIERS_3218357154702987275: VariantsMap = [
    &["liquefiers"],
    &["liquefiers"],
    &["liquefiers"],
    &["liquefiers"],
];

pub(crate) static ENTRY_LIQUEFIER_8084176495582278110: VariantsMap = [
    &["liquefier"],
    &["liquefier"],
    &["liquefier"],
    &["liquefier"],
];

pub(crate) static ENTRY_LIQUIDIZATION_6149909954612384940: VariantsMap = [
    &["liquidization"],
    &["liquidisation"],
    &["liquidization"],
    &["liquidisation"],
];

pub(crate) static ENTRY_LIQUIDIZED_3292692080763673196: VariantsMap = [
    &["liquidized"],
    &["liquidised"],
    &["liquidized"],
    &["liquidised"],
];

pub(crate) static ENTRY_LIQUIDIZERS_4929831666489438893: VariantsMap = [
    &["liquidizers"],
    &["liquidisers"],
    &["liquidizers"],
    &["liquidisers"],
];

pub(crate) static ENTRY_LIQUIDIZER_11706828663079340333: VariantsMap = [
    &["liquidizer"],
    &["liquidiser"],
    &["liquidizer"],
    &["liquidiser"],
];

pub(crate) static ENTRY_LIQUIDIZES_15521435243413925703: VariantsMap = [
    &["liquidizes"],
    &["liquidises"],
    &["liquidizes"],
    &["liquidises"],
];

pub(crate) static ENTRY_LIQUIDIZE_14194923337466264130: VariantsMap = [
    &["liquidize"],
    &["liquidise"],
    &["liquidize"],
    &["liquidise"],
];

pub(crate) static ENTRY_LIQUIDIZING_9649118097468787294: VariantsMap = [
    &["liquidizing"],
    &["liquidising"],
    &["liquidizing"],
    &["liquidising"],
];

pub(crate) static ENTRY_LISSOMENESSES_15531245348799674971: VariantsMap = [
    &["lissomenesses"],
    &["lissomnesses"],
    &["lissomenesses"],
    &["lissomnesses"],
];

pub(crate) static ENTRY_LISSOMENESS_3042611249910147188: VariantsMap = [
    &["lissomeness"],
    &["lissomness"],
    &["lissomeness"],
    &["lissomness"],
];

pub(crate) static ENTRY_LISTERIZED_14632038138125604365: VariantsMap = [
    &["listerized"],
    &["listerised"],
    &["listerized"],
    &["listerised"],
];

pub(crate) static ENTRY_LISTERIZES_14087757069664162339: VariantsMap = [
    &["listerizes"],
    &["listerises"],
    &["listerizes"],
    &["listerises"],
];

pub(crate) static ENTRY_LISTERIZE_9880759270323455733: VariantsMap = [
    &["listerize"],
    &["listerise"],
    &["listerize"],
    &["listerise"],
];

pub(crate) static ENTRY_LISTERIZING_3929969546134536615: VariantsMap = [
    &["listerizing"],
    &["listerising"],
    &["listerizing"],
    &["listerising"],
];

pub(crate) static ENTRY_LITERALIZATIONS_12672487873607486420: VariantsMap = [
    &["literalizations"],
    &["literalisations"],
    &["literalizations"],
    &["literalisations"],
];

pub(crate) static ENTRY_LITERALIZATION_1756167120132481203: VariantsMap = [
    &["literalization"],
    &["literalisation"],
    &["literalization"],
    &["literalisation"],
];

pub(crate) static ENTRY_LITERALIZED_12392805848021505273: VariantsMap = [
    &["literalized"],
    &["literalised"],
    &["literalized"],
    &["literalised"],
];

pub(crate) static ENTRY_LITERALIZERS_8534907654562214344: VariantsMap = [
    &["literalizers"],
    &["literalisers"],
    &["literalizers"],
    &["literalisers"],
];

pub(crate) static ENTRY_LITERALIZER_11935455981977574700: VariantsMap = [
    &["literalizer"],
    &["literaliser"],
    &["literalizer"],
    &["literaliser"],
];

pub(crate) static ENTRY_LITERALIZES_12963354118044673239: VariantsMap = [
    &["literalizes"],
    &["literalises"],
    &["literalizes"],
    &["literalises"],
];

pub(crate) static ENTRY_LITERALIZE_936950175462886011: VariantsMap = [
    &["literalize"],
    &["literalise"],
    &["literalize"],
    &["literalise"],
];

pub(crate) static ENTRY_LITERALIZING_4067560910880631706: VariantsMap = [
    &["literalizing"],
    &["literalising"],
    &["literalizing"],
    &["literalising"],
];

pub(crate) static ENTRY_LITERS_6702315605664025195: VariantsMap =
    [&["liters"], &["litres"], &["litres"], &["litres"]];

pub(crate) static ENTRY_LITER_6442068802085842758: VariantsMap =
    [&["liter"], &["litre"], &["litre"], &["litre"]];

pub(crate) static ENTRY_LITHED_9698245383532623012: VariantsMap =
    [&["lithed"], &["lithoed"], &["lithoed"], &["lithoed"]];

pub(crate) static ENTRY_LITHEMIA_951694259866460815: VariantsMap = [
    &["lithemia"],
    &["lithaemia"],
    &["lithaemia"],
    &["lithaemia"],
];

pub(crate) static ENTRY_LITHEMIC_4518089608533106528: VariantsMap = [
    &["lithemic"],
    &["lithaemic"],
    &["lithaemic"],
    &["lithaemic"],
];

pub(crate) static ENTRY_LITHOGRAPHIZES_4093440307906412004: VariantsMap = [
    &["lithographizes"],
    &["lithographises"],
    &["lithographizes"],
    &["lithographises"],
];

pub(crate) static ENTRY_LITHOGRAPHIZE_10224940842516385348: VariantsMap = [
    &["lithographize"],
    &["lithographise"],
    &["lithographize"],
    &["lithographise"],
];

pub(crate) static ENTRY_LITHOPEDION_16487916873434462293: VariantsMap = [
    &["lithopedion"],
    &["lithopaedion"],
    &["lithopaedion"],
    &["lithopaedion"],
];

pub(crate) static ENTRY_LITHOPEDIUM_5496254320864204281: VariantsMap = [
    &["lithopedium"],
    &["lithopaedium"],
    &["lithopaedium"],
    &["lithopaedium"],
];

pub(crate) static ENTRY_LITHOPHYSE_11706337403790507355: VariantsMap = [
    &["lithophyse"],
    &["lithophysae"],
    &["lithophysae"],
    &["lithophysae"],
];

pub(crate) static ENTRY_LITHOTRITIZED_2791851903963662948: VariantsMap = [
    &["lithotritized"],
    &["lithotritised"],
    &["lithotritized"],
    &["lithotritised"],
];

pub(crate) static ENTRY_LITHOTRITIZES_18077690319530725305: VariantsMap = [
    &["lithotritizes"],
    &["lithotritises"],
    &["lithotritizes"],
    &["lithotritises"],
];

pub(crate) static ENTRY_LITHOTRITIZE_8820380951742023282: VariantsMap = [
    &["lithotritize"],
    &["lithotritise"],
    &["lithotritize"],
    &["lithotritise"],
];

pub(crate) static ENTRY_LITHOTRITIZING_7988737376840854573: VariantsMap = [
    &["lithotritizing"],
    &["lithotritising"],
    &["lithotritizing"],
    &["lithotritising"],
];

pub(crate) static ENTRY_LIVABLE_13408079841838673902: VariantsMap =
    [&["livable"], &["liveable"], &["livable"], &["livable"]];

pub(crate) static ENTRY_LOBOTOMIZED_8233435547170173963: VariantsMap = [
    &["lobotomized"],
    &["lobotomised"],
    &["lobotomized"],
    &["lobotomised"],
];

pub(crate) static ENTRY_LOBOTOMIZES_12096959998457471825: VariantsMap = [
    &["lobotomizes"],
    &["lobotomises"],
    &["lobotomizes"],
    &["lobotomises"],
];

pub(crate) static ENTRY_LOBOTOMIZE_8963885444869982297: VariantsMap = [
    &["lobotomize"],
    &["lobotomise"],
    &["lobotomize"],
    &["lobotomise"],
];

pub(crate) static ENTRY_LOBOTOMIZING_1629157880661707450: VariantsMap = [
    &["lobotomizing"],
    &["lobotomising"],
    &["lobotomizing"],
    &["lobotomising"],
];

pub(crate) static ENTRY_LOCALIZABLER_4472819140531439518: VariantsMap = [
    &["localizabler"],
    &["localisabler"],
    &["localizabler"],
    &["localisabler"],
];

pub(crate) static ENTRY_LOCALIZABLEST_6312048620019063505: VariantsMap = [
    &["localizablest"],
    &["localisablest"],
    &["localizablest"],
    &["localisablest"],
];

pub(crate) static ENTRY_LOCALIZABLES_14485108443499471420: VariantsMap = [
    &["localizables"],
    &["localisables"],
    &["localizables"],
    &["localisables"],
];

pub(crate) static ENTRY_LOCALIZABLE_18184729227341816025: VariantsMap = [
    &["localizable"],
    &["localisable"],
    &["localizable"],
    &["localisable"],
];

pub(crate) static ENTRY_LOCALIZATIONS_10357720798895176938: VariantsMap = [
    &["localizations"],
    &["localisations"],
    &["localizations"],
    &["localisations"],
];

pub(crate) static ENTRY_LOCALIZATION_1714165233158101768: VariantsMap = [
    &["localization"],
    &["localisation"],
    &["localization"],
    &["localisation"],
];

pub(crate) static ENTRY_LOCALIZED_15436756507414158023: VariantsMap = [
    &["localized"],
    &["localised"],
    &["localized"],
    &["localised"],
];

pub(crate) static ENTRY_LOCALIZERS_9928746809280119061: VariantsMap = [
    &["localizers"],
    &["localisers"],
    &["localizers"],
    &["localisers"],
];

pub(crate) static ENTRY_LOCALIZER_12500323668628991619: VariantsMap = [
    &["localizer"],
    &["localiser"],
    &["localizer"],
    &["localiser"],
];

pub(crate) static ENTRY_LOCALIZES_128174617828783907: VariantsMap = [
    &["localizes"],
    &["localises"],
    &["localizes"],
    &["localises"],
];

pub(crate) static ENTRY_LOCALIZE_3508370761131546110: VariantsMap =
    [&["localize"], &["localise"], &["localize"], &["localise"]];

pub(crate) static ENTRY_LOCALIZING_919540865361361114: VariantsMap = [
    &["localizing"],
    &["localising"],
    &["localizing"],
    &["localising"],
];

pub(crate) static ENTRY_LODICULE_6758636995666963377: VariantsMap = [
    &["lodicule"],
    &["lodiculae"],
    &["lodiculae"],
    &["lodiculae"],
];

pub(crate) static ENTRY_LOED_8365575545159393313: VariantsMap =
    [&["loed"], &["looed"], &["looed"], &["looed"]];

pub(crate) static ENTRY_LOGICALIZATIONS_16140088037300490067: VariantsMap = [
    &["logicalizations"],
    &["logicalisations"],
    &["logicalizations"],
    &["logicalisations"],
];

pub(crate) static ENTRY_LOGICALIZATION_18058606544682163505: VariantsMap = [
    &["logicalization"],
    &["logicalisation"],
    &["logicalization"],
    &["logicalisation"],
];

pub(crate) static ENTRY_LOGICALIZES_2075559869050334975: VariantsMap = [
    &["logicalizes"],
    &["logicalises"],
    &["logicalizes"],
    &["logicalises"],
];

pub(crate) static ENTRY_LOGICALIZE_18334947113562046396: VariantsMap = [
    &["logicalize"],
    &["logicalise"],
    &["logicalize"],
    &["logicalise"],
];

pub(crate) static ENTRY_LOGICIZED_12091726186783944112: VariantsMap = [
    &["logicized"],
    &["logicised"],
    &["logicized"],
    &["logicised"],
];

pub(crate) static ENTRY_LOGICIZES_17442537854886090020: VariantsMap = [
    &["logicizes"],
    &["logicises"],
    &["logicizes"],
    &["logicises"],
];

pub(crate) static ENTRY_LOGICIZE_939832317937132206: VariantsMap =
    [&["logicize"], &["logicise"], &["logicize"], &["logicise"]];

pub(crate) static ENTRY_LOGICIZING_8064941827003577208: VariantsMap = [
    &["logicizing"],
    &["logicising"],
    &["logicizing"],
    &["logicising"],
];

pub(crate) static ENTRY_LOGOPEDICS_1761751374576042069: VariantsMap = [
    &["logopedics"],
    &["logopaedics"],
    &["logopaedics"],
    &["logopaedics"],
];

pub(crate) static ENTRY_LOGOPEDIC_1358074550790185466: VariantsMap = [
    &["logopedic"],
    &["logopaedic"],
    &["logopaedic"],
    &["logopaedic"],
];

pub(crate) static ENTRY_LOGORRHEAS_14700518672865329126: VariantsMap = [
    &["logorrheas"],
    &["logorrhoeas"],
    &["logorrheas"],
    &["logorrhoeas"],
];

pub(crate) static ENTRY_LOGORRHEA_8997080484454664729: VariantsMap = [
    &["logorrhea"],
    &["logorrhoea"],
    &["logorrhea"],
    &["logorrhoea"],
];

pub(crate) static ENTRY_LONDONIZATIONS_5821790237984933474: VariantsMap = [
    &["londonizations"],
    &["londonisations"],
    &["londonizations"],
    &["londonisations"],
];

pub(crate) static ENTRY_LONDONIZATION_3483226003146039796: VariantsMap = [
    &["londonization"],
    &["londonisation"],
    &["londonization"],
    &["londonisation"],
];

pub(crate) static ENTRY_LONDONIZED_13682591894069407091: VariantsMap = [
    &["londonized"],
    &["londonised"],
    &["londonized"],
    &["londonised"],
];

pub(crate) static ENTRY_LONDONIZES_17116389071000645306: VariantsMap = [
    &["londonizes"],
    &["londonises"],
    &["londonizes"],
    &["londonises"],
];

pub(crate) static ENTRY_LONDONIZE_2285619791685745756: VariantsMap = [
    &["londonize"],
    &["londonise"],
    &["londonize"],
    &["londonise"],
];

pub(crate) static ENTRY_LONDONIZING_5049646724184981911: VariantsMap = [
    &["londonizing"],
    &["londonising"],
    &["londonizing"],
    &["londonising"],
];

pub(crate) static ENTRY_LONGEVAL_13747105351595227774: VariantsMap = [
    &["longeval"],
    &["longaeval"],
    &["longaeval"],
    &["longaeval"],
];

pub(crate) static ENTRY_LONGEVOUS_11977473951943958946: VariantsMap = [
    &["longevous"],
    &["longaevous"],
    &["longaevous"],
    &["longaevous"],
];

pub(crate) static ENTRY_LORDY_15173183331192004241: VariantsMap =
    [&["lordy"], &["lourdy"], &["lourdy"], &["lourdy"]];

pub(crate) static ENTRY_LORINGS_7794739241325186621: VariantsMap =
    [&["lorings"], &["lourings"], &["lourings"], &["lourings"]];

pub(crate) static ENTRY_LORY_10409127771494675257: VariantsMap =
    [&["lory"], &["loury"], &["loury"], &["loury"]];

pub(crate) static ENTRY_LOUTER_8528235889824422998: VariantsMap =
    [&["louter"], &["loutre"], &["loutre"], &["loutre"]];

pub(crate) static ENTRY_LOUVERED_4612129354743875164: VariantsMap =
    [&["louvered"], &["louvred"], &["louvred"], &["louvred"]];

pub(crate) static ENTRY_LOUVERS_13562782101200585962: VariantsMap =
    [&["louvers"], &["louvres"], &["louvres"], &["louvres"]];

pub(crate) static ENTRY_LOUVER_16383649386238497792: VariantsMap =
    [&["louver"], &["louvre"], &["louvre"], &["louvre"]];

pub(crate) static ENTRY_LOVABILITY_12982835729070356135: VariantsMap = [
    &["lovability"],
    &["lovability"],
    &["lovability"],
    &["lovability"],
];

pub(crate) static ENTRY_LOVABLENESS_15385519583573319347: VariantsMap = [
    &["lovableness"],
    &["lovableness"],
    &["lovableness"],
    &["lovableness"],
];

pub(crate) static ENTRY_LOVABLY_8687570857338148234: VariantsMap =
    [&["lovably"], &["lovably"], &["lovably"], &["lovably"]];

pub(crate) static ENTRY_LOVES_9736395093583352222: VariantsMap =
    [&["loves"], &["loves"], &["loves"], &["loves"]];

pub(crate) static ENTRY_LOVE_17065904044059271019: VariantsMap =
    [&["love"], &["love"], &["love"], &["love"]];

pub(crate) static ENTRY_LOYALIZES_16040945990365025303: VariantsMap = [
    &["loyalizes"],
    &["loyalises"],
    &["loyalizes"],
    &["loyalises"],
];

pub(crate) static ENTRY_LOYALIZE_2379116295027966003: VariantsMap =
    [&["loyalize"], &["loyalise"], &["loyalize"], &["loyalise"]];

pub(crate) static ENTRY_LUMBARIZATIONS_14924040958914962850: VariantsMap = [
    &["lumbarizations"],
    &["lumbarisations"],
    &["lumbarizations"],
    &["lumbarisations"],
];

pub(crate) static ENTRY_LUMBARIZATION_4848264276836271036: VariantsMap = [
    &["lumbarization"],
    &["lumbarisation"],
    &["lumbarization"],
    &["lumbarisation"],
];

pub(crate) static ENTRY_LUNATIZES_13282870687606940178: VariantsMap = [
    &["lunatizes"],
    &["lunatises"],
    &["lunatizes"],
    &["lunatises"],
];

pub(crate) static ENTRY_LUNATIZE_12434524765834737617: VariantsMap =
    [&["lunatize"], &["lunatise"], &["lunatize"], &["lunatise"]];

pub(crate) static ENTRY_LUNULE_15978057700030636506: VariantsMap =
    [&["lunule"], &["lunulae"], &["lunulae"], &["lunulae"]];

pub(crate) static ENTRY_LUPINES_16622756440390859222: VariantsMap =
    [&["lupines"], &["lupins"], &["lupines"], &["lupins"]];

pub(crate) static ENTRY_LUSTERED_11665281529057185042: VariantsMap =
    [&["lustered"], &["lustred"], &["lustred"], &["lustred"]];

pub(crate) static ENTRY_LUSTERING_8070190029646350099: VariantsMap =
    [&["lustering"], &["lustring"], &["lustring"], &["lustring"]];

pub(crate) static ENTRY_LUSTERLESSER_2845716573356909139: VariantsMap = [
    &["lusterlesser"],
    &["lustrelesser"],
    &["lustrelesser"],
    &["lustrelesser"],
];

pub(crate) static ENTRY_LUSTERLESSEST_5530749287519804822: VariantsMap = [
    &["lusterlessest"],
    &["lustrelessest"],
    &["lustrelessest"],
    &["lustrelessest"],
];

pub(crate) static ENTRY_LUSTERLESS_18388613709739398315: VariantsMap = [
    &["lusterless"],
    &["lustreless"],
    &["lustreless"],
    &["lustreless"],
];

pub(crate) static ENTRY_LUSTERS_15914131236659551229: VariantsMap =
    [&["lusters"], &["lustres"], &["lustres"], &["lustres"]];

pub(crate) static ENTRY_LUSTERWARES_13754816865182407391: VariantsMap = [
    &["lusterwares"],
    &["lustrewares"],
    &["lustrewares"],
    &["lustrewares"],
];

pub(crate) static ENTRY_LUSTERWARE_9411302114705132644: VariantsMap = [
    &["lusterware"],
    &["lustreware"],
    &["lustreware"],
    &["lustreware"],
];

pub(crate) static ENTRY_LUSTER_34214050459909607: VariantsMap =
    [&["luster"], &["lustre"], &["lustre"], &["lustre"]];

pub(crate) static ENTRY_LUTEINIZATIONS_5156597664222852099: VariantsMap = [
    &["luteinizations"],
    &["luteinisations"],
    &["luteinizations"],
    &["luteinisations"],
];

pub(crate) static ENTRY_LUTEINIZATION_5209056682966161126: VariantsMap = [
    &["luteinization"],
    &["luteinisation"],
    &["luteinization"],
    &["luteinisation"],
];

pub(crate) static ENTRY_LUTEINIZED_9144184424728701800: VariantsMap = [
    &["luteinized"],
    &["luteinised"],
    &["luteinized"],
    &["luteinised"],
];

pub(crate) static ENTRY_LUTEINIZES_490965262104541864: VariantsMap = [
    &["luteinizes"],
    &["luteinises"],
    &["luteinizes"],
    &["luteinises"],
];

pub(crate) static ENTRY_LUTEINIZE_15983798455720539425: VariantsMap = [
    &["luteinize"],
    &["luteinise"],
    &["luteinize"],
    &["luteinise"],
];

pub(crate) static ENTRY_LUTEINIZING_14093891372252248907: VariantsMap = [
    &["luteinizing"],
    &["luteinising"],
    &["luteinizing"],
    &["luteinising"],
];

pub(crate) static ENTRY_LUTHERANIZERS_3305274308745110063: VariantsMap = [
    &["lutheranizers"],
    &["lutheranisers"],
    &["lutheranizers"],
    &["lutheranisers"],
];

pub(crate) static ENTRY_LUTHERANIZER_4331994060702238391: VariantsMap = [
    &["lutheranizer"],
    &["lutheraniser"],
    &["lutheranizer"],
    &["lutheraniser"],
];

pub(crate) static ENTRY_LUTHERANIZES_6735624303465810961: VariantsMap = [
    &["lutheranizes"],
    &["lutheranises"],
    &["lutheranizes"],
    &["lutheranises"],
];

pub(crate) static ENTRY_LUTHERANIZE_3661784829525467686: VariantsMap = [
    &["lutheranize"],
    &["lutheranise"],
    &["lutheranize"],
    &["lutheranise"],
];

pub(crate) static ENTRY_LUTRINE_10287032623387360926: VariantsMap =
    [&["lutrine"], &["lutrinae"], &["lutrinae"], &["lutrinae"]];

pub(crate) static ENTRY_LYMPHEDEMA_9462257687050546686: VariantsMap = [
    &["lymphedema"],
    &["lymphoedema"],
    &["lymphoedema"],
    &["lymphoedema"],
];

pub(crate) static ENTRY_LYMPHEMIA_4006395487683547063: VariantsMap = [
    &["lymphemia"],
    &["lymphaemia"],
    &["lymphaemia"],
    &["lymphaemia"],
];

pub(crate) static ENTRY_LYOPHILIZATIONS_11641961854700529778: VariantsMap = [
    &["lyophilizations"],
    &["lyophilisations"],
    &["lyophilizations"],
    &["lyophilisations"],
];

pub(crate) static ENTRY_LYOPHILIZATION_238925001880862200: VariantsMap = [
    &["lyophilization"],
    &["lyophilisation"],
    &["lyophilization"],
    &["lyophilisation"],
];

pub(crate) static ENTRY_LYOPHILIZED_12354358301774087178: VariantsMap = [
    &["lyophilized"],
    &["lyophilised"],
    &["lyophilized"],
    &["lyophilised"],
];

pub(crate) static ENTRY_LYOPHILIZER_16461672929174295949: VariantsMap = [
    &["lyophilizer"],
    &["lyophiliser"],
    &["lyophilizer"],
    &["lyophiliser"],
];

pub(crate) static ENTRY_LYOPHILIZES_10620381546865479198: VariantsMap = [
    &["lyophilizes"],
    &["lyophilises"],
    &["lyophilizes"],
    &["lyophilises"],
];

pub(crate) static ENTRY_LYOPHILIZE_17394361786807322599: VariantsMap = [
    &["lyophilize"],
    &["lyophilise"],
    &["lyophilize"],
    &["lyophilise"],
];

pub(crate) static ENTRY_LYOPHILIZING_854033355703357663: VariantsMap = [
    &["lyophilizing"],
    &["lyophilising"],
    &["lyophilizing"],
    &["lyophilising"],
];

pub(crate) static ENTRY_LYRICIZATION_4845217792517129539: VariantsMap = [
    &["lyricization"],
    &["lyricisation"],
    &["lyricization"],
    &["lyricisation"],
];

pub(crate) static ENTRY_LYRICIZED_10062582136112184480: VariantsMap = [
    &["lyricized"],
    &["lyricised"],
    &["lyricized"],
    &["lyricised"],
];

pub(crate) static ENTRY_LYRICIZES_17152418688457986946: VariantsMap = [
    &["lyricizes"],
    &["lyricises"],
    &["lyricizes"],
    &["lyricises"],
];

pub(crate) static ENTRY_LYRICIZE_3580471702679217431: VariantsMap =
    [&["lyricize"], &["lyricise"], &["lyricize"], &["lyricise"]];

pub(crate) static ENTRY_LYRICIZING_12512179180165755609: VariantsMap = [
    &["lyricizing"],
    &["lyricising"],
    &["lyricizing"],
    &["lyricising"],
];

pub(crate) static ENTRY_LYSOGENIZATION_16032634144563300808: VariantsMap = [
    &["lysogenization"],
    &["lysogenisation"],
    &["lysogenization"],
    &["lysogenisation"],
];

pub(crate) static ENTRY_LYSOGENIZED_694860359451013188: VariantsMap = [
    &["lysogenized"],
    &["lysogenised"],
    &["lysogenized"],
    &["lysogenised"],
];

pub(crate) static ENTRY_LYSOGENIZES_7093370063997505423: VariantsMap = [
    &["lysogenizes"],
    &["lysogenises"],
    &["lysogenizes"],
    &["lysogenises"],
];

pub(crate) static ENTRY_LYSOGENIZE_13480065233288456493: VariantsMap = [
    &["lysogenize"],
    &["lysogenise"],
    &["lysogenize"],
    &["lysogenise"],
];

pub(crate) static ENTRY_LYSOGENIZING_12375606902428979326: VariantsMap = [
    &["lysogenizing"],
    &["lysogenising"],
    &["lysogenizing"],
    &["lysogenising"],
];

pub(crate) static ENTRY_MACADAMIZATIONS_16187855466620683932: VariantsMap = [
    &["macadamizations"],
    &["macadamisations"],
    &["macadamizations"],
    &["macadamisations"],
];

pub(crate) static ENTRY_MACADAMIZATION_1584431820497876066: VariantsMap = [
    &["macadamization"],
    &["macadamisation"],
    &["macadamization"],
    &["macadamisation"],
];

pub(crate) static ENTRY_MACADAMIZED_13516952754031008572: VariantsMap = [
    &["macadamized"],
    &["macadamised"],
    &["macadamized"],
    &["macadamised"],
];

pub(crate) static ENTRY_MACADAMIZES_11934694989490356459: VariantsMap = [
    &["macadamizes"],
    &["macadamises"],
    &["macadamizes"],
    &["macadamises"],
];

pub(crate) static ENTRY_MACADAMIZE_1644284481314424821: VariantsMap = [
    &["macadamize"],
    &["macadamise"],
    &["macadamize"],
    &["macadamise"],
];

pub(crate) static ENTRY_MACADAMIZING_8185181599575595730: VariantsMap = [
    &["macadamizing"],
    &["macadamising"],
    &["macadamizing"],
    &["macadamising"],
];

pub(crate) static ENTRY_MACARIZED_2654443907575694690: VariantsMap = [
    &["macarized"],
    &["macarised"],
    &["macarized"],
    &["macarised"],
];

pub(crate) static ENTRY_MACARIZES_7151048964818447107: VariantsMap = [
    &["macarizes"],
    &["macarises"],
    &["macarizes"],
    &["macarises"],
];

pub(crate) static ENTRY_MACARIZE_14735487357752047094: VariantsMap =
    [&["macarize"], &["macarise"], &["macarize"], &["macarise"]];

pub(crate) static ENTRY_MACARIZING_1437864631803225684: VariantsMap = [
    &["macarizing"],
    &["macarising"],
    &["macarizing"],
    &["macarising"],
];

pub(crate) static ENTRY_MACCABEAN_16382101033687873595: VariantsMap = [
    &["maccabean"],
    &["maccabaean"],
    &["maccabaean"],
    &["maccabaean"],
];

pub(crate) static ENTRY_MACHINIZATIONS_1639400841870117244: VariantsMap = [
    &["machinizations"],
    &["machinisations"],
    &["machinizations"],
    &["machinisations"],
];

pub(crate) static ENTRY_MACHINIZATION_2975760707951176713: VariantsMap = [
    &["machinization"],
    &["machinisation"],
    &["machinization"],
    &["machinisation"],
];

pub(crate) static ENTRY_MACHINIZES_15690933792051137186: VariantsMap = [
    &["machinizes"],
    &["machinises"],
    &["machinizes"],
    &["machinises"],
];

pub(crate) static ENTRY_MACHINIZE_364217525312318254: VariantsMap = [
    &["machinize"],
    &["machinise"],
    &["machinize"],
    &["machinise"],
];

pub(crate) static ENTRY_MACRANDER_8372772025292196647: VariantsMap = [
    &["macrander"],
    &["macrandre"],
    &["macrandre"],
    &["macrandre"],
];

pub(crate) static ENTRY_MACULE_16877936518180777160: VariantsMap =
    [&["macule"], &["maculae"], &["maculae"], &["maculae"]];

pub(crate) static ENTRY_MADERA_11374954307771265273: VariantsMap =
    [&["madera"], &["madoera"], &["madoera"], &["madoera"]];

pub(crate) static ENTRY_MADERIZATIONS_16223063707725361780: VariantsMap = [
    &["maderizations"],
    &["maderisations"],
    &["maderizations"],
    &["maderisations"],
];

pub(crate) static ENTRY_MADERIZATION_3019983916135661284: VariantsMap = [
    &["maderization"],
    &["maderisation"],
    &["maderization"],
    &["maderisation"],
];

pub(crate) static ENTRY_MADERIZED_2215427830718499320: VariantsMap = [
    &["maderized"],
    &["maderised"],
    &["maderized"],
    &["maderised"],
];

pub(crate) static ENTRY_MADERIZES_4849561976516325657: VariantsMap = [
    &["maderizes"],
    &["maderises"],
    &["maderizes"],
    &["maderises"],
];

pub(crate) static ENTRY_MADERIZE_4945810677802352669: VariantsMap =
    [&["maderize"], &["maderise"], &["maderize"], &["maderise"]];

pub(crate) static ENTRY_MADERIZING_6023219948706368202: VariantsMap = [
    &["maderizing"],
    &["maderising"],
    &["maderizing"],
    &["maderising"],
];

pub(crate) static ENTRY_MAED_10894543362537765338: VariantsMap =
    [&["maed"], &["maaed"], &["maaed"], &["maaed"]];

pub(crate) static ENTRY_MAENADIC_10391457552203438714: VariantsMap =
    [&["maenadic"], &["maenadic"], &["maenadic"], &["maenadic"]];

pub(crate) static ENTRY_MAENADS_16301310937820360625: VariantsMap =
    [&["maenads"], &["maenads"], &["maenads"], &["maenads"]];

pub(crate) static ENTRY_MAENAD_17014549470545688439: VariantsMap =
    [&["maenad"], &["maenad"], &["maenad"], &["maenad"]];

pub(crate) static ENTRY_MAGICALIZES_13106311844272986894: VariantsMap = [
    &["magicalizes"],
    &["magicalises"],
    &["magicalizes"],
    &["magicalises"],
];

pub(crate) static ENTRY_MAGICALIZE_7976953137203064254: VariantsMap = [
    &["magicalize"],
    &["magicalise"],
    &["magicalize"],
    &["magicalise"],
];

pub(crate) static ENTRY_MAGNETIZABILITIES_4532976500756958585: VariantsMap = [
    &["magnetizabilities"],
    &["magnetisabilities"],
    &["magnetizabilities"],
    &["magnetisabilities"],
];

pub(crate) static ENTRY_MAGNETIZABILITY_8897213535690779505: VariantsMap = [
    &["magnetizability"],
    &["magnetisability"],
    &["magnetizability"],
    &["magnetisability"],
];

pub(crate) static ENTRY_MAGNETIZABLES_5771377044771033482: VariantsMap = [
    &["magnetizables"],
    &["magnetisables"],
    &["magnetizables"],
    &["magnetisables"],
];

pub(crate) static ENTRY_MAGNETIZABLE_7101166656275427306: VariantsMap = [
    &["magnetizable"],
    &["magnetisable"],
    &["magnetizable"],
    &["magnetisable"],
];

pub(crate) static ENTRY_MAGNETIZATIONS_4200667569204648331: VariantsMap = [
    &["magnetizations"],
    &["magnetisations"],
    &["magnetizations"],
    &["magnetisations"],
];

pub(crate) static ENTRY_MAGNETIZATION_9483881663837891030: VariantsMap = [
    &["magnetization"],
    &["magnetisation"],
    &["magnetization"],
    &["magnetisation"],
];

pub(crate) static ENTRY_MAGNETIZED_12485429316868328420: VariantsMap = [
    &["magnetized"],
    &["magnetised"],
    &["magnetized"],
    &["magnetised"],
];

pub(crate) static ENTRY_MAGNETIZERS_13287799402027624739: VariantsMap = [
    &["magnetizers"],
    &["magnetisers"],
    &["magnetizers"],
    &["magnetisers"],
];

pub(crate) static ENTRY_MAGNETIZER_6335170645696487654: VariantsMap = [
    &["magnetizer"],
    &["magnetiser"],
    &["magnetizer"],
    &["magnetiser"],
];

pub(crate) static ENTRY_MAGNETIZES_15356358395494315006: VariantsMap = [
    &["magnetizes"],
    &["magnetises"],
    &["magnetizes"],
    &["magnetises"],
];

pub(crate) static ENTRY_MAGNETIZE_17032040585995329794: VariantsMap = [
    &["magnetize"],
    &["magnetise"],
    &["magnetize"],
    &["magnetise"],
];

pub(crate) static ENTRY_MAGNETIZING_16368507504957955556: VariantsMap = [
    &["magnetizing"],
    &["magnetising"],
    &["magnetizing"],
    &["magnetising"],
];

pub(crate) static ENTRY_MAHOGANIZED_13765023460960760851: VariantsMap = [
    &["mahoganized"],
    &["mahoganised"],
    &["mahoganized"],
    &["mahoganised"],
];

pub(crate) static ENTRY_MAHOGANIZES_8869675625531273161: VariantsMap = [
    &["mahoganizes"],
    &["mahoganises"],
    &["mahoganizes"],
    &["mahoganises"],
];

pub(crate) static ENTRY_MAHOGANIZE_12704575684923134739: VariantsMap = [
    &["mahoganize"],
    &["mahoganise"],
    &["mahoganize"],
    &["mahoganise"],
];

pub(crate) static ENTRY_MAHOGANIZING_2157300732143181632: VariantsMap = [
    &["mahoganizing"],
    &["mahoganising"],
    &["mahoganizing"],
    &["mahoganising"],
];

pub(crate) static ENTRY_MAIGER_13537152603960564241: VariantsMap =
    [&["maiger"], &["maigre"], &["maigre"], &["maigre"]];

pub(crate) static ENTRY_MAINORS_8986120186842844665: VariantsMap =
    [&["mainors"], &["mainours"], &["mainours"], &["mainours"]];

pub(crate) static ENTRY_MAINOR_5733081872389949682: VariantsMap =
    [&["mainor"], &["mainour"], &["mainour"], &["mainour"]];

pub(crate) static ENTRY_MAINPRIZE_16260916113631122574: VariantsMap = [
    &["mainprize"],
    &["mainprise"],
    &["mainprize"],
    &["mainprise"],
];

pub(crate) static ENTRY_MAISTERS_17393346748487206287: VariantsMap =
    [&["maisters"], &["maistres"], &["maistres"], &["maistres"]];

pub(crate) static ENTRY_MAIZE_12062254114105624826: VariantsMap =
    [&["maize"], &["maise"], &["maize"], &["maise"]];

pub(crate) static ENTRY_MAJORIZES_12523983368341336385: VariantsMap = [
    &["majorizes"],
    &["majorises"],
    &["majorizes"],
    &["majorises"],
];

pub(crate) static ENTRY_MAJORIZE_5539776276955597241: VariantsMap =
    [&["majorize"], &["majorise"], &["majorize"], &["majorise"]];

pub(crate) static ENTRY_MAJUSCULE_12033401179137388733: VariantsMap = [
    &["majuscule"],
    &["majusculae"],
    &["majusculae"],
    &["majusculae"],
];

pub(crate) static ENTRY_MALAYIZES_18276018162196625473: VariantsMap = [
    &["malayizes"],
    &["malayises"],
    &["malayizes"],
    &["malayises"],
];

pub(crate) static ENTRY_MALAYIZE_5296430804535202958: VariantsMap =
    [&["malayize"], &["malayise"], &["malayize"], &["malayise"]];

pub(crate) static ENTRY_MALLEABLIZES_18366287958729116459: VariantsMap = [
    &["malleablizes"],
    &["malleablises"],
    &["malleablizes"],
    &["malleablises"],
];

pub(crate) static ENTRY_MALLEABLIZE_10318655257721603696: VariantsMap = [
    &["malleablize"],
    &["malleablise"],
    &["malleablize"],
    &["malleablise"],
];

pub(crate) static ENTRY_MALODOROUSNESS_10428601882655519000: VariantsMap = [
    &["malodorousness"],
    &["malodourousness"],
    &["malodourousness"],
    &["malodourousness"],
];

pub(crate) static ENTRY_MALODORS_5259814758580078739: VariantsMap = [
    &["malodors"],
    &["malodours"],
    &["malodours"],
    &["malodours"],
];

pub(crate) static ENTRY_MALODOR_9484860272957019145: VariantsMap =
    [&["malodor"], &["malodour"], &["malodour"], &["malodour"]];

pub(crate) static ENTRY_MANDARINIZES_2520496390400529848: VariantsMap = [
    &["mandarinizes"],
    &["mandarinises"],
    &["mandarinizes"],
    &["mandarinises"],
];

pub(crate) static ENTRY_MANDARINIZE_10729500110561326871: VariantsMap = [
    &["mandarinize"],
    &["mandarinise"],
    &["mandarinize"],
    &["mandarinise"],
];

pub(crate) static ENTRY_MANDEANS_6139983685022239651: VariantsMap = [
    &["mandeans"],
    &["mandaeans"],
    &["mandaeans"],
    &["mandaeans"],
];

pub(crate) static ENTRY_MANDEAN_16756153629008001222: VariantsMap =
    [&["mandean"], &["mandaean"], &["mandaean"], &["mandaean"]];

pub(crate) static ENTRY_MANDOER_4488991635236985614: VariantsMap =
    [&["mandoer"], &["mandore"], &["mandore"], &["mandore"]];

pub(crate) static ENTRY_MANEUVERABILITIES_1191935897985178601: VariantsMap = [
    &["maneuverabilities"],
    &["manoeuvrabilities"],
    &["manoeuvrabilities"],
    &["manoeuvrabilities"],
];

pub(crate) static ENTRY_MANEUVERABILITY_13828505830247153454: VariantsMap = [
    &["maneuverability"],
    &["manoeuvrability"],
    &["manoeuvrability"],
    &["manoeuvrability"],
];

pub(crate) static ENTRY_MANEUVERABLER_8453360608082720316: VariantsMap = [
    &["maneuverabler"],
    &["manoeuvrabler"],
    &["manoeuvrabler"],
    &["manoeuvrabler"],
];

pub(crate) static ENTRY_MANEUVERABLEST_9950206171061443172: VariantsMap = [
    &["maneuverablest"],
    &["manoeuvrablest"],
    &["manoeuvrablest"],
    &["manoeuvrablest"],
];

pub(crate) static ENTRY_MANEUVERABLE_15149317836898965786: VariantsMap = [
    &["maneuverable"],
    &["manoeuvrable"],
    &["manoeuvrable"],
    &["manoeuvrable"],
];

pub(crate) static ENTRY_MANEUVERED_1283956380608823667: VariantsMap = [
    &["maneuvered"],
    &["manoeuvred"],
    &["manoeuvred"],
    &["manoeuvred"],
];

pub(crate) static ENTRY_MANEUVERERS_16918168302778575325: VariantsMap = [
    &["maneuverers"],
    &["manoeuvrers"],
    &["manoeuvrers"],
    &["manoeuvrers"],
];

pub(crate) static ENTRY_MANEUVERER_16909121286634766647: VariantsMap = [
    &["maneuverer"],
    &["manoeuvrer"],
    &["manoeuvrer"],
    &["manoeuvrer"],
];

pub(crate) static ENTRY_MANEUVERINGS_15820076380390390309: VariantsMap = [
    &["maneuverings"],
    &["manoeuvrings"],
    &["manoeuvrings"],
    &["manoeuvrings"],
];

pub(crate) static ENTRY_MANEUVERING_7486833768050311559: VariantsMap = [
    &["maneuvering"],
    &["manoeuvring"],
    &["manoeuvring"],
    &["manoeuvring"],
];

pub(crate) static ENTRY_MANEUVERS_11853919997692060327: VariantsMap = [
    &["maneuvers"],
    &["manoeuvres"],
    &["manoeuvres"],
    &["manoeuvres"],
];

pub(crate) static ENTRY_MANEUVER_2827757268422810275: VariantsMap = [
    &["maneuver"],
    &["manoeuvre"],
    &["manoeuvre"],
    &["manoeuvre"],
];

pub(crate) static ENTRY_MANHATTANIZES_14271946544415650661: VariantsMap = [
    &["manhattanizes"],
    &["manhattanises"],
    &["manhattanizes"],
    &["manhattanises"],
];

pub(crate) static ENTRY_MANHATTANIZE_5647753485098145098: VariantsMap = [
    &["manhattanize"],
    &["manhattanise"],
    &["manhattanize"],
    &["manhattanise"],
];

pub(crate) static ENTRY_MANICHEANISM_14488550733831474062: VariantsMap = [
    &["manicheanism"],
    &["manichaeanism"],
    &["manichaeanism"],
    &["manichaeanism"],
];

pub(crate) static ENTRY_MANICHEANS_3707320145394072632: VariantsMap = [
    &["manicheans"],
    &["manichaeans"],
    &["manichaeans"],
    &["manichaeans"],
];

pub(crate) static ENTRY_MANICHEISMS_4550426137129529134: VariantsMap = [
    &["manicheisms"],
    &["manichaeisms"],
    &["manichaeisms"],
    &["manichaeisms"],
];

pub(crate) static ENTRY_MANICHEISM_13987531657185741850: VariantsMap = [
    &["manicheism"],
    &["manichaeism"],
    &["manichaeism"],
    &["manichaeism"],
];

pub(crate) static ENTRY_MANICHEUS_2463259862210459140: VariantsMap = [
    &["manicheus"],
    &["manichaeus"],
    &["manichaeus"],
    &["manichaeus"],
];

pub(crate) static ENTRY_MANNERIZES_6256609262116879332: VariantsMap = [
    &["mannerizes"],
    &["mannerises"],
    &["mannerizes"],
    &["mannerises"],
];

pub(crate) static ENTRY_MANNERIZE_11395156809687075343: VariantsMap = [
    &["mannerize"],
    &["mannerise"],
    &["mannerize"],
    &["mannerise"],
];

pub(crate) static ENTRY_MANTES_7948491308942840471: VariantsMap =
    [&["mantes"], &["mantoes"], &["mantoes"], &["mantoes"]];

pub(crate) static ENTRY_MARBLEIZED_9909511827189901753: VariantsMap = [
    &["marbleized"],
    &["marbleised"],
    &["marbleized"],
    &["marbleised"],
];

pub(crate) static ENTRY_MARBLEIZES_13333904138730712912: VariantsMap = [
    &["marbleizes"],
    &["marbleises"],
    &["marbleizes"],
    &["marbleises"],
];

pub(crate) static ENTRY_MARBLEIZE_1587151371458840015: VariantsMap = [
    &["marbleize"],
    &["marbleise"],
    &["marbleize"],
    &["marbleise"],
];

pub(crate) static ENTRY_MARBLEIZING_4602625009210891897: VariantsMap = [
    &["marbleizing"],
    &["marbleising"],
    &["marbleizing"],
    &["marbleising"],
];

pub(crate) static ENTRY_MARGARITE_2133834570687219123: VariantsMap = [
    &["margarite"],
    &["margaritae"],
    &["margaritae"],
    &["margaritae"],
];

pub(crate) static ENTRY_MARGINALIZATION_845141011968765477: VariantsMap = [
    &["marginalization"],
    &["marginalisation"],
    &["marginalization"],
    &["marginalisation"],
];

pub(crate) static ENTRY_MARGINALIZED_7354157641651435628: VariantsMap = [
    &["marginalized"],
    &["marginalised"],
    &["marginalized"],
    &["marginalised"],
];

pub(crate) static ENTRY_MARGINALIZES_2216379754364106454: VariantsMap = [
    &["marginalizes"],
    &["marginalises"],
    &["marginalizes"],
    &["marginalises"],
];

pub(crate) static ENTRY_MARGINALIZE_3216468021553056827: VariantsMap = [
    &["marginalize"],
    &["marginalise"],
    &["marginalize"],
    &["marginalise"],
];

pub(crate) static ENTRY_MARGINALIZING_14750515117536904615: VariantsMap = [
    &["marginalizing"],
    &["marginalising"],
    &["marginalizing"],
    &["marginalising"],
];

pub(crate) static ENTRY_MARMARIZED_6434649714306603112: VariantsMap = [
    &["marmarized"],
    &["marmarised"],
    &["marmarized"],
    &["marmarised"],
];

pub(crate) static ENTRY_MARMARIZES_4398920726053776800: VariantsMap = [
    &["marmarizes"],
    &["marmarises"],
    &["marmarizes"],
    &["marmarises"],
];

pub(crate) static ENTRY_MARMARIZE_1530762564973937962: VariantsMap = [
    &["marmarize"],
    &["marmarise"],
    &["marmarize"],
    &["marmarise"],
];

pub(crate) static ENTRY_MARMARIZING_10944122775049128953: VariantsMap = [
    &["marmarizing"],
    &["marmarising"],
    &["marmarizing"],
    &["marmarising"],
];

pub(crate) static ENTRY_MARMELIZED_14017857917576761060: VariantsMap = [
    &["marmelized"],
    &["marmelised"],
    &["marmelized"],
    &["marmelised"],
];

pub(crate) static ENTRY_MARMELIZES_149426436477796995: VariantsMap = [
    &["marmelizes"],
    &["marmelises"],
    &["marmelizes"],
    &["marmelises"],
];

pub(crate) static ENTRY_MARMELIZE_3830049982860361754: VariantsMap = [
    &["marmelize"],
    &["marmelise"],
    &["marmelize"],
    &["marmelise"],
];

pub(crate) static ENTRY_MARMELIZING_16367583444998062001: VariantsMap = [
    &["marmelizing"],
    &["marmelising"],
    &["marmelizing"],
    &["marmelising"],
];

pub(crate) static ENTRY_MARSHALED_17388940496017695622: VariantsMap = [
    &["marshaled"],
    &["marshalled"],
    &["marshalled"],
    &["marshalled"],
];

pub(crate) static ENTRY_MARSHALING_14317227469213788602: VariantsMap = [
    &["marshaling"],
    &["marshalling"],
    &["marshalling"],
    &["marshalling"],
];

pub(crate) static ENTRY_MARSUPIALIZATIONS_3654437093276933848: VariantsMap = [
    &["marsupializations"],
    &["marsupialisations"],
    &["marsupializations"],
    &["marsupialisations"],
];

pub(crate) static ENTRY_MARSUPIALIZATION_10219947028803421507: VariantsMap = [
    &["marsupialization"],
    &["marsupialisation"],
    &["marsupialization"],
    &["marsupialisation"],
];

pub(crate) static ENTRY_MARSUPIALIZED_10735344292991105898: VariantsMap = [
    &["marsupialized"],
    &["marsupialised"],
    &["marsupialized"],
    &["marsupialised"],
];

pub(crate) static ENTRY_MARSUPIALIZES_5341397497022180977: VariantsMap = [
    &["marsupializes"],
    &["marsupialises"],
    &["marsupializes"],
    &["marsupialises"],
];

pub(crate) static ENTRY_MARSUPIALIZE_12376296445019036389: VariantsMap = [
    &["marsupialize"],
    &["marsupialise"],
    &["marsupialize"],
    &["marsupialise"],
];

pub(crate) static ENTRY_MARSUPIALIZING_11776500715390903839: VariantsMap = [
    &["marsupializing"],
    &["marsupialising"],
    &["marsupializing"],
    &["marsupialising"],
];

pub(crate) static ENTRY_MARTE_1264890466246841604: VariantsMap =
    [&["marte"], &["martae"], &["martae"], &["martae"]];

pub(crate) static ENTRY_MARTIALIZATIONS_11331832307351504062: VariantsMap = [
    &["martializations"],
    &["martialisations"],
    &["martializations"],
    &["martialisations"],
];

pub(crate) static ENTRY_MARTIALIZATION_5691320795357161519: VariantsMap = [
    &["martialization"],
    &["martialisation"],
    &["martialization"],
    &["martialisation"],
];

pub(crate) static ENTRY_MARTIALIZES_9070015199521476812: VariantsMap = [
    &["martializes"],
    &["martialises"],
    &["martializes"],
    &["martialises"],
];

pub(crate) static ENTRY_MARTIALIZE_6207600694655157640: VariantsMap = [
    &["martialize"],
    &["martialise"],
    &["martialize"],
    &["martialise"],
];

pub(crate) static ENTRY_MARTYRIZATIONS_7865429312991140174: VariantsMap = [
    &["martyrizations"],
    &["martyrisations"],
    &["martyrizations"],
    &["martyrisations"],
];

pub(crate) static ENTRY_MARTYRIZATION_1336038246734054184: VariantsMap = [
    &["martyrization"],
    &["martyrisation"],
    &["martyrization"],
    &["martyrisation"],
];

pub(crate) static ENTRY_MARTYRIZED_13501718715194307317: VariantsMap = [
    &["martyrized"],
    &["martyrised"],
    &["martyrized"],
    &["martyrised"],
];

pub(crate) static ENTRY_MARTYRIZERS_13107375000111031172: VariantsMap = [
    &["martyrizers"],
    &["martyrisers"],
    &["martyrizers"],
    &["martyrisers"],
];

pub(crate) static ENTRY_MARTYRIZER_352978430796310060: VariantsMap = [
    &["martyrizer"],
    &["martyriser"],
    &["martyrizer"],
    &["martyriser"],
];

pub(crate) static ENTRY_MARTYRIZES_7886905685535476589: VariantsMap = [
    &["martyrizes"],
    &["martyrises"],
    &["martyrizes"],
    &["martyrises"],
];

pub(crate) static ENTRY_MARTYRIZE_10273613966575722757: VariantsMap = [
    &["martyrize"],
    &["martyrise"],
    &["martyrize"],
    &["martyrise"],
];

pub(crate) static ENTRY_MARTYRIZING_12166812365596250426: VariantsMap = [
    &["martyrizing"],
    &["martyrising"],
    &["martyrizing"],
    &["martyrising"],
];

pub(crate) static ENTRY_MARVELED_7643699015465825056: VariantsMap = [
    &["marveled"],
    &["marvelled"],
    &["marvelled"],
    &["marvelled"],
];

pub(crate) static ENTRY_MARVELER_3178046291913300644: VariantsMap = [
    &["marveler"],
    &["marveller"],
    &["marveller"],
    &["marveller"],
];

pub(crate) static ENTRY_MARVELING_1354065551177639579: VariantsMap = [
    &["marveling"],
    &["marvelling"],
    &["marvelling"],
    &["marvelling"],
];

pub(crate) static ENTRY_MARVELOUSER_7705396939137168592: VariantsMap = [
    &["marvelouser"],
    &["marvellouser"],
    &["marvellouser"],
    &["marvellouser"],
];

pub(crate) static ENTRY_MARVELOUSEST_912599784216442683: VariantsMap = [
    &["marvelousest"],
    &["marvellousest"],
    &["marvellousest"],
    &["marvellousest"],
];

pub(crate) static ENTRY_MARVELOUSLIER_12811886966499643595: VariantsMap = [
    &["marvelouslier"],
    &["marvellouslier"],
    &["marvellouslier"],
    &["marvellouslier"],
];

pub(crate) static ENTRY_MARVELOUSLIEST_16737159169599622279: VariantsMap = [
    &["marvelousliest"],
    &["marvellousliest"],
    &["marvellousliest"],
    &["marvellousliest"],
];

pub(crate) static ENTRY_MARVELOUSLY_18213355249698171803: VariantsMap = [
    &["marvelously"],
    &["marvellously"],
    &["marvellously"],
    &["marvellously"],
];

pub(crate) static ENTRY_MARVELOUSNESSES_8865126466913012309: VariantsMap = [
    &["marvelousnesses"],
    &["marvellousnesses"],
    &["marvellousnesses"],
    &["marvellousnesses"],
];

pub(crate) static ENTRY_MARVELOUSNESS_15500940188234401273: VariantsMap = [
    &["marvelousness"],
    &["marvellousness"],
    &["marvellousness"],
    &["marvellousness"],
];

pub(crate) static ENTRY_MARVELOUS_82637440345212214: VariantsMap = [
    &["marvelous"],
    &["marvellous"],
    &["marvellous"],
    &["marvellous"],
];

pub(crate) static ENTRY_MASCULINIZATIONS_3741302049457474: VariantsMap = [
    &["masculinizations"],
    &["masculinisations"],
    &["masculinizations"],
    &["masculinisations"],
];

pub(crate) static ENTRY_MASCULINIZATION_476161312855423377: VariantsMap = [
    &["masculinization"],
    &["masculinisation"],
    &["masculinization"],
    &["masculinisation"],
];

pub(crate) static ENTRY_MASCULINIZED_1893478532974749197: VariantsMap = [
    &["masculinized"],
    &["masculinised"],
    &["masculinized"],
    &["masculinised"],
];

pub(crate) static ENTRY_MASCULINIZES_5402931026791646861: VariantsMap = [
    &["masculinizes"],
    &["masculinises"],
    &["masculinizes"],
    &["masculinises"],
];

pub(crate) static ENTRY_MASCULINIZE_10465215235891946975: VariantsMap = [
    &["masculinize"],
    &["masculinise"],
    &["masculinize"],
    &["masculinise"],
];

pub(crate) static ENTRY_MASCULINIZING_5578995349640297964: VariantsMap = [
    &["masculinizing"],
    &["masculinising"],
    &["masculinizing"],
    &["masculinising"],
];

pub(crate) static ENTRY_MATERIALIZATIONS_2652185200878385871: VariantsMap = [
    &["materializations"],
    &["materialisations"],
    &["materializations"],
    &["materialisations"],
];

pub(crate) static ENTRY_MATERIALIZATION_15275246538418004637: VariantsMap = [
    &["materialization"],
    &["materialisation"],
    &["materialization"],
    &["materialisation"],
];

pub(crate) static ENTRY_MATERIALIZED_12794251805380683570: VariantsMap = [
    &["materialized"],
    &["materialised"],
    &["materialized"],
    &["materialised"],
];

pub(crate) static ENTRY_MATERIALIZERS_17327920471884108445: VariantsMap = [
    &["materializers"],
    &["materialisers"],
    &["materializers"],
    &["materialisers"],
];

pub(crate) static ENTRY_MATERIALIZER_11688721774965420403: VariantsMap = [
    &["materializer"],
    &["materialiser"],
    &["materializer"],
    &["materialiser"],
];

pub(crate) static ENTRY_MATERIALIZES_1701928859160069487: VariantsMap = [
    &["materializes"],
    &["materialises"],
    &["materializes"],
    &["materialises"],
];

pub(crate) static ENTRY_MATERIALIZE_751513275282658322: VariantsMap = [
    &["materialize"],
    &["materialise"],
    &["materialize"],
    &["materialise"],
];

pub(crate) static ENTRY_MATERIALIZING_12202103934838377179: VariantsMap = [
    &["materializing"],
    &["materialising"],
    &["materializing"],
    &["materialising"],
];

pub(crate) static ENTRY_MATERNALIZED_15273074932454584755: VariantsMap = [
    &["maternalized"],
    &["maternalised"],
    &["maternalized"],
    &["maternalised"],
];

pub(crate) static ENTRY_MATERNALIZES_1361027105246711827: VariantsMap = [
    &["maternalizes"],
    &["maternalises"],
    &["maternalizes"],
    &["maternalises"],
];

pub(crate) static ENTRY_MATERNALIZE_8146656266552049814: VariantsMap = [
    &["maternalize"],
    &["maternalise"],
    &["maternalize"],
    &["maternalise"],
];

pub(crate) static ENTRY_MATERNALIZING_15264839345210217548: VariantsMap = [
    &["maternalizing"],
    &["maternalising"],
    &["maternalizing"],
    &["maternalising"],
];

pub(crate) static ENTRY_MATERS_6749099045482027726: VariantsMap =
    [&["maters"], &["matres"], &["matres"], &["matres"]];

pub(crate) static ENTRY_MATHEMATICIZED_4371402645098526662: VariantsMap = [
    &["mathematicized"],
    &["mathematicised"],
    &["mathematicized"],
    &["mathematicised"],
];

pub(crate) static ENTRY_MATHEMATICIZES_8912469294750964039: VariantsMap = [
    &["mathematicizes"],
    &["mathematicises"],
    &["mathematicizes"],
    &["mathematicises"],
];

pub(crate) static ENTRY_MATHEMATICIZE_7619298293588115367: VariantsMap = [
    &["mathematicize"],
    &["mathematicise"],
    &["mathematicize"],
    &["mathematicise"],
];

pub(crate) static ENTRY_MATHEMATICIZING_4735407800819113204: VariantsMap = [
    &["mathematicizing"],
    &["mathematicising"],
    &["mathematicizing"],
    &["mathematicising"],
];

pub(crate) static ENTRY_MATHEMATIZATIONS_12482611724386674740: VariantsMap = [
    &["mathematizations"],
    &["mathematisations"],
    &["mathematizations"],
    &["mathematisations"],
];

pub(crate) static ENTRY_MATHEMATIZATION_4218296263451613289: VariantsMap = [
    &["mathematization"],
    &["mathematisation"],
    &["mathematization"],
    &["mathematisation"],
];

pub(crate) static ENTRY_MATHEMATIZED_868413170166016625: VariantsMap = [
    &["mathematized"],
    &["mathematised"],
    &["mathematized"],
    &["mathematised"],
];

pub(crate) static ENTRY_MATHEMATIZES_16106848134857387696: VariantsMap = [
    &["mathematizes"],
    &["mathematises"],
    &["mathematizes"],
    &["mathematises"],
];

pub(crate) static ENTRY_MATHEMATIZE_15531317149241859255: VariantsMap = [
    &["mathematize"],
    &["mathematise"],
    &["mathematize"],
    &["mathematise"],
];

pub(crate) static ENTRY_MATHEMATIZING_8212888872028484322: VariantsMap = [
    &["mathematizing"],
    &["mathematising"],
    &["mathematizing"],
    &["mathematising"],
];

pub(crate) static ENTRY_MATH_3909695083920851313: VariantsMap =
    [&["math"], &["maths"], &["math"], &["maths"]];

pub(crate) static ENTRY_MATRONIZED_9922374353897617495: VariantsMap = [
    &["matronized"],
    &["matronised"],
    &["matronized"],
    &["matronised"],
];

pub(crate) static ENTRY_MATRONIZES_6031455015684947908: VariantsMap = [
    &["matronizes"],
    &["matronises"],
    &["matronizes"],
    &["matronises"],
];

pub(crate) static ENTRY_MATRONIZE_9290846381271361340: VariantsMap = [
    &["matronize"],
    &["matronise"],
    &["matronize"],
    &["matronise"],
];

pub(crate) static ENTRY_MATRONIZING_17960105682675878116: VariantsMap = [
    &["matronizing"],
    &["matronising"],
    &["matronizing"],
    &["matronising"],
];

pub(crate) static ENTRY_MATS_9238000290813577978: VariantsMap = [
    &["mats", "mattes", "matts"],
    &["matts"],
    &["mattes"],
    &["matts"],
];

pub(crate) static ENTRY_MATTHEAN_1484447536407526980: VariantsMap = [
    &["matthean"],
    &["matthaean"],
    &["matthaean"],
    &["matthaean"],
];

pub(crate) static ENTRY_MAUDLINIZES_5073047051339035071: VariantsMap = [
    &["maudlinizes"],
    &["maudlinises"],
    &["maudlinizes"],
    &["maudlinises"],
];

pub(crate) static ENTRY_MAUDLINIZE_9618965871569092413: VariantsMap = [
    &["maudlinize"],
    &["maudlinise"],
    &["maudlinize"],
    &["maudlinise"],
];

pub(crate) static ENTRY_MAUGER_14029214682617013006: VariantsMap =
    [&["mauger"], &["maugre"], &["maugre"], &["maugre"]];

pub(crate) static ENTRY_MAXIMIZATIONS_17498251387785973609: VariantsMap = [
    &["maximizations"],
    &["maximisations"],
    &["maximizations"],
    &["maximisations"],
];

pub(crate) static ENTRY_MAXIMIZATION_3582457980210831801: VariantsMap = [
    &["maximization"],
    &["maximisation"],
    &["maximization"],
    &["maximisation"],
];

pub(crate) static ENTRY_MAXIMIZED_18322342409602816855: VariantsMap = [
    &["maximized"],
    &["maximised"],
    &["maximized"],
    &["maximised"],
];

pub(crate) static ENTRY_MAXIMIZERS_9246458667812951153: VariantsMap = [
    &["maximizers"],
    &["maximisers"],
    &["maximizers"],
    &["maximisers"],
];

pub(crate) static ENTRY_MAXIMIZER_7689755575199270297: VariantsMap = [
    &["maximizer"],
    &["maximiser"],
    &["maximizer"],
    &["maximiser"],
];

pub(crate) static ENTRY_MAXIMIZES_8121680605285929508: VariantsMap = [
    &["maximizes"],
    &["maximises"],
    &["maximizes"],
    &["maximises"],
];

pub(crate) static ENTRY_MAXIMIZE_3031872585153948954: VariantsMap =
    [&["maximize"], &["maximise"], &["maximize"], &["maximise"]];

pub(crate) static ENTRY_MAXIMIZING_944961283075648715: VariantsMap = [
    &["maximizing"],
    &["maximising"],
    &["maximizing"],
    &["maximising"],
];

pub(crate) static ENTRY_MEAGERLY_2869873257215414407: VariantsMap =
    [&["meagerly"], &["meagrely"], &["meagrely"], &["meagrely"]];

pub(crate) static ENTRY_MEAGERNESSES_3102048822221539405: VariantsMap = [
    &["meagernesses"],
    &["meagrenesses"],
    &["meagrenesses"],
    &["meagrenesses"],
];

pub(crate) static ENTRY_MEAGERNESS_12236245874669728945: VariantsMap = [
    &["meagerness"],
    &["meagreness"],
    &["meagreness"],
    &["meagreness"],
];

pub(crate) static ENTRY_MEAGERRER_16342562731232285770: VariantsMap =
    [&["meagerrer"], &["meagrer"], &["meagrer"], &["meagrer"]];

pub(crate) static ENTRY_MEAGERREST_10155328827598626356: VariantsMap =
    [&["meagerrest"], &["meagrest"], &["meagrest"], &["meagrest"]];

pub(crate) static ENTRY_MEAGER_16437138915349494155: VariantsMap =
    [&["meager"], &["meagre"], &["meagre"], &["meagre"]];

pub(crate) static ENTRY_MEANDRINE_17403064704702625622: VariantsMap = [
    &["meandrine"],
    &["maeandrine"],
    &["maeandrine"],
    &["maeandrine"],
];

pub(crate) static ENTRY_MEANDRINIFORM_447585923576901338: VariantsMap = [
    &["meandriniform"],
    &["maeandriniform"],
    &["maeandriniform"],
    &["maeandriniform"],
];

pub(crate) static ENTRY_MECHANICALIZATIONS_3581916288212780638: VariantsMap = [
    &["mechanicalizations"],
    &["mechanicalisations"],
    &["mechanicalizations"],
    &["mechanicalisations"],
];

pub(crate) static ENTRY_MECHANICALIZATION_4786839792074015481: VariantsMap = [
    &["mechanicalization"],
    &["mechanicalisation"],
    &["mechanicalization"],
    &["mechanicalisation"],
];

pub(crate) static ENTRY_MECHANICALIZES_7598675745539959209: VariantsMap = [
    &["mechanicalizes"],
    &["mechanicalises"],
    &["mechanicalizes"],
    &["mechanicalises"],
];

pub(crate) static ENTRY_MECHANICALIZE_14122646639975689126: VariantsMap = [
    &["mechanicalize"],
    &["mechanicalise"],
    &["mechanicalize"],
    &["mechanicalise"],
];

pub(crate) static ENTRY_MECHANIZABLE_5249425868989509109: VariantsMap = [
    &["mechanizable"],
    &["mechanisable"],
    &["mechanizable"],
    &["mechanisable"],
];

pub(crate) static ENTRY_MECHANIZATIONS_14663166362277345847: VariantsMap = [
    &["mechanizations"],
    &["mechanisations"],
    &["mechanizations"],
    &["mechanisations"],
];

pub(crate) static ENTRY_MECHANIZATION_1053035171790140063: VariantsMap = [
    &["mechanization"],
    &["mechanisation"],
    &["mechanization"],
    &["mechanisation"],
];

pub(crate) static ENTRY_MECHANIZED_9673871810101964259: VariantsMap = [
    &["mechanized"],
    &["mechanised"],
    &["mechanized"],
    &["mechanised"],
];

pub(crate) static ENTRY_MECHANIZERS_14840837706803972436: VariantsMap = [
    &["mechanizers"],
    &["mechanisers"],
    &["mechanizers"],
    &["mechanisers"],
];

pub(crate) static ENTRY_MECHANIZER_3254719858646223585: VariantsMap = [
    &["mechanizer"],
    &["mechaniser"],
    &["mechanizer"],
    &["mechaniser"],
];

pub(crate) static ENTRY_MECHANIZES_7811802180133123379: VariantsMap = [
    &["mechanizes"],
    &["mechanises"],
    &["mechanizes"],
    &["mechanises"],
];

pub(crate) static ENTRY_MECHANIZE_16535652198395559730: VariantsMap = [
    &["mechanize"],
    &["mechanise"],
    &["mechanize"],
    &["mechanise"],
];

pub(crate) static ENTRY_MECHANIZING_15860356773348186437: VariantsMap = [
    &["mechanizing"],
    &["mechanising"],
    &["mechanizing"],
    &["mechanising"],
];

pub(crate) static ENTRY_MECK_5007702210116580279: VariantsMap =
    [&["meck"], &["moeck"], &["moeck"], &["moeck"]];

pub(crate) static ENTRY_MEDALED_11601917023410661347: VariantsMap =
    [&["medaled"], &["medalled"], &["medalled"], &["medalled"]];

pub(crate) static ENTRY_MEDALING_14602019896865311927: VariantsMap = [
    &["medaling"],
    &["medalling"],
    &["medalling"],
    &["medalling"],
];

pub(crate) static ENTRY_MEDALISTS_7569600200481823699: VariantsMap = [
    &["medalists"],
    &["medallists"],
    &["medallists"],
    &["medallists"],
];

pub(crate) static ENTRY_MEDALIST_17015107528020299327: VariantsMap = [
    &["medalist"],
    &["medallist"],
    &["medallist"],
    &["medallist"],
];

pub(crate) static ENTRY_MEDALIZES_1584149944297837431: VariantsMap = [
    &["medalizes"],
    &["medalises"],
    &["medalizes"],
    &["medalises"],
];

pub(crate) static ENTRY_MEDALIZE_17540992999380469913: VariantsMap =
    [&["medalize"], &["medalise"], &["medalize"], &["medalise"]];

pub(crate) static ENTRY_MEDIALIZATIONS_7712797253841570193: VariantsMap = [
    &["medializations"],
    &["medialisations"],
    &["medializations"],
    &["medialisations"],
];

pub(crate) static ENTRY_MEDIALIZATION_2773287312950879275: VariantsMap = [
    &["medialization"],
    &["medialisation"],
    &["medialization"],
    &["medialisation"],
];

pub(crate) static ENTRY_MEDIALIZES_11093411886143030573: VariantsMap = [
    &["medializes"],
    &["medialises"],
    &["medializes"],
    &["medialises"],
];

pub(crate) static ENTRY_MEDIALIZE_4174223040152180933: VariantsMap = [
    &["medialize"],
    &["medialise"],
    &["medialize"],
    &["medialise"],
];

pub(crate) static ENTRY_MEDIATIZATIONS_4548539761425641022: VariantsMap = [
    &["mediatizations"],
    &["mediatisations"],
    &["mediatizations"],
    &["mediatisations"],
];

pub(crate) static ENTRY_MEDIATIZATION_16965747020256741506: VariantsMap = [
    &["mediatization"],
    &["mediatisation"],
    &["mediatization"],
    &["mediatisation"],
];

pub(crate) static ENTRY_MEDIATIZED_2185354847870653573: VariantsMap = [
    &["mediatized"],
    &["mediatised"],
    &["mediatized"],
    &["mediatised"],
];

pub(crate) static ENTRY_MEDIATIZES_5491715552293568451: VariantsMap = [
    &["mediatizes"],
    &["mediatises"],
    &["mediatizes"],
    &["mediatises"],
];

pub(crate) static ENTRY_MEDIATIZE_1073675855124105129: VariantsMap = [
    &["mediatize"],
    &["mediatise"],
    &["mediatize"],
    &["mediatise"],
];

pub(crate) static ENTRY_MEDIATIZING_15145498889980832015: VariantsMap = [
    &["mediatizing"],
    &["mediatising"],
    &["mediatizing"],
    &["mediatising"],
];

pub(crate) static ENTRY_MEDICALIZATIONS_11138757215969860042: VariantsMap = [
    &["medicalizations"],
    &["medicalisations"],
    &["medicalizations"],
    &["medicalisations"],
];

pub(crate) static ENTRY_MEDICALIZATION_13901867202075475919: VariantsMap = [
    &["medicalization"],
    &["medicalisation"],
    &["medicalization"],
    &["medicalisation"],
];

pub(crate) static ENTRY_MEDICALIZED_14637350429218388791: VariantsMap = [
    &["medicalized"],
    &["medicalised"],
    &["medicalized"],
    &["medicalised"],
];

pub(crate) static ENTRY_MEDICALIZES_11382808734283425833: VariantsMap = [
    &["medicalizes"],
    &["medicalises"],
    &["medicalizes"],
    &["medicalises"],
];

pub(crate) static ENTRY_MEDICALIZE_12140561579340280896: VariantsMap = [
    &["medicalize"],
    &["medicalise"],
    &["medicalize"],
    &["medicalise"],
];

pub(crate) static ENTRY_MEDICALIZING_16755237480538911687: VariantsMap = [
    &["medicalizing"],
    &["medicalising"],
    &["medicalizing"],
    &["medicalising"],
];

pub(crate) static ENTRY_MEDIEVALISMS_3877776466393255830: VariantsMap = [
    &["medievalisms"],
    &["mediaevalisms"],
    &["mediaevalisms"],
    &["mediaevalisms"],
];

pub(crate) static ENTRY_MEDIEVALISM_12350363398481242202: VariantsMap = [
    &["medievalism"],
    &["mediaevalism"],
    &["mediaevalism"],
    &["mediaevalism"],
];

pub(crate) static ENTRY_MEDIEVALLY_7126203456978659821: VariantsMap = [
    &["medievally"],
    &["mediaevally"],
    &["mediaevally"],
    &["mediaevally"],
];

pub(crate) static ENTRY_MEDIEVALS_565656105957485309: VariantsMap = [
    &["medievals"],
    &["medievals"],
    &["medievals"],
    &["medievals"],
];

pub(crate) static ENTRY_MEDIEVAL_17850117342556318282: VariantsMap =
    [&["medieval"], &["medieval"], &["medieval"], &["medieval"]];

pub(crate) static ENTRY_MEDITERRANEANIZATIONS_4152813757418022161: VariantsMap = [
    &["mediterraneanizations"],
    &["mediterraneanisations"],
    &["mediterraneanizations"],
    &["mediterraneanisations"],
];

pub(crate) static ENTRY_MEDITERRANEANIZATION_14409869142875503448: VariantsMap = [
    &["mediterraneanization"],
    &["mediterraneanisation"],
    &["mediterraneanization"],
    &["mediterraneanisation"],
];

pub(crate) static ENTRY_MEDITERRANEANIZES_14935273528506989785: VariantsMap = [
    &["mediterraneanizes"],
    &["mediterraneanises"],
    &["mediterraneanizes"],
    &["mediterraneanises"],
];

pub(crate) static ENTRY_MEDITERRANEANIZE_8505087008798927202: VariantsMap = [
    &["mediterraneanize"],
    &["mediterraneanise"],
    &["mediterraneanize"],
    &["mediterraneanise"],
];

pub(crate) static ENTRY_MEDIUMIZATIONS_8199131889328831153: VariantsMap = [
    &["mediumizations"],
    &["mediumisations"],
    &["mediumizations"],
    &["mediumisations"],
];

pub(crate) static ENTRY_MEDIUMIZATION_13312123412145110516: VariantsMap = [
    &["mediumization"],
    &["mediumisation"],
    &["mediumization"],
    &["mediumisation"],
];

pub(crate) static ENTRY_MEDIUMIZES_481548870452861109: VariantsMap = [
    &["mediumizes"],
    &["mediumises"],
    &["mediumizes"],
    &["mediumises"],
];

pub(crate) static ENTRY_MEDIUMIZE_2080345639943490884: VariantsMap = [
    &["mediumize"],
    &["mediumise"],
    &["mediumize"],
    &["mediumise"],
];

pub(crate) static ENTRY_MED_5005187106832009132: VariantsMap =
    [&["med"], &["moed"], &["moed"], &["moed"]];

pub(crate) static ENTRY_MEGAGRAMS_16983511226700950884: VariantsMap = [
    &["megagrams"],
    &["megagrams"],
    &["megagrams"],
    &["megagrams"],
];

pub(crate) static ENTRY_MEGAGRAM_8029617688198245061: VariantsMap =
    [&["megagram"], &["megagram"], &["megagram"], &["megagram"]];

pub(crate) static ENTRY_MEGAMETERS_11568490769246802016: VariantsMap = [
    &["megameters"],
    &["megametres"],
    &["megametres"],
    &["megametres"],
];

pub(crate) static ENTRY_MEGAMETER_13646180126000061986: VariantsMap = [
    &["megameter"],
    &["megametre"],
    &["megametre"],
    &["megametre"],
];

pub(crate) static ENTRY_MEGBOTE_8260748554334190230: VariantsMap =
    [&["megbote"], &["maegbote"], &["maegbote"], &["maegbote"]];

pub(crate) static ENTRY_MEGERG_12697116810965677133: VariantsMap =
    [&["megerg"], &["megaerg"], &["megaerg"], &["megaerg"]];

pub(crate) static ENTRY_MELANEMIA_9412572547728781693: VariantsMap = [
    &["melanemia"],
    &["melanaemia"],
    &["melanaemia"],
    &["melanaemia"],
];

pub(crate) static ENTRY_MELANEMIC_12814356237780442555: VariantsMap = [
    &["melanemic"],
    &["melanaemic"],
    &["melanaemic"],
    &["melanaemic"],
];

pub(crate) static ENTRY_MELANIZATION_8548851357095187898: VariantsMap = [
    &["melanization"],
    &["melanisation"],
    &["melanization"],
    &["melanisation"],
];

pub(crate) static ENTRY_MELANIZED_9428739129770441806: VariantsMap = [
    &["melanized"],
    &["melanised"],
    &["melanized"],
    &["melanised"],
];

pub(crate) static ENTRY_MELANIZES_4133910184183953718: VariantsMap = [
    &["melanizes"],
    &["melanises"],
    &["melanizes"],
    &["melanises"],
];

pub(crate) static ENTRY_MELANIZE_4514273414820038876: VariantsMap =
    [&["melanize"], &["melanise"], &["melanize"], &["melanise"]];

pub(crate) static ENTRY_MELANIZING_16999099722254777130: VariantsMap = [
    &["melanizing"],
    &["melanising"],
    &["melanizing"],
    &["melanising"],
];

pub(crate) static ENTRY_MELENA_1319080246283801884: VariantsMap =
    [&["melena"], &["melaena"], &["melaena"], &["melaena"]];

pub(crate) static ENTRY_MELENIC_3928666269532265702: VariantsMap =
    [&["melenic"], &["melaenic"], &["melaenic"], &["melaenic"]];

pub(crate) static ENTRY_MELE_3468995732305175976: VariantsMap =
    [&["mele"], &["meloe"], &["meloe"], &["meloe"]];

pub(crate) static ENTRY_MELIE_10983361518408075735: VariantsMap =
    [&["melie"], &["meliae"], &["meliae"], &["meliae"]];

pub(crate) static ENTRY_MELINE_4877430347055832480: VariantsMap =
    [&["meline"], &["melinae"], &["melinae"], &["melinae"]];

pub(crate) static ENTRY_MELITEMIA_13453885714439194713: VariantsMap = [
    &["melitemia"],
    &["melitaemia"],
    &["melitaemia"],
    &["melitaemia"],
];

pub(crate) static ENTRY_MELITHEMIA_18261531354421030308: VariantsMap = [
    &["melithemia"],
    &["melithaemia"],
    &["melithaemia"],
    &["melithaemia"],
];

pub(crate) static ENTRY_MELLON_660640033212487292: VariantsMap =
    [&["mellon"], &["moellon"], &["moellon"], &["moellon"]];

pub(crate) static ENTRY_MELODIZATION_9293798775884390672: VariantsMap = [
    &["melodization"],
    &["melodisation"],
    &["melodization"],
    &["melodisation"],
];

pub(crate) static ENTRY_MELODIZED_3082275023028261392: VariantsMap = [
    &["melodized"],
    &["melodised"],
    &["melodized"],
    &["melodised"],
];

pub(crate) static ENTRY_MELODIZER_4236053590845193093: VariantsMap = [
    &["melodizer"],
    &["melodiser"],
    &["melodizer"],
    &["melodiser"],
];

pub(crate) static ENTRY_MELODIZES_2517544335598130476: VariantsMap = [
    &["melodizes"],
    &["melodises"],
    &["melodizes"],
    &["melodises"],
];

pub(crate) static ENTRY_MELODIZE_7912016393930350549: VariantsMap =
    [&["melodize"], &["melodise"], &["melodize"], &["melodise"]];

pub(crate) static ENTRY_MELODIZING_6937142596752062613: VariantsMap = [
    &["melodizing"],
    &["melodising"],
    &["melodizing"],
    &["melodising"],
];

pub(crate) static ENTRY_MELODRAMATIZATION_15214542859978971170: VariantsMap = [
    &["melodramatization"],
    &["melodramatisation"],
    &["melodramatization"],
    &["melodramatisation"],
];

pub(crate) static ENTRY_MELODRAMATIZED_8147783138457416369: VariantsMap = [
    &["melodramatized"],
    &["melodramatised"],
    &["melodramatized"],
    &["melodramatised"],
];

pub(crate) static ENTRY_MELODRAMATIZES_13654098972815682124: VariantsMap = [
    &["melodramatizes"],
    &["melodramatises"],
    &["melodramatizes"],
    &["melodramatises"],
];

pub(crate) static ENTRY_MELODRAMATIZE_8158763736750286482: VariantsMap = [
    &["melodramatize"],
    &["melodramatise"],
    &["melodramatize"],
    &["melodramatise"],
];

pub(crate) static ENTRY_MELODRAMATIZING_8357301537520359496: VariantsMap = [
    &["melodramatizing"],
    &["melodramatising"],
    &["melodramatizing"],
    &["melodramatising"],
];

pub(crate) static ENTRY_MEMORIALIZATIONS_12221954007792895141: VariantsMap = [
    &["memorializations"],
    &["memorialisations"],
    &["memorializations"],
    &["memorialisations"],
];

pub(crate) static ENTRY_MEMORIALIZATION_17445729035231672357: VariantsMap = [
    &["memorialization"],
    &["memorialisation"],
    &["memorialization"],
    &["memorialisation"],
];

pub(crate) static ENTRY_MEMORIALIZED_12387502526621019454: VariantsMap = [
    &["memorialized"],
    &["memorialised"],
    &["memorialized"],
    &["memorialised"],
];

pub(crate) static ENTRY_MEMORIALIZERS_13528156587756561766: VariantsMap = [
    &["memorializers"],
    &["memorialisers"],
    &["memorializers"],
    &["memorialisers"],
];

pub(crate) static ENTRY_MEMORIALIZER_17702355369469865313: VariantsMap = [
    &["memorializer"],
    &["memorialiser"],
    &["memorializer"],
    &["memorialiser"],
];

pub(crate) static ENTRY_MEMORIALIZES_6025600930549122809: VariantsMap = [
    &["memorializes"],
    &["memorialises"],
    &["memorializes"],
    &["memorialises"],
];

pub(crate) static ENTRY_MEMORIALIZE_1075532353319465636: VariantsMap = [
    &["memorialize"],
    &["memorialise"],
    &["memorialize"],
    &["memorialise"],
];

pub(crate) static ENTRY_MEMORIALIZING_6464676930179799173: VariantsMap = [
    &["memorializing"],
    &["memorialising"],
    &["memorializing"],
    &["memorialising"],
];

pub(crate) static ENTRY_MEMORIZABLES_1763920220382427272: VariantsMap = [
    &["memorizables"],
    &["memorisables"],
    &["memorizables"],
    &["memorisables"],
];

pub(crate) static ENTRY_MEMORIZABLE_1586066428099139828: VariantsMap = [
    &["memorizable"],
    &["memorisable"],
    &["memorizable"],
    &["memorisable"],
];

pub(crate) static ENTRY_MEMORIZATIONS_9230505688495133407: VariantsMap = [
    &["memorizations"],
    &["memorisations"],
    &["memorizations"],
    &["memorisations"],
];

pub(crate) static ENTRY_MEMORIZATION_9905762212081933855: VariantsMap = [
    &["memorization"],
    &["memorisation"],
    &["memorization"],
    &["memorisation"],
];

pub(crate) static ENTRY_MEMORIZED_6819787376078494141: VariantsMap = [
    &["memorized"],
    &["memorised"],
    &["memorized"],
    &["memorised"],
];

pub(crate) static ENTRY_MEMORIZERS_1062747053394007451: VariantsMap = [
    &["memorizers"],
    &["memorisers"],
    &["memorizers"],
    &["memorisers"],
];

pub(crate) static ENTRY_MEMORIZER_17044084127009102585: VariantsMap = [
    &["memorizer"],
    &["memoriser"],
    &["memorizer"],
    &["memoriser"],
];

pub(crate) static ENTRY_MEMORIZES_5171178815680156610: VariantsMap = [
    &["memorizes"],
    &["memorises"],
    &["memorizes"],
    &["memorises"],
];

pub(crate) static ENTRY_MEMORIZE_12947638813038433309: VariantsMap =
    [&["memorize"], &["memorise"], &["memorize"], &["memorise"]];

pub(crate) static ENTRY_MEMORIZING_3818508847656258506: VariantsMap = [
    &["memorizing"],
    &["memorising"],
    &["memorizing"],
    &["memorising"],
];

pub(crate) static ENTRY_MENDELIZES_3714572217602732083: VariantsMap = [
    &["mendelizes"],
    &["mendelises"],
    &["mendelizes"],
    &["mendelises"],
];

pub(crate) static ENTRY_MENDELIZE_725660384615195139: VariantsMap = [
    &["mendelize"],
    &["mendelise"],
    &["mendelize"],
    &["mendelise"],
];

pub(crate) static ENTRY_MENINGORRHEA_3280169182584942067: VariantsMap = [
    &["meningorrhea"],
    &["meningorrhoea"],
    &["meningorrhoea"],
    &["meningorrhoea"],
];

pub(crate) static ENTRY_MENORRHEAS_4376102286533960802: VariantsMap = [
    &["menorrheas"],
    &["menorrhoeas"],
    &["menorrhoeas"],
    &["menorrhoeas"],
];

pub(crate) static ENTRY_MENORRHEA_15147728501411744284: VariantsMap = [
    &["menorrhea"],
    &["menorrhoea"],
    &["menorrhoea"],
    &["menorrhoea"],
];

pub(crate) static ENTRY_MENORRHEIC_11950299570730209529: VariantsMap = [
    &["menorrheic"],
    &["menorrhoeic"],
    &["menorrhoeic"],
    &["menorrhoeic"],
];

pub(crate) static ENTRY_MENSE_4361400896559675654: VariantsMap =
    [&["mense"], &["mensae"], &["mensae"], &["mensae"]];

pub(crate) static ENTRY_MENTALIZATIONS_9393104229127640857: VariantsMap = [
    &["mentalizations"],
    &["mentalisations"],
    &["mentalizations"],
    &["mentalisations"],
];

pub(crate) static ENTRY_MENTALIZATION_5298081617361900300: VariantsMap = [
    &["mentalization"],
    &["mentalisation"],
    &["mentalization"],
    &["mentalisation"],
];

pub(crate) static ENTRY_MENTALIZES_7900711112885808496: VariantsMap = [
    &["mentalizes"],
    &["mentalises"],
    &["mentalizes"],
    &["mentalises"],
];

pub(crate) static ENTRY_MENTALIZE_9941072476539187082: VariantsMap = [
    &["mentalize"],
    &["mentalise"],
    &["mentalize"],
    &["mentalise"],
];

pub(crate) static ENTRY_MEOWED_12917082202071017756: VariantsMap =
    [&["meowed"], &["miaowed"], &["meowed"], &["miaowed"]];

pub(crate) static ENTRY_MEOWING_14461347911601242891: VariantsMap =
    [&["meowing"], &["miaowing"], &["meowing"], &["miaowing"]];

pub(crate) static ENTRY_MEOWS_2381455287142978475: VariantsMap =
    [&["meows"], &["miaows"], &["meows"], &["miaows"]];

pub(crate) static ENTRY_MEOW_9410098915523682519: VariantsMap =
    [&["meow"], &["miaow"], &["meow"], &["miaow"]];

pub(crate) static ENTRY_MEPHITINE_2592245251947249411: VariantsMap = [
    &["mephitine"],
    &["mephitinae"],
    &["mephitinae"],
    &["mephitinae"],
];

pub(crate) static ENTRY_MERA_10740593344023131930: VariantsMap =
    [&["mera"], &["maera"], &["maera"], &["maera"]];

pub(crate) static ENTRY_MERCERIZATIONS_1373548936308982813: VariantsMap = [
    &["mercerizations"],
    &["mercerisations"],
    &["mercerizations"],
    &["mercerisations"],
];

pub(crate) static ENTRY_MERCERIZATION_7225985380401307657: VariantsMap = [
    &["mercerization"],
    &["mercerisation"],
    &["mercerization"],
    &["mercerisation"],
];

pub(crate) static ENTRY_MERCERIZED_6026301924133596159: VariantsMap = [
    &["mercerized"],
    &["mercerised"],
    &["mercerized"],
    &["mercerised"],
];

pub(crate) static ENTRY_MERCERIZERS_4667586509379652583: VariantsMap = [
    &["mercerizers"],
    &["mercerisers"],
    &["mercerizers"],
    &["mercerisers"],
];

pub(crate) static ENTRY_MERCERIZER_17418192070910227605: VariantsMap = [
    &["mercerizer"],
    &["merceriser"],
    &["mercerizer"],
    &["merceriser"],
];

pub(crate) static ENTRY_MERCERIZES_14867805097673002748: VariantsMap = [
    &["mercerizes"],
    &["mercerises"],
    &["mercerizes"],
    &["mercerises"],
];

pub(crate) static ENTRY_MERCERIZE_10358461438508840539: VariantsMap = [
    &["mercerize"],
    &["mercerise"],
    &["mercerize"],
    &["mercerise"],
];

pub(crate) static ENTRY_MERCERIZING_15719429984314868087: VariantsMap = [
    &["mercerizing"],
    &["mercerising"],
    &["mercerizing"],
    &["mercerising"],
];

pub(crate) static ENTRY_MERCURIALIZATIONS_2925060499316503633: VariantsMap = [
    &["mercurializations"],
    &["mercurialisations"],
    &["mercurializations"],
    &["mercurialisations"],
];

pub(crate) static ENTRY_MERCURIALIZATION_3019477287363156501: VariantsMap = [
    &["mercurialization"],
    &["mercurialisation"],
    &["mercurialization"],
    &["mercurialisation"],
];

pub(crate) static ENTRY_MERCURIALIZED_17489760872731595206: VariantsMap = [
    &["mercurialized"],
    &["mercurialised"],
    &["mercurialized"],
    &["mercurialised"],
];

pub(crate) static ENTRY_MERCURIALIZES_16718020801665912512: VariantsMap = [
    &["mercurializes"],
    &["mercurialises"],
    &["mercurializes"],
    &["mercurialises"],
];

pub(crate) static ENTRY_MERCURIALIZE_5840604397082793337: VariantsMap = [
    &["mercurialize"],
    &["mercurialise"],
    &["mercurialize"],
    &["mercurialise"],
];

pub(crate) static ENTRY_MERCURIALIZING_16302250787832211940: VariantsMap = [
    &["mercurializing"],
    &["mercurialising"],
    &["mercurializing"],
    &["mercurialising"],
];

pub(crate) static ENTRY_MERCURIZED_5448748826649481653: VariantsMap = [
    &["mercurized"],
    &["mercurised"],
    &["mercurized"],
    &["mercurised"],
];

pub(crate) static ENTRY_MERCURIZES_7473635049011508463: VariantsMap = [
    &["mercurizes"],
    &["mercurises"],
    &["mercurizes"],
    &["mercurises"],
];

pub(crate) static ENTRY_MERCURIZE_8240767278076320017: VariantsMap = [
    &["mercurize"],
    &["mercurise"],
    &["mercurize"],
    &["mercurise"],
];

pub(crate) static ENTRY_MERCURIZING_11754600008945629993: VariantsMap = [
    &["mercurizing"],
    &["mercurising"],
    &["mercurizing"],
    &["mercurising"],
];

pub(crate) static ENTRY_MEROE_3985235841752863979: VariantsMap =
    [&["meroe"], &["meroae"], &["meroae"], &["meroae"]];

pub(crate) static ENTRY_MESMERIZABILITIES_12304847665223063691: VariantsMap = [
    &["mesmerizabilities"],
    &["mesmerisabilities"],
    &["mesmerizabilities"],
    &["mesmerisabilities"],
];

pub(crate) static ENTRY_MESMERIZABILITY_3536639779424392826: VariantsMap = [
    &["mesmerizability"],
    &["mesmerisability"],
    &["mesmerizability"],
    &["mesmerisability"],
];

pub(crate) static ENTRY_MESMERIZABLES_2422389219890530110: VariantsMap = [
    &["mesmerizables"],
    &["mesmerisables"],
    &["mesmerizables"],
    &["mesmerisables"],
];

pub(crate) static ENTRY_MESMERIZABLE_15950937949831696970: VariantsMap = [
    &["mesmerizable"],
    &["mesmerisable"],
    &["mesmerizable"],
    &["mesmerisable"],
];

pub(crate) static ENTRY_MESMERIZATIONS_11950161412465266055: VariantsMap = [
    &["mesmerizations"],
    &["mesmerisations"],
    &["mesmerizations"],
    &["mesmerisations"],
];

pub(crate) static ENTRY_MESMERIZATION_14956156599191298646: VariantsMap = [
    &["mesmerization"],
    &["mesmerisation"],
    &["mesmerization"],
    &["mesmerisation"],
];

pub(crate) static ENTRY_MESMERIZED_16433180714453641642: VariantsMap = [
    &["mesmerized"],
    &["mesmerised"],
    &["mesmerized"],
    &["mesmerised"],
];

pub(crate) static ENTRY_MESMERIZERS_17679840299174687341: VariantsMap = [
    &["mesmerizers"],
    &["mesmerisers"],
    &["mesmerizers"],
    &["mesmerisers"],
];

pub(crate) static ENTRY_MESMERIZER_14781508848355925919: VariantsMap = [
    &["mesmerizer"],
    &["mesmeriser"],
    &["mesmerizer"],
    &["mesmeriser"],
];

pub(crate) static ENTRY_MESMERIZES_16069764006210185557: VariantsMap = [
    &["mesmerizes"],
    &["mesmerises"],
    &["mesmerizes"],
    &["mesmerises"],
];

pub(crate) static ENTRY_MESMERIZE_5317367348452378793: VariantsMap = [
    &["mesmerize"],
    &["mesmerise"],
    &["mesmerize"],
    &["mesmerise"],
];

pub(crate) static ENTRY_MESMERIZING_10029307437868883072: VariantsMap = [
    &["mesmerizing"],
    &["mesmerising"],
    &["mesmerizing"],
    &["mesmerising"],
];

pub(crate) static ENTRY_MESOGLEAL_1417922158905887904: VariantsMap = [
    &["mesogleal"],
    &["mesogloeal"],
    &["mesogloeal"],
    &["mesogloeal"],
];

pub(crate) static ENTRY_MESOGLEAS_3496831994756905336: VariantsMap = [
    &["mesogleas"],
    &["mesogloeas"],
    &["mesogloeas"],
    &["mesogloeas"],
];

pub(crate) static ENTRY_MESOGLEA_18401623678263429076: VariantsMap = [
    &["mesoglea"],
    &["mesogloea"],
    &["mesogloea"],
    &["mesogloea"],
];

pub(crate) static ENTRY_MESPRIZES_7758910180714977300: VariantsMap = [
    &["mesprizes"],
    &["mesprises"],
    &["mesprizes"],
    &["mesprises"],
];

pub(crate) static ENTRY_MESPRIZE_10098306562322193815: VariantsMap =
    [&["mesprize"], &["mesprise"], &["mesprize"], &["mesprise"]];

pub(crate) static ENTRY_METABOLIZABLES_16212828364863118123: VariantsMap = [
    &["metabolizables"],
    &["metabolisables"],
    &["metabolizables"],
    &["metabolisables"],
];

pub(crate) static ENTRY_METABOLIZABLE_9512483414343288081: VariantsMap = [
    &["metabolizable"],
    &["metabolisable"],
    &["metabolizable"],
    &["metabolisable"],
];

pub(crate) static ENTRY_METABOLIZED_894424192524670370: VariantsMap = [
    &["metabolized"],
    &["metabolised"],
    &["metabolized"],
    &["metabolised"],
];

pub(crate) static ENTRY_METABOLIZES_2735479621970518981: VariantsMap = [
    &["metabolizes"],
    &["metabolises"],
    &["metabolizes"],
    &["metabolises"],
];

pub(crate) static ENTRY_METABOLIZE_5263729176482445241: VariantsMap = [
    &["metabolize"],
    &["metabolise"],
    &["metabolize"],
    &["metabolise"],
];

pub(crate) static ENTRY_METABOLIZING_8339637372408897948: VariantsMap = [
    &["metabolizing"],
    &["metabolising"],
    &["metabolizing"],
    &["metabolising"],
];

pub(crate) static ENTRY_METACENTERS_5577639685165206381: VariantsMap = [
    &["metacenters"],
    &["metacentres"],
    &["metacentres"],
    &["metacentres"],
];

pub(crate) static ENTRY_METACENTER_16724078749924963707: VariantsMap = [
    &["metacenter"],
    &["metacentre"],
    &["metacentre"],
    &["metacentre"],
];

pub(crate) static ENTRY_METAGRABOLIZED_3069196729213555991: VariantsMap = [
    &["metagrabolized"],
    &["metagrabolised"],
    &["metagrabolized"],
    &["metagrabolised"],
];

pub(crate) static ENTRY_METAGRABOLIZES_16179801690891399959: VariantsMap = [
    &["metagrabolizes"],
    &["metagrabolises"],
    &["metagrabolizes"],
    &["metagrabolises"],
];

pub(crate) static ENTRY_METAGRABOLIZE_15199335552706575875: VariantsMap = [
    &["metagrabolize"],
    &["metagrabolise"],
    &["metagrabolize"],
    &["metagrabolise"],
];

pub(crate) static ENTRY_METAGRABOLIZING_7649726571267122104: VariantsMap = [
    &["metagrabolizing"],
    &["metagrabolising"],
    &["metagrabolizing"],
    &["metagrabolising"],
];

pub(crate) static ENTRY_METAGROBOLIZED_14294598726067451953: VariantsMap = [
    &["metagrobolized"],
    &["metagrobolised"],
    &["metagrobolized"],
    &["metagrobolised"],
];

pub(crate) static ENTRY_METAGROBOLIZES_90893501209569579: VariantsMap = [
    &["metagrobolizes"],
    &["metagrobolises"],
    &["metagrobolizes"],
    &["metagrobolises"],
];

pub(crate) static ENTRY_METAGROBOLIZE_4973455702264683086: VariantsMap = [
    &["metagrobolize"],
    &["metagrobolise"],
    &["metagrobolize"],
    &["metagrobolise"],
];

pub(crate) static ENTRY_METAGROBOLIZING_4424158609091001763: VariantsMap = [
    &["metagrobolizing"],
    &["metagrobolising"],
    &["metagrobolizing"],
    &["metagrobolising"],
];

pub(crate) static ENTRY_METALED_9553049451671231773: VariantsMap =
    [&["metaled"], &["metalled"], &["metalled"], &["metalled"]];

pub(crate) static ENTRY_METALING_15686558716068715897: VariantsMap = [
    &["metaling"],
    &["metalling"],
    &["metalling"],
    &["metalling"],
];

pub(crate) static ENTRY_METALIZATIONS_6695845103746956826: VariantsMap = [
    &["metalizations"],
    &["metallisations"],
    &["metallizations"],
    &["metallisations"],
];

pub(crate) static ENTRY_METALIZATION_98135509290292258: VariantsMap = [
    &["metalization"],
    &["metallisation"],
    &["metallization"],
    &["metallisation"],
];

pub(crate) static ENTRY_METALIZED_15261403894302784256: VariantsMap = [
    &["metalized"],
    &["metallised"],
    &["metallized"],
    &["metallised"],
];

pub(crate) static ENTRY_METALIZES_10341894663346117437: VariantsMap = [
    &["metalizes"],
    &["metallises"],
    &["metallizes"],
    &["metallises"],
];

pub(crate) static ENTRY_METALIZE_16814796087793133597: VariantsMap = [
    &["metalize"],
    &["metallise"],
    &["metallize"],
    &["metallise"],
];

pub(crate) static ENTRY_METALIZING_496172402873116442: VariantsMap = [
    &["metalizing"],
    &["metallising"],
    &["metallizing"],
    &["metallising"],
];

pub(crate) static ENTRY_METAMERIZATIONS_4156955698615640017: VariantsMap = [
    &["metamerizations"],
    &["metamerisations"],
    &["metamerizations"],
    &["metamerisations"],
];

pub(crate) static ENTRY_METAMERIZATION_4255123050371136137: VariantsMap = [
    &["metamerization"],
    &["metamerisation"],
    &["metamerization"],
    &["metamerisation"],
];

pub(crate) static ENTRY_METAMERIZEDS_15543905702563975279: VariantsMap = [
    &["metamerizeds"],
    &["metameriseds"],
    &["metamerizeds"],
    &["metameriseds"],
];

pub(crate) static ENTRY_METAMERIZED_9574184110864577453: VariantsMap = [
    &["metamerized"],
    &["metamerised"],
    &["metamerized"],
    &["metamerised"],
];

pub(crate) static ENTRY_METAPHONIZES_12395714309695693792: VariantsMap = [
    &["metaphonizes"],
    &["metaphonises"],
    &["metaphonizes"],
    &["metaphonises"],
];

pub(crate) static ENTRY_METAPHONIZE_1203465835944745085: VariantsMap = [
    &["metaphonize"],
    &["metaphonise"],
    &["metaphonize"],
    &["metaphonise"],
];

pub(crate) static ENTRY_METAPHORIZES_10519287146723752029: VariantsMap = [
    &["metaphorizes"],
    &["metaphorises"],
    &["metaphorizes"],
    &["metaphorises"],
];

pub(crate) static ENTRY_METAPHORIZE_4096506888744429951: VariantsMap = [
    &["metaphorize"],
    &["metaphorise"],
    &["metaphorize"],
    &["metaphorise"],
];

pub(crate) static ENTRY_METAPHYSICIZES_10696292295026215412: VariantsMap = [
    &["metaphysicizes"],
    &["metaphysicises"],
    &["metaphysicizes"],
    &["metaphysicises"],
];

pub(crate) static ENTRY_METAPHYSICIZE_18217550823319187116: VariantsMap = [
    &["metaphysicize"],
    &["metaphysicise"],
    &["metaphysicize"],
    &["metaphysicise"],
];

pub(crate) static ENTRY_METASTASIZED_6407966435125605786: VariantsMap = [
    &["metastasized"],
    &["metastasised"],
    &["metastasized"],
    &["metastasised"],
];

pub(crate) static ENTRY_METASTASIZES_10123690877213783906: VariantsMap = [
    &["metastasizes"],
    &["metastasises"],
    &["metastasizes"],
    &["metastasises"],
];

pub(crate) static ENTRY_METASTASIZE_5162116501126745804: VariantsMap = [
    &["metastasize"],
    &["metastasise"],
    &["metastasize"],
    &["metastasise"],
];

pub(crate) static ENTRY_METASTASIZING_6012917817918288983: VariantsMap = [
    &["metastasizing"],
    &["metastasising"],
    &["metastasizing"],
    &["metastasising"],
];

pub(crate) static ENTRY_METATHESIZED_17698511522871311822: VariantsMap = [
    &["metathesized"],
    &["metathesised"],
    &["metathesized"],
    &["metathesised"],
];

pub(crate) static ENTRY_METATHESIZES_3250355132971623620: VariantsMap = [
    &["metathesizes"],
    &["metathesises"],
    &["metathesizes"],
    &["metathesises"],
];

pub(crate) static ENTRY_METATHESIZE_8317290549404760172: VariantsMap = [
    &["metathesize"],
    &["metathesise"],
    &["metathesize"],
    &["metathesise"],
];

pub(crate) static ENTRY_METATHESIZING_13420103038593666525: VariantsMap = [
    &["metathesizing"],
    &["metathesising"],
    &["metathesizing"],
    &["metathesising"],
];

pub(crate) static ENTRY_METEORIZATIONS_4257868931766191814: VariantsMap = [
    &["meteorizations"],
    &["meteorisations"],
    &["meteorizations"],
    &["meteorisations"],
];

pub(crate) static ENTRY_METEORIZATION_14509627179308580678: VariantsMap = [
    &["meteorization"],
    &["meteorisation"],
    &["meteorization"],
    &["meteorisation"],
];

pub(crate) static ENTRY_METEORIZES_1562060441883806775: VariantsMap = [
    &["meteorizes"],
    &["meteorises"],
    &["meteorizes"],
    &["meteorises"],
];

pub(crate) static ENTRY_METEORIZE_13283083497455170525: VariantsMap = [
    &["meteorize"],
    &["meteorise"],
    &["meteorize"],
    &["meteorise"],
];

pub(crate) static ENTRY_METERGRAM_2011699453456886332: VariantsMap = [
    &["metergram"],
    &["metregram"],
    &["metregram"],
    &["metregram"],
];

pub(crate) static ENTRY_METERLESS_12592948617315833276: VariantsMap = [
    &["meterless"],
    &["metreless"],
    &["metreless"],
    &["metreless"],
];

pub(crate) static ENTRY_METERSHIP_4620649639929107458: VariantsMap = [
    &["metership"],
    &["metreship"],
    &["metreship"],
    &["metreship"],
];

pub(crate) static ENTRY_METERS_1321374795298554236: VariantsMap =
    [&["meters"], &["metres"], &["metres"], &["metres"]];

pub(crate) static ENTRY_METER_3080570475644919217: VariantsMap =
    [&["meter"], &["metre"], &["metre"], &["metre"]];

pub(crate) static ENTRY_METESTRUS_14748773313097136439: VariantsMap = [
    &["metestrus"],
    &["metoestrus"],
    &["metoestrus"],
    &["metoestrus"],
];

pub(crate) static ENTRY_METHEMOGLOBIN_1539963096510356106: VariantsMap = [
    &["methemoglobin"],
    &["methaemoglobin"],
    &["methaemoglobin"],
    &["methaemoglobin"],
];

pub(crate) static ENTRY_METHODIZATIONS_13055113924321472470: VariantsMap = [
    &["methodizations"],
    &["methodisations"],
    &["methodizations"],
    &["methodisations"],
];

pub(crate) static ENTRY_METHODIZATION_4047996741902712542: VariantsMap = [
    &["methodization"],
    &["methodisation"],
    &["methodization"],
    &["methodisation"],
];

pub(crate) static ENTRY_METHODIZED_2923710854870457764: VariantsMap = [
    &["methodized"],
    &["methodised"],
    &["methodized"],
    &["methodised"],
];

pub(crate) static ENTRY_METHODIZERS_7660184830293053445: VariantsMap = [
    &["methodizers"],
    &["methodisers"],
    &["methodizers"],
    &["methodisers"],
];

pub(crate) static ENTRY_METHODIZER_6382879261326403628: VariantsMap = [
    &["methodizer"],
    &["methodiser"],
    &["methodizer"],
    &["methodiser"],
];

pub(crate) static ENTRY_METHODIZES_5329049990835330235: VariantsMap = [
    &["methodizes"],
    &["methodises"],
    &["methodizes"],
    &["methodises"],
];

pub(crate) static ENTRY_METHODIZE_14573740405190546697: VariantsMap = [
    &["methodize"],
    &["methodise"],
    &["methodize"],
    &["methodise"],
];

pub(crate) static ENTRY_METHODIZING_300246035838082411: VariantsMap = [
    &["methodizing"],
    &["methodising"],
    &["methodizing"],
    &["methodising"],
];

pub(crate) static ENTRY_METOPE_8108834617331696480: VariantsMap =
    [&["metope"], &["metopae"], &["metopae"], &["metopae"]];

pub(crate) static ENTRY_METRICIZED_13837683027917960528: VariantsMap = [
    &["metricized"],
    &["metricised"],
    &["metricized"],
    &["metricised"],
];

pub(crate) static ENTRY_METRICIZES_6116919209404015068: VariantsMap = [
    &["metricizes"],
    &["metricises"],
    &["metricizes"],
    &["metricises"],
];

pub(crate) static ENTRY_METRICIZE_12712778788179541034: VariantsMap = [
    &["metricize"],
    &["metricise"],
    &["metricize"],
    &["metricise"],
];

pub(crate) static ENTRY_METRICIZING_8349643762624940557: VariantsMap = [
    &["metricizing"],
    &["metricising"],
    &["metricizing"],
    &["metricising"],
];

pub(crate) static ENTRY_METRIZE_14087333133836452055: VariantsMap =
    [&["metrize"], &["metrise"], &["metrize"], &["metrise"]];

pub(crate) static ENTRY_METROPOLITANIZATION_14198198985964840255: VariantsMap = [
    &["metropolitanization"],
    &["metropolitanisation"],
    &["metropolitanization"],
    &["metropolitanisation"],
];

pub(crate) static ENTRY_METROPOLITANIZED_2023559975004354749: VariantsMap = [
    &["metropolitanized"],
    &["metropolitanised"],
    &["metropolitanized"],
    &["metropolitanised"],
];

pub(crate) static ENTRY_METROPOLITANIZES_14586245815433709014: VariantsMap = [
    &["metropolitanizes"],
    &["metropolitanises"],
    &["metropolitanizes"],
    &["metropolitanises"],
];

pub(crate) static ENTRY_METROPOLITANIZE_10953698211072784188: VariantsMap = [
    &["metropolitanize"],
    &["metropolitanise"],
    &["metropolitanize"],
    &["metropolitanise"],
];

pub(crate) static ENTRY_METROPOLITANIZING_4475094545669127656: VariantsMap = [
    &["metropolitanizing"],
    &["metropolitanising"],
    &["metropolitanizing"],
    &["metropolitanising"],
];

pub(crate) static ENTRY_MEXICANIZES_15197604106394100070: VariantsMap = [
    &["mexicanizes"],
    &["mexicanises"],
    &["mexicanizes"],
    &["mexicanises"],
];

pub(crate) static ENTRY_MEXICANIZE_8042596661826909778: VariantsMap = [
    &["mexicanize"],
    &["mexicanise"],
    &["mexicanize"],
    &["mexicanise"],
];

pub(crate) static ENTRY_MICELLE_7576714829270505941: VariantsMap =
    [&["micelle"], &["micellae"], &["micellae"], &["micellae"]];

pub(crate) static ENTRY_MICRESTHETE_9672005037653736575: VariantsMap = [
    &["micresthete"],
    &["micraesthete"],
    &["micraesthete"],
    &["micraesthete"],
];

pub(crate) static ENTRY_MICROCOLORIMETER_18004280412051238652: VariantsMap = [
    &["microcolorimeter"],
    &["microcolourimeter"],
    &["microcolourimeter"],
    &["microcolourimeter"],
];

pub(crate) static ENTRY_MICROCOLORIMETRICALLY_11611466844951844847: VariantsMap = [
    &["microcolorimetrically"],
    &["microcolourimetrically"],
    &["microcolourimetrically"],
    &["microcolourimetrically"],
];

pub(crate) static ENTRY_MICROCOLORIMETRIC_16673082101782053736: VariantsMap = [
    &["microcolorimetric"],
    &["microcolourimetric"],
    &["microcolourimetric"],
    &["microcolourimetric"],
];

pub(crate) static ENTRY_MICROCOLORIMETRY_14367716593404245072: VariantsMap = [
    &["microcolorimetry"],
    &["microcolourimetry"],
    &["microcolourimetry"],
    &["microcolourimetry"],
];

pub(crate) static ENTRY_MICROGRAMS_8250624480840600961: VariantsMap = [
    &["micrograms"],
    &["micrograms"],
    &["micrograms"],
    &["micrograms"],
];

pub(crate) static ENTRY_MICROGRAM_5550826611173391714: VariantsMap = [
    &["microgram"],
    &["microgram"],
    &["microgram"],
    &["microgram"],
];

pub(crate) static ENTRY_MICROLITERS_3234207303821669806: VariantsMap = [
    &["microliters"],
    &["microlitres"],
    &["microlitres"],
    &["microlitres"],
];

pub(crate) static ENTRY_MICROLITER_596723014881505352: VariantsMap = [
    &["microliter"],
    &["microlitre"],
    &["microlitre"],
    &["microlitre"],
];

pub(crate) static ENTRY_MICROMETERS_17594798746021449366: VariantsMap = [
    &["micrometers"],
    &["micrometres"],
    &["micrometres"],
    &["micrometres"],
];

pub(crate) static ENTRY_MICROMETER_12426531854552032888: VariantsMap = [
    &["micrometer"],
    &["micrometre"],
    &["micrometre"],
    &["micrometre"],
];

pub(crate) static ENTRY_MICROMILLIMETERS_4239096654730961785: VariantsMap = [
    &["micromillimeters"],
    &["micromillimetres"],
    &["micromillimetres"],
    &["micromillimetres"],
];

pub(crate) static ENTRY_MICROMILLIMETER_1760735628859617214: VariantsMap = [
    &["micromillimeter"],
    &["micromillimetre"],
    &["micromillimetre"],
    &["micromillimetre"],
];

pub(crate) static ENTRY_MICROMINIATURIZATIONS_5246749790513836150: VariantsMap = [
    &["microminiaturizations"],
    &["microminiaturisations"],
    &["microminiaturizations"],
    &["microminiaturisations"],
];

pub(crate) static ENTRY_MICROMINIATURIZATION_11811432514999527166: VariantsMap = [
    &["microminiaturization"],
    &["microminiaturisation"],
    &["microminiaturization"],
    &["microminiaturisation"],
];

pub(crate) static ENTRY_MICROMINIATURIZED_13202761646942630780: VariantsMap = [
    &["microminiaturized"],
    &["microminiaturised"],
    &["microminiaturized"],
    &["microminiaturised"],
];

pub(crate) static ENTRY_MICROMINIATURIZERS_18300728401437591217: VariantsMap = [
    &["microminiaturizers"],
    &["microminiaturisers"],
    &["microminiaturizers"],
    &["microminiaturisers"],
];

pub(crate) static ENTRY_MICROMINIATURIZER_13902094523123847309: VariantsMap = [
    &["microminiaturizer"],
    &["microminiaturiser"],
    &["microminiaturizer"],
    &["microminiaturiser"],
];

pub(crate) static ENTRY_MICROMINIATURIZES_322083564052894576: VariantsMap = [
    &["microminiaturizes"],
    &["microminiaturises"],
    &["microminiaturizes"],
    &["microminiaturises"],
];

pub(crate) static ENTRY_MICROMINIATURIZE_12416138093292278333: VariantsMap = [
    &["microminiaturize"],
    &["microminiaturise"],
    &["microminiaturize"],
    &["microminiaturise"],
];

pub(crate) static ENTRY_MICROMINIATURIZING_15922056758993789047: VariantsMap = [
    &["microminiaturizing"],
    &["microminiaturising"],
    &["microminiaturizing"],
    &["microminiaturising"],
];

pub(crate) static ENTRY_MICRONIZATIONS_2591998753795230500: VariantsMap = [
    &["micronizations"],
    &["micronisations"],
    &["micronizations"],
    &["micronisations"],
];

pub(crate) static ENTRY_MICRONIZATION_4363650953137409948: VariantsMap = [
    &["micronization"],
    &["micronisation"],
    &["micronization"],
    &["micronisation"],
];

pub(crate) static ENTRY_MICRONIZES_4658653937109421785: VariantsMap = [
    &["micronizes"],
    &["micronises"],
    &["micronizes"],
    &["micronises"],
];

pub(crate) static ENTRY_MICRONIZE_17111995987212311330: VariantsMap = [
    &["micronize"],
    &["micronise"],
    &["micronize"],
    &["micronise"],
];

pub(crate) static ENTRY_MICROPALEONTOLOGIES_16970317568428882967: VariantsMap = [
    &["micropaleontologies"],
    &["micropalaeontologies"],
    &["micropalaeontologies"],
    &["micropalaeontologies"],
];

pub(crate) static ENTRY_MICROPALEONTOLOGISTS_530232495682957827: VariantsMap = [
    &["micropaleontologists"],
    &["micropalaeontologists"],
    &["micropalaeontologists"],
    &["micropalaeontologists"],
];

pub(crate) static ENTRY_MICROPALEONTOLOGIST_7148258118564071422: VariantsMap = [
    &["micropaleontologist"],
    &["micropalaeontologist"],
    &["micropalaeontologist"],
    &["micropalaeontologist"],
];

pub(crate) static ENTRY_MICROPALEONTOLOGY_4636373730108244068: VariantsMap = [
    &["micropaleontology"],
    &["micropalaeontology"],
    &["micropalaeontology"],
    &["micropalaeontology"],
];

pub(crate) static ENTRY_MICROPOLARIZATIONS_9001859270075015688: VariantsMap = [
    &["micropolarizations"],
    &["micropolarisations"],
    &["micropolarizations"],
    &["micropolarisations"],
];

pub(crate) static ENTRY_MICROPOLARIZATION_8251585643477451806: VariantsMap = [
    &["micropolarization"],
    &["micropolarisation"],
    &["micropolarization"],
    &["micropolarisation"],
];

pub(crate) static ENTRY_MICROSCOPIZES_15874855682887385434: VariantsMap = [
    &["microscopizes"],
    &["microscopises"],
    &["microscopizes"],
    &["microscopises"],
];

pub(crate) static ENTRY_MICROSCOPIZE_360268649475089968: VariantsMap = [
    &["microscopize"],
    &["microscopise"],
    &["microscopize"],
    &["microscopise"],
];

pub(crate) static ENTRY_MICROSPHERIC_15627383990000838305: VariantsMap = [
    &["microspheric"],
    &["microsphaeric"],
    &["microsphaeric"],
    &["microsphaeric"],
];

pub(crate) static ENTRY_MIDLANDIZES_12489301275419999190: VariantsMap = [
    &["midlandizes"],
    &["midlandises"],
    &["midlandizes"],
    &["midlandises"],
];

pub(crate) static ENTRY_MIDLANDIZE_6630693690356339718: VariantsMap = [
    &["midlandize"],
    &["midlandise"],
    &["midlandize"],
    &["midlandise"],
];

pub(crate) static ENTRY_MIGNIARDIZE_4149614480326600754: VariantsMap = [
    &["migniardize"],
    &["migniardise"],
    &["migniardize"],
    &["migniardise"],
];

pub(crate) static ENTRY_MILITARIZATIONS_7705734301801515430: VariantsMap = [
    &["militarizations"],
    &["militarisations"],
    &["militarizations"],
    &["militarisations"],
];

pub(crate) static ENTRY_MILITARIZATION_8896321595375246390: VariantsMap = [
    &["militarization"],
    &["militarisation"],
    &["militarization"],
    &["militarisation"],
];

pub(crate) static ENTRY_MILITARIZED_16232436267971009706: VariantsMap = [
    &["militarized"],
    &["militarised"],
    &["militarized"],
    &["militarised"],
];

pub(crate) static ENTRY_MILITARIZES_14452269897116904753: VariantsMap = [
    &["militarizes"],
    &["militarises"],
    &["militarizes"],
    &["militarises"],
];

pub(crate) static ENTRY_MILITARIZE_9495798303128415382: VariantsMap = [
    &["militarize"],
    &["militarise"],
    &["militarize"],
    &["militarise"],
];

pub(crate) static ENTRY_MILITARIZING_554769254101207928: VariantsMap = [
    &["militarizing"],
    &["militarising"],
    &["militarizing"],
    &["militarising"],
];

pub(crate) static ENTRY_MILLIGRAMS_1518179305136992377: VariantsMap = [
    &["milligrams"],
    &["milligrams"],
    &["milligrams"],
    &["milligrams"],
];

pub(crate) static ENTRY_MILLIGRAM_13513186363380334269: VariantsMap = [
    &["milligram"],
    &["milligram"],
    &["milligram"],
    &["milligram"],
];

pub(crate) static ENTRY_MILLILITERS_11102962851052563190: VariantsMap = [
    &["milliliters"],
    &["millilitres"],
    &["millilitres"],
    &["millilitres"],
];

pub(crate) static ENTRY_MILLILITER_4334261634926370944: VariantsMap = [
    &["milliliter"],
    &["millilitre"],
    &["millilitre"],
    &["millilitre"],
];

pub(crate) static ENTRY_MILLIMETERS_15997711111545097679: VariantsMap = [
    &["millimeters"],
    &["millimetres"],
    &["millimetres"],
    &["millimetres"],
];

pub(crate) static ENTRY_MILLIMETER_910141945772637554: VariantsMap = [
    &["millimeter"],
    &["millimetre"],
    &["millimetre"],
    &["millimetre"],
];

pub(crate) static ENTRY_MILLIONIZES_8106805268939119590: VariantsMap = [
    &["millionizes"],
    &["millionises"],
    &["millionizes"],
    &["millionises"],
];

pub(crate) static ENTRY_MILLIONIZE_8710296959776291321: VariantsMap = [
    &["millionize"],
    &["millionise"],
    &["millionize"],
    &["millionise"],
];

pub(crate) static ENTRY_MILTONIZED_17857068391321573364: VariantsMap = [
    &["miltonized"],
    &["miltonised"],
    &["miltonized"],
    &["miltonised"],
];

pub(crate) static ENTRY_MILTONIZES_4582802465496810532: VariantsMap = [
    &["miltonizes"],
    &["miltonises"],
    &["miltonizes"],
    &["miltonises"],
];

pub(crate) static ENTRY_MILTONIZE_5481427781071274567: VariantsMap = [
    &["miltonize"],
    &["miltonise"],
    &["miltonize"],
    &["miltonise"],
];

pub(crate) static ENTRY_MILTONIZING_13876342377178577317: VariantsMap = [
    &["miltonizing"],
    &["miltonising"],
    &["miltonizing"],
    &["miltonising"],
];

pub(crate) static ENTRY_MINERALIZABLES_5106780707407964970: VariantsMap = [
    &["mineralizables"],
    &["mineralisables"],
    &["mineralizables"],
    &["mineralisables"],
];

pub(crate) static ENTRY_MINERALIZABLE_8842518699676983946: VariantsMap = [
    &["mineralizable"],
    &["mineralisable"],
    &["mineralizable"],
    &["mineralisable"],
];

pub(crate) static ENTRY_MINERALIZATIONS_10546963403531567133: VariantsMap = [
    &["mineralizations"],
    &["mineralisations"],
    &["mineralizations"],
    &["mineralisations"],
];

pub(crate) static ENTRY_MINERALIZATION_6932253078663165468: VariantsMap = [
    &["mineralization"],
    &["mineralisation"],
    &["mineralization"],
    &["mineralisation"],
];

pub(crate) static ENTRY_MINERALIZED_4247107678262591457: VariantsMap = [
    &["mineralized"],
    &["mineralised"],
    &["mineralized"],
    &["mineralised"],
];

pub(crate) static ENTRY_MINERALIZERS_6700043765339885165: VariantsMap = [
    &["mineralizers"],
    &["mineralisers"],
    &["mineralizers"],
    &["mineralisers"],
];

pub(crate) static ENTRY_MINERALIZER_3737034346131356210: VariantsMap = [
    &["mineralizer"],
    &["mineraliser"],
    &["mineralizer"],
    &["mineraliser"],
];

pub(crate) static ENTRY_MINERALIZES_12077281629276944607: VariantsMap = [
    &["mineralizes"],
    &["mineralises"],
    &["mineralizes"],
    &["mineralises"],
];

pub(crate) static ENTRY_MINERALIZE_7945578525483035467: VariantsMap = [
    &["mineralize"],
    &["mineralise"],
    &["mineralize"],
    &["mineralise"],
];

pub(crate) static ENTRY_MINERALIZING_3182430059767749821: VariantsMap = [
    &["mineralizing"],
    &["mineralising"],
    &["mineralizing"],
    &["mineralising"],
];

pub(crate) static ENTRY_MINERALOGIZED_13505275795027010900: VariantsMap = [
    &["mineralogized"],
    &["mineralogised"],
    &["mineralogized"],
    &["mineralogised"],
];

pub(crate) static ENTRY_MINERALOGIZES_10531047901674270914: VariantsMap = [
    &["mineralogizes"],
    &["mineralogises"],
    &["mineralogizes"],
    &["mineralogises"],
];

pub(crate) static ENTRY_MINERALOGIZE_12837927935605358001: VariantsMap = [
    &["mineralogize"],
    &["mineralogise"],
    &["mineralogize"],
    &["mineralogise"],
];

pub(crate) static ENTRY_MINERALOGIZING_7977291710561372216: VariantsMap = [
    &["mineralogizing"],
    &["mineralogising"],
    &["mineralogizing"],
    &["mineralogising"],
];

pub(crate) static ENTRY_MINIATURIZATIONS_13443825612505429435: VariantsMap = [
    &["miniaturizations"],
    &["miniaturisations"],
    &["miniaturizations"],
    &["miniaturisations"],
];

pub(crate) static ENTRY_MINIATURIZATION_11771675081402773636: VariantsMap = [
    &["miniaturization"],
    &["miniaturisation"],
    &["miniaturization"],
    &["miniaturisation"],
];

pub(crate) static ENTRY_MINIATURIZED_3880152562256982898: VariantsMap = [
    &["miniaturized"],
    &["miniaturised"],
    &["miniaturized"],
    &["miniaturised"],
];

pub(crate) static ENTRY_MINIATURIZES_4987348295329229449: VariantsMap = [
    &["miniaturizes"],
    &["miniaturises"],
    &["miniaturizes"],
    &["miniaturises"],
];

pub(crate) static ENTRY_MINIATURIZE_14775476687436824687: VariantsMap = [
    &["miniaturize"],
    &["miniaturise"],
    &["miniaturize"],
    &["miniaturise"],
];

pub(crate) static ENTRY_MINIATURIZING_4324908215288109965: VariantsMap = [
    &["miniaturizing"],
    &["miniaturising"],
    &["miniaturizing"],
    &["miniaturising"],
];

pub(crate) static ENTRY_MINIBUSES_11051687516105212429: VariantsMap = [
    &["minibuses"],
    &["minibuses"],
    &["minibuses"],
    &["minibuses"],
];

pub(crate) static ENTRY_MINIMIZATIONS_16859838846464243203: VariantsMap = [
    &["minimizations"],
    &["minimisations"],
    &["minimizations"],
    &["minimisations"],
];

pub(crate) static ENTRY_MINIMIZATION_15941432212626950244: VariantsMap = [
    &["minimization"],
    &["minimisation"],
    &["minimization"],
    &["minimisation"],
];

pub(crate) static ENTRY_MINIMIZED_11553117414376788475: VariantsMap = [
    &["minimized"],
    &["minimised"],
    &["minimized"],
    &["minimised"],
];

pub(crate) static ENTRY_MINIMIZERS_3612737951166107599: VariantsMap = [
    &["minimizers"],
    &["minimisers"],
    &["minimizers"],
    &["minimisers"],
];

pub(crate) static ENTRY_MINIMIZER_5548812611203507924: VariantsMap = [
    &["minimizer"],
    &["minimiser"],
    &["minimizer"],
    &["minimiser"],
];

pub(crate) static ENTRY_MINIMIZES_9554981472878791756: VariantsMap = [
    &["minimizes"],
    &["minimises"],
    &["minimizes"],
    &["minimises"],
];

pub(crate) static ENTRY_MINIMIZE_2781781045543044735: VariantsMap =
    [&["minimize"], &["minimise"], &["minimize"], &["minimise"]];

pub(crate) static ENTRY_MINIMIZING_16481774084401198225: VariantsMap = [
    &["minimizing"],
    &["minimising"],
    &["minimizing"],
    &["minimising"],
];

pub(crate) static ENTRY_MIRACULIZED_18124387121142671186: VariantsMap = [
    &["miraculized"],
    &["miraculised"],
    &["miraculized"],
    &["miraculised"],
];

pub(crate) static ENTRY_MIRACULIZES_3024248323745780201: VariantsMap = [
    &["miraculizes"],
    &["miraculises"],
    &["miraculizes"],
    &["miraculises"],
];

pub(crate) static ENTRY_MIRACULIZE_12594578967332117147: VariantsMap = [
    &["miraculize"],
    &["miraculise"],
    &["miraculize"],
    &["miraculise"],
];

pub(crate) static ENTRY_MIRACULIZING_9780578229159926476: VariantsMap = [
    &["miraculizing"],
    &["miraculising"],
    &["miraculizing"],
    &["miraculising"],
];

pub(crate) static ENTRY_MIRRORIZES_2859817952428182045: VariantsMap = [
    &["mirrorizes"],
    &["mirrorises"],
    &["mirrorizes"],
    &["mirrorises"],
];

pub(crate) static ENTRY_MIRRORIZE_17308641168637711576: VariantsMap = [
    &["mirrorize"],
    &["mirrorise"],
    &["mirrorize"],
    &["mirrorise"],
];

pub(crate) static ENTRY_MISADVIZE_1613208909926045561: VariantsMap = [
    &["misadvize"],
    &["misadvise"],
    &["misadvize"],
    &["misadvise"],
];

pub(crate) static ENTRY_MISALPHABETIZES_2749952515466087884: VariantsMap = [
    &["misalphabetizes"],
    &["misalphabetises"],
    &["misalphabetizes"],
    &["misalphabetises"],
];

pub(crate) static ENTRY_MISALPHABETIZE_15903925617999627004: VariantsMap = [
    &["misalphabetize"],
    &["misalphabetise"],
    &["misalphabetize"],
    &["misalphabetise"],
];

pub(crate) static ENTRY_MISANTHROPIZED_5494865608069126958: VariantsMap = [
    &["misanthropized"],
    &["misanthropised"],
    &["misanthropized"],
    &["misanthropised"],
];

pub(crate) static ENTRY_MISANTHROPIZES_8621200081370476291: VariantsMap = [
    &["misanthropizes"],
    &["misanthropises"],
    &["misanthropizes"],
    &["misanthropises"],
];

pub(crate) static ENTRY_MISANTHROPIZE_17170767351201053555: VariantsMap = [
    &["misanthropize"],
    &["misanthropise"],
    &["misanthropize"],
    &["misanthropise"],
];

pub(crate) static ENTRY_MISANTHROPIZING_17955560059393289897: VariantsMap = [
    &["misanthropizing"],
    &["misanthropising"],
    &["misanthropizing"],
    &["misanthropising"],
];

pub(crate) static ENTRY_MISAUTHORIZATIONS_12436849369504879800: VariantsMap = [
    &["misauthorizations"],
    &["misauthorisations"],
    &["misauthorizations"],
    &["misauthorisations"],
];

pub(crate) static ENTRY_MISAUTHORIZATION_14891497048505685561: VariantsMap = [
    &["misauthorization"],
    &["misauthorisation"],
    &["misauthorization"],
    &["misauthorisation"],
];

pub(crate) static ENTRY_MISAUTHORIZES_4900945154483453360: VariantsMap = [
    &["misauthorizes"],
    &["misauthorises"],
    &["misauthorizes"],
    &["misauthorises"],
];

pub(crate) static ENTRY_MISAUTHORIZE_2271687349975291464: VariantsMap = [
    &["misauthorize"],
    &["misauthorise"],
    &["misauthorize"],
    &["misauthorise"],
];

pub(crate) static ENTRY_MISBAPTIZES_3045720393639226403: VariantsMap = [
    &["misbaptizes"],
    &["misbaptises"],
    &["misbaptizes"],
    &["misbaptises"],
];

pub(crate) static ENTRY_MISBAPTIZE_1708261197362730245: VariantsMap = [
    &["misbaptize"],
    &["misbaptise"],
    &["misbaptize"],
    &["misbaptise"],
];

pub(crate) static ENTRY_MISBEHAVIORS_4095360583991043350: VariantsMap = [
    &["misbehaviors"],
    &["misbehaviours"],
    &["misbehaviours"],
    &["misbehaviours"],
];

pub(crate) static ENTRY_MISBEHAVIOR_1494581758331316402: VariantsMap = [
    &["misbehavior"],
    &["misbehaviour"],
    &["misbehaviour"],
    &["misbehaviour"],
];

pub(crate) static ENTRY_MISCANONIZES_7870617629942275975: VariantsMap = [
    &["miscanonizes"],
    &["miscanonises"],
    &["miscanonizes"],
    &["miscanonises"],
];

pub(crate) static ENTRY_MISCANONIZE_10826665566184909604: VariantsMap = [
    &["miscanonize"],
    &["miscanonise"],
    &["miscanonize"],
    &["miscanonise"],
];

pub(crate) static ENTRY_MISCHARACTERIZATIONS_14463836821244335501: VariantsMap = [
    &["mischaracterizations"],
    &["mischaracterisations"],
    &["mischaracterizations"],
    &["mischaracterisations"],
];

pub(crate) static ENTRY_MISCHARACTERIZATION_10291461125809939083: VariantsMap = [
    &["mischaracterization"],
    &["mischaracterisation"],
    &["mischaracterization"],
    &["mischaracterisation"],
];

pub(crate) static ENTRY_MISCHARACTERIZES_2053463788293812639: VariantsMap = [
    &["mischaracterizes"],
    &["mischaracterises"],
    &["mischaracterizes"],
    &["mischaracterises"],
];

pub(crate) static ENTRY_MISCHARACTERIZE_17813891911357917532: VariantsMap = [
    &["mischaracterize"],
    &["mischaracterise"],
    &["mischaracterize"],
    &["mischaracterise"],
];

pub(crate) static ENTRY_MISCOLORATION_1690416727086001845: VariantsMap = [
    &["miscoloration"],
    &["miscolouration"],
    &["miscolouration"],
    &["miscolouration"],
];

pub(crate) static ENTRY_MISCOLORED_13297919653949634361: VariantsMap = [
    &["miscolored"],
    &["miscoloured"],
    &["miscoloured"],
    &["miscoloured"],
];

pub(crate) static ENTRY_MISCOLORING_14732928106161795811: VariantsMap = [
    &["miscoloring"],
    &["miscolouring"],
    &["miscolouring"],
    &["miscolouring"],
];

pub(crate) static ENTRY_MISCOLORS_8989716299210529212: VariantsMap = [
    &["miscolors"],
    &["miscolours"],
    &["miscolours"],
    &["miscolours"],
];

pub(crate) static ENTRY_MISCOLOR_1908472380673894947: VariantsMap = [
    &["miscolor"],
    &["miscolour"],
    &["miscolour"],
    &["miscolour"],
];

pub(crate) static ENTRY_MISDEMEANORS_11749207148565478841: VariantsMap = [
    &["misdemeanors"],
    &["misdemeanours"],
    &["misdemeanours"],
    &["misdemeanours"],
];

pub(crate) static ENTRY_MISDEMEANOR_1250919998876899665: VariantsMap = [
    &["misdemeanor"],
    &["misdemeanour"],
    &["misdemeanour"],
    &["misdemeanour"],
];

pub(crate) static ENTRY_MISEMPHASIZES_15835142756342884945: VariantsMap = [
    &["misemphasizes"],
    &["misemphasises"],
    &["misemphasizes"],
    &["misemphasises"],
];

pub(crate) static ENTRY_MISEMPHASIZE_2936109535805352767: VariantsMap = [
    &["misemphasize"],
    &["misemphasise"],
    &["misemphasize"],
    &["misemphasise"],
];

pub(crate) static ENTRY_MISJUDGMENTS_17389672896349870910: VariantsMap = [
    &["misjudgments"],
    &["misjudgements"],
    &["misjudgments"],
    &["misjudgements"],
];

pub(crate) static ENTRY_MISJUDGMENT_17843686745476490529: VariantsMap = [
    &["misjudgment"],
    &["misjudgement"],
    &["misjudgment"],
    &["misjudgement"],
];

pub(crate) static ENTRY_MISLABELED_7926653334976693959: VariantsMap = [
    &["mislabeled"],
    &["mislabelled"],
    &["mislabelled"],
    &["mislabelled"],
];

pub(crate) static ENTRY_MISLABELING_368815218416940620: VariantsMap = [
    &["mislabeling"],
    &["mislabelling"],
    &["mislabelling"],
    &["mislabelling"],
];

pub(crate) static ENTRY_MISLABORED_10704627531362921647: VariantsMap = [
    &["mislabored"],
    &["mislaboured"],
    &["mislaboured"],
    &["mislaboured"],
];

pub(crate) static ENTRY_MISLABORING_3306598715211504366: VariantsMap = [
    &["mislaboring"],
    &["mislabouring"],
    &["mislabouring"],
    &["mislabouring"],
];

pub(crate) static ENTRY_MISLABORS_17741241387381188744: VariantsMap = [
    &["mislabors"],
    &["mislabours"],
    &["mislabours"],
    &["mislabours"],
];

pub(crate) static ENTRY_MISLABOR_11862740488880915405: VariantsMap = [
    &["mislabor"],
    &["mislabour"],
    &["mislabour"],
    &["mislabour"],
];

pub(crate) static ENTRY_MISOPEDIA_3367574278824775575: VariantsMap = [
    &["misopedia"],
    &["misopaedia"],
    &["misopaedia"],
    &["misopaedia"],
];

pub(crate) static ENTRY_MISOPEDISM_17961691095480486146: VariantsMap = [
    &["misopedism"],
    &["misopaedism"],
    &["misopaedism"],
    &["misopaedism"],
];

pub(crate) static ENTRY_MISOPEDIST_13958701045726659475: VariantsMap = [
    &["misopedist"],
    &["misopaedist"],
    &["misopaedist"],
    &["misopaedist"],
];

pub(crate) static ENTRY_MISORGANIZATIONS_16256056216985643161: VariantsMap = [
    &["misorganizations"],
    &["misorganisations"],
    &["misorganizations"],
    &["misorganisations"],
];

pub(crate) static ENTRY_MISORGANIZATION_4528274519460006130: VariantsMap = [
    &["misorganization"],
    &["misorganisation"],
    &["misorganization"],
    &["misorganisation"],
];

pub(crate) static ENTRY_MISORGANIZES_16396120482654767343: VariantsMap = [
    &["misorganizes"],
    &["misorganises"],
    &["misorganizes"],
    &["misorganises"],
];

pub(crate) static ENTRY_MISORGANIZE_8043699224147914594: VariantsMap = [
    &["misorganize"],
    &["misorganise"],
    &["misorganize"],
    &["misorganise"],
];

pub(crate) static ENTRY_MISPRIZAL_1906224147210876596: VariantsMap = [
    &["misprizal"],
    &["misprisal"],
    &["misprizal"],
    &["misprisal"],
];

pub(crate) static ENTRY_MISPRIZED_15910979320445924885: VariantsMap = [
    &["misprized"],
    &["misprized"],
    &["misprized"],
    &["misprized"],
];

pub(crate) static ENTRY_MISPRIZER_1574809362067258794: VariantsMap = [
    &["misprizer"],
    &["mispriser"],
    &["misprizer"],
    &["mispriser"],
];

pub(crate) static ENTRY_MISPRIZES_16040140991463042359: VariantsMap = [
    &["misprizes"],
    &["misprizes"],
    &["misprizes"],
    &["misprizes"],
];

pub(crate) static ENTRY_MISPRIZE_7317761504865217596: VariantsMap =
    [&["misprize"], &["misprize"], &["misprize"], &["misprize"]];

pub(crate) static ENTRY_MISPRIZING_12105379912423556571: VariantsMap = [
    &["misprizing"],
    &["misprizing"],
    &["misprizing"],
    &["misprizing"],
];

pub(crate) static ENTRY_MISREALIZES_5429375807985531029: VariantsMap = [
    &["misrealizes"],
    &["misrealises"],
    &["misrealizes"],
    &["misrealises"],
];

pub(crate) static ENTRY_MISREALIZE_46370965209688711: VariantsMap = [
    &["misrealize"],
    &["misrealise"],
    &["misrealize"],
    &["misrealise"],
];

pub(crate) static ENTRY_MISRECOGNIZES_10782325434195444690: VariantsMap = [
    &["misrecognizes"],
    &["misrecognises"],
    &["misrecognizes"],
    &["misrecognises"],
];

pub(crate) static ENTRY_MISRECOGNIZE_4535527973403537388: VariantsMap = [
    &["misrecognize"],
    &["misrecognise"],
    &["misrecognize"],
    &["misrecognise"],
];

pub(crate) static ENTRY_MISROUTING_6953912846649926545: VariantsMap = [
    &["misrouting"],
    &["misrouteing"],
    &["misrouteing"],
    &["misrouteing"],
];

pub(crate) static ENTRY_MISSIONARIZED_3550258362783566279: VariantsMap = [
    &["missionarized"],
    &["missionarised"],
    &["missionarized"],
    &["missionarised"],
];

pub(crate) static ENTRY_MISSIONARIZES_2865828932098182673: VariantsMap = [
    &["missionarizes"],
    &["missionarises"],
    &["missionarizes"],
    &["missionarises"],
];

pub(crate) static ENTRY_MISSIONARIZE_8659233219888427790: VariantsMap = [
    &["missionarize"],
    &["missionarise"],
    &["missionarize"],
    &["missionarise"],
];

pub(crate) static ENTRY_MISSIONARIZING_6713234286118309855: VariantsMap = [
    &["missionarizing"],
    &["missionarising"],
    &["missionarizing"],
    &["missionarising"],
];

pub(crate) static ENTRY_MISSIONIZATION_5386570164157640867: VariantsMap = [
    &["missionization"],
    &["missionisation"],
    &["missionization"],
    &["missionisation"],
];

pub(crate) static ENTRY_MISSIONIZED_8256176424405826525: VariantsMap = [
    &["missionized"],
    &["missionised"],
    &["missionized"],
    &["missionised"],
];

pub(crate) static ENTRY_MISSIONIZERS_11864753429827863840: VariantsMap = [
    &["missionizers"],
    &["missionisers"],
    &["missionizers"],
    &["missionisers"],
];

pub(crate) static ENTRY_MISSIONIZER_15289881884612675093: VariantsMap = [
    &["missionizer"],
    &["missioniser"],
    &["missionizer"],
    &["missioniser"],
];

pub(crate) static ENTRY_MISSIONIZES_7974503074241187699: VariantsMap = [
    &["missionizes"],
    &["missionises"],
    &["missionizes"],
    &["missionises"],
];

pub(crate) static ENTRY_MISSIONIZE_9215465213060476024: VariantsMap = [
    &["missionize"],
    &["missionise"],
    &["missionize"],
    &["missionise"],
];

pub(crate) static ENTRY_MISSIONIZING_4494832750144779312: VariantsMap = [
    &["missionizing"],
    &["missionising"],
    &["missionizing"],
    &["missionising"],
];

pub(crate) static ENTRY_MITERED_8698507717371065494: VariantsMap =
    [&["mitered"], &["mitred"], &["mitred"], &["mitred"]];

pub(crate) static ENTRY_MITERER_12530932115756420713: VariantsMap =
    [&["miterer"], &["mitrer"], &["mitrer"], &["mitrer"]];

pub(crate) static ENTRY_MITERFLOWER_14337093432563184888: VariantsMap = [
    &["miterflower"],
    &["mitreflower"],
    &["mitreflower"],
    &["mitreflower"],
];

pub(crate) static ENTRY_MITERING_17472611887349673354: VariantsMap =
    [&["mitering"], &["mitring"], &["mitring"], &["mitring"]];

pub(crate) static ENTRY_MITERS_13601882143052765005: VariantsMap =
    [&["miters"], &["mitres"], &["mitres"], &["mitres"]];

pub(crate) static ENTRY_MITERWORTS_17121170244158720767: VariantsMap = [
    &["miterworts"],
    &["mitreworts"],
    &["mitreworts"],
    &["mitreworts"],
];

pub(crate) static ENTRY_MITERWORT_8547548283547590528: VariantsMap = [
    &["miterwort"],
    &["mitrewort"],
    &["mitrewort"],
    &["mitrewort"],
];

pub(crate) static ENTRY_MITER_14901282210601132768: VariantsMap =
    [&["miter"], &["mitre"], &["mitre"], &["mitre"]];

pub(crate) static ENTRY_MITHRIDATIZED_15226011945453367877: VariantsMap = [
    &["mithridatized"],
    &["mithridatised"],
    &["mithridatized"],
    &["mithridatised"],
];

pub(crate) static ENTRY_MITHRIDATIZES_17923000552005460927: VariantsMap = [
    &["mithridatizes"],
    &["mithridatises"],
    &["mithridatizes"],
    &["mithridatises"],
];

pub(crate) static ENTRY_MITHRIDATIZE_2966636373317648004: VariantsMap = [
    &["mithridatize"],
    &["mithridatise"],
    &["mithridatize"],
    &["mithridatise"],
];

pub(crate) static ENTRY_MITHRIDATIZING_11477680424456392910: VariantsMap = [
    &["mithridatizing"],
    &["mithridatising"],
    &["mithridatizing"],
    &["mithridatising"],
];

pub(crate) static ENTRY_MIZE_18024382563076168859: VariantsMap =
    [&["mize"], &["mise"], &["mize"], &["mise"]];

pub(crate) static ENTRY_MOBILIZABLER_550692436973252168: VariantsMap = [
    &["mobilizabler"],
    &["mobilisabler"],
    &["mobilizabler"],
    &["mobilisabler"],
];

pub(crate) static ENTRY_MOBILIZABLEST_2936215873432536207: VariantsMap = [
    &["mobilizablest"],
    &["mobilisablest"],
    &["mobilizablest"],
    &["mobilisablest"],
];

pub(crate) static ENTRY_MOBILIZABLES_13069683708079300928: VariantsMap = [
    &["mobilizables"],
    &["mobilisables"],
    &["mobilizables"],
    &["mobilisables"],
];

pub(crate) static ENTRY_MOBILIZABLE_4838354601271065797: VariantsMap = [
    &["mobilizable"],
    &["mobilisable"],
    &["mobilizable"],
    &["mobilisable"],
];

pub(crate) static ENTRY_MOBILIZATIONS_14453487133355314782: VariantsMap = [
    &["mobilizations"],
    &["mobilisations"],
    &["mobilizations"],
    &["mobilisations"],
];

pub(crate) static ENTRY_MOBILIZATION_5777426368387580657: VariantsMap = [
    &["mobilization"],
    &["mobilisation"],
    &["mobilization"],
    &["mobilisation"],
];

pub(crate) static ENTRY_MOBILIZED_5804933841881642219: VariantsMap = [
    &["mobilized"],
    &["mobilised"],
    &["mobilized"],
    &["mobilised"],
];

pub(crate) static ENTRY_MOBILIZERS_3858507952045243762: VariantsMap = [
    &["mobilizers"],
    &["mobilisers"],
    &["mobilizers"],
    &["mobilisers"],
];

pub(crate) static ENTRY_MOBILIZER_10343085295594491112: VariantsMap = [
    &["mobilizer"],
    &["mobiliser"],
    &["mobilizer"],
    &["mobiliser"],
];

pub(crate) static ENTRY_MOBILIZES_16439067393017229087: VariantsMap = [
    &["mobilizes"],
    &["mobilises"],
    &["mobilizes"],
    &["mobilises"],
];

pub(crate) static ENTRY_MOBILIZE_8789464231798787986: VariantsMap =
    [&["mobilize"], &["mobilise"], &["mobilize"], &["mobilise"]];

pub(crate) static ENTRY_MOBILIZING_1417290482744517718: VariantsMap = [
    &["mobilizing"],
    &["mobilising"],
    &["mobilizing"],
    &["mobilising"],
];

pub(crate) static ENTRY_MODALIZES_11613635884904143996: VariantsMap = [
    &["modalizes"],
    &["modalises"],
    &["modalizes"],
    &["modalises"],
];

pub(crate) static ENTRY_MODALIZE_16350838792808777521: VariantsMap =
    [&["modalize"], &["modalise"], &["modalize"], &["modalise"]];

pub(crate) static ENTRY_MODELED_12650479689070423426: VariantsMap =
    [&["modeled"], &["modelled"], &["modelled"], &["modelled"]];

pub(crate) static ENTRY_MODELERS_3381426157906439456: VariantsMap = [
    &["modelers"],
    &["modellers"],
    &["modellers"],
    &["modellers"],
];

pub(crate) static ENTRY_MODELER_14424786862458395262: VariantsMap =
    [&["modeler"], &["modeller"], &["modeller"], &["modeller"]];

pub(crate) static ENTRY_MODELINGS_18288599171721945682: VariantsMap = [
    &["modelings"],
    &["modellings"],
    &["modellings"],
    &["modellings"],
];

pub(crate) static ENTRY_MODELING_2974344260900643587: VariantsMap = [
    &["modeling"],
    &["modelling"],
    &["modelling"],
    &["modelling"],
];

pub(crate) static ENTRY_MODERNIZABLES_17762667775078181032: VariantsMap = [
    &["modernizables"],
    &["modernisables"],
    &["modernizables"],
    &["modernisables"],
];

pub(crate) static ENTRY_MODERNIZABLE_2241201696674028296: VariantsMap = [
    &["modernizable"],
    &["modernisable"],
    &["modernizable"],
    &["modernisable"],
];

pub(crate) static ENTRY_MODERNIZATIONS_11584063023767292185: VariantsMap = [
    &["modernizations"],
    &["modernisations"],
    &["modernizations"],
    &["modernisations"],
];

pub(crate) static ENTRY_MODERNIZATION_14709070202714057545: VariantsMap = [
    &["modernization"],
    &["modernisation"],
    &["modernization"],
    &["modernisation"],
];

pub(crate) static ENTRY_MODERNIZED_16345622123558324284: VariantsMap = [
    &["modernized"],
    &["modernised"],
    &["modernized"],
    &["modernised"],
];

pub(crate) static ENTRY_MODERNIZERS_17286474013116987617: VariantsMap = [
    &["modernizers"],
    &["modernisers"],
    &["modernizers"],
    &["modernisers"],
];

pub(crate) static ENTRY_MODERNIZER_18233663007102441685: VariantsMap = [
    &["modernizer"],
    &["moderniser"],
    &["modernizer"],
    &["moderniser"],
];

pub(crate) static ENTRY_MODERNIZES_12697791365347916756: VariantsMap = [
    &["modernizes"],
    &["modernises"],
    &["modernizes"],
    &["modernises"],
];

pub(crate) static ENTRY_MODERNIZE_7510605744058517470: VariantsMap = [
    &["modernize"],
    &["modernise"],
    &["modernize"],
    &["modernise"],
];

pub(crate) static ENTRY_MODERNIZING_5025029940522757107: VariantsMap = [
    &["modernizing"],
    &["modernising"],
    &["modernizing"],
    &["modernising"],
];

pub(crate) static ENTRY_MODULARIZATION_1558183326417358953: VariantsMap = [
    &["modularization"],
    &["modularisation"],
    &["modularization"],
    &["modularisation"],
];

pub(crate) static ENTRY_MODULARIZED_10761682201246036312: VariantsMap = [
    &["modularized"],
    &["modularised"],
    &["modularized"],
    &["modularised"],
];

pub(crate) static ENTRY_MODULARIZES_14876821131445153583: VariantsMap = [
    &["modularizes"],
    &["modularises"],
    &["modularizes"],
    &["modularises"],
];

pub(crate) static ENTRY_MODULARIZE_2749267996562714054: VariantsMap = [
    &["modularize"],
    &["modularise"],
    &["modularize"],
    &["modularise"],
];

pub(crate) static ENTRY_MODULARIZING_18092728005779185876: VariantsMap = [
    &["modularizing"],
    &["modularising"],
    &["modularizing"],
    &["modularising"],
];

pub(crate) static ENTRY_MOGGY_7403358484289979778: VariantsMap =
    [&["moggy"], &["moggie"], &["moggie"], &["moggie"]];

pub(crate) static ENTRY_MOHAMMEDANIZATIONS_17148982401883279782: VariantsMap = [
    &["mohammedanizations"],
    &["mohammedanisations"],
    &["mohammedanizations"],
    &["mohammedanisations"],
];

pub(crate) static ENTRY_MOHAMMEDANIZATION_16744967596386683848: VariantsMap = [
    &["mohammedanization"],
    &["mohammedanisation"],
    &["mohammedanization"],
    &["mohammedanisation"],
];

pub(crate) static ENTRY_MOHAMMEDANIZED_15191782132430589893: VariantsMap = [
    &["mohammedanized"],
    &["mohammedanised"],
    &["mohammedanized"],
    &["mohammedanised"],
];

pub(crate) static ENTRY_MOHAMMEDANIZES_4957996437102920437: VariantsMap = [
    &["mohammedanizes"],
    &["mohammedanises"],
    &["mohammedanizes"],
    &["mohammedanises"],
];

pub(crate) static ENTRY_MOHAMMEDANIZE_2013237486051435987: VariantsMap = [
    &["mohammedanize"],
    &["mohammedanise"],
    &["mohammedanize"],
    &["mohammedanise"],
];

pub(crate) static ENTRY_MOHAMMEDANIZING_16231921957501731765: VariantsMap = [
    &["mohammedanizing"],
    &["mohammedanising"],
    &["mohammedanizing"],
    &["mohammedanising"],
];

pub(crate) static ENTRY_MOISTURIZATION_10380414116064573146: VariantsMap = [
    &["moisturization"],
    &["moisturisation"],
    &["moisturization"],
    &["moisturisation"],
];

pub(crate) static ENTRY_MOISTURIZED_16147661633583544526: VariantsMap = [
    &["moisturized"],
    &["moisturised"],
    &["moisturized"],
    &["moisturised"],
];

pub(crate) static ENTRY_MOISTURIZERS_9974196958240719712: VariantsMap = [
    &["moisturizers"],
    &["moisturisers"],
    &["moisturizers"],
    &["moisturisers"],
];

pub(crate) static ENTRY_MOISTURIZER_976074536579829817: VariantsMap = [
    &["moisturizer"],
    &["moisturiser"],
    &["moisturizer"],
    &["moisturiser"],
];

pub(crate) static ENTRY_MOISTURIZES_5386452103898759766: VariantsMap = [
    &["moisturizes"],
    &["moisturises"],
    &["moisturizes"],
    &["moisturises"],
];

pub(crate) static ENTRY_MOISTURIZE_3082181073277609007: VariantsMap = [
    &["moisturize"],
    &["moisturise"],
    &["moisturize"],
    &["moisturise"],
];

pub(crate) static ENTRY_MOISTURIZING_1153301405850895778: VariantsMap = [
    &["moisturizing"],
    &["moisturising"],
    &["moisturizing"],
    &["moisturising"],
];

pub(crate) static ENTRY_MOLARIZATIONS_16507279008859766734: VariantsMap = [
    &["molarizations"],
    &["molarisations"],
    &["molarizations"],
    &["molarisations"],
];

pub(crate) static ENTRY_MOLARIZATION_13660005087668514663: VariantsMap = [
    &["molarization"],
    &["molarisation"],
    &["molarization"],
    &["molarisation"],
];

pub(crate) static ENTRY_MOLDED_18226100678955103665: VariantsMap =
    [&["molded"], &["moulded"], &["moulded"], &["moulded"]];

pub(crate) static ENTRY_MOLDERED_4758916297507026457: VariantsMap = [
    &["moldered"],
    &["mouldered"],
    &["mouldered"],
    &["mouldered"],
];

pub(crate) static ENTRY_MOLDERING_12580871299131147348: VariantsMap = [
    &["moldering"],
    &["mouldering"],
    &["mouldering"],
    &["mouldering"],
];

pub(crate) static ENTRY_MOLDERS_13997118245436919961: VariantsMap =
    [&["molders"], &["moulders"], &["moulders"], &["moulders"]];

pub(crate) static ENTRY_MOLDER_15465918692066970810: VariantsMap =
    [&["molder"], &["moulder"], &["moulder"], &["moulder"]];

pub(crate) static ENTRY_MOLDIER_10922522589068582068: VariantsMap =
    [&["moldier"], &["mouldier"], &["mouldier"], &["mouldier"]];

pub(crate) static ENTRY_MOLDIEST_1317386157625536454: VariantsMap = [
    &["moldiest"],
    &["mouldiest"],
    &["mouldiest"],
    &["mouldiest"],
];

pub(crate) static ENTRY_MOLDINGS_2565998909932841371: VariantsMap = [
    &["moldings"],
    &["mouldings"],
    &["mouldings"],
    &["mouldings"],
];

pub(crate) static ENTRY_MOLDING_5803372015928130364: VariantsMap =
    [&["molding"], &["moulding"], &["moulding"], &["moulding"]];

pub(crate) static ENTRY_MOLDS_12422213630336798844: VariantsMap =
    [&["molds"], &["moulds"], &["moulds"], &["moulds"]];

pub(crate) static ENTRY_MOLDY_14321784814821274745: VariantsMap =
    [&["moldy"], &["mouldy"], &["mouldy"], &["mouldy"]];

pub(crate) static ENTRY_MOLD_13654108368759432573: VariantsMap =
    [&["mold"], &["mould"], &["mould"], &["mould"]];

pub(crate) static ENTRY_MOLLUSCAN_17330317330413879995: VariantsMap = [
    &["molluscan"],
    &["molluscan"],
    &["molluscan"],
    &["molluscan"],
];

pub(crate) static ENTRY_MOLLUSKS_7011160555842704825: VariantsMap =
    [&["mollusks"], &["molluscs"], &["molluscs"], &["molluscs"]];

pub(crate) static ENTRY_MOLLUSK_6823511292751098286: VariantsMap =
    [&["mollusk"], &["mollusc"], &["mollusc"], &["mollusc"]];

pub(crate) static ENTRY_MOLOCHIZED_821791843761212929: VariantsMap = [
    &["molochized"],
    &["molochised"],
    &["molochized"],
    &["molochised"],
];

pub(crate) static ENTRY_MOLOCHIZES_4165788617829197688: VariantsMap = [
    &["molochizes"],
    &["molochises"],
    &["molochizes"],
    &["molochises"],
];

pub(crate) static ENTRY_MOLOCHIZE_18208589110973869272: VariantsMap = [
    &["molochize"],
    &["molochise"],
    &["molochize"],
    &["molochise"],
];

pub(crate) static ENTRY_MOLOCHIZING_2091155534102840219: VariantsMap = [
    &["molochizing"],
    &["molochising"],
    &["molochizing"],
    &["molochising"],
];

pub(crate) static ENTRY_MOLTED_15961459823560620603: VariantsMap =
    [&["molted"], &["moulted"], &["moulted"], &["moulted"]];

pub(crate) static ENTRY_MOLTING_8804427143377484509: VariantsMap =
    [&["molting"], &["moulting"], &["moulting"], &["moulting"]];

pub(crate) static ENTRY_MOLTS_9899279585297366446: VariantsMap =
    [&["molts"], &["moults"], &["moults"], &["moults"]];

pub(crate) static ENTRY_MOLT_17322314851966354350: VariantsMap =
    [&["molt"], &["moult"], &["moult"], &["moult"]];

pub(crate) static ENTRY_MOMS_12551587271348147263: VariantsMap =
    [&["moms"], &["mums"], &["moms"], &["mums"]];

pub(crate) static ENTRY_MOM_5106551349804515206: VariantsMap =
    [&["mom"], &["mum"], &["mom"], &["mum"]];

pub(crate) static ENTRY_MONARCHIZED_14485113839253836143: VariantsMap = [
    &["monarchized"],
    &["monarchised"],
    &["monarchized"],
    &["monarchised"],
];

pub(crate) static ENTRY_MONARCHIZERS_9930135356106528857: VariantsMap = [
    &["monarchizers"],
    &["monarchisers"],
    &["monarchizers"],
    &["monarchisers"],
];

pub(crate) static ENTRY_MONARCHIZER_4284095516115676620: VariantsMap = [
    &["monarchizer"],
    &["monarchiser"],
    &["monarchizer"],
    &["monarchiser"],
];

pub(crate) static ENTRY_MONARCHIZES_8572784744664864851: VariantsMap = [
    &["monarchizes"],
    &["monarchises"],
    &["monarchizes"],
    &["monarchises"],
];

pub(crate) static ENTRY_MONARCHIZE_9559277820673512352: VariantsMap = [
    &["monarchize"],
    &["monarchise"],
    &["monarchize"],
    &["monarchise"],
];

pub(crate) static ENTRY_MONARCHIZING_7759908511293928199: VariantsMap = [
    &["monarchizing"],
    &["monarchising"],
    &["monarchizing"],
    &["monarchising"],
];

pub(crate) static ENTRY_MONASTICIZES_5305902420161432780: VariantsMap = [
    &["monasticizes"],
    &["monasticises"],
    &["monasticizes"],
    &["monasticises"],
];

pub(crate) static ENTRY_MONASTICIZE_8704681192852397467: VariantsMap = [
    &["monasticize"],
    &["monasticise"],
    &["monasticize"],
    &["monasticise"],
];

pub(crate) static ENTRY_MONECIAN_11450168883673844089: VariantsMap = [
    &["monecian"],
    &["monoecian"],
    &["monoecian"],
    &["monoecian"],
];

pub(crate) static ENTRY_MONESTROUS_6196258053360644210: VariantsMap = [
    &["monestrous"],
    &["monoestrous"],
    &["monoestrous"],
    &["monoestrous"],
];

pub(crate) static ENTRY_MONETIZATIONS_14358715948666978904: VariantsMap = [
    &["monetizations"],
    &["monetisations"],
    &["monetizations"],
    &["monetisations"],
];

pub(crate) static ENTRY_MONETIZATION_13483845355572497348: VariantsMap = [
    &["monetization"],
    &["monetisation"],
    &["monetization"],
    &["monetisation"],
];

pub(crate) static ENTRY_MONETIZED_9484572886023410910: VariantsMap = [
    &["monetized"],
    &["monetised"],
    &["monetized"],
    &["monetised"],
];

pub(crate) static ENTRY_MONETIZES_5492661646680399709: VariantsMap = [
    &["monetizes"],
    &["monetises"],
    &["monetizes"],
    &["monetises"],
];

pub(crate) static ENTRY_MONETIZE_8502079722472007377: VariantsMap =
    [&["monetize"], &["monetise"], &["monetize"], &["monetise"]];

pub(crate) static ENTRY_MONETIZING_3083227925499032589: VariantsMap = [
    &["monetizing"],
    &["monetising"],
    &["monetizing"],
    &["monetising"],
];

pub(crate) static ENTRY_MONGOLIZED_5299121885656590363: VariantsMap = [
    &["mongolized"],
    &["mongolised"],
    &["mongolized"],
    &["mongolised"],
];

pub(crate) static ENTRY_MONGOLIZES_14085267755452553789: VariantsMap = [
    &["mongolizes"],
    &["mongolises"],
    &["mongolizes"],
    &["mongolises"],
];

pub(crate) static ENTRY_MONGOLIZE_9713647571907152281: VariantsMap = [
    &["mongolize"],
    &["mongolise"],
    &["mongolize"],
    &["mongolise"],
];

pub(crate) static ENTRY_MONGOLIZING_1384426201759162743: VariantsMap = [
    &["mongolizing"],
    &["mongolising"],
    &["mongolizing"],
    &["mongolising"],
];

pub(crate) static ENTRY_MONGRELIZATIONS_2436371981269651275: VariantsMap = [
    &["mongrelizations"],
    &["mongrelisations"],
    &["mongrelizations"],
    &["mongrelisations"],
];

pub(crate) static ENTRY_MONGRELIZATION_15091053595967389048: VariantsMap = [
    &["mongrelization"],
    &["mongrelisation"],
    &["mongrelization"],
    &["mongrelisation"],
];

pub(crate) static ENTRY_MONGRELIZED_8363623153012541092: VariantsMap = [
    &["mongrelized"],
    &["mongrelised"],
    &["mongrelized"],
    &["mongrelised"],
];

pub(crate) static ENTRY_MONGRELIZER_13839004276754308084: VariantsMap = [
    &["mongrelizer"],
    &["mongreliser"],
    &["mongrelizer"],
    &["mongreliser"],
];

pub(crate) static ENTRY_MONGRELIZES_8947086149363047319: VariantsMap = [
    &["mongrelizes"],
    &["mongrelises"],
    &["mongrelizes"],
    &["mongrelises"],
];

pub(crate) static ENTRY_MONGRELIZE_11229468945460271254: VariantsMap = [
    &["mongrelize"],
    &["mongrelise"],
    &["mongrelize"],
    &["mongrelise"],
];

pub(crate) static ENTRY_MONGRELIZING_5997412177056765410: VariantsMap = [
    &["mongrelizing"],
    &["mongrelising"],
    &["mongrelizing"],
    &["mongrelising"],
];

pub(crate) static ENTRY_MONOCHORDIZES_5615164871706853064: VariantsMap = [
    &["monochordizes"],
    &["monochordises"],
    &["monochordizes"],
    &["monochordises"],
];

pub(crate) static ENTRY_MONOCHORDIZE_9437961652627754770: VariantsMap = [
    &["monochordize"],
    &["monochordise"],
    &["monochordize"],
    &["monochordise"],
];

pub(crate) static ENTRY_MONOECIOUS_9746279935101117316: VariantsMap = [
    &["monoecious"],
    &["monoecious"],
    &["monoecious"],
    &["monoecious"],
];

pub(crate) static ENTRY_MONOLOGIZED_16156031911401991864: VariantsMap = [
    &["monologized"],
    &["monologised"],
    &["monologized"],
    &["monologised"],
];

pub(crate) static ENTRY_MONOLOGIZES_13918596476650442746: VariantsMap = [
    &["monologizes"],
    &["monologises"],
    &["monologizes"],
    &["monologises"],
];

pub(crate) static ENTRY_MONOLOGIZE_16201429293272246013: VariantsMap = [
    &["monologize"],
    &["monologise"],
    &["monologize"],
    &["monologise"],
];

pub(crate) static ENTRY_MONOLOGIZING_11961970835142712480: VariantsMap = [
    &["monologizing"],
    &["monologising"],
    &["monologizing"],
    &["monologising"],
];

pub(crate) static ENTRY_MONOLOGUES_17834811023314193123: VariantsMap = [
    &["monologues"],
    &["monologues"],
    &["monologues"],
    &["monologues"],
];

pub(crate) static ENTRY_MONOLOGUE_3143921545359140083: VariantsMap = [
    &["monologue"],
    &["monologue"],
    &["monologue"],
    &["monologue"],
];

pub(crate) static ENTRY_MONOLOGUIZED_5963649767345305434: VariantsMap = [
    &["monologuized"],
    &["monologuised"],
    &["monologuized"],
    &["monologuised"],
];

pub(crate) static ENTRY_MONOLOGUIZES_40954755333017747: VariantsMap = [
    &["monologuizes"],
    &["monologuises"],
    &["monologuizes"],
    &["monologuises"],
];

pub(crate) static ENTRY_MONOLOGUIZE_5977110452781416925: VariantsMap = [
    &["monologuize"],
    &["monologuise"],
    &["monologuize"],
    &["monologuise"],
];

pub(crate) static ENTRY_MONOLOGUIZING_8885404513109687921: VariantsMap = [
    &["monologuizing"],
    &["monologuising"],
    &["monologuizing"],
    &["monologuising"],
];

pub(crate) static ENTRY_MONOMETALISM_6551087928155711829: VariantsMap = [
    &["monometalism"],
    &["monometallism"],
    &["monometallism"],
    &["monometallism"],
];

pub(crate) static ENTRY_MONOMETALIST_14189662387309527600: VariantsMap = [
    &["monometalist"],
    &["monometallist"],
    &["monometallist"],
    &["monometallist"],
];

pub(crate) static ENTRY_MONOPHTHONGIZED_10522312864287160124: VariantsMap = [
    &["monophthongized"],
    &["monophthongised"],
    &["monophthongized"],
    &["monophthongised"],
];

pub(crate) static ENTRY_MONOPHTHONGIZES_3680420610763632670: VariantsMap = [
    &["monophthongizes"],
    &["monophthongises"],
    &["monophthongizes"],
    &["monophthongises"],
];

pub(crate) static ENTRY_MONOPHTHONGIZE_15472653960750438186: VariantsMap = [
    &["monophthongize"],
    &["monophthongise"],
    &["monophthongize"],
    &["monophthongise"],
];

pub(crate) static ENTRY_MONOPHTHONGIZING_5513151536385246373: VariantsMap = [
    &["monophthongizing"],
    &["monophthongising"],
    &["monophthongizing"],
    &["monophthongising"],
];

pub(crate) static ENTRY_MONOPOLIZABLES_8954416702263834797: VariantsMap = [
    &["monopolizables"],
    &["monopolisables"],
    &["monopolizables"],
    &["monopolisables"],
];

pub(crate) static ENTRY_MONOPOLIZABLE_9755797109480546894: VariantsMap = [
    &["monopolizable"],
    &["monopolisable"],
    &["monopolizable"],
    &["monopolisable"],
];

pub(crate) static ENTRY_MONOPOLIZATIONS_10067342361986951454: VariantsMap = [
    &["monopolizations"],
    &["monopolisations"],
    &["monopolizations"],
    &["monopolisations"],
];

pub(crate) static ENTRY_MONOPOLIZATION_17799440194255806413: VariantsMap = [
    &["monopolization"],
    &["monopolisation"],
    &["monopolization"],
    &["monopolisation"],
];

pub(crate) static ENTRY_MONOPOLIZED_12340647197458384203: VariantsMap = [
    &["monopolized"],
    &["monopolised"],
    &["monopolized"],
    &["monopolised"],
];

pub(crate) static ENTRY_MONOPOLIZERS_6125991689529832032: VariantsMap = [
    &["monopolizers"],
    &["monopolisers"],
    &["monopolizers"],
    &["monopolisers"],
];

pub(crate) static ENTRY_MONOPOLIZER_2371550496160060744: VariantsMap = [
    &["monopolizer"],
    &["monopoliser"],
    &["monopolizer"],
    &["monopoliser"],
];

pub(crate) static ENTRY_MONOPOLIZES_12189941398566584704: VariantsMap = [
    &["monopolizes"],
    &["monopolises"],
    &["monopolizes"],
    &["monopolises"],
];

pub(crate) static ENTRY_MONOPOLIZE_7442479439377420004: VariantsMap = [
    &["monopolize"],
    &["monopolise"],
    &["monopolize"],
    &["monopolise"],
];

pub(crate) static ENTRY_MONOPOLIZING_16637234271263734393: VariantsMap = [
    &["monopolizing"],
    &["monopolising"],
    &["monopolizing"],
    &["monopolising"],
];

pub(crate) static ENTRY_MONOTONIZES_3864188890843789110: VariantsMap = [
    &["monotonizes"],
    &["monotonises"],
    &["monotonizes"],
    &["monotonises"],
];

pub(crate) static ENTRY_MONOTONIZE_11597278597980404355: VariantsMap = [
    &["monotonize"],
    &["monotonise"],
    &["monotonize"],
    &["monotonise"],
];

pub(crate) static ENTRY_MONUMENTALIZATIONS_4951631867947876343: VariantsMap = [
    &["monumentalizations"],
    &["monumentalisations"],
    &["monumentalizations"],
    &["monumentalisations"],
];

pub(crate) static ENTRY_MONUMENTALIZATION_2612437042934297805: VariantsMap = [
    &["monumentalization"],
    &["monumentalisation"],
    &["monumentalization"],
    &["monumentalisation"],
];

pub(crate) static ENTRY_MONUMENTALIZED_5711079078755470487: VariantsMap = [
    &["monumentalized"],
    &["monumentalised"],
    &["monumentalized"],
    &["monumentalised"],
];

pub(crate) static ENTRY_MONUMENTALIZES_504136983336154068: VariantsMap = [
    &["monumentalizes"],
    &["monumentalises"],
    &["monumentalizes"],
    &["monumentalises"],
];

pub(crate) static ENTRY_MONUMENTALIZE_13392828455281638997: VariantsMap = [
    &["monumentalize"],
    &["monumentalise"],
    &["monumentalize"],
    &["monumentalise"],
];

pub(crate) static ENTRY_MONUMENTALIZING_135723146422787131: VariantsMap = [
    &["monumentalizing"],
    &["monumentalising"],
    &["monumentalizing"],
    &["monumentalising"],
];

pub(crate) static ENTRY_MORALIZATIONS_1247598452579114999: VariantsMap = [
    &["moralizations"],
    &["moralisations"],
    &["moralizations"],
    &["moralisations"],
];

pub(crate) static ENTRY_MORALIZATION_14314788277554352162: VariantsMap = [
    &["moralization"],
    &["moralisation"],
    &["moralization"],
    &["moralisation"],
];

pub(crate) static ENTRY_MORALIZED_16553177123856203000: VariantsMap = [
    &["moralized"],
    &["moralised"],
    &["moralized"],
    &["moralised"],
];

pub(crate) static ENTRY_MORALIZERS_10483038900046187164: VariantsMap = [
    &["moralizers"],
    &["moralisers"],
    &["moralizers"],
    &["moralisers"],
];

pub(crate) static ENTRY_MORALIZER_4189449725336148474: VariantsMap = [
    &["moralizer"],
    &["moraliser"],
    &["moralizer"],
    &["moraliser"],
];

pub(crate) static ENTRY_MORALIZES_9700732558433022344: VariantsMap = [
    &["moralizes"],
    &["moralises"],
    &["moralizes"],
    &["moralises"],
];

pub(crate) static ENTRY_MORALIZE_12018775556937054309: VariantsMap =
    [&["moralize"], &["moralise"], &["moralize"], &["moralise"]];

pub(crate) static ENTRY_MORALIZINGLIES_11220751541860329137: VariantsMap = [
    &["moralizinglies"],
    &["moralisinglies"],
    &["moralizinglies"],
    &["moralisinglies"],
];

pub(crate) static ENTRY_MORALIZINGLY_11960315981427170808: VariantsMap = [
    &["moralizingly"],
    &["moralisingly"],
    &["moralizingly"],
    &["moralisingly"],
];

pub(crate) static ENTRY_MORALIZING_1210066302484943067: VariantsMap = [
    &["moralizing"],
    &["moralising"],
    &["moralizing"],
    &["moralising"],
];

pub(crate) static ENTRY_MORAVIANIZEDS_13353558936917116925: VariantsMap = [
    &["moravianizeds"],
    &["moravianiseds"],
    &["moravianizeds"],
    &["moravianiseds"],
];

pub(crate) static ENTRY_MORAVIANIZED_14670220446741413727: VariantsMap = [
    &["moravianized"],
    &["moravianised"],
    &["moravianized"],
    &["moravianised"],
];

pub(crate) static ENTRY_MORBIDIZES_12371432513893667541: VariantsMap = [
    &["morbidizes"],
    &["morbidises"],
    &["morbidizes"],
    &["morbidises"],
];

pub(crate) static ENTRY_MORBIDIZE_12078718734506704893: VariantsMap = [
    &["morbidize"],
    &["morbidise"],
    &["morbidize"],
    &["morbidise"],
];

pub(crate) static ENTRY_MOREA_4710185171044665703: VariantsMap =
    [&["morea"], &["moraea"], &["moraea"], &["moraea"]];

pub(crate) static ENTRY_MORNE_13877158832149230429: VariantsMap =
    [&["morne"], &["mourne"], &["mourne"], &["mourne"]];

pub(crate) static ENTRY_MORNINGLY_16758033098749460711: VariantsMap = [
    &["morningly"],
    &["mourningly"],
    &["mourningly"],
    &["mourningly"],
];

pub(crate) static ENTRY_MORPHINIZATIONS_17459024898140526868: VariantsMap = [
    &["morphinizations"],
    &["morphinisations"],
    &["morphinizations"],
    &["morphinisations"],
];

pub(crate) static ENTRY_MORPHINIZATION_15722085196376554379: VariantsMap = [
    &["morphinization"],
    &["morphinisation"],
    &["morphinization"],
    &["morphinisation"],
];

pub(crate) static ENTRY_MORPHINIZES_281525901207296974: VariantsMap = [
    &["morphinizes"],
    &["morphinises"],
    &["morphinizes"],
    &["morphinises"],
];

pub(crate) static ENTRY_MORPHINIZE_1408570028954955957: VariantsMap = [
    &["morphinize"],
    &["morphinise"],
    &["morphinize"],
    &["morphinise"],
];

pub(crate) static ENTRY_MORSELED_14726714058254476740: VariantsMap = [
    &["morseled"],
    &["morselled"],
    &["morselled"],
    &["morselled"],
];

pub(crate) static ENTRY_MORSELING_3101151610129962939: VariantsMap = [
    &["morseling"],
    &["morselling"],
    &["morselling"],
    &["morselling"],
];

pub(crate) static ENTRY_MORSELIZATIONS_9222041810519154677: VariantsMap = [
    &["morselizations"],
    &["morselisations"],
    &["morselizations"],
    &["morselisations"],
];

pub(crate) static ENTRY_MORSELIZATION_17621367972561654648: VariantsMap = [
    &["morselization"],
    &["morselisation"],
    &["morselization"],
    &["morselisation"],
];

pub(crate) static ENTRY_MORSELIZES_11440357553276262382: VariantsMap = [
    &["morselizes"],
    &["morselises"],
    &["morselizes"],
    &["morselises"],
];

pub(crate) static ENTRY_MORSELIZE_16639284457434622117: VariantsMap = [
    &["morselize"],
    &["morselise"],
    &["morselize"],
    &["morselise"],
];

pub(crate) static ENTRY_MORTALIZED_16595582357656997017: VariantsMap = [
    &["mortalized"],
    &["mortalised"],
    &["mortalized"],
    &["mortalised"],
];

pub(crate) static ENTRY_MORTALIZES_3397908347506824477: VariantsMap = [
    &["mortalizes"],
    &["mortalises"],
    &["mortalizes"],
    &["mortalises"],
];

pub(crate) static ENTRY_MORTALIZE_14165173813480383415: VariantsMap = [
    &["mortalize"],
    &["mortalise"],
    &["mortalize"],
    &["mortalise"],
];

pub(crate) static ENTRY_MORTALIZING_15295132795832492104: VariantsMap = [
    &["mortalizing"],
    &["mortalising"],
    &["mortalizing"],
    &["mortalising"],
];

pub(crate) static ENTRY_MORTARIZES_189381837719695349: VariantsMap = [
    &["mortarizes"],
    &["mortarises"],
    &["mortarizes"],
    &["mortarises"],
];

pub(crate) static ENTRY_MORTARIZE_8024753042638725661: VariantsMap = [
    &["mortarize"],
    &["mortarise"],
    &["mortarize"],
    &["mortarise"],
];

pub(crate) static ENTRY_MORULE_13908092229635939804: VariantsMap =
    [&["morule"], &["morulae"], &["morulae"], &["morulae"]];

pub(crate) static ENTRY_MOSLEMIZES_13236232024590556568: VariantsMap = [
    &["moslemizes"],
    &["moslemises"],
    &["moslemizes"],
    &["moslemises"],
];

pub(crate) static ENTRY_MOSLEMIZE_2447106069412629763: VariantsMap = [
    &["moslemize"],
    &["moslemise"],
    &["moslemize"],
    &["moslemise"],
];

pub(crate) static ENTRY_MOTORIZATIONS_5644703283678263848: VariantsMap = [
    &["motorizations"],
    &["motorisations"],
    &["motorizations"],
    &["motorisations"],
];

pub(crate) static ENTRY_MOTORIZATION_15203193516949680060: VariantsMap = [
    &["motorization"],
    &["motorisation"],
    &["motorization"],
    &["motorisation"],
];

pub(crate) static ENTRY_MOTORIZED_10933184907556825861: VariantsMap = [
    &["motorized"],
    &["motorised"],
    &["motorized"],
    &["motorised"],
];

pub(crate) static ENTRY_MOTORIZES_16591316114722878019: VariantsMap = [
    &["motorizes"],
    &["motorises"],
    &["motorizes"],
    &["motorises"],
];

pub(crate) static ENTRY_MOTORIZE_8341729549011887242: VariantsMap =
    [&["motorize"], &["motorise"], &["motorize"], &["motorise"]];

pub(crate) static ENTRY_MOTORIZING_5672986852014941836: VariantsMap = [
    &["motorizing"],
    &["motorising"],
    &["motorizing"],
    &["motorising"],
];

pub(crate) static ENTRY_MOVABILITY_2120736134131484989: VariantsMap = [
    &["movability"],
    &["movability"],
    &["movability"],
    &["movability"],
];

pub(crate) static ENTRY_MUCORRHEA_9758911000992883420: VariantsMap = [
    &["mucorrhea"],
    &["mucorrhoea"],
    &["mucorrhoea"],
    &["mucorrhoea"],
];

pub(crate) static ENTRY_MUCOSE_13290817895984668630: VariantsMap =
    [&["mucose"], &["mucosae"], &["mucosae"], &["mucosae"]];

pub(crate) static ENTRY_MULTICOLOREDDER_1814659508380879098: VariantsMap = [
    &["multicoloredder"],
    &["multicolouredder"],
    &["multicolouredder"],
    &["multicolouredder"],
];

pub(crate) static ENTRY_MULTICOLOREDDEST_12879211592969011974: VariantsMap = [
    &["multicoloreddest"],
    &["multicoloureddest"],
    &["multicoloureddest"],
    &["multicoloureddest"],
];

pub(crate) static ENTRY_MULTICOLORED_12103500635627536666: VariantsMap = [
    &["multicolored"],
    &["multicoloured"],
    &["multicoloured"],
    &["multicoloured"],
];

pub(crate) static ENTRY_MULTICOLOROUS_17436796182494464863: VariantsMap = [
    &["multicolorous"],
    &["multicolourous"],
    &["multicolourous"],
    &["multicolourous"],
];

pub(crate) static ENTRY_MULTICOLORS_10160586035565921447: VariantsMap = [
    &["multicolors"],
    &["multicolours"],
    &["multicolours"],
    &["multicolours"],
];

pub(crate) static ENTRY_MULTICOLOR_3173114956166714023: VariantsMap = [
    &["multicolor"],
    &["multicolour"],
    &["multicolour"],
    &["multicolour"],
];

pub(crate) static ENTRY_MULTIFIBEREDS_15651140180032813198: VariantsMap = [
    &["multifibereds"],
    &["multifibreds"],
    &["multifibreds"],
    &["multifibreds"],
];

pub(crate) static ENTRY_MULTIFIBERED_9777656427319858043: VariantsMap = [
    &["multifibered"],
    &["multifibred"],
    &["multifibred"],
    &["multifibred"],
];

pub(crate) static ENTRY_MULTILEVELED_13761925714020978018: VariantsMap = [
    &["multileveled"],
    &["multilevelled"],
    &["multilevelled"],
    &["multilevelled"],
];

pub(crate) static ENTRY_MUNICIPALIZATIONS_1982383937788912890: VariantsMap = [
    &["municipalizations"],
    &["municipalisations"],
    &["municipalizations"],
    &["municipalisations"],
];

pub(crate) static ENTRY_MUNICIPALIZATION_13296817045590651682: VariantsMap = [
    &["municipalization"],
    &["municipalisation"],
    &["municipalization"],
    &["municipalisation"],
];

pub(crate) static ENTRY_MUNICIPALIZED_1893539661807241403: VariantsMap = [
    &["municipalized"],
    &["municipalised"],
    &["municipalized"],
    &["municipalised"],
];

pub(crate) static ENTRY_MUNICIPALIZERS_15751974184161708637: VariantsMap = [
    &["municipalizers"],
    &["municipalisers"],
    &["municipalizers"],
    &["municipalisers"],
];

pub(crate) static ENTRY_MUNICIPALIZER_8397559197205255552: VariantsMap = [
    &["municipalizer"],
    &["municipaliser"],
    &["municipalizer"],
    &["municipaliser"],
];

pub(crate) static ENTRY_MUNICIPALIZES_8777169176721386892: VariantsMap = [
    &["municipalizes"],
    &["municipalises"],
    &["municipalizes"],
    &["municipalises"],
];

pub(crate) static ENTRY_MUNICIPALIZE_13998151355165326582: VariantsMap = [
    &["municipalize"],
    &["municipalise"],
    &["municipalize"],
    &["municipalise"],
];

pub(crate) static ENTRY_MUNICIPALIZING_6572106513172195095: VariantsMap = [
    &["municipalizing"],
    &["municipalising"],
    &["municipalizing"],
    &["municipalising"],
];

pub(crate) static ENTRY_MURENAS_18309887665811878489: VariantsMap =
    [&["murenas"], &["muraenas"], &["muraenas"], &["muraenas"]];

pub(crate) static ENTRY_MURENA_3602800291326863112: VariantsMap =
    [&["murena"], &["muraena"], &["muraena"], &["muraena"]];

pub(crate) static ENTRY_MUSCULARIZES_13145618825512982567: VariantsMap = [
    &["muscularizes"],
    &["muscularises"],
    &["muscularizes"],
    &["muscularises"],
];

pub(crate) static ENTRY_MUSCULARIZE_2217027534398923764: VariantsMap = [
    &["muscularize"],
    &["muscularise"],
    &["muscularize"],
    &["muscularise"],
];

pub(crate) static ENTRY_MUSEUMIZES_6190118461441026569: VariantsMap = [
    &["museumizes"],
    &["museumises"],
    &["museumizes"],
    &["museumises"],
];

pub(crate) static ENTRY_MUSEUMIZE_1968563834894716277: VariantsMap = [
    &["museumize"],
    &["museumise"],
    &["museumize"],
    &["museumise"],
];

pub(crate) static ENTRY_MUSICALIZATIONS_7745580515258970558: VariantsMap = [
    &["musicalizations"],
    &["musicalisations"],
    &["musicalizations"],
    &["musicalisations"],
];

pub(crate) static ENTRY_MUSICALIZATION_6023814984289211559: VariantsMap = [
    &["musicalization"],
    &["musicalisation"],
    &["musicalization"],
    &["musicalisation"],
];

pub(crate) static ENTRY_MUSICALIZED_12507869883696493968: VariantsMap = [
    &["musicalized"],
    &["musicalised"],
    &["musicalized"],
    &["musicalised"],
];

pub(crate) static ENTRY_MUSICALIZES_7781710158440353995: VariantsMap = [
    &["musicalizes"],
    &["musicalises"],
    &["musicalizes"],
    &["musicalises"],
];

pub(crate) static ENTRY_MUSICALIZE_12036502854257975396: VariantsMap = [
    &["musicalize"],
    &["musicalise"],
    &["musicalize"],
    &["musicalise"],
];

pub(crate) static ENTRY_MUSICALIZING_225857687349487255: VariantsMap = [
    &["musicalizing"],
    &["musicalising"],
    &["musicalizing"],
    &["musicalising"],
];

pub(crate) static ENTRY_MUSTACHED_2746912378249692800: VariantsMap = [
    &["mustached"],
    &["moustached"],
    &["moustached"],
    &["moustached"],
];

pub(crate) static ENTRY_MUSTACHES_1764222008694028144: VariantsMap = [
    &["mustaches"],
    &["moustaches"],
    &["moustaches"],
    &["moustaches"],
];

pub(crate) static ENTRY_MUSTACHE_14138320497461763274: VariantsMap = [
    &["mustache"],
    &["moustache"],
    &["moustache"],
    &["moustache"],
];

pub(crate) static ENTRY_MUTAGENIZED_17026143764789605127: VariantsMap = [
    &["mutagenized"],
    &["mutagenised"],
    &["mutagenized"],
    &["mutagenised"],
];

pub(crate) static ENTRY_MUTAGENIZES_15664626304885678569: VariantsMap = [
    &["mutagenizes"],
    &["mutagenises"],
    &["mutagenizes"],
    &["mutagenises"],
];

pub(crate) static ENTRY_MUTAGENIZE_13759825348433434239: VariantsMap = [
    &["mutagenize"],
    &["mutagenise"],
    &["mutagenize"],
    &["mutagenise"],
];

pub(crate) static ENTRY_MUTAGENIZING_9072964483829135116: VariantsMap = [
    &["mutagenizing"],
    &["mutagenising"],
    &["mutagenizing"],
    &["mutagenising"],
];

pub(crate) static ENTRY_MUTUALIZATIONS_1794203952948700713: VariantsMap = [
    &["mutualizations"],
    &["mutualisations"],
    &["mutualizations"],
    &["mutualisations"],
];

pub(crate) static ENTRY_MUTUALIZATION_2181481883879803980: VariantsMap = [
    &["mutualization"],
    &["mutualisation"],
    &["mutualization"],
    &["mutualisation"],
];

pub(crate) static ENTRY_MUTUALIZED_4053112456469320411: VariantsMap = [
    &["mutualized"],
    &["mutualised"],
    &["mutualized"],
    &["mutualised"],
];

pub(crate) static ENTRY_MUTUALIZES_7068244903051623915: VariantsMap = [
    &["mutualizes"],
    &["mutualises"],
    &["mutualizes"],
    &["mutualises"],
];

pub(crate) static ENTRY_MUTUALIZE_10015739606322901839: VariantsMap = [
    &["mutualize"],
    &["mutualise"],
    &["mutualize"],
    &["mutualise"],
];

pub(crate) static ENTRY_MUTUALIZING_17949149122720669838: VariantsMap = [
    &["mutualizing"],
    &["mutualising"],
    &["mutualizing"],
    &["mutualising"],
];

pub(crate) static ENTRY_MYCOHEMIA_2984875008205372900: VariantsMap = [
    &["mycohemia"],
    &["mycohaemia"],
    &["mycohaemia"],
    &["mycohaemia"],
];

pub(crate) static ENTRY_MYELINIZATIONS_12624078092966683363: VariantsMap = [
    &["myelinizations"],
    &["myelinisations"],
    &["myelinizations"],
    &["myelinisations"],
];

pub(crate) static ENTRY_MYELINIZATION_8949840965904168512: VariantsMap = [
    &["myelinization"],
    &["myelinisation"],
    &["myelinization"],
    &["myelinisation"],
];

pub(crate) static ENTRY_MYELOCELE_18333296943677670966: VariantsMap = [
    &["myelocele"],
    &["myelocoele"],
    &["myelocoele"],
    &["myelocoele"],
];

pub(crate) static ENTRY_MYELOCYTHEMIA_1755047617775883552: VariantsMap = [
    &["myelocythemia"],
    &["myelocythaemia"],
    &["myelocythaemia"],
    &["myelocythaemia"],
];

pub(crate) static ENTRY_MYLONITIZATIONS_14425994255902394728: VariantsMap = [
    &["mylonitizations"],
    &["mylonitisations"],
    &["mylonitizations"],
    &["mylonitisations"],
];

pub(crate) static ENTRY_MYLONITIZATION_4418648514064972367: VariantsMap = [
    &["mylonitization"],
    &["mylonitisation"],
    &["mylonitization"],
    &["mylonitisation"],
];

pub(crate) static ENTRY_MYLONITIZED_7329838352739442602: VariantsMap = [
    &["mylonitized"],
    &["mylonitised"],
    &["mylonitized"],
    &["mylonitised"],
];

pub(crate) static ENTRY_MYLONITIZES_5749138435299478867: VariantsMap = [
    &["mylonitizes"],
    &["mylonitises"],
    &["mylonitizes"],
    &["mylonitises"],
];

pub(crate) static ENTRY_MYLONITIZE_4400772467779308928: VariantsMap = [
    &["mylonitize"],
    &["mylonitise"],
    &["mylonitize"],
    &["mylonitise"],
];

pub(crate) static ENTRY_MYLONITIZING_6531689896571343856: VariantsMap = [
    &["mylonitizing"],
    &["mylonitising"],
    &["mylonitizing"],
    &["mylonitising"],
];

pub(crate) static ENTRY_MYOCELE_2113838931852125220: VariantsMap =
    [&["myocele"], &["myocoele"], &["myocoele"], &["myocoele"]];

pub(crate) static ENTRY_MYOHEMATIN_5507843415397979353: VariantsMap = [
    &["myohematin"],
    &["myohaematin"],
    &["myohaematin"],
    &["myohaematin"],
];

pub(crate) static ENTRY_MYRIALITER_2130498984813843028: VariantsMap = [
    &["myrialiter"],
    &["myrialitre"],
    &["myrialitre"],
    &["myrialitre"],
];

pub(crate) static ENTRY_MYRIAMETER_13815643917255154020: VariantsMap = [
    &["myriameter"],
    &["myriametre"],
    &["myriametre"],
    &["myriametre"],
];

pub(crate) static ENTRY_MYSTICIZES_16303159112289723878: VariantsMap = [
    &["mysticizes"],
    &["mysticises"],
    &["mysticizes"],
    &["mysticises"],
];

pub(crate) static ENTRY_MYSTICIZE_3876757555982084725: VariantsMap = [
    &["mysticize"],
    &["mysticise"],
    &["mysticize"],
    &["mysticise"],
];

pub(crate) static ENTRY_MYTHICIZATION_17936354132540285569: VariantsMap = [
    &["mythicization"],
    &["mythicisation"],
    &["mythicization"],
    &["mythicisation"],
];

pub(crate) static ENTRY_MYTHICIZED_11662179048722869017: VariantsMap = [
    &["mythicized"],
    &["mythicised"],
    &["mythicized"],
    &["mythicised"],
];

pub(crate) static ENTRY_MYTHICIZERS_2218909918152762607: VariantsMap = [
    &["mythicizers"],
    &["mythicisers"],
    &["mythicizers"],
    &["mythicisers"],
];

pub(crate) static ENTRY_MYTHICIZER_11441938160492625382: VariantsMap = [
    &["mythicizer"],
    &["mythiciser"],
    &["mythicizer"],
    &["mythiciser"],
];

pub(crate) static ENTRY_MYTHICIZES_9101844747788591414: VariantsMap = [
    &["mythicizes"],
    &["mythicises"],
    &["mythicizes"],
    &["mythicises"],
];

pub(crate) static ENTRY_MYTHICIZE_15101061579084626306: VariantsMap = [
    &["mythicize"],
    &["mythicise"],
    &["mythicize"],
    &["mythicise"],
];

pub(crate) static ENTRY_MYTHICIZING_8015028542255723699: VariantsMap = [
    &["mythicizing"],
    &["mythicising"],
    &["mythicizing"],
    &["mythicising"],
];

pub(crate) static ENTRY_MYTHIZED_17688103185943122949: VariantsMap =
    [&["mythized"], &["mythised"], &["mythized"], &["mythised"]];

pub(crate) static ENTRY_MYTHIZES_15782993228179635485: VariantsMap =
    [&["mythizes"], &["mythises"], &["mythizes"], &["mythises"]];

pub(crate) static ENTRY_MYTHIZE_8683869589765306927: VariantsMap =
    [&["mythize"], &["mythise"], &["mythize"], &["mythise"]];

pub(crate) static ENTRY_MYTHIZING_9315513939397212063: VariantsMap = [
    &["mythizing"],
    &["mythising"],
    &["mythizing"],
    &["mythising"],
];

pub(crate) static ENTRY_MYTHOLOGIZATIONS_2783311720016567931: VariantsMap = [
    &["mythologizations"],
    &["mythologisations"],
    &["mythologizations"],
    &["mythologisations"],
];

pub(crate) static ENTRY_MYTHOLOGIZATION_14864001500968688244: VariantsMap = [
    &["mythologization"],
    &["mythologisation"],
    &["mythologization"],
    &["mythologisation"],
];

pub(crate) static ENTRY_MYTHOLOGIZED_428065733344575408: VariantsMap = [
    &["mythologized"],
    &["mythologised"],
    &["mythologized"],
    &["mythologised"],
];

pub(crate) static ENTRY_MYTHOLOGIZERS_12949952831045609835: VariantsMap = [
    &["mythologizers"],
    &["mythologisers"],
    &["mythologizers"],
    &["mythologisers"],
];

pub(crate) static ENTRY_MYTHOLOGIZER_5981916303789676389: VariantsMap = [
    &["mythologizer"],
    &["mythologiser"],
    &["mythologizer"],
    &["mythologiser"],
];

pub(crate) static ENTRY_MYTHOLOGIZES_10098277791216764614: VariantsMap = [
    &["mythologizes"],
    &["mythologises"],
    &["mythologizes"],
    &["mythologises"],
];

pub(crate) static ENTRY_MYTHOLOGIZE_17851220199810661728: VariantsMap = [
    &["mythologize"],
    &["mythologise"],
    &["mythologize"],
    &["mythologise"],
];

pub(crate) static ENTRY_MYTHOLOGIZING_5599630321255412519: VariantsMap = [
    &["mythologizing"],
    &["mythologising"],
    &["mythologizing"],
    &["mythologising"],
];

pub(crate) static ENTRY_MYTHOPEIC_2516977976434896705: VariantsMap = [
    &["mythopeic"],
    &["mythopoeic"],
    &["mythopoeic"],
    &["mythopoeic"],
];

pub(crate) static ENTRY_MYTHOPEIST_12174992698446027521: VariantsMap = [
    &["mythopeist"],
    &["mythopoeist"],
    &["mythopoeist"],
    &["mythopoeist"],
];

pub(crate) static ENTRY_MYTHOPOETIZED_11191151156378454201: VariantsMap = [
    &["mythopoetized"],
    &["mythopoetised"],
    &["mythopoetized"],
    &["mythopoetised"],
];

pub(crate) static ENTRY_MYTHOPOETIZE_241863482006487994: VariantsMap = [
    &["mythopoetize"],
    &["mythopoetise"],
    &["mythopoetize"],
    &["mythopoetise"],
];

pub(crate) static ENTRY_MYTHOPOETIZING_9507303258741791727: VariantsMap = [
    &["mythopoetizing"],
    &["mythopoetising"],
    &["mythopoetizing"],
    &["mythopoetising"],
];

pub(crate) static ENTRY_MYXAMEBA_14643433663329128144: VariantsMap = [
    &["myxameba"],
    &["myxamoeba"],
    &["myxamoeba"],
    &["myxamoeba"],
];

pub(crate) static ENTRY_MYXEDEMAS_15468056638103415791: VariantsMap = [
    &["myxedemas"],
    &["myxoedemas"],
    &["myxedemas"],
    &["myxoedemas"],
];

pub(crate) static ENTRY_MYXEDEMATOUS_15622444540288493744: VariantsMap = [
    &["myxedematous"],
    &["myxoedematous"],
    &["myxoedematous"],
    &["myxoedematous"],
];

pub(crate) static ENTRY_MYXEDEMA_1555701545725524849: VariantsMap =
    [&["myxedema"], &["myxoedema"], &["myxedema"], &["myxoedema"]];

pub(crate) static ENTRY_MYXEDEMIC_9553375441668912393: VariantsMap = [
    &["myxedemic"],
    &["myxoedemic"],
    &["myxoedemic"],
    &["myxoedemic"],
];

pub(crate) static ENTRY_MYXEMIA_1141130721765613596: VariantsMap =
    [&["myxemia"], &["myxaemia"], &["myxaemia"], &["myxaemia"]];

pub(crate) static ENTRY_NABATEANS_569710781128463273: VariantsMap = [
    &["nabateans"],
    &["nabataeans"],
    &["nabataeans"],
    &["nabataeans"],
];

pub(crate) static ENTRY_NABATHEAN_18274860619838246891: VariantsMap = [
    &["nabathean"],
    &["nabathaean"],
    &["nabathaean"],
    &["nabathaean"],
];

pub(crate) static ENTRY_NAKEDIZES_9777760669263216460: VariantsMap = [
    &["nakedizes"],
    &["nakedises"],
    &["nakedizes"],
    &["nakedises"],
];

pub(crate) static ENTRY_NAKEDIZE_16788050557980236016: VariantsMap =
    [&["nakedize"], &["nakedise"], &["nakedize"], &["nakedise"]];

pub(crate) static ENTRY_NANIZATIONS_9741997057394079383: VariantsMap = [
    &["nanizations"],
    &["nanisations"],
    &["nanizations"],
    &["nanisations"],
];

pub(crate) static ENTRY_NANIZATION_6965256141011755320: VariantsMap = [
    &["nanization"],
    &["nanisation"],
    &["nanization"],
    &["nanisation"],
];

pub(crate) static ENTRY_NANOGRAMS_17642704447694885166: VariantsMap = [
    &["nanograms"],
    &["nanograms"],
    &["nanograms"],
    &["nanograms"],
];

pub(crate) static ENTRY_NANOGRAM_11942860163821644329: VariantsMap =
    [&["nanogram"], &["nanogram"], &["nanogram"], &["nanogram"]];

pub(crate) static ENTRY_NANOMETERS_14532694249183942048: VariantsMap = [
    &["nanometers"],
    &["nanometres"],
    &["nanometres"],
    &["nanometres"],
];

pub(crate) static ENTRY_NANOMETER_15050479722914391248: VariantsMap = [
    &["nanometer"],
    &["nanometre"],
    &["nanometre"],
    &["nanometre"],
];

pub(crate) static ENTRY_NAPEA_2972076182375748936: VariantsMap =
    [&["napea"], &["napaea"], &["napaea"], &["napaea"]];

pub(crate) static ENTRY_NAPHTHALIZED_1033199897067261368: VariantsMap = [
    &["naphthalized"],
    &["naphthalised"],
    &["naphthalized"],
    &["naphthalised"],
];

pub(crate) static ENTRY_NAPHTHALIZES_5804795985920271479: VariantsMap = [
    &["naphthalizes"],
    &["naphthalises"],
    &["naphthalizes"],
    &["naphthalises"],
];

pub(crate) static ENTRY_NAPHTHALIZE_3036249934484436937: VariantsMap = [
    &["naphthalize"],
    &["naphthalise"],
    &["naphthalize"],
    &["naphthalise"],
];

pub(crate) static ENTRY_NAPHTHALIZING_16162836589293692810: VariantsMap = [
    &["naphthalizing"],
    &["naphthalising"],
    &["naphthalizing"],
    &["naphthalising"],
];

pub(crate) static ENTRY_NAPOLEONIZES_4379534235679670079: VariantsMap = [
    &["napoleonizes"],
    &["napoleonises"],
    &["napoleonizes"],
    &["napoleonises"],
];

pub(crate) static ENTRY_NAPOLEONIZE_3662659967404924605: VariantsMap = [
    &["napoleonize"],
    &["napoleonise"],
    &["napoleonize"],
    &["napoleonise"],
];

pub(crate) static ENTRY_NARCOTIZATIONS_8442277263581755114: VariantsMap = [
    &["narcotizations"],
    &["narcotisations"],
    &["narcotizations"],
    &["narcotisations"],
];

pub(crate) static ENTRY_NARCOTIZATION_12066717855128327454: VariantsMap = [
    &["narcotization"],
    &["narcotisation"],
    &["narcotization"],
    &["narcotisation"],
];

pub(crate) static ENTRY_NARCOTIZED_16901265805353552450: VariantsMap = [
    &["narcotized"],
    &["narcotised"],
    &["narcotized"],
    &["narcotised"],
];

pub(crate) static ENTRY_NARCOTIZES_5310729382357568649: VariantsMap = [
    &["narcotizes"],
    &["narcotises"],
    &["narcotizes"],
    &["narcotises"],
];

pub(crate) static ENTRY_NARCOTIZE_14616380840716794484: VariantsMap = [
    &["narcotize"],
    &["narcotise"],
    &["narcotize"],
    &["narcotise"],
];

pub(crate) static ENTRY_NARCOTIZING_7516536430926503777: VariantsMap = [
    &["narcotizing"],
    &["narcotising"],
    &["narcotizing"],
    &["narcotising"],
];

pub(crate) static ENTRY_NASALIZATIONS_7277160551960333351: VariantsMap = [
    &["nasalizations"],
    &["nasalisations"],
    &["nasalizations"],
    &["nasalisations"],
];

pub(crate) static ENTRY_NASALIZATION_9447471797004510318: VariantsMap = [
    &["nasalization"],
    &["nasalisation"],
    &["nasalization"],
    &["nasalisation"],
];

pub(crate) static ENTRY_NASALIZED_1043946313139330861: VariantsMap = [
    &["nasalized"],
    &["nasalised"],
    &["nasalized"],
    &["nasalised"],
];

pub(crate) static ENTRY_NASALIZES_6487641598131144165: VariantsMap = [
    &["nasalizes"],
    &["nasalises"],
    &["nasalizes"],
    &["nasalises"],
];

pub(crate) static ENTRY_NASALIZE_76311075047194658: VariantsMap =
    [&["nasalize"], &["nasalise"], &["nasalize"], &["nasalise"]];

pub(crate) static ENTRY_NASALIZING_2082301516066873014: VariantsMap = [
    &["nasalizing"],
    &["nasalising"],
    &["nasalizing"],
    &["nasalising"],
];

pub(crate) static ENTRY_NATIONALIZATIONS_5281594635957507193: VariantsMap = [
    &["nationalizations"],
    &["nationalisations"],
    &["nationalizations"],
    &["nationalisations"],
];

pub(crate) static ENTRY_NATIONALIZATION_16093349884516853513: VariantsMap = [
    &["nationalization"],
    &["nationalisation"],
    &["nationalization"],
    &["nationalisation"],
];

pub(crate) static ENTRY_NATIONALIZED_14123403696319407671: VariantsMap = [
    &["nationalized"],
    &["nationalised"],
    &["nationalized"],
    &["nationalised"],
];

pub(crate) static ENTRY_NATIONALIZERS_13336757627588867669: VariantsMap = [
    &["nationalizers"],
    &["nationalisers"],
    &["nationalizers"],
    &["nationalisers"],
];

pub(crate) static ENTRY_NATIONALIZER_4646678062279574784: VariantsMap = [
    &["nationalizer"],
    &["nationaliser"],
    &["nationalizer"],
    &["nationaliser"],
];

pub(crate) static ENTRY_NATIONALIZES_9931517547348470217: VariantsMap = [
    &["nationalizes"],
    &["nationalises"],
    &["nationalizes"],
    &["nationalises"],
];

pub(crate) static ENTRY_NATIONALIZE_1535875549943010403: VariantsMap = [
    &["nationalize"],
    &["nationalise"],
    &["nationalize"],
    &["nationalise"],
];

pub(crate) static ENTRY_NATIONALIZING_154708228623797355: VariantsMap = [
    &["nationalizing"],
    &["nationalising"],
    &["nationalizing"],
    &["nationalising"],
];

pub(crate) static ENTRY_NATURALIZATIONS_15146375781211350844: VariantsMap = [
    &["naturalizations"],
    &["naturalisations"],
    &["naturalizations"],
    &["naturalisations"],
];

pub(crate) static ENTRY_NATURALIZATION_901934936058317884: VariantsMap = [
    &["naturalization"],
    &["naturalisation"],
    &["naturalization"],
    &["naturalisation"],
];

pub(crate) static ENTRY_NATURALIZED_4952898848561703349: VariantsMap = [
    &["naturalized"],
    &["naturalised"],
    &["naturalized"],
    &["naturalised"],
];

pub(crate) static ENTRY_NATURALIZERS_10150306956216872864: VariantsMap = [
    &["naturalizers"],
    &["naturalisers"],
    &["naturalizers"],
    &["naturalisers"],
];

pub(crate) static ENTRY_NATURALIZER_13986726448266401105: VariantsMap = [
    &["naturalizer"],
    &["naturaliser"],
    &["naturalizer"],
    &["naturaliser"],
];

pub(crate) static ENTRY_NATURALIZES_7464268429055724811: VariantsMap = [
    &["naturalizes"],
    &["naturalises"],
    &["naturalizes"],
    &["naturalises"],
];

pub(crate) static ENTRY_NATURALIZE_15129142042727649412: VariantsMap = [
    &["naturalize"],
    &["naturalise"],
    &["naturalize"],
    &["naturalise"],
];

pub(crate) static ENTRY_NATURALIZING_7589140168222731708: VariantsMap = [
    &["naturalizing"],
    &["naturalising"],
    &["naturalizing"],
    &["naturalising"],
];

pub(crate) static ENTRY_NATURIZES_15311848507319444172: VariantsMap = [
    &["naturizes"],
    &["naturises"],
    &["naturizes"],
    &["naturises"],
];

pub(crate) static ENTRY_NATURIZE_17136190831997236970: VariantsMap =
    [&["naturize"], &["naturise"], &["naturize"], &["naturise"]];

pub(crate) static ENTRY_NEBULARIZATIONS_16140717010768565468: VariantsMap = [
    &["nebularizations"],
    &["nebularisations"],
    &["nebularizations"],
    &["nebularisations"],
];

pub(crate) static ENTRY_NEBULARIZATION_3258696472450942938: VariantsMap = [
    &["nebularization"],
    &["nebularisation"],
    &["nebularization"],
    &["nebularisation"],
];

pub(crate) static ENTRY_NEBULARIZES_7468940411162471977: VariantsMap = [
    &["nebularizes"],
    &["nebularises"],
    &["nebularizes"],
    &["nebularises"],
];

pub(crate) static ENTRY_NEBULARIZE_419103860158710298: VariantsMap = [
    &["nebularize"],
    &["nebularise"],
    &["nebularize"],
    &["nebularise"],
];

pub(crate) static ENTRY_NEBULIZATIONS_13271366314956373563: VariantsMap = [
    &["nebulizations"],
    &["nebulisations"],
    &["nebulizations"],
    &["nebulisations"],
];

pub(crate) static ENTRY_NEBULIZATION_1642955319706951393: VariantsMap = [
    &["nebulization"],
    &["nebulisation"],
    &["nebulization"],
    &["nebulisation"],
];

pub(crate) static ENTRY_NEBULIZED_8317403402858231652: VariantsMap = [
    &["nebulized"],
    &["nebulised"],
    &["nebulized"],
    &["nebulised"],
];

pub(crate) static ENTRY_NEBULIZERS_575364184566751247: VariantsMap = [
    &["nebulizers"],
    &["nebulisers"],
    &["nebulizers"],
    &["nebulisers"],
];

pub(crate) static ENTRY_NEBULIZER_9105631547111211944: VariantsMap = [
    &["nebulizer"],
    &["nebuliser"],
    &["nebulizer"],
    &["nebuliser"],
];

pub(crate) static ENTRY_NEBULIZES_1042694150983522129: VariantsMap = [
    &["nebulizes"],
    &["nebulises"],
    &["nebulizes"],
    &["nebulises"],
];

pub(crate) static ENTRY_NEBULIZE_897376798026210104: VariantsMap =
    [&["nebulize"], &["nebulise"], &["nebulize"], &["nebulise"]];

pub(crate) static ENTRY_NEBULIZING_9748130735255218557: VariantsMap = [
    &["nebulizing"],
    &["nebulising"],
    &["nebulizing"],
    &["nebulising"],
];

pub(crate) static ENTRY_NECREMIA_2209235602725432624: VariantsMap = [
    &["necremia"],
    &["necraemia"],
    &["necraemia"],
    &["necraemia"],
];

pub(crate) static ENTRY_NECROTIZED_16485177737821660398: VariantsMap = [
    &["necrotized"],
    &["necrotised"],
    &["necrotized"],
    &["necrotised"],
];

pub(crate) static ENTRY_NECROTIZES_6718759902100842968: VariantsMap = [
    &["necrotizes"],
    &["necrotises"],
    &["necrotizes"],
    &["necrotises"],
];

pub(crate) static ENTRY_NECROTIZE_248925496160162456: VariantsMap = [
    &["necrotize"],
    &["necrotise"],
    &["necrotize"],
    &["necrotise"],
];

pub(crate) static ENTRY_NECROTIZING_992481852800391492: VariantsMap = [
    &["necrotizing"],
    &["necrotising"],
    &["necrotizing"],
    &["necrotising"],
];

pub(crate) static ENTRY_NECTARIZED_5989083498818079168: VariantsMap = [
    &["nectarized"],
    &["nectarised"],
    &["nectarized"],
    &["nectarised"],
];

pub(crate) static ENTRY_NECTARIZES_17994754460986475766: VariantsMap = [
    &["nectarizes"],
    &["nectarises"],
    &["nectarizes"],
    &["nectarises"],
];

pub(crate) static ENTRY_NECTARIZE_16440625593515876087: VariantsMap = [
    &["nectarize"],
    &["nectarise"],
    &["nectarize"],
    &["nectarise"],
];

pub(crate) static ENTRY_NECTARIZING_7069406744718506258: VariantsMap = [
    &["nectarizing"],
    &["nectarising"],
    &["nectarizing"],
    &["nectarising"],
];

pub(crate) static ENTRY_NEEBOR_18269956267250848330: VariantsMap =
    [&["neebor"], &["neebour"], &["neebour"], &["neebour"]];

pub(crate) static ENTRY_NEENCEPHALON_979094039364233829: VariantsMap = [
    &["neencephalon"],
    &["neoencephalon"],
    &["neoencephalon"],
    &["neoencephalon"],
];

pub(crate) static ENTRY_NEER_16368651073851802940: VariantsMap =
    [&["neer"], &["nere"], &["nere"], &["nere"]];

pub(crate) static ENTRY_NEGLIGEES_4454821460830858983: VariantsMap = [
    &["negligees"],
    &["negligees"],
    &["negligees"],
    &["negligees"],
];

pub(crate) static ENTRY_NEGLIGEE_12210121686392984472: VariantsMap =
    [&["negligee"], &["negligee"], &["negligee"], &["negligee"]];

pub(crate) static ENTRY_NEGRITIZED_15092433378035298133: VariantsMap = [
    &["negritized"],
    &["negritised"],
    &["negritized"],
    &["negritised"],
];

pub(crate) static ENTRY_NEGRITIZE_9210974913397215749: VariantsMap = [
    &["negritize"],
    &["negritise"],
    &["negritize"],
    &["negritise"],
];

pub(crate) static ENTRY_NEGRITIZING_18411327602026760303: VariantsMap = [
    &["negritizing"],
    &["negritising"],
    &["negritizing"],
    &["negritising"],
];

pub(crate) static ENTRY_NEGROIZATIONS_3017888884521311143: VariantsMap = [
    &["negroizations"],
    &["negroisations"],
    &["negroizations"],
    &["negroisations"],
];

pub(crate) static ENTRY_NEGROIZATION_734165123169837681: VariantsMap = [
    &["negroization"],
    &["negroisation"],
    &["negroization"],
    &["negroisation"],
];

pub(crate) static ENTRY_NEGROIZED_8511374797642149972: VariantsMap = [
    &["negroized"],
    &["negroised"],
    &["negroized"],
    &["negroised"],
];

pub(crate) static ENTRY_NEGROIZES_2943242169344115772: VariantsMap = [
    &["negroizes"],
    &["negroises"],
    &["negroizes"],
    &["negroises"],
];

pub(crate) static ENTRY_NEGROIZE_676151142023635085: VariantsMap =
    [&["negroize"], &["negroise"], &["negroize"], &["negroise"]];

pub(crate) static ENTRY_NEGROIZING_12007313249945227181: VariantsMap = [
    &["negroizing"],
    &["negroising"],
    &["negroizing"],
    &["negroising"],
];

pub(crate) static ENTRY_NEIGHBORED_1453065315242132972: VariantsMap = [
    &["neighbored"],
    &["neighboured"],
    &["neighboured"],
    &["neighboured"],
];

pub(crate) static ENTRY_NEIGHBORERS_3234519608682158967: VariantsMap = [
    &["neighborers"],
    &["neighbourers"],
    &["neighbourers"],
    &["neighbourers"],
];

pub(crate) static ENTRY_NEIGHBORER_13012747299862986620: VariantsMap = [
    &["neighborer"],
    &["neighbourer"],
    &["neighbourer"],
    &["neighbourer"],
];

pub(crate) static ENTRY_NEIGHBORESS_9273358629774412394: VariantsMap = [
    &["neighboress"],
    &["neighbouress"],
    &["neighbouress"],
    &["neighbouress"],
];

pub(crate) static ENTRY_NEIGHBORHOODS_13147261698969498299: VariantsMap = [
    &["neighborhoods"],
    &["neighbourhoods"],
    &["neighbourhoods"],
    &["neighbourhoods"],
];

pub(crate) static ENTRY_NEIGHBORHOOD_13179978688818671082: VariantsMap = [
    &["neighborhood"],
    &["neighbourhood"],
    &["neighbourhood"],
    &["neighbourhood"],
];

pub(crate) static ENTRY_NEIGHBORINGS_12373492488609025236: VariantsMap = [
    &["neighborings"],
    &["neighbourings"],
    &["neighbourings"],
    &["neighbourings"],
];

pub(crate) static ENTRY_NEIGHBORING_11318750292661541645: VariantsMap = [
    &["neighboring"],
    &["neighbouring"],
    &["neighbouring"],
    &["neighbouring"],
];

pub(crate) static ENTRY_NEIGHBORLESSER_15998195990911091581: VariantsMap = [
    &["neighborlesser"],
    &["neighbourlesser"],
    &["neighbourlesser"],
    &["neighbourlesser"],
];

pub(crate) static ENTRY_NEIGHBORLESSEST_16873799645280627574: VariantsMap = [
    &["neighborlessest"],
    &["neighbourlessest"],
    &["neighbourlessest"],
    &["neighbourlessest"],
];

pub(crate) static ENTRY_NEIGHBORLESSES_17062516910133863736: VariantsMap = [
    &["neighborlesses"],
    &["neighbourlesses"],
    &["neighbourlesses"],
    &["neighbourlesses"],
];

pub(crate) static ENTRY_NEIGHBORLESS_16958265927368217965: VariantsMap = [
    &["neighborless"],
    &["neighbourless"],
    &["neighbourless"],
    &["neighbourless"],
];

pub(crate) static ENTRY_NEIGHBORLIER_5964029050832264412: VariantsMap = [
    &["neighborlier"],
    &["neighbourlier"],
    &["neighbourlier"],
    &["neighbourlier"],
];

pub(crate) static ENTRY_NEIGHBORLIEST_6163034189378516769: VariantsMap = [
    &["neighborliest"],
    &["neighbourliest"],
    &["neighbourliest"],
    &["neighbourliest"],
];

pub(crate) static ENTRY_NEIGHBORLIKES_11602580781433436933: VariantsMap = [
    &["neighborlikes"],
    &["neighbourlikes"],
    &["neighbourlikes"],
    &["neighbourlikes"],
];

pub(crate) static ENTRY_NEIGHBORLIKE_13851941964575482888: VariantsMap = [
    &["neighborlike"],
    &["neighbourlike"],
    &["neighbourlike"],
    &["neighbourlike"],
];

pub(crate) static ENTRY_NEIGHBORLINESSES_15429938495896734143: VariantsMap = [
    &["neighborlinesses"],
    &["neighbourlinesses"],
    &["neighbourlinesses"],
    &["neighbourlinesses"],
];

pub(crate) static ENTRY_NEIGHBORLINESS_10203381514206777935: VariantsMap = [
    &["neighborliness"],
    &["neighbourliness"],
    &["neighbourliness"],
    &["neighbourliness"],
];

pub(crate) static ENTRY_NEIGHBORLY_1379658281742193125: VariantsMap = [
    &["neighborly"],
    &["neighbourly"],
    &["neighbourly"],
    &["neighbourly"],
];

pub(crate) static ENTRY_NEIGHBORSHIPS_5522605364924311025: VariantsMap = [
    &["neighborships"],
    &["neighbourships"],
    &["neighbourships"],
    &["neighbourships"],
];

pub(crate) static ENTRY_NEIGHBORSHIP_14837261908353670667: VariantsMap = [
    &["neighborship"],
    &["neighbourship"],
    &["neighbourship"],
    &["neighbourship"],
];

pub(crate) static ENTRY_NEIGHBORS_11834946978992293791: VariantsMap = [
    &["neighbors"],
    &["neighbours"],
    &["neighbours"],
    &["neighbours"],
];

pub(crate) static ENTRY_NEIGHBOR_9223532537551591313: VariantsMap = [
    &["neighbor"],
    &["neighbour"],
    &["neighbour"],
    &["neighbour"],
];

pub(crate) static ENTRY_NEOGEAL_16251425573587958366: VariantsMap =
    [&["neogeal"], &["neogaeal"], &["neogaeal"], &["neogaeal"]];

pub(crate) static ENTRY_NEOGEAN_12601233030585408024: VariantsMap =
    [&["neogean"], &["neogaean"], &["neogaean"], &["neogaean"]];

pub(crate) static ENTRY_NEOGEA_1284680222354583533: VariantsMap =
    [&["neogea"], &["neogaea"], &["neogaea"], &["neogaea"]];

pub(crate) static ENTRY_NEOGEIC_5021902121890301728: VariantsMap =
    [&["neogeic"], &["neogaeic"], &["neogaeic"], &["neogaeic"]];

pub(crate) static ENTRY_NEOLOGIZATION_1831850649569469075: VariantsMap = [
    &["neologization"],
    &["neologisation"],
    &["neologization"],
    &["neologisation"],
];

pub(crate) static ENTRY_NEOLOGIZED_9476639829063323419: VariantsMap = [
    &["neologized"],
    &["neologised"],
    &["neologized"],
    &["neologised"],
];

pub(crate) static ENTRY_NEOLOGIZES_2611172356463477981: VariantsMap = [
    &["neologizes"],
    &["neologises"],
    &["neologizes"],
    &["neologises"],
];

pub(crate) static ENTRY_NEOLOGIZE_5094848877824842155: VariantsMap = [
    &["neologize"],
    &["neologise"],
    &["neologize"],
    &["neologise"],
];

pub(crate) static ENTRY_NEOLOGIZING_6439029299467534255: VariantsMap = [
    &["neologizing"],
    &["neologising"],
    &["neologizing"],
    &["neologising"],
];

pub(crate) static ENTRY_NEOPAGANIZED_10850521355046515785: VariantsMap = [
    &["neopaganized"],
    &["neopaganised"],
    &["neopaganized"],
    &["neopaganised"],
];

pub(crate) static ENTRY_NEOPAGANIZES_6716210077285627581: VariantsMap = [
    &["neopaganizes"],
    &["neopaganises"],
    &["neopaganizes"],
    &["neopaganises"],
];

pub(crate) static ENTRY_NEOPAGANIZE_17137797559492162954: VariantsMap = [
    &["neopaganize"],
    &["neopaganise"],
    &["neopaganize"],
    &["neopaganise"],
];

pub(crate) static ENTRY_NEOPAGANIZING_7247721295390537710: VariantsMap = [
    &["neopaganizing"],
    &["neopaganising"],
    &["neopaganizing"],
    &["neopaganising"],
];

pub(crate) static ENTRY_NEOTERIZED_5721029857030207574: VariantsMap = [
    &["neoterized"],
    &["neoterised"],
    &["neoterized"],
    &["neoterised"],
];

pub(crate) static ENTRY_NEOTERIZES_8732588249524157867: VariantsMap = [
    &["neoterizes"],
    &["neoterises"],
    &["neoterizes"],
    &["neoterises"],
];

pub(crate) static ENTRY_NEOTERIZE_5399698345453637528: VariantsMap = [
    &["neoterize"],
    &["neoterise"],
    &["neoterize"],
    &["neoterise"],
];

pub(crate) static ENTRY_NEOTERIZING_10159918373796657938: VariantsMap = [
    &["neoterizing"],
    &["neoterising"],
    &["neoterizing"],
    &["neoterising"],
];

pub(crate) static ENTRY_NEPHRECTOMIZED_3535158641297367003: VariantsMap = [
    &["nephrectomized"],
    &["nephrectomised"],
    &["nephrectomized"],
    &["nephrectomised"],
];

pub(crate) static ENTRY_NEPHRECTOMIZE_5590748123455365447: VariantsMap = [
    &["nephrectomize"],
    &["nephrectomise"],
    &["nephrectomize"],
    &["nephrectomise"],
];

pub(crate) static ENTRY_NEPHRECTOMIZING_4545639191156251970: VariantsMap = [
    &["nephrectomizing"],
    &["nephrectomising"],
    &["nephrectomizing"],
    &["nephrectomising"],
];

pub(crate) static ENTRY_NEPHROCELE_4864421137682686009: VariantsMap = [
    &["nephrocele"],
    &["nephrocoele"],
    &["nephrocoele"],
    &["nephrocoele"],
];

pub(crate) static ENTRY_NEPHROTOMIZE_7557324606949473167: VariantsMap = [
    &["nephrotomize"],
    &["nephrotomise"],
    &["nephrotomize"],
    &["nephrotomise"],
];

pub(crate) static ENTRY_NESSLERIZED_6735223692031566594: VariantsMap = [
    &["nesslerized"],
    &["nesslerised"],
    &["nesslerized"],
    &["nesslerised"],
];

pub(crate) static ENTRY_NESSLERIZE_14666129395865185325: VariantsMap = [
    &["nesslerize"],
    &["nesslerise"],
    &["nesslerize"],
    &["nesslerise"],
];

pub(crate) static ENTRY_NESSLERIZING_4020314319948887274: VariantsMap = [
    &["nesslerizing"],
    &["nesslerising"],
    &["nesslerizing"],
    &["nesslerising"],
];

pub(crate) static ENTRY_NETS_165907139467352353: VariantsMap =
    [&["nets"], &["nets"], &["nets"], &["nets"]];

pub(crate) static ENTRY_NET_1634985998898472374: VariantsMap =
    [&["net"], &["net"], &["net"], &["net"]];

pub(crate) static ENTRY_NEUREPITHELIUM_15153948946044562070: VariantsMap = [
    &["neurepithelium"],
    &["neuroepithelium"],
    &["neuroepithelium"],
    &["neuroepithelium"],
];

pub(crate) static ENTRY_NEUROCELE_18314488711130096917: VariantsMap = [
    &["neurocele"],
    &["neurocoele"],
    &["neurocoele"],
    &["neurocoele"],
];

pub(crate) static ENTRY_NEUROCELIAN_7181556015461931297: VariantsMap = [
    &["neurocelian"],
    &["neurocoelian"],
    &["neurocoelian"],
    &["neurocoelian"],
];

pub(crate) static ENTRY_NEUROTICIZES_17967380009910329352: VariantsMap = [
    &["neuroticizes"],
    &["neuroticises"],
    &["neuroticizes"],
    &["neuroticises"],
];

pub(crate) static ENTRY_NEUROTICIZE_9554224556419287994: VariantsMap = [
    &["neuroticize"],
    &["neuroticise"],
    &["neuroticize"],
    &["neuroticise"],
];

pub(crate) static ENTRY_NEUTRALIZATIONS_7938385529409734858: VariantsMap = [
    &["neutralizations"],
    &["neutralisations"],
    &["neutralizations"],
    &["neutralisations"],
];

pub(crate) static ENTRY_NEUTRALIZATION_3752767150712391454: VariantsMap = [
    &["neutralization"],
    &["neutralisation"],
    &["neutralization"],
    &["neutralisation"],
];

pub(crate) static ENTRY_NEUTRALIZED_23570169514124780: VariantsMap = [
    &["neutralized"],
    &["neutralised"],
    &["neutralized"],
    &["neutralised"],
];

pub(crate) static ENTRY_NEUTRALIZERS_1000093030679533320: VariantsMap = [
    &["neutralizers"],
    &["neutralisers"],
    &["neutralizers"],
    &["neutralisers"],
];

pub(crate) static ENTRY_NEUTRALIZER_13734573167959567076: VariantsMap = [
    &["neutralizer"],
    &["neutraliser"],
    &["neutralizer"],
    &["neutraliser"],
];

pub(crate) static ENTRY_NEUTRALIZES_3865166621052534884: VariantsMap = [
    &["neutralizes"],
    &["neutralises"],
    &["neutralizes"],
    &["neutralises"],
];

pub(crate) static ENTRY_NEUTRALIZE_8250094940796239103: VariantsMap = [
    &["neutralize"],
    &["neutralise"],
    &["neutralize"],
    &["neutralise"],
];

pub(crate) static ENTRY_NEUTRALIZING_14844449700074149114: VariantsMap = [
    &["neutralizing"],
    &["neutralising"],
    &["neutralizing"],
    &["neutralising"],
];

pub(crate) static ENTRY_NEVES_8948066186077998625: VariantsMap =
    [&["neves"], &["naeves"], &["naeves"], &["naeves"]];

pub(crate) static ENTRY_NEVOID_11903217152834367665: VariantsMap =
    [&["nevoid"], &["naevoid"], &["naevoid"], &["naevoid"]];

pub(crate) static ENTRY_NEWMANIZED_9146175780378871651: VariantsMap = [
    &["newmanized"],
    &["newmanised"],
    &["newmanized"],
    &["newmanised"],
];

pub(crate) static ENTRY_NEWMANIZES_7008662780500071215: VariantsMap = [
    &["newmanizes"],
    &["newmanises"],
    &["newmanizes"],
    &["newmanises"],
];

pub(crate) static ENTRY_NEWMANIZE_4267502944050665424: VariantsMap = [
    &["newmanize"],
    &["newmanise"],
    &["newmanize"],
    &["newmanise"],
];

pub(crate) static ENTRY_NEWMANIZING_1248960014721661588: VariantsMap = [
    &["newmanizing"],
    &["newmanising"],
    &["newmanizing"],
    &["newmanising"],
];

pub(crate) static ENTRY_NEWSPAPERIZEDS_4085444114357868312: VariantsMap = [
    &["newspaperizeds"],
    &["newspaperiseds"],
    &["newspaperizeds"],
    &["newspaperiseds"],
];

pub(crate) static ENTRY_NEWSPAPERIZED_10066561383969209786: VariantsMap = [
    &["newspaperized"],
    &["newspaperised"],
    &["newspaperized"],
    &["newspaperised"],
];

pub(crate) static ENTRY_NICKELED_2598322456844726625: VariantsMap = [
    &["nickeled"],
    &["nickelled"],
    &["nickelled"],
    &["nickelled"],
];

pub(crate) static ENTRY_NICKELING_15456695821844219317: VariantsMap = [
    &["nickeling"],
    &["nickelling"],
    &["nickelling"],
    &["nickelling"],
];

pub(crate) static ENTRY_NICKELIZATIONS_12503400902645240500: VariantsMap = [
    &["nickelizations"],
    &["nickelisations"],
    &["nickelizations"],
    &["nickelisations"],
];

pub(crate) static ENTRY_NICKELIZATION_14665726966731544811: VariantsMap = [
    &["nickelization"],
    &["nickelisation"],
    &["nickelization"],
    &["nickelisation"],
];

pub(crate) static ENTRY_NICKELIZED_13993422313862972332: VariantsMap = [
    &["nickelized"],
    &["nickelised"],
    &["nickelized"],
    &["nickelised"],
];

pub(crate) static ENTRY_NICKELIZES_15031997318790044419: VariantsMap = [
    &["nickelizes"],
    &["nickelises"],
    &["nickelizes"],
    &["nickelises"],
];

pub(crate) static ENTRY_NICKELIZE_9935219708315169877: VariantsMap = [
    &["nickelize"],
    &["nickelise"],
    &["nickelize"],
    &["nickelise"],
];

pub(crate) static ENTRY_NICKELIZING_4089906927195099259: VariantsMap = [
    &["nickelizing"],
    &["nickelising"],
    &["nickelizing"],
    &["nickelising"],
];

pub(crate) static ENTRY_NICOTINIZED_11525546249126469972: VariantsMap = [
    &["nicotinized"],
    &["nicotinised"],
    &["nicotinized"],
    &["nicotinised"],
];

pub(crate) static ENTRY_NICOTINIZES_10592308588452861660: VariantsMap = [
    &["nicotinizes"],
    &["nicotinises"],
    &["nicotinizes"],
    &["nicotinises"],
];

pub(crate) static ENTRY_NICOTINIZE_15784314479049096934: VariantsMap = [
    &["nicotinize"],
    &["nicotinise"],
    &["nicotinize"],
    &["nicotinise"],
];

pub(crate) static ENTRY_NICOTINIZING_4899607697104850379: VariantsMap = [
    &["nicotinizing"],
    &["nicotinising"],
    &["nicotinizing"],
    &["nicotinising"],
];

pub(crate) static ENTRY_NIELLED_9403053863620728097: VariantsMap =
    [&["nielled"], &["nielloed"], &["nielloed"], &["nielloed"]];

pub(crate) static ENTRY_NIGER_11201071166372852882: VariantsMap =
    [&["niger"], &["nigre"], &["nigre"], &["nigre"]];

pub(crate) static ENTRY_NIGGARDIZED_9427235700634115178: VariantsMap = [
    &["niggardized"],
    &["niggardised"],
    &["niggardized"],
    &["niggardised"],
];

pub(crate) static ENTRY_NIGGARDIZES_11798686653079866433: VariantsMap = [
    &["niggardizes"],
    &["niggardises"],
    &["niggardizes"],
    &["niggardises"],
];

pub(crate) static ENTRY_NIGGARDIZE_4254244204505193934: VariantsMap = [
    &["niggardize"],
    &["niggardise"],
    &["niggardize"],
    &["niggardise"],
];

pub(crate) static ENTRY_NIGGARDIZING_3373243570534227088: VariantsMap = [
    &["niggardizing"],
    &["niggardising"],
    &["niggardizing"],
    &["niggardising"],
];

pub(crate) static ENTRY_NIGHTINGALIZES_9830470880801498295: VariantsMap = [
    &["nightingalizes"],
    &["nightingalises"],
    &["nightingalizes"],
    &["nightingalises"],
];

pub(crate) static ENTRY_NIGHTINGALIZE_17142924367808523526: VariantsMap = [
    &["nightingalize"],
    &["nightingalise"],
    &["nightingalize"],
    &["nightingalise"],
];

pub(crate) static ENTRY_NIGHTS_2853012648953157620: VariantsMap =
    [&["nights"], &["nights"], &["nights"], &["nights"]];

pub(crate) static ENTRY_NIGHT_12445825267878435538: VariantsMap =
    [&["night"], &["night"], &["night"], &["night"]];

pub(crate) static ENTRY_NIPPONIZES_6554210241154895240: VariantsMap = [
    &["nipponizes"],
    &["nipponises"],
    &["nipponizes"],
    &["nipponises"],
];

pub(crate) static ENTRY_NIPPONIZE_4579132590160165644: VariantsMap = [
    &["nipponize"],
    &["nipponise"],
    &["nipponize"],
    &["nipponise"],
];

pub(crate) static ENTRY_NITERS_15109525363766142335: VariantsMap =
    [&["niters"], &["nitres"], &["nitres"], &["nitres"]];

pub(crate) static ENTRY_NITER_11730030586484906596: VariantsMap =
    [&["niter"], &["nitre"], &["nitre"], &["nitre"]];

pub(crate) static ENTRY_NITRIDIZATIONS_2619922062168662007: VariantsMap = [
    &["nitridizations"],
    &["nitridisations"],
    &["nitridizations"],
    &["nitridisations"],
];

pub(crate) static ENTRY_NITRIDIZATION_16083845896083362416: VariantsMap = [
    &["nitridization"],
    &["nitridisation"],
    &["nitridization"],
    &["nitridisation"],
];

pub(crate) static ENTRY_NITRIDIZES_1863459397472838518: VariantsMap = [
    &["nitridizes"],
    &["nitridises"],
    &["nitridizes"],
    &["nitridises"],
];

pub(crate) static ENTRY_NITRIDIZE_13544081686934658830: VariantsMap = [
    &["nitridize"],
    &["nitridise"],
    &["nitridize"],
    &["nitridise"],
];

pub(crate) static ENTRY_NITROGENIZATIONS_17176486832772077313: VariantsMap = [
    &["nitrogenizations"],
    &["nitrogenisations"],
    &["nitrogenizations"],
    &["nitrogenisations"],
];

pub(crate) static ENTRY_NITROGENIZATION_14350056587973254157: VariantsMap = [
    &["nitrogenization"],
    &["nitrogenisation"],
    &["nitrogenization"],
    &["nitrogenisation"],
];

pub(crate) static ENTRY_NITROGENIZED_2806489925492009236: VariantsMap = [
    &["nitrogenized"],
    &["nitrogenised"],
    &["nitrogenized"],
    &["nitrogenised"],
];

pub(crate) static ENTRY_NITROGENIZES_13983524784279127593: VariantsMap = [
    &["nitrogenizes"],
    &["nitrogenises"],
    &["nitrogenizes"],
    &["nitrogenises"],
];

pub(crate) static ENTRY_NITROGENIZE_703235107353112890: VariantsMap = [
    &["nitrogenize"],
    &["nitrogenise"],
    &["nitrogenize"],
    &["nitrogenise"],
];

pub(crate) static ENTRY_NITROGENIZING_4171458431333219871: VariantsMap = [
    &["nitrogenizing"],
    &["nitrogenising"],
    &["nitrogenizing"],
    &["nitrogenising"],
];

pub(crate) static ENTRY_NITROGLYCERINS_868987947481490504: VariantsMap = [
    &["nitroglycerins"],
    &["nitroglycerines"],
    &["nitroglycerines"],
    &["nitroglycerines"],
];

pub(crate) static ENTRY_NITROGLYCERIN_14614401800457155758: VariantsMap = [
    &["nitroglycerin"],
    &["nitroglycerine"],
    &["nitroglycerine"],
    &["nitroglycerine"],
];

pub(crate) static ENTRY_NODALIZED_16625400756956152734: VariantsMap = [
    &["nodalized"],
    &["nodalised"],
    &["nodalized"],
    &["nodalised"],
];

pub(crate) static ENTRY_NODALIZES_11438261223912295797: VariantsMap = [
    &["nodalizes"],
    &["nodalises"],
    &["nodalizes"],
    &["nodalises"],
];

pub(crate) static ENTRY_NODALIZE_2482979525031615560: VariantsMap =
    [&["nodalize"], &["nodalise"], &["nodalize"], &["nodalise"]];

pub(crate) static ENTRY_NODALIZING_3463035244214116724: VariantsMap = [
    &["nodalizing"],
    &["nodalising"],
    &["nodalizing"],
    &["nodalising"],
];

pub(crate) static ENTRY_NODULIZES_8756363846466309349: VariantsMap = [
    &["nodulizes"],
    &["nodulises"],
    &["nodulizes"],
    &["nodulises"],
];

pub(crate) static ENTRY_NODULIZE_9262608488062865502: VariantsMap =
    [&["nodulize"], &["nodulise"], &["nodulize"], &["nodulise"]];

pub(crate) static ENTRY_NOEMON_10873567031051101962: VariantsMap =
    [&["noemon"], &["noaemon"], &["noaemon"], &["noaemon"]];

pub(crate) static ENTRY_NOMADIZATIONS_14059871491871936323: VariantsMap = [
    &["nomadizations"],
    &["nomadisations"],
    &["nomadizations"],
    &["nomadisations"],
];

pub(crate) static ENTRY_NOMADIZATION_3726418886473657659: VariantsMap = [
    &["nomadization"],
    &["nomadisation"],
    &["nomadization"],
    &["nomadisation"],
];

pub(crate) static ENTRY_NOMADIZED_17060101352980657463: VariantsMap = [
    &["nomadized"],
    &["nomadised"],
    &["nomadized"],
    &["nomadised"],
];

pub(crate) static ENTRY_NOMADIZES_7490658564095276952: VariantsMap = [
    &["nomadizes"],
    &["nomadises"],
    &["nomadizes"],
    &["nomadises"],
];

pub(crate) static ENTRY_NOMADIZE_7419521819158010147: VariantsMap =
    [&["nomadize"], &["nomadise"], &["nomadize"], &["nomadise"]];

pub(crate) static ENTRY_NOMADIZING_2240078758612833075: VariantsMap = [
    &["nomadizing"],
    &["nomadising"],
    &["nomadizing"],
    &["nomadising"],
];

pub(crate) static ENTRY_NOMINALIZATIONS_17926119396970399435: VariantsMap = [
    &["nominalizations"],
    &["nominalisations"],
    &["nominalizations"],
    &["nominalisations"],
];

pub(crate) static ENTRY_NOMINALIZATION_15107108373532687182: VariantsMap = [
    &["nominalization"],
    &["nominalisation"],
    &["nominalization"],
    &["nominalisation"],
];

pub(crate) static ENTRY_NOMINALIZED_9317987662267404083: VariantsMap = [
    &["nominalized"],
    &["nominalised"],
    &["nominalized"],
    &["nominalised"],
];

pub(crate) static ENTRY_NOMINALIZES_7590279431491000660: VariantsMap = [
    &["nominalizes"],
    &["nominalises"],
    &["nominalizes"],
    &["nominalises"],
];

pub(crate) static ENTRY_NOMINALIZE_10111105335237024044: VariantsMap = [
    &["nominalize"],
    &["nominalise"],
    &["nominalize"],
    &["nominalise"],
];

pub(crate) static ENTRY_NOMINALIZING_17210085527679423974: VariantsMap = [
    &["nominalizing"],
    &["nominalising"],
    &["nominalizing"],
    &["nominalising"],
];

pub(crate) static ENTRY_NONACKNOWLEDGMENTS_12640036285499344454: VariantsMap = [
    &["nonacknowledgments"],
    &["nonacknowledgements"],
    &["nonacknowledgements"],
    &["nonacknowledgements"],
];

pub(crate) static ENTRY_NONACKNOWLEDGMENT_10855774066809250441: VariantsMap = [
    &["nonacknowledgment"],
    &["nonacknowledgement"],
    &["nonacknowledgement"],
    &["nonacknowledgement"],
];

pub(crate) static ENTRY_NONANEMIC_15444821350095455223: VariantsMap = [
    &["nonanemic"],
    &["nonanaemic"],
    &["nonanaemic"],
    &["nonanaemic"],
];

pub(crate) static ENTRY_NONANESTHETIZED_9198347943161763514: VariantsMap = [
    &["nonanesthetized"],
    &["nonanaesthetised"],
    &["nonanaesthetized"],
    &["nonanaesthetised"],
];

pub(crate) static ENTRY_NONAPOSTATIZINGS_16518298917775117568: VariantsMap = [
    &["nonapostatizings"],
    &["nonapostatisings"],
    &["nonapostatizings"],
    &["nonapostatisings"],
];

pub(crate) static ENTRY_NONAPOSTATIZING_17606338307706364018: VariantsMap = [
    &["nonapostatizing"],
    &["nonapostatising"],
    &["nonapostatizing"],
    &["nonapostatising"],
];

pub(crate) static ENTRY_NONCANONIZATIONS_7638961939958144698: VariantsMap = [
    &["noncanonizations"],
    &["noncanonisations"],
    &["noncanonizations"],
    &["noncanonisations"],
];

pub(crate) static ENTRY_NONCANONIZATION_445261145541333623: VariantsMap = [
    &["noncanonization"],
    &["noncanonisation"],
    &["noncanonization"],
    &["noncanonisation"],
];

pub(crate) static ENTRY_NONCARTELIZEDS_17969407783152652717: VariantsMap = [
    &["noncartelizeds"],
    &["noncarteliseds"],
    &["noncartelizeds"],
    &["noncarteliseds"],
];

pub(crate) static ENTRY_NONCARTELIZED_6322002509020882794: VariantsMap = [
    &["noncartelized"],
    &["noncartelised"],
    &["noncartelized"],
    &["noncartelised"],
];

pub(crate) static ENTRY_NONCATECHIZABLES_1642435244323993126: VariantsMap = [
    &["noncatechizables"],
    &["noncatechisables"],
    &["noncatechizables"],
    &["noncatechisables"],
];

pub(crate) static ENTRY_NONCATECHIZABLE_10484851131855579792: VariantsMap = [
    &["noncatechizable"],
    &["noncatechisable"],
    &["noncatechizable"],
    &["noncatechisable"],
];

pub(crate) static ENTRY_NONCIVILIZEDS_1908754485486798836: VariantsMap = [
    &["noncivilizeds"],
    &["nonciviliseds"],
    &["noncivilizeds"],
    &["nonciviliseds"],
];

pub(crate) static ENTRY_NONCIVILIZED_6441644839637486277: VariantsMap = [
    &["noncivilized"],
    &["noncivilised"],
    &["noncivilized"],
    &["noncivilised"],
];

pub(crate) static ENTRY_NONCOLORABILITIES_4632001048163187739: VariantsMap = [
    &["noncolorabilities"],
    &["noncolourabilities"],
    &["noncolourabilities"],
    &["noncolourabilities"],
];

pub(crate) static ENTRY_NONCOLORABILITY_5533585286824786241: VariantsMap = [
    &["noncolorability"],
    &["noncolourability"],
    &["noncolourability"],
    &["noncolourability"],
];

pub(crate) static ENTRY_NONCOLORABLENESS_5261192976036412796: VariantsMap = [
    &["noncolorableness"],
    &["noncolourableness"],
    &["noncolourableness"],
    &["noncolourableness"],
];

pub(crate) static ENTRY_NONCOLORABLES_1727679389289748377: VariantsMap = [
    &["noncolorables"],
    &["noncolourables"],
    &["noncolourables"],
    &["noncolourables"],
];

pub(crate) static ENTRY_NONCOLORABLE_15709560648548694896: VariantsMap = [
    &["noncolorable"],
    &["noncolourable"],
    &["noncolourable"],
    &["noncolourable"],
];

pub(crate) static ENTRY_NONCOLORABLIES_5998817198041959004: VariantsMap = [
    &["noncolorablies"],
    &["noncolourablies"],
    &["noncolourablies"],
    &["noncolourablies"],
];

pub(crate) static ENTRY_NONCOLORABLY_3878269464585493782: VariantsMap = [
    &["noncolorably"],
    &["noncolourably"],
    &["noncolourably"],
    &["noncolourably"],
];

pub(crate) static ENTRY_NONCOLORED_2167088987541317140: VariantsMap = [
    &["noncolored"],
    &["noncoloured"],
    &["noncoloured"],
    &["noncoloured"],
];

pub(crate) static ENTRY_NONCOLORERS_1139612663123614815: VariantsMap = [
    &["noncolorers"],
    &["noncolourers"],
    &["noncolourers"],
    &["noncolourers"],
];

pub(crate) static ENTRY_NONCOLORER_17317229215012927154: VariantsMap = [
    &["noncolorer"],
    &["noncolourer"],
    &["noncolourer"],
    &["noncolourer"],
];

pub(crate) static ENTRY_NONCOLORFAST_15726041912771117535: VariantsMap = [
    &["noncolorfast"],
    &["noncolourfast"],
    &["noncolourfast"],
    &["noncolourfast"],
];

pub(crate) static ENTRY_NONCOLORINGS_5298650017970611127: VariantsMap = [
    &["noncolorings"],
    &["noncolourings"],
    &["noncolourings"],
    &["noncolourings"],
];

pub(crate) static ENTRY_NONCOLORING_5917730754685432342: VariantsMap = [
    &["noncoloring"],
    &["noncolouring"],
    &["noncolouring"],
    &["noncolouring"],
];

pub(crate) static ENTRY_NONCOLORS_1933476685975670621: VariantsMap = [
    &["noncolors"],
    &["noncolours"],
    &["noncolours"],
    &["noncolours"],
];

pub(crate) static ENTRY_NONCOLOR_3149179056960307443: VariantsMap = [
    &["noncolor"],
    &["noncolour"],
    &["noncolour"],
    &["noncolour"],
];

pub(crate) static ENTRY_NONCRYSTALLIZABLES_18102046015913198078: VariantsMap = [
    &["noncrystallizables"],
    &["noncrystallisables"],
    &["noncrystallizables"],
    &["noncrystallisables"],
];

pub(crate) static ENTRY_NONCRYSTALLIZABLE_10372505411607325770: VariantsMap = [
    &["noncrystallizable"],
    &["noncrystallisable"],
    &["noncrystallizable"],
    &["noncrystallisable"],
];

pub(crate) static ENTRY_NONCRYSTALLIZEDS_1965011183723304686: VariantsMap = [
    &["noncrystallizeds"],
    &["noncrystalliseds"],
    &["noncrystallizeds"],
    &["noncrystalliseds"],
];

pub(crate) static ENTRY_NONCRYSTALLIZED_5605940453320328190: VariantsMap = [
    &["noncrystallized"],
    &["noncrystallised"],
    &["noncrystallized"],
    &["noncrystallised"],
];

pub(crate) static ENTRY_NONCRYSTALLIZINGS_17233992070596336023: VariantsMap = [
    &["noncrystallizings"],
    &["noncrystallisings"],
    &["noncrystallizings"],
    &["noncrystallisings"],
];

pub(crate) static ENTRY_NONCRYSTALLIZING_10201570469442349314: VariantsMap = [
    &["noncrystallizing"],
    &["noncrystallising"],
    &["noncrystallizing"],
    &["noncrystallising"],
];

pub(crate) static ENTRY_NONDEMOBILIZATIONS_15826216627113214457: VariantsMap = [
    &["nondemobilizations"],
    &["nondemobilisations"],
    &["nondemobilizations"],
    &["nondemobilisations"],
];

pub(crate) static ENTRY_NONDEMOBILIZATION_11387355722360688339: VariantsMap = [
    &["nondemobilization"],
    &["nondemobilisation"],
    &["nondemobilization"],
    &["nondemobilisation"],
];

pub(crate) static ENTRY_NONDIALYZINGS_11543173817555613522: VariantsMap = [
    &["nondialyzings"],
    &["nondialysings"],
    &["nondialysings"],
    &["nondialysings"],
];

pub(crate) static ENTRY_NONDIALYZING_8935478329511290197: VariantsMap = [
    &["nondialyzing"],
    &["nondialysing"],
    &["nondialysing"],
    &["nondialysing"],
];

pub(crate) static ENTRY_NONDIMENSIONALIZED_10355726740313798452: VariantsMap = [
    &["nondimensionalized"],
    &["nondimensionalised"],
    &["nondimensionalized"],
    &["nondimensionalised"],
];

pub(crate) static ENTRY_NONDIMENSIONALIZE_17818368850919719572: VariantsMap = [
    &["nondimensionalize"],
    &["nondimensionalise"],
    &["nondimensionalize"],
    &["nondimensionalise"],
];

pub(crate) static ENTRY_NONECUMENICAL_810904659323722625: VariantsMap = [
    &["nonecumenical"],
    &["nonoecumenical"],
    &["nonoecumenical"],
    &["nonoecumenical"],
];

pub(crate) static ENTRY_NONECUMENIC_15150105529473042099: VariantsMap = [
    &["nonecumenic"],
    &["nonoecumenic"],
    &["nonoecumenic"],
    &["nonoecumenic"],
];

pub(crate) static ENTRY_NONESTHETICALLY_9030761369515840292: VariantsMap = [
    &["nonesthetically"],
    &["nonaesthetically"],
    &["nonaesthetically"],
    &["nonaesthetically"],
];

pub(crate) static ENTRY_NONESTHETICAL_17133793059861648567: VariantsMap = [
    &["nonesthetical"],
    &["nonaesthetical"],
    &["nonaesthetical"],
    &["nonaesthetical"],
];

pub(crate) static ENTRY_NONESTHETIC_2666778020362669429: VariantsMap = [
    &["nonesthetic"],
    &["nonaesthetic"],
    &["nonaesthetic"],
    &["nonaesthetic"],
];

pub(crate) static ENTRY_NONFAVORITES_16348199772317515957: VariantsMap = [
    &["nonfavorites"],
    &["nonfavourites"],
    &["nonfavourites"],
    &["nonfavourites"],
];

pub(crate) static ENTRY_NONFAVORITE_9212483996832040949: VariantsMap = [
    &["nonfavorite"],
    &["nonfavourite"],
    &["nonfavourite"],
    &["nonfavourite"],
];

pub(crate) static ENTRY_NONFLAVORED_10494480100237219729: VariantsMap = [
    &["nonflavored"],
    &["nonflavoured"],
    &["nonflavoured"],
    &["nonflavoured"],
];

pub(crate) static ENTRY_NONFULFILLMENTS_15135034110516785101: VariantsMap = [
    &["nonfulfillments"],
    &["nonfulfilments"],
    &["nonfulfilments"],
    &["nonfulfilments"],
];

pub(crate) static ENTRY_NONFULFILLMENT_2709075420628011330: VariantsMap = [
    &["nonfulfillment"],
    &["nonfulfilment"],
    &["nonfulfilment"],
    &["nonfulfilment"],
];

pub(crate) static ENTRY_NONGALVANIZEDS_8550940513824683889: VariantsMap = [
    &["nongalvanizeds"],
    &["nongalvaniseds"],
    &["nongalvanizeds"],
    &["nongalvaniseds"],
];

pub(crate) static ENTRY_NONGALVANIZED_11384392564239466868: VariantsMap = [
    &["nongalvanized"],
    &["nongalvanised"],
    &["nongalvanized"],
    &["nongalvanised"],
];

pub(crate) static ENTRY_NONGELATINIZINGS_4067743041157459041: VariantsMap = [
    &["nongelatinizings"],
    &["nongelatinisings"],
    &["nongelatinizings"],
    &["nongelatinisings"],
];

pub(crate) static ENTRY_NONGELATINIZING_5051984650375658405: VariantsMap = [
    &["nongelatinizing"],
    &["nongelatinising"],
    &["nongelatinizing"],
    &["nongelatinising"],
];

pub(crate) static ENTRY_NONHYDROLYZABLES_1998067287234569229: VariantsMap = [
    &["nonhydrolyzables"],
    &["nonhydrolysables"],
    &["nonhydrolysables"],
    &["nonhydrolysables"],
];

pub(crate) static ENTRY_NONHYDROLYZABLE_17320011376315732668: VariantsMap = [
    &["nonhydrolyzable"],
    &["nonhydrolysable"],
    &["nonhydrolysable"],
    &["nonhydrolysable"],
];

pub(crate) static ENTRY_NONIMMUNIZEDS_2963611111727770694: VariantsMap = [
    &["nonimmunizeds"],
    &["nonimmuniseds"],
    &["nonimmunizeds"],
    &["nonimmuniseds"],
];

pub(crate) static ENTRY_NONIMMUNIZED_4590493450951603549: VariantsMap = [
    &["nonimmunized"],
    &["nonimmunised"],
    &["nonimmunized"],
    &["nonimmunised"],
];

pub(crate) static ENTRY_NONIONIZEDS_5599188828242558716: VariantsMap = [
    &["nonionizeds"],
    &["nonioniseds"],
    &["nonionizeds"],
    &["nonioniseds"],
];

pub(crate) static ENTRY_NONIONIZED_17820724010194720017: VariantsMap = [
    &["nonionized"],
    &["nonionised"],
    &["nonionized"],
    &["nonionised"],
];

pub(crate) static ENTRY_NONIONIZINGS_5881375827446483087: VariantsMap = [
    &["nonionizings"],
    &["nonionisings"],
    &["nonionizings"],
    &["nonionisings"],
];

pub(crate) static ENTRY_NONIONIZING_12310413608399838371: VariantsMap = [
    &["nonionizing"],
    &["nonionising"],
    &["nonionizing"],
    &["nonionising"],
];

pub(crate) static ENTRY_NONLOCALIZEDS_2038148318593203679: VariantsMap = [
    &["nonlocalizeds"],
    &["nonlocaliseds"],
    &["nonlocalizeds"],
    &["nonlocaliseds"],
];

pub(crate) static ENTRY_NONLOCALIZED_8241380360957256875: VariantsMap = [
    &["nonlocalized"],
    &["nonlocalised"],
    &["nonlocalized"],
    &["nonlocalised"],
];

pub(crate) static ENTRY_NONMAGNETIZABLES_7457992790204468436: VariantsMap = [
    &["nonmagnetizables"],
    &["nonmagnetisables"],
    &["nonmagnetizables"],
    &["nonmagnetisables"],
];

pub(crate) static ENTRY_NONMAGNETIZABLE_17141546560968815138: VariantsMap = [
    &["nonmagnetizable"],
    &["nonmagnetisable"],
    &["nonmagnetizable"],
    &["nonmagnetisable"],
];

pub(crate) static ENTRY_NONNITROGENIZEDS_13860960024826722287: VariantsMap = [
    &["nonnitrogenizeds"],
    &["nonnitrogeniseds"],
    &["nonnitrogenizeds"],
    &["nonnitrogeniseds"],
];

pub(crate) static ENTRY_NONNITROGENIZED_6692106666255942926: VariantsMap = [
    &["nonnitrogenized"],
    &["nonnitrogenised"],
    &["nonnitrogenized"],
    &["nonnitrogenised"],
];

pub(crate) static ENTRY_NONORGANIZATIONS_7584860267076573731: VariantsMap = [
    &["nonorganizations"],
    &["nonorganisations"],
    &["nonorganizations"],
    &["nonorganisations"],
];

pub(crate) static ENTRY_NONORGANIZATION_15261480439585844401: VariantsMap = [
    &["nonorganization"],
    &["nonorganisation"],
    &["nonorganization"],
    &["nonorganisation"],
];

pub(crate) static ENTRY_NONOXIDIZABLES_2491632333208328373: VariantsMap = [
    &["nonoxidizables"],
    &["nonoxidisables"],
    &["nonoxidizables"],
    &["nonoxidisables"],
];

pub(crate) static ENTRY_NONOXIDIZABLE_3176964828889782374: VariantsMap = [
    &["nonoxidizable"],
    &["nonoxidisable"],
    &["nonoxidizable"],
    &["nonoxidisable"],
];

pub(crate) static ENTRY_NONOXIDIZINGS_9315788901303966844: VariantsMap = [
    &["nonoxidizings"],
    &["nonoxidisings"],
    &["nonoxidizings"],
    &["nonoxidisings"],
];

pub(crate) static ENTRY_NONOXIDIZING_15441038092706737796: VariantsMap = [
    &["nonoxidizing"],
    &["nonoxidising"],
    &["nonoxidizing"],
    &["nonoxidising"],
];

pub(crate) static ENTRY_NONPARLORS_1263265995512153061: VariantsMap = [
    &["nonparlors"],
    &["nonparlours"],
    &["nonparlours"],
    &["nonparlours"],
];

pub(crate) static ENTRY_NONPARLOR_2583560003148588775: VariantsMap = [
    &["nonparlor"],
    &["nonparlour"],
    &["nonparlour"],
    &["nonparlour"],
];

pub(crate) static ENTRY_NONPENALIZEDS_14714048229201860516: VariantsMap = [
    &["nonpenalizeds"],
    &["nonpenaliseds"],
    &["nonpenalizeds"],
    &["nonpenaliseds"],
];

pub(crate) static ENTRY_NONPENALIZED_9938333688009159198: VariantsMap = [
    &["nonpenalized"],
    &["nonpenalised"],
    &["nonpenalized"],
    &["nonpenalised"],
];

pub(crate) static ENTRY_NONPHOSPHORIZEDS_10408290644367324425: VariantsMap = [
    &["nonphosphorizeds"],
    &["nonphosphoriseds"],
    &["nonphosphorizeds"],
    &["nonphosphoriseds"],
];

pub(crate) static ENTRY_NONPHOSPHORIZED_15226565697312913858: VariantsMap = [
    &["nonphosphorized"],
    &["nonphosphorised"],
    &["nonphosphorized"],
    &["nonphosphorised"],
];

pub(crate) static ENTRY_NONPOLARIZABLES_14784416862913176760: VariantsMap = [
    &["nonpolarizables"],
    &["nonpolarisables"],
    &["nonpolarizables"],
    &["nonpolarisables"],
];

pub(crate) static ENTRY_NONPOLARIZABLE_6473533389464029696: VariantsMap = [
    &["nonpolarizable"],
    &["nonpolarisable"],
    &["nonpolarizable"],
    &["nonpolarisable"],
];

pub(crate) static ENTRY_NONPOLARIZED_9666868525356577877: VariantsMap = [
    &["nonpolarized"],
    &["nonpolarised"],
    &["nonpolarized"],
    &["nonpolarised"],
];

pub(crate) static ENTRY_NONPOLARIZINGS_10991174532515610089: VariantsMap = [
    &["nonpolarizings"],
    &["nonpolarisings"],
    &["nonpolarizings"],
    &["nonpolarisings"],
];

pub(crate) static ENTRY_NONPOLARIZING_10385047813105106287: VariantsMap = [
    &["nonpolarizing"],
    &["nonpolarising"],
    &["nonpolarizing"],
    &["nonpolarising"],
];

pub(crate) static ENTRY_NONRATIONALIZEDS_12119683182893470771: VariantsMap = [
    &["nonrationalizeds"],
    &["nonrationaliseds"],
    &["nonrationalizeds"],
    &["nonrationaliseds"],
];

pub(crate) static ENTRY_NONRATIONALIZED_14252903993087392578: VariantsMap = [
    &["nonrationalized"],
    &["nonrationalised"],
    &["nonrationalized"],
    &["nonrationalised"],
];

pub(crate) static ENTRY_NONREALIZATIONS_9707907650171739948: VariantsMap = [
    &["nonrealizations"],
    &["nonrealisations"],
    &["nonrealizations"],
    &["nonrealisations"],
];

pub(crate) static ENTRY_NONREALIZATION_1085294749674131476: VariantsMap = [
    &["nonrealization"],
    &["nonrealisation"],
    &["nonrealization"],
    &["nonrealisation"],
];

pub(crate) static ENTRY_NONRECOGNIZEDS_7029223781209778460: VariantsMap = [
    &["nonrecognizeds"],
    &["nonrecogniseds"],
    &["nonrecognizeds"],
    &["nonrecogniseds"],
];

pub(crate) static ENTRY_NONRECOGNIZED_7144499538091654669: VariantsMap = [
    &["nonrecognized"],
    &["nonrecognised"],
    &["nonrecognized"],
    &["nonrecognised"],
];

pub(crate) static ENTRY_NONSCHEMATIZEDS_3534565221599326465: VariantsMap = [
    &["nonschematizeds"],
    &["nonschematiseds"],
    &["nonschematizeds"],
    &["nonschematiseds"],
];

pub(crate) static ENTRY_NONSCHEMATIZED_8632859639656826393: VariantsMap = [
    &["nonschematized"],
    &["nonschematised"],
    &["nonschematized"],
    &["nonschematised"],
];

pub(crate) static ENTRY_NONSENSITIZEDS_16265989731308339490: VariantsMap = [
    &["nonsensitizeds"],
    &["nonsensitiseds"],
    &["nonsensitizeds"],
    &["nonsensitiseds"],
];

pub(crate) static ENTRY_NONSENSITIZED_7636351124138354819: VariantsMap = [
    &["nonsensitized"],
    &["nonsensitised"],
    &["nonsensitized"],
    &["nonsensitised"],
];

pub(crate) static ENTRY_NONSPECIALIZEDS_16267745606425806478: VariantsMap = [
    &["nonspecializeds"],
    &["nonspecialiseds"],
    &["nonspecializeds"],
    &["nonspecialiseds"],
];

pub(crate) static ENTRY_NONSPECIALIZED_16389043871429531385: VariantsMap = [
    &["nonspecialized"],
    &["nonspecialised"],
    &["nonspecialized"],
    &["nonspecialised"],
];

pub(crate) static ENTRY_NONSTANDARDIZEDS_5050992934219440733: VariantsMap = [
    &["nonstandardizeds"],
    &["nonstandardiseds"],
    &["nonstandardizeds"],
    &["nonstandardiseds"],
];

pub(crate) static ENTRY_NONSTANDARDIZED_15278040731989517059: VariantsMap = [
    &["nonstandardized"],
    &["nonstandardised"],
    &["nonstandardized"],
    &["nonstandardised"],
];

pub(crate) static ENTRY_NONSTYLIZEDS_3245363354710554909: VariantsMap = [
    &["nonstylizeds"],
    &["nonstyliseds"],
    &["nonstylizeds"],
    &["nonstyliseds"],
];

pub(crate) static ENTRY_NONSTYLIZED_14411143336075924222: VariantsMap = [
    &["nonstylized"],
    &["nonstylised"],
    &["nonstylized"],
    &["nonstylised"],
];

pub(crate) static ENTRY_NONSUCCOR_6598579766592657596: VariantsMap = [
    &["nonsuccor"],
    &["nonsuccour"],
    &["nonsuccour"],
    &["nonsuccour"],
];

pub(crate) static ENTRY_NONSYMPATHIZERS_10490688261674736888: VariantsMap = [
    &["nonsympathizers"],
    &["nonsympathisers"],
    &["nonsympathizers"],
    &["nonsympathisers"],
];

pub(crate) static ENTRY_NONSYMPATHIZER_4965121140144675590: VariantsMap = [
    &["nonsympathizer"],
    &["nonsympathiser"],
    &["nonsympathizer"],
    &["nonsympathiser"],
];

pub(crate) static ENTRY_NONSYNTHESIZEDS_17024224519378347416: VariantsMap = [
    &["nonsynthesizeds"],
    &["nonsynthesiseds"],
    &["nonsynthesizeds"],
    &["nonsynthesiseds"],
];

pub(crate) static ENTRY_NONSYNTHESIZED_13512975394986317082: VariantsMap = [
    &["nonsynthesized"],
    &["nonsynthesised"],
    &["nonsynthesized"],
    &["nonsynthesised"],
];

pub(crate) static ENTRY_NONTEMPORIZINGS_11414232594298995489: VariantsMap = [
    &["nontemporizings"],
    &["nontemporisings"],
    &["nontemporizings"],
    &["nontemporisings"],
];

pub(crate) static ENTRY_NONTEMPORIZING_7482017649343591602: VariantsMap = [
    &["nontemporizing"],
    &["nontemporising"],
    &["nontemporizing"],
    &["nontemporising"],
];

pub(crate) static ENTRY_NONUTILIZEDS_16763392484212693985: VariantsMap = [
    &["nonutilizeds"],
    &["nonutiliseds"],
    &["nonutilizeds"],
    &["nonutiliseds"],
];

pub(crate) static ENTRY_NONUTILIZED_6977234052565107201: VariantsMap = [
    &["nonutilized"],
    &["nonutilised"],
    &["nonutilized"],
    &["nonutilised"],
];

pub(crate) static ENTRY_NONVISUALIZEDS_321628249125916825: VariantsMap = [
    &["nonvisualizeds"],
    &["nonvisualiseds"],
    &["nonvisualizeds"],
    &["nonvisualiseds"],
];

pub(crate) static ENTRY_NONVISUALIZED_4803694735487431704: VariantsMap = [
    &["nonvisualized"],
    &["nonvisualised"],
    &["nonvisualized"],
    &["nonvisualised"],
];

pub(crate) static ENTRY_NONVOLATILIZEDS_9930790287842469013: VariantsMap = [
    &["nonvolatilizeds"],
    &["nonvolatiliseds"],
    &["nonvolatilizeds"],
    &["nonvolatiliseds"],
];

pub(crate) static ENTRY_NONVOLATILIZED_14122463800578325946: VariantsMap = [
    &["nonvolatilized"],
    &["nonvolatilised"],
    &["nonvolatilized"],
    &["nonvolatilised"],
];

pub(crate) static ENTRY_NONVULCANIZABLES_1406568761218608134: VariantsMap = [
    &["nonvulcanizables"],
    &["nonvulcanisables"],
    &["nonvulcanizables"],
    &["nonvulcanisables"],
];

pub(crate) static ENTRY_NONVULCANIZABLE_5020601800715170726: VariantsMap = [
    &["nonvulcanizable"],
    &["nonvulcanisable"],
    &["nonvulcanizable"],
    &["nonvulcanisable"],
];

pub(crate) static ENTRY_NORICE_11649257481922397534: VariantsMap =
    [&["norice"], &["nourice"], &["nourice"], &["nourice"]];

pub(crate) static ENTRY_NORMALIZABLE_14256375385440464739: VariantsMap = [
    &["normalizable"],
    &["normalisable"],
    &["normalizable"],
    &["normalisable"],
];

pub(crate) static ENTRY_NORMALIZATIONS_6086334685841165071: VariantsMap = [
    &["normalizations"],
    &["normalisations"],
    &["normalizations"],
    &["normalisations"],
];

pub(crate) static ENTRY_NORMALIZATION_1763771903231509736: VariantsMap = [
    &["normalization"],
    &["normalisation"],
    &["normalization"],
    &["normalisation"],
];

pub(crate) static ENTRY_NORMALIZED_13905640716588216801: VariantsMap = [
    &["normalized"],
    &["normalised"],
    &["normalized"],
    &["normalised"],
];

pub(crate) static ENTRY_NORMALIZERS_9242854506371928930: VariantsMap = [
    &["normalizers"],
    &["normalisers"],
    &["normalizers"],
    &["normalisers"],
];

pub(crate) static ENTRY_NORMALIZER_6185815349658447968: VariantsMap = [
    &["normalizer"],
    &["normaliser"],
    &["normalizer"],
    &["normaliser"],
];

pub(crate) static ENTRY_NORMALIZES_11815977506135648870: VariantsMap = [
    &["normalizes"],
    &["normalises"],
    &["normalizes"],
    &["normalises"],
];

pub(crate) static ENTRY_NORMALIZE_17937494001703948277: VariantsMap = [
    &["normalize"],
    &["normalise"],
    &["normalize"],
    &["normalise"],
];

pub(crate) static ENTRY_NORMALIZING_8454204097903734518: VariantsMap = [
    &["normalizing"],
    &["normalising"],
    &["normalizing"],
    &["normalising"],
];

pub(crate) static ENTRY_NORMANIZATIONS_9277423991706179990: VariantsMap = [
    &["normanizations"],
    &["normanisations"],
    &["normanizations"],
    &["normanisations"],
];

pub(crate) static ENTRY_NORMANIZATION_6961828407816376561: VariantsMap = [
    &["normanization"],
    &["normanisation"],
    &["normanization"],
    &["normanisation"],
];

pub(crate) static ENTRY_NORMANIZED_14551932295476748760: VariantsMap = [
    &["normanized"],
    &["normanised"],
    &["normanized"],
    &["normanised"],
];

pub(crate) static ENTRY_NORMANIZERS_12925142031749146670: VariantsMap = [
    &["normanizers"],
    &["normanisers"],
    &["normanizers"],
    &["normanisers"],
];

pub(crate) static ENTRY_NORMANIZER_5080941412143667065: VariantsMap = [
    &["normanizer"],
    &["normaniser"],
    &["normanizer"],
    &["normaniser"],
];

pub(crate) static ENTRY_NORMANIZES_16041441689197564016: VariantsMap = [
    &["normanizes"],
    &["normanises"],
    &["normanizes"],
    &["normanises"],
];

pub(crate) static ENTRY_NORMANIZE_2965443577391748183: VariantsMap = [
    &["normanize"],
    &["normanise"],
    &["normanize"],
    &["normanise"],
];

pub(crate) static ENTRY_NORMANIZING_10483194032455928026: VariantsMap = [
    &["normanizing"],
    &["normanising"],
    &["normanizing"],
    &["normanising"],
];

pub(crate) static ENTRY_NORTHERNIZED_13771447161233484057: VariantsMap = [
    &["northernized"],
    &["northernised"],
    &["northernized"],
    &["northernised"],
];

pub(crate) static ENTRY_NORTHERNIZES_11095974865864372366: VariantsMap = [
    &["northernizes"],
    &["northernises"],
    &["northernizes"],
    &["northernises"],
];

pub(crate) static ENTRY_NORTHERNIZE_9212991273136137117: VariantsMap = [
    &["northernize"],
    &["northernise"],
    &["northernize"],
    &["northernise"],
];

pub(crate) static ENTRY_NORTHERNIZING_7618561667513786062: VariantsMap = [
    &["northernizing"],
    &["northernising"],
    &["northernizing"],
    &["northernising"],
];

pub(crate) static ENTRY_NOSIES_15482746754024260075: VariantsMap =
    [&["nosies"], &["nosies"], &["nosies"], &["nosies"]];

pub(crate) static ENTRY_NOSIZE_14624422945441670096: VariantsMap =
    [&["nosize"], &["nosise"], &["nosize"], &["nosise"]];

pub(crate) static ENTRY_NOSOHEMIA_1514931224404468711: VariantsMap = [
    &["nosohemia"],
    &["nosohaemia"],
    &["nosohaemia"],
    &["nosohaemia"],
];

pub(crate) static ENTRY_NOSY_1009929718367174024: VariantsMap =
    [&["nosy"], &["nosy"], &["nosy"], &["nosy"]];

pub(crate) static ENTRY_NOTARIZATIONS_16318755198604086001: VariantsMap = [
    &["notarizations"],
    &["notarisations"],
    &["notarizations"],
    &["notarisations"],
];

pub(crate) static ENTRY_NOTARIZATION_8951353232118053302: VariantsMap = [
    &["notarization"],
    &["notarisation"],
    &["notarization"],
    &["notarisation"],
];

pub(crate) static ENTRY_NOTARIZED_5329696136884282809: VariantsMap = [
    &["notarized"],
    &["notarised"],
    &["notarized"],
    &["notarised"],
];

pub(crate) static ENTRY_NOTARIZES_9436796973316272397: VariantsMap = [
    &["notarizes"],
    &["notarises"],
    &["notarizes"],
    &["notarises"],
];

pub(crate) static ENTRY_NOTARIZE_14995362902294634015: VariantsMap =
    [&["notarize"], &["notarise"], &["notarize"], &["notarise"]];

pub(crate) static ENTRY_NOTARIZING_5636125110527307987: VariantsMap = [
    &["notarizing"],
    &["notarising"],
    &["notarizing"],
    &["notarising"],
];

pub(crate) static ENTRY_NOTER_7982355487050318652: VariantsMap =
    [&["noter"], &["notre"], &["notre"], &["notre"]];

pub(crate) static ENTRY_NOTHINGIZES_8887372277211243227: VariantsMap = [
    &["nothingizes"],
    &["nothingises"],
    &["nothingizes"],
    &["nothingises"],
];

pub(crate) static ENTRY_NOTHINGIZE_2529018495677046007: VariantsMap = [
    &["nothingize"],
    &["nothingise"],
    &["nothingize"],
    &["nothingise"],
];

pub(crate) static ENTRY_NOTOGEA_12842356277236712449: VariantsMap =
    [&["notogea"], &["notogaea"], &["notogaea"], &["notogaea"]];

pub(crate) static ENTRY_NOUNIZES_1623788942254245780: VariantsMap =
    [&["nounizes"], &["nounises"], &["nounizes"], &["nounises"]];

pub(crate) static ENTRY_NOUNIZE_4724905253679159672: VariantsMap =
    [&["nounize"], &["nounise"], &["nounize"], &["nounise"]];

pub(crate) static ENTRY_NOVELIZATIONS_3735074127764106015: VariantsMap = [
    &["novelizations"],
    &["novelisations"],
    &["novelizations"],
    &["novelisations"],
];

pub(crate) static ENTRY_NOVELIZATION_21718915207717005: VariantsMap = [
    &["novelization"],
    &["novelisation"],
    &["novelization"],
    &["novelisation"],
];

pub(crate) static ENTRY_NOVELIZED_15738528375210454895: VariantsMap = [
    &["novelized"],
    &["novelised"],
    &["novelized"],
    &["novelised"],
];

pub(crate) static ENTRY_NOVELIZERS_16950317005606382575: VariantsMap = [
    &["novelizers"],
    &["novelisers"],
    &["novelizers"],
    &["novelisers"],
];

pub(crate) static ENTRY_NOVELIZER_15766315188431000536: VariantsMap = [
    &["novelizer"],
    &["noveliser"],
    &["novelizer"],
    &["noveliser"],
];

pub(crate) static ENTRY_NOVELIZES_4390292103638708970: VariantsMap = [
    &["novelizes"],
    &["novelises"],
    &["novelizes"],
    &["novelises"],
];

pub(crate) static ENTRY_NOVELIZE_9678275742447267508: VariantsMap =
    [&["novelize"], &["novelise"], &["novelize"], &["novelise"]];

pub(crate) static ENTRY_NOVELIZING_8236112411426222682: VariantsMap = [
    &["novelizing"],
    &["novelising"],
    &["novelizing"],
    &["novelising"],
];

pub(crate) static ENTRY_NOVENE_8369049316963603721: VariantsMap =
    [&["novene"], &["novenae"], &["novenae"], &["novenae"]];

pub(crate) static ENTRY_NUCLEARIZATIONS_14289779087630955640: VariantsMap = [
    &["nuclearizations"],
    &["nuclearisations"],
    &["nuclearizations"],
    &["nuclearisations"],
];

pub(crate) static ENTRY_NUCLEARIZATION_15701379174589299721: VariantsMap = [
    &["nuclearization"],
    &["nuclearisation"],
    &["nuclearization"],
    &["nuclearisation"],
];

pub(crate) static ENTRY_NUCLEARIZED_6673795548622925030: VariantsMap = [
    &["nuclearized"],
    &["nuclearised"],
    &["nuclearized"],
    &["nuclearised"],
];

pub(crate) static ENTRY_NUCLEARIZES_5460600536427785035: VariantsMap = [
    &["nuclearizes"],
    &["nuclearises"],
    &["nuclearizes"],
    &["nuclearises"],
];

pub(crate) static ENTRY_NUCLEARIZE_16873979658884021829: VariantsMap = [
    &["nuclearize"],
    &["nuclearise"],
    &["nuclearize"],
    &["nuclearise"],
];

pub(crate) static ENTRY_NUCLEARIZING_15786741416474645245: VariantsMap = [
    &["nuclearizing"],
    &["nuclearising"],
    &["nuclearizing"],
    &["nuclearising"],
];

pub(crate) static ENTRY_NUPTIALIZES_10810848802613002169: VariantsMap = [
    &["nuptializes"],
    &["nuptialises"],
    &["nuptializes"],
    &["nuptialises"],
];

pub(crate) static ENTRY_NUPTIALIZE_1486337558182989700: VariantsMap = [
    &["nuptialize"],
    &["nuptialise"],
    &["nuptialize"],
    &["nuptialise"],
];

pub(crate) static ENTRY_NYMPHEUM_11562010131373678409: VariantsMap = [
    &["nympheum"],
    &["nymphaeum"],
    &["nymphaeum"],
    &["nymphaeum"],
];

pub(crate) static ENTRY_OBELIZED_5205778799169039990: VariantsMap =
    [&["obelized"], &["obelised"], &["obelized"], &["obelised"]];

pub(crate) static ENTRY_OBELIZES_716031993831418076: VariantsMap =
    [&["obelizes"], &["obelises"], &["obelizes"], &["obelises"]];

pub(crate) static ENTRY_OBELIZE_6489558286080618836: VariantsMap =
    [&["obelize"], &["obelise"], &["obelize"], &["obelise"]];

pub(crate) static ENTRY_OBELIZING_11436948508699926722: VariantsMap = [
    &["obelizing"],
    &["obelising"],
    &["obelizing"],
    &["obelising"],
];

pub(crate) static ENTRY_OBE_1507663346832934200: VariantsMap =
    [&["obe"], &["oboe"], &["oboe"], &["oboe"]];

pub(crate) static ENTRY_OBJECTIVIZED_15413360897315336968: VariantsMap = [
    &["objectivized"],
    &["objectivised"],
    &["objectivized"],
    &["objectivised"],
];

pub(crate) static ENTRY_OBJECTIVIZES_9105568866369059029: VariantsMap = [
    &["objectivizes"],
    &["objectivises"],
    &["objectivizes"],
    &["objectivises"],
];

pub(crate) static ENTRY_OBJECTIVIZE_17947776649437604843: VariantsMap = [
    &["objectivize"],
    &["objectivise"],
    &["objectivize"],
    &["objectivise"],
];

pub(crate) static ENTRY_OBJECTIVIZING_12654258354920210911: VariantsMap = [
    &["objectivizing"],
    &["objectivising"],
    &["objectivizing"],
    &["objectivising"],
];

pub(crate) static ENTRY_OBJECTIZATIONS_5369909600107239746: VariantsMap = [
    &["objectizations"],
    &["objectisations"],
    &["objectizations"],
    &["objectisations"],
];

pub(crate) static ENTRY_OBJECTIZATION_7865667227742220120: VariantsMap = [
    &["objectization"],
    &["objectisation"],
    &["objectization"],
    &["objectisation"],
];

pub(crate) static ENTRY_OBJECTIZES_8079723669956332188: VariantsMap = [
    &["objectizes"],
    &["objectises"],
    &["objectizes"],
    &["objectises"],
];

pub(crate) static ENTRY_OBJECTIZE_1941703412324553040: VariantsMap = [
    &["objectize"],
    &["objectise"],
    &["objectize"],
    &["objectise"],
];

pub(crate) static ENTRY_OBLIVIONIZES_16152353056435754063: VariantsMap = [
    &["oblivionizes"],
    &["oblivionises"],
    &["oblivionizes"],
    &["oblivionises"],
];

pub(crate) static ENTRY_OBLIVIONIZE_7661904693925296298: VariantsMap = [
    &["oblivionize"],
    &["oblivionise"],
    &["oblivionize"],
    &["oblivionise"],
];

pub(crate) static ENTRY_OCCIDENTALIZATIONS_17139435434038991612: VariantsMap = [
    &["occidentalizations"],
    &["occidentalisations"],
    &["occidentalizations"],
    &["occidentalisations"],
];

pub(crate) static ENTRY_OCCIDENTALIZATION_15524974948175552775: VariantsMap = [
    &["occidentalization"],
    &["occidentalisation"],
    &["occidentalization"],
    &["occidentalisation"],
];

pub(crate) static ENTRY_OCCIDENTALIZED_13409124988057556187: VariantsMap = [
    &["occidentalized"],
    &["occidentalised"],
    &["occidentalized"],
    &["occidentalised"],
];

pub(crate) static ENTRY_OCCIDENTALIZES_15812493525050066801: VariantsMap = [
    &["occidentalizes"],
    &["occidentalises"],
    &["occidentalizes"],
    &["occidentalises"],
];

pub(crate) static ENTRY_OCCIDENTALIZE_10589550920412342970: VariantsMap = [
    &["occidentalize"],
    &["occidentalise"],
    &["occidentalize"],
    &["occidentalise"],
];

pub(crate) static ENTRY_OCCIDENTALIZING_6771021046622848919: VariantsMap = [
    &["occidentalizing"],
    &["occidentalising"],
    &["occidentalizing"],
    &["occidentalising"],
];

pub(crate) static ENTRY_OCHERED_16675172852225671937: VariantsMap =
    [&["ochered"], &["ochred"], &["ochred"], &["ochred"]];

pub(crate) static ENTRY_OCHERING_14121606727366800680: VariantsMap =
    [&["ochering"], &["ochring"], &["ochring"], &["ochring"]];

pub(crate) static ENTRY_OCHERISH_15629897168603851362: VariantsMap =
    [&["ocherish"], &["ochreish"], &["ochreish"], &["ochreish"]];

pub(crate) static ENTRY_OCHEROUSER_9548217901029813754: VariantsMap = [
    &["ocherouser"],
    &["ochreouser"],
    &["ochreouser"],
    &["ochreouser"],
];

pub(crate) static ENTRY_OCHEROUSEST_9550248650160884919: VariantsMap = [
    &["ocherousest"],
    &["ochreousest"],
    &["ochreousest"],
    &["ochreousest"],
];

pub(crate) static ENTRY_OCHEROUS_7457653784346760110: VariantsMap =
    [&["ocherous"], &["ochreous"], &["ochreous"], &["ochreous"]];

pub(crate) static ENTRY_OCHERRER_16308994947056150512: VariantsMap =
    [&["ocherrer"], &["ochrer"], &["ochrer"], &["ochrer"]];

pub(crate) static ENTRY_OCHERREST_7388621669374657137: VariantsMap =
    [&["ocherrest"], &["ochrest"], &["ochrest"], &["ochrest"]];

pub(crate) static ENTRY_OCHERS_4760067737965399289: VariantsMap =
    [&["ochers"], &["ochres"], &["ochres"], &["ochres"]];

pub(crate) static ENTRY_OCHERY_8176749558188989833: VariantsMap =
    [&["ochery"], &["ochrey"], &["ochrey"], &["ochrey"]];

pub(crate) static ENTRY_OCHER_17256686823220191412: VariantsMap =
    [&["ocher"], &["ochre"], &["ochre"], &["ochre"]];

pub(crate) static ENTRY_OCYRRHOE_6375534256118272896: VariantsMap = [
    &["ocyrrhoe"],
    &["ocyrrhoae"],
    &["ocyrrhoae"],
    &["ocyrrhoae"],
];

pub(crate) static ENTRY_ODORED_16591159416202204717: VariantsMap =
    [&["odored"], &["odoured"], &["odoured"], &["odoured"]];

pub(crate) static ENTRY_ODORFULLER_13227327083024783843: VariantsMap = [
    &["odorfuller"],
    &["odourfuller"],
    &["odourfuller"],
    &["odourfuller"],
];

pub(crate) static ENTRY_ODORFULLEST_561913207316625895: VariantsMap = [
    &["odorfullest"],
    &["odourfullest"],
    &["odourfullest"],
    &["odourfullest"],
];

pub(crate) static ENTRY_ODORFUL_10183651138141826760: VariantsMap =
    [&["odorful"], &["odourful"], &["odourful"], &["odourful"]];

pub(crate) static ENTRY_ODORIZED_18414489297080773534: VariantsMap =
    [&["odorized"], &["odorised"], &["odorized"], &["odorised"]];

pub(crate) static ENTRY_ODORIZER_5204041533476108502: VariantsMap =
    [&["odorizer"], &["odoriser"], &["odorizer"], &["odoriser"]];

pub(crate) static ENTRY_ODORIZES_16793160564252381786: VariantsMap =
    [&["odorizes"], &["odorises"], &["odorizes"], &["odorises"]];

pub(crate) static ENTRY_ODORIZE_872977924177419056: VariantsMap =
    [&["odorize"], &["odorise"], &["odorize"], &["odorise"]];

pub(crate) static ENTRY_ODORIZING_1882846929730225949: VariantsMap = [
    &["odorizing"],
    &["odorising"],
    &["odorizing"],
    &["odorising"],
];

pub(crate) static ENTRY_ODORLESSER_9186460254240088489: VariantsMap = [
    &["odorlesser"],
    &["odourlesser"],
    &["odourlesser"],
    &["odourlesser"],
];

pub(crate) static ENTRY_ODORLESSEST_9571347228428809475: VariantsMap = [
    &["odorlessest"],
    &["odourlessest"],
    &["odourlessest"],
    &["odourlessest"],
];

pub(crate) static ENTRY_ODORLESSES_2783434654756197474: VariantsMap = [
    &["odorlesses"],
    &["odourlesses"],
    &["odourlesses"],
    &["odourlesses"],
];

pub(crate) static ENTRY_ODORLESS_16700169054217746196: VariantsMap = [
    &["odorless"],
    &["odourless"],
    &["odourless"],
    &["odourless"],
];

pub(crate) static ENTRY_ODORS_1722093147325611045: VariantsMap =
    [&["odors"], &["odours"], &["odours"], &["odours"]];

pub(crate) static ENTRY_ODOR_2702216183818705106: VariantsMap =
    [&["odor"], &["odour"], &["odour"], &["odour"]];

pub(crate) static ENTRY_OFFENSELESSER_11777917350340758028: VariantsMap = [
    &["offenselesser"],
    &["offencelesser"],
    &["offencelesser"],
    &["offencelesser"],
];

pub(crate) static ENTRY_OFFENSELESSEST_9145066131421191055: VariantsMap = [
    &["offenselessest"],
    &["offencelessest"],
    &["offencelessest"],
    &["offencelessest"],
];

pub(crate) static ENTRY_OFFENSELESSES_13236163449907150320: VariantsMap = [
    &["offenselesses"],
    &["offencelesses"],
    &["offencelesses"],
    &["offencelesses"],
];

pub(crate) static ENTRY_OFFENSELESSLY_5078736202987113916: VariantsMap = [
    &["offenselessly"],
    &["offencelessly"],
    &["offencelessly"],
    &["offencelessly"],
];

pub(crate) static ENTRY_OFFENSELESS_2398765789263825333: VariantsMap = [
    &["offenseless"],
    &["offenceless"],
    &["offenceless"],
    &["offenceless"],
];

pub(crate) static ENTRY_OFFENSES_14914149738486494625: VariantsMap =
    [&["offenses"], &["offences"], &["offences"], &["offences"]];

pub(crate) static ENTRY_OFFENSE_3255912368052973030: VariantsMap =
    [&["offense"], &["offence"], &["offence"], &["offence"]];

pub(crate) static ENTRY_OFFICIALIZATIONS_3020857948638018278: VariantsMap = [
    &["officializations"],
    &["officialisations"],
    &["officializations"],
    &["officialisations"],
];

pub(crate) static ENTRY_OFFICIALIZATION_7004816527823497683: VariantsMap = [
    &["officialization"],
    &["officialisation"],
    &["officialization"],
    &["officialisation"],
];

pub(crate) static ENTRY_OFFICIALIZES_5576900539771678977: VariantsMap = [
    &["officializes"],
    &["officialises"],
    &["officializes"],
    &["officialises"],
];

pub(crate) static ENTRY_OFFICIALIZE_18360229525723516910: VariantsMap = [
    &["officialize"],
    &["officialise"],
    &["officialize"],
    &["officialise"],
];

pub(crate) static ENTRY_OLIGEMIA_2437312993307346729: VariantsMap = [
    &["oligemia"],
    &["oligaemia"],
    &["oligaemia"],
    &["oligaemia"],
];

pub(crate) static ENTRY_OLIGOCYTHEMIA_11016311239765932815: VariantsMap = [
    &["oligocythemia"],
    &["oligocythaemia"],
    &["oligocythaemia"],
    &["oligocythaemia"],
];

pub(crate) static ENTRY_OLPE_8094297296134265506: VariantsMap =
    [&["olpe"], &["olpae"], &["olpae"], &["olpae"]];

pub(crate) static ENTRY_OLYMPIANIZES_11684603460342800519: VariantsMap = [
    &["olympianizes"],
    &["olympianises"],
    &["olympianizes"],
    &["olympianises"],
];

pub(crate) static ENTRY_OLYMPIANIZE_2609363663438954403: VariantsMap = [
    &["olympianize"],
    &["olympianise"],
    &["olympianize"],
    &["olympianise"],
];

pub(crate) static ENTRY_OMBERS_8620615949302259409: VariantsMap =
    [&["ombers"], &["ombres"], &["ombres"], &["ombres"]];

pub(crate) static ENTRY_OMBER_14663073390907191243: VariantsMap =
    [&["omber"], &["ombre"], &["ombre"], &["ombre"]];

pub(crate) static ENTRY_OMELETS_3609558159591624407: VariantsMap =
    [&["omelets"], &["omelettes"], &["omelettes"], &["omelettes"]];

pub(crate) static ENTRY_OMELET_764513264155611675: VariantsMap =
    [&["omelet"], &["omelette"], &["omelette"], &["omelette"]];

pub(crate) static ENTRY_ONEYERS_17135938246039464961: VariantsMap =
    [&["oneyers"], &["oneyres"], &["oneyres"], &["oneyres"]];

pub(crate) static ENTRY_ONEYER_1302914143351093181: VariantsMap =
    [&["oneyer"], &["oneyre"], &["oneyre"], &["oneyre"]];

pub(crate) static ENTRY_ONIONIZEDS_7393920731584280289: VariantsMap = [
    &["onionizeds"],
    &["onioniseds"],
    &["onionizeds"],
    &["onioniseds"],
];

pub(crate) static ENTRY_ONIONIZED_12389658815685910930: VariantsMap = [
    &["onionized"],
    &["onionised"],
    &["onionized"],
    &["onionised"],
];

pub(crate) static ENTRY_ONTOLOGIZE_16817464287858369211: VariantsMap = [
    &["ontologize"],
    &["ontologise"],
    &["ontologize"],
    &["ontologise"],
];

pub(crate) static ENTRY_ONWARD_5633188724180907694: VariantsMap =
    [&["onward"], &["onwards"], &["onward"], &["onwards"]];

pub(crate) static ENTRY_OOGLEA_9695545370949817893: VariantsMap =
    [&["ooglea"], &["oogloea"], &["oogloea"], &["oogloea"]];

pub(crate) static ENTRY_OOPHORECTOMIZED_14268303583521763064: VariantsMap = [
    &["oophorectomized"],
    &["oophorectomised"],
    &["oophorectomized"],
    &["oophorectomised"],
];

pub(crate) static ENTRY_OOPHORECTOMIZES_11659877128377332157: VariantsMap = [
    &["oophorectomizes"],
    &["oophorectomises"],
    &["oophorectomizes"],
    &["oophorectomises"],
];

pub(crate) static ENTRY_OOPHORECTOMIZE_1811121544488658856: VariantsMap = [
    &["oophorectomize"],
    &["oophorectomise"],
    &["oophorectomize"],
    &["oophorectomise"],
];

pub(crate) static ENTRY_OOPHORECTOMIZING_18341066518044446483: VariantsMap = [
    &["oophorectomizing"],
    &["oophorectomising"],
    &["oophorectomizing"],
    &["oophorectomising"],
];

pub(crate) static ENTRY_OPALED_4268978649764110434: VariantsMap =
    [&["opaled"], &["opalled"], &["opalled"], &["opalled"]];

pub(crate) static ENTRY_OPALIZED_4004234219806495147: VariantsMap =
    [&["opalized"], &["opalised"], &["opalized"], &["opalised"]];

pub(crate) static ENTRY_OPALIZES_13091586316761723756: VariantsMap =
    [&["opalizes"], &["opalises"], &["opalizes"], &["opalises"]];

pub(crate) static ENTRY_OPALIZE_1437903205364528409: VariantsMap =
    [&["opalize"], &["opalise"], &["opalize"], &["opalise"]];

pub(crate) static ENTRY_OPERATIONALIZATIONS_17065729379646598828: VariantsMap = [
    &["operationalizations"],
    &["operationalisations"],
    &["operationalizations"],
    &["operationalisations"],
];

pub(crate) static ENTRY_OPERATIONALIZATION_12829818197536963102: VariantsMap = [
    &["operationalization"],
    &["operationalisation"],
    &["operationalization"],
    &["operationalisation"],
];

pub(crate) static ENTRY_OPERATIONALIZED_2127043114686016582: VariantsMap = [
    &["operationalized"],
    &["operationalised"],
    &["operationalized"],
    &["operationalised"],
];

pub(crate) static ENTRY_OPERATIONALIZE_15949572577613892246: VariantsMap = [
    &["operationalize"],
    &["operationalise"],
    &["operationalize"],
    &["operationalise"],
];

pub(crate) static ENTRY_OPERATIZED_2802384364460316139: VariantsMap = [
    &["operatized"],
    &["operatised"],
    &["operatized"],
    &["operatised"],
];

pub(crate) static ENTRY_OPERATIZES_15123147664326939450: VariantsMap = [
    &["operatizes"],
    &["operatises"],
    &["operatizes"],
    &["operatises"],
];

pub(crate) static ENTRY_OPERATIZE_2365742892752822648: VariantsMap = [
    &["operatize"],
    &["operatise"],
    &["operatize"],
    &["operatise"],
];

pub(crate) static ENTRY_OPERATIZING_18314800119781305216: VariantsMap = [
    &["operatizing"],
    &["operatising"],
    &["operatizing"],
    &["operatising"],
];

pub(crate) static ENTRY_OPINIASTER_923208296007920958: VariantsMap = [
    &["opiniaster"],
    &["opiniastre"],
    &["opiniastre"],
    &["opiniastre"],
];

pub(crate) static ENTRY_OPINIATER_17164500991773351887: VariantsMap = [
    &["opiniater"],
    &["opiniatre"],
    &["opiniatre"],
    &["opiniatre"],
];

pub(crate) static ENTRY_OPTIMALIZATIONS_2899060633295590432: VariantsMap = [
    &["optimalizations"],
    &["optimalisations"],
    &["optimalizations"],
    &["optimalisations"],
];

pub(crate) static ENTRY_OPTIMALIZATION_5266921443954560262: VariantsMap = [
    &["optimalization"],
    &["optimalisation"],
    &["optimalization"],
    &["optimalisation"],
];

pub(crate) static ENTRY_OPTIMALIZED_18163256389331832808: VariantsMap = [
    &["optimalized"],
    &["optimalised"],
    &["optimalized"],
    &["optimalised"],
];

pub(crate) static ENTRY_OPTIMALIZES_16961555613967169097: VariantsMap = [
    &["optimalizes"],
    &["optimalises"],
    &["optimalizes"],
    &["optimalises"],
];

pub(crate) static ENTRY_OPTIMALIZE_4657203074060229056: VariantsMap = [
    &["optimalize"],
    &["optimalise"],
    &["optimalize"],
    &["optimalise"],
];

pub(crate) static ENTRY_OPTIMALIZING_3678300131645142586: VariantsMap = [
    &["optimalizing"],
    &["optimalising"],
    &["optimalizing"],
    &["optimalising"],
];

pub(crate) static ENTRY_OPTIMIZATIONS_5853505921922952795: VariantsMap = [
    &["optimizations"],
    &["optimisations"],
    &["optimizations"],
    &["optimisations"],
];

pub(crate) static ENTRY_OPTIMIZATION_7999660279345208813: VariantsMap = [
    &["optimization"],
    &["optimisation"],
    &["optimization"],
    &["optimisation"],
];

pub(crate) static ENTRY_OPTIMIZED_1595116357475103476: VariantsMap = [
    &["optimized"],
    &["optimised"],
    &["optimized"],
    &["optimised"],
];

pub(crate) static ENTRY_OPTIMIZERS_9262293159377441067: VariantsMap = [
    &["optimizers"],
    &["optimisers"],
    &["optimizers"],
    &["optimisers"],
];

pub(crate) static ENTRY_OPTIMIZER_17271297266309970872: VariantsMap = [
    &["optimizer"],
    &["optimiser"],
    &["optimizer"],
    &["optimiser"],
];

pub(crate) static ENTRY_OPTIMIZES_4735979948079339705: VariantsMap = [
    &["optimizes"],
    &["optimises"],
    &["optimizes"],
    &["optimises"],
];

pub(crate) static ENTRY_OPTIMIZE_2249839710181808282: VariantsMap =
    [&["optimize"], &["optimise"], &["optimize"], &["optimise"]];

pub(crate) static ENTRY_OPTIMIZING_13977015133672850235: VariantsMap = [
    &["optimizing"],
    &["optimising"],
    &["optimizing"],
    &["optimising"],
];

pub(crate) static ENTRY_OPTIONALIZES_9215004327024243624: VariantsMap = [
    &["optionalizes"],
    &["optionalises"],
    &["optionalizes"],
    &["optionalises"],
];

pub(crate) static ENTRY_OPTIONALIZE_14534625353219798956: VariantsMap = [
    &["optionalize"],
    &["optionalise"],
    &["optionalize"],
    &["optionalise"],
];

pub(crate) static ENTRY_ORALIZATIONS_7948469631672727124: VariantsMap = [
    &["oralizations"],
    &["oralisations"],
    &["oralizations"],
    &["oralisations"],
];

pub(crate) static ENTRY_ORALIZATION_14102364602676138991: VariantsMap = [
    &["oralization"],
    &["oralisation"],
    &["oralization"],
    &["oralisation"],
];

pub(crate) static ENTRY_ORALIZES_4086024195630455303: VariantsMap =
    [&["oralizes"], &["oralises"], &["oralizes"], &["oralises"]];

pub(crate) static ENTRY_ORALIZE_13699344227459420149: VariantsMap =
    [&["oralize"], &["oralise"], &["oralize"], &["oralise"]];

pub(crate) static ENTRY_ORANGIZES_11725856239709635108: VariantsMap = [
    &["orangizes"],
    &["orangises"],
    &["orangizes"],
    &["orangises"],
];

pub(crate) static ENTRY_ORANGIZE_2611683647153302964: VariantsMap =
    [&["orangize"], &["orangise"], &["orangize"], &["orangise"]];

pub(crate) static ENTRY_ORANGS_11893539110910417877: VariantsMap =
    [&["orangs"], &["orangs"], &["orangs"], &["orangs"]];

pub(crate) static ENTRY_ORANG_3026443150827231855: VariantsMap =
    [&["orang"], &["orang"], &["orang"], &["orang"]];

pub(crate) static ENTRY_ORATORIZES_6306251252951589283: VariantsMap = [
    &["oratorizes"],
    &["oratorises"],
    &["oratorizes"],
    &["oratorises"],
];

pub(crate) static ENTRY_ORATORIZE_6597645605933742855: VariantsMap = [
    &["oratorize"],
    &["oratorise"],
    &["oratorize"],
    &["oratorise"],
];

pub(crate) static ENTRY_ORCHESTER_10087918988280176676: VariantsMap = [
    &["orchester"],
    &["orchestre"],
    &["orchestre"],
    &["orchestre"],
];

pub(crate) static ENTRY_ORGANDY_16885011380899378447: VariantsMap =
    [&["organdy"], &["organdie"], &["organdy"], &["organdie"]];

pub(crate) static ENTRY_ORGANIZABILITIES_9394931609149039377: VariantsMap = [
    &["organizabilities"],
    &["organisabilities"],
    &["organizabilities"],
    &["organisabilities"],
];

pub(crate) static ENTRY_ORGANIZABILITY_5246488745229410216: VariantsMap = [
    &["organizability"],
    &["organisability"],
    &["organizability"],
    &["organisability"],
];

pub(crate) static ENTRY_ORGANIZABLER_1969669150958775103: VariantsMap = [
    &["organizabler"],
    &["organisabler"],
    &["organizabler"],
    &["organisabler"],
];

pub(crate) static ENTRY_ORGANIZABLEST_8166375843038220493: VariantsMap = [
    &["organizablest"],
    &["organisablest"],
    &["organizablest"],
    &["organisablest"],
];

pub(crate) static ENTRY_ORGANIZABLES_18100950647422214168: VariantsMap = [
    &["organizables"],
    &["organisables"],
    &["organizables"],
    &["organisables"],
];

pub(crate) static ENTRY_ORGANIZABLE_6357914431188658371: VariantsMap = [
    &["organizable"],
    &["organisable"],
    &["organizable"],
    &["organisable"],
];

pub(crate) static ENTRY_ORGANIZATIONALER_3873019173853092798: VariantsMap = [
    &["organizationaler"],
    &["organisationaler"],
    &["organizationaler"],
    &["organisationaler"],
];

pub(crate) static ENTRY_ORGANIZATIONALEST_1078872185464956795: VariantsMap = [
    &["organizationalest"],
    &["organisationalest"],
    &["organizationalest"],
    &["organisationalest"],
];

pub(crate) static ENTRY_ORGANIZATIONALLIER_4232299366340167031: VariantsMap = [
    &["organizationallier"],
    &["organisationallier"],
    &["organizationallier"],
    &["organisationallier"],
];

pub(crate) static ENTRY_ORGANIZATIONALLIEST_5781070786689457967: VariantsMap = [
    &["organizationalliest"],
    &["organisationalliest"],
    &["organizationalliest"],
    &["organisationalliest"],
];

pub(crate) static ENTRY_ORGANIZATIONALLY_14545398087106745696: VariantsMap = [
    &["organizationally"],
    &["organisationally"],
    &["organizationally"],
    &["organisationally"],
];

pub(crate) static ENTRY_ORGANIZATIONALS_14375928891357084131: VariantsMap = [
    &["organizationals"],
    &["organisationals"],
    &["organizationals"],
    &["organisationals"],
];

pub(crate) static ENTRY_ORGANIZATIONAL_2693930595138979162: VariantsMap = [
    &["organizational"],
    &["organisational"],
    &["organizational"],
    &["organisational"],
];

pub(crate) static ENTRY_ORGANIZATIONISTS_16677324722617299171: VariantsMap = [
    &["organizationists"],
    &["organisationists"],
    &["organizationists"],
    &["organisationists"],
];

pub(crate) static ENTRY_ORGANIZATIONIST_4240138124771372347: VariantsMap = [
    &["organizationist"],
    &["organisationist"],
    &["organizationist"],
    &["organisationist"],
];

pub(crate) static ENTRY_ORGANIZATIONS_4577579545569833942: VariantsMap = [
    &["organizations"],
    &["organisations"],
    &["organizations"],
    &["organisations"],
];

pub(crate) static ENTRY_ORGANIZATION_17289795818827632314: VariantsMap = [
    &["organization"],
    &["organisation"],
    &["organization"],
    &["organisation"],
];

pub(crate) static ENTRY_ORGANIZED_14662641348959642965: VariantsMap = [
    &["organized"],
    &["organised"],
    &["organized"],
    &["organised"],
];

pub(crate) static ENTRY_ORGANIZERS_3593448493398179170: VariantsMap = [
    &["organizers"],
    &["organisers"],
    &["organizers"],
    &["organisers"],
];

pub(crate) static ENTRY_ORGANIZER_11892981286551035399: VariantsMap = [
    &["organizer"],
    &["organiser"],
    &["organizer"],
    &["organiser"],
];

pub(crate) static ENTRY_ORGANIZES_10823078939317146880: VariantsMap = [
    &["organizes"],
    &["organises"],
    &["organizes"],
    &["organises"],
];

pub(crate) static ENTRY_ORGANIZE_5877473548332466223: VariantsMap =
    [&["organize"], &["organise"], &["organize"], &["organise"]];

pub(crate) static ENTRY_ORGANIZING_8682329261432472945: VariantsMap = [
    &["organizing"],
    &["organising"],
    &["organizing"],
    &["organising"],
];

pub(crate) static ENTRY_ORIENTALIZATIONS_3726476841271105524: VariantsMap = [
    &["orientalizations"],
    &["orientalisations"],
    &["orientalizations"],
    &["orientalisations"],
];

pub(crate) static ENTRY_ORIENTALIZATION_1232208388762237133: VariantsMap = [
    &["orientalization"],
    &["orientalisation"],
    &["orientalization"],
    &["orientalisation"],
];

pub(crate) static ENTRY_ORIENTALIZED_17195678597420672824: VariantsMap = [
    &["orientalized"],
    &["orientalised"],
    &["orientalized"],
    &["orientalised"],
];

pub(crate) static ENTRY_ORIENTALIZES_15493764345171362933: VariantsMap = [
    &["orientalizes"],
    &["orientalises"],
    &["orientalizes"],
    &["orientalises"],
];

pub(crate) static ENTRY_ORIENTALIZE_3925980212984131506: VariantsMap = [
    &["orientalize"],
    &["orientalise"],
    &["orientalize"],
    &["orientalise"],
];

pub(crate) static ENTRY_ORIENTALIZING_16469770502347036371: VariantsMap = [
    &["orientalizing"],
    &["orientalising"],
    &["orientalizing"],
    &["orientalising"],
];

pub(crate) static ENTRY_ORIENTIZATIONS_16760664737151206075: VariantsMap = [
    &["orientizations"],
    &["orientisations"],
    &["orientizations"],
    &["orientisations"],
];

pub(crate) static ENTRY_ORIENTIZATION_2913174614870744272: VariantsMap = [
    &["orientization"],
    &["orientisation"],
    &["orientization"],
    &["orientisation"],
];

pub(crate) static ENTRY_ORIENTIZES_4137063984653504864: VariantsMap = [
    &["orientizes"],
    &["orientises"],
    &["orientizes"],
    &["orientises"],
];

pub(crate) static ENTRY_ORIENTIZE_16169620859440661915: VariantsMap = [
    &["orientize"],
    &["orientise"],
    &["orientize"],
    &["orientise"],
];

pub(crate) static ENTRY_ORNAMENTALIZES_910695680953477344: VariantsMap = [
    &["ornamentalizes"],
    &["ornamentalises"],
    &["ornamentalizes"],
    &["ornamentalises"],
];

pub(crate) static ENTRY_ORNAMENTALIZE_7265064091795605703: VariantsMap = [
    &["ornamentalize"],
    &["ornamentalise"],
    &["ornamentalize"],
    &["ornamentalise"],
];

pub(crate) static ENTRY_OROLOGIES_1741200697611441025: VariantsMap = [
    &["orologies"],
    &["ourologies"],
    &["ourologies"],
    &["ourologies"],
];

pub(crate) static ENTRY_OROLOGY_10784240065242117238: VariantsMap =
    [&["orology"], &["ourology"], &["ourology"], &["ourology"]];

pub(crate) static ENTRY_ORPHANIZES_9131568606393406839: VariantsMap = [
    &["orphanizes"],
    &["orphanises"],
    &["orphanizes"],
    &["orphanises"],
];

pub(crate) static ENTRY_ORPHANIZE_12252103065591212309: VariantsMap = [
    &["orphanize"],
    &["orphanise"],
    &["orphanize"],
    &["orphanise"],
];

pub(crate) static ENTRY_ORSEL_3088141134430316343: VariantsMap =
    [&["orsel"], &["oursel"], &["oursel"], &["oursel"]];

pub(crate) static ENTRY_ORTHOCENTERS_13755283236164913906: VariantsMap = [
    &["orthocenters"],
    &["orthocentres"],
    &["orthocentres"],
    &["orthocentres"],
];

pub(crate) static ENTRY_ORTHOCENTER_13207654446878205458: VariantsMap = [
    &["orthocenter"],
    &["orthocentre"],
    &["orthocentre"],
    &["orthocentre"],
];

pub(crate) static ENTRY_ORTHOGONALIZATION_8307926330180047305: VariantsMap = [
    &["orthogonalization"],
    &["orthogonalisation"],
    &["orthogonalization"],
    &["orthogonalisation"],
];

pub(crate) static ENTRY_ORTHOGONALIZED_16305306345092783979: VariantsMap = [
    &["orthogonalized"],
    &["orthogonalised"],
    &["orthogonalized"],
    &["orthogonalised"],
];

pub(crate) static ENTRY_ORTHOGONALIZES_12099471702779010348: VariantsMap = [
    &["orthogonalizes"],
    &["orthogonalises"],
    &["orthogonalizes"],
    &["orthogonalises"],
];

pub(crate) static ENTRY_ORTHOGONALIZE_6060658647304766221: VariantsMap = [
    &["orthogonalize"],
    &["orthogonalise"],
    &["orthogonalize"],
    &["orthogonalise"],
];

pub(crate) static ENTRY_ORTHOGONALIZING_1408036844114979301: VariantsMap = [
    &["orthogonalizing"],
    &["orthogonalising"],
    &["orthogonalizing"],
    &["orthogonalising"],
];

pub(crate) static ENTRY_ORTHOGRAPHIZED_13781857966805232511: VariantsMap = [
    &["orthographized"],
    &["orthographised"],
    &["orthographized"],
    &["orthographised"],
];

pub(crate) static ENTRY_ORTHOGRAPHIZE_3476357704806405396: VariantsMap = [
    &["orthographize"],
    &["orthographise"],
    &["orthographize"],
    &["orthographise"],
];

pub(crate) static ENTRY_ORTHOGRAPHIZING_4089809753480171437: VariantsMap = [
    &["orthographizing"],
    &["orthographising"],
    &["orthographizing"],
    &["orthographising"],
];

pub(crate) static ENTRY_ORTHOPEDIA_16461309721642844449: VariantsMap = [
    &["orthopedia"],
    &["orthopaedia"],
    &["orthopaedia"],
    &["orthopaedia"],
];

pub(crate) static ENTRY_ORTHOPEDICALLIER_3224037467165156060: VariantsMap = [
    &["orthopedicallier"],
    &["orthopaedicallier"],
    &["orthopaedicallier"],
    &["orthopaedicallier"],
];

pub(crate) static ENTRY_ORTHOPEDICALLIEST_8960378657095551218: VariantsMap = [
    &["orthopedicalliest"],
    &["orthopaedicalliest"],
    &["orthopaedicalliest"],
    &["orthopaedicalliest"],
];

pub(crate) static ENTRY_ORTHOPEDICALLY_2298336873051715813: VariantsMap = [
    &["orthopedically"],
    &["orthopaedically"],
    &["orthopaedically"],
    &["orthopaedically"],
];

pub(crate) static ENTRY_ORTHOPEDICAL_6610437949463263530: VariantsMap = [
    &["orthopedical"],
    &["orthopaedical"],
    &["orthopaedical"],
    &["orthopaedical"],
];

pub(crate) static ENTRY_ORTHOPEDICER_3585810925484129429: VariantsMap = [
    &["orthopedicer"],
    &["orthopaedicer"],
    &["orthopaedicer"],
    &["orthopaedicer"],
];

pub(crate) static ENTRY_ORTHOPEDICEST_12750955173838086616: VariantsMap = [
    &["orthopedicest"],
    &["orthopaedicest"],
    &["orthopaedicest"],
    &["orthopaedicest"],
];

pub(crate) static ENTRY_ORTHOPEDICS_12977459761715868784: VariantsMap = [
    &["orthopedics"],
    &["orthopaedics"],
    &["orthopaedics"],
    &["orthopaedics"],
];

pub(crate) static ENTRY_ORTHOPEDIC_11181628856417796299: VariantsMap = [
    &["orthopedic"],
    &["orthopaedic"],
    &["orthopaedic"],
    &["orthopaedic"],
];

pub(crate) static ENTRY_ORTHOPEDIES_5292169995821299852: VariantsMap = [
    &["orthopedies"],
    &["orthopaedies"],
    &["orthopaedies"],
    &["orthopaedies"],
];

pub(crate) static ENTRY_ORTHOPEDISTS_13748363777846849291: VariantsMap = [
    &["orthopedists"],
    &["orthopaedists"],
    &["orthopaedists"],
    &["orthopaedists"],
];

pub(crate) static ENTRY_ORTHOPEDIST_6644326132964977786: VariantsMap = [
    &["orthopedist"],
    &["orthopaedist"],
    &["orthopaedist"],
    &["orthopaedist"],
];

pub(crate) static ENTRY_ORTHOPEDY_9278741910215259372: VariantsMap = [
    &["orthopedy"],
    &["orthopaedy"],
    &["orthopaedy"],
    &["orthopaedy"],
];

pub(crate) static ENTRY_ORTHOPNEA_1668703272398397545: VariantsMap = [
    &["orthopnea"],
    &["orthopnoea"],
    &["orthopnoea"],
    &["orthopnoea"],
];

pub(crate) static ENTRY_ORTHOPNEIC_11214547916528097306: VariantsMap = [
    &["orthopneic"],
    &["orthopnoeic"],
    &["orthopnoeic"],
    &["orthopnoeic"],
];

pub(crate) static ENTRY_OSTEOPEDION_4857509053557423347: VariantsMap = [
    &["osteopedion"],
    &["osteopaedion"],
    &["osteopaedion"],
    &["osteopaedion"],
];

pub(crate) static ENTRY_OSTRACIZABLES_14502674393095664398: VariantsMap = [
    &["ostracizables"],
    &["ostracisables"],
    &["ostracizables"],
    &["ostracisables"],
];

pub(crate) static ENTRY_OSTRACIZABLE_17001025771860320461: VariantsMap = [
    &["ostracizable"],
    &["ostracisable"],
    &["ostracizable"],
    &["ostracisable"],
];

pub(crate) static ENTRY_OSTRACIZATIONS_2093227212501115759: VariantsMap = [
    &["ostracizations"],
    &["ostracisations"],
    &["ostracizations"],
    &["ostracisations"],
];

pub(crate) static ENTRY_OSTRACIZATION_4685169978124572954: VariantsMap = [
    &["ostracization"],
    &["ostracisation"],
    &["ostracization"],
    &["ostracisation"],
];

pub(crate) static ENTRY_OSTRACIZED_17082390290234422430: VariantsMap = [
    &["ostracized"],
    &["ostracised"],
    &["ostracized"],
    &["ostracised"],
];

pub(crate) static ENTRY_OSTRACIZERS_5292704159191951070: VariantsMap = [
    &["ostracizers"],
    &["ostracisers"],
    &["ostracizers"],
    &["ostracisers"],
];

pub(crate) static ENTRY_OSTRACIZER_6163748049161701474: VariantsMap = [
    &["ostracizer"],
    &["ostraciser"],
    &["ostracizer"],
    &["ostraciser"],
];

pub(crate) static ENTRY_OSTRACIZES_12242933710212962262: VariantsMap = [
    &["ostracizes"],
    &["ostracises"],
    &["ostracizes"],
    &["ostracises"],
];

pub(crate) static ENTRY_OSTRACIZE_16556482869488657514: VariantsMap = [
    &["ostracize"],
    &["ostracise"],
    &["ostracize"],
    &["ostracise"],
];

pub(crate) static ENTRY_OSTRACIZING_13078448502630833661: VariantsMap = [
    &["ostracizing"],
    &["ostracising"],
    &["ostracizing"],
    &["ostracising"],
];

pub(crate) static ENTRY_OTHEMATOMA_5365268843459293252: VariantsMap = [
    &["othematoma"],
    &["othaematoma"],
    &["othaematoma"],
    &["othaematoma"],
];

pub(crate) static ENTRY_OTORRHEA_117491974381310742: VariantsMap = [
    &["otorrhea"],
    &["otorrhoea"],
    &["otorrhoea"],
    &["otorrhoea"],
];

pub(crate) static ENTRY_OTTOMANIZATIONS_18103044857042617134: VariantsMap = [
    &["ottomanizations"],
    &["ottomanisations"],
    &["ottomanizations"],
    &["ottomanisations"],
];

pub(crate) static ENTRY_OTTOMANIZATION_16626009540415399841: VariantsMap = [
    &["ottomanization"],
    &["ottomanisation"],
    &["ottomanization"],
    &["ottomanisation"],
];

pub(crate) static ENTRY_OTTOMANIZES_8070802369257673752: VariantsMap = [
    &["ottomanizes"],
    &["ottomanises"],
    &["ottomanizes"],
    &["ottomanises"],
];

pub(crate) static ENTRY_OTTOMANIZE_13171359343489848435: VariantsMap = [
    &["ottomanize"],
    &["ottomanise"],
    &["ottomanize"],
    &["ottomanise"],
];

pub(crate) static ENTRY_OUTCAVILED_8067524519482771834: VariantsMap = [
    &["outcaviled"],
    &["outcavilled"],
    &["outcavilled"],
    &["outcavilled"],
];

pub(crate) static ENTRY_OUTCAVILING_7846684353859330358: VariantsMap = [
    &["outcaviling"],
    &["outcavilling"],
    &["outcavilling"],
    &["outcavilling"],
];

pub(crate) static ENTRY_OUTCLAMORS_1932016408951518776: VariantsMap = [
    &["outclamors"],
    &["outclamours"],
    &["outclamours"],
    &["outclamours"],
];

pub(crate) static ENTRY_OUTCLAMOR_2628099102923288161: VariantsMap = [
    &["outclamor"],
    &["outclamour"],
    &["outclamour"],
    &["outclamour"],
];

pub(crate) static ENTRY_OUTERNESS_5110209358797551194: VariantsMap = [
    &["outerness"],
    &["outreness"],
    &["outreness"],
    &["outreness"],
];

pub(crate) static ENTRY_OUTHUMORED_17153608064346262904: VariantsMap = [
    &["outhumored"],
    &["outhumoured"],
    &["outhumoured"],
    &["outhumoured"],
];

pub(crate) static ENTRY_OUTHUMORING_5294044524439877555: VariantsMap = [
    &["outhumoring"],
    &["outhumouring"],
    &["outhumouring"],
    &["outhumouring"],
];

pub(crate) static ENTRY_OUTHUMORS_6379878794964447015: VariantsMap = [
    &["outhumors"],
    &["outhumours"],
    &["outhumours"],
    &["outhumours"],
];

pub(crate) static ENTRY_OUTHUMOR_12739979941160567143: VariantsMap = [
    &["outhumor"],
    &["outhumour"],
    &["outhumour"],
    &["outhumour"],
];

pub(crate) static ENTRY_OUTHYPERBOLIZES_3730443298592019408: VariantsMap = [
    &["outhyperbolizes"],
    &["outhyperbolises"],
    &["outhyperbolizes"],
    &["outhyperbolises"],
];

pub(crate) static ENTRY_OUTHYPERBOLIZE_17971419597167705024: VariantsMap = [
    &["outhyperbolize"],
    &["outhyperbolise"],
    &["outhyperbolize"],
    &["outhyperbolise"],
];

pub(crate) static ENTRY_OUTLABORS_8639955974059144964: VariantsMap = [
    &["outlabors"],
    &["outlabours"],
    &["outlabours"],
    &["outlabours"],
];

pub(crate) static ENTRY_OUTLABOR_4477843439986939547: VariantsMap = [
    &["outlabor"],
    &["outlabour"],
    &["outlabour"],
    &["outlabour"],
];

pub(crate) static ENTRY_OUTLUSTER_14753354047674654656: VariantsMap = [
    &["outluster"],
    &["outlustre"],
    &["outlustre"],
    &["outlustre"],
];

pub(crate) static ENTRY_OUTMANEUVERED_15207995604008599908: VariantsMap = [
    &["outmaneuvered"],
    &["outmanoeuvred"],
    &["outmanoeuvred"],
    &["outmanoeuvred"],
];

pub(crate) static ENTRY_OUTMANEUVERING_18066101649103069658: VariantsMap = [
    &["outmaneuvering"],
    &["outmanoeuvring"],
    &["outmanoeuvring"],
    &["outmanoeuvring"],
];

pub(crate) static ENTRY_OUTMANEUVERS_12354989641176250449: VariantsMap = [
    &["outmaneuvers"],
    &["outmanoeuvres"],
    &["outmanoeuvres"],
    &["outmanoeuvres"],
];

pub(crate) static ENTRY_OUTMANEUVER_8971376472472700486: VariantsMap = [
    &["outmaneuver"],
    &["outmanoeuvre"],
    &["outmanoeuvre"],
    &["outmanoeuvre"],
];

pub(crate) static ENTRY_OUTRIVALED_3341374795207180843: VariantsMap = [
    &["outrivaled"],
    &["outrivalled"],
    &["outrivalled"],
    &["outrivalled"],
];

pub(crate) static ENTRY_OUTRIVALING_2545493549405891999: VariantsMap = [
    &["outrivaling"],
    &["outrivalling"],
    &["outrivalling"],
    &["outrivalling"],
];

pub(crate) static ENTRY_OUTSAVORING_12930164474104036309: VariantsMap = [
    &["outsavoring"],
    &["outsavouring"],
    &["outsavouring"],
    &["outsavouring"],
];

pub(crate) static ENTRY_OUTSAVORS_8162427042123223209: VariantsMap = [
    &["outsavors"],
    &["outsavours"],
    &["outsavours"],
    &["outsavours"],
];

pub(crate) static ENTRY_OUTSAVOR_10580389165402595979: VariantsMap = [
    &["outsavor"],
    &["outsavour"],
    &["outsavour"],
    &["outsavour"],
];

pub(crate) static ENTRY_OUTSPLENDORS_11316257281529662399: VariantsMap = [
    &["outsplendors"],
    &["outsplendours"],
    &["outsplendours"],
    &["outsplendours"],
];

pub(crate) static ENTRY_OUTSPLENDOR_5260326500390827064: VariantsMap = [
    &["outsplendor"],
    &["outsplendour"],
    &["outsplendour"],
    &["outsplendour"],
];

pub(crate) static ENTRY_OUTTYRANNIZES_14123969537438855678: VariantsMap = [
    &["outtyrannizes"],
    &["outtyrannises"],
    &["outtyrannizes"],
    &["outtyrannises"],
];

pub(crate) static ENTRY_OUTTYRANNIZE_15662237949831559495: VariantsMap = [
    &["outtyrannize"],
    &["outtyrannise"],
    &["outtyrannize"],
    &["outtyrannise"],
];

pub(crate) static ENTRY_OVALIZATIONS_18116960851150407547: VariantsMap = [
    &["ovalizations"],
    &["ovalisations"],
    &["ovalizations"],
    &["ovalisations"],
];

pub(crate) static ENTRY_OVALIZATION_1291479772354921953: VariantsMap = [
    &["ovalization"],
    &["ovalisation"],
    &["ovalization"],
    &["ovalisation"],
];

pub(crate) static ENTRY_OVALIZES_14265834545135198955: VariantsMap =
    [&["ovalizes"], &["ovalises"], &["ovalizes"], &["ovalises"]];

pub(crate) static ENTRY_OVALIZE_10690880851091583963: VariantsMap =
    [&["ovalize"], &["ovalise"], &["ovalize"], &["ovalise"]];

pub(crate) static ENTRY_OVARIECTOMIZED_10591671171299862773: VariantsMap = [
    &["ovariectomized"],
    &["ovariectomised"],
    &["ovariectomized"],
    &["ovariectomised"],
];

pub(crate) static ENTRY_OVERAGONIZES_18072904232465525038: VariantsMap = [
    &["overagonizes"],
    &["overagonises"],
    &["overagonizes"],
    &["overagonises"],
];

pub(crate) static ENTRY_OVERAGONIZE_12839802073298082121: VariantsMap = [
    &["overagonize"],
    &["overagonise"],
    &["overagonize"],
    &["overagonise"],
];

pub(crate) static ENTRY_OVERANALYZES_1261439988617962985: VariantsMap = [
    &["overanalyzes"],
    &["overanalyses"],
    &["overanalyzes"],
    &["overanalyses"],
];

pub(crate) static ENTRY_OVERANALYZE_9915211901630072465: VariantsMap = [
    &["overanalyze"],
    &["overanalyse"],
    &["overanalyze"],
    &["overanalyse"],
];

pub(crate) static ENTRY_OVERBRUTALIZES_5838247981424780614: VariantsMap = [
    &["overbrutalizes"],
    &["overbrutalises"],
    &["overbrutalizes"],
    &["overbrutalises"],
];

pub(crate) static ENTRY_OVERBRUTALIZE_12508120024832721923: VariantsMap = [
    &["overbrutalize"],
    &["overbrutalise"],
    &["overbrutalize"],
    &["overbrutalise"],
];

pub(crate) static ENTRY_OVERCAPITALIZATIONS_8515268345747345778: VariantsMap = [
    &["overcapitalizations"],
    &["overcapitalisations"],
    &["overcapitalizations"],
    &["overcapitalisations"],
];

pub(crate) static ENTRY_OVERCAPITALIZATION_16491991909868759291: VariantsMap = [
    &["overcapitalization"],
    &["overcapitalisation"],
    &["overcapitalization"],
    &["overcapitalisation"],
];

pub(crate) static ENTRY_OVERCAPITALIZED_16391070453870509941: VariantsMap = [
    &["overcapitalized"],
    &["overcapitalised"],
    &["overcapitalized"],
    &["overcapitalised"],
];

pub(crate) static ENTRY_OVERCAPITALIZES_6277345493449192746: VariantsMap = [
    &["overcapitalizes"],
    &["overcapitalises"],
    &["overcapitalizes"],
    &["overcapitalises"],
];

pub(crate) static ENTRY_OVERCAPITALIZE_5137404458805033721: VariantsMap = [
    &["overcapitalize"],
    &["overcapitalise"],
    &["overcapitalize"],
    &["overcapitalise"],
];

pub(crate) static ENTRY_OVERCAPITALIZING_1761143477577642450: VariantsMap = [
    &["overcapitalizing"],
    &["overcapitalising"],
    &["overcapitalizing"],
    &["overcapitalising"],
];

pub(crate) static ENTRY_OVERCENTRALIZATIONS_8087116287428750116: VariantsMap = [
    &["overcentralizations"],
    &["overcentralisations"],
    &["overcentralizations"],
    &["overcentralisations"],
];

pub(crate) static ENTRY_OVERCENTRALIZATION_4206431460039066433: VariantsMap = [
    &["overcentralization"],
    &["overcentralisation"],
    &["overcentralization"],
    &["overcentralisation"],
];

pub(crate) static ENTRY_OVERCENTRALIZES_5222524178127209553: VariantsMap = [
    &["overcentralizes"],
    &["overcentralises"],
    &["overcentralizes"],
    &["overcentralises"],
];

pub(crate) static ENTRY_OVERCENTRALIZE_12851132365246138388: VariantsMap = [
    &["overcentralize"],
    &["overcentralise"],
    &["overcentralize"],
    &["overcentralise"],
];

pub(crate) static ENTRY_OVERCIVILIZATIONS_1687537129456067045: VariantsMap = [
    &["overcivilizations"],
    &["overcivilisations"],
    &["overcivilizations"],
    &["overcivilisations"],
];

pub(crate) static ENTRY_OVERCIVILIZATION_14330185198631343224: VariantsMap = [
    &["overcivilization"],
    &["overcivilisation"],
    &["overcivilization"],
    &["overcivilisation"],
];

pub(crate) static ENTRY_OVERCIVILIZES_7600225434837167383: VariantsMap = [
    &["overcivilizes"],
    &["overcivilises"],
    &["overcivilizes"],
    &["overcivilises"],
];

pub(crate) static ENTRY_OVERCIVILIZE_7361104998251555913: VariantsMap = [
    &["overcivilize"],
    &["overcivilise"],
    &["overcivilize"],
    &["overcivilise"],
];

pub(crate) static ENTRY_OVERCLAMORS_13060839905474300243: VariantsMap = [
    &["overclamors"],
    &["overclamours"],
    &["overclamours"],
    &["overclamours"],
];

pub(crate) static ENTRY_OVERCLAMOR_7626038013386332277: VariantsMap = [
    &["overclamor"],
    &["overclamour"],
    &["overclamour"],
    &["overclamour"],
];

pub(crate) static ENTRY_OVERCOLORATION_9954247583751155389: VariantsMap = [
    &["overcoloration"],
    &["overcolouration"],
    &["overcolouration"],
    &["overcolouration"],
];

pub(crate) static ENTRY_OVERCOLORING_12857603657681315527: VariantsMap = [
    &["overcoloring"],
    &["overcolouring"],
    &["overcolouring"],
    &["overcolouring"],
];

pub(crate) static ENTRY_OVERCOLORS_12585352933997313554: VariantsMap = [
    &["overcolors"],
    &["overcolours"],
    &["overcolours"],
    &["overcolours"],
];

pub(crate) static ENTRY_OVERCOLOR_9560847732348280457: VariantsMap = [
    &["overcolor"],
    &["overcolour"],
    &["overcolour"],
    &["overcolour"],
];

pub(crate) static ENTRY_OVERCRITICIZES_410272753519343801: VariantsMap = [
    &["overcriticizes"],
    &["overcriticises"],
    &["overcriticizes"],
    &["overcriticises"],
];

pub(crate) static ENTRY_OVERCRITICIZE_8553366067384322807: VariantsMap = [
    &["overcriticize"],
    &["overcriticise"],
    &["overcriticize"],
    &["overcriticise"],
];

pub(crate) static ENTRY_OVERDOCTRINIZES_16618778111872081207: VariantsMap = [
    &["overdoctrinizes"],
    &["overdoctrinises"],
    &["overdoctrinizes"],
    &["overdoctrinises"],
];

pub(crate) static ENTRY_OVERDOCTRINIZE_9952294591350746328: VariantsMap = [
    &["overdoctrinize"],
    &["overdoctrinise"],
    &["overdoctrinize"],
    &["overdoctrinise"],
];

pub(crate) static ENTRY_OVERDRAMATIZED_568182443613701103: VariantsMap = [
    &["overdramatized"],
    &["overdramatised"],
    &["overdramatized"],
    &["overdramatised"],
];

pub(crate) static ENTRY_OVERDRAMATIZES_677559530199440792: VariantsMap = [
    &["overdramatizes"],
    &["overdramatises"],
    &["overdramatizes"],
    &["overdramatises"],
];

pub(crate) static ENTRY_OVERDRAMATIZE_9956046184240652478: VariantsMap = [
    &["overdramatize"],
    &["overdramatise"],
    &["overdramatize"],
    &["overdramatise"],
];

pub(crate) static ENTRY_OVERDRAMATIZING_8041727993818066162: VariantsMap = [
    &["overdramatizing"],
    &["overdramatising"],
    &["overdramatizing"],
    &["overdramatising"],
];

pub(crate) static ENTRY_OVEREMOTIONALIZES_15929713333601260258: VariantsMap = [
    &["overemotionalizes"],
    &["overemotionalises"],
    &["overemotionalizes"],
    &["overemotionalises"],
];

pub(crate) static ENTRY_OVEREMOTIONALIZE_3492219056437347076: VariantsMap = [
    &["overemotionalize"],
    &["overemotionalise"],
    &["overemotionalize"],
    &["overemotionalise"],
];

pub(crate) static ENTRY_OVEREMPHASIZED_14422660185907423404: VariantsMap = [
    &["overemphasized"],
    &["overemphasised"],
    &["overemphasized"],
    &["overemphasised"],
];

pub(crate) static ENTRY_OVEREMPHASIZERS_12835127742532574597: VariantsMap = [
    &["overemphasizers"],
    &["overemphasisers"],
    &["overemphasizers"],
    &["overemphasisers"],
];

pub(crate) static ENTRY_OVEREMPHASIZER_13084428145414100736: VariantsMap = [
    &["overemphasizer"],
    &["overemphasiser"],
    &["overemphasizer"],
    &["overemphasiser"],
];

pub(crate) static ENTRY_OVEREMPHASIZES_9211947340714823778: VariantsMap = [
    &["overemphasizes"],
    &["overemphasises"],
    &["overemphasizes"],
    &["overemphasises"],
];

pub(crate) static ENTRY_OVEREMPHASIZE_10188078811171146690: VariantsMap = [
    &["overemphasize"],
    &["overemphasise"],
    &["overemphasize"],
    &["overemphasise"],
];

pub(crate) static ENTRY_OVEREMPHASIZING_656930053748535278: VariantsMap = [
    &["overemphasizing"],
    &["overemphasising"],
    &["overemphasizing"],
    &["overemphasising"],
];

pub(crate) static ENTRY_OVERFAVORABLES_3683339017470690215: VariantsMap = [
    &["overfavorables"],
    &["overfavourables"],
    &["overfavourables"],
    &["overfavourables"],
];

pub(crate) static ENTRY_OVERFAVORABLE_10044615958182307903: VariantsMap = [
    &["overfavorable"],
    &["overfavourable"],
    &["overfavourable"],
    &["overfavourable"],
];

pub(crate) static ENTRY_OVERFAVORABLIES_16549422454865344977: VariantsMap = [
    &["overfavorablies"],
    &["overfavourablies"],
    &["overfavourablies"],
    &["overfavourablies"],
];

pub(crate) static ENTRY_OVERFAVORABLY_17663512402196493148: VariantsMap = [
    &["overfavorably"],
    &["overfavourably"],
    &["overfavourably"],
    &["overfavourably"],
];

pub(crate) static ENTRY_OVERFAVORS_2292027566669700103: VariantsMap = [
    &["overfavors"],
    &["overfavours"],
    &["overfavours"],
    &["overfavours"],
];

pub(crate) static ENTRY_OVERFAVOR_17309564975320504308: VariantsMap = [
    &["overfavor"],
    &["overfavour"],
    &["overfavour"],
    &["overfavour"],
];

pub(crate) static ENTRY_OVERFERTILIZATION_15723879745564166382: VariantsMap = [
    &["overfertilization"],
    &["overfertilisation"],
    &["overfertilization"],
    &["overfertilisation"],
];

pub(crate) static ENTRY_OVERGENERALIZED_2362525225382909269: VariantsMap = [
    &["overgeneralized"],
    &["overgeneralised"],
    &["overgeneralized"],
    &["overgeneralised"],
];

pub(crate) static ENTRY_OVERGENERALIZES_1194543416222013859: VariantsMap = [
    &["overgeneralizes"],
    &["overgeneralises"],
    &["overgeneralizes"],
    &["overgeneralises"],
];

pub(crate) static ENTRY_OVERGENERALIZE_7625722739665195923: VariantsMap = [
    &["overgeneralize"],
    &["overgeneralise"],
    &["overgeneralize"],
    &["overgeneralise"],
];

pub(crate) static ENTRY_OVERGENERALIZING_3046182641254114632: VariantsMap = [
    &["overgeneralizing"],
    &["overgeneralising"],
    &["overgeneralizing"],
    &["overgeneralising"],
];

pub(crate) static ENTRY_OVERHONORS_12559365250164975436: VariantsMap = [
    &["overhonors"],
    &["overhonours"],
    &["overhonours"],
    &["overhonours"],
];

pub(crate) static ENTRY_OVERHONOR_7061058962043742785: VariantsMap = [
    &["overhonor"],
    &["overhonour"],
    &["overhonour"],
    &["overhonour"],
];

pub(crate) static ENTRY_OVERHUMANIZES_2059890155268395387: VariantsMap = [
    &["overhumanizes"],
    &["overhumanises"],
    &["overhumanizes"],
    &["overhumanises"],
];

pub(crate) static ENTRY_OVERHUMANIZE_17831519361456561071: VariantsMap = [
    &["overhumanize"],
    &["overhumanise"],
    &["overhumanize"],
    &["overhumanise"],
];

pub(crate) static ENTRY_OVERINDUSTRIALIZATIONS_880181449046892729: VariantsMap = [
    &["overindustrializations"],
    &["overindustrialisations"],
    &["overindustrializations"],
    &["overindustrialisations"],
];

pub(crate) static ENTRY_OVERINDUSTRIALIZATION_1518640640867699568: VariantsMap = [
    &["overindustrialization"],
    &["overindustrialisation"],
    &["overindustrialization"],
    &["overindustrialisation"],
];

pub(crate) static ENTRY_OVERINDUSTRIALIZES_15665873696822393914: VariantsMap = [
    &["overindustrializes"],
    &["overindustrialises"],
    &["overindustrializes"],
    &["overindustrialises"],
];

pub(crate) static ENTRY_OVERINDUSTRIALIZE_1935760429076726086: VariantsMap = [
    &["overindustrialize"],
    &["overindustrialise"],
    &["overindustrialize"],
    &["overindustrialise"],
];

pub(crate) static ENTRY_OVERJUDGMENTS_1683734198657934729: VariantsMap = [
    &["overjudgments"],
    &["overjudgements"],
    &["overjudgements"],
    &["overjudgements"],
];

pub(crate) static ENTRY_OVERJUDGMENT_14410272038538410201: VariantsMap = [
    &["overjudgment"],
    &["overjudgement"],
    &["overjudgement"],
    &["overjudgement"],
];

pub(crate) static ENTRY_OVERLABORED_12205791932532611074: VariantsMap = [
    &["overlabored"],
    &["overlaboured"],
    &["overlaboured"],
    &["overlaboured"],
];

pub(crate) static ENTRY_OVERLABORING_7695604562828463501: VariantsMap = [
    &["overlaboring"],
    &["overlabouring"],
    &["overlabouring"],
    &["overlabouring"],
];

pub(crate) static ENTRY_OVERLABORS_7659441557822287857: VariantsMap = [
    &["overlabors"],
    &["overlabours"],
    &["overlabours"],
    &["overlabours"],
];

pub(crate) static ENTRY_OVERLABOR_17688410265271100123: VariantsMap = [
    &["overlabor"],
    &["overlabour"],
    &["overlabour"],
    &["overlabour"],
];

pub(crate) static ENTRY_OVERNATIONALIZATIONS_15292388911190908837: VariantsMap = [
    &["overnationalizations"],
    &["overnationalisations"],
    &["overnationalizations"],
    &["overnationalisations"],
];

pub(crate) static ENTRY_OVERNATIONALIZATION_14750126295058482804: VariantsMap = [
    &["overnationalization"],
    &["overnationalisation"],
    &["overnationalization"],
    &["overnationalisation"],
];

pub(crate) static ENTRY_OVERRAPTURIZES_13279076080761686590: VariantsMap = [
    &["overrapturizes"],
    &["overrapturises"],
    &["overrapturizes"],
    &["overrapturises"],
];

pub(crate) static ENTRY_OVERRAPTURIZE_4942964855869337557: VariantsMap = [
    &["overrapturize"],
    &["overrapturise"],
    &["overrapturize"],
    &["overrapturise"],
];

pub(crate) static ENTRY_OVERRATIONALIZES_11313615435929619: VariantsMap = [
    &["overrationalizes"],
    &["overrationalises"],
    &["overrationalizes"],
    &["overrationalises"],
];

pub(crate) static ENTRY_OVERRATIONALIZE_6906270410629017501: VariantsMap = [
    &["overrationalize"],
    &["overrationalise"],
    &["overrationalize"],
    &["overrationalise"],
];

pub(crate) static ENTRY_OVERSENTIMENTALIZES_16872043038895867715: VariantsMap = [
    &["oversentimentalizes"],
    &["oversentimentalises"],
    &["oversentimentalizes"],
    &["oversentimentalises"],
];

pub(crate) static ENTRY_OVERSENTIMENTALIZE_9811793490104951879: VariantsMap = [
    &["oversentimentalize"],
    &["oversentimentalise"],
    &["oversentimentalize"],
    &["oversentimentalise"],
];

pub(crate) static ENTRY_OVERSPECIALIZATIONS_18126012734047267284: VariantsMap = [
    &["overspecializations"],
    &["overspecialisations"],
    &["overspecializations"],
    &["overspecialisations"],
];

pub(crate) static ENTRY_OVERSPECIALIZATION_1633031571639798019: VariantsMap = [
    &["overspecialization"],
    &["overspecialisation"],
    &["overspecialization"],
    &["overspecialisation"],
];

pub(crate) static ENTRY_OVERSPECIALIZED_1547172552972623375: VariantsMap = [
    &["overspecialized"],
    &["overspecialised"],
    &["overspecialized"],
    &["overspecialised"],
];

pub(crate) static ENTRY_OVERSPECIALIZES_10793320734082567309: VariantsMap = [
    &["overspecializes"],
    &["overspecialises"],
    &["overspecializes"],
    &["overspecialises"],
];

pub(crate) static ENTRY_OVERSPECIALIZE_7229749289149801509: VariantsMap = [
    &["overspecialize"],
    &["overspecialise"],
    &["overspecialize"],
    &["overspecialise"],
];

pub(crate) static ENTRY_OVERSPECIALIZING_3587227959598734164: VariantsMap = [
    &["overspecializing"],
    &["overspecialising"],
    &["overspecializing"],
    &["overspecialising"],
];

pub(crate) static ENTRY_OVERSYSTEMATIZES_15181329179373696484: VariantsMap = [
    &["oversystematizes"],
    &["oversystematises"],
    &["oversystematizes"],
    &["oversystematises"],
];

pub(crate) static ENTRY_OVERSYSTEMATIZE_15992334018865759556: VariantsMap = [
    &["oversystematize"],
    &["oversystematise"],
    &["oversystematize"],
    &["oversystematise"],
];

pub(crate) static ENTRY_OVERUNIONIZEDS_1211100019455129140: VariantsMap = [
    &["overunionizeds"],
    &["overunioniseds"],
    &["overunionizeds"],
    &["overunioniseds"],
];

pub(crate) static ENTRY_OVERUNIONIZED_6174875703556667280: VariantsMap = [
    &["overunionized"],
    &["overunionised"],
    &["overunionized"],
    &["overunionised"],
];

pub(crate) static ENTRY_OVERURBANIZATIONS_4989453349116630693: VariantsMap = [
    &["overurbanizations"],
    &["overurbanisations"],
    &["overurbanizations"],
    &["overurbanisations"],
];

pub(crate) static ENTRY_OVERURBANIZATION_18316259619018505400: VariantsMap = [
    &["overurbanization"],
    &["overurbanisation"],
    &["overurbanization"],
    &["overurbanisation"],
];

pub(crate) static ENTRY_OVERUTILIZATION_17588927385548718079: VariantsMap = [
    &["overutilization"],
    &["overutilisation"],
    &["overutilization"],
    &["overutilisation"],
];

pub(crate) static ENTRY_OVERWOMANIZES_2414716567143102514: VariantsMap = [
    &["overwomanizes"],
    &["overwomanises"],
    &["overwomanizes"],
    &["overwomanises"],
];

pub(crate) static ENTRY_OVERWOMANIZE_11490817551978529822: VariantsMap = [
    &["overwomanize"],
    &["overwomanise"],
    &["overwomanize"],
    &["overwomanise"],
];

pub(crate) static ENTRY_OWERCOME_4480209725664164037: VariantsMap =
    [&["owercome"], &["owrecome"], &["owrecome"], &["owrecome"]];

pub(crate) static ENTRY_OWERWORD_17641737365333065987: VariantsMap =
    [&["owerword"], &["owreword"], &["owreword"], &["owreword"]];

pub(crate) static ENTRY_OWER_714367973734079294: VariantsMap =
    [&["ower"], &["owre"], &["owre"], &["owre"]];

pub(crate) static ENTRY_OXALEMIA_11109410730791647209: VariantsMap = [
    &["oxalemia"],
    &["oxalaemia"],
    &["oxalaemia"],
    &["oxalaemia"],
];

pub(crate) static ENTRY_OXIDIZABILITIES_6073197852100555717: VariantsMap = [
    &["oxidizabilities"],
    &["oxidisabilities"],
    &["oxidizabilities"],
    &["oxidisabilities"],
];

pub(crate) static ENTRY_OXIDIZABILITY_989208003122354980: VariantsMap = [
    &["oxidizability"],
    &["oxidisability"],
    &["oxidizability"],
    &["oxidisability"],
];

pub(crate) static ENTRY_OXIDIZABLES_10964178463482153600: VariantsMap = [
    &["oxidizables"],
    &["oxidisables"],
    &["oxidizables"],
    &["oxidisables"],
];

pub(crate) static ENTRY_OXIDIZABLE_5289655147636602365: VariantsMap = [
    &["oxidizable"],
    &["oxidisable"],
    &["oxidizable"],
    &["oxidisable"],
];

pub(crate) static ENTRY_OXIDIZATIONS_10794857157062767651: VariantsMap = [
    &["oxidizations"],
    &["oxidisations"],
    &["oxidizations"],
    &["oxidisations"],
];

pub(crate) static ENTRY_OXIDIZATION_13166504173020505769: VariantsMap = [
    &["oxidization"],
    &["oxidisation"],
    &["oxidization"],
    &["oxidisation"],
];

pub(crate) static ENTRY_OXIDIZED_11075904073295172473: VariantsMap =
    [&["oxidized"], &["oxidised"], &["oxidized"], &["oxidised"]];

pub(crate) static ENTRY_OXIDIZEMENTS_97180816186053602: VariantsMap = [
    &["oxidizements"],
    &["oxidisements"],
    &["oxidizements"],
    &["oxidisements"],
];

pub(crate) static ENTRY_OXIDIZEMENT_4972583911879846564: VariantsMap = [
    &["oxidizement"],
    &["oxidisement"],
    &["oxidizement"],
    &["oxidisement"],
];

pub(crate) static ENTRY_OXIDIZERS_15313203568879188818: VariantsMap = [
    &["oxidizers"],
    &["oxidisers"],
    &["oxidizers"],
    &["oxidisers"],
];

pub(crate) static ENTRY_OXIDIZER_10115554319871451478: VariantsMap =
    [&["oxidizer"], &["oxidiser"], &["oxidizer"], &["oxidiser"]];

pub(crate) static ENTRY_OXIDIZES_9639252663902404191: VariantsMap =
    [&["oxidizes"], &["oxidises"], &["oxidizes"], &["oxidises"]];

pub(crate) static ENTRY_OXIDIZE_16273392528175590013: VariantsMap =
    [&["oxidize"], &["oxidise"], &["oxidize"], &["oxidise"]];

pub(crate) static ENTRY_OXIDIZINGS_10090589532009393809: VariantsMap = [
    &["oxidizings"],
    &["oxidisings"],
    &["oxidizings"],
    &["oxidisings"],
];

pub(crate) static ENTRY_OXIDIZING_16338645204512386709: VariantsMap = [
    &["oxidizing"],
    &["oxidising"],
    &["oxidizing"],
    &["oxidising"],
];

pub(crate) static ENTRY_OXYGENIZABLES_12197126132345293113: VariantsMap = [
    &["oxygenizables"],
    &["oxygenisables"],
    &["oxygenizables"],
    &["oxygenisables"],
];

pub(crate) static ENTRY_OXYGENIZABLE_9202370148099325185: VariantsMap = [
    &["oxygenizable"],
    &["oxygenisable"],
    &["oxygenizable"],
    &["oxygenisable"],
];

pub(crate) static ENTRY_OXYGENIZED_9126851973435245083: VariantsMap = [
    &["oxygenized"],
    &["oxygenised"],
    &["oxygenized"],
    &["oxygenised"],
];

pub(crate) static ENTRY_OXYGENIZEMENTS_16517849615537520423: VariantsMap = [
    &["oxygenizements"],
    &["oxygenisements"],
    &["oxygenizements"],
    &["oxygenisements"],
];

pub(crate) static ENTRY_OXYGENIZEMENT_18236184986628200327: VariantsMap = [
    &["oxygenizement"],
    &["oxygenisement"],
    &["oxygenizement"],
    &["oxygenisement"],
];

pub(crate) static ENTRY_OXYGENIZERS_150704751084290053: VariantsMap = [
    &["oxygenizers"],
    &["oxygenisers"],
    &["oxygenizers"],
    &["oxygenisers"],
];

pub(crate) static ENTRY_OXYGENIZER_11932344404155632770: VariantsMap = [
    &["oxygenizer"],
    &["oxygeniser"],
    &["oxygenizer"],
    &["oxygeniser"],
];

pub(crate) static ENTRY_OXYGENIZES_12009319071464897303: VariantsMap = [
    &["oxygenizes"],
    &["oxygenises"],
    &["oxygenizes"],
    &["oxygenises"],
];

pub(crate) static ENTRY_OXYGENIZE_13897612552534735492: VariantsMap = [
    &["oxygenize"],
    &["oxygenise"],
    &["oxygenize"],
    &["oxygenise"],
];

pub(crate) static ENTRY_OXYGENIZING_10986136118043010748: VariantsMap = [
    &["oxygenizing"],
    &["oxygenising"],
    &["oxygenizing"],
    &["oxygenising"],
];

pub(crate) static ENTRY_OXYHEMATIN_13193737801953766702: VariantsMap = [
    &["oxyhematin"],
    &["oxyhaematin"],
    &["oxyhaematin"],
    &["oxyhaematin"],
];

pub(crate) static ENTRY_OXYHEMOGLOBINS_8110549662482466088: VariantsMap = [
    &["oxyhemoglobins"],
    &["oxyhaemoglobins"],
    &["oxyhaemoglobins"],
    &["oxyhaemoglobins"],
];

pub(crate) static ENTRY_OXYHEMOGLOBIN_1846482423983796024: VariantsMap = [
    &["oxyhemoglobin"],
    &["oxyhaemoglobin"],
    &["oxyhaemoglobin"],
    &["oxyhaemoglobin"],
];

pub(crate) static ENTRY_OZENA_5442312756553924434: VariantsMap =
    [&["ozena"], &["ozoena"], &["ozoena"], &["ozoena"]];

pub(crate) static ENTRY_OZENA_7757597485130320426: VariantsMap =
    [&["ozena"], &["ozaena"], &["ozaena"], &["ozaena"]];

pub(crate) static ENTRY_OZONIZATIONS_15122382781840799944: VariantsMap = [
    &["ozonizations"],
    &["ozonisations"],
    &["ozonizations"],
    &["ozonisations"],
];

pub(crate) static ENTRY_OZONIZATION_12273080851661121450: VariantsMap = [
    &["ozonization"],
    &["ozonisation"],
    &["ozonization"],
    &["ozonisation"],
];

pub(crate) static ENTRY_OZONIZED_9207502852384727699: VariantsMap =
    [&["ozonized"], &["ozonised"], &["ozonized"], &["ozonised"]];

pub(crate) static ENTRY_OZONIZERS_10604136522486103167: VariantsMap = [
    &["ozonizers"],
    &["ozonisers"],
    &["ozonizers"],
    &["ozonisers"],
];

pub(crate) static ENTRY_OZONIZER_15162830907127483395: VariantsMap =
    [&["ozonizer"], &["ozoniser"], &["ozonizer"], &["ozoniser"]];

pub(crate) static ENTRY_OZONIZES_3688167369925893609: VariantsMap =
    [&["ozonizes"], &["ozonises"], &["ozonizes"], &["ozonises"]];

pub(crate) static ENTRY_OZONIZE_346284534762547575: VariantsMap =
    [&["ozonize"], &["ozonise"], &["ozonize"], &["ozonise"]];

pub(crate) static ENTRY_OZONIZING_8937744434536354872: VariantsMap = [
    &["ozonizing"],
    &["ozonising"],
    &["ozonizing"],
    &["ozonising"],
];

pub(crate) static ENTRY_PACHYEMIA_9489620928857821879: VariantsMap = [
    &["pachyemia"],
    &["pachyaemia"],
    &["pachyaemia"],
    &["pachyaemia"],
];

pub(crate) static ENTRY_PACHYHEMIA_8832332591288336993: VariantsMap = [
    &["pachyhemia"],
    &["pachyhaemia"],
    &["pachyhaemia"],
    &["pachyhaemia"],
];

pub(crate) static ENTRY_PACKETIZATION_10464592564290475261: VariantsMap = [
    &["packetization"],
    &["packetisation"],
    &["packetization"],
    &["packetisation"],
];

pub(crate) static ENTRY_PACKETIZED_8036428449595588231: VariantsMap = [
    &["packetized"],
    &["packetised"],
    &["packetized"],
    &["packetised"],
];

pub(crate) static ENTRY_PACKETIZERS_3352597016758962447: VariantsMap = [
    &["packetizers"],
    &["packetisers"],
    &["packetizers"],
    &["packetisers"],
];

pub(crate) static ENTRY_PACKETIZER_15919936461315780788: VariantsMap = [
    &["packetizer"],
    &["packetiser"],
    &["packetizer"],
    &["packetiser"],
];

pub(crate) static ENTRY_PACKETIZES_11082673242873858301: VariantsMap = [
    &["packetizes"],
    &["packetises"],
    &["packetizes"],
    &["packetises"],
];

pub(crate) static ENTRY_PACKETIZE_5763572427852346907: VariantsMap = [
    &["packetize"],
    &["packetise"],
    &["packetize"],
    &["packetise"],
];

pub(crate) static ENTRY_PACKETIZING_2464553966414791741: VariantsMap = [
    &["packetizing"],
    &["packetising"],
    &["packetizing"],
    &["packetising"],
];

pub(crate) static ENTRY_PAEANIZES_11463331795160910581: VariantsMap = [
    &["paeanizes"],
    &["paeanises"],
    &["paeanizes"],
    &["paeanises"],
];

pub(crate) static ENTRY_PAEANIZE_15507572022142186294: VariantsMap =
    [&["paeanize"], &["paeanise"], &["paeanize"], &["paeanise"]];

pub(crate) static ENTRY_PAGANIZATIONS_12724171596950745904: VariantsMap = [
    &["paganizations"],
    &["paganisations"],
    &["paganizations"],
    &["paganisations"],
];

pub(crate) static ENTRY_PAGANIZATION_2943576925427198072: VariantsMap = [
    &["paganization"],
    &["paganisation"],
    &["paganization"],
    &["paganisation"],
];

pub(crate) static ENTRY_PAGANIZED_10870075564649051258: VariantsMap = [
    &["paganized"],
    &["paganised"],
    &["paganized"],
    &["paganised"],
];

pub(crate) static ENTRY_PAGANIZERS_9387808109651520352: VariantsMap = [
    &["paganizers"],
    &["paganisers"],
    &["paganizers"],
    &["paganisers"],
];

pub(crate) static ENTRY_PAGANIZER_1865530174558486992: VariantsMap = [
    &["paganizer"],
    &["paganiser"],
    &["paganizer"],
    &["paganiser"],
];

pub(crate) static ENTRY_PAGANIZES_1804382210312745290: VariantsMap = [
    &["paganizes"],
    &["paganises"],
    &["paganizes"],
    &["paganises"],
];

pub(crate) static ENTRY_PAGANIZE_15046389715179883624: VariantsMap =
    [&["paganize"], &["paganise"], &["paganize"], &["paganise"]];

pub(crate) static ENTRY_PAGANIZING_16496197304705619669: VariantsMap = [
    &["paganizing"],
    &["paganising"],
    &["paganizing"],
    &["paganising"],
];

pub(crate) static ENTRY_PAGINE_14521861128818045118: VariantsMap =
    [&["pagine"], &["paginae"], &["paginae"], &["paginae"]];

pub(crate) static ENTRY_PAJAMAED_6840620032200463652: VariantsMap = [
    &["pajamaed"],
    &["pyjamased"],
    &["pyjamased"],
    &["pyjamased"],
];

pub(crate) static ENTRY_PAJAMAS_18438866384752213563: VariantsMap =
    [&["pajamas"], &["pyjamas"], &["pyjamas"], &["pyjamas"]];

pub(crate) static ENTRY_PAJAMA_3939742153808099869: VariantsMap =
    [&["pajama"], &["pyjama"], &["pyjama"], &["pyjama"]];

pub(crate) static ENTRY_PALAME_4183236324927672378: VariantsMap =
    [&["palame"], &["palamae"], &["palamae"], &["palamae"]];

pub(crate) static ENTRY_PALATALIZATIONS_4807700789809767940: VariantsMap = [
    &["palatalizations"],
    &["palatalisations"],
    &["palatalizations"],
    &["palatalisations"],
];

pub(crate) static ENTRY_PALATALIZATION_5484250888619777534: VariantsMap = [
    &["palatalization"],
    &["palatalisation"],
    &["palatalization"],
    &["palatalisation"],
];

pub(crate) static ENTRY_PALATALIZED_9802151654299491783: VariantsMap = [
    &["palatalized"],
    &["palatalised"],
    &["palatalized"],
    &["palatalised"],
];

pub(crate) static ENTRY_PALATALIZES_9060739880362868418: VariantsMap = [
    &["palatalizes"],
    &["palatalises"],
    &["palatalizes"],
    &["palatalises"],
];

pub(crate) static ENTRY_PALATALIZE_11951391819712678616: VariantsMap = [
    &["palatalize"],
    &["palatalise"],
    &["palatalize"],
    &["palatalise"],
];

pub(crate) static ENTRY_PALATALIZING_8149766451780072792: VariantsMap = [
    &["palatalizing"],
    &["palatalising"],
    &["palatalizing"],
    &["palatalising"],
];

pub(crate) static ENTRY_PALATIZATIONS_1427522090300090503: VariantsMap = [
    &["palatizations"],
    &["palatisations"],
    &["palatizations"],
    &["palatisations"],
];

pub(crate) static ENTRY_PALATIZATION_13119970299223991169: VariantsMap = [
    &["palatization"],
    &["palatisation"],
    &["palatization"],
    &["palatisation"],
];

pub(crate) static ENTRY_PALATIZES_7409196583984830669: VariantsMap = [
    &["palatizes"],
    &["palatises"],
    &["palatizes"],
    &["palatises"],
];

pub(crate) static ENTRY_PALATIZE_5247212428943117433: VariantsMap =
    [&["palatize"], &["palatise"], &["palatize"], &["palatise"]];

pub(crate) static ENTRY_PALEANTHROPIC_16127484915247367741: VariantsMap = [
    &["paleanthropic"],
    &["palaeanthropic"],
    &["palaeanthropic"],
    &["palaeanthropic"],
];

pub(crate) static ENTRY_PALEARCTIC_269034461231115236: VariantsMap = [
    &["palearctic"],
    &["palaearctic"],
    &["palearctic"],
    &["palaearctic"],
];

pub(crate) static ENTRY_PALEENCEPHALON_11148932634549019619: VariantsMap = [
    &["paleencephalon"],
    &["palaeencephalon"],
    &["palaeencephalon"],
    &["palaeencephalon"],
];

pub(crate) static ENTRY_PALEENTOMOLOGY_15712434980354703142: VariantsMap = [
    &["paleentomology"],
    &["palaeentomology"],
    &["palaeentomology"],
    &["palaeentomology"],
];

pub(crate) static ENTRY_PALEETHNOLOGICAL_4481749690646676213: VariantsMap = [
    &["paleethnological"],
    &["palaeethnological"],
    &["palaeethnological"],
    &["palaeethnological"],
];

pub(crate) static ENTRY_PALEETHNOLOGIC_8892871688742593100: VariantsMap = [
    &["paleethnologic"],
    &["palaeethnologic"],
    &["palaeethnologic"],
    &["palaeethnologic"],
];

pub(crate) static ENTRY_PALEETHNOLOGIST_6906911702331517133: VariantsMap = [
    &["paleethnologist"],
    &["palaeethnologist"],
    &["palaeethnologist"],
    &["palaeethnologist"],
];

pub(crate) static ENTRY_PALEETHNOLOGY_3869668393036843087: VariantsMap = [
    &["paleethnology"],
    &["palaeethnology"],
    &["palaeethnology"],
    &["palaeethnology"],
];

pub(crate) static ENTRY_PALEICHTHYOLOGIST_10083578482342894714: VariantsMap = [
    &["paleichthyologist"],
    &["palaeichthyologist"],
    &["palaeichthyologist"],
    &["palaeichthyologist"],
];

pub(crate) static ENTRY_PALEICHTHYOLOGY_16090612391743494942: VariantsMap = [
    &["paleichthyology"],
    &["palaeichthyology"],
    &["palaeichthyology"],
    &["palaeichthyology"],
];

pub(crate) static ENTRY_PALEOALCHEMICAL_2017386339869599932: VariantsMap = [
    &["paleoalchemical"],
    &["palaeoalchemical"],
    &["palaeoalchemical"],
    &["palaeoalchemical"],
];

pub(crate) static ENTRY_PALEOANTHROPIC_5536563183205702870: VariantsMap = [
    &["paleoanthropic"],
    &["palaeoanthropic"],
    &["palaeoanthropic"],
    &["palaeoanthropic"],
];

pub(crate) static ENTRY_PALEOANTHROPOGRAPHY_12272975649262449090: VariantsMap = [
    &["paleoanthropography"],
    &["palaeoanthropography"],
    &["palaeoanthropography"],
    &["palaeoanthropography"],
];

pub(crate) static ENTRY_PALEOANTHROPOLOGICAL_8354621329613991958: VariantsMap = [
    &["paleoanthropological"],
    &["palaeoanthropological"],
    &["palaeoanthropological"],
    &["palaeoanthropological"],
];

pub(crate) static ENTRY_PALEOANTHROPOLOGIES_574959913847154144: VariantsMap = [
    &["paleoanthropologies"],
    &["palaeoanthropologies"],
    &["palaeoanthropologies"],
    &["palaeoanthropologies"],
];

pub(crate) static ENTRY_PALEOANTHROPOLOGISTS_5480906880376936367: VariantsMap = [
    &["paleoanthropologists"],
    &["palaeoanthropologists"],
    &["palaeoanthropologists"],
    &["palaeoanthropologists"],
];

pub(crate) static ENTRY_PALEOANTHROPOLOGIST_7159496852876445664: VariantsMap = [
    &["paleoanthropologist"],
    &["palaeoanthropologist"],
    &["palaeoanthropologist"],
    &["palaeoanthropologist"],
];

pub(crate) static ENTRY_PALEOANTHROPOLOGY_9395441508658928847: VariantsMap = [
    &["paleoanthropology"],
    &["palaeoanthropology"],
    &["palaeoanthropology"],
    &["palaeoanthropology"],
];

pub(crate) static ENTRY_PALEOANTHROPUS_4669275914071277181: VariantsMap = [
    &["paleoanthropus"],
    &["palaeoanthropus"],
    &["palaeoanthropus"],
    &["palaeoanthropus"],
];

pub(crate) static ENTRY_PALEOATAVISM_10031993578414975154: VariantsMap = [
    &["paleoatavism"],
    &["palaeoatavism"],
    &["palaeoatavism"],
    &["palaeoatavism"],
];

pub(crate) static ENTRY_PALEOATAVISTIC_4298342201893698464: VariantsMap = [
    &["paleoatavistic"],
    &["palaeoatavistic"],
    &["palaeoatavistic"],
    &["palaeoatavistic"],
];

pub(crate) static ENTRY_PALEOBIOGEOGRAPHY_325937363029607315: VariantsMap = [
    &["paleobiogeography"],
    &["palaeobiogeography"],
    &["palaeobiogeography"],
    &["palaeobiogeography"],
];

pub(crate) static ENTRY_PALEOBIOLOGICAL_11068936077299560080: VariantsMap = [
    &["paleobiological"],
    &["palaeobiological"],
    &["palaeobiological"],
    &["palaeobiological"],
];

pub(crate) static ENTRY_PALEOBIOLOGIC_4482534007872730058: VariantsMap = [
    &["paleobiologic"],
    &["palaeobiologic"],
    &["palaeobiologic"],
    &["palaeobiologic"],
];

pub(crate) static ENTRY_PALEOBIOLOGIES_16079649969733714006: VariantsMap = [
    &["paleobiologies"],
    &["palaeobiologies"],
    &["palaeobiologies"],
    &["palaeobiologies"],
];

pub(crate) static ENTRY_PALEOBIOLOGISTS_5556956387839510467: VariantsMap = [
    &["paleobiologists"],
    &["palaeobiologists"],
    &["palaeobiologists"],
    &["palaeobiologists"],
];

pub(crate) static ENTRY_PALEOBIOLOGIST_11463263721083732972: VariantsMap = [
    &["paleobiologist"],
    &["palaeobiologist"],
    &["palaeobiologist"],
    &["palaeobiologist"],
];

pub(crate) static ENTRY_PALEOBIOLOGY_516075182383032405: VariantsMap = [
    &["paleobiology"],
    &["palaeobiology"],
    &["palaeobiology"],
    &["palaeobiology"],
];

pub(crate) static ENTRY_PALEOBOTANICALLY_8114378639258087733: VariantsMap = [
    &["paleobotanically"],
    &["palaeobotanically"],
    &["palaeobotanically"],
    &["palaeobotanically"],
];

pub(crate) static ENTRY_PALEOBOTANICAL_6725030604787116294: VariantsMap = [
    &["paleobotanical"],
    &["palaeobotanical"],
    &["palaeobotanical"],
    &["palaeobotanical"],
];

pub(crate) static ENTRY_PALEOBOTANIC_15818878290850712580: VariantsMap = [
    &["paleobotanic"],
    &["palaeobotanic"],
    &["palaeobotanic"],
    &["palaeobotanic"],
];

pub(crate) static ENTRY_PALEOBOTANIES_3595430527233437089: VariantsMap = [
    &["paleobotanies"],
    &["palaeobotanies"],
    &["palaeobotanies"],
    &["palaeobotanies"],
];

pub(crate) static ENTRY_PALEOBOTANISTS_12893724949436199492: VariantsMap = [
    &["paleobotanists"],
    &["palaeobotanists"],
    &["palaeobotanists"],
    &["palaeobotanists"],
];

pub(crate) static ENTRY_PALEOBOTANIST_12652116508136864156: VariantsMap = [
    &["paleobotanist"],
    &["palaeobotanist"],
    &["palaeobotanist"],
    &["palaeobotanist"],
];

pub(crate) static ENTRY_PALEOBOTANY_15311510435996174332: VariantsMap = [
    &["paleobotany"],
    &["palaeobotany"],
    &["palaeobotany"],
    &["palaeobotany"],
];

pub(crate) static ENTRY_PALEOCEANOGRAPHY_14962055579685652535: VariantsMap = [
    &["paleoceanography"],
    &["palaeoceanography"],
    &["palaeoceanography"],
    &["palaeoceanography"],
];

pub(crate) static ENTRY_PALEOCHOROLOGY_850601678065927399: VariantsMap = [
    &["paleochorology"],
    &["palaeochorology"],
    &["palaeochorology"],
    &["palaeochorology"],
];

pub(crate) static ENTRY_PALEOCLIMATIC_6296078474332592218: VariantsMap = [
    &["paleoclimatic"],
    &["palaeoclimatic"],
    &["palaeoclimatic"],
    &["palaeoclimatic"],
];

pub(crate) static ENTRY_PALEOCLIMATOLOGICAL_10778161163245213013: VariantsMap = [
    &["paleoclimatological"],
    &["palaeoclimatological"],
    &["palaeoclimatological"],
    &["palaeoclimatological"],
];

pub(crate) static ENTRY_PALEOCLIMATOLOGIC_16629931497670783741: VariantsMap = [
    &["paleoclimatologic"],
    &["palaeoclimatologic"],
    &["palaeoclimatologic"],
    &["palaeoclimatologic"],
];

pub(crate) static ENTRY_PALEOCLIMATOLOGIES_11917584077388492841: VariantsMap = [
    &["paleoclimatologies"],
    &["palaeoclimatologies"],
    &["paleoclimatologies"],
    &["palaeoclimatologies"],
];

pub(crate) static ENTRY_PALEOCLIMATOLOGISTS_1702175029968282301: VariantsMap = [
    &["paleoclimatologists"],
    &["palaeoclimatologists"],
    &["palaeoclimatologists"],
    &["palaeoclimatologists"],
];

pub(crate) static ENTRY_PALEOCLIMATOLOGIST_11724353766703176409: VariantsMap = [
    &["paleoclimatologist"],
    &["palaeoclimatologist"],
    &["palaeoclimatologist"],
    &["palaeoclimatologist"],
];

pub(crate) static ENTRY_PALEOCLIMATOLOGY_1888923764675563721: VariantsMap = [
    &["paleoclimatology"],
    &["palaeoclimatology"],
    &["paleoclimatology"],
    &["palaeoclimatology"],
];

pub(crate) static ENTRY_PALEOCONCHA_12575460314070906956: VariantsMap = [
    &["paleoconcha"],
    &["palaeoconcha"],
    &["palaeoconcha"],
    &["palaeoconcha"],
];

pub(crate) static ENTRY_PALEOCOSMIC_8220601833060404387: VariantsMap = [
    &["paleocosmic"],
    &["palaeocosmic"],
    &["palaeocosmic"],
    &["palaeocosmic"],
];

pub(crate) static ENTRY_PALEOCOSMOLOGY_3054270398344471213: VariantsMap = [
    &["paleocosmology"],
    &["palaeocosmology"],
    &["palaeocosmology"],
    &["palaeocosmology"],
];

pub(crate) static ENTRY_PALEOCRYSTALLIC_7687563109158345160: VariantsMap = [
    &["paleocrystallic"],
    &["palaeocrystallic"],
    &["palaeocrystallic"],
    &["palaeocrystallic"],
];

pub(crate) static ENTRY_PALEOCRYSTALLINE_16791923438113684889: VariantsMap = [
    &["paleocrystalline"],
    &["palaeocrystalline"],
    &["palaeocrystalline"],
    &["palaeocrystalline"],
];

pub(crate) static ENTRY_PALEOCRYSTAL_6061679730436734129: VariantsMap = [
    &["paleocrystal"],
    &["palaeocrystal"],
    &["palaeocrystal"],
    &["palaeocrystal"],
];

pub(crate) static ENTRY_PALEOCRYSTIC_6917970529581792050: VariantsMap = [
    &["paleocrystic"],
    &["palaeocrystic"],
    &["palaeocrystic"],
    &["palaeocrystic"],
];

pub(crate) static ENTRY_PALEOCYCLIC_2933965135068085885: VariantsMap = [
    &["paleocyclic"],
    &["palaeocyclic"],
    &["palaeocyclic"],
    &["palaeocyclic"],
];

pub(crate) static ENTRY_PALEODENDROLOGICALLY_10449298583529356832: VariantsMap = [
    &["paleodendrologically"],
    &["palaeodendrologically"],
    &["palaeodendrologically"],
    &["palaeodendrologically"],
];

pub(crate) static ENTRY_PALEODENDROLOGICAL_16026323992623885288: VariantsMap = [
    &["paleodendrological"],
    &["palaeodendrological"],
    &["palaeodendrological"],
    &["palaeodendrological"],
];

pub(crate) static ENTRY_PALEODENDROLOGIC_6856992872417007321: VariantsMap = [
    &["paleodendrologic"],
    &["palaeodendrologic"],
    &["palaeodendrologic"],
    &["palaeodendrologic"],
];

pub(crate) static ENTRY_PALEODENDROLOGIST_3579987086039471029: VariantsMap = [
    &["paleodendrologist"],
    &["palaeodendrologist"],
    &["palaeodendrologist"],
    &["palaeodendrologist"],
];

pub(crate) static ENTRY_PALEODENDROLOGY_644708576508951069: VariantsMap = [
    &["paleodendrology"],
    &["palaeodendrology"],
    &["palaeodendrology"],
    &["palaeodendrology"],
];

pub(crate) static ENTRY_PALEOECOLOGICAL_12243112048304818096: VariantsMap = [
    &["paleoecological"],
    &["palaeoecological"],
    &["palaeoecological"],
    &["palaeoecological"],
];

pub(crate) static ENTRY_PALEOECOLOGIC_4669354935242540330: VariantsMap = [
    &["paleoecologic"],
    &["palaeoecologic"],
    &["palaeoecologic"],
    &["palaeoecologic"],
];

pub(crate) static ENTRY_PALEOECOLOGIES_18110959250046855627: VariantsMap = [
    &["paleoecologies"],
    &["palaeoecologies"],
    &["paleoecologies"],
    &["palaeoecologies"],
];

pub(crate) static ENTRY_PALEOECOLOGISTS_3308516876293590602: VariantsMap = [
    &["paleoecologists"],
    &["palaeoecologists"],
    &["palaeoecologists"],
    &["palaeoecologists"],
];

pub(crate) static ENTRY_PALEOECOLOGIST_8254000552693957088: VariantsMap = [
    &["paleoecologist"],
    &["palaeoecologist"],
    &["palaeoecologist"],
    &["palaeoecologist"],
];

pub(crate) static ENTRY_PALEOECOLOGY_4482816158539091906: VariantsMap = [
    &["paleoecology"],
    &["palaeoecology"],
    &["paleoecology"],
    &["palaeoecology"],
];

pub(crate) static ENTRY_PALEOENCEPHALON_9569832069668177801: VariantsMap = [
    &["paleoencephalon"],
    &["palaeoencephalon"],
    &["palaeoencephalon"],
    &["palaeoencephalon"],
];

pub(crate) static ENTRY_PALEOENTOMOLOGICAL_16493536171383050969: VariantsMap = [
    &["paleoentomological"],
    &["palaeoentomological"],
    &["palaeoentomological"],
    &["palaeoentomological"],
];

pub(crate) static ENTRY_PALEOENTOMOLOGIC_4007524847624498176: VariantsMap = [
    &["paleoentomologic"],
    &["palaeoentomologic"],
    &["palaeoentomologic"],
    &["palaeoentomologic"],
];

pub(crate) static ENTRY_PALEOENTOMOLOGIST_5004696292111737108: VariantsMap = [
    &["paleoentomologist"],
    &["palaeoentomologist"],
    &["palaeoentomologist"],
    &["palaeoentomologist"],
];

pub(crate) static ENTRY_PALEOEREMOLOGY_179203799725486477: VariantsMap = [
    &["paleoeremology"],
    &["palaeoeremology"],
    &["palaeoeremology"],
    &["palaeoeremology"],
];

pub(crate) static ENTRY_PALEOETHNIC_18256982848006324404: VariantsMap = [
    &["paleoethnic"],
    &["palaeoethnic"],
    &["palaeoethnic"],
    &["palaeoethnic"],
];

pub(crate) static ENTRY_PALEOETHNOGRAPHY_4293329065986396408: VariantsMap = [
    &["paleoethnography"],
    &["palaeoethnography"],
    &["palaeoethnography"],
    &["palaeoethnography"],
];

pub(crate) static ENTRY_PALEOETHNOLOGICAL_2716015278756182228: VariantsMap = [
    &["paleoethnological"],
    &["palaeoethnological"],
    &["palaeoethnological"],
    &["palaeoethnological"],
];

pub(crate) static ENTRY_PALEOETHNOLOGIC_3941018589215004237: VariantsMap = [
    &["paleoethnologic"],
    &["palaeoethnologic"],
    &["palaeoethnologic"],
    &["palaeoethnologic"],
];

pub(crate) static ENTRY_PALEOETHNOLOGIST_5288127538766606384: VariantsMap = [
    &["paleoethnologist"],
    &["palaeoethnologist"],
    &["palaeoethnologist"],
    &["palaeoethnologist"],
];

pub(crate) static ENTRY_PALEOETHNOLOGY_4385814784718071920: VariantsMap = [
    &["paleoethnology"],
    &["palaeoethnology"],
    &["palaeoethnology"],
    &["palaeoethnology"],
];

pub(crate) static ENTRY_PALEOFAUNA_14514918396801724693: VariantsMap = [
    &["paleofauna"],
    &["palaeofauna"],
    &["palaeofauna"],
    &["palaeofauna"],
];

pub(crate) static ENTRY_PALEOGENESIS_17234588466739986743: VariantsMap = [
    &["paleogenesis"],
    &["palaeogenesis"],
    &["palaeogenesis"],
    &["palaeogenesis"],
];

pub(crate) static ENTRY_PALEOGENETIC_3671327870094791359: VariantsMap = [
    &["paleogenetic"],
    &["palaeogenetic"],
    &["palaeogenetic"],
    &["palaeogenetic"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHERS_17925499304699862812: VariantsMap = [
    &["paleogeographers"],
    &["palaeogeographers"],
    &["palaeogeographers"],
    &["palaeogeographers"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHER_7865313036683833980: VariantsMap = [
    &["paleogeographer"],
    &["palaeogeographer"],
    &["palaeogeographer"],
    &["palaeogeographer"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHICALLY_15437320738294900083: VariantsMap = [
    &["paleogeographically"],
    &["palaeogeographically"],
    &["palaeogeographically"],
    &["palaeogeographically"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHICAL_16657456835077012317: VariantsMap = [
    &["paleogeographical"],
    &["palaeogeographical"],
    &["palaeogeographical"],
    &["palaeogeographical"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHIC_12366567756392166026: VariantsMap = [
    &["paleogeographic"],
    &["palaeogeographic"],
    &["palaeogeographic"],
    &["palaeogeographic"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHIES_12038367756274519862: VariantsMap = [
    &["paleogeographies"],
    &["palaeogeographies"],
    &["paleogeographies"],
    &["palaeogeographies"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHY_14735924833615110050: VariantsMap = [
    &["paleogeography"],
    &["palaeogeography"],
    &["paleogeography"],
    &["palaeogeography"],
];

pub(crate) static ENTRY_PALEOGEOLOGY_10091590621653936254: VariantsMap = [
    &["paleogeology"],
    &["palaeogeology"],
    &["palaeogeology"],
    &["palaeogeology"],
];

pub(crate) static ENTRY_PALEOGLACIOLOGY_16037720465585450625: VariantsMap = [
    &["paleoglaciology"],
    &["palaeoglaciology"],
    &["palaeoglaciology"],
    &["palaeoglaciology"],
];

pub(crate) static ENTRY_PALEOGLYPH_15930058668062136413: VariantsMap = [
    &["paleoglyph"],
    &["palaeoglyph"],
    &["palaeoglyph"],
    &["palaeoglyph"],
];

pub(crate) static ENTRY_PALEOGRAPHICALLY_10052249768233307285: VariantsMap = [
    &["paleographically"],
    &["palaeographically"],
    &["palaeographically"],
    &["palaeographically"],
];

pub(crate) static ENTRY_PALEOGRAPHICAL_4607017356275969347: VariantsMap = [
    &["paleographical"],
    &["palaeographical"],
    &["palaeographical"],
    &["palaeographical"],
];

pub(crate) static ENTRY_PALEOGRAPHIC_8091858415531998756: VariantsMap = [
    &["paleographic"],
    &["palaeographic"],
    &["palaeographic"],
    &["palaeographic"],
];

pub(crate) static ENTRY_PALEOGRAPHIST_16452384260584578278: VariantsMap = [
    &["paleographist"],
    &["palaeographist"],
    &["palaeographist"],
    &["palaeographist"],
];

pub(crate) static ENTRY_PALEOGRAPH_13677256025266645311: VariantsMap = [
    &["paleograph"],
    &["palaeograph"],
    &["palaeograph"],
    &["palaeograph"],
];

pub(crate) static ENTRY_PALEOHERPETOLOGIST_3262925931087486684: VariantsMap = [
    &["paleoherpetologist"],
    &["palaeoherpetologist"],
    &["palaeoherpetologist"],
    &["palaeoherpetologist"],
];

pub(crate) static ENTRY_PALEOHERPETOLOGY_10885033853235926434: VariantsMap = [
    &["paleoherpetology"],
    &["palaeoherpetology"],
    &["palaeoherpetology"],
    &["palaeoherpetology"],
];

pub(crate) static ENTRY_PALEOHISTOLOGY_8638825422062573518: VariantsMap = [
    &["paleohistology"],
    &["palaeohistology"],
    &["palaeohistology"],
    &["palaeohistology"],
];

pub(crate) static ENTRY_PALEOHYDROGRAPHY_2971028169559708924: VariantsMap = [
    &["paleohydrography"],
    &["palaeohydrography"],
    &["palaeohydrography"],
    &["palaeohydrography"],
];

pub(crate) static ENTRY_PALEOICHTHYOLOGY_16030251089000297685: VariantsMap = [
    &["paleoichthyology"],
    &["palaeoichthyology"],
    &["palaeoichthyology"],
    &["palaeoichthyology"],
];

pub(crate) static ENTRY_PALEOLATRY_14450699210706774620: VariantsMap = [
    &["paleolatry"],
    &["palaeolatry"],
    &["palaeolatry"],
    &["palaeolatry"],
];

pub(crate) static ENTRY_PALEOLIMNOLOGY_1236880097590741596: VariantsMap = [
    &["paleolimnology"],
    &["palaeolimnology"],
    &["palaeolimnology"],
    &["palaeolimnology"],
];

pub(crate) static ENTRY_PALEOLITHICAL_1935974690293577369: VariantsMap = [
    &["paleolithical"],
    &["palaeolithical"],
    &["palaeolithical"],
    &["palaeolithical"],
];

pub(crate) static ENTRY_PALEOLITHIC_10579173722626414001: VariantsMap = [
    &["paleolithic"],
    &["palaeolithic"],
    &["paleolithic"],
    &["palaeolithic"],
];

pub(crate) static ENTRY_PALEOLITHIST_9458879760716165734: VariantsMap = [
    &["paleolithist"],
    &["palaeolithist"],
    &["palaeolithist"],
    &["palaeolithist"],
];

pub(crate) static ENTRY_PALEOLITHOID_6543358911316320294: VariantsMap = [
    &["paleolithoid"],
    &["palaeolithoid"],
    &["palaeolithoid"],
    &["palaeolithoid"],
];

pub(crate) static ENTRY_PALEOLITHS_7568765529239450192: VariantsMap = [
    &["paleoliths"],
    &["palaeoliths"],
    &["palaeoliths"],
    &["palaeoliths"],
];

pub(crate) static ENTRY_PALEOLITHY_7860170771676717319: VariantsMap = [
    &["paleolithy"],
    &["palaeolithy"],
    &["palaeolithy"],
    &["palaeolithy"],
];

pub(crate) static ENTRY_PALEOLITH_12363554094675316318: VariantsMap = [
    &["paleolith"],
    &["palaeolith"],
    &["palaeolith"],
    &["palaeolith"],
];

pub(crate) static ENTRY_PALEOLOGICAL_1841349892746131160: VariantsMap = [
    &["paleological"],
    &["palaeological"],
    &["palaeological"],
    &["palaeological"],
];

pub(crate) static ENTRY_PALEOLOGIST_1275103816971686493: VariantsMap = [
    &["paleologist"],
    &["palaeologist"],
    &["palaeologist"],
    &["palaeologist"],
];

pub(crate) static ENTRY_PALEOLOGY_9039082638538518660: VariantsMap = [
    &["paleology"],
    &["palaeology"],
    &["palaeology"],
    &["palaeology"],
];

pub(crate) static ENTRY_PALEOMAGNETISMS_11618371615606652138: VariantsMap = [
    &["paleomagnetisms"],
    &["palaeomagnetisms"],
    &["palaeomagnetisms"],
    &["palaeomagnetisms"],
];

pub(crate) static ENTRY_PALEOMAGNETISM_10382230568315308075: VariantsMap = [
    &["paleomagnetism"],
    &["palaeomagnetism"],
    &["palaeomagnetism"],
    &["palaeomagnetism"],
];

pub(crate) static ENTRY_PALEOMETALLIC_1327931506117283329: VariantsMap = [
    &["paleometallic"],
    &["palaeometallic"],
    &["palaeometallic"],
    &["palaeometallic"],
];

pub(crate) static ENTRY_PALEOMETEOROLOGICAL_13764122166986418655: VariantsMap = [
    &["paleometeorological"],
    &["palaeometeorological"],
    &["palaeometeorological"],
    &["palaeometeorological"],
];

pub(crate) static ENTRY_PALEOMETEOROLOGY_5577530218919631079: VariantsMap = [
    &["paleometeorology"],
    &["palaeometeorology"],
    &["palaeometeorology"],
    &["palaeometeorology"],
];

pub(crate) static ENTRY_PALEONTOGRAPHICAL_8390709172465677724: VariantsMap = [
    &["paleontographical"],
    &["palaeontographical"],
    &["palaeontographical"],
    &["palaeontographical"],
];

pub(crate) static ENTRY_PALEONTOGRAPHIC_8614487224686150719: VariantsMap = [
    &["paleontographic"],
    &["palaeontographic"],
    &["palaeontographic"],
    &["palaeontographic"],
];

pub(crate) static ENTRY_PALEONTOGRAPHIES_6412037643243713928: VariantsMap = [
    &["paleontographies"],
    &["palaeontographies"],
    &["palaeontographies"],
    &["palaeontographies"],
];

pub(crate) static ENTRY_PALEONTOGRAPHY_15155568729047027987: VariantsMap = [
    &["paleontography"],
    &["palaeontography"],
    &["palaeontography"],
    &["palaeontography"],
];

pub(crate) static ENTRY_PALEONTOLOGICALLY_7795552250402863412: VariantsMap = [
    &["paleontologically"],
    &["palaeontologically"],
    &["palaeontologically"],
    &["palaeontologically"],
];

pub(crate) static ENTRY_PALEONTOLOGICAL_11378757918485663576: VariantsMap = [
    &["paleontological"],
    &["palaeontological"],
    &["paleontological"],
    &["palaeontological"],
];

pub(crate) static ENTRY_PALEONTOLOGIC_9726526633122558228: VariantsMap = [
    &["paleontologic"],
    &["palaeontologic"],
    &["palaeontologic"],
    &["palaeontologic"],
];

pub(crate) static ENTRY_PALEONTOLOGISTS_1615341850049645435: VariantsMap = [
    &["paleontologists"],
    &["palaeontologists"],
    &["paleontologists"],
    &["palaeontologists"],
];

pub(crate) static ENTRY_PALEONTOLOGIST_14409308310083449867: VariantsMap = [
    &["paleontologist"],
    &["palaeontologist"],
    &["paleontologist"],
    &["palaeontologist"],
];

pub(crate) static ENTRY_PALEONTOLOGY_8727472879076855658: VariantsMap = [
    &["paleontology"],
    &["palaeontology"],
    &["paleontology"],
    &["palaeontology"],
];

pub(crate) static ENTRY_PALEONTOL_16908832703236553374: VariantsMap = [
    &["paleontol"],
    &["palaeontol"],
    &["palaeontol"],
    &["palaeontol"],
];

pub(crate) static ENTRY_PALEOPATHOLOGICAL_6355077786853784135: VariantsMap = [
    &["paleopathological"],
    &["palaeopathological"],
    &["palaeopathological"],
    &["palaeopathological"],
];

pub(crate) static ENTRY_PALEOPATHOLOGIC_8048979982047381626: VariantsMap = [
    &["paleopathologic"],
    &["palaeopathologic"],
    &["palaeopathologic"],
    &["palaeopathologic"],
];

pub(crate) static ENTRY_PALEOPATHOLOGIES_3907569211124295484: VariantsMap = [
    &["paleopathologies"],
    &["palaeopathologies"],
    &["palaeopathologies"],
    &["palaeopathologies"],
];

pub(crate) static ENTRY_PALEOPATHOLOGISTS_16699786230783410448: VariantsMap = [
    &["paleopathologists"],
    &["palaeopathologists"],
    &["palaeopathologists"],
    &["palaeopathologists"],
];

pub(crate) static ENTRY_PALEOPATHOLOGIST_11591525888140398394: VariantsMap = [
    &["paleopathologist"],
    &["palaeopathologist"],
    &["palaeopathologist"],
    &["palaeopathologist"],
];

pub(crate) static ENTRY_PALEOPATHOLOGY_3434376491146064878: VariantsMap = [
    &["paleopathology"],
    &["palaeopathology"],
    &["palaeopathology"],
    &["palaeopathology"],
];

pub(crate) static ENTRY_PALEOPEDOLOGY_3869256322046937665: VariantsMap = [
    &["paleopedology"],
    &["palaeopedology"],
    &["palaeopedology"],
    &["palaeopedology"],
];

pub(crate) static ENTRY_PALEOPHYSIOGRAPHY_11544580360735995612: VariantsMap = [
    &["paleophysiography"],
    &["palaeophysiography"],
    &["palaeophysiography"],
    &["palaeophysiography"],
];

pub(crate) static ENTRY_PALEOPHYSIOLOGY_15071752915664349110: VariantsMap = [
    &["paleophysiology"],
    &["palaeophysiology"],
    &["palaeophysiology"],
    &["palaeophysiology"],
];

pub(crate) static ENTRY_PALEOPHYTIC_6789302132283036079: VariantsMap = [
    &["paleophytic"],
    &["palaeophytic"],
    &["palaeophytic"],
    &["palaeophytic"],
];

pub(crate) static ENTRY_PALEOPHYTOLOGICAL_5744086473592891476: VariantsMap = [
    &["paleophytological"],
    &["palaeophytological"],
    &["palaeophytological"],
    &["palaeophytological"],
];

pub(crate) static ENTRY_PALEOPHYTOLOGIST_10785914590748470485: VariantsMap = [
    &["paleophytologist"],
    &["palaeophytologist"],
    &["palaeophytologist"],
    &["palaeophytologist"],
];

pub(crate) static ENTRY_PALEOPHYTOLOGY_3952145533872729647: VariantsMap = [
    &["paleophytology"],
    &["palaeophytology"],
    &["palaeophytology"],
    &["palaeophytology"],
];

pub(crate) static ENTRY_PALEOPLAIN_4445180941860383489: VariantsMap = [
    &["paleoplain"],
    &["palaeoplain"],
    &["palaeoplain"],
    &["palaeoplain"],
];

pub(crate) static ENTRY_PALEOPOTAMOLOGY_9728822371435540856: VariantsMap = [
    &["paleopotamology"],
    &["palaeopotamology"],
    &["palaeopotamology"],
    &["palaeopotamology"],
];

pub(crate) static ENTRY_PALEOPSYCHIC_1286029760595353697: VariantsMap = [
    &["paleopsychic"],
    &["palaeopsychic"],
    &["palaeopsychic"],
    &["palaeopsychic"],
];

pub(crate) static ENTRY_PALEOPSYCHOLOGICAL_8115976081179191215: VariantsMap = [
    &["paleopsychological"],
    &["palaeopsychological"],
    &["palaeopsychological"],
    &["palaeopsychological"],
];

pub(crate) static ENTRY_PALEOPSYCHOLOGY_14002375044163854176: VariantsMap = [
    &["paleopsychology"],
    &["palaeopsychology"],
    &["palaeopsychology"],
    &["palaeopsychology"],
];

pub(crate) static ENTRY_PALEORNITHOLOGICAL_6805615354003961394: VariantsMap = [
    &["paleornithological"],
    &["palaeornithological"],
    &["palaeornithological"],
    &["palaeornithological"],
];

pub(crate) static ENTRY_PALEORNITHOLOGY_4480620476474604419: VariantsMap = [
    &["paleornithology"],
    &["palaeornithology"],
    &["palaeornithology"],
    &["palaeornithology"],
];

pub(crate) static ENTRY_PALEOSTRIATAL_17033529618847936065: VariantsMap = [
    &["paleostriatal"],
    &["palaeostriatal"],
    &["palaeostriatal"],
    &["palaeostriatal"],
];

pub(crate) static ENTRY_PALEOSTRIATUM_8135708815680998194: VariantsMap = [
    &["paleostriatum"],
    &["palaeostriatum"],
    &["palaeostriatum"],
    &["palaeostriatum"],
];

pub(crate) static ENTRY_PALEOSTYLIC_13586027329666518772: VariantsMap = [
    &["paleostylic"],
    &["palaeostylic"],
    &["palaeostylic"],
    &["palaeostylic"],
];

pub(crate) static ENTRY_PALEOSTYLY_329937646655027738: VariantsMap = [
    &["paleostyly"],
    &["palaeostyly"],
    &["palaeostyly"],
    &["palaeostyly"],
];

pub(crate) static ENTRY_PALEOTECHNIC_9551091213770179886: VariantsMap = [
    &["paleotechnic"],
    &["palaeotechnic"],
    &["palaeotechnic"],
    &["palaeotechnic"],
];

pub(crate) static ENTRY_PALEOTHALAMUS_10925563677009720429: VariantsMap = [
    &["paleothalamus"],
    &["palaeothalamus"],
    &["palaeothalamus"],
    &["palaeothalamus"],
];

pub(crate) static ENTRY_PALEOTROPICAL_18065203176296129763: VariantsMap = [
    &["paleotropical"],
    &["palaeotropical"],
    &["palaeotropical"],
    &["palaeotropical"],
];

pub(crate) static ENTRY_PALEOVOLCANIC_1100245805130475160: VariantsMap = [
    &["paleovolcanic"],
    &["palaeovolcanic"],
    &["palaeovolcanic"],
    &["palaeovolcanic"],
];

pub(crate) static ENTRY_PALEOZOIC_2171352618595825046: VariantsMap = [
    &["paleozoic"],
    &["palaeozoic"],
    &["palaeozoic"],
    &["palaeozoic"],
];

pub(crate) static ENTRY_PALEOZOOLOGICAL_7651649713235051506: VariantsMap = [
    &["paleozoological"],
    &["palaeozoological"],
    &["palaeozoological"],
    &["palaeozoological"],
];

pub(crate) static ENTRY_PALEOZOOLOGIC_12472183251804979806: VariantsMap = [
    &["paleozoologic"],
    &["palaeozoologic"],
    &["palaeozoologic"],
    &["palaeozoologic"],
];

pub(crate) static ENTRY_PALEOZOOLOGIES_17902367901707184491: VariantsMap = [
    &["paleozoologies"],
    &["palaeozoologies"],
    &["palaeozoologies"],
    &["palaeozoologies"],
];

pub(crate) static ENTRY_PALEOZOOLOGISTS_6609845946465372037: VariantsMap = [
    &["paleozoologists"],
    &["palaeozoologists"],
    &["palaeozoologists"],
    &["palaeozoologists"],
];

pub(crate) static ENTRY_PALEOZOOLOGIST_4602703364020254946: VariantsMap = [
    &["paleozoologist"],
    &["palaeozoologist"],
    &["palaeozoologist"],
    &["palaeozoologist"],
];

pub(crate) static ENTRY_PALEOZOOLOGY_5066201776927454990: VariantsMap = [
    &["paleozoology"],
    &["palaeozoology"],
    &["palaeozoology"],
    &["palaeozoology"],
];

pub(crate) static ENTRY_PALESTRAE_14184714476900356877: VariantsMap = [
    &["palestrae"],
    &["palaestrae"],
    &["palaestrae"],
    &["palaestrae"],
];

pub(crate) static ENTRY_PALESTRAL_17875036424127182820: VariantsMap = [
    &["palestral"],
    &["palaestral"],
    &["palaestral"],
    &["palaestral"],
];

pub(crate) static ENTRY_PALESTRAS_18241821718554443326: VariantsMap = [
    &["palestras"],
    &["palaestras"],
    &["palaestras"],
    &["palaestras"],
];

pub(crate) static ENTRY_PALESTRA_15858313904716663869: VariantsMap = [
    &["palestra"],
    &["palaestra"],
    &["palaestra"],
    &["palaestra"],
];

pub(crate) static ENTRY_PALESTRIAN_16430867387330520444: VariantsMap = [
    &["palestrian"],
    &["palaestrian"],
    &["palaestrian"],
    &["palaestrian"],
];

pub(crate) static ENTRY_PALESTRIC_10702847815072409215: VariantsMap = [
    &["palestric"],
    &["palaestric"],
    &["palaestric"],
    &["palaestric"],
];

pub(crate) static ENTRY_PALETIOLOGY_4388412756789031487: VariantsMap = [
    &["paletiology"],
    &["palaetiology"],
    &["palaetiology"],
    &["palaetiology"],
];

pub(crate) static ENTRY_PALLADIUMIZES_1909221670496633613: VariantsMap = [
    &["palladiumizes"],
    &["palladiumises"],
    &["palladiumizes"],
    &["palladiumises"],
];

pub(crate) static ENTRY_PALLADIUMIZE_4224398356428570618: VariantsMap = [
    &["palladiumize"],
    &["palladiumise"],
    &["palladiumize"],
    &["palladiumise"],
];

pub(crate) static ENTRY_PALLETIZATIONS_18403803161909956898: VariantsMap = [
    &["palletizations"],
    &["palletisations"],
    &["palletizations"],
    &["palletisations"],
];

pub(crate) static ENTRY_PALLETIZATION_8304716403450886029: VariantsMap = [
    &["palletization"],
    &["palletisation"],
    &["palletization"],
    &["palletisation"],
];

pub(crate) static ENTRY_PALLETIZED_7486422692101120739: VariantsMap = [
    &["palletized"],
    &["palletised"],
    &["palletized"],
    &["palletised"],
];

pub(crate) static ENTRY_PALLETIZERS_11136958979392472544: VariantsMap = [
    &["palletizers"],
    &["palletisers"],
    &["palletizers"],
    &["palletisers"],
];

pub(crate) static ENTRY_PALLETIZER_2834663411422436703: VariantsMap = [
    &["palletizer"],
    &["palletiser"],
    &["palletizer"],
    &["palletiser"],
];

pub(crate) static ENTRY_PALLETIZES_16047276413399886354: VariantsMap = [
    &["palletizes"],
    &["palletises"],
    &["palletizes"],
    &["palletises"],
];

pub(crate) static ENTRY_PALLETIZE_7471981148190319796: VariantsMap = [
    &["palletize"],
    &["palletise"],
    &["palletize"],
    &["palletise"],
];

pub(crate) static ENTRY_PALLETIZING_11317686306337242707: VariantsMap = [
    &["palletizing"],
    &["palletising"],
    &["palletizing"],
    &["palletising"],
];

pub(crate) static ENTRY_PAMPERIZES_17242646056475121067: VariantsMap = [
    &["pamperizes"],
    &["pamperises"],
    &["pamperizes"],
    &["pamperises"],
];

pub(crate) static ENTRY_PAMPERIZE_15290111866003819228: VariantsMap = [
    &["pamperize"],
    &["pamperise"],
    &["pamperize"],
    &["pamperise"],
];

pub(crate) static ENTRY_PAMPHLETIZES_7614193080459247598: VariantsMap = [
    &["pamphletizes"],
    &["pamphletises"],
    &["pamphletizes"],
    &["pamphletises"],
];

pub(crate) static ENTRY_PAMPHLETIZE_3783375103913911282: VariantsMap = [
    &["pamphletize"],
    &["pamphletise"],
    &["pamphletize"],
    &["pamphletise"],
];

pub(crate) static ENTRY_PANDERIZES_5781283006745603488: VariantsMap = [
    &["panderizes"],
    &["panderises"],
    &["panderizes"],
    &["panderises"],
];

pub(crate) static ENTRY_PANDERIZE_9746369180172729455: VariantsMap = [
    &["panderize"],
    &["panderise"],
    &["panderize"],
    &["panderise"],
];

pub(crate) static ENTRY_PANDORA_6847060433331710267: VariantsMap =
    [&["pandora"], &["pandoura"], &["pandoura"], &["pandoura"]];

pub(crate) static ENTRY_PANEGYRIZED_1510999540705297287: VariantsMap = [
    &["panegyrized"],
    &["panegyrised"],
    &["panegyrized"],
    &["panegyrised"],
];

pub(crate) static ENTRY_PANEGYRIZES_614276823774184510: VariantsMap = [
    &["panegyrizes"],
    &["panegyrises"],
    &["panegyrizes"],
    &["panegyrises"],
];

pub(crate) static ENTRY_PANEGYRIZE_464787387720568012: VariantsMap = [
    &["panegyrize"],
    &["panegyrise"],
    &["panegyrize"],
    &["panegyrise"],
];

pub(crate) static ENTRY_PANEGYRIZING_7503940443087587961: VariantsMap = [
    &["panegyrizing"],
    &["panegyrising"],
    &["panegyrizing"],
    &["panegyrising"],
];

pub(crate) static ENTRY_PANELED_12586780164955993512: VariantsMap =
    [&["paneled"], &["panelled"], &["panelled"], &["panelled"]];

pub(crate) static ENTRY_PANELINGS_11260550015389622953: VariantsMap = [
    &["panelings"],
    &["panellings"],
    &["panellings"],
    &["panellings"],
];

pub(crate) static ENTRY_PANELING_8089572046105071609: VariantsMap = [
    &["paneling"],
    &["panelling"],
    &["panelling"],
    &["panelling"],
];

pub(crate) static ENTRY_PANELISTS_16863143863031647099: VariantsMap = [
    &["panelists"],
    &["panellists"],
    &["panellists"],
    &["panellists"],
];

pub(crate) static ENTRY_PANELIST_3043263775088249330: VariantsMap = [
    &["panelist"],
    &["panellist"],
    &["panellist"],
    &["panellist"],
];

pub(crate) static ENTRY_PANELIZATION_1723586301806345893: VariantsMap = [
    &["panelization"],
    &["panellisation"],
    &["panellization"],
    &["panellisation"],
];

pub(crate) static ENTRY_PANELIZED_10063143549086734887: VariantsMap = [
    &["panelized"],
    &["panelised"],
    &["panelized"],
    &["panelised"],
];

pub(crate) static ENTRY_PANESTHESIAS_2205607449667143893: VariantsMap = [
    &["panesthesias"],
    &["panaesthesias"],
    &["panaesthesias"],
    &["panaesthesias"],
];

pub(crate) static ENTRY_PANESTHESIA_5954150154376905982: VariantsMap = [
    &["panesthesia"],
    &["panaesthesia"],
    &["panaesthesia"],
    &["panaesthesia"],
];

pub(crate) static ENTRY_PANESTHETIC_15762002620434117648: VariantsMap = [
    &["panesthetic"],
    &["panaesthetic"],
    &["panaesthetic"],
    &["panaesthetic"],
];

pub(crate) static ENTRY_PANGEA_15349461870177052673: VariantsMap =
    [&["pangea"], &["pangaea"], &["pangaea"], &["pangaea"]];

pub(crate) static ENTRY_PANOMPHEAN_11042013803124847042: VariantsMap = [
    &["panomphean"],
    &["panomphaean"],
    &["panomphaean"],
    &["panomphaean"],
];

pub(crate) static ENTRY_PANTHEONIZATIONS_12369984766927055092: VariantsMap = [
    &["pantheonizations"],
    &["pantheonisations"],
    &["pantheonizations"],
    &["pantheonisations"],
];

pub(crate) static ENTRY_PANTHEONIZATION_3031761940679684536: VariantsMap = [
    &["pantheonization"],
    &["pantheonisation"],
    &["pantheonization"],
    &["pantheonisation"],
];

pub(crate) static ENTRY_PANTHEONIZES_6927021183986839165: VariantsMap = [
    &["pantheonizes"],
    &["pantheonises"],
    &["pantheonizes"],
    &["pantheonises"],
];

pub(crate) static ENTRY_PANTHEONIZE_4830761873149783365: VariantsMap = [
    &["pantheonize"],
    &["pantheonise"],
    &["pantheonize"],
    &["pantheonise"],
];

pub(crate) static ENTRY_PAPALIZATIONS_14103151976039127637: VariantsMap = [
    &["papalizations"],
    &["papalisations"],
    &["papalizations"],
    &["papalisations"],
];

pub(crate) static ENTRY_PAPALIZATION_10305112316051179611: VariantsMap = [
    &["papalization"],
    &["papalisation"],
    &["papalization"],
    &["papalisation"],
];

pub(crate) static ENTRY_PAPALIZED_7105409138327586534: VariantsMap = [
    &["papalized"],
    &["papalised"],
    &["papalized"],
    &["papalised"],
];

pub(crate) static ENTRY_PAPALIZERS_15756683407514873742: VariantsMap = [
    &["papalizers"],
    &["papalisers"],
    &["papalizers"],
    &["papalisers"],
];

pub(crate) static ENTRY_PAPALIZER_18353219266660388688: VariantsMap = [
    &["papalizer"],
    &["papaliser"],
    &["papalizer"],
    &["papaliser"],
];

pub(crate) static ENTRY_PAPALIZES_3090977471549773473: VariantsMap = [
    &["papalizes"],
    &["papalises"],
    &["papalizes"],
    &["papalises"],
];

pub(crate) static ENTRY_PAPALIZE_17095323209535476080: VariantsMap =
    [&["papalize"], &["papalise"], &["papalize"], &["papalise"]];

pub(crate) static ENTRY_PAPALIZING_15022851819713987399: VariantsMap = [
    &["papalizing"],
    &["papalising"],
    &["papalizing"],
    &["papalising"],
];

pub(crate) static ENTRY_PAPILLEDEMA_17898703555064318930: VariantsMap = [
    &["papilledema"],
    &["papilloedema"],
    &["papilloedema"],
    &["papilloedema"],
];

pub(crate) static ENTRY_PAPULE_14971280913138248927: VariantsMap =
    [&["papule"], &["papulae"], &["papulae"], &["papulae"]];

pub(crate) static ENTRY_PARABOLIZATION_9979029011128629425: VariantsMap = [
    &["parabolization"],
    &["parabolisation"],
    &["parabolization"],
    &["parabolisation"],
];

pub(crate) static ENTRY_PARABOLIZED_18319308228981949562: VariantsMap = [
    &["parabolized"],
    &["parabolised"],
    &["parabolized"],
    &["parabolised"],
];

pub(crate) static ENTRY_PARABOLIZES_15064031586705803527: VariantsMap = [
    &["parabolizes"],
    &["parabolises"],
    &["parabolizes"],
    &["parabolises"],
];

pub(crate) static ENTRY_PARABOLIZE_3633976210888421037: VariantsMap = [
    &["parabolize"],
    &["parabolise"],
    &["parabolize"],
    &["parabolise"],
];

pub(crate) static ENTRY_PARABOLIZING_4559864831118431645: VariantsMap = [
    &["parabolizing"],
    &["parabolising"],
    &["parabolizing"],
    &["parabolising"],
];

pub(crate) static ENTRY_PARAFFINIZES_1377166017348875375: VariantsMap = [
    &["paraffinizes"],
    &["paraffinises"],
    &["paraffinizes"],
    &["paraffinises"],
];

pub(crate) static ENTRY_PARAFFINIZE_4902479195187558819: VariantsMap = [
    &["paraffinize"],
    &["paraffinise"],
    &["paraffinize"],
    &["paraffinise"],
];

pub(crate) static ENTRY_PARAGRAPHIZES_17320641323920182037: VariantsMap = [
    &["paragraphizes"],
    &["paragraphises"],
    &["paragraphizes"],
    &["paragraphises"],
];

pub(crate) static ENTRY_PARAGRAPHIZE_6569788940642685820: VariantsMap = [
    &["paragraphize"],
    &["paragraphise"],
    &["paragraphize"],
    &["paragraphise"],
];

pub(crate) static ENTRY_PARALLELIZATIONS_133672918746936059: VariantsMap = [
    &["parallelizations"],
    &["parallelisations"],
    &["parallelizations"],
    &["parallelisations"],
];

pub(crate) static ENTRY_PARALLELIZATION_7245934204447125604: VariantsMap = [
    &["parallelization"],
    &["parallelisation"],
    &["parallelization"],
    &["parallelisation"],
];

pub(crate) static ENTRY_PARALLELIZED_4111465640711886667: VariantsMap = [
    &["parallelized"],
    &["parallelised"],
    &["parallelized"],
    &["parallelised"],
];

pub(crate) static ENTRY_PARALLELIZERS_8909000637472788633: VariantsMap = [
    &["parallelizers"],
    &["parallelisers"],
    &["parallelizers"],
    &["parallelisers"],
];

pub(crate) static ENTRY_PARALLELIZER_12768796695953090002: VariantsMap = [
    &["parallelizer"],
    &["paralleliser"],
    &["parallelizer"],
    &["paralleliser"],
];

pub(crate) static ENTRY_PARALLELIZES_4727085859295719609: VariantsMap = [
    &["parallelizes"],
    &["parallelises"],
    &["parallelizes"],
    &["parallelises"],
];

pub(crate) static ENTRY_PARALLELIZE_1958083969952429229: VariantsMap = [
    &["parallelize"],
    &["parallelise"],
    &["parallelize"],
    &["parallelise"],
];

pub(crate) static ENTRY_PARALLELIZING_17049440584088440335: VariantsMap = [
    &["parallelizing"],
    &["parallelising"],
    &["parallelizing"],
    &["parallelising"],
];

pub(crate) static ENTRY_PARALOGIZED_14744665030205649557: VariantsMap = [
    &["paralogized"],
    &["paralogised"],
    &["paralogized"],
    &["paralogised"],
];

pub(crate) static ENTRY_PARALOGIZES_9488115918771452379: VariantsMap = [
    &["paralogizes"],
    &["paralogises"],
    &["paralogizes"],
    &["paralogises"],
];

pub(crate) static ENTRY_PARALOGIZE_12214907662748039398: VariantsMap = [
    &["paralogize"],
    &["paralogise"],
    &["paralogize"],
    &["paralogise"],
];

pub(crate) static ENTRY_PARALOGIZING_11295656204568323189: VariantsMap = [
    &["paralogizing"],
    &["paralogising"],
    &["paralogizing"],
    &["paralogising"],
];

pub(crate) static ENTRY_PARALYZATIONS_7680809956520835808: VariantsMap = [
    &["paralyzations"],
    &["paralysations"],
    &["paralysations"],
    &["paralysations"],
];

pub(crate) static ENTRY_PARALYZATION_9848908666776705153: VariantsMap = [
    &["paralyzation"],
    &["paralysation"],
    &["paralysation"],
    &["paralysation"],
];

pub(crate) static ENTRY_PARALYZEDLIES_6503851599747415664: VariantsMap = [
    &["paralyzedlies"],
    &["paralysedlies"],
    &["paralysedlies"],
    &["paralysedlies"],
];

pub(crate) static ENTRY_PARALYZEDLY_15858220542027209484: VariantsMap = [
    &["paralyzedly"],
    &["paralysedly"],
    &["paralysedly"],
    &["paralysedly"],
];

pub(crate) static ENTRY_PARALYZED_16839880512939084025: VariantsMap = [
    &["paralyzed"],
    &["paralysed"],
    &["paralyzed"],
    &["paralysed"],
];

pub(crate) static ENTRY_PARALYZERS_13745656060590463226: VariantsMap = [
    &["paralyzers"],
    &["paralysers"],
    &["paralysers"],
    &["paralysers"],
];

pub(crate) static ENTRY_PARALYZER_4178714175758599714: VariantsMap = [
    &["paralyzer"],
    &["paralyser"],
    &["paralyser"],
    &["paralyser"],
];

pub(crate) static ENTRY_PARALYZES_2906384954321317007: VariantsMap = [
    &["paralyzes"],
    &["paralyses"],
    &["paralyzes"],
    &["paralyses"],
];

pub(crate) static ENTRY_PARALYZE_5616245633076129426: VariantsMap =
    [&["paralyze"], &["paralyse"], &["paralyze"], &["paralyse"]];

pub(crate) static ENTRY_PARALYZINGLIES_11000762994581262667: VariantsMap = [
    &["paralyzinglies"],
    &["paralysinglies"],
    &["paralysinglies"],
    &["paralysinglies"],
];

pub(crate) static ENTRY_PARALYZINGLY_2254446540316450510: VariantsMap = [
    &["paralyzingly"],
    &["paralysingly"],
    &["paralysingly"],
    &["paralysingly"],
];

pub(crate) static ENTRY_PARALYZING_3887960173123159019: VariantsMap = [
    &["paralyzing"],
    &["paralysing"],
    &["paralyzing"],
    &["paralysing"],
];

pub(crate) static ENTRY_PARAMECIUM_3779667447675673813: VariantsMap = [
    &["paramecium"],
    &["paramoecium"],
    &["paramoecium"],
    &["paramoecium"],
];

pub(crate) static ENTRY_PARAMETERIZABLE_8797908909194558616: VariantsMap = [
    &["parameterizable"],
    &["parameterisable"],
    &["parameterizable"],
    &["parameterisable"],
];

pub(crate) static ENTRY_PARAMETERIZATIONS_7162471395165876296: VariantsMap = [
    &["parameterizations"],
    &["parameterisations"],
    &["parameterizations"],
    &["parameterisations"],
];

pub(crate) static ENTRY_PARAMETERIZATION_11837209911752300457: VariantsMap = [
    &["parameterization"],
    &["parameterisation"],
    &["parameterization"],
    &["parameterisation"],
];

pub(crate) static ENTRY_PARAMETERIZED_10523524909406136092: VariantsMap = [
    &["parameterized"],
    &["parameterised"],
    &["parameterized"],
    &["parameterised"],
];

pub(crate) static ENTRY_PARAMETERIZES_16321927350979537220: VariantsMap = [
    &["parameterizes"],
    &["parameterises"],
    &["parameterizes"],
    &["parameterises"],
];

pub(crate) static ENTRY_PARAMETERIZE_15902800810917069503: VariantsMap = [
    &["parameterize"],
    &["parameterise"],
    &["parameterize"],
    &["parameterise"],
];

pub(crate) static ENTRY_PARAMETERIZING_17336476515168482632: VariantsMap = [
    &["parameterizing"],
    &["parameterising"],
    &["parameterizing"],
    &["parameterising"],
];

pub(crate) static ENTRY_PARAMETRIZABLE_7927413513463824291: VariantsMap = [
    &["parametrizable"],
    &["parametrisable"],
    &["parametrizable"],
    &["parametrisable"],
];

pub(crate) static ENTRY_PARAMETRIZATIONS_7360315396492509494: VariantsMap = [
    &["parametrizations"],
    &["parametrisations"],
    &["parametrizations"],
    &["parametrisations"],
];

pub(crate) static ENTRY_PARAMETRIZATION_8706840929864673961: VariantsMap = [
    &["parametrization"],
    &["parametrisation"],
    &["parametrization"],
    &["parametrisation"],
];

pub(crate) static ENTRY_PARAMETRIZED_9399874769518811207: VariantsMap = [
    &["parametrized"],
    &["parametrised"],
    &["parametrized"],
    &["parametrised"],
];

pub(crate) static ENTRY_PARAMETRIZES_5906260080588211958: VariantsMap = [
    &["parametrizes"],
    &["parametrises"],
    &["parametrizes"],
    &["parametrises"],
];

pub(crate) static ENTRY_PARAMETRIZE_7024833004706310910: VariantsMap = [
    &["parametrize"],
    &["parametrise"],
    &["parametrize"],
    &["parametrise"],
];

pub(crate) static ENTRY_PARAMETRIZING_2499223549119532396: VariantsMap = [
    &["parametrizing"],
    &["parametrising"],
    &["parametrizing"],
    &["parametrising"],
];

pub(crate) static ENTRY_PARASELENE_6912874048936205670: VariantsMap = [
    &["paraselene"],
    &["paraselenae"],
    &["paraselenae"],
    &["paraselenae"],
];

pub(crate) static ENTRY_PARASITEMIA_6177658356922218519: VariantsMap = [
    &["parasitemia"],
    &["parasitaemia"],
    &["parasitaemia"],
    &["parasitaemia"],
];

pub(crate) static ENTRY_PARASITIZATION_10764422602155636226: VariantsMap = [
    &["parasitization"],
    &["parasitisation"],
    &["parasitization"],
    &["parasitisation"],
];

pub(crate) static ENTRY_PARASITIZED_17454588215531391347: VariantsMap = [
    &["parasitized"],
    &["parasitised"],
    &["parasitized"],
    &["parasitised"],
];

pub(crate) static ENTRY_PARASITIZES_15093324507866591370: VariantsMap = [
    &["parasitizes"],
    &["parasitises"],
    &["parasitizes"],
    &["parasitises"],
];

pub(crate) static ENTRY_PARASITIZE_10442537268642059851: VariantsMap = [
    &["parasitize"],
    &["parasitise"],
    &["parasitize"],
    &["parasitise"],
];

pub(crate) static ENTRY_PARASITIZING_13253219762304399299: VariantsMap = [
    &["parasitizing"],
    &["parasitising"],
    &["parasitizing"],
    &["parasitising"],
];

pub(crate) static ENTRY_PARATHYROIDECTOMIZED_5474592337131298831: VariantsMap = [
    &["parathyroidectomized"],
    &["parathyroidectomised"],
    &["parathyroidectomized"],
    &["parathyroidectomised"],
];

pub(crate) static ENTRY_PARATHYROIDECTOMIZES_2007746234745477770: VariantsMap = [
    &["parathyroidectomizes"],
    &["parathyroidectomises"],
    &["parathyroidectomizes"],
    &["parathyroidectomises"],
];

pub(crate) static ENTRY_PARATHYROIDECTOMIZE_14484344006380038665: VariantsMap = [
    &["parathyroidectomize"],
    &["parathyroidectomise"],
    &["parathyroidectomize"],
    &["parathyroidectomise"],
];

pub(crate) static ENTRY_PARATHYROIDECTOMIZING_123904040877460171: VariantsMap = [
    &["parathyroidectomizing"],
    &["parathyroidectomising"],
    &["parathyroidectomizing"],
    &["parathyroidectomising"],
];

pub(crate) static ENTRY_PARATRAGEDIA_16004760938575301167: VariantsMap = [
    &["paratragedia"],
    &["paratragoedia"],
    &["paratragoedia"],
    &["paratragoedia"],
];

pub(crate) static ENTRY_PARCELED_6170016542434984869: VariantsMap = [
    &["parceled"],
    &["parcelled"],
    &["parcelled"],
    &["parcelled"],
];

pub(crate) static ENTRY_PARCELER_17576388958982772521: VariantsMap = [
    &["parceler"],
    &["parceller"],
    &["parceller"],
    &["parceller"],
];

pub(crate) static ENTRY_PARCELING_851710970245334651: VariantsMap = [
    &["parceling"],
    &["parcelling"],
    &["parcelling"],
    &["parcelling"],
];

pub(crate) static ENTRY_PARCHMENTIZED_16479603540981235266: VariantsMap = [
    &["parchmentized"],
    &["parchmentised"],
    &["parchmentized"],
    &["parchmentised"],
];

pub(crate) static ENTRY_PARCHMENTIZES_844658164566902891: VariantsMap = [
    &["parchmentizes"],
    &["parchmentises"],
    &["parchmentizes"],
    &["parchmentises"],
];

pub(crate) static ENTRY_PARCHMENTIZE_1939046984216613974: VariantsMap = [
    &["parchmentize"],
    &["parchmentise"],
    &["parchmentize"],
    &["parchmentise"],
];

pub(crate) static ENTRY_PARCHMENTIZING_15031589244698001883: VariantsMap = [
    &["parchmentizing"],
    &["parchmentising"],
    &["parchmentizing"],
    &["parchmentising"],
];

pub(crate) static ENTRY_PARECIOUSLY_1136225838796007635: VariantsMap = [
    &["pareciously"],
    &["paroeciously"],
    &["paroeciously"],
    &["paroeciously"],
];

pub(crate) static ENTRY_PARECIOUSNESS_14170146750788160014: VariantsMap = [
    &["pareciousness"],
    &["paroeciousness"],
    &["paroeciousness"],
    &["paroeciousness"],
];

pub(crate) static ENTRY_PARECIOUS_14569683298578543735: VariantsMap = [
    &["parecious"],
    &["paroecious"],
    &["paroecious"],
    &["paroecious"],
];

pub(crate) static ENTRY_PARECISM_16138695721790138925: VariantsMap = [
    &["parecism"],
    &["paroecism"],
    &["paroecism"],
    &["paroecism"],
];

pub(crate) static ENTRY_PARECY_16642153001069896304: VariantsMap =
    [&["parecy"], &["paroecy"], &["paroecy"], &["paroecy"]];

pub(crate) static ENTRY_PARENESES_15075590434109366156: VariantsMap = [
    &["pareneses"],
    &["paraeneses"],
    &["paraeneses"],
    &["paraeneses"],
];

pub(crate) static ENTRY_PARENESIS_10831614342484659031: VariantsMap = [
    &["parenesis"],
    &["paraenesis"],
    &["paraenesis"],
    &["paraenesis"],
];

pub(crate) static ENTRY_PARENETICAL_7355921821382251766: VariantsMap = [
    &["parenetical"],
    &["paraenetical"],
    &["paraenetical"],
    &["paraenetical"],
];

pub(crate) static ENTRY_PARENETIC_14670463709273075800: VariantsMap = [
    &["parenetic"],
    &["paraenetic"],
    &["paraenetic"],
    &["paraenetic"],
];

pub(crate) static ENTRY_PARENTHESIZATION_13202063789668639765: VariantsMap = [
    &["parenthesization"],
    &["parenthesisation"],
    &["parenthesization"],
    &["parenthesisation"],
];

pub(crate) static ENTRY_PARENTHESIZED_3648906989752316418: VariantsMap = [
    &["parenthesized"],
    &["parenthesised"],
    &["parenthesized"],
    &["parenthesised"],
];

pub(crate) static ENTRY_PARENTHESIZES_9065065510113606774: VariantsMap = [
    &["parenthesizes"],
    &["parenthesises"],
    &["parenthesizes"],
    &["parenthesises"],
];

pub(crate) static ENTRY_PARENTHESIZE_16232933755981914094: VariantsMap = [
    &["parenthesize"],
    &["parenthesise"],
    &["parenthesize"],
    &["parenthesise"],
];

pub(crate) static ENTRY_PARENTHESIZING_632457343746225122: VariantsMap = [
    &["parenthesizing"],
    &["parenthesising"],
    &["parenthesizing"],
    &["parenthesising"],
];

pub(crate) static ENTRY_PARESTHESIAS_12326929322577395759: VariantsMap = [
    &["paresthesias"],
    &["paraesthesias"],
    &["paraesthesias"],
    &["paraesthesias"],
];

pub(crate) static ENTRY_PARESTHESIA_6053545970539213078: VariantsMap = [
    &["paresthesia"],
    &["paraesthesia"],
    &["paraesthesia"],
    &["paraesthesia"],
];

pub(crate) static ENTRY_PARESTHETIC_7625031320540803873: VariantsMap = [
    &["paresthetic"],
    &["paraesthetic"],
    &["paraesthetic"],
    &["paraesthetic"],
];

pub(crate) static ENTRY_PARFOCALIZATION_2105460359882027002: VariantsMap = [
    &["parfocalization"],
    &["parfocalisation"],
    &["parfocalization"],
    &["parfocalisation"],
];

pub(crate) static ENTRY_PARFOCALIZE_17464433649035265735: VariantsMap = [
    &["parfocalize"],
    &["parfocalise"],
    &["parfocalize"],
    &["parfocalise"],
];

pub(crate) static ENTRY_PARISIANIZATIONS_4850617849122164225: VariantsMap = [
    &["parisianizations"],
    &["parisianisations"],
    &["parisianizations"],
    &["parisianisations"],
];

pub(crate) static ENTRY_PARISIANIZATION_8796044822297406094: VariantsMap = [
    &["parisianization"],
    &["parisianisation"],
    &["parisianization"],
    &["parisianisation"],
];

pub(crate) static ENTRY_PARISIANIZES_15357022119572583625: VariantsMap = [
    &["parisianizes"],
    &["parisianises"],
    &["parisianizes"],
    &["parisianises"],
];

pub(crate) static ENTRY_PARISIANIZE_18132108741295808736: VariantsMap = [
    &["parisianize"],
    &["parisianise"],
    &["parisianize"],
    &["parisianise"],
];

pub(crate) static ENTRY_PARLORISH_13017991595146743483: VariantsMap = [
    &["parlorish"],
    &["parlourish"],
    &["parlourish"],
    &["parlourish"],
];

pub(crate) static ENTRY_PARLORMAID_4150851883941162027: VariantsMap = [
    &["parlormaid"],
    &["parlourmaid"],
    &["parlourmaid"],
    &["parlourmaid"],
];

pub(crate) static ENTRY_PARLORS_13263653608415272696: VariantsMap =
    [&["parlors"], &["parlours"], &["parlours"], &["parlours"]];

pub(crate) static ENTRY_PARLOR_5988253503224208460: VariantsMap =
    [&["parlor"], &["parlour"], &["parlour"], &["parlour"]];

pub(crate) static ENTRY_PAROCHIALIZATIONS_16574969241210280652: VariantsMap = [
    &["parochializations"],
    &["parochialisations"],
    &["parochializations"],
    &["parochialisations"],
];

pub(crate) static ENTRY_PAROCHIALIZATION_14100344379237107874: VariantsMap = [
    &["parochialization"],
    &["parochialisation"],
    &["parochialization"],
    &["parochialisation"],
];

pub(crate) static ENTRY_PAROCHIALIZED_7303132907572634206: VariantsMap = [
    &["parochialized"],
    &["parochialised"],
    &["parochialized"],
    &["parochialised"],
];

pub(crate) static ENTRY_PAROCHIALIZES_6747512001914510504: VariantsMap = [
    &["parochializes"],
    &["parochialises"],
    &["parochializes"],
    &["parochialises"],
];

pub(crate) static ENTRY_PAROCHIALIZE_1801958382160346709: VariantsMap = [
    &["parochialize"],
    &["parochialise"],
    &["parochialize"],
    &["parochialise"],
];

pub(crate) static ENTRY_PAROCHIALIZING_675693589145640380: VariantsMap = [
    &["parochializing"],
    &["parochialising"],
    &["parochializing"],
    &["parochialising"],
];

pub(crate) static ENTRY_PARROTIZES_11339528989147708955: VariantsMap = [
    &["parrotizes"],
    &["parrotises"],
    &["parrotizes"],
    &["parrotises"],
];

pub(crate) static ENTRY_PARROTIZE_6855799754055791992: VariantsMap = [
    &["parrotize"],
    &["parrotise"],
    &["parrotize"],
    &["parrotise"],
];

pub(crate) static ENTRY_PARSONIZES_8755384066719912504: VariantsMap = [
    &["parsonizes"],
    &["parsonises"],
    &["parsonizes"],
    &["parsonises"],
];

pub(crate) static ENTRY_PARSONIZE_6711982105966566323: VariantsMap = [
    &["parsonize"],
    &["parsonise"],
    &["parsonize"],
    &["parsonise"],
];

pub(crate) static ENTRY_PARTIALIZED_4252087159550355238: VariantsMap = [
    &["partialized"],
    &["partialised"],
    &["partialized"],
    &["partialised"],
];

pub(crate) static ENTRY_PARTIALIZES_6032034501365058234: VariantsMap = [
    &["partializes"],
    &["partialises"],
    &["partializes"],
    &["partialises"],
];

pub(crate) static ENTRY_PARTIALIZE_1962663665740826203: VariantsMap = [
    &["partialize"],
    &["partialise"],
    &["partialize"],
    &["partialise"],
];

pub(crate) static ENTRY_PARTIALIZING_12669034655608424199: VariantsMap = [
    &["partializing"],
    &["partialising"],
    &["partializing"],
    &["partialising"],
];

pub(crate) static ENTRY_PARTICOLOREDDER_9511263899731979802: VariantsMap = [
    &["particoloredder"],
    &["particolouredder"],
    &["particolouredder"],
    &["particolouredder"],
];

pub(crate) static ENTRY_PARTICOLOREDDEST_1358436328033457410: VariantsMap = [
    &["particoloreddest"],
    &["particoloureddest"],
    &["particoloureddest"],
    &["particoloureddest"],
];

pub(crate) static ENTRY_PARTICOLORED_13675013999250147429: VariantsMap = [
    &["particolored"],
    &["particoloured"],
    &["particoloured"],
    &["particoloured"],
];

pub(crate) static ENTRY_PARTICULARIZATIONS_7496757883724885887: VariantsMap = [
    &["particularizations"],
    &["particularisations"],
    &["particularizations"],
    &["particularisations"],
];

pub(crate) static ENTRY_PARTICULARIZATION_15085297445135933435: VariantsMap = [
    &["particularization"],
    &["particularisation"],
    &["particularization"],
    &["particularisation"],
];

pub(crate) static ENTRY_PARTICULARIZED_11569157644638431290: VariantsMap = [
    &["particularized"],
    &["particularised"],
    &["particularized"],
    &["particularised"],
];

pub(crate) static ENTRY_PARTICULARIZER_14936600870613435660: VariantsMap = [
    &["particularizer"],
    &["particulariser"],
    &["particularizer"],
    &["particulariser"],
];

pub(crate) static ENTRY_PARTICULARIZES_8370763796403583228: VariantsMap = [
    &["particularizes"],
    &["particularises"],
    &["particularizes"],
    &["particularises"],
];

pub(crate) static ENTRY_PARTICULARIZE_15520939813264385830: VariantsMap = [
    &["particularize"],
    &["particularise"],
    &["particularize"],
    &["particularise"],
];

pub(crate) static ENTRY_PARTICULARIZING_5658452593803942085: VariantsMap = [
    &["particularizing"],
    &["particularising"],
    &["particularizing"],
    &["particularising"],
];

pub(crate) static ENTRY_PARTISANIZES_1728318026660141228: VariantsMap = [
    &["partisanizes"],
    &["partisanises"],
    &["partisanizes"],
    &["partisanises"],
];

pub(crate) static ENTRY_PARTISANIZE_2022426188255513510: VariantsMap = [
    &["partisanize"],
    &["partisanise"],
    &["partisanize"],
    &["partisanise"],
];

pub(crate) static ENTRY_PASIPHAE_14757892558890999139: VariantsMap = [
    &["pasiphae"],
    &["pasiphaae"],
    &["pasiphaae"],
    &["pasiphaae"],
];

pub(crate) static ENTRY_PASSADES_14898665474288463392: VariantsMap = [
    &["passades"],
    &["passadoes"],
    &["passadoes"],
    &["passadoes"],
];

pub(crate) static ENTRY_PASSIVIZATION_14555794353650852047: VariantsMap = [
    &["passivization"],
    &["passivisation"],
    &["passivization"],
    &["passivisation"],
];

pub(crate) static ENTRY_PASTEURIZATIONS_2915811841905287610: VariantsMap = [
    &["pasteurizations"],
    &["pasteurisations"],
    &["pasteurizations"],
    &["pasteurisations"],
];

pub(crate) static ENTRY_PASTEURIZATION_15699653175330456323: VariantsMap = [
    &["pasteurization"],
    &["pasteurisation"],
    &["pasteurization"],
    &["pasteurisation"],
];

pub(crate) static ENTRY_PASTEURIZED_13548937625186713170: VariantsMap = [
    &["pasteurized"],
    &["pasteurised"],
    &["pasteurized"],
    &["pasteurised"],
];

pub(crate) static ENTRY_PASTEURIZERS_15085534957712496351: VariantsMap = [
    &["pasteurizers"],
    &["pasteurisers"],
    &["pasteurizers"],
    &["pasteurisers"],
];

pub(crate) static ENTRY_PASTEURIZER_2458848217830417439: VariantsMap = [
    &["pasteurizer"],
    &["pasteuriser"],
    &["pasteurizer"],
    &["pasteuriser"],
];

pub(crate) static ENTRY_PASTEURIZES_5846494049033549631: VariantsMap = [
    &["pasteurizes"],
    &["pasteurises"],
    &["pasteurizes"],
    &["pasteurises"],
];

pub(crate) static ENTRY_PASTEURIZE_163174462491369649: VariantsMap = [
    &["pasteurize"],
    &["pasteurise"],
    &["pasteurize"],
    &["pasteurise"],
];

pub(crate) static ENTRY_PASTEURIZING_15425456478399382152: VariantsMap = [
    &["pasteurizing"],
    &["pasteurising"],
    &["pasteurizing"],
    &["pasteurising"],
];

pub(crate) static ENTRY_PASTORALIZES_6186051459304798026: VariantsMap = [
    &["pastoralizes"],
    &["pastoralises"],
    &["pastoralizes"],
    &["pastoralises"],
];

pub(crate) static ENTRY_PASTORALIZE_14882784365438844418: VariantsMap = [
    &["pastoralize"],
    &["pastoralise"],
    &["pastoralize"],
    &["pastoralise"],
];

pub(crate) static ENTRY_PASTORIZES_18160198317277729221: VariantsMap = [
    &["pastorizes"],
    &["pastorises"],
    &["pastorizes"],
    &["pastorises"],
];

pub(crate) static ENTRY_PASTORIZE_17256510429688032591: VariantsMap = [
    &["pastorize"],
    &["pastorise"],
    &["pastorize"],
    &["pastorise"],
];

pub(crate) static ENTRY_PATERNALIZES_6090370098103830575: VariantsMap = [
    &["paternalizes"],
    &["paternalises"],
    &["paternalizes"],
    &["paternalises"],
];

pub(crate) static ENTRY_PATERNALIZE_17612845585576962910: VariantsMap = [
    &["paternalize"],
    &["paternalise"],
    &["paternalize"],
    &["paternalise"],
];

pub(crate) static ENTRY_PATINED_17741036475179872327: VariantsMap =
    [&["patined"], &["patinaed"], &["patinaed"], &["patinaed"]];

pub(crate) static ENTRY_PATINE_2383187798704264861: VariantsMap =
    [&["patine"], &["patinae"], &["patinae"], &["patinae"]];

pub(crate) static ENTRY_PATRIALIZATIONS_8913404008720113294: VariantsMap = [
    &["patrializations"],
    &["patrialisations"],
    &["patrializations"],
    &["patrialisations"],
];

pub(crate) static ENTRY_PATRIALIZATION_9949115296750967273: VariantsMap = [
    &["patrialization"],
    &["patrialisation"],
    &["patrialization"],
    &["patrialisation"],
];

pub(crate) static ENTRY_PATRIALIZED_438648802317738966: VariantsMap = [
    &["patrialized"],
    &["patrialised"],
    &["patrialized"],
    &["patrialised"],
];

pub(crate) static ENTRY_PATRIALIZES_14381499556205684969: VariantsMap = [
    &["patrializes"],
    &["patrialises"],
    &["patrializes"],
    &["patrialises"],
];

pub(crate) static ENTRY_PATRIALIZE_2025590991584754634: VariantsMap = [
    &["patrialize"],
    &["patrialise"],
    &["patrialize"],
    &["patrialise"],
];

pub(crate) static ENTRY_PATRIALIZING_12870398855810619317: VariantsMap = [
    &["patrializing"],
    &["patrialising"],
    &["patrializing"],
    &["patrialising"],
];

pub(crate) static ENTRY_PATRICES_7408034855473052638: VariantsMap = [
    &["patrices"],
    &["patricoes"],
    &["patricoes"],
    &["patricoes"],
];

pub(crate) static ENTRY_PATRONIZABLER_8283184479282006483: VariantsMap = [
    &["patronizabler"],
    &["patronisabler"],
    &["patronizabler"],
    &["patronisabler"],
];

pub(crate) static ENTRY_PATRONIZABLEST_307591711490088244: VariantsMap = [
    &["patronizablest"],
    &["patronisablest"],
    &["patronizablest"],
    &["patronisablest"],
];

pub(crate) static ENTRY_PATRONIZABLES_7300624032056980557: VariantsMap = [
    &["patronizables"],
    &["patronisables"],
    &["patronizables"],
    &["patronisables"],
];

pub(crate) static ENTRY_PATRONIZABLE_18388697617212249244: VariantsMap = [
    &["patronizable"],
    &["patronisable"],
    &["patronizable"],
    &["patronisable"],
];

pub(crate) static ENTRY_PATRONIZATIONS_18089723998023320020: VariantsMap = [
    &["patronizations"],
    &["patronisations"],
    &["patronizations"],
    &["patronisations"],
];

pub(crate) static ENTRY_PATRONIZATION_10398895486217879996: VariantsMap = [
    &["patronization"],
    &["patronisation"],
    &["patronization"],
    &["patronisation"],
];

pub(crate) static ENTRY_PATRONIZED_11064398139600850345: VariantsMap = [
    &["patronized"],
    &["patronised"],
    &["patronized"],
    &["patronised"],
];

pub(crate) static ENTRY_PATRONIZERS_11272030543646937310: VariantsMap = [
    &["patronizers"],
    &["patronisers"],
    &["patronizers"],
    &["patronisers"],
];

pub(crate) static ENTRY_PATRONIZER_10813433458376234707: VariantsMap = [
    &["patronizer"],
    &["patroniser"],
    &["patronizer"],
    &["patroniser"],
];

pub(crate) static ENTRY_PATRONIZES_11395708073720458865: VariantsMap = [
    &["patronizes"],
    &["patronises"],
    &["patronizes"],
    &["patronises"],
];

pub(crate) static ENTRY_PATRONIZE_2120552335415939536: VariantsMap = [
    &["patronize"],
    &["patronise"],
    &["patronize"],
    &["patronise"],
];

pub(crate) static ENTRY_PATRONIZINGLIER_302802414773543310: VariantsMap = [
    &["patronizinglier"],
    &["patronisinglier"],
    &["patronizinglier"],
    &["patronisinglier"],
];

pub(crate) static ENTRY_PATRONIZINGLIEST_16305371931388137130: VariantsMap = [
    &["patronizingliest"],
    &["patronisingliest"],
    &["patronizingliest"],
    &["patronisingliest"],
];

pub(crate) static ENTRY_PATRONIZINGLY_6847062421337873239: VariantsMap = [
    &["patronizingly"],
    &["patronisingly"],
    &["patronizingly"],
    &["patronisingly"],
];

pub(crate) static ENTRY_PATRONIZINGS_13629575403778748423: VariantsMap = [
    &["patronizings"],
    &["patronisings"],
    &["patronizings"],
    &["patronisings"],
];

pub(crate) static ENTRY_PATRONIZING_12434118065877059973: VariantsMap = [
    &["patronizing"],
    &["patronising"],
    &["patronizing"],
    &["patronising"],
];

pub(crate) static ENTRY_PATTERNIZES_5545508925274719419: VariantsMap = [
    &["patternizes"],
    &["patternises"],
    &["patternizes"],
    &["patternises"],
];

pub(crate) static ENTRY_PATTERNIZE_5417694889107920916: VariantsMap = [
    &["patternize"],
    &["patternise"],
    &["patternize"],
    &["patternise"],
];

pub(crate) static ENTRY_PATTE_8336102578296137635: VariantsMap =
    [&["patte"], &["pattae"], &["pattae"], &["pattae"]];

pub(crate) static ENTRY_PAULINIZES_16873641534240765118: VariantsMap = [
    &["paulinizes"],
    &["paulinises"],
    &["paulinizes"],
    &["paulinises"],
];

pub(crate) static ENTRY_PAULINIZE_2460573239735736716: VariantsMap = [
    &["paulinize"],
    &["paulinise"],
    &["paulinize"],
    &["paulinise"],
];

pub(crate) static ENTRY_PAUPERIZATIONS_10251769409806507728: VariantsMap = [
    &["pauperizations"],
    &["pauperisations"],
    &["pauperizations"],
    &["pauperisations"],
];

pub(crate) static ENTRY_PAUPERIZATION_2161984306553805604: VariantsMap = [
    &["pauperization"],
    &["pauperisation"],
    &["pauperization"],
    &["pauperisation"],
];

pub(crate) static ENTRY_PAUPERIZED_6686296815894484392: VariantsMap = [
    &["pauperized"],
    &["pauperised"],
    &["pauperized"],
    &["pauperised"],
];

pub(crate) static ENTRY_PAUPERIZERS_18420726162837139825: VariantsMap = [
    &["pauperizers"],
    &["pauperisers"],
    &["pauperizers"],
    &["pauperisers"],
];

pub(crate) static ENTRY_PAUPERIZER_15676497663002877808: VariantsMap = [
    &["pauperizer"],
    &["pauperiser"],
    &["pauperizer"],
    &["pauperiser"],
];

pub(crate) static ENTRY_PAUPERIZES_13654913193374307039: VariantsMap = [
    &["pauperizes"],
    &["pauperises"],
    &["pauperizes"],
    &["pauperises"],
];

pub(crate) static ENTRY_PAUPERIZE_18158151809070795878: VariantsMap = [
    &["pauperize"],
    &["pauperise"],
    &["pauperize"],
    &["pauperise"],
];

pub(crate) static ENTRY_PAUPERIZING_9202769342367666141: VariantsMap = [
    &["pauperizing"],
    &["pauperising"],
    &["pauperizing"],
    &["pauperising"],
];

pub(crate) static ENTRY_PAVIORS_6064325610314922380: VariantsMap =
    [&["paviors"], &["paviours"], &["paviours"], &["paviours"]];

pub(crate) static ENTRY_PAVIOR_15746156113380683198: VariantsMap =
    [&["pavior"], &["paviour"], &["paviour"], &["paviour"]];

pub(crate) static ENTRY_PAYNIZES_13618850850869066244: VariantsMap =
    [&["paynizes"], &["paynises"], &["paynizes"], &["paynises"]];

pub(crate) static ENTRY_PAYNIZE_5649388039598420083: VariantsMap =
    [&["paynize"], &["paynise"], &["paynize"], &["paynise"]];

pub(crate) static ENTRY_PEARLIZATION_1551638197806205636: VariantsMap = [
    &["pearlization"],
    &["pearlisation"],
    &["pearlization"],
    &["pearlisation"],
];

pub(crate) static ENTRY_PEARLIZED_14450889956724609032: VariantsMap = [
    &["pearlized"],
    &["pearlised"],
    &["pearlized"],
    &["pearlised"],
];

pub(crate) static ENTRY_PEARLIZES_5892211774151827893: VariantsMap = [
    &["pearlizes"],
    &["pearlises"],
    &["pearlizes"],
    &["pearlises"],
];

pub(crate) static ENTRY_PEARLIZE_11311542095439566464: VariantsMap =
    [&["pearlize"], &["pearlise"], &["pearlize"], &["pearlise"]];

pub(crate) static ENTRY_PEARLIZING_2645796683659888681: VariantsMap = [
    &["pearlizing"],
    &["pearlising"],
    &["pearlizing"],
    &["pearlising"],
];

pub(crate) static ENTRY_PEASANTIZES_6479750851568010639: VariantsMap = [
    &["peasantizes"],
    &["peasantises"],
    &["peasantizes"],
    &["peasantises"],
];

pub(crate) static ENTRY_PEASANTIZE_13558495439484194442: VariantsMap = [
    &["peasantize"],
    &["peasantise"],
    &["peasantize"],
    &["peasantise"],
];

pub(crate) static ENTRY_PECTIZATIONS_6560766904324138817: VariantsMap = [
    &["pectizations"],
    &["pectisations"],
    &["pectizations"],
    &["pectisations"],
];

pub(crate) static ENTRY_PECTIZATION_10823502370164603724: VariantsMap = [
    &["pectization"],
    &["pectisation"],
    &["pectization"],
    &["pectisation"],
];

pub(crate) static ENTRY_PECTIZED_4855680733574523884: VariantsMap =
    [&["pectized"], &["pectised"], &["pectized"], &["pectised"]];

pub(crate) static ENTRY_PECTIZES_9322778985278923283: VariantsMap =
    [&["pectizes"], &["pectises"], &["pectizes"], &["pectises"]];

pub(crate) static ENTRY_PECTIZE_5427052689928146895: VariantsMap =
    [&["pectize"], &["pectise"], &["pectize"], &["pectise"]];

pub(crate) static ENTRY_PECTIZING_14368223699615574041: VariantsMap = [
    &["pectizing"],
    &["pectising"],
    &["pectizing"],
    &["pectising"],
];

pub(crate) static ENTRY_PECULIARIZED_1480104559580961178: VariantsMap = [
    &["peculiarized"],
    &["peculiarised"],
    &["peculiarized"],
    &["peculiarised"],
];

pub(crate) static ENTRY_PECULIARIZES_5117499293497869568: VariantsMap = [
    &["peculiarizes"],
    &["peculiarises"],
    &["peculiarizes"],
    &["peculiarises"],
];

pub(crate) static ENTRY_PECULIARIZE_5557459505404245071: VariantsMap = [
    &["peculiarize"],
    &["peculiarise"],
    &["peculiarize"],
    &["peculiarise"],
];

pub(crate) static ENTRY_PECULIARIZING_16350485573039538930: VariantsMap = [
    &["peculiarizing"],
    &["peculiarising"],
    &["peculiarizing"],
    &["peculiarising"],
];

pub(crate) static ENTRY_PEDAGOGISM_12986063057005247378: VariantsMap = [
    &["pedagogism"],
    &["paedagogism"],
    &["paedagogism"],
    &["paedagogism"],
];

pub(crate) static ENTRY_PEDAGOGUES_7902989780410302300: VariantsMap = [
    &["pedagogues"],
    &["pedagogues"],
    &["pedagogues"],
    &["pedagogues"],
];

pub(crate) static ENTRY_PEDAGOGUE_17463305726294731487: VariantsMap = [
    &["pedagogue"],
    &["pedagogue"],
    &["pedagogue"],
    &["pedagogue"],
];

pub(crate) static ENTRY_PEDALED_11301735024430265900: VariantsMap =
    [&["pedaled"], &["pedalled"], &["pedalled"], &["pedalled"]];

pub(crate) static ENTRY_PEDALERS_15975067802508211844: VariantsMap = [
    &["pedalers"],
    &["pedallers"],
    &["pedallers"],
    &["pedallers"],
];

pub(crate) static ENTRY_PEDALER_6897157105660727886: VariantsMap =
    [&["pedaler"], &["pedaller"], &["pedaller"], &["pedaller"]];

pub(crate) static ENTRY_PEDALING_5358000154746792705: VariantsMap = [
    &["pedaling"],
    &["pedalling"],
    &["pedalling"],
    &["pedalling"],
];

pub(crate) static ENTRY_PEDANTICIZED_5325771179377667563: VariantsMap = [
    &["pedanticized"],
    &["pedanticised"],
    &["pedanticized"],
    &["pedanticised"],
];

pub(crate) static ENTRY_PEDANTICIZES_2473214515859949893: VariantsMap = [
    &["pedanticizes"],
    &["pedanticises"],
    &["pedanticizes"],
    &["pedanticises"],
];

pub(crate) static ENTRY_PEDANTICIZE_4397269955051838054: VariantsMap = [
    &["pedanticize"],
    &["pedanticise"],
    &["pedanticize"],
    &["pedanticise"],
];

pub(crate) static ENTRY_PEDANTICIZING_16769706095455553889: VariantsMap = [
    &["pedanticizing"],
    &["pedanticising"],
    &["pedanticizing"],
    &["pedanticising"],
];

pub(crate) static ENTRY_PEDANTIZED_16507756779947105562: VariantsMap = [
    &["pedantized"],
    &["pedantised"],
    &["pedantized"],
    &["pedantised"],
];

pub(crate) static ENTRY_PEDANTIZES_12798801729250307983: VariantsMap = [
    &["pedantizes"],
    &["pedantises"],
    &["pedantizes"],
    &["pedantises"],
];

pub(crate) static ENTRY_PEDANTIZE_16316367695842370347: VariantsMap = [
    &["pedantize"],
    &["pedantise"],
    &["pedantize"],
    &["pedantise"],
];

pub(crate) static ENTRY_PEDANTIZING_4575465028095390897: VariantsMap = [
    &["pedantizing"],
    &["pedantising"],
    &["pedantizing"],
    &["pedantising"],
];

pub(crate) static ENTRY_PEDATROPHIA_14603400894477278904: VariantsMap = [
    &["pedatrophia"],
    &["paedatrophia"],
    &["paedatrophia"],
    &["paedatrophia"],
];

pub(crate) static ENTRY_PEDATROPHY_987856254519026242: VariantsMap = [
    &["pedatrophy"],
    &["paedatrophy"],
    &["paedatrophy"],
    &["paedatrophy"],
];

pub(crate) static ENTRY_PEDDLERS_13297303646234860431: VariantsMap =
    [&["peddlers"], &["pedlars"], &["peddlers"], &["pedlars"]];

pub(crate) static ENTRY_PEDDLER_7340625236288148080: VariantsMap =
    [&["peddler"], &["pedlar"], &["peddler"], &["pedlar"]];

pub(crate) static ENTRY_PEDERASTICALLY_851286493260604551: VariantsMap = [
    &["pederastically"],
    &["paederastically"],
    &["paederastically"],
    &["paederastically"],
];

pub(crate) static ENTRY_PEDERASTIC_5749923948076776972: VariantsMap = [
    &["pederastic"],
    &["paederastic"],
    &["paederastic"],
    &["paederastic"],
];

pub(crate) static ENTRY_PEDERASTS_5835872448427039713: VariantsMap = [
    &["pederasts"],
    &["pederasts"],
    &["pederasts"],
    &["pederasts"],
];

pub(crate) static ENTRY_PEDERAST_6508738365729508616: VariantsMap =
    [&["pederast"], &["pederast"], &["pederast"], &["pederast"]];

pub(crate) static ENTRY_PEDESTALED_15135809349372761183: VariantsMap = [
    &["pedestaled"],
    &["pedestalled"],
    &["pedestalled"],
    &["pedestalled"],
];

pub(crate) static ENTRY_PEDESTALING_5711575848882675830: VariantsMap = [
    &["pedestaling"],
    &["pedestalling"],
    &["pedestalling"],
    &["pedestalling"],
];

pub(crate) static ENTRY_PEDESTRIANIZATIONS_15701187568960243875: VariantsMap = [
    &["pedestrianizations"],
    &["pedestrianisations"],
    &["pedestrianizations"],
    &["pedestrianisations"],
];

pub(crate) static ENTRY_PEDESTRIANIZATION_10522132408255479732: VariantsMap = [
    &["pedestrianization"],
    &["pedestrianisation"],
    &["pedestrianization"],
    &["pedestrianisation"],
];

pub(crate) static ENTRY_PEDESTRIANIZED_13675127004868727770: VariantsMap = [
    &["pedestrianized"],
    &["pedestrianised"],
    &["pedestrianized"],
    &["pedestrianised"],
];

pub(crate) static ENTRY_PEDESTRIANIZES_3493882547527020632: VariantsMap = [
    &["pedestrianizes"],
    &["pedestrianises"],
    &["pedestrianizes"],
    &["pedestrianises"],
];

pub(crate) static ENTRY_PEDESTRIANIZE_14520784452518295924: VariantsMap = [
    &["pedestrianize"],
    &["pedestrianise"],
    &["pedestrianize"],
    &["pedestrianise"],
];

pub(crate) static ENTRY_PEDESTRIANIZING_6617534362263439264: VariantsMap = [
    &["pedestrianizing"],
    &["pedestrianising"],
    &["pedestrianizing"],
    &["pedestrianising"],
];

pub(crate) static ENTRY_PEDIATRICIANS_11770782104393001942: VariantsMap = [
    &["pediatricians"],
    &["paediatricians"],
    &["pediatricians"],
    &["paediatricians"],
];

pub(crate) static ENTRY_PEDIATRICIAN_10944796143655723735: VariantsMap = [
    &["pediatrician"],
    &["paediatrician"],
    &["pediatrician"],
    &["paediatrician"],
];

pub(crate) static ENTRY_PEDIATRICS_11689829247825832837: VariantsMap = [
    &["pediatrics"],
    &["paediatrics"],
    &["pediatrics"],
    &["paediatrics"],
];

pub(crate) static ENTRY_PEDIATRIC_14057388448801273518: VariantsMap = [
    &["pediatric"],
    &["paediatric"],
    &["pediatric"],
    &["paediatric"],
];

pub(crate) static ENTRY_PEDIATRY_12652041456225827046: VariantsMap = [
    &["pediatry"],
    &["paediatry"],
    &["paediatry"],
    &["paediatry"],
];

pub(crate) static ENTRY_PEDOBAPTISM_6120739017189134576: VariantsMap = [
    &["pedobaptism"],
    &["paedobaptism"],
    &["paedobaptism"],
    &["paedobaptism"],
];

pub(crate) static ENTRY_PEDOBAPTIST_13392021271448005376: VariantsMap = [
    &["pedobaptist"],
    &["paedobaptist"],
    &["paedobaptist"],
    &["paedobaptist"],
];

pub(crate) static ENTRY_PEDODONTICS_8145223833546781144: VariantsMap = [
    &["pedodontics"],
    &["paedodontics"],
    &["paedodontics"],
    &["paedodontics"],
];

pub(crate) static ENTRY_PEDODONTIC_7097035619717257706: VariantsMap = [
    &["pedodontic"],
    &["paedodontic"],
    &["paedodontic"],
    &["paedodontic"],
];

pub(crate) static ENTRY_PEDOGENESES_11751885517659328439: VariantsMap = [
    &["pedogeneses"],
    &["paedogeneses"],
    &["paedogeneses"],
    &["paedogeneses"],
];

pub(crate) static ENTRY_PEDOGENESIS_16553520519907492848: VariantsMap = [
    &["pedogenesis"],
    &["paedogenesis"],
    &["paedogenesis"],
    &["paedogenesis"],
];

pub(crate) static ENTRY_PEDOGENETIC_14694065223630380055: VariantsMap = [
    &["pedogenetic"],
    &["paedogenetic"],
    &["paedogenetic"],
    &["paedogenetic"],
];

pub(crate) static ENTRY_PEDOGENIC_1833539086674286725: VariantsMap = [
    &["pedogenic"],
    &["paedogenic"],
    &["paedogenic"],
    &["paedogenic"],
];

pub(crate) static ENTRY_PEDOLOGICAL_2385823981182048058: VariantsMap = [
    &["pedological"],
    &["paedological"],
    &["paedological"],
    &["paedological"],
];

pub(crate) static ENTRY_PEDOLOGIES_1726305538167071973: VariantsMap = [
    &["pedologies"],
    &["paedologies"],
    &["paedologies"],
    &["paedologies"],
];

pub(crate) static ENTRY_PEDOLOGISTS_1566477727057184854: VariantsMap = [
    &["pedologists"],
    &["paedologists"],
    &["paedologists"],
    &["paedologists"],
];

pub(crate) static ENTRY_PEDOLOGIST_354177147374191220: VariantsMap = [
    &["pedologist"],
    &["paedologist"],
    &["paedologist"],
    &["paedologist"],
];

pub(crate) static ENTRY_PEDOLOGY_4566379431183985277: VariantsMap = [
    &["pedology"],
    &["paedology"],
    &["paedology"],
    &["paedology"],
];

pub(crate) static ENTRY_PEDOMETRICAL_17829124265715907889: VariantsMap = [
    &["pedometrical"],
    &["paedometrical"],
    &["paedometrical"],
    &["paedometrical"],
];

pub(crate) static ENTRY_PEDOMORPHIC_146159920442818415: VariantsMap = [
    &["pedomorphic"],
    &["paedomorphic"],
    &["paedomorphic"],
    &["paedomorphic"],
];

pub(crate) static ENTRY_PEDOMORPHISMS_7963376961948666057: VariantsMap = [
    &["pedomorphisms"],
    &["paedomorphisms"],
    &["paedomorphisms"],
    &["paedomorphisms"],
];

pub(crate) static ENTRY_PEDOMORPHISM_11023075726064362802: VariantsMap = [
    &["pedomorphism"],
    &["paedomorphism"],
    &["paedomorphism"],
    &["paedomorphism"],
];

pub(crate) static ENTRY_PEDOMORPHOSES_13196177470788332356: VariantsMap = [
    &["pedomorphoses"],
    &["paedomorphoses"],
    &["paedomorphoses"],
    &["paedomorphoses"],
];

pub(crate) static ENTRY_PEDOMORPHOSIS_10919909675152569331: VariantsMap = [
    &["pedomorphosis"],
    &["paedomorphosis"],
    &["paedomorphosis"],
    &["paedomorphosis"],
];

pub(crate) static ENTRY_PEDOPHILES_18122867727560912141: VariantsMap = [
    &["pedophiles"],
    &["paedophiles"],
    &["pedophiles"],
    &["paedophiles"],
];

pub(crate) static ENTRY_PEDOPHILE_17284081556096473917: VariantsMap = [
    &["pedophile"],
    &["paedophile"],
    &["pedophile"],
    &["paedophile"],
];

pub(crate) static ENTRY_PEDOPHILIACS_13603976488274466890: VariantsMap = [
    &["pedophiliacs"],
    &["paedophiliacs"],
    &["paedophiliacs"],
    &["paedophiliacs"],
];

pub(crate) static ENTRY_PEDOPHILIAC_9617447498442302443: VariantsMap = [
    &["pedophiliac"],
    &["paedophiliac"],
    &["paedophiliac"],
    &["paedophiliac"],
];

pub(crate) static ENTRY_PEDOPHILIAS_7493061271312788807: VariantsMap = [
    &["pedophilias"],
    &["paedophilias"],
    &["paedophilias"],
    &["paedophilias"],
];

pub(crate) static ENTRY_PEDOPHILIA_6687546858614581858: VariantsMap = [
    &["pedophilia"],
    &["paedophilia"],
    &["paedophilia"],
    &["paedophilia"],
];

pub(crate) static ENTRY_PEDOPHILIC_17657453635897677867: VariantsMap = [
    &["pedophilic"],
    &["paedophilic"],
    &["paedophilic"],
    &["paedophilic"],
];

pub(crate) static ENTRY_PEDOTRIBE_8433883032428611364: VariantsMap = [
    &["pedotribe"],
    &["paedotribe"],
    &["paedotribe"],
    &["paedotribe"],
];

pub(crate) static ENTRY_PEDOTROPHIC_13712350295339661103: VariantsMap = [
    &["pedotrophic"],
    &["paedotrophic"],
    &["paedotrophic"],
    &["paedotrophic"],
];

pub(crate) static ENTRY_PEDOTROPHIST_8546583891936764947: VariantsMap = [
    &["pedotrophist"],
    &["paedotrophist"],
    &["paedotrophist"],
    &["paedotrophist"],
];

pub(crate) static ENTRY_PEDOTROPHY_12360033708377322745: VariantsMap = [
    &["pedotrophy"],
    &["paedotrophy"],
    &["paedotrophy"],
    &["paedotrophy"],
];

pub(crate) static ENTRY_PEIZED_375446066448131987: VariantsMap =
    [&["peized"], &["peised"], &["peized"], &["peised"]];

pub(crate) static ENTRY_PEIZES_4039009294122552266: VariantsMap =
    [&["peizes"], &["peises"], &["peizes"], &["peises"]];

pub(crate) static ENTRY_PEIZE_2588318101141868014: VariantsMap =
    [&["peize"], &["peise"], &["peize"], &["peise"]];

pub(crate) static ENTRY_PEIZING_1448966680631053962: VariantsMap =
    [&["peizing"], &["peising"], &["peizing"], &["peising"]];

pub(crate) static ENTRY_PELLETIZATIONS_1578808908659139702: VariantsMap = [
    &["pelletizations"],
    &["pelletisations"],
    &["pelletizations"],
    &["pelletisations"],
];

pub(crate) static ENTRY_PELLETIZATION_1256758943430120850: VariantsMap = [
    &["pelletization"],
    &["pelletisation"],
    &["pelletization"],
    &["pelletisation"],
];

pub(crate) static ENTRY_PELLETIZED_17773084033857349036: VariantsMap = [
    &["pelletized"],
    &["pelletised"],
    &["pelletized"],
    &["pelletised"],
];

pub(crate) static ENTRY_PELLETIZER_16282407634028657238: VariantsMap = [
    &["pelletizer"],
    &["pelletiser"],
    &["pelletizer"],
    &["pelletiser"],
];

pub(crate) static ENTRY_PELLETIZES_10483149214534795271: VariantsMap = [
    &["pelletizes"],
    &["pelletises"],
    &["pelletizes"],
    &["pelletises"],
];

pub(crate) static ENTRY_PELLETIZE_895054063093563526: VariantsMap = [
    &["pelletize"],
    &["pelletise"],
    &["pelletize"],
    &["pelletise"],
];

pub(crate) static ENTRY_PELLETIZING_4612268880939417810: VariantsMap = [
    &["pelletizing"],
    &["pelletising"],
    &["pelletizing"],
    &["pelletising"],
];

pub(crate) static ENTRY_PELORIZED_3025534207228128571: VariantsMap = [
    &["pelorized"],
    &["pelorised"],
    &["pelorized"],
    &["pelorised"],
];

pub(crate) static ENTRY_PEMMICANIZATIONS_3371249122296666006: VariantsMap = [
    &["pemmicanizations"],
    &["pemmicanisations"],
    &["pemmicanizations"],
    &["pemmicanisations"],
];

pub(crate) static ENTRY_PEMMICANIZATION_6834983618739941341: VariantsMap = [
    &["pemmicanization"],
    &["pemmicanisation"],
    &["pemmicanization"],
    &["pemmicanisation"],
];

pub(crate) static ENTRY_PEMMICANIZES_15457349973362759137: VariantsMap = [
    &["pemmicanizes"],
    &["pemmicanises"],
    &["pemmicanizes"],
    &["pemmicanises"],
];

pub(crate) static ENTRY_PEMMICANIZE_4530348954719077520: VariantsMap = [
    &["pemmicanize"],
    &["pemmicanise"],
    &["pemmicanize"],
    &["pemmicanise"],
];

pub(crate) static ENTRY_PENALIZABLER_13315936384310138731: VariantsMap = [
    &["penalizabler"],
    &["penalisabler"],
    &["penalizabler"],
    &["penalisabler"],
];

pub(crate) static ENTRY_PENALIZABLEST_16408899980166923386: VariantsMap = [
    &["penalizablest"],
    &["penalisablest"],
    &["penalizablest"],
    &["penalisablest"],
];

pub(crate) static ENTRY_PENALIZABLES_4001001474166504822: VariantsMap = [
    &["penalizables"],
    &["penalisables"],
    &["penalizables"],
    &["penalisables"],
];

pub(crate) static ENTRY_PENALIZABLE_17690740352185429467: VariantsMap = [
    &["penalizable"],
    &["penalisable"],
    &["penalizable"],
    &["penalisable"],
];

pub(crate) static ENTRY_PENALIZATIONS_6599684304676350857: VariantsMap = [
    &["penalizations"],
    &["penalisations"],
    &["penalizations"],
    &["penalisations"],
];

pub(crate) static ENTRY_PENALIZATION_11949589953931542079: VariantsMap = [
    &["penalization"],
    &["penalisation"],
    &["penalization"],
    &["penalisation"],
];

pub(crate) static ENTRY_PENALIZED_11761122234321379751: VariantsMap = [
    &["penalized"],
    &["penalised"],
    &["penalized"],
    &["penalised"],
];

pub(crate) static ENTRY_PENALIZES_3731488236002265727: VariantsMap = [
    &["penalizes"],
    &["penalises"],
    &["penalizes"],
    &["penalises"],
];

pub(crate) static ENTRY_PENALIZE_2530505701143168189: VariantsMap =
    [&["penalize"], &["penalise"], &["penalize"], &["penalise"]];

pub(crate) static ENTRY_PENALIZING_15558361744095191436: VariantsMap = [
    &["penalizing"],
    &["penalising"],
    &["penalizing"],
    &["penalising"],
];

pub(crate) static ENTRY_PENCILED_12950313690598237437: VariantsMap = [
    &["penciled"],
    &["pencilled"],
    &["pencilled"],
    &["pencilled"],
];

pub(crate) static ENTRY_PENCILERS_16761262302512468378: VariantsMap = [
    &["pencilers"],
    &["pencillers"],
    &["pencillers"],
    &["pencillers"],
];

pub(crate) static ENTRY_PENCILER_648131672630788391: VariantsMap = [
    &["penciler"],
    &["penciller"],
    &["penciller"],
    &["penciller"],
];

pub(crate) static ENTRY_PENCILINGS_15763703545745446520: VariantsMap = [
    &["pencilings"],
    &["pencillings"],
    &["pencillings"],
    &["pencillings"],
];

pub(crate) static ENTRY_PENCILING_16152937612714350821: VariantsMap = [
    &["penciling"],
    &["pencilling"],
    &["pencilling"],
    &["pencilling"],
];

pub(crate) static ENTRY_PENELOPIZED_9633788614812989197: VariantsMap = [
    &["penelopized"],
    &["penelopised"],
    &["penelopized"],
    &["penelopised"],
];

pub(crate) static ENTRY_PENELOPIZES_689767339108882697: VariantsMap = [
    &["penelopizes"],
    &["penelopises"],
    &["penelopizes"],
    &["penelopises"],
];

pub(crate) static ENTRY_PENELOPIZE_15326668379859195264: VariantsMap = [
    &["penelopize"],
    &["penelopise"],
    &["penelopize"],
    &["penelopise"],
];

pub(crate) static ENTRY_PENELOPIZING_7014423288398423825: VariantsMap = [
    &["penelopizing"],
    &["penelopising"],
    &["penelopizing"],
    &["penelopising"],
];

pub(crate) static ENTRY_PENNE_15841661894922746764: VariantsMap =
    [&["penne"], &["pennae"], &["pennae"], &["pennae"]];

pub(crate) static ENTRY_PENSE_8108242775850229925: VariantsMap =
    [&["pense"], &["pensae"], &["pensae"], &["pensae"]];

pub(crate) static ENTRY_PEPTIZABLES_11059733857451389630: VariantsMap = [
    &["peptizables"],
    &["peptisables"],
    &["peptizables"],
    &["peptisables"],
];

pub(crate) static ENTRY_PEPTIZABLE_10009160293830058217: VariantsMap = [
    &["peptizable"],
    &["peptisable"],
    &["peptizable"],
    &["peptisable"],
];

pub(crate) static ENTRY_PEPTIZATIONS_4461223542992646400: VariantsMap = [
    &["peptizations"],
    &["peptisations"],
    &["peptizations"],
    &["peptisations"],
];

pub(crate) static ENTRY_PEPTIZATION_2277498319096983409: VariantsMap = [
    &["peptization"],
    &["peptisation"],
    &["peptization"],
    &["peptisation"],
];

pub(crate) static ENTRY_PEPTIZED_9732700991499029534: VariantsMap =
    [&["peptized"], &["peptised"], &["peptized"], &["peptised"]];

pub(crate) static ENTRY_PEPTIZERS_15152990595163734193: VariantsMap = [
    &["peptizers"],
    &["peptisers"],
    &["peptizers"],
    &["peptisers"],
];

pub(crate) static ENTRY_PEPTIZER_8332572606012159911: VariantsMap =
    [&["peptizer"], &["peptiser"], &["peptizer"], &["peptiser"]];

pub(crate) static ENTRY_PEPTIZES_14243270822862510623: VariantsMap =
    [&["peptizes"], &["peptises"], &["peptizes"], &["peptises"]];

pub(crate) static ENTRY_PEPTIZE_1985280393670536602: VariantsMap =
    [&["peptize"], &["peptise"], &["peptize"], &["peptise"]];

pub(crate) static ENTRY_PEPTIZING_1479862026322855639: VariantsMap = [
    &["peptizing"],
    &["peptising"],
    &["peptizing"],
    &["peptising"],
];

pub(crate) static ENTRY_PEPTONEMIA_17907025745393161380: VariantsMap = [
    &["peptonemia"],
    &["peptonaemia"],
    &["peptonaemia"],
    &["peptonaemia"],
];

pub(crate) static ENTRY_PEPTONIZATIONS_129619205916628004: VariantsMap = [
    &["peptonizations"],
    &["peptonisations"],
    &["peptonizations"],
    &["peptonisations"],
];

pub(crate) static ENTRY_PEPTONIZATION_5464229779513025707: VariantsMap = [
    &["peptonization"],
    &["peptonisation"],
    &["peptonization"],
    &["peptonisation"],
];

pub(crate) static ENTRY_PEPTONIZED_13686078805549079398: VariantsMap = [
    &["peptonized"],
    &["peptonised"],
    &["peptonized"],
    &["peptonised"],
];

pub(crate) static ENTRY_PEPTONIZER_13244378595341792018: VariantsMap = [
    &["peptonizer"],
    &["peptoniser"],
    &["peptonizer"],
    &["peptoniser"],
];

pub(crate) static ENTRY_PEPTONIZES_6176239638278066971: VariantsMap = [
    &["peptonizes"],
    &["peptonises"],
    &["peptonizes"],
    &["peptonises"],
];

pub(crate) static ENTRY_PEPTONIZE_11347438316995918427: VariantsMap = [
    &["peptonize"],
    &["peptonise"],
    &["peptonize"],
    &["peptonise"],
];

pub(crate) static ENTRY_PEPTONIZING_641849953879089250: VariantsMap = [
    &["peptonizing"],
    &["peptonising"],
    &["peptonizing"],
    &["peptonising"],
];

pub(crate) static ENTRY_PERACIDITY_4694554317646599680: VariantsMap = [
    &["peracidity"],
    &["preacidity"],
    &["preacidity"],
    &["preacidity"],
];

pub(crate) static ENTRY_PERACID_18248699393309889840: VariantsMap =
    [&["peracid"], &["preacid"], &["preacid"], &["preacid"]];

pub(crate) static ENTRY_PERACT_13646631763087455494: VariantsMap =
    [&["peract"], &["preact"], &["preact"], &["preact"]];

pub(crate) static ENTRY_PERACUTE_18080047841868048531: VariantsMap =
    [&["peracute"], &["preacute"], &["preacute"], &["preacute"]];

pub(crate) static ENTRY_PERAMBULATORY_3157892809066109163: VariantsMap = [
    &["perambulatory"],
    &["preambulatory"],
    &["preambulatory"],
    &["preambulatory"],
];

pub(crate) static ENTRY_PERCES_18231213262419993595: VariantsMap =
    [&["perces"], &["preces"], &["preces"], &["preces"]];

pub(crate) static ENTRY_PERCHLORETHANE_1893865275398341525: VariantsMap = [
    &["perchlorethane"],
    &["perchloroethane"],
    &["perchloroethane"],
    &["perchloroethane"],
];

pub(crate) static ENTRY_PERCHLORETHYLENE_525647590945342214: VariantsMap = [
    &["perchlorethylene"],
    &["perchloroethylene"],
    &["perchloroethylene"],
    &["perchloroethylene"],
];

pub(crate) static ENTRY_PERCHLORIC_15873681416223690811: VariantsMap = [
    &["perchloric"],
    &["prechloric"],
    &["prechloric"],
    &["prechloric"],
];

pub(crate) static ENTRY_PERCLOSE_8855509826381556500: VariantsMap =
    [&["perclose"], &["preclose"], &["preclose"], &["preclose"]];

pub(crate) static ENTRY_PERCOMPOUND_4631387873257903195: VariantsMap = [
    &["percompound"],
    &["precompound"],
    &["precompound"],
    &["precompound"],
];

pub(crate) static ENTRY_PERCURRENT_7729534483371927658: VariantsMap = [
    &["percurrent"],
    &["precurrent"],
    &["precurrent"],
    &["precurrent"],
];

pub(crate) static ENTRY_PERCUSSIONIZES_13062136969515927546: VariantsMap = [
    &["percussionizes"],
    &["percussionises"],
    &["percussionizes"],
    &["percussionises"],
];

pub(crate) static ENTRY_PERCUSSIONIZE_6452251918750798380: VariantsMap = [
    &["percussionize"],
    &["percussionise"],
    &["percussionize"],
    &["percussionise"],
];

pub(crate) static ENTRY_PERDICINE_12163131408787238481: VariantsMap = [
    &["perdicine"],
    &["perdicinae"],
    &["perdicinae"],
    &["perdicinae"],
];

pub(crate) static ENTRY_PERDILIGENT_6178720230946595348: VariantsMap = [
    &["perdiligent"],
    &["prediligent"],
    &["prediligent"],
    &["prediligent"],
];

pub(crate) static ENTRY_PERDY_17015242260554099593: VariantsMap =
    [&["perdy"], &["predy"], &["predy"], &["predy"]];

pub(crate) static ENTRY_PEREA_9815109123113005524: VariantsMap =
    [&["perea"], &["peraea"], &["peraea"], &["peraea"]];

pub(crate) static ENTRY_PERENNIALIZES_7776437049346762142: VariantsMap = [
    &["perennializes"],
    &["perennialises"],
    &["perennializes"],
    &["perennialises"],
];

pub(crate) static ENTRY_PERENNIALIZE_17073460830652016286: VariantsMap = [
    &["perennialize"],
    &["perennialise"],
    &["perennialize"],
    &["perennialise"],
];

pub(crate) static ENTRY_PEREON_10052830467199040722: VariantsMap =
    [&["pereon"], &["peraeon"], &["peraeon"], &["peraeon"]];

pub(crate) static ENTRY_PEREOPODS_5967506407992460438: VariantsMap = [
    &["pereopods"],
    &["peraeopods"],
    &["peraeopods"],
    &["peraeopods"],
];

pub(crate) static ENTRY_PEREOPOD_4376907164155484639: VariantsMap = [
    &["pereopod"],
    &["peraeopod"],
    &["peraeopod"],
    &["peraeopod"],
];

pub(crate) static ENTRY_PERFECTIVIZES_3556092795978966359: VariantsMap = [
    &["perfectivizes"],
    &["perfectivises"],
    &["perfectivizes"],
    &["perfectivises"],
];

pub(crate) static ENTRY_PERFECTIVIZE_4991190653079170578: VariantsMap = [
    &["perfectivize"],
    &["perfectivise"],
    &["perfectivize"],
    &["perfectivise"],
];

pub(crate) static ENTRY_PERFERVORS_408834739628621753: VariantsMap = [
    &["perfervors"],
    &["perfervours"],
    &["perfervours"],
    &["perfervours"],
];

pub(crate) static ENTRY_PERFERVOR_5094411619878396347: VariantsMap = [
    &["perfervor"],
    &["perfervour"],
    &["perfervour"],
    &["perfervour"],
];

pub(crate) static ENTRY_PERFET_13896758539689213591: VariantsMap =
    [&["perfet"], &["prefet"], &["prefet"], &["prefet"]];

pub(crate) static ENTRY_PERFOLIATIONS_17365195892397282393: VariantsMap = [
    &["perfoliations"],
    &["prefoliations"],
    &["prefoliations"],
    &["prefoliations"],
];

pub(crate) static ENTRY_PERFOLIATION_5188268018612471981: VariantsMap = [
    &["perfoliation"],
    &["prefoliation"],
    &["prefoliation"],
    &["prefoliation"],
];

pub(crate) static ENTRY_PERFORMANT_15759765683817996390: VariantsMap = [
    &["performant"],
    &["preformant"],
    &["preformant"],
    &["preformant"],
];

pub(crate) static ENTRY_PERFORMATIVE_2390820457715027525: VariantsMap = [
    &["performative"],
    &["preformative"],
    &["preformative"],
    &["preformative"],
];

pub(crate) static ENTRY_PERHAZARD_3309804805860844776: VariantsMap = [
    &["perhazard"],
    &["prehazard"],
    &["prehazard"],
    &["prehazard"],
];

pub(crate) static ENTRY_PERICECAL_11561552565749838840: VariantsMap = [
    &["pericecal"],
    &["pericaecal"],
    &["pericaecal"],
    &["pericaecal"],
];

pub(crate) static ENTRY_PERICECITIS_17229068204731568936: VariantsMap = [
    &["pericecitis"],
    &["pericaecitis"],
    &["pericaecitis"],
    &["pericaecitis"],
];

pub(crate) static ENTRY_PERICENTER_10614733866576424320: VariantsMap = [
    &["pericenter"],
    &["pericentre"],
    &["pericentre"],
    &["pericentre"],
];

pub(crate) static ENTRY_PERICHETE_18105271752996227267: VariantsMap = [
    &["perichete"],
    &["perichaete"],
    &["perichaete"],
    &["perichaete"],
];

pub(crate) static ENTRY_PERICOPE_14246960621803601482: VariantsMap = [
    &["pericope"],
    &["pericopae"],
    &["pericopae"],
    &["pericopae"],
];

pub(crate) static ENTRY_PERIESOPHAGEAL_1263127563857060969: VariantsMap = [
    &["periesophageal"],
    &["perioesophageal"],
    &["perioesophageal"],
    &["perioesophageal"],
];

pub(crate) static ENTRY_PERILED_15060178372319479950: VariantsMap =
    [&["periled"], &["perilled"], &["perilled"], &["perilled"]];

pub(crate) static ENTRY_PERILING_16221031141616213209: VariantsMap = [
    &["periling"],
    &["perilling"],
    &["perilling"],
    &["perilling"],
];

pub(crate) static ENTRY_PERIODICALIZES_17372107047478590982: VariantsMap = [
    &["periodicalizes"],
    &["periodicalises"],
    &["periodicalizes"],
    &["periodicalises"],
];

pub(crate) static ENTRY_PERIODICALIZE_2528030134467014135: VariantsMap = [
    &["periodicalize"],
    &["periodicalise"],
    &["periodicalize"],
    &["periodicalise"],
];

pub(crate) static ENTRY_PERIODIZATIONS_17618036349132017353: VariantsMap = [
    &["periodizations"],
    &["periodisations"],
    &["periodizations"],
    &["periodisations"],
];

pub(crate) static ENTRY_PERIODIZATION_10629388178555953074: VariantsMap = [
    &["periodization"],
    &["periodisation"],
    &["periodization"],
    &["periodisation"],
];

pub(crate) static ENTRY_PERIODIZED_17003691710060511111: VariantsMap = [
    &["periodized"],
    &["periodised"],
    &["periodized"],
    &["periodised"],
];

pub(crate) static ENTRY_PERIODIZES_18153679890341959171: VariantsMap = [
    &["periodizes"],
    &["periodises"],
    &["periodizes"],
    &["periodises"],
];

pub(crate) static ENTRY_PERIODIZE_9672274415726820349: VariantsMap = [
    &["periodize"],
    &["periodise"],
    &["periodize"],
    &["periodise"],
];

pub(crate) static ENTRY_PERIODIZING_11263976325652979359: VariantsMap = [
    &["periodizing"],
    &["periodising"],
    &["periodizing"],
    &["periodising"],
];

pub(crate) static ENTRY_PERJINK_8081638468925211155: VariantsMap =
    [&["perjink"], &["prejink"], &["prejink"], &["prejink"]];

pub(crate) static ENTRY_PERLECTION_10848653127438263550: VariantsMap = [
    &["perlection"],
    &["prelection"],
    &["prelection"],
    &["prelection"],
];

pub(crate) static ENTRY_PERLINGUALLY_9782531538000987848: VariantsMap = [
    &["perlingually"],
    &["prelingually"],
    &["prelingually"],
    &["prelingually"],
];

pub(crate) static ENTRY_PERLINGUAL_9348282944919159241: VariantsMap = [
    &["perlingual"],
    &["prelingual"],
    &["prelingual"],
    &["prelingual"],
];

pub(crate) static ENTRY_PERMISSABLE_15564403146668071230: VariantsMap = [
    &["permissable"],
    &["premissable"],
    &["premissable"],
    &["premissable"],
];

pub(crate) static ENTRY_PERMIXTURE_14648968165378084827: VariantsMap = [
    &["permixture"],
    &["premixture"],
    &["premixture"],
    &["premixture"],
];

pub(crate) static ENTRY_PERNASAL_9314997630181268940: VariantsMap =
    [&["pernasal"], &["prenasal"], &["prenasal"], &["prenasal"]];

pub(crate) static ENTRY_PERORALLY_13736466146014362811: VariantsMap = [
    &["perorally"],
    &["preorally"],
    &["preorally"],
    &["preorally"],
];

pub(crate) static ENTRY_PERORAL_7733507504372641537: VariantsMap =
    [&["peroral"], &["preoral"], &["preoral"], &["preoral"]];

pub(crate) static ENTRY_PEROTIC_5938557738822235093: VariantsMap =
    [&["perotic"], &["preotic"], &["preotic"], &["preotic"]];

pub(crate) static ENTRY_PEROXIDIZED_1496757986507118262: VariantsMap = [
    &["peroxidized"],
    &["peroxidised"],
    &["peroxidized"],
    &["peroxidised"],
];

pub(crate) static ENTRY_PEROXIDIZEMENTS_13015140457438659181: VariantsMap = [
    &["peroxidizements"],
    &["peroxidisements"],
    &["peroxidizements"],
    &["peroxidisements"],
];

pub(crate) static ENTRY_PEROXIDIZEMENT_2992204370621740514: VariantsMap = [
    &["peroxidizement"],
    &["peroxidisement"],
    &["peroxidizement"],
    &["peroxidisement"],
];

pub(crate) static ENTRY_PEROXIDIZES_17724693640385328099: VariantsMap = [
    &["peroxidizes"],
    &["peroxidises"],
    &["peroxidizes"],
    &["peroxidises"],
];

pub(crate) static ENTRY_PEROXIDIZE_10190672229167948456: VariantsMap = [
    &["peroxidize"],
    &["peroxidise"],
    &["peroxidize"],
    &["peroxidise"],
];

pub(crate) static ENTRY_PEROXIDIZING_402392174204032068: VariantsMap = [
    &["peroxidizing"],
    &["peroxidising"],
    &["peroxidizing"],
    &["peroxidising"],
];

pub(crate) static ENTRY_PERPERFECT_18179313282884798168: VariantsMap = [
    &["perperfect"],
    &["preperfect"],
    &["preperfect"],
    &["preperfect"],
];

pub(crate) static ENTRY_PERSE_11387837727041811534: VariantsMap =
    [&["perse"], &["prese"], &["prese"], &["prese"]];

pub(crate) static ENTRY_PERSE_16607558930587897129: VariantsMap =
    [&["perse"], &["persae"], &["persae"], &["persae"]];

pub(crate) static ENTRY_PERSIANIZATIONS_313451334445471865: VariantsMap = [
    &["persianizations"],
    &["persianisations"],
    &["persianizations"],
    &["persianisations"],
];

pub(crate) static ENTRY_PERSIANIZATION_18022273901354166264: VariantsMap = [
    &["persianization"],
    &["persianisation"],
    &["persianization"],
    &["persianisation"],
];

pub(crate) static ENTRY_PERSIANIZED_14851869006792985600: VariantsMap = [
    &["persianized"],
    &["persianised"],
    &["persianized"],
    &["persianised"],
];

pub(crate) static ENTRY_PERSIANIZES_3568176301631230831: VariantsMap = [
    &["persianizes"],
    &["persianises"],
    &["persianizes"],
    &["persianises"],
];

pub(crate) static ENTRY_PERSIANIZE_9671949628640572602: VariantsMap = [
    &["persianize"],
    &["persianise"],
    &["persianize"],
    &["persianise"],
];

pub(crate) static ENTRY_PERSIANIZING_14450069458480800675: VariantsMap = [
    &["persianizing"],
    &["persianising"],
    &["persianizing"],
    &["persianising"],
];

pub(crate) static ENTRY_PERSICIZED_5078414010687668628: VariantsMap = [
    &["persicized"],
    &["persicised"],
    &["persicized"],
    &["persicised"],
];

pub(crate) static ENTRY_PERSICIZES_14697873868504090786: VariantsMap = [
    &["persicizes"],
    &["persicises"],
    &["persicizes"],
    &["persicises"],
];

pub(crate) static ENTRY_PERSICIZE_7446428141072412578: VariantsMap = [
    &["persicize"],
    &["persicise"],
    &["persicize"],
    &["persicise"],
];

pub(crate) static ENTRY_PERSICIZING_912433421347336038: VariantsMap = [
    &["persicizing"],
    &["persicising"],
    &["persicizing"],
    &["persicising"],
];

pub(crate) static ENTRY_PERSOLVE_6208805617619929798: VariantsMap =
    [&["persolve"], &["presolve"], &["presolve"], &["presolve"]];

pub(crate) static ENTRY_PERSONALIZATIONS_8445180728009943143: VariantsMap = [
    &["personalizations"],
    &["personalisations"],
    &["personalizations"],
    &["personalisations"],
];

pub(crate) static ENTRY_PERSONALIZATION_2807413073355132478: VariantsMap = [
    &["personalization"],
    &["personalisation"],
    &["personalization"],
    &["personalisation"],
];

pub(crate) static ENTRY_PERSONALIZED_7678165486146161596: VariantsMap = [
    &["personalized"],
    &["personalised"],
    &["personalized"],
    &["personalised"],
];

pub(crate) static ENTRY_PERSONALIZES_498227984615996131: VariantsMap = [
    &["personalizes"],
    &["personalises"],
    &["personalizes"],
    &["personalises"],
];

pub(crate) static ENTRY_PERSONALIZE_16406670836185668125: VariantsMap = [
    &["personalize"],
    &["personalise"],
    &["personalize"],
    &["personalise"],
];

pub(crate) static ENTRY_PERSONALIZING_5672131506914446806: VariantsMap = [
    &["personalizing"],
    &["personalising"],
    &["personalizing"],
    &["personalising"],
];

pub(crate) static ENTRY_PERSONIZATIONS_11988733076780280712: VariantsMap = [
    &["personizations"],
    &["personisations"],
    &["personizations"],
    &["personisations"],
];

pub(crate) static ENTRY_PERSONIZATION_1020700707438862869: VariantsMap = [
    &["personization"],
    &["personisation"],
    &["personization"],
    &["personisation"],
];

pub(crate) static ENTRY_PERSONIZED_7128716389683509405: VariantsMap = [
    &["personized"],
    &["personised"],
    &["personized"],
    &["personised"],
];

pub(crate) static ENTRY_PERSONIZES_3422163177015925790: VariantsMap = [
    &["personizes"],
    &["personises"],
    &["personizes"],
    &["personises"],
];

pub(crate) static ENTRY_PERSONIZE_8848776385579513558: VariantsMap = [
    &["personize"],
    &["personise"],
    &["personize"],
    &["personise"],
];

pub(crate) static ENTRY_PERSONIZING_3522234374911377812: VariantsMap = [
    &["personizing"],
    &["personising"],
    &["personizing"],
    &["personising"],
];

pub(crate) static ENTRY_PERST_13560994870115707725: VariantsMap =
    [&["perst"], &["prest"], &["prest"], &["prest"]];

pub(crate) static ENTRY_PERUVIANIZES_5512079830671646: VariantsMap = [
    &["peruvianizes"],
    &["peruvianises"],
    &["peruvianizes"],
    &["peruvianises"],
];

pub(crate) static ENTRY_PERUVIANIZE_11424645593077204472: VariantsMap = [
    &["peruvianize"],
    &["peruvianise"],
    &["peruvianize"],
    &["peruvianise"],
];

pub(crate) static ENTRY_PERVED_5641773030984045701: VariantsMap =
    [&["perved"], &["preved"], &["preved"], &["preved"]];

pub(crate) static ENTRY_PERVES_15457354577274877085: VariantsMap =
    [&["perves"], &["preves"], &["preves"], &["preves"]];

pub(crate) static ENTRY_PERVE_15605705734121788203: VariantsMap =
    [&["perve"], &["preve"], &["preve"], &["preve"]];

pub(crate) static ENTRY_PERVIABLE_7017934559789149180: VariantsMap = [
    &["perviable"],
    &["previable"],
    &["previable"],
    &["previable"],
];

pub(crate) static ENTRY_PERVING_861961187036741303: VariantsMap =
    [&["perving"], &["preving"], &["preving"], &["preving"]];

pub(crate) static ENTRY_PERVIOUSNESSES_16881754789905331743: VariantsMap = [
    &["perviousnesses"],
    &["previousnesses"],
    &["previousnesses"],
    &["previousnesses"],
];

pub(crate) static ENTRY_PERVIOUSNESS_12070729285035585339: VariantsMap = [
    &["perviousness"],
    &["previousness"],
    &["previousness"],
    &["previousness"],
];

pub(crate) static ENTRY_PERV_12538763894300491770: VariantsMap =
    [&["perv"], &["prev"], &["prev"], &["prev"]];

pub(crate) static ENTRY_PETALED_7430352286411012981: VariantsMap =
    [&["petaled"], &["petalled"], &["petalled"], &["petalled"]];

pub(crate) static ENTRY_PETLING_10839442998921882121: VariantsMap =
    [&["petling"], &["poetling"], &["poetling"], &["poetling"]];

pub(crate) static ENTRY_PETRARCHIZED_7348574978602994537: VariantsMap = [
    &["petrarchized"],
    &["petrarchised"],
    &["petrarchized"],
    &["petrarchised"],
];

pub(crate) static ENTRY_PETRARCHIZES_5058218394133373743: VariantsMap = [
    &["petrarchizes"],
    &["petrarchises"],
    &["petrarchizes"],
    &["petrarchises"],
];

pub(crate) static ENTRY_PETRARCHIZE_9904851722785626871: VariantsMap = [
    &["petrarchize"],
    &["petrarchise"],
    &["petrarchize"],
    &["petrarchise"],
];

pub(crate) static ENTRY_PETRARCHIZING_12190562219826886176: VariantsMap = [
    &["petrarchizing"],
    &["petrarchising"],
    &["petrarchizing"],
    &["petrarchising"],
];

pub(crate) static ENTRY_PETROLIZATIONS_3981394461797224358: VariantsMap = [
    &["petrolizations"],
    &["petrolisations"],
    &["petrolizations"],
    &["petrolisations"],
];

pub(crate) static ENTRY_PETROLIZATION_13498255753961375094: VariantsMap = [
    &["petrolization"],
    &["petrolisation"],
    &["petrolization"],
    &["petrolisation"],
];

pub(crate) static ENTRY_PETROLIZES_7786452671132997357: VariantsMap = [
    &["petrolizes"],
    &["petrolises"],
    &["petrolizes"],
    &["petrolises"],
];

pub(crate) static ENTRY_PETROLIZE_11225628320479097869: VariantsMap = [
    &["petrolize"],
    &["petrolise"],
    &["petrolize"],
    &["petrolise"],
];

pub(crate) static ENTRY_PE_17043181136692725962: VariantsMap =
    [&["pe"], &["poe"], &["poe"], &["poe"]];

pub(crate) static ENTRY_PHACOCHERE_13405482370905993670: VariantsMap = [
    &["phacochere"],
    &["phacochoere"],
    &["phacochoere"],
    &["phacochoere"],
];

pub(crate) static ENTRY_PHACOCHERINE_10554606661894707387: VariantsMap = [
    &["phacocherine"],
    &["phacochoerine"],
    &["phacochoerine"],
    &["phacochoerine"],
];

pub(crate) static ENTRY_PHAENNA_14814304862853568718: VariantsMap =
    [&["phaenna"], &["phaaenna"], &["phaaenna"], &["phaaenna"]];

pub(crate) static ENTRY_PHAGEDENAS_5494425801711070409: VariantsMap = [
    &["phagedenas"],
    &["phagedaenas"],
    &["phagedaenas"],
    &["phagedaenas"],
];

pub(crate) static ENTRY_PHAGEDENA_6704742627403782762: VariantsMap = [
    &["phagedena"],
    &["phagedaena"],
    &["phagedaena"],
    &["phagedaena"],
];

pub(crate) static ENTRY_PHAGEDENICAL_3768231547699838610: VariantsMap = [
    &["phagedenical"],
    &["phagedaenical"],
    &["phagedaenical"],
    &["phagedaenical"],
];

pub(crate) static ENTRY_PHAGEDENIC_18396375847593319909: VariantsMap = [
    &["phagedenic"],
    &["phagedaenic"],
    &["phagedaenic"],
    &["phagedaenic"],
];

pub(crate) static ENTRY_PHAGEDENOUS_1711073083864725072: VariantsMap = [
    &["phagedenous"],
    &["phagedaenous"],
    &["phagedaenous"],
    &["phagedaenous"],
];

pub(crate) static ENTRY_PHAGOCYTIZES_9458568216408453182: VariantsMap = [
    &["phagocytizes"],
    &["phagocytises"],
    &["phagocytizes"],
    &["phagocytises"],
];

pub(crate) static ENTRY_PHAGOCYTIZE_16597394072222984740: VariantsMap = [
    &["phagocytize"],
    &["phagocytise"],
    &["phagocytize"],
    &["phagocytise"],
];

pub(crate) static ENTRY_PHANTOMIZERS_9577813910680390311: VariantsMap = [
    &["phantomizers"],
    &["phantomisers"],
    &["phantomizers"],
    &["phantomisers"],
];

pub(crate) static ENTRY_PHANTOMIZER_17193520697780091154: VariantsMap = [
    &["phantomizer"],
    &["phantomiser"],
    &["phantomizer"],
    &["phantomiser"],
];

pub(crate) static ENTRY_PHANTOMIZES_7467789553969706258: VariantsMap = [
    &["phantomizes"],
    &["phantomises"],
    &["phantomizes"],
    &["phantomises"],
];

pub(crate) static ENTRY_PHANTOMIZE_11390339407875429440: VariantsMap = [
    &["phantomize"],
    &["phantomise"],
    &["phantomize"],
    &["phantomise"],
];

pub(crate) static ENTRY_PHARISEAN_7036875068880504869: VariantsMap = [
    &["pharisean"],
    &["pharisaean"],
    &["pharisaean"],
    &["pharisaean"],
];

pub(crate) static ENTRY_PHARMACOPEIAN_4180747604463943610: VariantsMap = [
    &["pharmacopeian"],
    &["pharmacopoeian"],
    &["pharmacopoeian"],
    &["pharmacopoeian"],
];

pub(crate) static ENTRY_PHARMACOPOEIAL_5233925692521382480: VariantsMap = [
    &["pharmacopoeial"],
    &["pharmacopoeial"],
    &["pharmacopoeial"],
    &["pharmacopoeial"],
];

pub(crate) static ENTRY_PHELONIONS_15367895008171210427: VariantsMap = [
    &["phelonions"],
    &["phaelonions"],
    &["phaelonions"],
    &["phaelonions"],
];

pub(crate) static ENTRY_PHELONION_16911775146755324729: VariantsMap = [
    &["phelonion"],
    &["phaelonion"],
    &["phaelonion"],
    &["phaelonion"],
];

pub(crate) static ENTRY_PHENICIA_15630851869480130195: VariantsMap = [
    &["phenicia"],
    &["phoenicia"],
    &["phoenicia"],
    &["phoenicia"],
];

pub(crate) static ENTRY_PHENICOPTER_2824141521828380168: VariantsMap = [
    &["phenicopter"],
    &["phoenicopter"],
    &["phoenicopter"],
    &["phoenicopter"],
];

pub(crate) static ENTRY_PHENOGAMS_1730886532743225108: VariantsMap = [
    &["phenogams"],
    &["phaenogams"],
    &["phaenogams"],
    &["phaenogams"],
];

pub(crate) static ENTRY_PHENOGAM_4209907075654374375: VariantsMap = [
    &["phenogam"],
    &["phaenogam"],
    &["phaenogam"],
    &["phaenogam"],
];

pub(crate) static ENTRY_PHENOGENESIS_5657114645659088205: VariantsMap = [
    &["phenogenesis"],
    &["phaenogenesis"],
    &["phaenogenesis"],
    &["phaenogenesis"],
];

pub(crate) static ENTRY_PHENOGENETIC_4532917918539313819: VariantsMap = [
    &["phenogenetic"],
    &["phaenogenetic"],
    &["phaenogenetic"],
    &["phaenogenetic"],
];

pub(crate) static ENTRY_PHENOLIZATIONS_14816642927391194800: VariantsMap = [
    &["phenolizations"],
    &["phenolisations"],
    &["phenolizations"],
    &["phenolisations"],
];

pub(crate) static ENTRY_PHENOLIZATION_6178643424301535160: VariantsMap = [
    &["phenolization"],
    &["phenolisation"],
    &["phenolization"],
    &["phenolisation"],
];

pub(crate) static ENTRY_PHENOLIZES_12025904088177779404: VariantsMap = [
    &["phenolizes"],
    &["phenolises"],
    &["phenolizes"],
    &["phenolises"],
];

pub(crate) static ENTRY_PHENOLIZE_1901105808826241610: VariantsMap = [
    &["phenolize"],
    &["phenolise"],
    &["phenolize"],
    &["phenolise"],
];

pub(crate) static ENTRY_PHENOLOGICAL_10955652503353448632: VariantsMap = [
    &["phenological"],
    &["phaenological"],
    &["phaenological"],
    &["phaenological"],
];

pub(crate) static ENTRY_PHENOLOGIES_16299581387606345895: VariantsMap = [
    &["phenologies"],
    &["phaenologies"],
    &["phaenologies"],
    &["phaenologies"],
];

pub(crate) static ENTRY_PHENOLOGY_2533225012965146295: VariantsMap = [
    &["phenology"],
    &["phaenology"],
    &["phaenology"],
    &["phaenology"],
];

pub(crate) static ENTRY_PHENOMENALIZATIONS_12206092907848664074: VariantsMap = [
    &["phenomenalizations"],
    &["phenomenalisations"],
    &["phenomenalizations"],
    &["phenomenalisations"],
];

pub(crate) static ENTRY_PHENOMENALIZATION_14528853097910122994: VariantsMap = [
    &["phenomenalization"],
    &["phenomenalisation"],
    &["phenomenalization"],
    &["phenomenalisation"],
];

pub(crate) static ENTRY_PHENOMENALIZED_11643906778812926830: VariantsMap = [
    &["phenomenalized"],
    &["phenomenalised"],
    &["phenomenalized"],
    &["phenomenalised"],
];

pub(crate) static ENTRY_PHENOMENALIZES_17401908608894538474: VariantsMap = [
    &["phenomenalizes"],
    &["phenomenalises"],
    &["phenomenalizes"],
    &["phenomenalises"],
];

pub(crate) static ENTRY_PHENOMENALIZE_5560443916737905726: VariantsMap = [
    &["phenomenalize"],
    &["phenomenalise"],
    &["phenomenalize"],
    &["phenomenalise"],
];

pub(crate) static ENTRY_PHENOMENALIZING_153151426474266164: VariantsMap = [
    &["phenomenalizing"],
    &["phenomenalising"],
    &["phenomenalizing"],
    &["phenomenalising"],
];

pub(crate) static ENTRY_PHENOMENISM_960132059160089939: VariantsMap = [
    &["phenomenism"],
    &["phaenomenism"],
    &["phaenomenism"],
    &["phaenomenism"],
];

pub(crate) static ENTRY_PHENOMENIZED_13186647982537861618: VariantsMap = [
    &["phenomenized"],
    &["phenomenised"],
    &["phenomenized"],
    &["phenomenised"],
];

pub(crate) static ENTRY_PHENOMENIZES_8149035924823974047: VariantsMap = [
    &["phenomenizes"],
    &["phenomenises"],
    &["phenomenizes"],
    &["phenomenises"],
];

pub(crate) static ENTRY_PHENOMENIZE_3388568256287381277: VariantsMap = [
    &["phenomenize"],
    &["phenomenise"],
    &["phenomenize"],
    &["phenomenise"],
];

pub(crate) static ENTRY_PHENOMENIZING_3379221850892214321: VariantsMap = [
    &["phenomenizing"],
    &["phenomenising"],
    &["phenomenizing"],
    &["phenomenising"],
];

pub(crate) static ENTRY_PHENOZYGOUS_5083828519660760393: VariantsMap = [
    &["phenozygous"],
    &["phaenozygous"],
    &["phaenozygous"],
    &["phaenozygous"],
];

pub(crate) static ENTRY_PHEOPHYLL_2945109598564039144: VariantsMap = [
    &["pheophyll"],
    &["phaeophyll"],
    &["phaeophyll"],
    &["phaeophyll"],
];

pub(crate) static ENTRY_PHEOPHYL_6124525277655392353: VariantsMap = [
    &["pheophyl"],
    &["phaeophyl"],
    &["phaeophyl"],
    &["phaeophyl"],
];

pub(crate) static ENTRY_PHEOPHYTIN_6768938655441713384: VariantsMap = [
    &["pheophytin"],
    &["phaeophytin"],
    &["phaeophytin"],
    &["phaeophytin"],
];

pub(crate) static ENTRY_PHIALE_16648988129627894747: VariantsMap =
    [&["phiale"], &["phialae"], &["phialae"], &["phialae"]];

pub(crate) static ENTRY_PHILANTHROPIZED_8816715198631162734: VariantsMap = [
    &["philanthropized"],
    &["philanthropised"],
    &["philanthropized"],
    &["philanthropised"],
];

pub(crate) static ENTRY_PHILANTHROPIZES_15996753996390534851: VariantsMap = [
    &["philanthropizes"],
    &["philanthropises"],
    &["philanthropizes"],
    &["philanthropises"],
];

pub(crate) static ENTRY_PHILANTHROPIZE_11035127392376583449: VariantsMap = [
    &["philanthropize"],
    &["philanthropise"],
    &["philanthropize"],
    &["philanthropise"],
];

pub(crate) static ENTRY_PHILANTHROPIZING_927855906725859822: VariantsMap = [
    &["philanthropizing"],
    &["philanthropising"],
    &["philanthropizing"],
    &["philanthropising"],
];

pub(crate) static ENTRY_PHILIPPIZED_10195366950258611952: VariantsMap = [
    &["philippized"],
    &["philippised"],
    &["philippized"],
    &["philippised"],
];

pub(crate) static ENTRY_PHILIPPIZES_3858718280017954826: VariantsMap = [
    &["philippizes"],
    &["philippises"],
    &["philippizes"],
    &["philippises"],
];

pub(crate) static ENTRY_PHILIPPIZE_13053145819398147538: VariantsMap = [
    &["philippize"],
    &["philippise"],
    &["philippize"],
    &["philippise"],
];

pub(crate) static ENTRY_PHILIPPIZING_12304909522561212858: VariantsMap = [
    &["philippizing"],
    &["philippising"],
    &["philippizing"],
    &["philippising"],
];

pub(crate) static ENTRY_PHILISTINIZED_15824917951523189934: VariantsMap = [
    &["philistinized"],
    &["philistinised"],
    &["philistinized"],
    &["philistinised"],
];

pub(crate) static ENTRY_PHILISTINIZES_121754806134507167: VariantsMap = [
    &["philistinizes"],
    &["philistinises"],
    &["philistinizes"],
    &["philistinises"],
];

pub(crate) static ENTRY_PHILISTINIZE_13261459833175390275: VariantsMap = [
    &["philistinize"],
    &["philistinise"],
    &["philistinize"],
    &["philistinise"],
];

pub(crate) static ENTRY_PHILISTINIZING_9474558502061243392: VariantsMap = [
    &["philistinizing"],
    &["philistinising"],
    &["philistinizing"],
    &["philistinising"],
];

pub(crate) static ENTRY_PHILOPENAS_10705048107924510090: VariantsMap = [
    &["philopenas"],
    &["philopoenas"],
    &["philopoenas"],
    &["philopoenas"],
];

pub(crate) static ENTRY_PHILOPENA_1662688293565385739: VariantsMap = [
    &["philopena"],
    &["philopoena"],
    &["philopoena"],
    &["philopoena"],
];

pub(crate) static ENTRY_PHILOSOPHIZATIONS_8563926038056739714: VariantsMap = [
    &["philosophizations"],
    &["philosophisations"],
    &["philosophizations"],
    &["philosophisations"],
];

pub(crate) static ENTRY_PHILOSOPHIZATION_4092799111515698897: VariantsMap = [
    &["philosophization"],
    &["philosophisation"],
    &["philosophization"],
    &["philosophisation"],
];

pub(crate) static ENTRY_PHILOSOPHIZED_2316681608168076190: VariantsMap = [
    &["philosophized"],
    &["philosophised"],
    &["philosophized"],
    &["philosophised"],
];

pub(crate) static ENTRY_PHILOSOPHIZERS_9751548833379500220: VariantsMap = [
    &["philosophizers"],
    &["philosophisers"],
    &["philosophizers"],
    &["philosophisers"],
];

pub(crate) static ENTRY_PHILOSOPHIZER_13078210838054950081: VariantsMap = [
    &["philosophizer"],
    &["philosophiser"],
    &["philosophizer"],
    &["philosophiser"],
];

pub(crate) static ENTRY_PHILOSOPHIZES_4374489325746751173: VariantsMap = [
    &["philosophizes"],
    &["philosophises"],
    &["philosophizes"],
    &["philosophises"],
];

pub(crate) static ENTRY_PHILOSOPHIZE_6289672951361880530: VariantsMap = [
    &["philosophize"],
    &["philosophise"],
    &["philosophize"],
    &["philosophise"],
];

pub(crate) static ENTRY_PHILOSOPHIZING_7293438746871613968: VariantsMap = [
    &["philosophizing"],
    &["philosophising"],
    &["philosophizing"],
    &["philosophising"],
];

pub(crate) static ENTRY_PHILTERS_15728406259693213137: VariantsMap =
    [&["philters"], &["philtres"], &["philtres"], &["philtres"]];

pub(crate) static ENTRY_PHILTER_10084940057302890116: VariantsMap =
    [&["philter"], &["philtre"], &["philtre"], &["philtre"]];

pub(crate) static ENTRY_PHLEBOTOMIZATIONS_13570026240025562120: VariantsMap = [
    &["phlebotomizations"],
    &["phlebotomisations"],
    &["phlebotomizations"],
    &["phlebotomisations"],
];

pub(crate) static ENTRY_PHLEBOTOMIZATION_14789748646153111751: VariantsMap = [
    &["phlebotomization"],
    &["phlebotomisation"],
    &["phlebotomization"],
    &["phlebotomisation"],
];

pub(crate) static ENTRY_PHLEBOTOMIZED_5100102168126674735: VariantsMap = [
    &["phlebotomized"],
    &["phlebotomised"],
    &["phlebotomized"],
    &["phlebotomised"],
];

pub(crate) static ENTRY_PHLEBOTOMIZES_4093384839909362396: VariantsMap = [
    &["phlebotomizes"],
    &["phlebotomises"],
    &["phlebotomizes"],
    &["phlebotomises"],
];

pub(crate) static ENTRY_PHLEBOTOMIZE_5424959391532030755: VariantsMap = [
    &["phlebotomize"],
    &["phlebotomise"],
    &["phlebotomize"],
    &["phlebotomise"],
];

pub(crate) static ENTRY_PHLEBOTOMIZING_12242317892759935073: VariantsMap = [
    &["phlebotomizing"],
    &["phlebotomising"],
    &["phlebotomizing"],
    &["phlebotomising"],
];

pub(crate) static ENTRY_PHLEUM_2009705278880979838: VariantsMap =
    [&["phleum"], &["phloeum"], &["phloeum"], &["phloeum"]];

pub(crate) static ENTRY_PHLYCTENAE_2049602725476666121: VariantsMap = [
    &["phlyctenae"],
    &["phlyctaenae"],
    &["phlyctaenae"],
    &["phlyctaenae"],
];

pub(crate) static ENTRY_PHLYCTENA_5882861521043497675: VariantsMap = [
    &["phlyctena"],
    &["phlyctaena"],
    &["phlyctaena"],
    &["phlyctaena"],
];

pub(crate) static ENTRY_PHLYCTENULA_514120502377170929: VariantsMap = [
    &["phlyctenula"],
    &["phlyctaenula"],
    &["phlyctaenula"],
    &["phlyctaenula"],
];

pub(crate) static ENTRY_PHOCEAN_8276831186971524579: VariantsMap =
    [&["phocean"], &["phocaean"], &["phocaean"], &["phocaean"]];

pub(crate) static ENTRY_PHONEMICIZATIONS_16553605663286995185: VariantsMap = [
    &["phonemicizations"],
    &["phonemicisations"],
    &["phonemicizations"],
    &["phonemicisations"],
];

pub(crate) static ENTRY_PHONEMICIZATION_6323160181205469127: VariantsMap = [
    &["phonemicization"],
    &["phonemicisation"],
    &["phonemicization"],
    &["phonemicisation"],
];

pub(crate) static ENTRY_PHONEMICIZED_4997860750971504400: VariantsMap = [
    &["phonemicized"],
    &["phonemicised"],
    &["phonemicized"],
    &["phonemicised"],
];

pub(crate) static ENTRY_PHONEMICIZES_6569001176089796159: VariantsMap = [
    &["phonemicizes"],
    &["phonemicises"],
    &["phonemicizes"],
    &["phonemicises"],
];

pub(crate) static ENTRY_PHONEMICIZE_927469605150151893: VariantsMap = [
    &["phonemicize"],
    &["phonemicise"],
    &["phonemicize"],
    &["phonemicise"],
];

pub(crate) static ENTRY_PHONEMICIZING_10695322427443994471: VariantsMap = [
    &["phonemicizing"],
    &["phonemicising"],
    &["phonemicizing"],
    &["phonemicising"],
];

pub(crate) static ENTRY_PHONETICIZATIONS_6895495606775013512: VariantsMap = [
    &["phoneticizations"],
    &["phoneticisations"],
    &["phoneticizations"],
    &["phoneticisations"],
];

pub(crate) static ENTRY_PHONETICIZATION_737615114921263050: VariantsMap = [
    &["phoneticization"],
    &["phoneticisation"],
    &["phoneticization"],
    &["phoneticisation"],
];

pub(crate) static ENTRY_PHONETICIZED_12784331896589493557: VariantsMap = [
    &["phoneticized"],
    &["phoneticised"],
    &["phoneticized"],
    &["phoneticised"],
];

pub(crate) static ENTRY_PHONETICIZES_8399555500802410311: VariantsMap = [
    &["phoneticizes"],
    &["phoneticises"],
    &["phoneticizes"],
    &["phoneticises"],
];

pub(crate) static ENTRY_PHONETICIZE_17444104769984047253: VariantsMap = [
    &["phoneticize"],
    &["phoneticise"],
    &["phoneticize"],
    &["phoneticise"],
];

pub(crate) static ENTRY_PHONETICIZING_1852361785918936440: VariantsMap = [
    &["phoneticizing"],
    &["phoneticising"],
    &["phoneticizing"],
    &["phoneticising"],
];

pub(crate) static ENTRY_PHONETIZATIONS_1248934340338779916: VariantsMap = [
    &["phonetizations"],
    &["phonetisations"],
    &["phonetizations"],
    &["phonetisations"],
];

pub(crate) static ENTRY_PHONETIZATION_18215901972235617344: VariantsMap = [
    &["phonetization"],
    &["phonetisation"],
    &["phonetization"],
    &["phonetisation"],
];

pub(crate) static ENTRY_PHONETIZED_5591888960341485474: VariantsMap = [
    &["phonetized"],
    &["phonetised"],
    &["phonetized"],
    &["phonetised"],
];

pub(crate) static ENTRY_PHONETIZES_17948181531880979803: VariantsMap = [
    &["phonetizes"],
    &["phonetises"],
    &["phonetizes"],
    &["phonetises"],
];

pub(crate) static ENTRY_PHONETIZE_8262409265563929787: VariantsMap = [
    &["phonetize"],
    &["phonetise"],
    &["phonetize"],
    &["phonetise"],
];

pub(crate) static ENTRY_PHONETIZING_4349191718988073503: VariantsMap = [
    &["phonetizing"],
    &["phonetising"],
    &["phonetizing"],
    &["phonetising"],
];

pub(crate) static ENTRY_PHONIED_2250260042946147168: VariantsMap =
    [&["phonied"], &["phonied"], &["phonied"], &["phonied"]];

pub(crate) static ENTRY_PHONYING_13054141319835686864: VariantsMap =
    [&["phonying"], &["phonying"], &["phonying"], &["phonying"]];

pub(crate) static ENTRY_PHORRHEA_17608253370867057471: VariantsMap = [
    &["phorrhea"],
    &["phorrhoea"],
    &["phorrhoea"],
    &["phorrhoea"],
];

pub(crate) static ENTRY_PHOSPHATIZATIONS_1121958433579509731: VariantsMap = [
    &["phosphatizations"],
    &["phosphatisations"],
    &["phosphatizations"],
    &["phosphatisations"],
];

pub(crate) static ENTRY_PHOSPHATIZATION_616667263394769289: VariantsMap = [
    &["phosphatization"],
    &["phosphatisation"],
    &["phosphatization"],
    &["phosphatisation"],
];

pub(crate) static ENTRY_PHOSPHATIZED_13126970640675535946: VariantsMap = [
    &["phosphatized"],
    &["phosphatised"],
    &["phosphatized"],
    &["phosphatised"],
];

pub(crate) static ENTRY_PHOSPHATIZES_8990776804655352551: VariantsMap = [
    &["phosphatizes"],
    &["phosphatises"],
    &["phosphatizes"],
    &["phosphatises"],
];

pub(crate) static ENTRY_PHOSPHATIZE_1667299755293922263: VariantsMap = [
    &["phosphatize"],
    &["phosphatise"],
    &["phosphatize"],
    &["phosphatise"],
];

pub(crate) static ENTRY_PHOSPHATIZING_17500888516700323389: VariantsMap = [
    &["phosphatizing"],
    &["phosphatising"],
    &["phosphatizing"],
    &["phosphatising"],
];

pub(crate) static ENTRY_PHOSPHORIZED_16384672095284129419: VariantsMap = [
    &["phosphorized"],
    &["phosphorised"],
    &["phosphorized"],
    &["phosphorised"],
];

pub(crate) static ENTRY_PHOSPHORIZES_14092986315021869609: VariantsMap = [
    &["phosphorizes"],
    &["phosphorises"],
    &["phosphorizes"],
    &["phosphorises"],
];

pub(crate) static ENTRY_PHOSPHORIZE_16358423542391123484: VariantsMap = [
    &["phosphorize"],
    &["phosphorise"],
    &["phosphorize"],
    &["phosphorise"],
];

pub(crate) static ENTRY_PHOSPHORIZING_17105539577918917030: VariantsMap = [
    &["phosphorizing"],
    &["phosphorising"],
    &["phosphorizing"],
    &["phosphorising"],
];

pub(crate) static ENTRY_PHOTESTHESIS_10504089027857371233: VariantsMap = [
    &["photesthesis"],
    &["photoesthesis"],
    &["photoesthesis"],
    &["photoesthesis"],
];

pub(crate) static ENTRY_PHOTESTHESIS_18028002935597043463: VariantsMap = [
    &["photesthesis"],
    &["photaesthesis"],
    &["photaesthesis"],
    &["photaesthesis"],
];

pub(crate) static ENTRY_PHOTOCATALYZERS_8164419550583756409: VariantsMap = [
    &["photocatalyzers"],
    &["photocatalysers"],
    &["photocatalysers"],
    &["photocatalysers"],
];

pub(crate) static ENTRY_PHOTOCATALYZER_16625334355925095744: VariantsMap = [
    &["photocatalyzer"],
    &["photocatalyser"],
    &["photocatalyser"],
    &["photocatalyser"],
];

pub(crate) static ENTRY_PHOTOESTHETIC_4162550279086204135: VariantsMap = [
    &["photoesthetic"],
    &["photoaesthetic"],
    &["photoaesthetic"],
    &["photoaesthetic"],
];

pub(crate) static ENTRY_PHOTOGRAPHIZES_17052291772239819803: VariantsMap = [
    &["photographizes"],
    &["photographises"],
    &["photographizes"],
    &["photographises"],
];

pub(crate) static ENTRY_PHOTOGRAPHIZE_13009051709358189470: VariantsMap = [
    &["photographize"],
    &["photographise"],
    &["photographize"],
    &["photographise"],
];

pub(crate) static ENTRY_PHOTOIONIZATIONS_12632972190380552273: VariantsMap = [
    &["photoionizations"],
    &["photoionisations"],
    &["photoionizations"],
    &["photoionisations"],
];

pub(crate) static ENTRY_PHOTOIONIZATION_2353665288545299552: VariantsMap = [
    &["photoionization"],
    &["photoionisation"],
    &["photoionization"],
    &["photoionisation"],
];

pub(crate) static ENTRY_PHOTOISOMERIZATIONS_3131890740686826947: VariantsMap = [
    &["photoisomerizations"],
    &["photoisomerisations"],
    &["photoisomerizations"],
    &["photoisomerisations"],
];

pub(crate) static ENTRY_PHOTOISOMERIZATION_14033181143754093132: VariantsMap = [
    &["photoisomerization"],
    &["photoisomerisation"],
    &["photoisomerization"],
    &["photoisomerisation"],
];

pub(crate) static ENTRY_PHOTOLABELED_7558538457232731327: VariantsMap = [
    &["photolabeled"],
    &["photolabelled"],
    &["photolabelled"],
    &["photolabelled"],
];

pub(crate) static ENTRY_PHOTOLABELER_9834790744528440316: VariantsMap = [
    &["photolabeler"],
    &["photolabeller"],
    &["photolabeller"],
    &["photolabeller"],
];

pub(crate) static ENTRY_PHOTOLABELING_12583957988292145757: VariantsMap = [
    &["photolabeling"],
    &["photolabelling"],
    &["photolabelling"],
    &["photolabelling"],
];

pub(crate) static ENTRY_PHOTOLYZABLE_3013653466379758491: VariantsMap = [
    &["photolyzable"],
    &["photolysable"],
    &["photolysable"],
    &["photolysable"],
];

pub(crate) static ENTRY_PHOTOLYZED_4044401391833424884: VariantsMap = [
    &["photolyzed"],
    &["photolysed"],
    &["photolyzed"],
    &["photolysed"],
];

pub(crate) static ENTRY_PHOTOLYZES_11442533529208998520: VariantsMap = [
    &["photolyzes"],
    &["photolyses"],
    &["photolyzes"],
    &["photolyses"],
];

pub(crate) static ENTRY_PHOTOLYZE_15369041603064723973: VariantsMap = [
    &["photolyze"],
    &["photolyse"],
    &["photolyze"],
    &["photolyse"],
];

pub(crate) static ENTRY_PHOTOLYZING_10304193905450130961: VariantsMap = [
    &["photolyzing"],
    &["photolysing"],
    &["photolyzing"],
    &["photolysing"],
];

pub(crate) static ENTRY_PHOTOPOLYMERIZATIONS_9963570724543744714: VariantsMap = [
    &["photopolymerizations"],
    &["photopolymerisations"],
    &["photopolymerizations"],
    &["photopolymerisations"],
];

pub(crate) static ENTRY_PHOTOPOLYMERIZATION_8332984251030365028: VariantsMap = [
    &["photopolymerization"],
    &["photopolymerisation"],
    &["photopolymerization"],
    &["photopolymerisation"],
];

pub(crate) static ENTRY_PHOTOSENSITIZATIONS_5900393581512994740: VariantsMap = [
    &["photosensitizations"],
    &["photosensitisations"],
    &["photosensitizations"],
    &["photosensitisations"],
];

pub(crate) static ENTRY_PHOTOSENSITIZATION_3455225719453288209: VariantsMap = [
    &["photosensitization"],
    &["photosensitisation"],
    &["photosensitization"],
    &["photosensitisation"],
];

pub(crate) static ENTRY_PHOTOSENSITIZED_6142679385850023798: VariantsMap = [
    &["photosensitized"],
    &["photosensitised"],
    &["photosensitized"],
    &["photosensitised"],
];

pub(crate) static ENTRY_PHOTOSENSITIZERS_11297622188466828139: VariantsMap = [
    &["photosensitizers"],
    &["photosensitisers"],
    &["photosensitizers"],
    &["photosensitisers"],
];

pub(crate) static ENTRY_PHOTOSENSITIZER_10017955015526437502: VariantsMap = [
    &["photosensitizer"],
    &["photosensitiser"],
    &["photosensitizer"],
    &["photosensitiser"],
];

pub(crate) static ENTRY_PHOTOSENSITIZES_5875867603426985013: VariantsMap = [
    &["photosensitizes"],
    &["photosensitises"],
    &["photosensitizes"],
    &["photosensitises"],
];

pub(crate) static ENTRY_PHOTOSENSITIZE_12371098856611489759: VariantsMap = [
    &["photosensitize"],
    &["photosensitise"],
    &["photosensitize"],
    &["photosensitise"],
];

pub(crate) static ENTRY_PHOTOSENSITIZING_3966854427188119206: VariantsMap = [
    &["photosensitizing"],
    &["photosensitising"],
    &["photosensitizing"],
    &["photosensitising"],
];

pub(crate) static ENTRY_PHOTOSYNTHESIZED_8205058313674230591: VariantsMap = [
    &["photosynthesized"],
    &["photosynthesised"],
    &["photosynthesized"],
    &["photosynthesised"],
];

pub(crate) static ENTRY_PHOTOSYNTHESIZES_2447766527906919866: VariantsMap = [
    &["photosynthesizes"],
    &["photosynthesises"],
    &["photosynthesizes"],
    &["photosynthesises"],
];

pub(crate) static ENTRY_PHOTOSYNTHESIZE_9353202202077615821: VariantsMap = [
    &["photosynthesize"],
    &["photosynthesise"],
    &["photosynthesize"],
    &["photosynthesise"],
];

pub(crate) static ENTRY_PHOTOSYNTHESIZING_9195844832593591204: VariantsMap = [
    &["photosynthesizing"],
    &["photosynthesising"],
    &["photosynthesizing"],
    &["photosynthesising"],
];

pub(crate) static ENTRY_PHRENOLOGIZED_3753596870390610768: VariantsMap = [
    &["phrenologized"],
    &["phrenologised"],
    &["phrenologized"],
    &["phrenologised"],
];

pub(crate) static ENTRY_PHRENOLOGIZES_9322358579091550629: VariantsMap = [
    &["phrenologizes"],
    &["phrenologises"],
    &["phrenologizes"],
    &["phrenologises"],
];

pub(crate) static ENTRY_PHRENOLOGIZE_8826874213224657962: VariantsMap = [
    &["phrenologize"],
    &["phrenologise"],
    &["phrenologize"],
    &["phrenologise"],
];

pub(crate) static ENTRY_PHRENOLOGIZING_8180250475409589410: VariantsMap = [
    &["phrenologizing"],
    &["phrenologising"],
    &["phrenologizing"],
    &["phrenologising"],
];

pub(crate) static ENTRY_PHYLACTOLEMATA_4727881121175758737: VariantsMap = [
    &["phylactolemata"],
    &["phylactolaemata"],
    &["phylactolaemata"],
    &["phylactolaemata"],
];

pub(crate) static ENTRY_PHYLACTOLEMA_9504620286399322607: VariantsMap = [
    &["phylactolema"],
    &["phylactolaema"],
    &["phylactolaema"],
    &["phylactolaema"],
];

pub(crate) static ENTRY_PHYTOECOLOGY_14832754206983871485: VariantsMap = [
    &["phytoecology"],
    &["phytooecology"],
    &["phytooecology"],
    &["phytooecology"],
];

pub(crate) static ENTRY_PHYTOHEMAGGLUTININ_6639532879219917503: VariantsMap = [
    &["phytohemagglutinin"],
    &["phytohaemagglutinin"],
    &["phytohaemagglutinin"],
    &["phytohaemagglutinin"],
];

pub(crate) static ENTRY_PIARHEMIC_7252173850563280414: VariantsMap = [
    &["piarhemic"],
    &["piarhaemic"],
    &["piarhaemic"],
    &["piarhaemic"],
];

pub(crate) static ENTRY_PIASTERS_7280037555234194522: VariantsMap =
    [&["piasters"], &["piastres"], &["piastres"], &["piastres"]];

pub(crate) static ENTRY_PIASTER_11202645044054150783: VariantsMap =
    [&["piaster"], &["piastre"], &["piastre"], &["piastre"]];

pub(crate) static ENTRY_PICOGRAMS_6301335701016571140: VariantsMap = [
    &["picograms"],
    &["picograms"],
    &["picograms"],
    &["picograms"],
];

pub(crate) static ENTRY_PICOGRAM_897071979947632084: VariantsMap =
    [&["picogram"], &["picogram"], &["picogram"], &["picogram"]];

pub(crate) static ENTRY_PICOMETERS_8849208120065637750: VariantsMap = [
    &["picometers"],
    &["picometres"],
    &["picometres"],
    &["picometres"],
];

pub(crate) static ENTRY_PICOMETER_18154171812281634044: VariantsMap = [
    &["picometer"],
    &["picometre"],
    &["picometre"],
    &["picometre"],
];

pub(crate) static ENTRY_PICTORIALIZATIONS_8617172813285892415: VariantsMap = [
    &["pictorializations"],
    &["pictorialisations"],
    &["pictorializations"],
    &["pictorialisations"],
];

pub(crate) static ENTRY_PICTORIALIZATION_7712094291310927501: VariantsMap = [
    &["pictorialization"],
    &["pictorialisation"],
    &["pictorialization"],
    &["pictorialisation"],
];

pub(crate) static ENTRY_PICTORIALIZED_6310600748747560949: VariantsMap = [
    &["pictorialized"],
    &["pictorialised"],
    &["pictorialized"],
    &["pictorialised"],
];

pub(crate) static ENTRY_PICTORIALIZES_1596343688530759401: VariantsMap = [
    &["pictorializes"],
    &["pictorialises"],
    &["pictorializes"],
    &["pictorialises"],
];

pub(crate) static ENTRY_PICTORIALIZE_1587515587218069513: VariantsMap = [
    &["pictorialize"],
    &["pictorialise"],
    &["pictorialize"],
    &["pictorialise"],
];

pub(crate) static ENTRY_PICTORIALIZING_1280923510844471637: VariantsMap = [
    &["pictorializing"],
    &["pictorialising"],
    &["pictorializing"],
    &["pictorialising"],
];

pub(crate) static ENTRY_PICTURIZATIONS_8434741872826810359: VariantsMap = [
    &["picturizations"],
    &["picturisations"],
    &["picturizations"],
    &["picturisations"],
];

pub(crate) static ENTRY_PICTURIZATION_17028325824167615829: VariantsMap = [
    &["picturization"],
    &["picturisation"],
    &["picturization"],
    &["picturisation"],
];

pub(crate) static ENTRY_PICTURIZED_15492681815366106114: VariantsMap = [
    &["picturized"],
    &["picturised"],
    &["picturized"],
    &["picturised"],
];

pub(crate) static ENTRY_PICTURIZES_3225547602517349068: VariantsMap = [
    &["picturizes"],
    &["picturises"],
    &["picturizes"],
    &["picturises"],
];

pub(crate) static ENTRY_PICTURIZE_4350733612421535987: VariantsMap = [
    &["picturize"],
    &["picturise"],
    &["picturize"],
    &["picturise"],
];

pub(crate) static ENTRY_PICTURIZING_9871609769029307573: VariantsMap = [
    &["picturizing"],
    &["picturising"],
    &["picturizing"],
    &["picturising"],
];

pub(crate) static ENTRY_PIDGINIZATIONS_9043568517184811829: VariantsMap = [
    &["pidginizations"],
    &["pidginisations"],
    &["pidginizations"],
    &["pidginisations"],
];

pub(crate) static ENTRY_PIDGINIZATION_14898298171211785128: VariantsMap = [
    &["pidginization"],
    &["pidginisation"],
    &["pidginization"],
    &["pidginisation"],
];

pub(crate) static ENTRY_PIDGINIZED_13513455210066371222: VariantsMap = [
    &["pidginized"],
    &["pidginised"],
    &["pidginized"],
    &["pidginised"],
];

pub(crate) static ENTRY_PIDGINIZES_5675570422788375057: VariantsMap = [
    &["pidginizes"],
    &["pidginises"],
    &["pidginizes"],
    &["pidginises"],
];

pub(crate) static ENTRY_PIDGINIZE_14642311815580598344: VariantsMap = [
    &["pidginize"],
    &["pidginise"],
    &["pidginize"],
    &["pidginise"],
];

pub(crate) static ENTRY_PIDGINIZING_5775992654421420841: VariantsMap = [
    &["pidginizing"],
    &["pidginising"],
    &["pidginizing"],
    &["pidginising"],
];

pub(crate) static ENTRY_PIGMEAN_16264762923594143012: VariantsMap =
    [&["pigmean"], &["pigmaean"], &["pigmaean"], &["pigmaean"]];

pub(crate) static ENTRY_PIGMENTIZES_5693731952847051859: VariantsMap = [
    &["pigmentizes"],
    &["pigmentises"],
    &["pigmentizes"],
    &["pigmentises"],
];

pub(crate) static ENTRY_PIGMENTIZE_5554925876815794210: VariantsMap = [
    &["pigmentize"],
    &["pigmentise"],
    &["pigmentize"],
    &["pigmentise"],
];

pub(crate) static ENTRY_PILGRIMIZED_7383980687925714066: VariantsMap = [
    &["pilgrimized"],
    &["pilgrimised"],
    &["pilgrimized"],
    &["pilgrimised"],
];

pub(crate) static ENTRY_PILGRIMIZES_712155321674693248: VariantsMap = [
    &["pilgrimizes"],
    &["pilgrimises"],
    &["pilgrimizes"],
    &["pilgrimises"],
];

pub(crate) static ENTRY_PILGRIMIZE_17154519410230272465: VariantsMap = [
    &["pilgrimize"],
    &["pilgrimise"],
    &["pilgrimize"],
    &["pilgrimise"],
];

pub(crate) static ENTRY_PILGRIMIZING_12398626332914324239: VariantsMap = [
    &["pilgrimizing"],
    &["pilgrimising"],
    &["pilgrimizing"],
    &["pilgrimising"],
];

pub(crate) static ENTRY_PILLARIZES_14004328546306417688: VariantsMap = [
    &["pillarizes"],
    &["pillarises"],
    &["pillarizes"],
    &["pillarises"],
];

pub(crate) static ENTRY_PILLARIZE_17893293885273404475: VariantsMap = [
    &["pillarize"],
    &["pillarise"],
    &["pillarize"],
    &["pillarise"],
];

pub(crate) static ENTRY_PILLORIZED_8385306358890514198: VariantsMap = [
    &["pillorized"],
    &["pillorised"],
    &["pillorized"],
    &["pillorised"],
];

pub(crate) static ENTRY_PILLORIZES_8938264984517358007: VariantsMap = [
    &["pillorizes"],
    &["pillorises"],
    &["pillorizes"],
    &["pillorises"],
];

pub(crate) static ENTRY_PILLORIZE_8959002670003616471: VariantsMap = [
    &["pillorize"],
    &["pillorise"],
    &["pillorize"],
    &["pillorise"],
];

pub(crate) static ENTRY_PILLORIZING_12916238741504692400: VariantsMap = [
    &["pillorizing"],
    &["pillorising"],
    &["pillorizing"],
    &["pillorising"],
];

pub(crate) static ENTRY_PILLOWBEER_7107283998185116408: VariantsMap = [
    &["pillowbeer"],
    &["pillowbere"],
    &["pillowbere"],
    &["pillowbere"],
];

pub(crate) static ENTRY_PINDARIZED_7413959525709250668: VariantsMap = [
    &["pindarized"],
    &["pindarised"],
    &["pindarized"],
    &["pindarised"],
];

pub(crate) static ENTRY_PINDARIZES_17165896999619788388: VariantsMap = [
    &["pindarizes"],
    &["pindarises"],
    &["pindarizes"],
    &["pindarises"],
];

pub(crate) static ENTRY_PINDARIZE_5665870824881318813: VariantsMap = [
    &["pindarize"],
    &["pindarise"],
    &["pindarize"],
    &["pindarise"],
];

pub(crate) static ENTRY_PINDARIZING_5252449072306360079: VariantsMap = [
    &["pindarizing"],
    &["pindarising"],
    &["pindarizing"],
    &["pindarising"],
];

pub(crate) static ENTRY_PINNULE_1047095209482962902: VariantsMap =
    [&["pinnule"], &["pinnulae"], &["pinnulae"], &["pinnulae"]];

pub(crate) static ENTRY_PIRATIZES_6363280016400180691: VariantsMap = [
    &["piratizes"],
    &["piratises"],
    &["piratizes"],
    &["piratises"],
];

pub(crate) static ENTRY_PIRATIZE_7498584575055060768: VariantsMap =
    [&["piratize"], &["piratise"], &["piratize"], &["piratise"]];

pub(crate) static ENTRY_PISCINE_3032140466849687519: VariantsMap =
    [&["piscine"], &["piscinae"], &["piscinae"], &["piscinae"]];

pub(crate) static ENTRY_PISTOLED_12241561110057693947: VariantsMap = [
    &["pistoled"],
    &["pistolled"],
    &["pistolled"],
    &["pistolled"],
];

pub(crate) static ENTRY_PISTOLING_2607035646140319770: VariantsMap = [
    &["pistoling"],
    &["pistolling"],
    &["pistolling"],
    &["pistolling"],
];

pub(crate) static ENTRY_PIZES_5560835984418995409: VariantsMap =
    [&["pizes"], &["pises"], &["pizes"], &["pises"]];

pub(crate) static ENTRY_PLACEAN_13827495213601838014: VariantsMap =
    [&["placean"], &["placaean"], &["placaean"], &["placaean"]];

pub(crate) static ENTRY_PLAGE_9296345710514961167: VariantsMap =
    [&["plage"], &["plagae"], &["plagae"], &["plagae"]];

pub(crate) static ENTRY_PLAGIARIZATIONS_198428492151552423: VariantsMap = [
    &["plagiarizations"],
    &["plagiarisations"],
    &["plagiarizations"],
    &["plagiarisations"],
];

pub(crate) static ENTRY_PLAGIARIZATION_7961094991777232104: VariantsMap = [
    &["plagiarization"],
    &["plagiarisation"],
    &["plagiarization"],
    &["plagiarisation"],
];

pub(crate) static ENTRY_PLAGIARIZED_9613017187196721707: VariantsMap = [
    &["plagiarized"],
    &["plagiarised"],
    &["plagiarized"],
    &["plagiarised"],
];

pub(crate) static ENTRY_PLAGIARIZERS_9616347174653166907: VariantsMap = [
    &["plagiarizers"],
    &["plagiarisers"],
    &["plagiarizers"],
    &["plagiarisers"],
];

pub(crate) static ENTRY_PLAGIARIZER_837829193172431711: VariantsMap = [
    &["plagiarizer"],
    &["plagiariser"],
    &["plagiarizer"],
    &["plagiariser"],
];

pub(crate) static ENTRY_PLAGIARIZES_5807100586921225426: VariantsMap = [
    &["plagiarizes"],
    &["plagiarises"],
    &["plagiarizes"],
    &["plagiarises"],
];

pub(crate) static ENTRY_PLAGIARIZE_10194759391693640324: VariantsMap = [
    &["plagiarize"],
    &["plagiarise"],
    &["plagiarize"],
    &["plagiarise"],
];

pub(crate) static ENTRY_PLAGIARIZING_14588615914934086132: VariantsMap = [
    &["plagiarizing"],
    &["plagiarising"],
    &["plagiarizing"],
    &["plagiarising"],
];

pub(crate) static ENTRY_PLANTE_10913440927257642720: VariantsMap =
    [&["plante"], &["plantae"], &["plantae"], &["plantae"]];

pub(crate) static ENTRY_PLANTULE_7843694394733769427: VariantsMap = [
    &["plantule"],
    &["plantulae"],
    &["plantulae"],
    &["plantulae"],
];

pub(crate) static ENTRY_PLASMAPHERESIS_1101729942583566589: VariantsMap = [
    &["plasmapheresis"],
    &["plasmaphaeresis"],
    &["plasmaphaeresis"],
    &["plasmaphaeresis"],
];

pub(crate) static ENTRY_PLASMOLYZED_5978703891064918750: VariantsMap = [
    &["plasmolyzed"],
    &["plasmolysed"],
    &["plasmolysed"],
    &["plasmolysed"],
];

pub(crate) static ENTRY_PLASMOLYZES_5557512980309334270: VariantsMap = [
    &["plasmolyzes"],
    &["plasmolyses"],
    &["plasmolyses"],
    &["plasmolyses"],
];

pub(crate) static ENTRY_PLASMOLYZE_1739506176647936790: VariantsMap = [
    &["plasmolyze"],
    &["plasmolyse"],
    &["plasmolyse"],
    &["plasmolyse"],
];

pub(crate) static ENTRY_PLASMOLYZING_4681078529426985256: VariantsMap = [
    &["plasmolyzing"],
    &["plasmolysing"],
    &["plasmolysing"],
    &["plasmolysing"],
];

pub(crate) static ENTRY_PLASTICIZATIONS_17193500125688789685: VariantsMap = [
    &["plasticizations"],
    &["plasticisations"],
    &["plasticizations"],
    &["plasticisations"],
];

pub(crate) static ENTRY_PLASTICIZATION_5223268547130847422: VariantsMap = [
    &["plasticization"],
    &["plasticisation"],
    &["plasticization"],
    &["plasticisation"],
];

pub(crate) static ENTRY_PLASTICIZED_7781252037154490596: VariantsMap = [
    &["plasticized"],
    &["plasticised"],
    &["plasticized"],
    &["plasticised"],
];

pub(crate) static ENTRY_PLASTICIZERS_6018942164442812723: VariantsMap = [
    &["plasticizers"],
    &["plasticisers"],
    &["plasticizers"],
    &["plasticisers"],
];

pub(crate) static ENTRY_PLASTICIZER_8318606071228781590: VariantsMap = [
    &["plasticizer"],
    &["plasticiser"],
    &["plasticizer"],
    &["plasticiser"],
];

pub(crate) static ENTRY_PLASTICIZES_9170692950470288401: VariantsMap = [
    &["plasticizes"],
    &["plasticises"],
    &["plasticizes"],
    &["plasticises"],
];

pub(crate) static ENTRY_PLASTICIZE_12797038501706387171: VariantsMap = [
    &["plasticize"],
    &["plasticise"],
    &["plasticize"],
    &["plasticise"],
];

pub(crate) static ENTRY_PLASTICIZING_9614229074072341821: VariantsMap = [
    &["plasticizing"],
    &["plasticising"],
    &["plasticizing"],
    &["plasticising"],
];

pub(crate) static ENTRY_PLATEA_11834704696568479057: VariantsMap =
    [&["platea"], &["plataea"], &["plataea"], &["plataea"]];

pub(crate) static ENTRY_PLATINIZATIONS_1156288939962168369: VariantsMap = [
    &["platinizations"],
    &["platinisations"],
    &["platinizations"],
    &["platinisations"],
];

pub(crate) static ENTRY_PLATINIZATION_1083038364602615335: VariantsMap = [
    &["platinization"],
    &["platinisation"],
    &["platinization"],
    &["platinisation"],
];

pub(crate) static ENTRY_PLATINIZED_14868058494774606882: VariantsMap = [
    &["platinized"],
    &["platinised"],
    &["platinized"],
    &["platinised"],
];

pub(crate) static ENTRY_PLATINIZES_2691556545522250539: VariantsMap = [
    &["platinizes"],
    &["platinises"],
    &["platinizes"],
    &["platinises"],
];

pub(crate) static ENTRY_PLATINIZE_6742218053291606205: VariantsMap = [
    &["platinize"],
    &["platinise"],
    &["platinize"],
    &["platinise"],
];

pub(crate) static ENTRY_PLATINIZING_8264599125346829618: VariantsMap = [
    &["platinizing"],
    &["platinising"],
    &["platinizing"],
    &["platinising"],
];

pub(crate) static ENTRY_PLATITUDINIZATIONS_8947623953157828775: VariantsMap = [
    &["platitudinizations"],
    &["platitudinisations"],
    &["platitudinizations"],
    &["platitudinisations"],
];

pub(crate) static ENTRY_PLATITUDINIZATION_11548882127482737211: VariantsMap = [
    &["platitudinization"],
    &["platitudinisation"],
    &["platitudinization"],
    &["platitudinisation"],
];

pub(crate) static ENTRY_PLATITUDINIZED_12324616080202347816: VariantsMap = [
    &["platitudinized"],
    &["platitudinised"],
    &["platitudinized"],
    &["platitudinised"],
];

pub(crate) static ENTRY_PLATITUDINIZER_7798668408381897855: VariantsMap = [
    &["platitudinizer"],
    &["platitudiniser"],
    &["platitudinizer"],
    &["platitudiniser"],
];

pub(crate) static ENTRY_PLATITUDINIZES_13848363114958142428: VariantsMap = [
    &["platitudinizes"],
    &["platitudinises"],
    &["platitudinizes"],
    &["platitudinises"],
];

pub(crate) static ENTRY_PLATITUDINIZE_5511778463063483337: VariantsMap = [
    &["platitudinize"],
    &["platitudinise"],
    &["platitudinize"],
    &["platitudinise"],
];

pub(crate) static ENTRY_PLATITUDINIZING_11960508778562463338: VariantsMap = [
    &["platitudinizing"],
    &["platitudinising"],
    &["platitudinizing"],
    &["platitudinising"],
];

pub(crate) static ENTRY_PLATONIZATION_1431972253304975157: VariantsMap = [
    &["platonization"],
    &["platonisation"],
    &["platonization"],
    &["platonisation"],
];

pub(crate) static ENTRY_PLATONIZED_9850939091619434183: VariantsMap = [
    &["platonized"],
    &["platonised"],
    &["platonized"],
    &["platonised"],
];

pub(crate) static ENTRY_PLATONIZER_18217924882843355421: VariantsMap = [
    &["platonizer"],
    &["platoniser"],
    &["platonizer"],
    &["platoniser"],
];

pub(crate) static ENTRY_PLATONIZES_11528499264638923457: VariantsMap = [
    &["platonizes"],
    &["platonises"],
    &["platonizes"],
    &["platonises"],
];

pub(crate) static ENTRY_PLATONIZE_4955313131784059286: VariantsMap = [
    &["platonize"],
    &["platonise"],
    &["platonize"],
    &["platonise"],
];

pub(crate) static ENTRY_PLATONIZING_3062623929119448423: VariantsMap = [
    &["platonizing"],
    &["platonising"],
    &["platonizing"],
    &["platonising"],
];

pub(crate) static ENTRY_PLATYCELIAN_7398526835897071803: VariantsMap = [
    &["platycelian"],
    &["platycoelian"],
    &["platycoelian"],
    &["platycoelian"],
];

pub(crate) static ENTRY_PLATYCELOUS_13326142746308283636: VariantsMap = [
    &["platycelous"],
    &["platycoelous"],
    &["platycoelous"],
    &["platycoelous"],
];

pub(crate) static ENTRY_PLEBEIANIZATION_12091869174390175684: VariantsMap = [
    &["plebeianization"],
    &["plebeianisation"],
    &["plebeianization"],
    &["plebeianisation"],
];

pub(crate) static ENTRY_PLEBEIANIZED_3279512410016852495: VariantsMap = [
    &["plebeianized"],
    &["plebeianised"],
    &["plebeianized"],
    &["plebeianised"],
];

pub(crate) static ENTRY_PLEBEIANIZES_13488763327989099599: VariantsMap = [
    &["plebeianizes"],
    &["plebeianises"],
    &["plebeianizes"],
    &["plebeianises"],
];

pub(crate) static ENTRY_PLEBEIANIZE_11877968367262483887: VariantsMap = [
    &["plebeianize"],
    &["plebeianise"],
    &["plebeianize"],
    &["plebeianise"],
];

pub(crate) static ENTRY_PLEBEIANIZING_3295946886737938243: VariantsMap = [
    &["plebeianizing"],
    &["plebeianising"],
    &["plebeianizing"],
    &["plebeianising"],
];

pub(crate) static ENTRY_PLEUROPERITONEAL_4698454746375539129: VariantsMap = [
    &["pleuroperitoneal"],
    &["pleuroperitonaeal"],
    &["pleuroperitonaeal"],
    &["pleuroperitonaeal"],
];

pub(crate) static ENTRY_PLOWABLE_17280767722391212022: VariantsMap = [
    &["plowable"],
    &["ploughable"],
    &["plowable"],
    &["ploughable"],
];

pub(crate) static ENTRY_PLOWBOYS_13918215017723803049: VariantsMap = [
    &["plowboys"],
    &["ploughboys"],
    &["ploughboys"],
    &["ploughboys"],
];

pub(crate) static ENTRY_PLOWBOY_3950688802796165974: VariantsMap =
    [&["plowboy"], &["ploughboy"], &["ploughboy"], &["ploughboy"]];

pub(crate) static ENTRY_PLOWED_9574602430050227983: VariantsMap =
    [&["plowed"], &["ploughed"], &["plowed"], &["ploughed"]];

pub(crate) static ENTRY_PLOWERS_12302245220185487703: VariantsMap =
    [&["plowers"], &["ploughers"], &["plowers"], &["ploughers"]];

pub(crate) static ENTRY_PLOWER_8745478383312458084: VariantsMap =
    [&["plower"], &["plougher"], &["plower"], &["plougher"]];

pub(crate) static ENTRY_PLOWHEAD_4904472169551678601: VariantsMap = [
    &["plowhead"],
    &["ploughhead"],
    &["ploughhead"],
    &["ploughhead"],
];

pub(crate) static ENTRY_PLOWING_17492249086035756049: VariantsMap =
    [&["plowing"], &["ploughing"], &["plowing"], &["ploughing"]];

pub(crate) static ENTRY_PLOWMAN_17563255430094623913: VariantsMap =
    [&["plowman"], &["ploughman"], &["ploughman"], &["ploughman"]];

pub(crate) static ENTRY_PLOWMEN_2445871749264248581: VariantsMap =
    [&["plowmen"], &["ploughmen"], &["ploughmen"], &["ploughmen"]];

pub(crate) static ENTRY_PLOWSHARES_13417439424755185353: VariantsMap = [
    &["plowshares"],
    &["ploughshares"],
    &["ploughshares"],
    &["ploughshares"],
];

pub(crate) static ENTRY_PLOWSHARE_951608328770233313: VariantsMap = [
    &["plowshare"],
    &["ploughshare"],
    &["ploughshare"],
    &["ploughshare"],
];

pub(crate) static ENTRY_PLOWS_11203227963409601706: VariantsMap =
    [&["plows"], &["ploughs"], &["plows"], &["ploughs"]];

pub(crate) static ENTRY_PLOW_5294773589996205415: VariantsMap =
    [&["plow"], &["plough"], &["plow"], &["plough"]];

pub(crate) static ENTRY_PLUMULE_4648783015281606707: VariantsMap =
    [&["plumule"], &["plumulae"], &["plumulae"], &["plumulae"]];

pub(crate) static ENTRY_PLURALIZATIONS_18269674181224004202: VariantsMap = [
    &["pluralizations"],
    &["pluralisations"],
    &["pluralizations"],
    &["pluralisations"],
];

pub(crate) static ENTRY_PLURALIZATION_5670946523880574178: VariantsMap = [
    &["pluralization"],
    &["pluralisation"],
    &["pluralization"],
    &["pluralisation"],
];

pub(crate) static ENTRY_PLURALIZED_6800060174654023706: VariantsMap = [
    &["pluralized"],
    &["pluralised"],
    &["pluralized"],
    &["pluralised"],
];

pub(crate) static ENTRY_PLURALIZERS_15471907995822956968: VariantsMap = [
    &["pluralizers"],
    &["pluralisers"],
    &["pluralizers"],
    &["pluralisers"],
];

pub(crate) static ENTRY_PLURALIZER_1150676904940417175: VariantsMap = [
    &["pluralizer"],
    &["pluraliser"],
    &["pluralizer"],
    &["pluraliser"],
];

pub(crate) static ENTRY_PLURALIZES_11096808149614325328: VariantsMap = [
    &["pluralizes"],
    &["pluralises"],
    &["pluralizes"],
    &["pluralises"],
];

pub(crate) static ENTRY_PLURALIZE_11864296364586636944: VariantsMap = [
    &["pluralize"],
    &["pluralise"],
    &["pluralize"],
    &["pluralise"],
];

pub(crate) static ENTRY_PLURALIZING_11611672548631403517: VariantsMap = [
    &["pluralizing"],
    &["pluralising"],
    &["pluralizing"],
    &["pluralising"],
];

pub(crate) static ENTRY_POETICIZATION_4360595178449589100: VariantsMap = [
    &["poeticization"],
    &["poeticisation"],
    &["poeticization"],
    &["poeticisation"],
];

pub(crate) static ENTRY_POETICIZED_11505730651571650970: VariantsMap = [
    &["poeticized"],
    &["poeticised"],
    &["poeticized"],
    &["poeticised"],
];

pub(crate) static ENTRY_POETICIZES_932344514096954986: VariantsMap = [
    &["poeticizes"],
    &["poeticises"],
    &["poeticizes"],
    &["poeticises"],
];

pub(crate) static ENTRY_POETICIZE_3171830565693860719: VariantsMap = [
    &["poeticize"],
    &["poeticise"],
    &["poeticize"],
    &["poeticise"],
];

pub(crate) static ENTRY_POETICIZING_2145412927507553207: VariantsMap = [
    &["poeticizing"],
    &["poeticising"],
    &["poeticizing"],
    &["poeticising"],
];

pub(crate) static ENTRY_POETIZATIONS_9001788595381046094: VariantsMap = [
    &["poetizations"],
    &["poetisations"],
    &["poetizations"],
    &["poetisations"],
];

pub(crate) static ENTRY_POETIZATION_15662003063836424254: VariantsMap = [
    &["poetization"],
    &["poetisation"],
    &["poetization"],
    &["poetisation"],
];

pub(crate) static ENTRY_POETIZED_10784111762264956661: VariantsMap =
    [&["poetized"], &["poetised"], &["poetized"], &["poetised"]];

pub(crate) static ENTRY_POETIZERS_9898979383342189761: VariantsMap = [
    &["poetizers"],
    &["poetisers"],
    &["poetizers"],
    &["poetisers"],
];

pub(crate) static ENTRY_POETIZER_7035494850642872918: VariantsMap =
    [&["poetizer"], &["poetiser"], &["poetizer"], &["poetiser"]];

pub(crate) static ENTRY_POETIZES_10934814919977679962: VariantsMap =
    [&["poetizes"], &["poetises"], &["poetizes"], &["poetises"]];

pub(crate) static ENTRY_POETIZE_4485886018698886455: VariantsMap =
    [&["poetize"], &["poetise"], &["poetize"], &["poetise"]];

pub(crate) static ENTRY_POETIZING_14064411681153855919: VariantsMap = [
    &["poetizing"],
    &["poetising"],
    &["poetizing"],
    &["poetising"],
];

pub(crate) static ENTRY_POGROMIZES_1020547626860892723: VariantsMap = [
    &["pogromizes"],
    &["pogromises"],
    &["pogromizes"],
    &["pogromises"],
];

pub(crate) static ENTRY_POGROMIZE_15682226993080301613: VariantsMap = [
    &["pogromize"],
    &["pogromise"],
    &["pogromize"],
    &["pogromise"],
];

pub(crate) static ENTRY_POLARIZABILITIES_10442898120414601326: VariantsMap = [
    &["polarizabilities"],
    &["polarisabilities"],
    &["polarizabilities"],
    &["polarisabilities"],
];

pub(crate) static ENTRY_POLARIZABILITY_2038012121804259011: VariantsMap = [
    &["polarizability"],
    &["polarisability"],
    &["polarizability"],
    &["polarisability"],
];

pub(crate) static ENTRY_POLARIZABLES_6205801333281852987: VariantsMap = [
    &["polarizables"],
    &["polarisables"],
    &["polarizables"],
    &["polarisables"],
];

pub(crate) static ENTRY_POLARIZABLE_18223083191028705666: VariantsMap = [
    &["polarizable"],
    &["polarisable"],
    &["polarizable"],
    &["polarisable"],
];

pub(crate) static ENTRY_POLARIZATIONS_5016707483625496334: VariantsMap = [
    &["polarizations"],
    &["polarisations"],
    &["polarizations"],
    &["polarisations"],
];

pub(crate) static ENTRY_POLARIZATION_6614126062136329693: VariantsMap = [
    &["polarization"],
    &["polarisation"],
    &["polarization"],
    &["polarisation"],
];

pub(crate) static ENTRY_POLARIZED_4384502108509113795: VariantsMap = [
    &["polarized"],
    &["polarised"],
    &["polarized"],
    &["polarised"],
];

pub(crate) static ENTRY_POLARIZERS_17435224860043461879: VariantsMap = [
    &["polarizers"],
    &["polarisers"],
    &["polarizers"],
    &["polarisers"],
];

pub(crate) static ENTRY_POLARIZER_216484594834440123: VariantsMap = [
    &["polarizer"],
    &["polariser"],
    &["polarizer"],
    &["polariser"],
];

pub(crate) static ENTRY_POLARIZES_8543434351223099952: VariantsMap = [
    &["polarizes"],
    &["polarises"],
    &["polarizes"],
    &["polarises"],
];

pub(crate) static ENTRY_POLARIZE_6991502646544699233: VariantsMap =
    [&["polarize"], &["polarise"], &["polarize"], &["polarise"]];

pub(crate) static ENTRY_POLARIZING_5791777031620829770: VariantsMap = [
    &["polarizing"],
    &["polarising"],
    &["polarizing"],
    &["polarising"],
];

pub(crate) static ENTRY_POLEMICIZED_5043816132806935047: VariantsMap = [
    &["polemicized"],
    &["polemicised"],
    &["polemicized"],
    &["polemicised"],
];

pub(crate) static ENTRY_POLEMICIZES_11323884554859340249: VariantsMap = [
    &["polemicizes"],
    &["polemicises"],
    &["polemicizes"],
    &["polemicises"],
];

pub(crate) static ENTRY_POLEMICIZE_15120423673289782910: VariantsMap = [
    &["polemicize"],
    &["polemicise"],
    &["polemicize"],
    &["polemicise"],
];

pub(crate) static ENTRY_POLEMICIZING_17142821477503800842: VariantsMap = [
    &["polemicizing"],
    &["polemicising"],
    &["polemicizing"],
    &["polemicising"],
];

pub(crate) static ENTRY_POLEMIZED_18177371753176965844: VariantsMap = [
    &["polemized"],
    &["polemised"],
    &["polemized"],
    &["polemised"],
];

pub(crate) static ENTRY_POLEMIZES_4956607855217033028: VariantsMap = [
    &["polemizes"],
    &["polemises"],
    &["polemizes"],
    &["polemises"],
];

pub(crate) static ENTRY_POLEMIZE_4645054350538789425: VariantsMap =
    [&["polemize"], &["polemise"], &["polemize"], &["polemise"]];

pub(crate) static ENTRY_POLEMIZING_12643115025013767594: VariantsMap = [
    &["polemizing"],
    &["polemising"],
    &["polemizing"],
    &["polemising"],
];

pub(crate) static ENTRY_POLICIZERS_10984675264862024887: VariantsMap = [
    &["policizers"],
    &["policisers"],
    &["policizers"],
    &["policisers"],
];

pub(crate) static ENTRY_POLICIZER_11504979841575522568: VariantsMap = [
    &["policizer"],
    &["policiser"],
    &["policizer"],
    &["policiser"],
];

pub(crate) static ENTRY_POLICIZES_3231780840519708788: VariantsMap = [
    &["policizes"],
    &["policises"],
    &["policizes"],
    &["policises"],
];

pub(crate) static ENTRY_POLICIZE_6261956984982088948: VariantsMap =
    [&["policize"], &["policise"], &["policize"], &["policise"]];

pub(crate) static ENTRY_POLIENCEPHALITIS_10355986804039942235: VariantsMap = [
    &["poliencephalitis"],
    &["polioencephalitis"],
    &["polioencephalitis"],
    &["polioencephalitis"],
];

pub(crate) static ENTRY_POLIENCEPHALOMYELITIS_18175298687506614222: VariantsMap = [
    &["poliencephalomyelitis"],
    &["polioencephalomyelitis"],
    &["polioencephalomyelitis"],
    &["polioencephalomyelitis"],
];

pub(crate) static ENTRY_POLITICALIZES_9952299193970370172: VariantsMap = [
    &["politicalizes"],
    &["politicalises"],
    &["politicalizes"],
    &["politicalises"],
];

pub(crate) static ENTRY_POLITICALIZE_13546525614092282549: VariantsMap = [
    &["politicalize"],
    &["politicalise"],
    &["politicalize"],
    &["politicalise"],
];

pub(crate) static ENTRY_POLITICIZATIONS_1624829829441968277: VariantsMap = [
    &["politicizations"],
    &["politicisations"],
    &["politicizations"],
    &["politicisations"],
];

pub(crate) static ENTRY_POLITICIZATION_14296189920998092712: VariantsMap = [
    &["politicization"],
    &["politicisation"],
    &["politicization"],
    &["politicisation"],
];

pub(crate) static ENTRY_POLITICIZED_2600843113498243890: VariantsMap = [
    &["politicized"],
    &["politicised"],
    &["politicized"],
    &["politicised"],
];

pub(crate) static ENTRY_POLITICIZERS_536327452029040996: VariantsMap = [
    &["politicizers"],
    &["politicisers"],
    &["politicizers"],
    &["politicisers"],
];

pub(crate) static ENTRY_POLITICIZER_16483262168673095615: VariantsMap = [
    &["politicizer"],
    &["politiciser"],
    &["politicizer"],
    &["politiciser"],
];

pub(crate) static ENTRY_POLITICIZES_15842748929836601577: VariantsMap = [
    &["politicizes"],
    &["politicises"],
    &["politicizes"],
    &["politicises"],
];

pub(crate) static ENTRY_POLITICIZE_14733719891264090605: VariantsMap = [
    &["politicize"],
    &["politicise"],
    &["politicize"],
    &["politicise"],
];

pub(crate) static ENTRY_POLITICIZING_2582222145866644700: VariantsMap = [
    &["politicizing"],
    &["politicising"],
    &["politicizing"],
    &["politicising"],
];

pub(crate) static ENTRY_POLITIZES_11960619261098930872: VariantsMap = [
    &["politizes"],
    &["politises"],
    &["politizes"],
    &["politises"],
];

pub(crate) static ENTRY_POLITIZE_15643725307730123435: VariantsMap =
    [&["politize"], &["politise"], &["politize"], &["politise"]];

pub(crate) static ENTRY_POLLENIZER_6903386018614258437: VariantsMap = [
    &["pollenizer"],
    &["polleniser"],
    &["pollenizer"],
    &["polleniser"],
];

pub(crate) static ENTRY_POLLINIZED_9141671454408181534: VariantsMap = [
    &["pollinized"],
    &["pollinised"],
    &["pollinized"],
    &["pollinised"],
];

pub(crate) static ENTRY_POLLINIZER_17051026365097333805: VariantsMap = [
    &["pollinizer"],
    &["polliniser"],
    &["pollinizer"],
    &["polliniser"],
];

pub(crate) static ENTRY_POLLINIZES_12439282934086792068: VariantsMap = [
    &["pollinizes"],
    &["pollinises"],
    &["pollinizes"],
    &["pollinises"],
];

pub(crate) static ENTRY_POLLINIZE_2202943414429288102: VariantsMap = [
    &["pollinize"],
    &["pollinise"],
    &["pollinize"],
    &["pollinise"],
];

pub(crate) static ENTRY_POLLINIZING_17154378888329023435: VariantsMap = [
    &["pollinizing"],
    &["pollinising"],
    &["pollinizing"],
    &["pollinising"],
];

pub(crate) static ENTRY_POLONIZATION_8949080039895919308: VariantsMap = [
    &["polonization"],
    &["polonisation"],
    &["polonization"],
    &["polonisation"],
];

pub(crate) static ENTRY_POLONIZED_600542361713627836: VariantsMap = [
    &["polonized"],
    &["polonised"],
    &["polonized"],
    &["polonised"],
];

pub(crate) static ENTRY_POLONIZES_7283464149215527797: VariantsMap = [
    &["polonizes"],
    &["polonises"],
    &["polonizes"],
    &["polonises"],
];

pub(crate) static ENTRY_POLONIZE_5875145906362854820: VariantsMap =
    [&["polonize"], &["polonise"], &["polonize"], &["polonise"]];

pub(crate) static ENTRY_POLONIZING_5285708850960514239: VariantsMap = [
    &["polonizing"],
    &["polonising"],
    &["polonizing"],
    &["polonising"],
];

pub(crate) static ENTRY_POLYCHETOUS_11825929076734596407: VariantsMap = [
    &["polychetous"],
    &["polychaetous"],
    &["polychaetous"],
    &["polychaetous"],
];

pub(crate) static ENTRY_POLYCHROMATIZES_14641652646809838991: VariantsMap = [
    &["polychromatizes"],
    &["polychromatises"],
    &["polychromatizes"],
    &["polychromatises"],
];

pub(crate) static ENTRY_POLYCHROMATIZE_10052020194151377560: VariantsMap = [
    &["polychromatize"],
    &["polychromatise"],
    &["polychromatize"],
    &["polychromatise"],
];

pub(crate) static ENTRY_POLYCHROMIZES_14814470113356117191: VariantsMap = [
    &["polychromizes"],
    &["polychromises"],
    &["polychromizes"],
    &["polychromises"],
];

pub(crate) static ENTRY_POLYCHROMIZE_5715117656342861961: VariantsMap = [
    &["polychromize"],
    &["polychromise"],
    &["polychromize"],
    &["polychromise"],
];

pub(crate) static ENTRY_POLYCYTHEMIAS_157883751608332886: VariantsMap = [
    &["polycythemias"],
    &["polycythaemias"],
    &["polycythaemias"],
    &["polycythaemias"],
];

pub(crate) static ENTRY_POLYCYTHEMIA_7260966493605108921: VariantsMap = [
    &["polycythemia"],
    &["polycythaemia"],
    &["polycythaemia"],
    &["polycythaemia"],
];

pub(crate) static ENTRY_POLYCYTHEMIC_12712383842754585769: VariantsMap = [
    &["polycythemic"],
    &["polycythaemic"],
    &["polycythaemic"],
    &["polycythaemic"],
];

pub(crate) static ENTRY_POLYDEMONISMS_1302003455364237571: VariantsMap = [
    &["polydemonisms"],
    &["polydaemonisms"],
    &["polydaemonisms"],
    &["polydaemonisms"],
];

pub(crate) static ENTRY_POLYDEMONISM_7317742690433096316: VariantsMap = [
    &["polydemonism"],
    &["polydaemonism"],
    &["polydaemonism"],
    &["polydaemonism"],
];

pub(crate) static ENTRY_POLYDEMONIST_3735364090533159436: VariantsMap = [
    &["polydemonist"],
    &["polydaemonist"],
    &["polydaemonist"],
    &["polydaemonist"],
];

pub(crate) static ENTRY_POLYEMIA_17027501052390389926: VariantsMap = [
    &["polyemia"],
    &["polyaemia"],
    &["polyaemia"],
    &["polyaemia"],
];

pub(crate) static ENTRY_POLYEMIC_16404653103485719307: VariantsMap = [
    &["polyemic"],
    &["polyaemic"],
    &["polyaemic"],
    &["polyaemic"],
];

pub(crate) static ENTRY_POLYESTROUS_17172156309762664707: VariantsMap = [
    &["polyestrous"],
    &["polyoestrous"],
    &["polyoestrous"],
    &["polyoestrous"],
];

pub(crate) static ENTRY_POLYGAMIZES_13516060080821320556: VariantsMap = [
    &["polygamizes"],
    &["polygamises"],
    &["polygamizes"],
    &["polygamises"],
];

pub(crate) static ENTRY_POLYGAMIZE_12078625945995610836: VariantsMap = [
    &["polygamize"],
    &["polygamise"],
    &["polygamize"],
    &["polygamise"],
];

pub(crate) static ENTRY_POLYHEMIA_974497438142146493: VariantsMap = [
    &["polyhemia"],
    &["polyhaemia"],
    &["polyhaemia"],
    &["polyhaemia"],
];

pub(crate) static ENTRY_POLYHEMIC_12649506891350992052: VariantsMap = [
    &["polyhemic"],
    &["polyhaemic"],
    &["polyhaemic"],
    &["polyhaemic"],
];

pub(crate) static ENTRY_POLYMERIZATIONS_6860899723431207692: VariantsMap = [
    &["polymerizations"],
    &["polymerisations"],
    &["polymerizations"],
    &["polymerisations"],
];

pub(crate) static ENTRY_POLYMERIZATION_1464478082413309887: VariantsMap = [
    &["polymerization"],
    &["polymerisation"],
    &["polymerization"],
    &["polymerisation"],
];

pub(crate) static ENTRY_POLYMERIZED_13422662021131191207: VariantsMap = [
    &["polymerized"],
    &["polymerised"],
    &["polymerized"],
    &["polymerised"],
];

pub(crate) static ENTRY_POLYMERIZES_2934787247449201471: VariantsMap = [
    &["polymerizes"],
    &["polymerises"],
    &["polymerizes"],
    &["polymerises"],
];

pub(crate) static ENTRY_POLYMERIZE_6708036056371064979: VariantsMap = [
    &["polymerize"],
    &["polymerise"],
    &["polymerize"],
    &["polymerise"],
];

pub(crate) static ENTRY_POLYMERIZING_4276224557971404133: VariantsMap = [
    &["polymerizing"],
    &["polymerising"],
    &["polymerizing"],
    &["polymerising"],
];

pub(crate) static ENTRY_POLYPNEA_6328008602290527604: VariantsMap = [
    &["polypnea"],
    &["polypnoea"],
    &["polypnoea"],
    &["polypnoea"],
];

pub(crate) static ENTRY_POLYPNEIC_16775313163795534836: VariantsMap = [
    &["polypneic"],
    &["polypnoeic"],
    &["polypnoeic"],
    &["polypnoeic"],
];

pub(crate) static ENTRY_POLYSULPHURIZATIONS_7327023976815066572: VariantsMap = [
    &["polysulphurizations"],
    &["polysulphurisations"],
    &["polysulphurizations"],
    &["polysulphurisations"],
];

pub(crate) static ENTRY_POLYSULPHURIZATION_11461377658804684698: VariantsMap = [
    &["polysulphurization"],
    &["polysulphurisation"],
    &["polysulphurization"],
    &["polysulphurisation"],
];

pub(crate) static ENTRY_POLYTETRAFLUORETHYLENES_6710798717502830509: VariantsMap = [
    &["polytetrafluorethylenes"],
    &["polytetrafluoroethylenes"],
    &["polytetrafluoroethylenes"],
    &["polytetrafluoroethylenes"],
];

pub(crate) static ENTRY_POLYTETRAFLUORETHYLENE_2112133591938710091: VariantsMap = [
    &["polytetrafluorethylene"],
    &["polytetrafluoroethylene"],
    &["polytetrafluoroethylene"],
    &["polytetrafluoroethylene"],
];

pub(crate) static ENTRY_POMERIUM_16734132116216610483: VariantsMap = [
    &["pomerium"],
    &["pomoerium"],
    &["pomoerium"],
    &["pomoerium"],
];

pub(crate) static ENTRY_POMMELED_12392540602238287482: VariantsMap = [
    &["pommeled"],
    &["pommelled"],
    &["pommelled"],
    &["pommelled"],
];

pub(crate) static ENTRY_POMMELING_9892304044489697369: VariantsMap = [
    &["pommeling"],
    &["pommelling"],
    &["pommelling"],
    &["pommelling"],
];

pub(crate) static ENTRY_POMME_1392041379995082220: VariantsMap =
    [&["pomme"], &["pommae"], &["pommae"], &["pommae"]];

pub(crate) static ENTRY_POPLITEAL_9036243440649577224: VariantsMap = [
    &["popliteal"],
    &["poplitaeal"],
    &["poplitaeal"],
    &["poplitaeal"],
];

pub(crate) static ENTRY_POPULARIZATIONS_9101849244962729450: VariantsMap = [
    &["popularizations"],
    &["popularisations"],
    &["popularizations"],
    &["popularisations"],
];

pub(crate) static ENTRY_POPULARIZATION_4319386853038418661: VariantsMap = [
    &["popularization"],
    &["popularisation"],
    &["popularization"],
    &["popularisation"],
];

pub(crate) static ENTRY_POPULARIZED_10236116886713392471: VariantsMap = [
    &["popularized"],
    &["popularised"],
    &["popularized"],
    &["popularised"],
];

pub(crate) static ENTRY_POPULARIZERS_7507780986550043141: VariantsMap = [
    &["popularizers"],
    &["popularisers"],
    &["popularizers"],
    &["popularisers"],
];

pub(crate) static ENTRY_POPULARIZER_3100157993575081442: VariantsMap = [
    &["popularizer"],
    &["populariser"],
    &["popularizer"],
    &["populariser"],
];

pub(crate) static ENTRY_POPULARIZES_14323192839718770214: VariantsMap = [
    &["popularizes"],
    &["popularises"],
    &["popularizes"],
    &["popularises"],
];

pub(crate) static ENTRY_POPULARIZE_11338007415870421983: VariantsMap = [
    &["popularize"],
    &["popularise"],
    &["popularize"],
    &["popularise"],
];

pub(crate) static ENTRY_POPULARIZING_12963060727527671938: VariantsMap = [
    &["popularizing"],
    &["popularising"],
    &["popularizing"],
    &["popularising"],
];

pub(crate) static ENTRY_PORCELAINIZATIONS_14043183736562241078: VariantsMap = [
    &["porcelainizations"],
    &["porcelainisations"],
    &["porcelainizations"],
    &["porcelainisations"],
];

pub(crate) static ENTRY_PORCELAINIZATION_7970284653006774312: VariantsMap = [
    &["porcelainization"],
    &["porcelainisation"],
    &["porcelainization"],
    &["porcelainisation"],
];

pub(crate) static ENTRY_PORCELAINIZED_17721995023351100286: VariantsMap = [
    &["porcelainized"],
    &["porcelainised"],
    &["porcelainized"],
    &["porcelainised"],
];

pub(crate) static ENTRY_PORCELAINIZES_15383829878492153993: VariantsMap = [
    &["porcelainizes"],
    &["porcelainises"],
    &["porcelainizes"],
    &["porcelainises"],
];

pub(crate) static ENTRY_PORCELAINIZE_15224248540476215268: VariantsMap = [
    &["porcelainize"],
    &["porcelainise"],
    &["porcelainize"],
    &["porcelainise"],
];

pub(crate) static ENTRY_PORCELAINIZING_6068406593577816117: VariantsMap = [
    &["porcelainizing"],
    &["porcelainising"],
    &["porcelainizing"],
    &["porcelainising"],
];

pub(crate) static ENTRY_PORCELLANIZED_1602184418072826370: VariantsMap = [
    &["porcellanized"],
    &["porcellanised"],
    &["porcellanized"],
    &["porcellanised"],
];

pub(crate) static ENTRY_PORCELLANIZES_11959737780523109755: VariantsMap = [
    &["porcellanizes"],
    &["porcellanises"],
    &["porcellanizes"],
    &["porcellanises"],
];

pub(crate) static ENTRY_PORCELLANIZE_9889734704487954397: VariantsMap = [
    &["porcellanize"],
    &["porcellanise"],
    &["porcellanize"],
    &["porcellanise"],
];

pub(crate) static ENTRY_PORCELLANIZING_72705707685647408: VariantsMap = [
    &["porcellanizing"],
    &["porcellanising"],
    &["porcellanizing"],
    &["porcellanising"],
];

pub(crate) static ENTRY_PORERS_4082508852567391444: VariantsMap =
    [&["porers"], &["pourers"], &["pourers"], &["pourers"]];

pub(crate) static ENTRY_PORER_2873682223884239996: VariantsMap =
    [&["porer"], &["pourer"], &["pourer"], &["pourer"]];

pub(crate) static ENTRY_PORINGLY_5338555285588891229: VariantsMap = [
    &["poringly"],
    &["pouringly"],
    &["pouringly"],
    &["pouringly"],
];

pub(crate) static ENTRY_PORPHYRIZATION_1148382602187520647: VariantsMap = [
    &["porphyrization"],
    &["porphyrisation"],
    &["porphyrization"],
    &["porphyrisation"],
];

pub(crate) static ENTRY_PORTE_7184144057547184883: VariantsMap =
    [&["porte"], &["portae"], &["portae"], &["portae"]];

pub(crate) static ENTRY_PORTIONIZES_14892365590304527286: VariantsMap = [
    &["portionizes"],
    &["portionises"],
    &["portionizes"],
    &["portionises"],
];

pub(crate) static ENTRY_PORTIONIZE_7745054283647390462: VariantsMap = [
    &["portionize"],
    &["portionise"],
    &["portionize"],
    &["portionise"],
];

pub(crate) static ENTRY_POSITIVIZES_14296934196287559541: VariantsMap = [
    &["positivizes"],
    &["positivises"],
    &["positivizes"],
    &["positivises"],
];

pub(crate) static ENTRY_POSITIVIZE_2787313673514904195: VariantsMap = [
    &["positivize"],
    &["positivise"],
    &["positivize"],
    &["positivise"],
];

pub(crate) static ENTRY_POSTCECAL_5697546375355169434: VariantsMap = [
    &["postcecal"],
    &["postcaecal"],
    &["postcaecal"],
    &["postcaecal"],
];

pub(crate) static ENTRY_POSTCENAL_18321668788413423675: VariantsMap = [
    &["postcenal"],
    &["postcoenal"],
    &["postcoenal"],
    &["postcoenal"],
];

pub(crate) static ENTRY_POSTERIZES_2395982070613751126: VariantsMap = [
    &["posterizes"],
    &["posterises"],
    &["posterizes"],
    &["posterises"],
];

pub(crate) static ENTRY_POSTERIZE_10675222155169741892: VariantsMap = [
    &["posterize"],
    &["posterise"],
    &["posterize"],
    &["posterise"],
];

pub(crate) static ENTRY_POSTFETAL_447021447482960445: VariantsMap = [
    &["postfetal"],
    &["postfoetal"],
    &["postfoetal"],
    &["postfoetal"],
];

pub(crate) static ENTRY_POSTMEDIEVAL_8669201851324592094: VariantsMap = [
    &["postmedieval"],
    &["postmediaeval"],
    &["postmediaeval"],
    &["postmediaeval"],
];

pub(crate) static ENTRY_POSTSYNCHRONIZATION_8787900960494278765: VariantsMap = [
    &["postsynchronization"],
    &["postsynchronisation"],
    &["postsynchronization"],
    &["postsynchronisation"],
];

pub(crate) static ENTRY_POSTURIZED_1855269915432760164: VariantsMap = [
    &["posturized"],
    &["posturised"],
    &["posturized"],
    &["posturised"],
];

pub(crate) static ENTRY_POSTURIZES_22978895906010729: VariantsMap = [
    &["posturizes"],
    &["posturises"],
    &["posturizes"],
    &["posturises"],
];

pub(crate) static ENTRY_POSTURIZE_2373561399793969964: VariantsMap = [
    &["posturize"],
    &["posturise"],
    &["posturize"],
    &["posturise"],
];

pub(crate) static ENTRY_POSTURIZING_7099554861688894034: VariantsMap = [
    &["posturizing"],
    &["posturising"],
    &["posturizing"],
    &["posturising"],
];

pub(crate) static ENTRY_POTENTIALIZATIONS_7148347553977205280: VariantsMap = [
    &["potentializations"],
    &["potentialisations"],
    &["potentializations"],
    &["potentialisations"],
];

pub(crate) static ENTRY_POTENTIALIZATION_14393801122557379251: VariantsMap = [
    &["potentialization"],
    &["potentialisation"],
    &["potentialization"],
    &["potentialisation"],
];

pub(crate) static ENTRY_POTENTIALIZES_636727104111977105: VariantsMap = [
    &["potentializes"],
    &["potentialises"],
    &["potentializes"],
    &["potentialises"],
];

pub(crate) static ENTRY_POTENTIALIZE_18360475252961479174: VariantsMap = [
    &["potentialize"],
    &["potentialise"],
    &["potentialize"],
    &["potentialise"],
];

pub(crate) static ENTRY_POTENTIZED_1612875680521039571: VariantsMap = [
    &["potentized"],
    &["potentised"],
    &["potentized"],
    &["potentised"],
];

pub(crate) static ENTRY_POTENTIZES_2878093835262550941: VariantsMap = [
    &["potentizes"],
    &["potentises"],
    &["potentizes"],
    &["potentises"],
];

pub(crate) static ENTRY_POTENTIZE_13964196851888528627: VariantsMap = [
    &["potentize"],
    &["potentise"],
    &["potentize"],
    &["potentise"],
];

pub(crate) static ENTRY_POTENTIZING_2786016681800986152: VariantsMap = [
    &["potentizing"],
    &["potentising"],
    &["potentizing"],
    &["potentising"],
];

pub(crate) static ENTRY_POUDERS_12605831179529023475: VariantsMap =
    [&["pouders"], &["poudres"], &["poudres"], &["poudres"]];

pub(crate) static ENTRY_POUDER_14484726764560419907: VariantsMap =
    [&["pouder"], &["poudre"], &["poudre"], &["poudre"]];

pub(crate) static ENTRY_POULDERS_17859768566291438567: VariantsMap =
    [&["poulders"], &["pouldres"], &["pouldres"], &["pouldres"]];

pub(crate) static ENTRY_POULDER_5243886849214829605: VariantsMap =
    [&["poulder"], &["pouldre"], &["pouldre"], &["pouldre"]];

pub(crate) static ENTRY_POWDERIZATIONS_3928705133701495130: VariantsMap = [
    &["powderizations"],
    &["powderisations"],
    &["powderizations"],
    &["powderisations"],
];

pub(crate) static ENTRY_POWDERIZATION_10139052710323629052: VariantsMap = [
    &["powderization"],
    &["powderisation"],
    &["powderization"],
    &["powderisation"],
];

pub(crate) static ENTRY_POWDERIZERS_16351372668298434346: VariantsMap = [
    &["powderizers"],
    &["powderisers"],
    &["powderizers"],
    &["powderisers"],
];

pub(crate) static ENTRY_POWDERIZER_15656006136737054867: VariantsMap = [
    &["powderizer"],
    &["powderiser"],
    &["powderizer"],
    &["powderiser"],
];

pub(crate) static ENTRY_POWDERIZES_13417898852536093227: VariantsMap = [
    &["powderizes"],
    &["powderises"],
    &["powderizes"],
    &["powderises"],
];

pub(crate) static ENTRY_POWDERIZE_8922790541318187108: VariantsMap = [
    &["powderize"],
    &["powderise"],
    &["powderize"],
    &["powderise"],
];

pub(crate) static ENTRY_POWELLIZED_6166230388698204716: VariantsMap = [
    &["powellized"],
    &["powellised"],
    &["powellized"],
    &["powellised"],
];

pub(crate) static ENTRY_POWELLIZES_512498962386922850: VariantsMap = [
    &["powellizes"],
    &["powellises"],
    &["powellizes"],
    &["powellises"],
];

pub(crate) static ENTRY_POWELLIZE_6906774516859375716: VariantsMap = [
    &["powellize"],
    &["powellise"],
    &["powellize"],
    &["powellise"],
];

pub(crate) static ENTRY_POWELLIZING_538575818245718275: VariantsMap = [
    &["powellizing"],
    &["powellising"],
    &["powellizing"],
    &["powellising"],
];

pub(crate) static ENTRY_PRACTICED_14764358740174771780: VariantsMap = [
    &["practiced"],
    &["practised"],
    &["practised"],
    &["practised"],
];

pub(crate) static ENTRY_PRACTICERS_11781048523398293872: VariantsMap = [
    &["practicers"],
    &["practisers"],
    &["practisers"],
    &["practisers"],
];

pub(crate) static ENTRY_PRACTICER_1604829236283350937: VariantsMap = [
    &["practicer"],
    &["practiser"],
    &["practiser"],
    &["practiser"],
];

pub(crate) static ENTRY_PRACTICING_14301958615475402676: VariantsMap = [
    &["practicing"],
    &["practising"],
    &["practising"],
    &["practising"],
];

pub(crate) static ENTRY_PRAENOMENS_251912711638326782: VariantsMap = [
    &["praenomens"],
    &["praenomens"],
    &["praenomens"],
    &["praenomens"],
];

pub(crate) static ENTRY_PRAENOMEN_12851101647627907857: VariantsMap = [
    &["praenomen"],
    &["praenomen"],
    &["praenomen"],
    &["praenomen"],
];

pub(crate) static ENTRY_PRAGMATIZATIONS_8662418597962158707: VariantsMap = [
    &["pragmatizations"],
    &["pragmatisations"],
    &["pragmatizations"],
    &["pragmatisations"],
];

pub(crate) static ENTRY_PRAGMATIZATION_7994386570071309962: VariantsMap = [
    &["pragmatization"],
    &["pragmatisation"],
    &["pragmatization"],
    &["pragmatisation"],
];

pub(crate) static ENTRY_PRAGMATIZED_1036888459501168703: VariantsMap = [
    &["pragmatized"],
    &["pragmatised"],
    &["pragmatized"],
    &["pragmatised"],
];

pub(crate) static ENTRY_PRAGMATIZERS_9799234638847516273: VariantsMap = [
    &["pragmatizers"],
    &["pragmatisers"],
    &["pragmatizers"],
    &["pragmatisers"],
];

pub(crate) static ENTRY_PRAGMATIZER_7483637005948000334: VariantsMap = [
    &["pragmatizer"],
    &["pragmatiser"],
    &["pragmatizer"],
    &["pragmatiser"],
];

pub(crate) static ENTRY_PRAGMATIZES_13474663761584307145: VariantsMap = [
    &["pragmatizes"],
    &["pragmatises"],
    &["pragmatizes"],
    &["pragmatises"],
];

pub(crate) static ENTRY_PRAGMATIZE_343422185629469665: VariantsMap = [
    &["pragmatize"],
    &["pragmatise"],
    &["pragmatize"],
    &["pragmatise"],
];

pub(crate) static ENTRY_PRAGMATIZING_7905336194280525793: VariantsMap = [
    &["pragmatizing"],
    &["pragmatising"],
    &["pragmatizing"],
    &["pragmatising"],
];

pub(crate) static ENTRY_PREABDOMEN_17654103674218328344: VariantsMap = [
    &["preabdomen"],
    &["praeabdomen"],
    &["praeabdomen"],
    &["praeabdomen"],
];

pub(crate) static ENTRY_PREACETABULAR_8636154966920332770: VariantsMap = [
    &["preacetabular"],
    &["praeacetabular"],
    &["praeacetabular"],
    &["praeacetabular"],
];

pub(crate) static ENTRY_PREACHERIZES_5353773739256681754: VariantsMap = [
    &["preacherizes"],
    &["preacherises"],
    &["preacherizes"],
    &["preacherises"],
];

pub(crate) static ENTRY_PREACHERIZE_15577462823086971421: VariantsMap = [
    &["preacherize"],
    &["preacherise"],
    &["preacherize"],
    &["preacherise"],
];

pub(crate) static ENTRY_PREACKNOWLEDGMENTS_6210578949702226482: VariantsMap = [
    &["preacknowledgments"],
    &["preacknowledgements"],
    &["preacknowledgements"],
    &["preacknowledgements"],
];

pub(crate) static ENTRY_PREACKNOWLEDGMENT_13370080387519237911: VariantsMap = [
    &["preacknowledgment"],
    &["preacknowledgement"],
    &["preacknowledgement"],
    &["preacknowledgement"],
];

pub(crate) static ENTRY_PREANAL_4045685164935232098: VariantsMap =
    [&["preanal"], &["praeanal"], &["praeanal"], &["praeanal"]];

pub(crate) static ENTRY_PREANESTHETICS_11926760638683781880: VariantsMap = [
    &["preanesthetics"],
    &["preanaesthetics"],
    &["preanaesthetics"],
    &["preanaesthetics"],
];

pub(crate) static ENTRY_PREANESTHETIC_9312256255292612148: VariantsMap = [
    &["preanesthetic"],
    &["preanaesthetic"],
    &["preanaesthetic"],
    &["preanaesthetic"],
];

pub(crate) static ENTRY_PREAPPRIZED_16626885948208304315: VariantsMap = [
    &["preapprized"],
    &["preapprised"],
    &["preapprized"],
    &["preapprised"],
];

pub(crate) static ENTRY_PREAPPRIZE_10965476670389309101: VariantsMap = [
    &["preapprize"],
    &["preapprise"],
    &["preapprize"],
    &["preapprise"],
];

pub(crate) static ENTRY_PREAPPRIZING_9245621224584706350: VariantsMap = [
    &["preapprizing"],
    &["preapprising"],
    &["preapprizing"],
    &["preapprising"],
];

pub(crate) static ENTRY_PREAUTHORIZE_17711895655398888607: VariantsMap = [
    &["preauthorize"],
    &["preauthorise"],
    &["preauthorize"],
    &["preauthorise"],
];

pub(crate) static ENTRY_PREBAPTIZES_6136234876096081294: VariantsMap = [
    &["prebaptizes"],
    &["prebaptises"],
    &["prebaptizes"],
    &["prebaptises"],
];

pub(crate) static ENTRY_PREBAPTIZE_5674634642550900380: VariantsMap = [
    &["prebaptize"],
    &["prebaptise"],
    &["prebaptize"],
    &["prebaptise"],
];

pub(crate) static ENTRY_PRECANCELATION_9783160411222572763: VariantsMap = [
    &["precancelation"],
    &["precancellation"],
    &["precancellation"],
    &["precancellation"],
];

pub(crate) static ENTRY_PRECAVAE_4088664315652932471: VariantsMap = [
    &["precavae"],
    &["praecavae"],
    &["praecavae"],
    &["praecavae"],
];

pub(crate) static ENTRY_PRECAVA_17244718726567157566: VariantsMap =
    [&["precava"], &["praecava"], &["praecava"], &["praecava"]];

pub(crate) static ENTRY_PRECIPES_11793138580696398194: VariantsMap = [
    &["precipes"],
    &["praecipes"],
    &["praecipes"],
    &["praecipes"],
];

pub(crate) static ENTRY_PRECIPE_16439872753817235281: VariantsMap =
    [&["precipe"], &["praecipe"], &["praecipe"], &["praecipe"]];

pub(crate) static ENTRY_PRECISIONIZES_8864457404063891143: VariantsMap = [
    &["precisionizes"],
    &["precisionises"],
    &["precisionizes"],
    &["precisionises"],
];

pub(crate) static ENTRY_PRECISIONIZE_7123140285802599910: VariantsMap = [
    &["precisionize"],
    &["precisionise"],
    &["precisionize"],
    &["precisionise"],
];

pub(crate) static ENTRY_PRECIVILIZATIONS_14883120958183038655: VariantsMap = [
    &["precivilizations"],
    &["precivilisations"],
    &["precivilizations"],
    &["precivilisations"],
];

pub(crate) static ENTRY_PRECIVILIZATION_8889763047458993422: VariantsMap = [
    &["precivilization"],
    &["precivilisation"],
    &["precivilization"],
    &["precivilisation"],
];

pub(crate) static ENTRY_PRECOCIAL_1632763347532933222: VariantsMap = [
    &["precocial"],
    &["praecocial"],
    &["praecocial"],
    &["praecocial"],
];

pub(crate) static ENTRY_PRECOLORABLER_12809399652471625977: VariantsMap = [
    &["precolorabler"],
    &["precolourabler"],
    &["precolourabler"],
    &["precolourabler"],
];

pub(crate) static ENTRY_PRECOLORABLEST_16508120149722086116: VariantsMap = [
    &["precolorablest"],
    &["precolourablest"],
    &["precolourablest"],
    &["precolourablest"],
];

pub(crate) static ENTRY_PRECOLORABLES_5228912827468002969: VariantsMap = [
    &["precolorables"],
    &["precolourables"],
    &["precolourables"],
    &["precolourables"],
];

pub(crate) static ENTRY_PRECOLORABLE_8927422689593708380: VariantsMap = [
    &["precolorable"],
    &["precolourable"],
    &["precolourable"],
    &["precolourable"],
];

pub(crate) static ENTRY_PRECOLORATIONS_10964118530390224803: VariantsMap = [
    &["precolorations"],
    &["precolourations"],
    &["precolourations"],
    &["precolourations"],
];

pub(crate) static ENTRY_PRECOLORATION_14701765064218173385: VariantsMap = [
    &["precoloration"],
    &["precolouration"],
    &["precolouration"],
    &["precolouration"],
];

pub(crate) static ENTRY_PRECOLORED_8558043425935508627: VariantsMap = [
    &["precolored"],
    &["precoloured"],
    &["precoloured"],
    &["precoloured"],
];

pub(crate) static ENTRY_PRECOLORINGS_1385084320150173125: VariantsMap = [
    &["precolorings"],
    &["precolourings"],
    &["precolourings"],
    &["precolourings"],
];

pub(crate) static ENTRY_PRECOLORING_15907201636458074973: VariantsMap = [
    &["precoloring"],
    &["precolouring"],
    &["precolouring"],
    &["precolouring"],
];

pub(crate) static ENTRY_PRECOLORS_4819161434090345366: VariantsMap = [
    &["precolors"],
    &["precolours"],
    &["precolours"],
    &["precolours"],
];

pub(crate) static ENTRY_PRECOLOR_421440567663720130: VariantsMap = [
    &["precolor"],
    &["precolour"],
    &["precolour"],
    &["precolour"],
];

pub(crate) static ENTRY_PRECONIZATIONS_15559954424980964068: VariantsMap = [
    &["preconizations"],
    &["preconisations"],
    &["preconizations"],
    &["preconisations"],
];

pub(crate) static ENTRY_PRECONIZATION_5128332384662999880: VariantsMap = [
    &["preconization"],
    &["preconisation"],
    &["preconization"],
    &["preconisation"],
];

pub(crate) static ENTRY_PRECONIZED_11673314501314681040: VariantsMap = [
    &["preconized"],
    &["preconised"],
    &["preconized"],
    &["preconised"],
];

pub(crate) static ENTRY_PRECONIZERS_2855306765570884664: VariantsMap = [
    &["preconizers"],
    &["preconisers"],
    &["preconizers"],
    &["preconisers"],
];

pub(crate) static ENTRY_PRECONIZER_183199819264544815: VariantsMap = [
    &["preconizer"],
    &["preconiser"],
    &["preconizer"],
    &["preconiser"],
];

pub(crate) static ENTRY_PRECONIZES_16046662733582737370: VariantsMap = [
    &["preconizes"],
    &["preconises"],
    &["preconizes"],
    &["preconises"],
];

pub(crate) static ENTRY_PRECONIZE_13784477669434917149: VariantsMap = [
    &["preconize"],
    &["preconise"],
    &["preconize"],
    &["preconise"],
];

pub(crate) static ENTRY_PRECONIZING_856066415909262347: VariantsMap = [
    &["preconizing"],
    &["preconising"],
    &["preconizing"],
    &["preconising"],
];

pub(crate) static ENTRY_PRECORACOID_14112650972840331881: VariantsMap = [
    &["precoracoid"],
    &["praecoracoid"],
    &["praecoracoid"],
    &["praecoracoid"],
];

pub(crate) static ENTRY_PRECORDIAL_11499053547875463822: VariantsMap = [
    &["precordial"],
    &["praecordial"],
    &["praecordial"],
    &["praecordial"],
];

pub(crate) static ENTRY_PRECORDIA_1917126594708911487: VariantsMap = [
    &["precordia"],
    &["praecordia"],
    &["praecordia"],
    &["praecordia"],
];

pub(crate) static ENTRY_PRECORDIUM_8035690684402584466: VariantsMap = [
    &["precordium"],
    &["praecordium"],
    &["praecordium"],
    &["praecordium"],
];

pub(crate) static ENTRY_PRECORNU_3251658118511369979: VariantsMap = [
    &["precornu"],
    &["praecornu"],
    &["praecornu"],
    &["praecornu"],
];

pub(crate) static ENTRY_PRECOX_16157515385095809645: VariantsMap =
    [&["precox"], &["praecox"], &["praecox"], &["praecox"]];

pub(crate) static ENTRY_PRECRITICIZES_5247080334248511116: VariantsMap = [
    &["precriticizes"],
    &["precriticises"],
    &["precriticizes"],
    &["precriticises"],
];

pub(crate) static ENTRY_PRECRITICIZE_9318452050596986184: VariantsMap = [
    &["precriticize"],
    &["precriticise"],
    &["precriticize"],
    &["precriticise"],
];

pub(crate) static ENTRY_PRECUNEUS_2232807234398123688: VariantsMap = [
    &["precuneus"],
    &["praecuneus"],
    &["praecuneus"],
    &["praecuneus"],
];

pub(crate) static ENTRY_PREDIALIST_15938835210648844562: VariantsMap = [
    &["predialist"],
    &["praedialist"],
    &["praedialist"],
    &["praedialist"],
];

pub(crate) static ENTRY_PREDIALITY_5941457168149043947: VariantsMap = [
    &["prediality"],
    &["praediality"],
    &["praediality"],
    &["praediality"],
];

pub(crate) static ENTRY_PREDIALS_13874920445884966698: VariantsMap = [
    &["predials"],
    &["praedials"],
    &["praedials"],
    &["praedials"],
];

pub(crate) static ENTRY_PREDIAL_13314408220157784404: VariantsMap =
    [&["predial"], &["praedial"], &["praedial"], &["praedial"]];

pub(crate) static ENTRY_PREEMPTOR_15768806273074897294: VariantsMap = [
    &["preemptor"],
    &["preaemptor"],
    &["preaemptor"],
    &["preaemptor"],
];

pub(crate) static ENTRY_PREESOPHAGEAL_7351484208782474235: VariantsMap = [
    &["preesophageal"],
    &["preoesophageal"],
    &["preoesophageal"],
    &["preoesophageal"],
];

pub(crate) static ENTRY_PREESOPHAGEAL_7806252650760260205: VariantsMap = [
    &["preesophageal"],
    &["praeesophageal"],
    &["praeesophageal"],
    &["praeesophageal"],
];

pub(crate) static ENTRY_PREESTIVAL_17457419379815350363: VariantsMap = [
    &["preestival"],
    &["preaestival"],
    &["preaestival"],
    &["preaestival"],
];

pub(crate) static ENTRY_PREEXISTENT_5553896724671901278: VariantsMap = [
    &["preexistent"],
    &["preaexistent"],
    &["preaexistent"],
    &["preaexistent"],
];

pub(crate) static ENTRY_PREFAVORABLES_14007584726075938864: VariantsMap = [
    &["prefavorables"],
    &["prefavourables"],
    &["prefavourables"],
    &["prefavourables"],
];

pub(crate) static ENTRY_PREFAVORABLE_11226316521498660594: VariantsMap = [
    &["prefavorable"],
    &["prefavourable"],
    &["prefavourable"],
    &["prefavourable"],
];

pub(crate) static ENTRY_PREFAVORABLIES_16468315820782161395: VariantsMap = [
    &["prefavorablies"],
    &["prefavourablies"],
    &["prefavourablies"],
    &["prefavourablies"],
];

pub(crate) static ENTRY_PREFAVORABLY_8511265901221040677: VariantsMap = [
    &["prefavorably"],
    &["prefavourably"],
    &["prefavourably"],
    &["prefavourably"],
];

pub(crate) static ENTRY_PREFAVORITES_6381395897759886730: VariantsMap = [
    &["prefavorites"],
    &["prefavourites"],
    &["prefavourites"],
    &["prefavourites"],
];

pub(crate) static ENTRY_PREFAVORITE_17782297686433439541: VariantsMap = [
    &["prefavorite"],
    &["prefavourite"],
    &["prefavourite"],
    &["prefavourite"],
];

pub(crate) static ENTRY_PREFAVORS_2743070173975491288: VariantsMap = [
    &["prefavors"],
    &["prefavours"],
    &["prefavours"],
    &["prefavours"],
];

pub(crate) static ENTRY_PREFAVOR_1052743038836547643: VariantsMap = [
    &["prefavor"],
    &["prefavour"],
    &["prefavour"],
    &["prefavour"],
];

pub(crate) static ENTRY_PREFECTORIAL_12394552410147263896: VariantsMap = [
    &["prefectorial"],
    &["praefectorial"],
    &["praefectorial"],
    &["praefectorial"],
];

pub(crate) static ENTRY_PREFERTILIZATIONS_11003132162782639220: VariantsMap = [
    &["prefertilizations"],
    &["prefertilisations"],
    &["prefertilizations"],
    &["prefertilisations"],
];

pub(crate) static ENTRY_PREFERTILIZATION_4841765994936591802: VariantsMap = [
    &["prefertilization"],
    &["prefertilisation"],
    &["prefertilization"],
    &["prefertilisation"],
];

pub(crate) static ENTRY_PREFERTILIZES_15925140722483029210: VariantsMap = [
    &["prefertilizes"],
    &["prefertilises"],
    &["prefertilizes"],
    &["prefertilises"],
];

pub(crate) static ENTRY_PREFERTILIZE_12979945903814095432: VariantsMap = [
    &["prefertilize"],
    &["prefertilise"],
    &["prefertilize"],
    &["prefertilise"],
];

pub(crate) static ENTRY_PREFLAVORINGS_8688443428859654444: VariantsMap = [
    &["preflavorings"],
    &["preflavourings"],
    &["preflavourings"],
    &["preflavourings"],
];

pub(crate) static ENTRY_PREFLAVORING_7487499086450337069: VariantsMap = [
    &["preflavoring"],
    &["preflavouring"],
    &["preflavouring"],
    &["preflavouring"],
];

pub(crate) static ENTRY_PREFLAVORS_8068519514702666048: VariantsMap = [
    &["preflavors"],
    &["preflavours"],
    &["preflavours"],
    &["preflavours"],
];

pub(crate) static ENTRY_PREFLAVOR_18251384983795695782: VariantsMap = [
    &["preflavor"],
    &["preflavour"],
    &["preflavour"],
    &["preflavour"],
];

pub(crate) static ENTRY_PREFLORATION_11469641643312189954: VariantsMap = [
    &["prefloration"],
    &["praefloration"],
    &["praefloration"],
    &["praefloration"],
];

pub(crate) static ENTRY_PREFOLIATION_17171347073332349592: VariantsMap = [
    &["prefoliation"],
    &["praefoliation"],
    &["praefoliation"],
    &["praefoliation"],
];

pub(crate) static ENTRY_PREGALVANIZES_18085190507843305402: VariantsMap = [
    &["pregalvanizes"],
    &["pregalvanises"],
    &["pregalvanizes"],
    &["pregalvanises"],
];

pub(crate) static ENTRY_PREGALVANIZE_16984111387364425037: VariantsMap = [
    &["pregalvanize"],
    &["pregalvanise"],
    &["pregalvanize"],
    &["pregalvanise"],
];

pub(crate) static ENTRY_PREHALLUX_4969284544099274299: VariantsMap = [
    &["prehallux"],
    &["praehallux"],
    &["praehallux"],
    &["praehallux"],
];

pub(crate) static ENTRY_PREHUMORS_13859524652523742789: VariantsMap = [
    &["prehumors"],
    &["prehumours"],
    &["prehumours"],
    &["prehumours"],
];

pub(crate) static ENTRY_PREHUMOR_1371086280255419223: VariantsMap = [
    &["prehumor"],
    &["prehumour"],
    &["prehumour"],
    &["prehumour"],
];

pub(crate) static ENTRY_PREINITIALIZED_9596394147383220664: VariantsMap = [
    &["preinitialized"],
    &["preinitialised"],
    &["preinitialized"],
    &["preinitialised"],
];

pub(crate) static ENTRY_PREINITIALIZES_16023204644649323111: VariantsMap = [
    &["preinitializes"],
    &["preinitialises"],
    &["preinitializes"],
    &["preinitialises"],
];

pub(crate) static ENTRY_PREINITIALIZE_1468717660753702862: VariantsMap = [
    &["preinitialize"],
    &["preinitialise"],
    &["preinitialize"],
    &["preinitialise"],
];

pub(crate) static ENTRY_PREINITIALIZING_18005348415129385802: VariantsMap = [
    &["preinitializing"],
    &["preinitialising"],
    &["preinitializing"],
    &["preinitialising"],
];

pub(crate) static ENTRY_PREJUDGMENTS_14741815798482492241: VariantsMap = [
    &["prejudgments"],
    &["prejudgements"],
    &["prejudgments"],
    &["prejudgements"],
];

pub(crate) static ENTRY_PREJUDGMENT_16703900164850541684: VariantsMap = [
    &["prejudgment"],
    &["prejudgement"],
    &["prejudgment"],
    &["prejudgement"],
];

pub(crate) static ENTRY_PRELABORS_1691176672047019402: VariantsMap = [
    &["prelabors"],
    &["prelabours"],
    &["prelabours"],
    &["prelabours"],
];

pub(crate) static ENTRY_PRELABOR_780423797883210133: VariantsMap = [
    &["prelabor"],
    &["prelabour"],
    &["prelabour"],
    &["prelabour"],
];

pub(crate) static ENTRY_PRELABRUM_4394969735839137776: VariantsMap = [
    &["prelabrum"],
    &["praelabrum"],
    &["praelabrum"],
    &["praelabrum"],
];

pub(crate) static ENTRY_PRELATIZED_5978559888639182049: VariantsMap = [
    &["prelatized"],
    &["prelatised"],
    &["prelatized"],
    &["prelatised"],
];

pub(crate) static ENTRY_PRELATIZES_1897637326171289560: VariantsMap = [
    &["prelatizes"],
    &["prelatises"],
    &["prelatizes"],
    &["prelatises"],
];

pub(crate) static ENTRY_PRELATIZE_10149280095441660432: VariantsMap = [
    &["prelatize"],
    &["prelatise"],
    &["prelatize"],
    &["prelatise"],
];

pub(crate) static ENTRY_PRELATIZING_4028012513229840028: VariantsMap = [
    &["prelatizing"],
    &["prelatising"],
    &["prelatizing"],
    &["prelatising"],
];

pub(crate) static ENTRY_PRELECTED_17531016903900240455: VariantsMap = [
    &["prelected"],
    &["praelected"],
    &["praelected"],
    &["praelected"],
];

pub(crate) static ENTRY_PRELECTING_17733481734284410679: VariantsMap = [
    &["prelecting"],
    &["praelecting"],
    &["praelecting"],
    &["praelecting"],
];

pub(crate) static ENTRY_PRELECTION_14375165505479018006: VariantsMap = [
    &["prelection"],
    &["praelection"],
    &["praelection"],
    &["praelection"],
];

pub(crate) static ENTRY_PRELECTORSHIP_13792769749923826474: VariantsMap = [
    &["prelectorship"],
    &["praelectorship"],
    &["praelectorship"],
    &["praelectorship"],
];

pub(crate) static ENTRY_PRELECTOR_16845719004040241611: VariantsMap = [
    &["prelector"],
    &["praelector"],
    &["praelector"],
    &["praelector"],
];

pub(crate) static ENTRY_PRELECTRESS_5401088119304407518: VariantsMap = [
    &["prelectress"],
    &["praelectress"],
    &["praelectress"],
    &["praelectress"],
];

pub(crate) static ENTRY_PRELECTS_11650422889665953253: VariantsMap = [
    &["prelects"],
    &["praelects"],
    &["praelects"],
    &["praelects"],
];

pub(crate) static ENTRY_PRELECT_12537605063468335740: VariantsMap =
    [&["prelect"], &["praelect"], &["praelect"], &["praelect"]];

pub(crate) static ENTRY_PRELOCALIZATIONS_12419652001524346907: VariantsMap = [
    &["prelocalizations"],
    &["prelocalisations"],
    &["prelocalizations"],
    &["prelocalisations"],
];

pub(crate) static ENTRY_PRELOCALIZATION_3522544466185913321: VariantsMap = [
    &["prelocalization"],
    &["prelocalisation"],
    &["prelocalization"],
    &["prelocalisation"],
];

pub(crate) static ENTRY_PRELUDIUM_10948679295576237674: VariantsMap = [
    &["preludium"],
    &["praeludium"],
    &["praeludium"],
    &["praeludium"],
];

pub(crate) static ENTRY_PRELUDIZES_785047441714468739: VariantsMap = [
    &["preludizes"],
    &["preludises"],
    &["preludizes"],
    &["preludises"],
];

pub(crate) static ENTRY_PRELUDIZE_15399918472889656379: VariantsMap = [
    &["preludize"],
    &["preludise"],
    &["preludize"],
    &["preludise"],
];

pub(crate) static ENTRY_PREMAXILLA_1949932614025975842: VariantsMap = [
    &["premaxilla"],
    &["praemaxilla"],
    &["praemaxilla"],
    &["praemaxilla"],
];

pub(crate) static ENTRY_PREMIAL_7239338890868461187: VariantsMap =
    [&["premial"], &["proemial"], &["proemial"], &["proemial"]];

pub(crate) static ENTRY_PREMILLENNIALIZED_1833932061640377180: VariantsMap = [
    &["premillennialized"],
    &["premillennialised"],
    &["premillennialized"],
    &["premillennialised"],
];

pub(crate) static ENTRY_PREMILLENNIALIZE_492481850943039694: VariantsMap = [
    &["premillennialize"],
    &["premillennialise"],
    &["premillennialize"],
    &["premillennialise"],
];

pub(crate) static ENTRY_PREMILLENNIALIZING_11897307349466382218: VariantsMap = [
    &["premillennializing"],
    &["premillennialising"],
    &["premillennializing"],
    &["premillennialising"],
];

pub(crate) static ENTRY_PREMONOPOLIZES_16617698551422036185: VariantsMap = [
    &["premonopolizes"],
    &["premonopolises"],
    &["premonopolizes"],
    &["premonopolises"],
];

pub(crate) static ENTRY_PREMONOPOLIZE_977575207751993670: VariantsMap = [
    &["premonopolize"],
    &["premonopolise"],
    &["premonopolize"],
    &["premonopolise"],
];

pub(crate) static ENTRY_PREMUNIRE_6858216713782981118: VariantsMap = [
    &["premunire"],
    &["praemunire"],
    &["praemunire"],
    &["praemunire"],
];

pub(crate) static ENTRY_PRENARIAL_260763454177661493: VariantsMap = [
    &["prenarial"],
    &["praenarial"],
    &["praenarial"],
    &["praenarial"],
];

pub(crate) static ENTRY_PRENEURAL_2408211185451005975: VariantsMap = [
    &["preneural"],
    &["praeneural"],
    &["praeneural"],
    &["praeneural"],
];

pub(crate) static ENTRY_PRENOMINAL_13090458952010105722: VariantsMap = [
    &["prenominal"],
    &["praenominal"],
    &["praenominal"],
    &["praenominal"],
];

pub(crate) static ENTRY_PRENOMINA_10767320086992242477: VariantsMap = [
    &["prenomina"],
    &["praenomina"],
    &["praenomina"],
    &["praenomina"],
];

pub(crate) static ENTRY_PREOFFENSES_7896176460933351275: VariantsMap = [
    &["preoffenses"],
    &["preoffences"],
    &["preoffences"],
    &["preoffences"],
];

pub(crate) static ENTRY_PREOFFENSE_579716648102296925: VariantsMap = [
    &["preoffense"],
    &["preoffence"],
    &["preoffence"],
    &["preoffence"],
];

pub(crate) static ENTRY_PREOPERCULUM_14063888562450517256: VariantsMap = [
    &["preoperculum"],
    &["praeoperculum"],
    &["praeoperculum"],
    &["praeoperculum"],
];

pub(crate) static ENTRY_PREORGANIZATIONS_9703149629890011334: VariantsMap = [
    &["preorganizations"],
    &["preorganisations"],
    &["preorganizations"],
    &["preorganisations"],
];

pub(crate) static ENTRY_PREORGANIZATION_2330721165999405697: VariantsMap = [
    &["preorganization"],
    &["preorganisation"],
    &["preorganization"],
    &["preorganisation"],
];

pub(crate) static ENTRY_PREORGANIZES_12964164181090276763: VariantsMap = [
    &["preorganizes"],
    &["preorganises"],
    &["preorganizes"],
    &["preorganises"],
];

pub(crate) static ENTRY_PREORGANIZE_11661260841615530241: VariantsMap = [
    &["preorganize"],
    &["preorganise"],
    &["preorganize"],
    &["preorganise"],
];

pub(crate) static ENTRY_PREOXIDIZED_7318658950505462890: VariantsMap = [
    &["preoxidized"],
    &["preoxidised"],
    &["preoxidized"],
    &["preoxidised"],
];

pub(crate) static ENTRY_PREOXIDIZES_12387705073002168500: VariantsMap = [
    &["preoxidizes"],
    &["preoxidises"],
    &["preoxidizes"],
    &["preoxidises"],
];

pub(crate) static ENTRY_PREOXIDIZE_16282140963246736780: VariantsMap = [
    &["preoxidize"],
    &["preoxidise"],
    &["preoxidize"],
    &["preoxidise"],
];

pub(crate) static ENTRY_PREOXIDIZING_9934682611281956009: VariantsMap = [
    &["preoxidizing"],
    &["preoxidising"],
    &["preoxidizing"],
    &["preoxidising"],
];

pub(crate) static ENTRY_PREPALEOLITHIC_183867950926594500: VariantsMap = [
    &["prepaleolithic"],
    &["prepalaeolithic"],
    &["prepalaeolithic"],
    &["prepalaeolithic"],
];

pub(crate) static ENTRY_PREPOSITOR_10063403644988472815: VariantsMap = [
    &["prepositor"],
    &["praepositor"],
    &["praepositor"],
    &["praepositor"],
];

pub(crate) static ENTRY_PREPOSITURE_4560239659829395865: VariantsMap = [
    &["prepositure"],
    &["praepositure"],
    &["praepositure"],
    &["praepositure"],
];

pub(crate) static ENTRY_PREPOSTER_5492394426366092278: VariantsMap = [
    &["preposter"],
    &["praeposter"],
    &["praeposter"],
    &["praeposter"],
];

pub(crate) static ENTRY_PREPOSTORS_7492263855684321754: VariantsMap = [
    &["prepostors"],
    &["praepostors"],
    &["praepostors"],
    &["praepostors"],
];

pub(crate) static ENTRY_PREPOSTOR_11151951142384506524: VariantsMap = [
    &["prepostor"],
    &["praepostor"],
    &["praepostor"],
    &["praepostor"],
];

pub(crate) static ENTRY_PREPROGRAM_748095052838191885: VariantsMap = [
    &["preprogram"],
    &["preprogramme"],
    &["preprogram"],
    &["preprogramme"],
];

pub(crate) static ENTRY_PREPUBIS_1427267276575788983: VariantsMap = [
    &["prepubis"],
    &["praepubis"],
    &["praepubis"],
    &["praepubis"],
];

pub(crate) static ENTRY_PREREALIZATIONS_2143545589004280472: VariantsMap = [
    &["prerealizations"],
    &["prerealisations"],
    &["prerealizations"],
    &["prerealisations"],
];

pub(crate) static ENTRY_PREREALIZATION_16751668738223798926: VariantsMap = [
    &["prerealization"],
    &["prerealisation"],
    &["prerealization"],
    &["prerealisation"],
];

pub(crate) static ENTRY_PREREALIZES_2916100817699778962: VariantsMap = [
    &["prerealizes"],
    &["prerealises"],
    &["prerealizes"],
    &["prerealises"],
];

pub(crate) static ENTRY_PREREALIZE_11988199343123512512: VariantsMap = [
    &["prerealize"],
    &["prerealise"],
    &["prerealize"],
    &["prerealise"],
];

pub(crate) static ENTRY_PRERECOGNIZES_5929115671355232434: VariantsMap = [
    &["prerecognizes"],
    &["prerecognises"],
    &["prerecognizes"],
    &["prerecognises"],
];

pub(crate) static ENTRY_PRERECOGNIZE_12618463696266445555: VariantsMap = [
    &["prerecognize"],
    &["prerecognise"],
    &["prerecognize"],
    &["prerecognise"],
];

pub(crate) static ENTRY_PRESBYTERIANIZED_17583472478168085387: VariantsMap = [
    &["presbyterianized"],
    &["presbyterianised"],
    &["presbyterianized"],
    &["presbyterianised"],
];

pub(crate) static ENTRY_PRESBYTERIANIZES_4964908232020982000: VariantsMap = [
    &["presbyterianizes"],
    &["presbyterianises"],
    &["presbyterianizes"],
    &["presbyterianises"],
];

pub(crate) static ENTRY_PRESBYTERIANIZE_4999287070580173639: VariantsMap = [
    &["presbyterianize"],
    &["presbyterianise"],
    &["presbyterianize"],
    &["presbyterianise"],
];

pub(crate) static ENTRY_PRESBYTERIANIZING_14044541616214486352: VariantsMap = [
    &["presbyterianizing"],
    &["presbyterianising"],
    &["presbyterianizing"],
    &["presbyterianising"],
];

pub(crate) static ENTRY_PRESCUTUM_4847968595911667425: VariantsMap = [
    &["prescutum"],
    &["praescutum"],
    &["praescutum"],
    &["praescutum"],
];

pub(crate) static ENTRY_PRESIDIUMS_1425790211349943895: VariantsMap = [
    &["praesidiums", "presidia", "presidiums"],
    &["presidiums"],
    &["presidiums"],
    &["presidiums"],
];

pub(crate) static ENTRY_PRESPECIALIZES_11006115119286112345: VariantsMap = [
    &["prespecializes"],
    &["prespecialises"],
    &["prespecializes"],
    &["prespecialises"],
];

pub(crate) static ENTRY_PRESPECIALIZE_967052105156335842: VariantsMap = [
    &["prespecialize"],
    &["prespecialise"],
    &["prespecialize"],
    &["prespecialise"],
];

pub(crate) static ENTRY_PRESPHENOID_4021931112345182287: VariantsMap = [
    &["presphenoid"],
    &["praesphenoid"],
    &["praesphenoid"],
    &["praesphenoid"],
];

pub(crate) static ENTRY_PRESPLENDORS_5824632808972650605: VariantsMap = [
    &["presplendors"],
    &["presplendours"],
    &["presplendours"],
    &["presplendours"],
];

pub(crate) static ENTRY_PRESPLENDOR_12905475499591730121: VariantsMap = [
    &["presplendor"],
    &["presplendour"],
    &["presplendour"],
    &["presplendour"],
];

pub(crate) static ENTRY_PRESSURIZATIONS_118195243034235909: VariantsMap = [
    &["pressurizations"],
    &["pressurisations"],
    &["pressurizations"],
    &["pressurisations"],
];

pub(crate) static ENTRY_PRESSURIZATION_13356670902399248842: VariantsMap = [
    &["pressurization"],
    &["pressurisation"],
    &["pressurization"],
    &["pressurisation"],
];

pub(crate) static ENTRY_PRESSURIZED_13396852261615154911: VariantsMap = [
    &["pressurized"],
    &["pressurised"],
    &["pressurized"],
    &["pressurised"],
];

pub(crate) static ENTRY_PRESSURIZERS_3559116169299219184: VariantsMap = [
    &["pressurizers"],
    &["pressurisers"],
    &["pressurizers"],
    &["pressurisers"],
];

pub(crate) static ENTRY_PRESSURIZER_4292185580180276393: VariantsMap = [
    &["pressurizer"],
    &["pressuriser"],
    &["pressurizer"],
    &["pressuriser"],
];

pub(crate) static ENTRY_PRESSURIZES_12650153372563760390: VariantsMap = [
    &["pressurizes"],
    &["pressurises"],
    &["pressurizes"],
    &["pressurises"],
];

pub(crate) static ENTRY_PRESSURIZE_2472285357926099657: VariantsMap = [
    &["pressurize"],
    &["pressurise"],
    &["pressurize"],
    &["pressurise"],
];

pub(crate) static ENTRY_PRESSURIZING_5224479349902662356: VariantsMap = [
    &["pressurizing"],
    &["pressurising"],
    &["pressurizing"],
    &["pressurising"],
];

pub(crate) static ENTRY_PRESTANDARDIZATIONS_18319526321595787840: VariantsMap = [
    &["prestandardizations"],
    &["prestandardisations"],
    &["prestandardizations"],
    &["prestandardisations"],
];

pub(crate) static ENTRY_PRESTANDARDIZATION_2363065887839704808: VariantsMap = [
    &["prestandardization"],
    &["prestandardisation"],
    &["prestandardization"],
    &["prestandardisation"],
];

pub(crate) static ENTRY_PRESTANDARDIZES_937266387346880025: VariantsMap = [
    &["prestandardizes"],
    &["prestandardises"],
    &["prestandardizes"],
    &["prestandardises"],
];

pub(crate) static ENTRY_PRESTANDARDIZE_15894564553262715859: VariantsMap = [
    &["prestandardize"],
    &["prestandardise"],
    &["prestandardize"],
    &["prestandardise"],
];

pub(crate) static ENTRY_PRESTERNAL_15812473893616823077: VariantsMap = [
    &["presternal"],
    &["praesternal"],
    &["praesternal"],
    &["praesternal"],
];

pub(crate) static ENTRY_PRESTERNUM_1763363816928245465: VariantsMap = [
    &["presternum"],
    &["praesternum"],
    &["praesternum"],
    &["praesternum"],
];

pub(crate) static ENTRY_PRESTOMIUM_16214618765076520281: VariantsMap = [
    &["prestomium"],
    &["praestomium"],
    &["praestomium"],
    &["praestomium"],
];

pub(crate) static ENTRY_PRESYMPATHIZES_14009852068318536738: VariantsMap = [
    &["presympathizes"],
    &["presympathises"],
    &["presympathizes"],
    &["presympathises"],
];

pub(crate) static ENTRY_PRESYMPATHIZE_8629925375514514985: VariantsMap = [
    &["presympathize"],
    &["presympathise"],
    &["presympathize"],
    &["presympathise"],
];

pub(crate) static ENTRY_PRESYSTOLIC_9748851267145215677: VariantsMap = [
    &["presystolic"],
    &["praesystolic"],
    &["praesystolic"],
    &["praesystolic"],
];

pub(crate) static ENTRY_PRETAXATION_8079989165281713211: VariantsMap = [
    &["pretaxation"],
    &["praetaxation"],
    &["praetaxation"],
    &["praetaxation"],
];

pub(crate) static ENTRY_PRETENSES_7458659267060171206: VariantsMap = [
    &["pretenses"],
    &["pretences"],
    &["pretenses"],
    &["pretences"],
];

pub(crate) static ENTRY_PRETENSE_11134246296321318334: VariantsMap =
    [&["pretense"], &["pretence"], &["pretense"], &["pretence"]];

pub(crate) static ENTRY_PRETENSIVE_9146039768574026128: VariantsMap = [
    &["pretensive"],
    &["pretencive"],
    &["pretencive"],
    &["pretencive"],
];

pub(crate) static ENTRY_PRETERITS_12755061437397802511: VariantsMap = [
    &["preterits"],
    &["preterites"],
    &["preterites"],
    &["preterites"],
];

pub(crate) static ENTRY_PRETERIT_7498968913037091407: VariantsMap = [
    &["preterit"],
    &["preterite"],
    &["preterite"],
    &["preterite"],
];

pub(crate) static ENTRY_PRETEXTAE_10204336454667170862: VariantsMap = [
    &["pretextae"],
    &["praetextae"],
    &["praetextae"],
    &["praetextae"],
];

pub(crate) static ENTRY_PRETEXTA_13846622072471023683: VariantsMap = [
    &["pretexta"],
    &["praetexta"],
    &["praetexta"],
    &["praetexta"],
];

pub(crate) static ENTRY_PRETORIAL_15378699772955129270: VariantsMap = [
    &["pretorial"],
    &["praetorial"],
    &["praetorial"],
    &["praetorial"],
];

pub(crate) static ENTRY_PRETORIANS_6215048104690331583: VariantsMap = [
    &["pretorians"],
    &["praetorians"],
    &["praetorians"],
    &["praetorians"],
];

pub(crate) static ENTRY_PRETORIUM_14398242596704932612: VariantsMap = [
    &["pretorium"],
    &["praetorium"],
    &["praetorium"],
    &["praetorium"],
];

pub(crate) static ENTRY_PRETORIUS_5267977306289147499: VariantsMap = [
    &["pretorius"],
    &["praetorius"],
    &["praetorius"],
    &["praetorius"],
];

pub(crate) static ENTRY_PRETORSHIP_6874769297580857439: VariantsMap = [
    &["pretorship"],
    &["praetorship"],
    &["praetorship"],
    &["praetorship"],
];

pub(crate) static ENTRY_PREUTILIZABLES_12568308354937276763: VariantsMap = [
    &["preutilizables"],
    &["preutilisables"],
    &["preutilizables"],
    &["preutilisables"],
];

pub(crate) static ENTRY_PREUTILIZABLE_10502977666588008006: VariantsMap = [
    &["preutilizable"],
    &["preutilisable"],
    &["preutilizable"],
    &["preutilisable"],
];

pub(crate) static ENTRY_PREUTILIZATIONS_13261898768735461584: VariantsMap = [
    &["preutilizations"],
    &["preutilisations"],
    &["preutilizations"],
    &["preutilisations"],
];

pub(crate) static ENTRY_PREUTILIZATION_5168298681347218530: VariantsMap = [
    &["preutilization"],
    &["preutilisation"],
    &["preutilization"],
    &["preutilisation"],
];

pub(crate) static ENTRY_PREUTILIZES_11485486872811225597: VariantsMap = [
    &["preutilizes"],
    &["preutilises"],
    &["preutilizes"],
    &["preutilises"],
];

pub(crate) static ENTRY_PREUTILIZE_13437269687735714618: VariantsMap = [
    &["preutilize"],
    &["preutilise"],
    &["preutilize"],
    &["preutilise"],
];

pub(crate) static ENTRY_PREVIEWS_15754902130358490470: VariantsMap =
    [&["previews"], &["previews"], &["previews"], &["previews"]];

pub(crate) static ENTRY_PREVIEW_17480641034975402216: VariantsMap =
    [&["preview"], &["preview"], &["preview"], &["preview"]];

pub(crate) static ENTRY_PREVIZE_11758683809300984520: VariantsMap =
    [&["previze"], &["previse"], &["previze"], &["previse"]];

pub(crate) static ENTRY_PREZYGAPOPHYSIS_12276661304999283736: VariantsMap = [
    &["prezygapophysis"],
    &["praezygapophysis"],
    &["praezygapophysis"],
    &["praezygapophysis"],
];

pub(crate) static ENTRY_PRIMEVALLY_5695214551446778886: VariantsMap = [
    &["primevally"],
    &["primevally"],
    &["primevally"],
    &["primevally"],
];

pub(crate) static ENTRY_PRIMEVAL_1417379882500902562: VariantsMap =
    [&["primeval"], &["primeval"], &["primeval"], &["primeval"]];

pub(crate) static ENTRY_PRIORITIZATIONS_4547440538414190662: VariantsMap = [
    &["prioritizations"],
    &["prioritisations"],
    &["prioritizations"],
    &["prioritisations"],
];

pub(crate) static ENTRY_PRIORITIZATION_17373812427352173208: VariantsMap = [
    &["prioritization"],
    &["prioritisation"],
    &["prioritization"],
    &["prioritisation"],
];

pub(crate) static ENTRY_PRIORITIZED_4527962682420219040: VariantsMap = [
    &["prioritized"],
    &["prioritised"],
    &["prioritized"],
    &["prioritised"],
];

pub(crate) static ENTRY_PRIORITIZERS_6825770252020420898: VariantsMap = [
    &["prioritizers"],
    &["prioritisers"],
    &["prioritizers"],
    &["prioritisers"],
];

pub(crate) static ENTRY_PRIORITIZER_13382006918758416159: VariantsMap = [
    &["prioritizer"],
    &["prioritiser"],
    &["prioritizer"],
    &["prioritiser"],
];

pub(crate) static ENTRY_PRIORITIZES_9554518663110998287: VariantsMap = [
    &["prioritizes"],
    &["prioritises"],
    &["prioritizes"],
    &["prioritises"],
];

pub(crate) static ENTRY_PRIORITIZE_7432754868592786562: VariantsMap = [
    &["prioritize"],
    &["prioritise"],
    &["prioritize"],
    &["prioritise"],
];

pub(crate) static ENTRY_PRIORITIZINGS_16876590680015495867: VariantsMap = [
    &["prioritizings"],
    &["prioritisings"],
    &["prioritizings"],
    &["prioritisings"],
];

pub(crate) static ENTRY_PRIORITIZING_10063035288697055724: VariantsMap = [
    &["prioritizing"],
    &["prioritising"],
    &["prioritizing"],
    &["prioritising"],
];

pub(crate) static ENTRY_PRIORIZATIONS_8298289640162436181: VariantsMap = [
    &["priorizations"],
    &["priorisations"],
    &["priorizations"],
    &["priorisations"],
];

pub(crate) static ENTRY_PRIORIZATION_6881117100427905620: VariantsMap = [
    &["priorization"],
    &["priorisation"],
    &["priorization"],
    &["priorisation"],
];

pub(crate) static ENTRY_PRIORIZED_7964231373333312688: VariantsMap = [
    &["priorized"],
    &["priorised"],
    &["priorized"],
    &["priorised"],
];

pub(crate) static ENTRY_PRIORIZES_9720813797683913872: VariantsMap = [
    &["priorizes"],
    &["priorises"],
    &["priorizes"],
    &["priorises"],
];

pub(crate) static ENTRY_PRIORIZE_144293817568297285: VariantsMap =
    [&["priorize"], &["priorise"], &["priorize"], &["priorise"]];

pub(crate) static ENTRY_PRIORIZING_11437754851911989314: VariantsMap = [
    &["priorizing"],
    &["priorising"],
    &["priorizing"],
    &["priorising"],
];

pub(crate) static ENTRY_PRIVATIZATIONS_17033667469063461810: VariantsMap = [
    &["privatizations"],
    &["privatisations"],
    &["privatizations"],
    &["privatisations"],
];

pub(crate) static ENTRY_PRIVATIZATION_3684133102365221258: VariantsMap = [
    &["privatization"],
    &["privatisation"],
    &["privatization"],
    &["privatisation"],
];

pub(crate) static ENTRY_PRIVATIZED_17871845478636985919: VariantsMap = [
    &["privatized"],
    &["privatised"],
    &["privatized"],
    &["privatised"],
];

pub(crate) static ENTRY_PRIVATIZERS_4157500876246357166: VariantsMap = [
    &["privatizers"],
    &["privatisers"],
    &["privatizers"],
    &["privatisers"],
];

pub(crate) static ENTRY_PRIVATIZER_3347166286516553417: VariantsMap = [
    &["privatizer"],
    &["privatiser"],
    &["privatizer"],
    &["privatiser"],
];

pub(crate) static ENTRY_PRIVATIZES_15354432852660291680: VariantsMap = [
    &["privatizes"],
    &["privatises"],
    &["privatizes"],
    &["privatises"],
];

pub(crate) static ENTRY_PRIVATIZE_9023800133991613189: VariantsMap = [
    &["privatize"],
    &["privatise"],
    &["privatize"],
    &["privatise"],
];

pub(crate) static ENTRY_PRIVATIZING_15665137231742087652: VariantsMap = [
    &["privatizing"],
    &["privatising"],
    &["privatizing"],
    &["privatising"],
];

pub(crate) static ENTRY_PRIZABLE_3624070517581805612: VariantsMap =
    [&["prizable"], &["prisable"], &["prizable"], &["prisable"]];

pub(crate) static ENTRY_PRIZED_13278503117736836068: VariantsMap =
    [&["prized"], &["prised"], &["prized"], &["prised"]];

pub(crate) static ENTRY_PRIZERS_15789594842148438822: VariantsMap =
    [&["prizers"], &["prisers"], &["prizers"], &["prisers"]];

pub(crate) static ENTRY_PRIZER_3172722922601400896: VariantsMap =
    [&["prizer"], &["priser"], &["prizer"], &["priser"]];

pub(crate) static ENTRY_PRIZES_7638257834418170687: VariantsMap =
    [&["prizes"], &["prises"], &["prizes"], &["prises"]];

pub(crate) static ENTRY_PRIZE_1961043608814215148: VariantsMap =
    [&["prize"], &["prise"], &["prize"], &["prise"]];

pub(crate) static ENTRY_PRIZING_5311484152980850571: VariantsMap =
    [&["prizing"], &["prising"], &["prizing"], &["prising"]];

pub(crate) static ENTRY_PROADVERTIZING_10146408801765586763: VariantsMap = [
    &["proadvertizing"],
    &["proadvertising"],
    &["proadvertizing"],
    &["proadvertising"],
];

pub(crate) static ENTRY_PROBLEMIZES_10106644264183859282: VariantsMap = [
    &["problemizes"],
    &["problemises"],
    &["problemizes"],
    &["problemises"],
];

pub(crate) static ENTRY_PROBLEMIZE_11504359583073410309: VariantsMap = [
    &["problemize"],
    &["problemise"],
    &["problemize"],
    &["problemise"],
];

pub(crate) static ENTRY_PROCESSIONIZES_3404719682305726652: VariantsMap = [
    &["processionizes"],
    &["processionises"],
    &["processionizes"],
    &["processionises"],
];

pub(crate) static ENTRY_PROCESSIONIZE_363359302673816281: VariantsMap = [
    &["processionize"],
    &["processionise"],
    &["processionize"],
    &["processionise"],
];

pub(crate) static ENTRY_PROCRUSTEANIZES_10425675503914668807: VariantsMap = [
    &["procrusteanizes"],
    &["procrusteanises"],
    &["procrusteanizes"],
    &["procrusteanises"],
];

pub(crate) static ENTRY_PROCRUSTEANIZE_17397014473088592045: VariantsMap = [
    &["procrusteanize"],
    &["procrusteanise"],
    &["procrusteanize"],
    &["procrusteanise"],
];

pub(crate) static ENTRY_PROCTODEAL_5673226521410272400: VariantsMap = [
    &["proctodeal"],
    &["proctodaeal"],
    &["proctodaeal"],
    &["proctodaeal"],
];

pub(crate) static ENTRY_PROCTODEA_9264272751486692747: VariantsMap = [
    &["proctodea"],
    &["proctodaea"],
    &["proctodaea"],
    &["proctodaea"],
];

pub(crate) static ENTRY_PROCTODEUMS_2978610134813867751: VariantsMap = [
    &["proctodeums"],
    &["proctodaeums"],
    &["proctodaeums"],
    &["proctodaeums"],
];

pub(crate) static ENTRY_PROCTODEUM_4237934730961962313: VariantsMap = [
    &["proctodeum"],
    &["proctodaeum"],
    &["proctodaeum"],
    &["proctodaeum"],
];

pub(crate) static ENTRY_PROCTORIZATIONS_12249312162294372727: VariantsMap = [
    &["proctorizations"],
    &["proctorisations"],
    &["proctorizations"],
    &["proctorisations"],
];

pub(crate) static ENTRY_PROCTORIZATION_9417674116945748895: VariantsMap = [
    &["proctorization"],
    &["proctorisation"],
    &["proctorization"],
    &["proctorisation"],
];

pub(crate) static ENTRY_PROCTORIZED_6091712676193842819: VariantsMap = [
    &["proctorized"],
    &["proctorised"],
    &["proctorized"],
    &["proctorised"],
];

pub(crate) static ENTRY_PROCTORIZES_221418959204501654: VariantsMap = [
    &["proctorizes"],
    &["proctorises"],
    &["proctorizes"],
    &["proctorises"],
];

pub(crate) static ENTRY_PROCTORIZE_3777189878290336613: VariantsMap = [
    &["proctorize"],
    &["proctorise"],
    &["proctorize"],
    &["proctorise"],
];

pub(crate) static ENTRY_PROCTORIZING_6126835312244696695: VariantsMap = [
    &["proctorizing"],
    &["proctorising"],
    &["proctorizing"],
    &["proctorising"],
];

pub(crate) static ENTRY_PRODIGALIZED_5183373559053607699: VariantsMap = [
    &["prodigalized"],
    &["prodigalised"],
    &["prodigalized"],
    &["prodigalised"],
];

pub(crate) static ENTRY_PRODIGALIZES_13614987973661874173: VariantsMap = [
    &["prodigalizes"],
    &["prodigalises"],
    &["prodigalizes"],
    &["prodigalises"],
];

pub(crate) static ENTRY_PRODIGALIZE_6556148767910967929: VariantsMap = [
    &["prodigalize"],
    &["prodigalise"],
    &["prodigalize"],
    &["prodigalise"],
];

pub(crate) static ENTRY_PRODIGALIZING_17327500545166930662: VariantsMap = [
    &["prodigalizing"],
    &["prodigalising"],
    &["prodigalizing"],
    &["prodigalising"],
];

pub(crate) static ENTRY_PRODUCTIZED_10875872271101596314: VariantsMap = [
    &["productized"],
    &["productised"],
    &["productized"],
    &["productised"],
];

pub(crate) static ENTRY_PRODUCTIZERS_3610620963148254180: VariantsMap = [
    &["productizers"],
    &["productisers"],
    &["productizers"],
    &["productisers"],
];

pub(crate) static ENTRY_PRODUCTIZER_15368907505651290238: VariantsMap = [
    &["productizer"],
    &["productiser"],
    &["productizer"],
    &["productiser"],
];

pub(crate) static ENTRY_PRODUCTIZES_2489445768881598197: VariantsMap = [
    &["productizes"],
    &["productises"],
    &["productizes"],
    &["productises"],
];

pub(crate) static ENTRY_PRODUCTIZE_5881144802979662642: VariantsMap = [
    &["productize"],
    &["productise"],
    &["productize"],
    &["productise"],
];

pub(crate) static ENTRY_PRODUCTIZING_913073828657978689: VariantsMap = [
    &["productizing"],
    &["productising"],
    &["productizing"],
    &["productising"],
];

pub(crate) static ENTRY_PROEMIUM_14234532915733161254: VariantsMap = [
    &["proemium"],
    &["prooemium"],
    &["prooemium"],
    &["prooemium"],
];

pub(crate) static ENTRY_PROFANIZES_15009721751572169566: VariantsMap = [
    &["profanizes"],
    &["profanises"],
    &["profanizes"],
    &["profanises"],
];

pub(crate) static ENTRY_PROFANIZE_16692055975755795401: VariantsMap = [
    &["profanize"],
    &["profanise"],
    &["profanize"],
    &["profanise"],
];

pub(crate) static ENTRY_PROFER_15410953148965704808: VariantsMap =
    [&["profer"], &["profre"], &["profre"], &["profre"]];

pub(crate) static ENTRY_PROFESSIONALIZATIONS_15242793239637656612: VariantsMap = [
    &["professionalizations"],
    &["professionalisations"],
    &["professionalizations"],
    &["professionalisations"],
];

pub(crate) static ENTRY_PROFESSIONALIZATION_18024061751549463881: VariantsMap = [
    &["professionalization"],
    &["professionalisation"],
    &["professionalization"],
    &["professionalisation"],
];

pub(crate) static ENTRY_PROFESSIONALIZED_2063985099756041218: VariantsMap = [
    &["professionalized"],
    &["professionalised"],
    &["professionalized"],
    &["professionalised"],
];

pub(crate) static ENTRY_PROFESSIONALIZES_13162965236440047136: VariantsMap = [
    &["professionalizes"],
    &["professionalises"],
    &["professionalizes"],
    &["professionalises"],
];

pub(crate) static ENTRY_PROFESSIONALIZE_8390330200790326962: VariantsMap = [
    &["professionalize"],
    &["professionalise"],
    &["professionalize"],
    &["professionalise"],
];

pub(crate) static ENTRY_PROFESSIONALIZING_11815435443308938942: VariantsMap = [
    &["professionalizing"],
    &["professionalising"],
    &["professionalizing"],
    &["professionalising"],
];

pub(crate) static ENTRY_PROFESSIONIZES_14576667596106193495: VariantsMap = [
    &["professionizes"],
    &["professionises"],
    &["professionizes"],
    &["professionises"],
];

pub(crate) static ENTRY_PROFESSIONIZE_14437669104523413326: VariantsMap = [
    &["professionize"],
    &["professionise"],
    &["professionize"],
    &["professionise"],
];

pub(crate) static ENTRY_PROGRAMMED_11095179087329270774: VariantsMap = [
    &["programmed"],
    &["programmed"],
    &["programmed"],
    &["programmed"],
];

pub(crate) static ENTRY_PROGRAMMED_14686782791235843952: VariantsMap = [
    &["programmed"],
    &["programmed"],
    &["programmed"],
    &["programmed"],
];

pub(crate) static ENTRY_PROGRAMMERS_7198725162117062597: VariantsMap = [
    &["programmers"],
    &["programmers"],
    &["programmers"],
    &["programmers"],
];

pub(crate) static ENTRY_PROGRAMMER_14647609425245098552: VariantsMap = [
    &["programmer"],
    &["programmer"],
    &["programmer"],
    &["programmer"],
];

pub(crate) static ENTRY_PROGRAMMING_3117523448840634735: VariantsMap = [
    &["programming"],
    &["programming"],
    &["programming"],
    &["programming"],
];

pub(crate) static ENTRY_PROGRAMMING_9189526122229014819: VariantsMap = [
    &["programming"],
    &["programming"],
    &["programming"],
    &["programming"],
];

pub(crate) static ENTRY_PROINDUSTRIALIZATION_7705497117665030256: VariantsMap = [
    &["proindustrialization"],
    &["proindustrialisation"],
    &["proindustrialization"],
    &["proindustrialisation"],
];

pub(crate) static ENTRY_PROJECTIZATIONS_17947038612206928913: VariantsMap = [
    &["projectizations"],
    &["projectisations"],
    &["projectizations"],
    &["projectisations"],
];

pub(crate) static ENTRY_PROJECTIZATION_1538272338112971382: VariantsMap = [
    &["projectization"],
    &["projectisation"],
    &["projectization"],
    &["projectisation"],
];

pub(crate) static ENTRY_PROLETARIANIZATIONS_1328735160914809433: VariantsMap = [
    &["proletarianizations"],
    &["proletarianisations"],
    &["proletarianizations"],
    &["proletarianisations"],
];

pub(crate) static ENTRY_PROLETARIANIZATION_15790660889449578730: VariantsMap = [
    &["proletarianization"],
    &["proletarianisation"],
    &["proletarianization"],
    &["proletarianisation"],
];

pub(crate) static ENTRY_PROLETARIANIZED_2183449213380270293: VariantsMap = [
    &["proletarianized"],
    &["proletarianised"],
    &["proletarianized"],
    &["proletarianised"],
];

pub(crate) static ENTRY_PROLETARIANIZES_6188493854575184994: VariantsMap = [
    &["proletarianizes"],
    &["proletarianises"],
    &["proletarianizes"],
    &["proletarianises"],
];

pub(crate) static ENTRY_PROLETARIANIZE_12339926232015096187: VariantsMap = [
    &["proletarianize"],
    &["proletarianise"],
    &["proletarianize"],
    &["proletarianise"],
];

pub(crate) static ENTRY_PROLETARIANIZING_15272438542602632385: VariantsMap = [
    &["proletarianizing"],
    &["proletarianising"],
    &["proletarianizing"],
    &["proletarianising"],
];

pub(crate) static ENTRY_PROLETARIZED_14247407550828649128: VariantsMap = [
    &["proletarized"],
    &["proletarised"],
    &["proletarized"],
    &["proletarised"],
];

pub(crate) static ENTRY_PROLETARIZE_9501153541273515734: VariantsMap = [
    &["proletarize"],
    &["proletarise"],
    &["proletarize"],
    &["proletarise"],
];

pub(crate) static ENTRY_PROLETARIZING_16999278085483859607: VariantsMap = [
    &["proletarizing"],
    &["proletarising"],
    &["proletarizing"],
    &["proletarising"],
];

pub(crate) static ENTRY_PROLOGIZED_6273077668308831309: VariantsMap = [
    &["prologized"],
    &["prologised"],
    &["prologized"],
    &["prologised"],
];

pub(crate) static ENTRY_PROLOGIZES_13741317884710515836: VariantsMap = [
    &["prologizes"],
    &["prologises"],
    &["prologizes"],
    &["prologises"],
];

pub(crate) static ENTRY_PROLOGIZE_16244188212641112947: VariantsMap = [
    &["prologize"],
    &["prologise"],
    &["prologize"],
    &["prologise"],
];

pub(crate) static ENTRY_PROLOGIZING_16747002832029621473: VariantsMap = [
    &["prologizing"],
    &["prologising"],
    &["prologizing"],
    &["prologising"],
];

pub(crate) static ENTRY_PROLOGUES_2022541342111438442: VariantsMap = [
    &["prologues"],
    &["prologues"],
    &["prologues"],
    &["prologues"],
];

pub(crate) static ENTRY_PROLOGUE_11728138965466131419: VariantsMap =
    [&["prologue"], &["prologue"], &["prologue"], &["prologue"]];

pub(crate) static ENTRY_PROLOGUIZED_1059404595951898705: VariantsMap = [
    &["prologuized"],
    &["prologuised"],
    &["prologuized"],
    &["prologuised"],
];

pub(crate) static ENTRY_PROLOGUIZERS_4337951202538976392: VariantsMap = [
    &["prologuizers"],
    &["prologuisers"],
    &["prologuizers"],
    &["prologuisers"],
];

pub(crate) static ENTRY_PROLOGUIZER_12529304749250729020: VariantsMap = [
    &["prologuizer"],
    &["prologuiser"],
    &["prologuizer"],
    &["prologuiser"],
];

pub(crate) static ENTRY_PROLOGUIZES_9492816923512770566: VariantsMap = [
    &["prologuizes"],
    &["prologuises"],
    &["prologuizes"],
    &["prologuises"],
];

pub(crate) static ENTRY_PROLOGUIZE_13986490182533024537: VariantsMap = [
    &["prologuize"],
    &["prologuise"],
    &["prologuize"],
    &["prologuise"],
];

pub(crate) static ENTRY_PROLOGUIZING_8390679435340498064: VariantsMap = [
    &["prologuizing"],
    &["prologuising"],
    &["prologuizing"],
    &["prologuising"],
];

pub(crate) static ENTRY_PROLUSIONIZES_9375527204411045313: VariantsMap = [
    &["prolusionizes"],
    &["prolusionises"],
    &["prolusionizes"],
    &["prolusionises"],
];

pub(crate) static ENTRY_PROLUSIONIZE_14743949812729365990: VariantsMap = [
    &["prolusionize"],
    &["prolusionise"],
    &["prolusionize"],
    &["prolusionise"],
];

pub(crate) static ENTRY_PRONOMINALIZATION_2160092279956307185: VariantsMap = [
    &["pronominalization"],
    &["pronominalisation"],
    &["pronominalization"],
    &["pronominalisation"],
];

pub(crate) static ENTRY_PRONOMINALIZE_16300143735228333916: VariantsMap = [
    &["pronominalize"],
    &["pronominalise"],
    &["pronominalize"],
    &["pronominalise"],
];

pub(crate) static ENTRY_PROPAGANDIZED_16934930634247263476: VariantsMap = [
    &["propagandized"],
    &["propagandised"],
    &["propagandized"],
    &["propagandised"],
];

pub(crate) static ENTRY_PROPAGANDIZES_9571312284054421445: VariantsMap = [
    &["propagandizes"],
    &["propagandises"],
    &["propagandizes"],
    &["propagandises"],
];

pub(crate) static ENTRY_PROPAGANDIZE_8177553084887485510: VariantsMap = [
    &["propagandize"],
    &["propagandise"],
    &["propagandize"],
    &["propagandise"],
];

pub(crate) static ENTRY_PROPAGANDIZING_8734852002578869522: VariantsMap = [
    &["propagandizing"],
    &["propagandising"],
    &["propagandizing"],
    &["propagandising"],
];

pub(crate) static ENTRY_PROPHETIZES_4261334625906585144: VariantsMap = [
    &["prophetizes"],
    &["prophetises"],
    &["prophetizes"],
    &["prophetises"],
];

pub(crate) static ENTRY_PROPHETIZE_452344212153495963: VariantsMap = [
    &["prophetize"],
    &["prophetise"],
    &["prophetize"],
    &["prophetise"],
];

pub(crate) static ENTRY_PROPOSITIONIZES_998017883950780980: VariantsMap = [
    &["propositionizes"],
    &["propositionises"],
    &["propositionizes"],
    &["propositionises"],
];

pub(crate) static ENTRY_PROPOSITIONIZE_15255429142774392236: VariantsMap = [
    &["propositionize"],
    &["propositionise"],
    &["propositionize"],
    &["propositionise"],
];

pub(crate) static ENTRY_PROPRETORIAL_2347772660746698838: VariantsMap = [
    &["propretorial"],
    &["propraetorial"],
    &["propraetorial"],
    &["propraetorial"],
];

pub(crate) static ENTRY_PROPRETORIAN_758510350938796380: VariantsMap = [
    &["propretorian"],
    &["propraetorian"],
    &["propraetorian"],
    &["propraetorian"],
];

pub(crate) static ENTRY_PROPRETORS_3015280642699082218: VariantsMap = [
    &["propretors"],
    &["propraetors"],
    &["propraetors"],
    &["propraetors"],
];

pub(crate) static ENTRY_PROPRETOR_17239413312041471631: VariantsMap = [
    &["propretor"],
    &["propraetor"],
    &["propraetor"],
    &["propraetor"],
];

pub(crate) static ENTRY_PROPYLITIZATIONS_6860959394412061312: VariantsMap = [
    &["propylitizations"],
    &["propylitisations"],
    &["propylitizations"],
    &["propylitisations"],
];

pub(crate) static ENTRY_PROPYLITIZATION_16422443521775391870: VariantsMap = [
    &["propylitization"],
    &["propylitisation"],
    &["propylitization"],
    &["propylitisation"],
];

pub(crate) static ENTRY_PROPYLITIZED_4181293442870295139: VariantsMap = [
    &["propylitized"],
    &["propylitised"],
    &["propylitized"],
    &["propylitised"],
];

pub(crate) static ENTRY_PROPYLITIZES_1024314893105495596: VariantsMap = [
    &["propylitizes"],
    &["propylitises"],
    &["propylitizes"],
    &["propylitises"],
];

pub(crate) static ENTRY_PROPYLITIZE_221263951211359073: VariantsMap = [
    &["propylitize"],
    &["propylitise"],
    &["propylitize"],
    &["propylitise"],
];

pub(crate) static ENTRY_PROPYLITIZING_8928406423210230276: VariantsMap = [
    &["propylitizing"],
    &["propylitising"],
    &["propylitizing"],
    &["propylitising"],
];

pub(crate) static ENTRY_PROSELYTIZATIONS_15779681958788343945: VariantsMap = [
    &["proselytizations"],
    &["proselytisations"],
    &["proselytizations"],
    &["proselytisations"],
];

pub(crate) static ENTRY_PROSELYTIZATION_17135856883988053610: VariantsMap = [
    &["proselytization"],
    &["proselytisation"],
    &["proselytization"],
    &["proselytisation"],
];

pub(crate) static ENTRY_PROSELYTIZED_13393641785992171327: VariantsMap = [
    &["proselytized"],
    &["proselytised"],
    &["proselytized"],
    &["proselytised"],
];

pub(crate) static ENTRY_PROSELYTIZERS_7582504000576690857: VariantsMap = [
    &["proselytizers"],
    &["proselytisers"],
    &["proselytizers"],
    &["proselytisers"],
];

pub(crate) static ENTRY_PROSELYTIZER_10730288809990334441: VariantsMap = [
    &["proselytizer"],
    &["proselytiser"],
    &["proselytizer"],
    &["proselytiser"],
];

pub(crate) static ENTRY_PROSELYTIZES_6759164791000097610: VariantsMap = [
    &["proselytizes"],
    &["proselytises"],
    &["proselytizes"],
    &["proselytises"],
];

pub(crate) static ENTRY_PROSELYTIZE_14508434076807964437: VariantsMap = [
    &["proselytize"],
    &["proselytise"],
    &["proselytize"],
    &["proselytise"],
];

pub(crate) static ENTRY_PROSELYTIZING_3222893683296080940: VariantsMap = [
    &["proselytizing"],
    &["proselytising"],
    &["proselytizing"],
    &["proselytising"],
];

pub(crate) static ENTRY_PROSEUCHE_10388889221593101497: VariantsMap = [
    &["proseuche"],
    &["proseuchae"],
    &["proseuchae"],
    &["proseuchae"],
];

pub(crate) static ENTRY_PROSOCELE_8387894783348711239: VariantsMap = [
    &["prosocele"],
    &["prosocoele"],
    &["prosocoele"],
    &["prosocoele"],
];

pub(crate) static ENTRY_PROSOPOPEIAL_12885233098577128627: VariantsMap = [
    &["prosopopeial"],
    &["prosopopoeial"],
    &["prosopopoeial"],
    &["prosopopoeial"],
];

pub(crate) static ENTRY_PROSOPOPOEIAS_10634619028210897533: VariantsMap = [
    &["prosopopoeias"],
    &["prosopopoeias"],
    &["prosopopoeias"],
    &["prosopopoeias"],
];

pub(crate) static ENTRY_PROSOPOPOEIA_3116153132173899307: VariantsMap = [
    &["prosopopoeia"],
    &["prosopopoeia"],
    &["prosopopoeia"],
    &["prosopopoeia"],
];

pub(crate) static ENTRY_PROSTATORRHEA_17007958745656658064: VariantsMap = [
    &["prostatorrhea"],
    &["prostatorrhoea"],
    &["prostatorrhoea"],
    &["prostatorrhoea"],
];

pub(crate) static ENTRY_PROTECTIONIZES_185151310463565901: VariantsMap = [
    &["protectionizes"],
    &["protectionises"],
    &["protectionizes"],
    &["protectionises"],
];

pub(crate) static ENTRY_PROTECTIONIZE_5626694334800959888: VariantsMap = [
    &["protectionize"],
    &["protectionise"],
    &["protectionize"],
    &["protectionise"],
];

pub(crate) static ENTRY_PROTEIDE_8541786308809678707: VariantsMap = [
    &["proteide"],
    &["proteidae"],
    &["proteidae"],
    &["proteidae"],
];

pub(crate) static ENTRY_PROTESTANTIZED_9706500663127294434: VariantsMap = [
    &["protestantized"],
    &["protestantised"],
    &["protestantized"],
    &["protestantised"],
];

pub(crate) static ENTRY_PROTESTANTIZES_14980175348825437179: VariantsMap = [
    &["protestantizes"],
    &["protestantises"],
    &["protestantizes"],
    &["protestantises"],
];

pub(crate) static ENTRY_PROTESTANTIZE_930408179750739241: VariantsMap = [
    &["protestantize"],
    &["protestantise"],
    &["protestantize"],
    &["protestantise"],
];

pub(crate) static ENTRY_PROTESTANTIZING_17553830627472979038: VariantsMap = [
    &["protestantizing"],
    &["protestantising"],
    &["protestantizing"],
    &["protestantising"],
];

pub(crate) static ENTRY_PROTHOENOR_12241019511979868123: VariantsMap = [
    &["prothoenor"],
    &["prothoaenor"],
    &["prothoaenor"],
    &["prothoaenor"],
];

pub(crate) static ENTRY_PROTOARCHEOLOGY_12948760782790762751: VariantsMap = [
    &["protoarcheology"],
    &["protoarchaeology"],
    &["protoarchaeology"],
    &["protoarchaeology"],
];

pub(crate) static ENTRY_PROTOCOLED_9512660668033614324: VariantsMap = [
    &["protocoled"],
    &["protocolled"],
    &["protocolled"],
    &["protocolled"],
];

pub(crate) static ENTRY_PROTOCOLING_4325129038987463009: VariantsMap = [
    &["protocoling"],
    &["protocolling"],
    &["protocolling"],
    &["protocolling"],
];

pub(crate) static ENTRY_PROTOCOLIZATIONS_1652690302390074801: VariantsMap = [
    &["protocolizations"],
    &["protocolisations"],
    &["protocolizations"],
    &["protocolisations"],
];

pub(crate) static ENTRY_PROTOCOLIZATION_7253399674306380843: VariantsMap = [
    &["protocolization"],
    &["protocolisation"],
    &["protocolization"],
    &["protocolisation"],
];

pub(crate) static ENTRY_PROTOCOLIZED_8014687509536437744: VariantsMap = [
    &["protocolized"],
    &["protocolised"],
    &["protocolized"],
    &["protocolised"],
];

pub(crate) static ENTRY_PROTOCOLIZES_12890931742186597048: VariantsMap = [
    &["protocolizes"],
    &["protocolises"],
    &["protocolizes"],
    &["protocolises"],
];

pub(crate) static ENTRY_PROTOCOLIZE_14027135970880253930: VariantsMap = [
    &["protocolize"],
    &["protocolise"],
    &["protocolize"],
    &["protocolise"],
];

pub(crate) static ENTRY_PROTOCOLIZING_3470922517137243613: VariantsMap = [
    &["protocolizing"],
    &["protocolising"],
    &["protocolizing"],
    &["protocolising"],
];

pub(crate) static ENTRY_PROVERBIALIZED_8987504788438996422: VariantsMap = [
    &["proverbialized"],
    &["proverbialised"],
    &["proverbialized"],
    &["proverbialised"],
];

pub(crate) static ENTRY_PROVERBIALIZES_8317029653044381349: VariantsMap = [
    &["proverbializes"],
    &["proverbialises"],
    &["proverbializes"],
    &["proverbialises"],
];

pub(crate) static ENTRY_PROVERBIALIZE_13334383391371333892: VariantsMap = [
    &["proverbialize"],
    &["proverbialise"],
    &["proverbialize"],
    &["proverbialise"],
];

pub(crate) static ENTRY_PROVERBIALIZING_18074267399445313428: VariantsMap = [
    &["proverbializing"],
    &["proverbialising"],
    &["proverbializing"],
    &["proverbialising"],
];

pub(crate) static ENTRY_PROVERBIZES_18160973412105788998: VariantsMap = [
    &["proverbizes"],
    &["proverbises"],
    &["proverbizes"],
    &["proverbises"],
];

pub(crate) static ENTRY_PROVERBIZE_10993755369638498420: VariantsMap = [
    &["proverbize"],
    &["proverbise"],
    &["proverbize"],
    &["proverbise"],
];

pub(crate) static ENTRY_PROVINCIALIZATIONS_1272068076611645435: VariantsMap = [
    &["provincializations"],
    &["provincialisations"],
    &["provincializations"],
    &["provincialisations"],
];

pub(crate) static ENTRY_PROVINCIALIZATION_11197353514593321649: VariantsMap = [
    &["provincialization"],
    &["provincialisation"],
    &["provincialization"],
    &["provincialisation"],
];

pub(crate) static ENTRY_PROVINCIALIZED_14091881793591709636: VariantsMap = [
    &["provincialized"],
    &["provincialised"],
    &["provincialized"],
    &["provincialised"],
];

pub(crate) static ENTRY_PROVINCIALIZES_7740199822590027111: VariantsMap = [
    &["provincializes"],
    &["provincialises"],
    &["provincializes"],
    &["provincialises"],
];

pub(crate) static ENTRY_PROVINCIALIZE_9892471258204714701: VariantsMap = [
    &["provincialize"],
    &["provincialise"],
    &["provincialize"],
    &["provincialise"],
];

pub(crate) static ENTRY_PROVINCIALIZING_12497264018634460310: VariantsMap = [
    &["provincializing"],
    &["provincialising"],
    &["provincializing"],
    &["provincialising"],
];

pub(crate) static ENTRY_PRUSSIANIZATIONS_3200828078370769033: VariantsMap = [
    &["prussianizations"],
    &["prussianisations"],
    &["prussianizations"],
    &["prussianisations"],
];

pub(crate) static ENTRY_PRUSSIANIZATION_4426098874560395046: VariantsMap = [
    &["prussianization"],
    &["prussianisation"],
    &["prussianization"],
    &["prussianisation"],
];

pub(crate) static ENTRY_PRUSSIANIZED_10124812572238942023: VariantsMap = [
    &["prussianized"],
    &["prussianised"],
    &["prussianized"],
    &["prussianised"],
];

pub(crate) static ENTRY_PRUSSIANIZERS_14800421025773551283: VariantsMap = [
    &["prussianizers"],
    &["prussianisers"],
    &["prussianizers"],
    &["prussianisers"],
];

pub(crate) static ENTRY_PRUSSIANIZER_18286762685167593766: VariantsMap = [
    &["prussianizer"],
    &["prussianiser"],
    &["prussianizer"],
    &["prussianiser"],
];

pub(crate) static ENTRY_PRUSSIANIZES_13923514287346300166: VariantsMap = [
    &["prussianizes"],
    &["prussianises"],
    &["prussianizes"],
    &["prussianises"],
];

pub(crate) static ENTRY_PRUSSIANIZE_12459016936159488594: VariantsMap = [
    &["prussianize"],
    &["prussianise"],
    &["prussianize"],
    &["prussianise"],
];

pub(crate) static ENTRY_PRUSSIANIZING_12424701237527019665: VariantsMap = [
    &["prussianizing"],
    &["prussianising"],
    &["prussianizing"],
    &["prussianising"],
];

pub(crate) static ENTRY_PSALMODIZED_7514155639553618886: VariantsMap = [
    &["psalmodized"],
    &["psalmodised"],
    &["psalmodized"],
    &["psalmodised"],
];

pub(crate) static ENTRY_PSALMODIZES_2076290176085375139: VariantsMap = [
    &["psalmodizes"],
    &["psalmodises"],
    &["psalmodizes"],
    &["psalmodises"],
];

pub(crate) static ENTRY_PSALMODIZE_15004094711325009957: VariantsMap = [
    &["psalmodize"],
    &["psalmodise"],
    &["psalmodize"],
    &["psalmodise"],
];

pub(crate) static ENTRY_PSALMODIZING_751749509657132335: VariantsMap = [
    &["psalmodizing"],
    &["psalmodising"],
    &["psalmodizing"],
    &["psalmodising"],
];

pub(crate) static ENTRY_PSEUDELEPHANT_2030914162737246911: VariantsMap = [
    &["pseudelephant"],
    &["pseudoelephant"],
    &["pseudoelephant"],
    &["pseudoelephant"],
];

pub(crate) static ENTRY_PSEUDEMBRYONIC_11216696215007963967: VariantsMap = [
    &["pseudembryonic"],
    &["pseudoembryonic"],
    &["pseudoembryonic"],
    &["pseudoembryonic"],
];

pub(crate) static ENTRY_PSEUDEMBRYO_14203020715857032391: VariantsMap = [
    &["pseudembryo"],
    &["pseudoembryo"],
    &["pseudoembryo"],
    &["pseudoembryo"],
];

pub(crate) static ENTRY_PSEUDESTHESIA_1275162758906081869: VariantsMap = [
    &["pseudesthesia"],
    &["pseudaesthesia"],
    &["pseudaesthesia"],
    &["pseudaesthesia"],
];

pub(crate) static ENTRY_PSEUDHEMAL_15598474376323098687: VariantsMap = [
    &["pseudhemal"],
    &["pseudhaemal"],
    &["pseudhaemal"],
    &["pseudhaemal"],
];

pub(crate) static ENTRY_PSEUDOANEMIAS_12376590166743463304: VariantsMap = [
    &["pseudoanemias"],
    &["pseudoanaemias"],
    &["pseudoanaemias"],
    &["pseudoanaemias"],
];

pub(crate) static ENTRY_PSEUDOANEMIA_13668020166240077472: VariantsMap = [
    &["pseudoanemia"],
    &["pseudoanaemia"],
    &["pseudoanaemia"],
    &["pseudoanaemia"],
];

pub(crate) static ENTRY_PSEUDOANEMICS_11106944421043495730: VariantsMap = [
    &["pseudoanemics"],
    &["pseudoanaemics"],
    &["pseudoanaemics"],
    &["pseudoanaemics"],
];

pub(crate) static ENTRY_PSEUDOANEMIC_12741381100990975341: VariantsMap = [
    &["pseudoanemic"],
    &["pseudoanaemic"],
    &["pseudoanaemic"],
    &["pseudoanaemic"],
];

pub(crate) static ENTRY_PSEUDOCELE_8053951785853751294: VariantsMap = [
    &["pseudocele"],
    &["pseudocoele"],
    &["pseudocoele"],
    &["pseudocoele"],
];

pub(crate) static ENTRY_PSEUDOCELOM_13969014156705538002: VariantsMap = [
    &["pseudocelom"],
    &["pseudocoelom"],
    &["pseudocoelom"],
    &["pseudocoelom"],
];

pub(crate) static ENTRY_PSEUDOEDEMAS_12395792322606353606: VariantsMap = [
    &["pseudoedemas"],
    &["pseudooedemas"],
    &["pseudooedemas"],
    &["pseudooedemas"],
];

pub(crate) static ENTRY_PSEUDOEDEMA_15365216887149708823: VariantsMap = [
    &["pseudoedema"],
    &["pseudooedema"],
    &["pseudooedema"],
    &["pseudooedema"],
];

pub(crate) static ENTRY_PSEUDOGRAPHIZES_9996987914403453497: VariantsMap = [
    &["pseudographizes"],
    &["pseudographises"],
    &["pseudographizes"],
    &["pseudographises"],
];

pub(crate) static ENTRY_PSEUDOGRAPHIZE_885997092067089742: VariantsMap = [
    &["pseudographize"],
    &["pseudographise"],
    &["pseudographize"],
    &["pseudographise"],
];

pub(crate) static ENTRY_PSEUDOLUNULE_14036316726076847351: VariantsMap = [
    &["pseudolunule"],
    &["pseudolunulae"],
    &["pseudolunulae"],
    &["pseudolunulae"],
];

pub(crate) static ENTRY_PSYCHOANALYZED_2361240273552649217: VariantsMap = [
    &["psychoanalyzed"],
    &["psychoanalysed"],
    &["psychoanalyzed"],
    &["psychoanalysed"],
];

pub(crate) static ENTRY_PSYCHOANALYZERS_6122603980161912665: VariantsMap = [
    &["psychoanalyzers"],
    &["psychoanalysers"],
    &["psychoanalyzers"],
    &["psychoanalysers"],
];

pub(crate) static ENTRY_PSYCHOANALYZER_1467300969528733943: VariantsMap = [
    &["psychoanalyzer"],
    &["psychoanalyser"],
    &["psychoanalyzer"],
    &["psychoanalyser"],
];

pub(crate) static ENTRY_PSYCHOANALYZES_17393570726957476631: VariantsMap = [
    &["psychoanalyzes"],
    &["psychoanalyses"],
    &["psychoanalyzes"],
    &["psychoanalyses"],
];

pub(crate) static ENTRY_PSYCHOANALYZE_13352325501420392703: VariantsMap = [
    &["psychoanalyze"],
    &["psychoanalyse"],
    &["psychoanalyze"],
    &["psychoanalyse"],
];

pub(crate) static ENTRY_PSYCHOANALYZING_17396903265279304718: VariantsMap = [
    &["psychoanalyzing"],
    &["psychoanalysing"],
    &["psychoanalyzing"],
    &["psychoanalysing"],
];

pub(crate) static ENTRY_PSYCHOLOGIZATION_6576901085662588432: VariantsMap = [
    &["psychologization"],
    &["psychologisation"],
    &["psychologization"],
    &["psychologisation"],
];

pub(crate) static ENTRY_PSYCHOLOGIZED_6245845065865139826: VariantsMap = [
    &["psychologized"],
    &["psychologised"],
    &["psychologized"],
    &["psychologised"],
];

pub(crate) static ENTRY_PSYCHOLOGIZES_5058513302027995583: VariantsMap = [
    &["psychologizes"],
    &["psychologises"],
    &["psychologizes"],
    &["psychologises"],
];

pub(crate) static ENTRY_PSYCHOLOGIZE_5793948135745501907: VariantsMap = [
    &["psychologize"],
    &["psychologise"],
    &["psychologize"],
    &["psychologise"],
];

pub(crate) static ENTRY_PSYCHOLOGIZING_3642591565222639415: VariantsMap = [
    &["psychologizing"],
    &["psychologising"],
    &["psychologizing"],
    &["psychologising"],
];

pub(crate) static ENTRY_PTOLEMEAN_2551741330039753225: VariantsMap = [
    &["ptolemean"],
    &["ptolemaean"],
    &["ptolemaean"],
    &["ptolemaean"],
];

pub(crate) static ENTRY_PTYALIZED_2480073821976771187: VariantsMap = [
    &["ptyalized"],
    &["ptyalised"],
    &["ptyalized"],
    &["ptyalised"],
];

pub(crate) static ENTRY_PTYALIZES_66260576722278161: VariantsMap = [
    &["ptyalizes"],
    &["ptyalises"],
    &["ptyalizes"],
    &["ptyalises"],
];

pub(crate) static ENTRY_PTYALIZE_10403248045054698478: VariantsMap =
    [&["ptyalize"], &["ptyalise"], &["ptyalize"], &["ptyalise"]];

pub(crate) static ENTRY_PTYALIZING_12909110709768995708: VariantsMap = [
    &["ptyalizing"],
    &["ptyalising"],
    &["ptyalizing"],
    &["ptyalising"],
];

pub(crate) static ENTRY_PUBLICE_3806609421992105409: VariantsMap =
    [&["publice"], &["publicae"], &["publicae"], &["publicae"]];

pub(crate) static ENTRY_PUBLICIZED_16571421876501016970: VariantsMap = [
    &["publicized"],
    &["publicised"],
    &["publicized"],
    &["publicised"],
];

pub(crate) static ENTRY_PUBLICIZES_9435453312305988637: VariantsMap = [
    &["publicizes"],
    &["publicises"],
    &["publicizes"],
    &["publicises"],
];

pub(crate) static ENTRY_PUBLICIZE_5424063269919566067: VariantsMap = [
    &["publicize"],
    &["publicise"],
    &["publicize"],
    &["publicise"],
];

pub(crate) static ENTRY_PUBLICIZING_9494963417088857325: VariantsMap = [
    &["publicizing"],
    &["publicising"],
    &["publicizing"],
    &["publicising"],
];

pub(crate) static ENTRY_PUEBLOIZATIONS_1207431189485470945: VariantsMap = [
    &["puebloizations"],
    &["puebloisations"],
    &["puebloizations"],
    &["puebloisations"],
];

pub(crate) static ENTRY_PUEBLOIZATION_11619662074461690533: VariantsMap = [
    &["puebloization"],
    &["puebloisation"],
    &["puebloization"],
    &["puebloisation"],
];

pub(crate) static ENTRY_PUEBLOIZES_5950295222868591250: VariantsMap = [
    &["puebloizes"],
    &["puebloises"],
    &["puebloizes"],
    &["puebloises"],
];

pub(crate) static ENTRY_PUEBLOIZE_10879706836776671039: VariantsMap = [
    &["puebloize"],
    &["puebloise"],
    &["puebloize"],
    &["puebloise"],
];

pub(crate) static ENTRY_PUERS_15212243335679873039: VariantsMap =
    [&["puers"], &["pures"], &["pures"], &["pures"]];

pub(crate) static ENTRY_PULICIDE_15247724617600167568: VariantsMap = [
    &["pulicide"],
    &["pulicidae"],
    &["pulicidae"],
    &["pulicidae"],
];

pub(crate) static ENTRY_PULLMANIZES_17269054163787556918: VariantsMap = [
    &["pullmanizes"],
    &["pullmanises"],
    &["pullmanizes"],
    &["pullmanises"],
];

pub(crate) static ENTRY_PULLMANIZE_14503256122372519048: VariantsMap = [
    &["pullmanize"],
    &["pullmanise"],
    &["pullmanize"],
    &["pullmanise"],
];

pub(crate) static ENTRY_PULPITIZES_12676842864281663017: VariantsMap = [
    &["pulpitizes"],
    &["pulpitises"],
    &["pulpitizes"],
    &["pulpitises"],
];

pub(crate) static ENTRY_PULPITIZE_10489028357901570216: VariantsMap = [
    &["pulpitize"],
    &["pulpitise"],
    &["pulpitize"],
    &["pulpitise"],
];

pub(crate) static ENTRY_PULVERIZABLER_5218535595905845450: VariantsMap = [
    &["pulverizabler"],
    &["pulverisabler"],
    &["pulverizabler"],
    &["pulverisabler"],
];

pub(crate) static ENTRY_PULVERIZABLEST_6079579218302677233: VariantsMap = [
    &["pulverizablest"],
    &["pulverisablest"],
    &["pulverizablest"],
    &["pulverisablest"],
];

pub(crate) static ENTRY_PULVERIZABLES_5549786631554922273: VariantsMap = [
    &["pulverizables"],
    &["pulverisables"],
    &["pulverizables"],
    &["pulverisables"],
];

pub(crate) static ENTRY_PULVERIZABLE_7604627270800430124: VariantsMap = [
    &["pulverizable"],
    &["pulverisable"],
    &["pulverizable"],
    &["pulverisable"],
];

pub(crate) static ENTRY_PULVERIZATIONS_2088646255652876100: VariantsMap = [
    &["pulverizations"],
    &["pulverisations"],
    &["pulverizations"],
    &["pulverisations"],
];

pub(crate) static ENTRY_PULVERIZATION_17401567700247612056: VariantsMap = [
    &["pulverization"],
    &["pulverisation"],
    &["pulverization"],
    &["pulverisation"],
];

pub(crate) static ENTRY_PULVERIZED_8994580757484344110: VariantsMap = [
    &["pulverized"],
    &["pulverised"],
    &["pulverized"],
    &["pulverised"],
];

pub(crate) static ENTRY_PULVERIZERS_9774439820094487955: VariantsMap = [
    &["pulverizers"],
    &["pulverisers"],
    &["pulverizers"],
    &["pulverisers"],
];

pub(crate) static ENTRY_PULVERIZER_10176365177336582670: VariantsMap = [
    &["pulverizer"],
    &["pulveriser"],
    &["pulverizer"],
    &["pulveriser"],
];

pub(crate) static ENTRY_PULVERIZES_10527798401373635350: VariantsMap = [
    &["pulverizes"],
    &["pulverises"],
    &["pulverizes"],
    &["pulverises"],
];

pub(crate) static ENTRY_PULVERIZE_7762340513545873128: VariantsMap = [
    &["pulverize"],
    &["pulverise"],
    &["pulverize"],
    &["pulverise"],
];

pub(crate) static ENTRY_PULVERIZING_2591037067348532366: VariantsMap = [
    &["pulverizing"],
    &["pulverising"],
    &["pulverizing"],
    &["pulverising"],
];

pub(crate) static ENTRY_PULVILIZED_8081698958947874094: VariantsMap = [
    &["pulvilized"],
    &["pulvilised"],
    &["pulvilized"],
    &["pulvilised"],
];

pub(crate) static ENTRY_PUMMELED_14220543769322316417: VariantsMap = [
    &["pummeled"],
    &["pummelled"],
    &["pummelled"],
    &["pummelled"],
];

pub(crate) static ENTRY_PUMMELER_10140090635614975322: VariantsMap = [
    &["pummeler"],
    &["pummeller"],
    &["pummeller"],
    &["pummeller"],
];

pub(crate) static ENTRY_PUMMELING_86144285377904737: VariantsMap = [
    &["pummeling"],
    &["pummelling"],
    &["pummelling"],
    &["pummelling"],
];

pub(crate) static ENTRY_PUPILIZES_3451767798624549889: VariantsMap = [
    &["pupilizes"],
    &["pupilises"],
    &["pupilizes"],
    &["pupilises"],
];

pub(crate) static ENTRY_PUPILIZE_4813815664186208258: VariantsMap =
    [&["pupilize"], &["pupilise"], &["pupilize"], &["pupilise"]];

pub(crate) static ENTRY_PUPPETIZES_6991413059968099138: VariantsMap = [
    &["puppetizes"],
    &["puppetises"],
    &["puppetizes"],
    &["puppetises"],
];

pub(crate) static ENTRY_PUPPETIZE_17610253588173061678: VariantsMap = [
    &["puppetize"],
    &["puppetise"],
    &["puppetize"],
    &["puppetise"],
];

pub(crate) static ENTRY_PURITANIZED_7990904455585990927: VariantsMap = [
    &["puritanized"],
    &["puritanised"],
    &["puritanized"],
    &["puritanised"],
];

pub(crate) static ENTRY_PURITANIZERS_2427860611923301122: VariantsMap = [
    &["puritanizers"],
    &["puritanisers"],
    &["puritanizers"],
    &["puritanisers"],
];

pub(crate) static ENTRY_PURITANIZER_5248542814648310307: VariantsMap = [
    &["puritanizer"],
    &["puritaniser"],
    &["puritanizer"],
    &["puritaniser"],
];

pub(crate) static ENTRY_PURITANIZES_412554844347730493: VariantsMap = [
    &["puritanizes"],
    &["puritanises"],
    &["puritanizes"],
    &["puritanises"],
];

pub(crate) static ENTRY_PURITANIZE_14818586420411105390: VariantsMap = [
    &["puritanize"],
    &["puritanise"],
    &["puritanize"],
    &["puritanise"],
];

pub(crate) static ENTRY_PURITANIZING_2930261870874651377: VariantsMap = [
    &["puritanizing"],
    &["puritanising"],
    &["puritanizing"],
    &["puritanising"],
];

pub(crate) static ENTRY_PYEMIAS_15972708527455152251: VariantsMap =
    [&["pyemias"], &["pyaemias"], &["pyaemias"], &["pyaemias"]];

pub(crate) static ENTRY_PYEMIA_6014368326116867825: VariantsMap =
    [&["pyemia"], &["pyaemia"], &["pyaemia"], &["pyaemia"]];

pub(crate) static ENTRY_PYEMIC_299205947973053064: VariantsMap =
    [&["pyemic"], &["pyaemic"], &["pyaemic"], &["pyaemic"]];

pub(crate) static ENTRY_PYGMEAN_17790184024575865702: VariantsMap =
    [&["pygmean"], &["pygmaean"], &["pygmaean"], &["pygmaean"]];

pub(crate) static ENTRY_PYORRHEALER_979614094516325433: VariantsMap = [
    &["pyorrhealer"],
    &["pyorrhoealer"],
    &["pyorrhoealer"],
    &["pyorrhoealer"],
];

pub(crate) static ENTRY_PYORRHEALEST_2608051559882275769: VariantsMap = [
    &["pyorrhealest"],
    &["pyorrhoealest"],
    &["pyorrhoealest"],
    &["pyorrhoealest"],
];

pub(crate) static ENTRY_PYORRHEAL_8724408354208820698: VariantsMap = [
    &["pyorrheal"],
    &["pyorrhoeal"],
    &["pyorrhoeal"],
    &["pyorrhoeal"],
];

pub(crate) static ENTRY_PYORRHEAS_10646277786557890077: VariantsMap = [
    &["pyorrheas"],
    &["pyorrhoeas"],
    &["pyorrheas"],
    &["pyorrhoeas"],
];

pub(crate) static ENTRY_PYORRHEA_3796710759481808618: VariantsMap =
    [&["pyorrhea"], &["pyorrhoea"], &["pyorrhea"], &["pyorrhoea"]];

pub(crate) static ENTRY_PYORRHEIC_11175810966012719800: VariantsMap = [
    &["pyorrheic"],
    &["pyorrhoeic"],
    &["pyorrhoeic"],
    &["pyorrhoeic"],
];

pub(crate) static ENTRY_PYRAMIDIZES_10735124649198481951: VariantsMap = [
    &["pyramidizes"],
    &["pyramidises"],
    &["pyramidizes"],
    &["pyramidises"],
];

pub(crate) static ENTRY_PYRAMIDIZE_6518185724012578568: VariantsMap = [
    &["pyramidize"],
    &["pyramidise"],
    &["pyramidize"],
    &["pyramidise"],
];

pub(crate) static ENTRY_PYRENEAN_15204083665180883806: VariantsMap = [
    &["pyrenean"],
    &["pyrenaean"],
    &["pyrenaean"],
    &["pyrenaean"],
];

pub(crate) static ENTRY_PYRENEUS_9499865956932679317: VariantsMap = [
    &["pyreneus"],
    &["pyrenaeus"],
    &["pyrenaeus"],
    &["pyrenaeus"],
];

pub(crate) static ENTRY_PYRIDINIZES_17373239390566251661: VariantsMap = [
    &["pyridinizes"],
    &["pyridinises"],
    &["pyridinizes"],
    &["pyridinises"],
];

pub(crate) static ENTRY_PYRIDINIZE_12080394653590795845: VariantsMap = [
    &["pyridinize"],
    &["pyridinise"],
    &["pyridinize"],
    &["pyridinise"],
];

pub(crate) static ENTRY_PYRITIZATIONS_15645658849345555870: VariantsMap = [
    &["pyritizations"],
    &["pyritisations"],
    &["pyritizations"],
    &["pyritisations"],
];

pub(crate) static ENTRY_PYRITIZATION_3981025262217302180: VariantsMap = [
    &["pyritization"],
    &["pyritisation"],
    &["pyritization"],
    &["pyritisation"],
];

pub(crate) static ENTRY_PYRITIZED_2729055497658727569: VariantsMap = [
    &["pyritized"],
    &["pyritised"],
    &["pyritized"],
    &["pyritised"],
];

pub(crate) static ENTRY_PYRITIZES_1825397531229652480: VariantsMap = [
    &["pyritizes"],
    &["pyritises"],
    &["pyritizes"],
    &["pyritises"],
];

pub(crate) static ENTRY_PYRITIZE_4098278292163241581: VariantsMap =
    [&["pyritize"], &["pyritise"], &["pyritize"], &["pyritise"]];

pub(crate) static ENTRY_PYRITIZING_9304613293971430176: VariantsMap = [
    &["pyritizing"],
    &["pyritising"],
    &["pyritizing"],
    &["pyritising"],
];

pub(crate) static ENTRY_PYROLYZABLE_11388782876912970763: VariantsMap = [
    &["pyrolyzable"],
    &["pyrolysable"],
    &["pyrolysable"],
    &["pyrolysable"],
];

pub(crate) static ENTRY_PYROLYZATES_5304514469678411687: VariantsMap = [
    &["pyrolyzates"],
    &["pyrolysates"],
    &["pyrolysates"],
    &["pyrolysates"],
];

pub(crate) static ENTRY_PYROLYZATE_6347070741811549467: VariantsMap = [
    &["pyrolyzate"],
    &["pyrolysate"],
    &["pyrolysate"],
    &["pyrolysate"],
];

pub(crate) static ENTRY_PYROLYZED_13833971036459417043: VariantsMap = [
    &["pyrolyzed"],
    &["pyrolysed"],
    &["pyrolyzed"],
    &["pyrolysed"],
];

pub(crate) static ENTRY_PYROLYZER_14520847897378277316: VariantsMap = [
    &["pyrolyzer"],
    &["pyrolyser"],
    &["pyrolyser"],
    &["pyrolyser"],
];

pub(crate) static ENTRY_PYROLYZES_4360458297920745869: VariantsMap = [
    &["pyrolyzes"],
    &["pyrolyses"],
    &["pyrolyzes"],
    &["pyrolyses"],
];

pub(crate) static ENTRY_PYROLYZE_1370306423959504329: VariantsMap =
    [&["pyrolyze"], &["pyrolyse"], &["pyrolyze"], &["pyrolyse"]];

pub(crate) static ENTRY_PYROLYZING_3017668529784184986: VariantsMap = [
    &["pyrolyzing"],
    &["pyrolysing"],
    &["pyrolyzing"],
    &["pyrolysing"],
];

pub(crate) static ENTRY_PYTHAGOREANIZES_4101293918117765599: VariantsMap = [
    &["pythagoreanizes"],
    &["pythagoreanises"],
    &["pythagoreanizes"],
    &["pythagoreanises"],
];

pub(crate) static ENTRY_PYTHAGOREANIZE_4718603082876001070: VariantsMap = [
    &["pythagoreanize"],
    &["pythagoreanise"],
    &["pythagoreanize"],
    &["pythagoreanise"],
];

pub(crate) static ENTRY_PYTHONINE_17988724234836146578: VariantsMap = [
    &["pythonine"],
    &["pythoninae"],
    &["pythoninae"],
    &["pythoninae"],
];

pub(crate) static ENTRY_PYTHONIZES_12966276028590092936: VariantsMap = [
    &["pythonizes"],
    &["pythonises"],
    &["pythonizes"],
    &["pythonises"],
];

pub(crate) static ENTRY_PYTHONIZE_11169836088771020218: VariantsMap = [
    &["pythonize"],
    &["pythonise"],
    &["pythonize"],
    &["pythonise"],
];

pub(crate) static ENTRY_QUAESTORS_10032398541103637992: VariantsMap = [
    &["quaestors"],
    &["quaestors"],
    &["quaestors"],
    &["quaestors"],
];

pub(crate) static ENTRY_QUAESTOR_2102274138115411812: VariantsMap =
    [&["quaestor"], &["quaestor"], &["quaestor"], &["quaestor"]];

pub(crate) static ENTRY_QUAKERIZATIONS_3245384999167216727: VariantsMap = [
    &["quakerizations"],
    &["quakerisations"],
    &["quakerizations"],
    &["quakerisations"],
];

pub(crate) static ENTRY_QUAKERIZATION_17206737357396103152: VariantsMap = [
    &["quakerization"],
    &["quakerisation"],
    &["quakerization"],
    &["quakerisation"],
];

pub(crate) static ENTRY_QUAKERIZES_10193743747756102765: VariantsMap = [
    &["quakerizes"],
    &["quakerises"],
    &["quakerizes"],
    &["quakerises"],
];

pub(crate) static ENTRY_QUAKERIZE_5397219040311238658: VariantsMap = [
    &["quakerize"],
    &["quakerise"],
    &["quakerize"],
    &["quakerise"],
];

pub(crate) static ENTRY_QUANTIZATIONS_15578988125770234593: VariantsMap = [
    &["quantizations"],
    &["quantisations"],
    &["quantizations"],
    &["quantisations"],
];

pub(crate) static ENTRY_QUANTIZATION_16189268688890136964: VariantsMap = [
    &["quantization"],
    &["quantisation"],
    &["quantization"],
    &["quantisation"],
];

pub(crate) static ENTRY_QUANTIZED_191687807901136208: VariantsMap = [
    &["quantized"],
    &["quantised"],
    &["quantized"],
    &["quantised"],
];

pub(crate) static ENTRY_QUANTIZERS_12112876514118865032: VariantsMap = [
    &["quantizers"],
    &["quantisers"],
    &["quantizers"],
    &["quantisers"],
];

pub(crate) static ENTRY_QUANTIZER_10076665771116527647: VariantsMap = [
    &["quantizer"],
    &["quantiser"],
    &["quantizer"],
    &["quantiser"],
];

pub(crate) static ENTRY_QUANTIZES_7731963658205656129: VariantsMap = [
    &["quantizes"],
    &["quantises"],
    &["quantizes"],
    &["quantises"],
];

pub(crate) static ENTRY_QUANTIZE_17116602340307321764: VariantsMap =
    [&["quantize"], &["quantise"], &["quantize"], &["quantise"]];

pub(crate) static ENTRY_QUANTIZING_10481986099348319524: VariantsMap = [
    &["quantizing"],
    &["quantising"],
    &["quantizing"],
    &["quantising"],
];

pub(crate) static ENTRY_QUARRELED_15985766844967944821: VariantsMap = [
    &["quarreled"],
    &["quarrelled"],
    &["quarrelled"],
    &["quarrelled"],
];

pub(crate) static ENTRY_QUARRELERS_11216624719057293145: VariantsMap = [
    &["quarrelers"],
    &["quarrellers"],
    &["quarrellers"],
    &["quarrellers"],
];

pub(crate) static ENTRY_QUARRELER_14446710496260840710: VariantsMap = [
    &["quarreler"],
    &["quarreller"],
    &["quarreller"],
    &["quarreller"],
];

pub(crate) static ENTRY_QUARRELING_14209000824927192944: VariantsMap = [
    &["quarreling"],
    &["quarrelling"],
    &["quarrelling"],
    &["quarrelling"],
];

pub(crate) static ENTRY_QUARRELOUS_4829001542031065451: VariantsMap = [
    &["quarrelous"],
    &["quarrellous"],
    &["quarrellous"],
    &["quarrellous"],
];

pub(crate) static ENTRY_QUARTERIZATIONS_11825260088632494839: VariantsMap = [
    &["quarterizations"],
    &["quarterisations"],
    &["quarterizations"],
    &["quarterisations"],
];

pub(crate) static ENTRY_QUARTERIZATION_8280402932685165689: VariantsMap = [
    &["quarterization"],
    &["quarterisation"],
    &["quarterization"],
    &["quarterisation"],
];

pub(crate) static ENTRY_QUATERS_2526447849750605551: VariantsMap =
    [&["quaters"], &["quatres"], &["quatres"], &["quatres"]];

pub(crate) static ENTRY_QUERELE_9438416090405216166: VariantsMap =
    [&["querele"], &["querelae"], &["querelae"], &["querelae"]];

pub(crate) static ENTRY_QUESTIONARIES_14112072398132498455: VariantsMap = [
    &["questionaries"],
    &["quaestionaries"],
    &["quaestionaries"],
    &["quaestionaries"],
];

pub(crate) static ENTRY_QUESTIONARY_3937811141146454597: VariantsMap = [
    &["questionary"],
    &["quaestionary"],
    &["quaestionary"],
    &["quaestionary"],
];

pub(crate) static ENTRY_QUESTORIAL_17326734910194857691: VariantsMap = [
    &["questorial"],
    &["quaestorial"],
    &["quaestorial"],
    &["quaestorial"],
];

pub(crate) static ENTRY_QUESTORSHIP_15494085821790686854: VariantsMap = [
    &["questorship"],
    &["quaestorship"],
    &["quaestorship"],
    &["quaestorship"],
];

pub(crate) static ENTRY_QUEUING_8138344236437954477: VariantsMap =
    [&["queuing"], &["queuing"], &["queuing"], &["queuing"]];

pub(crate) static ENTRY_QUE_13140225885135664317: VariantsMap =
    [&["que"], &["quae"], &["quae"], &["quae"]];

pub(crate) static ENTRY_QUININIZES_12729565422121835336: VariantsMap = [
    &["quininizes"],
    &["quininises"],
    &["quininizes"],
    &["quininises"],
];

pub(crate) static ENTRY_QUININIZE_17096362566529931559: VariantsMap = [
    &["quininize"],
    &["quininise"],
    &["quininize"],
    &["quininise"],
];

pub(crate) static ENTRY_QUINTESSENTIALIZED_13415832374097191642: VariantsMap = [
    &["quintessentialized"],
    &["quintessentialised"],
    &["quintessentialized"],
    &["quintessentialised"],
];

pub(crate) static ENTRY_QUINTESSENTIALIZES_9197519715821715432: VariantsMap = [
    &["quintessentializes"],
    &["quintessentialises"],
    &["quintessentializes"],
    &["quintessentialises"],
];

pub(crate) static ENTRY_QUINTESSENTIALIZE_16551571696077174150: VariantsMap = [
    &["quintessentialize"],
    &["quintessentialise"],
    &["quintessentialize"],
    &["quintessentialise"],
];

pub(crate) static ENTRY_QUINTESSENTIALIZING_17194024065213552996: VariantsMap = [
    &["quintessentializing"],
    &["quintessentialising"],
    &["quintessentializing"],
    &["quintessentialising"],
];

pub(crate) static ENTRY_RACEMIZATIONS_12310534806043247350: VariantsMap = [
    &["racemizations"],
    &["racemisations"],
    &["racemizations"],
    &["racemisations"],
];

pub(crate) static ENTRY_RACEMIZATION_9371693322902504373: VariantsMap = [
    &["racemization"],
    &["racemisation"],
    &["racemization"],
    &["racemisation"],
];

pub(crate) static ENTRY_RACEMIZED_9677793823006904997: VariantsMap = [
    &["racemized"],
    &["racemised"],
    &["racemized"],
    &["racemised"],
];

pub(crate) static ENTRY_RACEMIZES_10597386031959072058: VariantsMap = [
    &["racemizes"],
    &["racemises"],
    &["racemizes"],
    &["racemises"],
];

pub(crate) static ENTRY_RACEMIZE_3054918782672213541: VariantsMap =
    [&["racemize"], &["racemise"], &["racemize"], &["racemise"]];

pub(crate) static ENTRY_RACEMIZING_5309342562156096170: VariantsMap = [
    &["racemizing"],
    &["racemising"],
    &["racemizing"],
    &["racemising"],
];

pub(crate) static ENTRY_RACIALIZATIONS_9543941027629116033: VariantsMap = [
    &["racializations"],
    &["racialisations"],
    &["racializations"],
    &["racialisations"],
];

pub(crate) static ENTRY_RACIALIZATION_12563934097397087336: VariantsMap = [
    &["racialization"],
    &["racialisation"],
    &["racialization"],
    &["racialisation"],
];

pub(crate) static ENTRY_RACIALIZES_2119895632298352154: VariantsMap = [
    &["racializes"],
    &["racialises"],
    &["racializes"],
    &["racialises"],
];

pub(crate) static ENTRY_RACIALIZE_3649756850548033240: VariantsMap = [
    &["racialize"],
    &["racialise"],
    &["racialize"],
    &["racialise"],
];

pub(crate) static ENTRY_RADBORNE_3041954533932383584: VariantsMap = [
    &["radborne"],
    &["radbourne"],
    &["radbourne"],
    &["radbourne"],
];

pub(crate) static ENTRY_RADIALIZATIONS_10502594546253256068: VariantsMap = [
    &["radializations"],
    &["radialisations"],
    &["radializations"],
    &["radialisations"],
];

pub(crate) static ENTRY_RADIALIZATION_18383971186210393104: VariantsMap = [
    &["radialization"],
    &["radialisation"],
    &["radialization"],
    &["radialisation"],
];

pub(crate) static ENTRY_RADIALIZED_4237438878600149477: VariantsMap = [
    &["radialized"],
    &["radialised"],
    &["radialized"],
    &["radialised"],
];

pub(crate) static ENTRY_RADIALIZES_12634635863472551020: VariantsMap = [
    &["radializes"],
    &["radialises"],
    &["radializes"],
    &["radialises"],
];

pub(crate) static ENTRY_RADIALIZE_8311173565044984666: VariantsMap = [
    &["radialize"],
    &["radialise"],
    &["radialize"],
    &["radialise"],
];

pub(crate) static ENTRY_RADIALIZING_16490137149663325926: VariantsMap = [
    &["radializing"],
    &["radialising"],
    &["radializing"],
    &["radialising"],
];

pub(crate) static ENTRY_RADICALIZATIONS_11340536761047241964: VariantsMap = [
    &["radicalizations"],
    &["radicalisations"],
    &["radicalizations"],
    &["radicalisations"],
];

pub(crate) static ENTRY_RADICALIZATION_13110894594007945745: VariantsMap = [
    &["radicalization"],
    &["radicalisation"],
    &["radicalization"],
    &["radicalisation"],
];

pub(crate) static ENTRY_RADICALIZED_16178051502331122105: VariantsMap = [
    &["radicalized"],
    &["radicalised"],
    &["radicalized"],
    &["radicalised"],
];

pub(crate) static ENTRY_RADICALIZES_7656516679067813609: VariantsMap = [
    &["radicalizes"],
    &["radicalises"],
    &["radicalizes"],
    &["radicalises"],
];

pub(crate) static ENTRY_RADICALIZE_10054640819610183612: VariantsMap = [
    &["radicalize"],
    &["radicalise"],
    &["radicalize"],
    &["radicalise"],
];

pub(crate) static ENTRY_RADICALIZING_9302352701494268209: VariantsMap = [
    &["radicalizing"],
    &["radicalising"],
    &["radicalizing"],
    &["radicalising"],
];

pub(crate) static ENTRY_RADIOPASTEURIZATION_15447663133364104406: VariantsMap = [
    &["radiopasteurization"],
    &["radiopasteurisation"],
    &["radiopasteurization"],
    &["radiopasteurisation"],
];

pub(crate) static ENTRY_RADIOSENSITIZED_3133459093835999280: VariantsMap = [
    &["radiosensitized"],
    &["radiosensitised"],
    &["radiosensitized"],
    &["radiosensitised"],
];

pub(crate) static ENTRY_RADIOSENSITIZES_5205828049305600755: VariantsMap = [
    &["radiosensitizes"],
    &["radiosensitises"],
    &["radiosensitizes"],
    &["radiosensitises"],
];

pub(crate) static ENTRY_RADIOSENSITIZE_10576583280478170080: VariantsMap = [
    &["radiosensitize"],
    &["radiosensitise"],
    &["radiosensitize"],
    &["radiosensitise"],
];

pub(crate) static ENTRY_RADIOSENSITIZING_5621538877060197152: VariantsMap = [
    &["radiosensitizing"],
    &["radiosensitising"],
    &["radiosensitizing"],
    &["radiosensitising"],
];

pub(crate) static ENTRY_RADIOSTERILIZATION_5746202029644240544: VariantsMap = [
    &["radiosterilization"],
    &["radiosterilisation"],
    &["radiosterilization"],
    &["radiosterilisation"],
];

pub(crate) static ENTRY_RADIOSTERILIZED_18243964894695163623: VariantsMap = [
    &["radiosterilized"],
    &["radiosterilised"],
    &["radiosterilized"],
    &["radiosterilised"],
];

pub(crate) static ENTRY_RADIOSTERILIZES_1628059493209100984: VariantsMap = [
    &["radiosterilizes"],
    &["radiosterilises"],
    &["radiosterilizes"],
    &["radiosterilises"],
];

pub(crate) static ENTRY_RADIOSTERILIZE_12689946306814556239: VariantsMap = [
    &["radiosterilize"],
    &["radiosterilise"],
    &["radiosterilize"],
    &["radiosterilise"],
];

pub(crate) static ENTRY_RADIOSTERILIZING_15523793208987281845: VariantsMap = [
    &["radiosterilizing"],
    &["radiosterilising"],
    &["radiosterilizing"],
    &["radiosterilising"],
];

pub(crate) static ENTRY_RADIUMIZATIONS_7650953693255078336: VariantsMap = [
    &["radiumizations"],
    &["radiumisations"],
    &["radiumizations"],
    &["radiumisations"],
];

pub(crate) static ENTRY_RADIUMIZATION_602043437160535636: VariantsMap = [
    &["radiumization"],
    &["radiumisation"],
    &["radiumization"],
    &["radiumisation"],
];

pub(crate) static ENTRY_RADIUMIZES_5319143397967858483: VariantsMap = [
    &["radiumizes"],
    &["radiumises"],
    &["radiumizes"],
    &["radiumises"],
];

pub(crate) static ENTRY_RADIUMIZE_11607458329799776620: VariantsMap = [
    &["radiumize"],
    &["radiumise"],
    &["radiumize"],
    &["radiumise"],
];

pub(crate) static ENTRY_RAME_10158219518261805370: VariantsMap =
    [&["rame"], &["ramae"], &["ramae"], &["ramae"]];

pub(crate) static ENTRY_RAMPIER_3346640046708441849: VariantsMap =
    [&["rampier"], &["rampire"], &["rampire"], &["rampire"]];

pub(crate) static ENTRY_RANCORS_270940283740230206: VariantsMap =
    [&["rancors"], &["rancours"], &["rancours"], &["rancours"]];

pub(crate) static ENTRY_RANCOR_9356695782734834392: VariantsMap =
    [&["rancor"], &["rancour"], &["rancour"], &["rancour"]];

pub(crate) static ENTRY_RANDOMIZATIONS_17321397777946946784: VariantsMap = [
    &["randomizations"],
    &["randomisations"],
    &["randomizations"],
    &["randomisations"],
];

pub(crate) static ENTRY_RANDOMIZATION_3681577253421449588: VariantsMap = [
    &["randomization"],
    &["randomisation"],
    &["randomization"],
    &["randomisation"],
];

pub(crate) static ENTRY_RANDOMIZED_14277029247963491589: VariantsMap = [
    &["randomized"],
    &["randomised"],
    &["randomized"],
    &["randomised"],
];

pub(crate) static ENTRY_RANDOMIZERS_4291017330476860233: VariantsMap = [
    &["randomizers"],
    &["randomisers"],
    &["randomizers"],
    &["randomisers"],
];

pub(crate) static ENTRY_RANDOMIZER_1280923813569790342: VariantsMap = [
    &["randomizer"],
    &["randomiser"],
    &["randomizer"],
    &["randomiser"],
];

pub(crate) static ENTRY_RANDOMIZES_13911797236422860580: VariantsMap = [
    &["randomizes"],
    &["randomises"],
    &["randomizes"],
    &["randomises"],
];

pub(crate) static ENTRY_RANDOMIZE_6072760763688384932: VariantsMap = [
    &["randomize"],
    &["randomise"],
    &["randomize"],
    &["randomise"],
];

pub(crate) static ENTRY_RANDOMIZING_2799378200434038162: VariantsMap = [
    &["randomizing"],
    &["randomising"],
    &["randomizing"],
    &["randomising"],
];

pub(crate) static ENTRY_RAPHE_17614585471421284474: VariantsMap =
    [&["raphe"], &["raphae"], &["raphae"], &["raphae"]];

pub(crate) static ENTRY_RAPHIDE_11826784517180909569: VariantsMap =
    [&["raphide"], &["raphidae"], &["raphidae"], &["raphidae"]];

pub(crate) static ENTRY_RAPTURIZED_2957768997607937781: VariantsMap = [
    &["rapturized"],
    &["rapturised"],
    &["rapturized"],
    &["rapturised"],
];

pub(crate) static ENTRY_RAPTURIZES_10958799811768096836: VariantsMap = [
    &["rapturizes"],
    &["rapturises"],
    &["rapturizes"],
    &["rapturises"],
];

pub(crate) static ENTRY_RAPTURIZE_3642337496632244291: VariantsMap = [
    &["rapturize"],
    &["rapturise"],
    &["rapturize"],
    &["rapturise"],
];

pub(crate) static ENTRY_RAPTURIZING_11292594828989392597: VariantsMap = [
    &["rapturizing"],
    &["rapturising"],
    &["rapturizing"],
    &["rapturising"],
];

pub(crate) static ENTRY_RASCALIZES_3431692090706905594: VariantsMap = [
    &["rascalizes"],
    &["rascalises"],
    &["rascalizes"],
    &["rascalises"],
];

pub(crate) static ENTRY_RASCALIZE_11088984531047771127: VariantsMap = [
    &["rascalize"],
    &["rascalise"],
    &["rascalize"],
    &["rascalise"],
];

pub(crate) static ENTRY_RATIONALIZABLES_13479284365708575735: VariantsMap = [
    &["rationalizables"],
    &["rationalisables"],
    &["rationalizables"],
    &["rationalisables"],
];

pub(crate) static ENTRY_RATIONALIZABLE_13968007634740037455: VariantsMap = [
    &["rationalizable"],
    &["rationalisable"],
    &["rationalizable"],
    &["rationalisable"],
];

pub(crate) static ENTRY_RATIONALIZATIONS_9800744027548504414: VariantsMap = [
    &["rationalizations"],
    &["rationalisations"],
    &["rationalizations"],
    &["rationalisations"],
];

pub(crate) static ENTRY_RATIONALIZATION_15122379068974818074: VariantsMap = [
    &["rationalization"],
    &["rationalisation"],
    &["rationalization"],
    &["rationalisation"],
];

pub(crate) static ENTRY_RATIONALIZED_1971558827219194409: VariantsMap = [
    &["rationalized"],
    &["rationalised"],
    &["rationalized"],
    &["rationalised"],
];

pub(crate) static ENTRY_RATIONALIZERS_14291639036077192937: VariantsMap = [
    &["rationalizers"],
    &["rationalisers"],
    &["rationalizers"],
    &["rationalisers"],
];

pub(crate) static ENTRY_RATIONALIZER_11150960083745833433: VariantsMap = [
    &["rationalizer"],
    &["rationaliser"],
    &["rationalizer"],
    &["rationaliser"],
];

pub(crate) static ENTRY_RATIONALIZES_4247086699247832305: VariantsMap = [
    &["rationalizes"],
    &["rationalises"],
    &["rationalizes"],
    &["rationalises"],
];

pub(crate) static ENTRY_RATIONALIZE_6652701615501848408: VariantsMap = [
    &["rationalize"],
    &["rationalise"],
    &["rationalize"],
    &["rationalise"],
];

pub(crate) static ENTRY_RATIONALIZING_8795870211255807930: VariantsMap = [
    &["rationalizing"],
    &["rationalising"],
    &["rationalizing"],
    &["rationalising"],
];

pub(crate) static ENTRY_RATITE_12860753036335482821: VariantsMap =
    [&["ratite"], &["ratitae"], &["ratitae"], &["ratitae"]];

pub(crate) static ENTRY_RAVELED_9671236154632535117: VariantsMap =
    [&["raveled"], &["ravelled"], &["ravelled"], &["ravelled"]];

pub(crate) static ENTRY_RAVELERS_15963715376836433914: VariantsMap = [
    &["ravelers"],
    &["ravellers"],
    &["ravellers"],
    &["ravellers"],
];

pub(crate) static ENTRY_RAVELER_1875202002762708867: VariantsMap =
    [&["raveler"], &["raveller"], &["raveller"], &["raveller"]];

pub(crate) static ENTRY_RAVELINGS_15784329780600976151: VariantsMap = [
    &["ravelings"],
    &["ravellings"],
    &["ravellings"],
    &["ravellings"],
];

pub(crate) static ENTRY_RAVELING_11765690468894667622: VariantsMap = [
    &["raveling"],
    &["ravelling"],
    &["ravelling"],
    &["ravelling"],
];

pub(crate) static ENTRY_RAVELING_17031636493348292626: VariantsMap = [
    &["raveling"],
    &["ravelling"],
    &["ravelling"],
    &["ravelling"],
];

pub(crate) static ENTRY_REACCLIMATIZATIONS_1759410062674249822: VariantsMap = [
    &["reacclimatizations"],
    &["reacclimatisations"],
    &["reacclimatizations"],
    &["reacclimatisations"],
];

pub(crate) static ENTRY_REACCLIMATIZATION_2957354685459389977: VariantsMap = [
    &["reacclimatization"],
    &["reacclimatisation"],
    &["reacclimatization"],
    &["reacclimatisation"],
];

pub(crate) static ENTRY_REACCLIMATIZED_13074003933896937486: VariantsMap = [
    &["reacclimatized"],
    &["reacclimatised"],
    &["reacclimatized"],
    &["reacclimatised"],
];

pub(crate) static ENTRY_REACCLIMATIZES_2132848089448488857: VariantsMap = [
    &["reacclimatizes"],
    &["reacclimatises"],
    &["reacclimatizes"],
    &["reacclimatises"],
];

pub(crate) static ENTRY_REACCLIMATIZE_8214017527074354751: VariantsMap = [
    &["reacclimatize"],
    &["reacclimatise"],
    &["reacclimatize"],
    &["reacclimatise"],
];

pub(crate) static ENTRY_REACCLIMATIZING_9326049221438472202: VariantsMap = [
    &["reacclimatizing"],
    &["reacclimatising"],
    &["reacclimatizing"],
    &["reacclimatising"],
];

pub(crate) static ENTRY_REACTUALIZES_17893616365972474414: VariantsMap = [
    &["reactualizes"],
    &["reactualises"],
    &["reactualizes"],
    &["reactualises"],
];

pub(crate) static ENTRY_REACTUALIZE_3203135312213485752: VariantsMap = [
    &["reactualize"],
    &["reactualise"],
    &["reactualize"],
    &["reactualise"],
];

pub(crate) static ENTRY_READVERTIZED_17657507769021889566: VariantsMap = [
    &["readvertized"],
    &["readvertised"],
    &["readvertized"],
    &["readvertised"],
];

pub(crate) static ENTRY_READVERTIZE_13794491662836301519: VariantsMap = [
    &["readvertize"],
    &["readvertise"],
    &["readvertize"],
    &["readvertise"],
];

pub(crate) static ENTRY_READVERTIZING_8057785064827564408: VariantsMap = [
    &["readvertizing"],
    &["readvertising"],
    &["readvertizing"],
    &["readvertising"],
];

pub(crate) static ENTRY_REALISTICIZES_8988192173192469177: VariantsMap = [
    &["realisticizes"],
    &["realisticises"],
    &["realisticizes"],
    &["realisticises"],
];

pub(crate) static ENTRY_REALISTICIZE_13401215139227567955: VariantsMap = [
    &["realisticize"],
    &["realisticise"],
    &["realisticize"],
    &["realisticise"],
];

pub(crate) static ENTRY_REALIZABILITIES_13223271680114933460: VariantsMap = [
    &["realizabilities"],
    &["realisabilities"],
    &["realizabilities"],
    &["realisabilities"],
];

pub(crate) static ENTRY_REALIZABILITY_13322425294944377574: VariantsMap = [
    &["realizability"],
    &["realisability"],
    &["realizability"],
    &["realisability"],
];

pub(crate) static ENTRY_REALIZABLENESS_6515553396419609224: VariantsMap = [
    &["realizableness"],
    &["realisableness"],
    &["realizableness"],
    &["realisableness"],
];

pub(crate) static ENTRY_REALIZABLER_14683688646248955937: VariantsMap = [
    &["realizabler"],
    &["realisabler"],
    &["realizabler"],
    &["realisabler"],
];

pub(crate) static ENTRY_REALIZABLEST_2622856111033460976: VariantsMap = [
    &["realizablest"],
    &["realisablest"],
    &["realizablest"],
    &["realisablest"],
];

pub(crate) static ENTRY_REALIZABLES_7049723572386299791: VariantsMap = [
    &["realizables"],
    &["realisables"],
    &["realizables"],
    &["realisables"],
];

pub(crate) static ENTRY_REALIZABLE_10812601608535921771: VariantsMap = [
    &["realizable"],
    &["realisable"],
    &["realizable"],
    &["realisable"],
];

pub(crate) static ENTRY_REALIZABLIES_14651669305923865755: VariantsMap = [
    &["realizablies"],
    &["realisablies"],
    &["realizablies"],
    &["realisablies"],
];

pub(crate) static ENTRY_REALIZABLY_14326441766508324971: VariantsMap = [
    &["realizably"],
    &["realisably"],
    &["realizably"],
    &["realisably"],
];

pub(crate) static ENTRY_REALIZATIONS_12363509003743664991: VariantsMap = [
    &["realizations"],
    &["realisations"],
    &["realizations"],
    &["realisations"],
];

pub(crate) static ENTRY_REALIZATION_17538125674282335558: VariantsMap = [
    &["realization"],
    &["realisation"],
    &["realization"],
    &["realisation"],
];

pub(crate) static ENTRY_REALIZED_16745895995959846860: VariantsMap =
    [&["realized"], &["realised"], &["realized"], &["realised"]];

pub(crate) static ENTRY_REALIZERS_8487572591462819622: VariantsMap = [
    &["realizers"],
    &["realisers"],
    &["realizers"],
    &["realisers"],
];

pub(crate) static ENTRY_REALIZER_1946233796964896252: VariantsMap =
    [&["realizer"], &["realiser"], &["realizer"], &["realiser"]];

pub(crate) static ENTRY_REALIZES_2138970691925381265: VariantsMap =
    [&["realizes"], &["realises"], &["realizes"], &["realises"]];

pub(crate) static ENTRY_REALIZE_16854214244264054056: VariantsMap =
    [&["realize"], &["realise"], &["realize"], &["realise"]];

pub(crate) static ENTRY_REALIZINGLY_12242157990012557248: VariantsMap = [
    &["realizingly"],
    &["realisingly"],
    &["realizingly"],
    &["realisingly"],
];

pub(crate) static ENTRY_REALIZINGS_5530634631066484428: VariantsMap = [
    &["realizings"],
    &["realisings"],
    &["realizings"],
    &["realisings"],
];

pub(crate) static ENTRY_REALIZING_510217803664458507: VariantsMap = [
    &["realizing"],
    &["realising"],
    &["realizing"],
    &["realising"],
];

pub(crate) static ENTRY_REANALYZED_5684089744805187690: VariantsMap = [
    &["reanalyzed"],
    &["reanalysed"],
    &["reanalyzed"],
    &["reanalysed"],
];

pub(crate) static ENTRY_REANALYZERS_18352290434303600135: VariantsMap = [
    &["reanalyzers"],
    &["reanalysers"],
    &["reanalyzers"],
    &["reanalysers"],
];

pub(crate) static ENTRY_REANALYZER_7279112787130410746: VariantsMap = [
    &["reanalyzer"],
    &["reanalyser"],
    &["reanalyzer"],
    &["reanalyser"],
];

pub(crate) static ENTRY_REANALYZES_2618902483948124452: VariantsMap = [
    &["reanalyzes"],
    &["reanalyses"],
    &["reanalyzes"],
    &["reanalyses"],
];

pub(crate) static ENTRY_REANALYZE_1610229560390845063: VariantsMap = [
    &["reanalyze"],
    &["reanalyse"],
    &["reanalyze"],
    &["reanalyse"],
];

pub(crate) static ENTRY_REANALYZING_10344228664173305161: VariantsMap = [
    &["reanalyzing"],
    &["reanalysing"],
    &["reanalyzing"],
    &["reanalysing"],
];

pub(crate) static ENTRY_REANIMALIZES_7317637500851915762: VariantsMap = [
    &["reanimalizes"],
    &["reanimalises"],
    &["reanimalizes"],
    &["reanimalises"],
];

pub(crate) static ENTRY_REANIMALIZE_6983429568354275323: VariantsMap = [
    &["reanimalize"],
    &["reanimalise"],
    &["reanimalize"],
    &["reanimalise"],
];

pub(crate) static ENTRY_REAPOLOGIZES_5630570346849612644: VariantsMap = [
    &["reapologizes"],
    &["reapologises"],
    &["reapologizes"],
    &["reapologises"],
];

pub(crate) static ENTRY_REAPOLOGIZE_11605068466350684535: VariantsMap = [
    &["reapologize"],
    &["reapologise"],
    &["reapologize"],
    &["reapologise"],
];

pub(crate) static ENTRY_REAUTHORIZATIONS_11163266872832391485: VariantsMap = [
    &["reauthorizations"],
    &["reauthorisations"],
    &["reauthorizations"],
    &["reauthorisations"],
];

pub(crate) static ENTRY_REAUTHORIZATION_17955151986421375503: VariantsMap = [
    &["reauthorization"],
    &["reauthorisation"],
    &["reauthorization"],
    &["reauthorisation"],
];

pub(crate) static ENTRY_REAUTHORIZES_7279740540043941481: VariantsMap = [
    &["reauthorizes"],
    &["reauthorises"],
    &["reauthorizes"],
    &["reauthorises"],
];

pub(crate) static ENTRY_REAUTHORIZE_1656466035075118852: VariantsMap = [
    &["reauthorize"],
    &["reauthorise"],
    &["reauthorize"],
    &["reauthorise"],
];

pub(crate) static ENTRY_REBAPTIZATIONS_17812907935091196418: VariantsMap = [
    &["rebaptizations"],
    &["rebaptisations"],
    &["rebaptizations"],
    &["rebaptisations"],
];

pub(crate) static ENTRY_REBAPTIZATION_3181157675116561447: VariantsMap = [
    &["rebaptization"],
    &["rebaptisation"],
    &["rebaptization"],
    &["rebaptisation"],
];

pub(crate) static ENTRY_REBAPTIZED_11796464946138226291: VariantsMap = [
    &["rebaptized"],
    &["rebaptised"],
    &["rebaptized"],
    &["rebaptised"],
];

pub(crate) static ENTRY_REBAPTIZES_17975768782687735566: VariantsMap = [
    &["rebaptizes"],
    &["rebaptises"],
    &["rebaptizes"],
    &["rebaptises"],
];

pub(crate) static ENTRY_REBAPTIZE_8763418228695127451: VariantsMap = [
    &["rebaptize"],
    &["rebaptise"],
    &["rebaptize"],
    &["rebaptise"],
];

pub(crate) static ENTRY_REBAPTIZING_15159798223591665010: VariantsMap = [
    &["rebaptizing"],
    &["rebaptising"],
    &["rebaptizing"],
    &["rebaptising"],
];

pub(crate) static ENTRY_REBOURBONIZES_76067254702802558: VariantsMap = [
    &["rebourbonizes"],
    &["rebourbonises"],
    &["rebourbonizes"],
    &["rebourbonises"],
];

pub(crate) static ENTRY_REBOURBONIZE_5536931585817561068: VariantsMap = [
    &["rebourbonize"],
    &["rebourbonise"],
    &["rebourbonize"],
    &["rebourbonise"],
];

pub(crate) static ENTRY_REBRUTALIZES_3911771308757750270: VariantsMap = [
    &["rebrutalizes"],
    &["rebrutalises"],
    &["rebrutalizes"],
    &["rebrutalises"],
];

pub(crate) static ENTRY_REBRUTALIZE_15615381416038865669: VariantsMap = [
    &["rebrutalize"],
    &["rebrutalise"],
    &["rebrutalize"],
    &["rebrutalise"],
];

pub(crate) static ENTRY_RECANALIZATION_4336985207748089706: VariantsMap = [
    &["recanalization"],
    &["recanalisation"],
    &["recanalization"],
    &["recanalisation"],
];

pub(crate) static ENTRY_RECAPITALIZATIONS_4437798653748561592: VariantsMap = [
    &["recapitalizations"],
    &["recapitalisations"],
    &["recapitalizations"],
    &["recapitalisations"],
];

pub(crate) static ENTRY_RECAPITALIZATION_10508729055647744364: VariantsMap = [
    &["recapitalization"],
    &["recapitalisation"],
    &["recapitalization"],
    &["recapitalisation"],
];

pub(crate) static ENTRY_RECAPITALIZED_14061551312028988978: VariantsMap = [
    &["recapitalized"],
    &["recapitalised"],
    &["recapitalized"],
    &["recapitalised"],
];

pub(crate) static ENTRY_RECAPITALIZES_15012732459360105212: VariantsMap = [
    &["recapitalizes"],
    &["recapitalises"],
    &["recapitalizes"],
    &["recapitalises"],
];

pub(crate) static ENTRY_RECAPITALIZE_7414811184860400912: VariantsMap = [
    &["recapitalize"],
    &["recapitalise"],
    &["recapitalize"],
    &["recapitalise"],
];

pub(crate) static ENTRY_RECAPITALIZING_11777631663823328319: VariantsMap = [
    &["recapitalizing"],
    &["recapitalising"],
    &["recapitalizing"],
    &["recapitalising"],
];

pub(crate) static ENTRY_RECARBONIZATIONS_7855928618560079253: VariantsMap = [
    &["recarbonizations"],
    &["recarbonisations"],
    &["recarbonizations"],
    &["recarbonisations"],
];

pub(crate) static ENTRY_RECARBONIZATION_17410364536713786606: VariantsMap = [
    &["recarbonization"],
    &["recarbonisation"],
    &["recarbonization"],
    &["recarbonisation"],
];

pub(crate) static ENTRY_RECARBONIZERS_16664024814142242342: VariantsMap = [
    &["recarbonizers"],
    &["recarbonisers"],
    &["recarbonizers"],
    &["recarbonisers"],
];

pub(crate) static ENTRY_RECARBONIZER_583963286812209805: VariantsMap = [
    &["recarbonizer"],
    &["recarboniser"],
    &["recarbonizer"],
    &["recarboniser"],
];

pub(crate) static ENTRY_RECARBONIZES_1917047137495020788: VariantsMap = [
    &["recarbonizes"],
    &["recarbonises"],
    &["recarbonizes"],
    &["recarbonises"],
];

pub(crate) static ENTRY_RECARBONIZE_11574813584574021407: VariantsMap = [
    &["recarbonize"],
    &["recarbonise"],
    &["recarbonize"],
    &["recarbonise"],
];

pub(crate) static ENTRY_RECATEGORIZED_4396871015069911592: VariantsMap = [
    &["recategorized"],
    &["recategorised"],
    &["recategorized"],
    &["recategorised"],
];

pub(crate) static ENTRY_RECAUSTICIZES_8611668027402828974: VariantsMap = [
    &["recausticizes"],
    &["recausticises"],
    &["recausticizes"],
    &["recausticises"],
];

pub(crate) static ENTRY_RECAUSTICIZE_6187488483013956168: VariantsMap = [
    &["recausticize"],
    &["recausticise"],
    &["recausticize"],
    &["recausticise"],
];

pub(crate) static ENTRY_RECENTRALIZATIONS_17645646173969394267: VariantsMap = [
    &["recentralizations"],
    &["recentralisations"],
    &["recentralizations"],
    &["recentralisations"],
];

pub(crate) static ENTRY_RECENTRALIZATION_4468587086381460845: VariantsMap = [
    &["recentralization"],
    &["recentralisation"],
    &["recentralization"],
    &["recentralisation"],
];

pub(crate) static ENTRY_RECENTRALIZES_3639828701303018823: VariantsMap = [
    &["recentralizes"],
    &["recentralises"],
    &["recentralizes"],
    &["recentralises"],
];

pub(crate) static ENTRY_RECENTRALIZE_5617717555693360915: VariantsMap = [
    &["recentralize"],
    &["recentralise"],
    &["recentralize"],
    &["recentralise"],
];

pub(crate) static ENTRY_RECERCELE_9448895248888457782: VariantsMap = [
    &["recercele"],
    &["recercelae"],
    &["recercelae"],
    &["recercelae"],
];

pub(crate) static ENTRY_RECIPROCALIZES_14749039714160587750: VariantsMap = [
    &["reciprocalizes"],
    &["reciprocalises"],
    &["reciprocalizes"],
    &["reciprocalises"],
];

pub(crate) static ENTRY_RECIPROCALIZE_8911765288022758420: VariantsMap = [
    &["reciprocalize"],
    &["reciprocalise"],
    &["reciprocalize"],
    &["reciprocalise"],
];

pub(crate) static ENTRY_RECIVILIZATIONS_9694916523307178397: VariantsMap = [
    &["recivilizations"],
    &["recivilisations"],
    &["recivilizations"],
    &["recivilisations"],
];

pub(crate) static ENTRY_RECIVILIZATION_11740291015500736416: VariantsMap = [
    &["recivilization"],
    &["recivilisation"],
    &["recivilization"],
    &["recivilisation"],
];

pub(crate) static ENTRY_RECIVILIZES_15097987385833073137: VariantsMap = [
    &["recivilizes"],
    &["recivilises"],
    &["recivilizes"],
    &["recivilises"],
];

pub(crate) static ENTRY_RECIVILIZE_10748548005142278107: VariantsMap = [
    &["recivilize"],
    &["recivilise"],
    &["recivilize"],
    &["recivilise"],
];

pub(crate) static ENTRY_RECOGNIZABILITY_10357285971929431711: VariantsMap = [
    &["recognizability"],
    &["recognisability"],
    &["recognizability"],
    &["recognisability"],
];

pub(crate) static ENTRY_RECOGNIZABLER_4263942192681001064: VariantsMap = [
    &["recognizabler"],
    &["recognisabler"],
    &["recognizabler"],
    &["recognisabler"],
];

pub(crate) static ENTRY_RECOGNIZABLEST_4777556240445602065: VariantsMap = [
    &["recognizablest"],
    &["recognisablest"],
    &["recognizablest"],
    &["recognisablest"],
];

pub(crate) static ENTRY_RECOGNIZABLE_7613722258514271208: VariantsMap = [
    &["recognizable"],
    &["recognisable"],
    &["recognizable"],
    &["recognisable"],
];

pub(crate) static ENTRY_RECOGNIZABLY_5262242687840057985: VariantsMap = [
    &["recognizably"],
    &["recognisably"],
    &["recognizably"],
    &["recognisably"],
];

pub(crate) static ENTRY_RECOGNIZANCES_1889737239613628316: VariantsMap = [
    &["recognizances"],
    &["recognisances"],
    &["recognizances"],
    &["recognisances"],
];

pub(crate) static ENTRY_RECOGNIZANCE_4728169876554590520: VariantsMap = [
    &["recognizance"],
    &["recognisance"],
    &["recognizance"],
    &["recognisance"],
];

pub(crate) static ENTRY_RECOGNIZEDLIES_10785782978004508775: VariantsMap = [
    &["recognizedlies"],
    &["recognisedlies"],
    &["recognizedlies"],
    &["recognisedlies"],
];

pub(crate) static ENTRY_RECOGNIZEDLY_1378498050623081604: VariantsMap = [
    &["recognizedly"],
    &["recognisedly"],
    &["recognizedly"],
    &["recognisedly"],
];

pub(crate) static ENTRY_RECOGNIZED_8994678971763803574: VariantsMap = [
    &["recognized"],
    &["recognised"],
    &["recognized"],
    &["recognised"],
];

pub(crate) static ENTRY_RECOGNIZERS_12071383181262313264: VariantsMap = [
    &["recognizers"],
    &["recognisers"],
    &["recognizers"],
    &["recognisers"],
];

pub(crate) static ENTRY_RECOGNIZER_8837107831671387344: VariantsMap = [
    &["recognizer"],
    &["recogniser"],
    &["recognizer"],
    &["recogniser"],
];

pub(crate) static ENTRY_RECOGNIZES_4631719440910592363: VariantsMap = [
    &["recognizes"],
    &["recognises"],
    &["recognizes"],
    &["recognises"],
];

pub(crate) static ENTRY_RECOGNIZE_2951534439364429088: VariantsMap = [
    &["recognize"],
    &["recognise"],
    &["recognize"],
    &["recognise"],
];

pub(crate) static ENTRY_RECOGNIZINGLIES_10760710242279148374: VariantsMap = [
    &["recognizinglies"],
    &["recognisinglies"],
    &["recognizinglies"],
    &["recognisinglies"],
];

pub(crate) static ENTRY_RECOGNIZINGLY_3477993105941224267: VariantsMap = [
    &["recognizingly"],
    &["recognisingly"],
    &["recognizingly"],
    &["recognisingly"],
];

pub(crate) static ENTRY_RECOGNIZING_7647130431971528373: VariantsMap = [
    &["recognizing"],
    &["recognising"],
    &["recognizing"],
    &["recognising"],
];

pub(crate) static ENTRY_RECOLONIZATIONS_1558253647578378818: VariantsMap = [
    &["recolonizations"],
    &["recolonisations"],
    &["recolonizations"],
    &["recolonisations"],
];

pub(crate) static ENTRY_RECOLONIZATION_6967476021876992825: VariantsMap = [
    &["recolonization"],
    &["recolonisation"],
    &["recolonization"],
    &["recolonisation"],
];

pub(crate) static ENTRY_RECOLONIZED_13885306844450340179: VariantsMap = [
    &["recolonized"],
    &["recolonised"],
    &["recolonized"],
    &["recolonised"],
];

pub(crate) static ENTRY_RECOLONIZES_2544530612567301872: VariantsMap = [
    &["recolonizes"],
    &["recolonises"],
    &["recolonizes"],
    &["recolonises"],
];

pub(crate) static ENTRY_RECOLONIZE_8041961132234757613: VariantsMap = [
    &["recolonize"],
    &["recolonise"],
    &["recolonize"],
    &["recolonise"],
];

pub(crate) static ENTRY_RECOLONIZING_4581044221369467580: VariantsMap = [
    &["recolonizing"],
    &["recolonising"],
    &["recolonizing"],
    &["recolonising"],
];

pub(crate) static ENTRY_RECOLORATIONS_7653541374003132098: VariantsMap = [
    &["recolorations"],
    &["recolourations"],
    &["recolourations"],
    &["recolourations"],
];

pub(crate) static ENTRY_RECOLORATION_8940303655719757865: VariantsMap = [
    &["recoloration"],
    &["recolouration"],
    &["recolouration"],
    &["recolouration"],
];

pub(crate) static ENTRY_RECOLORED_15377054535466872394: VariantsMap = [
    &["recolored"],
    &["recoloured"],
    &["recoloured"],
    &["recoloured"],
];

pub(crate) static ENTRY_RECOLORING_2640269906145220161: VariantsMap = [
    &["recoloring"],
    &["recolouring"],
    &["recolouring"],
    &["recolouring"],
];

pub(crate) static ENTRY_RECOLORS_12626939234404298398: VariantsMap = [
    &["recolors"],
    &["recolours"],
    &["recolours"],
    &["recolours"],
];

pub(crate) static ENTRY_RECOLOR_618293369258486297: VariantsMap =
    [&["recolor"], &["recolour"], &["recolour"], &["recolour"]];

pub(crate) static ENTRY_RECONCEPTUALIZATION_5115077883005130043: VariantsMap = [
    &["reconceptualization"],
    &["reconceptualisation"],
    &["reconceptualization"],
    &["reconceptualisation"],
];

pub(crate) static ENTRY_RECONCEPTUALIZING_7225078240238716102: VariantsMap = [
    &["reconceptualizing"],
    &["reconceptualising"],
    &["reconceptualizing"],
    &["reconceptualising"],
];

pub(crate) static ENTRY_RECONNOITERED_2213490465207030464: VariantsMap = [
    &["reconnoitered"],
    &["reconnoitred"],
    &["reconnoitred"],
    &["reconnoitred"],
];

pub(crate) static ENTRY_RECONNOITERERS_10708801058031695478: VariantsMap = [
    &["reconnoiterers"],
    &["reconnoitrers"],
    &["reconnoitrers"],
    &["reconnoitrers"],
];

pub(crate) static ENTRY_RECONNOITERER_15649698041969515450: VariantsMap = [
    &["reconnoiterer"],
    &["reconnoitrer"],
    &["reconnoitrer"],
    &["reconnoitrer"],
];

pub(crate) static ENTRY_RECONNOITERING_445941575931390448: VariantsMap = [
    &["reconnoitering"],
    &["reconnoitring"],
    &["reconnoitring"],
    &["reconnoitring"],
];

pub(crate) static ENTRY_RECONNOITERS_525334200628355206: VariantsMap = [
    &["reconnoiters"],
    &["reconnoitres"],
    &["reconnoitres"],
    &["reconnoitres"],
];

pub(crate) static ENTRY_RECONNOITER_5276997216676634421: VariantsMap = [
    &["reconnoiter"],
    &["reconnoitre"],
    &["reconnoitre"],
    &["reconnoitre"],
];

pub(crate) static ENTRY_RECRITICIZES_5757238584671293335: VariantsMap = [
    &["recriticizes"],
    &["recriticises"],
    &["recriticizes"],
    &["recriticises"],
];

pub(crate) static ENTRY_RECRITICIZE_7964740355475163401: VariantsMap = [
    &["recriticize"],
    &["recriticise"],
    &["recriticize"],
    &["recriticise"],
];

pub(crate) static ENTRY_RECRYSTALLIZATIONS_18324758641447629783: VariantsMap = [
    &["recrystallizations"],
    &["recrystallisations"],
    &["recrystallizations"],
    &["recrystallisations"],
];

pub(crate) static ENTRY_RECRYSTALLIZATION_14277360853186621414: VariantsMap = [
    &["recrystallization"],
    &["recrystallisation"],
    &["recrystallization"],
    &["recrystallisation"],
];

pub(crate) static ENTRY_RECRYSTALLIZED_3447073258705239305: VariantsMap = [
    &["recrystallized"],
    &["recrystallised"],
    &["recrystallized"],
    &["recrystallised"],
];

pub(crate) static ENTRY_RECRYSTALLIZES_17463114497549275489: VariantsMap = [
    &["recrystallizes"],
    &["recrystallises"],
    &["recrystallizes"],
    &["recrystallises"],
];

pub(crate) static ENTRY_RECRYSTALLIZE_5091534275098388159: VariantsMap = [
    &["recrystallize"],
    &["recrystallise"],
    &["recrystallize"],
    &["recrystallise"],
];

pub(crate) static ENTRY_RECRYSTALLIZING_9560544457842789721: VariantsMap = [
    &["recrystallizing"],
    &["recrystallising"],
    &["recrystallizing"],
    &["recrystallising"],
];

pub(crate) static ENTRY_REDIALED_11643369836594380113: VariantsMap =
    [&["redialed"], &["redialled"], &["redialed"], &["redialled"]];

pub(crate) static ENTRY_REDIALER_5768833298059308208: VariantsMap = [
    &["redialer"],
    &["redialler"],
    &["redialler"],
    &["redialler"],
];

pub(crate) static ENTRY_REDIALING_15990642980268023127: VariantsMap = [
    &["redialing"],
    &["redialling"],
    &["redialing"],
    &["redialling"],
];

pub(crate) static ENTRY_REDISSEIZE_1150055887803215000: VariantsMap = [
    &["redisseize"],
    &["redisseise"],
    &["redisseize"],
    &["redisseise"],
];

pub(crate) static ENTRY_REDISSEIZIN_14496928078206365288: VariantsMap = [
    &["redisseizin"],
    &["redisseisin"],
    &["redisseizin"],
    &["redisseisin"],
];

pub(crate) static ENTRY_REEDIFIED_16744059649461415199: VariantsMap = [
    &["reedified"],
    &["reaedified"],
    &["reaedified"],
    &["reaedified"],
];

pub(crate) static ENTRY_REEDIFIES_1966686662934617271: VariantsMap = [
    &["reedifies"],
    &["reaedifies"],
    &["reaedifies"],
    &["reaedifies"],
];

pub(crate) static ENTRY_REEDIFYING_5914929745473328575: VariantsMap = [
    &["reedifying"],
    &["reaedifying"],
    &["reaedifying"],
    &["reaedifying"],
];

pub(crate) static ENTRY_REEDIFY_5917708217519330521: VariantsMap =
    [&["reedify"], &["reaedify"], &["reaedify"], &["reaedify"]];

pub(crate) static ENTRY_REEMPHASIZED_11315249846841914363: VariantsMap = [
    &["reemphasized"],
    &["reemphasised"],
    &["reemphasized"],
    &["reemphasised"],
];

pub(crate) static ENTRY_REEMPHASIZERS_18299626552564956821: VariantsMap = [
    &["reemphasizers"],
    &["reemphasisers"],
    &["reemphasizers"],
    &["reemphasisers"],
];

pub(crate) static ENTRY_REEMPHASIZER_4949541383479229465: VariantsMap = [
    &["reemphasizer"],
    &["reemphasiser"],
    &["reemphasizer"],
    &["reemphasiser"],
];

pub(crate) static ENTRY_REEMPHASIZES_16400475206506338440: VariantsMap = [
    &["reemphasizes"],
    &["reemphasises"],
    &["reemphasizes"],
    &["reemphasises"],
];

pub(crate) static ENTRY_REEMPHASIZE_2517327899033107994: VariantsMap = [
    &["reemphasize"],
    &["reemphasise"],
    &["reemphasize"],
    &["reemphasise"],
];

pub(crate) static ENTRY_REEMPHASIZING_14767153264578218470: VariantsMap = [
    &["reemphasizing"],
    &["reemphasising"],
    &["reemphasizing"],
    &["reemphasising"],
];

pub(crate) static ENTRY_REENTRANCE_9955645890849905473: VariantsMap = [
    &["reentrance"],
    &["reaentrance"],
    &["reaentrance"],
    &["reaentrance"],
];

pub(crate) static ENTRY_REEXPORTATION_15204503066819424789: VariantsMap = [
    &["reexportation"],
    &["reaexportation"],
    &["reaexportation"],
    &["reaexportation"],
];

pub(crate) static ENTRY_REEXPORTER_3504356768607899599: VariantsMap = [
    &["reexporter"],
    &["reaexporter"],
    &["reaexporter"],
    &["reaexporter"],
];

pub(crate) static ENTRY_REFAVORS_14196253739054548629: VariantsMap = [
    &["refavors"],
    &["refavours"],
    &["refavours"],
    &["refavours"],
];

pub(crate) static ENTRY_REFAVOR_440381483212661455: VariantsMap =
    [&["refavor"], &["refavour"], &["refavour"], &["refavour"]];

pub(crate) static ENTRY_REFERTILIZATIONS_5261991687493344165: VariantsMap = [
    &["refertilizations"],
    &["refertilisations"],
    &["refertilizations"],
    &["refertilisations"],
];

pub(crate) static ENTRY_REFERTILIZATION_676826337167581216: VariantsMap = [
    &["refertilization"],
    &["refertilisation"],
    &["refertilization"],
    &["refertilisation"],
];

pub(crate) static ENTRY_REFERTILIZES_17288465948629672736: VariantsMap = [
    &["refertilizes"],
    &["refertilises"],
    &["refertilizes"],
    &["refertilises"],
];

pub(crate) static ENTRY_REFERTILIZE_17084950143875772419: VariantsMap = [
    &["refertilize"],
    &["refertilise"],
    &["refertilize"],
    &["refertilise"],
];

pub(crate) static ENTRY_REFLECTORIZED_4589985131677101025: VariantsMap = [
    &["reflectorized"],
    &["reflectorised"],
    &["reflectorized"],
    &["reflectorised"],
];

pub(crate) static ENTRY_REFLECTORIZES_12344080187436028943: VariantsMap = [
    &["reflectorizes"],
    &["reflectorises"],
    &["reflectorizes"],
    &["reflectorises"],
];

pub(crate) static ENTRY_REFLECTORIZE_11371162249639935954: VariantsMap = [
    &["reflectorize"],
    &["reflectorise"],
    &["reflectorize"],
    &["reflectorise"],
];

pub(crate) static ENTRY_REFLECTORIZING_5244281938466548182: VariantsMap = [
    &["reflectorizing"],
    &["reflectorising"],
    &["reflectorizing"],
    &["reflectorising"],
];

pub(crate) static ENTRY_REFORESTIZATION_6515267701529405724: VariantsMap = [
    &["reforestization"],
    &["reforestisation"],
    &["reforestization"],
    &["reforestisation"],
];

pub(crate) static ENTRY_REFORESTIZES_11145631211548453896: VariantsMap = [
    &["reforestizes"],
    &["reforestises"],
    &["reforestizes"],
    &["reforestises"],
];

pub(crate) static ENTRY_REFORESTIZE_16668544380286953646: VariantsMap = [
    &["reforestize"],
    &["reforestise"],
    &["reforestize"],
    &["reforestise"],
];

pub(crate) static ENTRY_REFORMADES_15587228082588481869: VariantsMap = [
    &["reformades"],
    &["reformadoes"],
    &["reformadoes"],
    &["reformadoes"],
];

pub(crate) static ENTRY_REFUELED_4168397973029836713: VariantsMap = [
    &["refueled"],
    &["refuelled"],
    &["refuelled"],
    &["refuelled"],
];

pub(crate) static ENTRY_REFUELING_10201954940304240886: VariantsMap = [
    &["refueling"],
    &["refuelling"],
    &["refuelling"],
    &["refuelling"],
];

pub(crate) static ENTRY_REGALIZES_3383647071657330941: VariantsMap = [
    &["regalizes"],
    &["regalises"],
    &["regalizes"],
    &["regalises"],
];

pub(crate) static ENTRY_REGALIZE_18349192053449291058: VariantsMap =
    [&["regalize"], &["regalise"], &["regalize"], &["regalise"]];

pub(crate) static ENTRY_REGALVANIZATIONS_919543378143743050: VariantsMap = [
    &["regalvanizations"],
    &["regalvanisations"],
    &["regalvanizations"],
    &["regalvanisations"],
];

pub(crate) static ENTRY_REGALVANIZATION_14770688122729122519: VariantsMap = [
    &["regalvanization"],
    &["regalvanisation"],
    &["regalvanization"],
    &["regalvanisation"],
];

pub(crate) static ENTRY_REGALVANIZES_304667118914813165: VariantsMap = [
    &["regalvanizes"],
    &["regalvanises"],
    &["regalvanizes"],
    &["regalvanises"],
];

pub(crate) static ENTRY_REGALVANIZE_7301359009315947153: VariantsMap = [
    &["regalvanize"],
    &["regalvanise"],
    &["regalvanize"],
    &["regalvanise"],
];

pub(crate) static ENTRY_REGES_17152610849705018518: VariantsMap =
    [&["reges"], &["regoes"], &["regoes"], &["regoes"]];

pub(crate) static ENTRY_REGIONALIZATIONS_10627536877093646880: VariantsMap = [
    &["regionalizations"],
    &["regionalisations"],
    &["regionalizations"],
    &["regionalisations"],
];

pub(crate) static ENTRY_REGIONALIZATION_16472696414278810321: VariantsMap = [
    &["regionalization"],
    &["regionalisation"],
    &["regionalization"],
    &["regionalisation"],
];

pub(crate) static ENTRY_REGIONALIZED_1480282105596309948: VariantsMap = [
    &["regionalized"],
    &["regionalised"],
    &["regionalized"],
    &["regionalised"],
];

pub(crate) static ENTRY_REGIONALIZES_17696703383650639100: VariantsMap = [
    &["regionalizes"],
    &["regionalises"],
    &["regionalizes"],
    &["regionalises"],
];

pub(crate) static ENTRY_REGIONALIZE_8680940214045371061: VariantsMap = [
    &["regionalize"],
    &["regionalise"],
    &["regionalize"],
    &["regionalise"],
];

pub(crate) static ENTRY_REGIONALIZING_10614276366240882376: VariantsMap = [
    &["regionalizing"],
    &["regionalising"],
    &["regionalizing"],
    &["regionalising"],
];

pub(crate) static ENTRY_REGULARIZATIONS_14630290664482038867: VariantsMap = [
    &["regularizations"],
    &["regularisations"],
    &["regularizations"],
    &["regularisations"],
];

pub(crate) static ENTRY_REGULARIZATION_612324028625749871: VariantsMap = [
    &["regularization"],
    &["regularisation"],
    &["regularization"],
    &["regularisation"],
];

pub(crate) static ENTRY_REGULARIZED_812906416837862635: VariantsMap = [
    &["regularized"],
    &["regularised"],
    &["regularized"],
    &["regularised"],
];

pub(crate) static ENTRY_REGULARIZERS_16153254867995397548: VariantsMap = [
    &["regularizers"],
    &["regularisers"],
    &["regularizers"],
    &["regularisers"],
];

pub(crate) static ENTRY_REGULARIZER_7977815819407633965: VariantsMap = [
    &["regularizer"],
    &["regulariser"],
    &["regularizer"],
    &["regulariser"],
];

pub(crate) static ENTRY_REGULARIZES_12868817085662467445: VariantsMap = [
    &["regularizes"],
    &["regularises"],
    &["regularizes"],
    &["regularises"],
];

pub(crate) static ENTRY_REGULARIZE_1740270232233444369: VariantsMap = [
    &["regularize"],
    &["regularise"],
    &["regularize"],
    &["regularise"],
];

pub(crate) static ENTRY_REGULARIZING_11742129379425728272: VariantsMap = [
    &["regularizing"],
    &["regularising"],
    &["regularizing"],
    &["regularising"],
];

pub(crate) static ENTRY_REGULIZED_17448363826454849500: VariantsMap = [
    &["regulized"],
    &["regulised"],
    &["regulized"],
    &["regulised"],
];

pub(crate) static ENTRY_REGULIZES_5556416535406963250: VariantsMap = [
    &["regulizes"],
    &["regulises"],
    &["regulizes"],
    &["regulises"],
];

pub(crate) static ENTRY_REGULIZE_17135713958101181770: VariantsMap =
    [&["regulize"], &["regulise"], &["regulize"], &["regulise"]];

pub(crate) static ENTRY_REGULIZING_5539648899231396734: VariantsMap = [
    &["regulizing"],
    &["regulising"],
    &["regulizing"],
    &["regulising"],
];

pub(crate) static ENTRY_REHARMONIZATION_17308313781502035145: VariantsMap = [
    &["reharmonization"],
    &["reharmonisation"],
    &["reharmonization"],
    &["reharmonisation"],
];

pub(crate) static ENTRY_REHARMONIZES_3120273689150694896: VariantsMap = [
    &["reharmonizes"],
    &["reharmonises"],
    &["reharmonizes"],
    &["reharmonises"],
];

pub(crate) static ENTRY_REHARMONIZE_16334624218440972733: VariantsMap = [
    &["reharmonize"],
    &["reharmonise"],
    &["reharmonize"],
    &["reharmonise"],
];

pub(crate) static ENTRY_REHM_3696542319302039545: VariantsMap =
    [&["rehm"], &["roehm"], &["roehm"], &["roehm"]];

pub(crate) static ENTRY_REHONORS_18330568768132505982: VariantsMap = [
    &["rehonors"],
    &["rehonours"],
    &["rehonours"],
    &["rehonours"],
];

pub(crate) static ENTRY_REHONOR_1473315212950437033: VariantsMap =
    [&["rehonor"], &["rehonour"], &["rehonour"], &["rehonour"]];

pub(crate) static ENTRY_REHUMANIZATION_918946253825032389: VariantsMap = [
    &["rehumanization"],
    &["rehumanisation"],
    &["rehumanization"],
    &["rehumanisation"],
];

pub(crate) static ENTRY_REHUMANIZES_10927403786683544720: VariantsMap = [
    &["rehumanizes"],
    &["rehumanises"],
    &["rehumanizes"],
    &["rehumanises"],
];

pub(crate) static ENTRY_REHUMANIZE_15895248355910889063: VariantsMap = [
    &["rehumanize"],
    &["rehumanise"],
    &["rehumanize"],
    &["rehumanise"],
];

pub(crate) static ENTRY_REHYBRIDIZES_12835702250917460390: VariantsMap = [
    &["rehybridizes"],
    &["rehybridises"],
    &["rehybridizes"],
    &["rehybridises"],
];

pub(crate) static ENTRY_REHYBRIDIZE_1218918356413465326: VariantsMap = [
    &["rehybridize"],
    &["rehybridise"],
    &["rehybridize"],
    &["rehybridise"],
];

pub(crate) static ENTRY_REINDUSTRIALIZATIONS_8961658400240110657: VariantsMap = [
    &["reindustrializations"],
    &["reindustrialisations"],
    &["reindustrializations"],
    &["reindustrialisations"],
];

pub(crate) static ENTRY_REINDUSTRIALIZATION_14063114145961761637: VariantsMap = [
    &["reindustrialization"],
    &["reindustrialisation"],
    &["reindustrialization"],
    &["reindustrialisation"],
];

pub(crate) static ENTRY_REINDUSTRIALIZED_15225180291686207380: VariantsMap = [
    &["reindustrialized"],
    &["reindustrialised"],
    &["reindustrialized"],
    &["reindustrialised"],
];

pub(crate) static ENTRY_REINDUSTRIALIZES_204913172101098343: VariantsMap = [
    &["reindustrializes"],
    &["reindustrialises"],
    &["reindustrializes"],
    &["reindustrialises"],
];

pub(crate) static ENTRY_REINDUSTRIALIZE_8979958347078953594: VariantsMap = [
    &["reindustrialize"],
    &["reindustrialise"],
    &["reindustrialize"],
    &["reindustrialise"],
];

pub(crate) static ENTRY_REINDUSTRIALIZING_8817124278906281224: VariantsMap = [
    &["reindustrializing"],
    &["reindustrialising"],
    &["reindustrializing"],
    &["reindustrialising"],
];

pub(crate) static ENTRY_REINFORCED_4138373865022379291: VariantsMap = [
    &["reinforced"],
    &["reinforced"],
    &["reinforced"],
    &["reinforced"],
];

pub(crate) static ENTRY_REINFORCES_16061889159840988630: VariantsMap = [
    &["reinforces"],
    &["reinforces"],
    &["reinforces"],
    &["reinforces"],
];

pub(crate) static ENTRY_REINFORCE_7852553905371384184: VariantsMap = [
    &["reinforce"],
    &["reinforce"],
    &["reinforce"],
    &["reinforce"],
];

pub(crate) static ENTRY_REINFORCING_895373427829466869: VariantsMap = [
    &["reinforcing"],
    &["reinforcing"],
    &["reinforcing"],
    &["reinforcing"],
];

pub(crate) static ENTRY_REINITIALIZATION_16441849804286021867: VariantsMap = [
    &["reinitialization"],
    &["reinitialisation"],
    &["reinitialization"],
    &["reinitialisation"],
];

pub(crate) static ENTRY_REINITIALIZED_15858716417914176338: VariantsMap = [
    &["reinitialized"],
    &["reinitialised"],
    &["reinitialized"],
    &["reinitialised"],
];

pub(crate) static ENTRY_REINITIALIZES_2046725879231214867: VariantsMap = [
    &["reinitializes"],
    &["reinitialises"],
    &["reinitializes"],
    &["reinitialises"],
];

pub(crate) static ENTRY_REINITIALIZE_8538870993340819866: VariantsMap = [
    &["reinitialize"],
    &["reinitialise"],
    &["reinitialize"],
    &["reinitialise"],
];

pub(crate) static ENTRY_REINITIALIZING_15549187143453765429: VariantsMap = [
    &["reinitializing"],
    &["reinitialising"],
    &["reinitializing"],
    &["reinitialising"],
];

pub(crate) static ENTRY_REITEMIZES_1352221978277612629: VariantsMap = [
    &["reitemizes"],
    &["reitemises"],
    &["reitemizes"],
    &["reitemises"],
];

pub(crate) static ENTRY_REITEMIZE_156766827430890551: VariantsMap = [
    &["reitemize"],
    &["reitemise"],
    &["reitemize"],
    &["reitemise"],
];

pub(crate) static ENTRY_REJUVENIZED_5208500295865110171: VariantsMap = [
    &["rejuvenized"],
    &["rejuvenised"],
    &["rejuvenized"],
    &["rejuvenised"],
];

pub(crate) static ENTRY_REJUVENIZES_5396862514715717646: VariantsMap = [
    &["rejuvenizes"],
    &["rejuvenises"],
    &["rejuvenizes"],
    &["rejuvenises"],
];

pub(crate) static ENTRY_REJUVENIZE_12105031031242834344: VariantsMap = [
    &["rejuvenize"],
    &["rejuvenise"],
    &["rejuvenize"],
    &["rejuvenise"],
];

pub(crate) static ENTRY_REJUVENIZING_3153196577493666230: VariantsMap = [
    &["rejuvenizing"],
    &["rejuvenising"],
    &["rejuvenizing"],
    &["rejuvenising"],
];

pub(crate) static ENTRY_RELABELED_2578292475214170813: VariantsMap = [
    &["relabeled"],
    &["relabelled"],
    &["relabelled"],
    &["relabelled"],
];

pub(crate) static ENTRY_RELABELERS_16758078482434965857: VariantsMap = [
    &["relabelers"],
    &["relabellers"],
    &["relabellers"],
    &["relabellers"],
];

pub(crate) static ENTRY_RELABELER_15090670262055734242: VariantsMap = [
    &["relabeler"],
    &["relabeller"],
    &["relabeller"],
    &["relabeller"],
];

pub(crate) static ENTRY_RELABELING_5038377902363081991: VariantsMap = [
    &["relabeling"],
    &["relabelling"],
    &["relabelling"],
    &["relabelling"],
];

pub(crate) static ENTRY_RELATIVIZATIONS_5362517281385024225: VariantsMap = [
    &["relativizations"],
    &["relativisations"],
    &["relativizations"],
    &["relativisations"],
];

pub(crate) static ENTRY_RELATIVIZATION_7062869909836897887: VariantsMap = [
    &["relativization"],
    &["relativisation"],
    &["relativization"],
    &["relativisation"],
];

pub(crate) static ENTRY_RELATIVIZED_11759925488764903476: VariantsMap = [
    &["relativized"],
    &["relativised"],
    &["relativized"],
    &["relativised"],
];

pub(crate) static ENTRY_RELATIVIZES_786585049191494591: VariantsMap = [
    &["relativizes"],
    &["relativises"],
    &["relativizes"],
    &["relativises"],
];

pub(crate) static ENTRY_RELATIVIZE_10808045875347801764: VariantsMap = [
    &["relativize"],
    &["relativise"],
    &["relativize"],
    &["relativise"],
];

pub(crate) static ENTRY_RELATIVIZING_1902231948164306511: VariantsMap = [
    &["relativizing"],
    &["relativising"],
    &["relativizing"],
    &["relativising"],
];

pub(crate) static ENTRY_RELIGIONIZED_18310835726693613969: VariantsMap = [
    &["religionized"],
    &["religionised"],
    &["religionized"],
    &["religionised"],
];

pub(crate) static ENTRY_RELIGIONIZES_8491731464364398865: VariantsMap = [
    &["religionizes"],
    &["religionises"],
    &["religionizes"],
    &["religionises"],
];

pub(crate) static ENTRY_RELIGIONIZE_15332825418680356090: VariantsMap = [
    &["religionize"],
    &["religionise"],
    &["religionize"],
    &["religionise"],
];

pub(crate) static ENTRY_RELIGIONIZING_7615913217845991921: VariantsMap = [
    &["religionizing"],
    &["religionising"],
    &["religionizing"],
    &["religionising"],
];

pub(crate) static ENTRY_REMAGNETIZATIONS_4956643680125853179: VariantsMap = [
    &["remagnetizations"],
    &["remagnetisations"],
    &["remagnetizations"],
    &["remagnetisations"],
];

pub(crate) static ENTRY_REMAGNETIZATION_12108075581079874038: VariantsMap = [
    &["remagnetization"],
    &["remagnetisation"],
    &["remagnetization"],
    &["remagnetisation"],
];

pub(crate) static ENTRY_REMAGNETIZES_17679918670334606563: VariantsMap = [
    &["remagnetizes"],
    &["remagnetises"],
    &["remagnetizes"],
    &["remagnetises"],
];

pub(crate) static ENTRY_REMAGNETIZE_9085965881774024693: VariantsMap = [
    &["remagnetize"],
    &["remagnetise"],
    &["remagnetize"],
    &["remagnetise"],
];

pub(crate) static ENTRY_REMATERIALIZED_1799928130089984946: VariantsMap = [
    &["rematerialized"],
    &["rematerialised"],
    &["rematerialized"],
    &["rematerialised"],
];

pub(crate) static ENTRY_REMATERIALIZES_1652697384383833477: VariantsMap = [
    &["rematerializes"],
    &["rematerialises"],
    &["rematerializes"],
    &["rematerialises"],
];

pub(crate) static ENTRY_REMATERIALIZE_17390301741591532210: VariantsMap = [
    &["rematerialize"],
    &["rematerialise"],
    &["rematerialize"],
    &["rematerialise"],
];

pub(crate) static ENTRY_REMEMORIZES_14072378698037238090: VariantsMap = [
    &["rememorizes"],
    &["rememorises"],
    &["rememorizes"],
    &["rememorises"],
];

pub(crate) static ENTRY_REMEMORIZE_16548707727691595328: VariantsMap = [
    &["rememorize"],
    &["rememorise"],
    &["rememorize"],
    &["rememorise"],
];

pub(crate) static ENTRY_REMILITARIZATIONS_531606789856002103: VariantsMap = [
    &["remilitarizations"],
    &["remilitarisations"],
    &["remilitarizations"],
    &["remilitarisations"],
];

pub(crate) static ENTRY_REMILITARIZATION_15249091069445077797: VariantsMap = [
    &["remilitarization"],
    &["remilitarisation"],
    &["remilitarization"],
    &["remilitarisation"],
];

pub(crate) static ENTRY_REMILITARIZED_10537511245367310817: VariantsMap = [
    &["remilitarized"],
    &["remilitarised"],
    &["remilitarized"],
    &["remilitarised"],
];

pub(crate) static ENTRY_REMILITARIZES_17237274561496848809: VariantsMap = [
    &["remilitarizes"],
    &["remilitarises"],
    &["remilitarizes"],
    &["remilitarises"],
];

pub(crate) static ENTRY_REMILITARIZE_14754939446158944749: VariantsMap = [
    &["remilitarize"],
    &["remilitarise"],
    &["remilitarize"],
    &["remilitarise"],
];

pub(crate) static ENTRY_REMILITARIZING_8375538189428365870: VariantsMap = [
    &["remilitarizing"],
    &["remilitarising"],
    &["remilitarizing"],
    &["remilitarising"],
];

pub(crate) static ENTRY_REMINERALIZATIONS_1665273317667343865: VariantsMap = [
    &["remineralizations"],
    &["remineralisations"],
    &["remineralizations"],
    &["remineralisations"],
];

pub(crate) static ENTRY_REMINERALIZATION_9052677584861193778: VariantsMap = [
    &["remineralization"],
    &["remineralisation"],
    &["remineralization"],
    &["remineralisation"],
];

pub(crate) static ENTRY_REMINERALIZED_4335820429382500925: VariantsMap = [
    &["remineralized"],
    &["remineralised"],
    &["remineralized"],
    &["remineralised"],
];

pub(crate) static ENTRY_REMINERALIZES_9596344004419798191: VariantsMap = [
    &["remineralizes"],
    &["remineralises"],
    &["remineralizes"],
    &["remineralises"],
];

pub(crate) static ENTRY_REMINERALIZE_14492190323706730551: VariantsMap = [
    &["remineralize"],
    &["remineralise"],
    &["remineralize"],
    &["remineralise"],
];

pub(crate) static ENTRY_REMINERALIZING_2872679279373295313: VariantsMap = [
    &["remineralizing"],
    &["remineralising"],
    &["remineralizing"],
    &["remineralising"],
];

pub(crate) static ENTRY_REMOBILIZATIONS_9875854726841835980: VariantsMap = [
    &["remobilizations"],
    &["remobilisations"],
    &["remobilizations"],
    &["remobilisations"],
];

pub(crate) static ENTRY_REMOBILIZATION_3911424510662839151: VariantsMap = [
    &["remobilization"],
    &["remobilisation"],
    &["remobilization"],
    &["remobilisation"],
];

pub(crate) static ENTRY_REMOBILIZES_11952460500996091588: VariantsMap = [
    &["remobilizes"],
    &["remobilises"],
    &["remobilizes"],
    &["remobilises"],
];

pub(crate) static ENTRY_REMOBILIZE_15961403419796848444: VariantsMap = [
    &["remobilize"],
    &["remobilise"],
    &["remobilize"],
    &["remobilise"],
];

pub(crate) static ENTRY_REMODELED_12570106397455685821: VariantsMap = [
    &["remodeled"],
    &["remodelled"],
    &["remodelled"],
    &["remodelled"],
];

pub(crate) static ENTRY_REMODELING_4879706051317551240: VariantsMap = [
    &["remodeling"],
    &["remodelling"],
    &["remodelling"],
    &["remodelling"],
];

pub(crate) static ENTRY_REMOLDED_10738250144723767360: VariantsMap = [
    &["remolded"],
    &["remoulded"],
    &["remoulded"],
    &["remoulded"],
];

pub(crate) static ENTRY_REMOLDING_8712026113000611166: VariantsMap = [
    &["remolding"],
    &["remoulding"],
    &["remoulding"],
    &["remoulding"],
];

pub(crate) static ENTRY_REMOLDS_15039385602131518728: VariantsMap =
    [&["remolds"], &["remoulds"], &["remoulds"], &["remoulds"]];

pub(crate) static ENTRY_REMOLD_13068228302489147488: VariantsMap =
    [&["remold"], &["remould"], &["remould"], &["remould"]];

pub(crate) static ENTRY_REMONETIZATIONS_14205365778472515850: VariantsMap = [
    &["remonetizations"],
    &["remonetisations"],
    &["remonetizations"],
    &["remonetisations"],
];

pub(crate) static ENTRY_REMONETIZATION_831081512167517541: VariantsMap = [
    &["remonetization"],
    &["remonetisation"],
    &["remonetization"],
    &["remonetisation"],
];

pub(crate) static ENTRY_REMONETIZED_2395653370814126143: VariantsMap = [
    &["remonetized"],
    &["remonetised"],
    &["remonetized"],
    &["remonetised"],
];

pub(crate) static ENTRY_REMONETIZES_11180625770457207300: VariantsMap = [
    &["remonetizes"],
    &["remonetises"],
    &["remonetizes"],
    &["remonetises"],
];

pub(crate) static ENTRY_REMONETIZE_10990206227698645890: VariantsMap = [
    &["remonetize"],
    &["remonetise"],
    &["remonetize"],
    &["remonetise"],
];

pub(crate) static ENTRY_REMONETIZING_8513334196658791361: VariantsMap = [
    &["remonetizing"],
    &["remonetising"],
    &["remonetizing"],
    &["remonetising"],
];

pub(crate) static ENTRY_REMORALIZATIONS_15063711158296572611: VariantsMap = [
    &["remoralizations"],
    &["remoralisations"],
    &["remoralizations"],
    &["remoralisations"],
];

pub(crate) static ENTRY_REMORALIZATION_7004946949634897130: VariantsMap = [
    &["remoralization"],
    &["remoralisation"],
    &["remoralization"],
    &["remoralisation"],
];

pub(crate) static ENTRY_REMORALIZED_18212275141128252646: VariantsMap = [
    &["remoralized"],
    &["remoralised"],
    &["remoralized"],
    &["remoralised"],
];

pub(crate) static ENTRY_REMORALIZES_3604598684002769634: VariantsMap = [
    &["remoralizes"],
    &["remoralises"],
    &["remoralizes"],
    &["remoralises"],
];

pub(crate) static ENTRY_REMORALIZE_15359671937061114910: VariantsMap = [
    &["remoralize"],
    &["remoralise"],
    &["remoralize"],
    &["remoralise"],
];

pub(crate) static ENTRY_REMORALIZING_6424531846961576072: VariantsMap = [
    &["remoralizing"],
    &["remoralising"],
    &["remoralizing"],
    &["remoralising"],
];

pub(crate) static ENTRY_RENATIONALIZED_2249870200933481729: VariantsMap = [
    &["renationalized"],
    &["renationalised"],
    &["renationalized"],
    &["renationalised"],
];

pub(crate) static ENTRY_RENATIONALIZES_16850633933237806477: VariantsMap = [
    &["renationalizes"],
    &["renationalises"],
    &["renationalizes"],
    &["renationalises"],
];

pub(crate) static ENTRY_RENATIONALIZE_17849451892856589339: VariantsMap = [
    &["renationalize"],
    &["renationalise"],
    &["renationalize"],
    &["renationalise"],
];

pub(crate) static ENTRY_RENATIONALIZING_8517915481673110200: VariantsMap = [
    &["renationalizing"],
    &["renationalising"],
    &["renationalizing"],
    &["renationalising"],
];

pub(crate) static ENTRY_RENCOUNTER_9110752423620509524: VariantsMap = [
    &["rencounter"],
    &["rencontre"],
    &["rencontre"],
    &["rencontre"],
];

pub(crate) static ENTRY_RENFERD_4784459740983886586: VariantsMap =
    [&["renferd"], &["renfred"], &["renfred"], &["renfred"]];

pub(crate) static ENTRY_RENORMALIZATIONS_4425052903321597928: VariantsMap = [
    &["renormalizations"],
    &["renormalisations"],
    &["renormalizations"],
    &["renormalisations"],
];

pub(crate) static ENTRY_RENORMALIZATION_8391867486821314919: VariantsMap = [
    &["renormalization"],
    &["renormalisation"],
    &["renormalization"],
    &["renormalisation"],
];

pub(crate) static ENTRY_RENORMALIZED_8111399403491757307: VariantsMap = [
    &["renormalized"],
    &["renormalised"],
    &["renormalized"],
    &["renormalised"],
];

pub(crate) static ENTRY_RENORMALIZES_11361886570375678072: VariantsMap = [
    &["renormalizes"],
    &["renormalises"],
    &["renormalizes"],
    &["renormalises"],
];

pub(crate) static ENTRY_RENORMALIZE_4416109336888521166: VariantsMap = [
    &["renormalize"],
    &["renormalise"],
    &["renormalize"],
    &["renormalise"],
];

pub(crate) static ENTRY_RENORMALIZING_9450744988355213284: VariantsMap = [
    &["renormalizing"],
    &["renormalising"],
    &["renormalizing"],
    &["renormalising"],
];

pub(crate) static ENTRY_REOBJECTIVIZATIONS_12832085308515471284: VariantsMap = [
    &["reobjectivizations"],
    &["reobjectivisations"],
    &["reobjectivizations"],
    &["reobjectivisations"],
];

pub(crate) static ENTRY_REOBJECTIVIZATION_10107972743956340012: VariantsMap = [
    &["reobjectivization"],
    &["reobjectivisation"],
    &["reobjectivization"],
    &["reobjectivisation"],
];

pub(crate) static ENTRY_REOBJECTIVIZES_6122442709447882043: VariantsMap = [
    &["reobjectivizes"],
    &["reobjectivises"],
    &["reobjectivizes"],
    &["reobjectivises"],
];

pub(crate) static ENTRY_REOBJECTIVIZE_6566624772590074686: VariantsMap = [
    &["reobjectivize"],
    &["reobjectivise"],
    &["reobjectivize"],
    &["reobjectivise"],
];

pub(crate) static ENTRY_REORGANIZATIONAL_12969120263070544967: VariantsMap = [
    &["reorganizational"],
    &["reorganisational"],
    &["reorganizational"],
    &["reorganisational"],
];

pub(crate) static ENTRY_REORGANIZATIONISTS_17830319312761048019: VariantsMap = [
    &["reorganizationists"],
    &["reorganisationists"],
    &["reorganizationists"],
    &["reorganisationists"],
];

pub(crate) static ENTRY_REORGANIZATIONIST_1712329988947469684: VariantsMap = [
    &["reorganizationist"],
    &["reorganisationist"],
    &["reorganizationist"],
    &["reorganisationist"],
];

pub(crate) static ENTRY_REORGANIZATIONS_11667766387551531150: VariantsMap = [
    &["reorganizations"],
    &["reorganisations"],
    &["reorganizations"],
    &["reorganisations"],
];

pub(crate) static ENTRY_REORGANIZATION_1151969410969297489: VariantsMap = [
    &["reorganization"],
    &["reorganisation"],
    &["reorganization"],
    &["reorganisation"],
];

pub(crate) static ENTRY_REORGANIZED_11646562196618885024: VariantsMap = [
    &["reorganized"],
    &["reorganised"],
    &["reorganized"],
    &["reorganised"],
];

pub(crate) static ENTRY_REORGANIZERS_18113843032605671569: VariantsMap = [
    &["reorganizers"],
    &["reorganisers"],
    &["reorganizers"],
    &["reorganisers"],
];

pub(crate) static ENTRY_REORGANIZER_11200739295922273776: VariantsMap = [
    &["reorganizer"],
    &["reorganiser"],
    &["reorganizer"],
    &["reorganiser"],
];

pub(crate) static ENTRY_REORGANIZES_16934615739192478647: VariantsMap = [
    &["reorganizes"],
    &["reorganises"],
    &["reorganizes"],
    &["reorganises"],
];

pub(crate) static ENTRY_REORGANIZE_2389493382480671527: VariantsMap = [
    &["reorganize"],
    &["reorganise"],
    &["reorganize"],
    &["reorganise"],
];

pub(crate) static ENTRY_REORGANIZING_12928416874346171218: VariantsMap = [
    &["reorganizing"],
    &["reorganising"],
    &["reorganizing"],
    &["reorganising"],
];

pub(crate) static ENTRY_REOXIDIZED_16926234084032226889: VariantsMap = [
    &["reoxidized"],
    &["reoxidised"],
    &["reoxidized"],
    &["reoxidised"],
];

pub(crate) static ENTRY_REOXIDIZES_17400786414594541662: VariantsMap = [
    &["reoxidizes"],
    &["reoxidises"],
    &["reoxidizes"],
    &["reoxidises"],
];

pub(crate) static ENTRY_REOXIDIZE_11987238980825996393: VariantsMap = [
    &["reoxidize"],
    &["reoxidise"],
    &["reoxidize"],
    &["reoxidise"],
];

pub(crate) static ENTRY_REOXIDIZING_16376639746858829917: VariantsMap = [
    &["reoxidizing"],
    &["reoxidising"],
    &["reoxidizing"],
    &["reoxidising"],
];

pub(crate) static ENTRY_REOXYGENIZES_881529392879167791: VariantsMap = [
    &["reoxygenizes"],
    &["reoxygenises"],
    &["reoxygenizes"],
    &["reoxygenises"],
];

pub(crate) static ENTRY_REOXYGENIZE_15109191346848713927: VariantsMap = [
    &["reoxygenize"],
    &["reoxygenise"],
    &["reoxygenize"],
    &["reoxygenise"],
];

pub(crate) static ENTRY_REPAGANIZATIONS_14831045305658827434: VariantsMap = [
    &["repaganizations"],
    &["repaganisations"],
    &["repaganizations"],
    &["repaganisations"],
];

pub(crate) static ENTRY_REPAGANIZATION_10722808462424730668: VariantsMap = [
    &["repaganization"],
    &["repaganisation"],
    &["repaganization"],
    &["repaganisation"],
];

pub(crate) static ENTRY_REPAGANIZERS_5457673805973373581: VariantsMap = [
    &["repaganizers"],
    &["repaganisers"],
    &["repaganizers"],
    &["repaganisers"],
];

pub(crate) static ENTRY_REPAGANIZER_17013688811730877026: VariantsMap = [
    &["repaganizer"],
    &["repaganiser"],
    &["repaganizer"],
    &["repaganiser"],
];

pub(crate) static ENTRY_REPAGANIZES_11158057579415390595: VariantsMap = [
    &["repaganizes"],
    &["repaganises"],
    &["repaganizes"],
    &["repaganises"],
];

pub(crate) static ENTRY_REPAGANIZE_15633051587401367664: VariantsMap = [
    &["repaganize"],
    &["repaganise"],
    &["repaganize"],
    &["repaganise"],
];

pub(crate) static ENTRY_REPATRONIZES_6398567070067672365: VariantsMap = [
    &["repatronizes"],
    &["repatronises"],
    &["repatronizes"],
    &["repatronises"],
];

pub(crate) static ENTRY_REPATRONIZE_815740053535532228: VariantsMap = [
    &["repatronize"],
    &["repatronise"],
    &["repatronize"],
    &["repatronise"],
];

pub(crate) static ENTRY_REPERSONALIZE_15402376780199132756: VariantsMap = [
    &["repersonalize"],
    &["repersonalise"],
    &["repersonalize"],
    &["repersonalise"],
];

pub(crate) static ENTRY_REPHOSPHORIZATIONS_12340313224750194997: VariantsMap = [
    &["rephosphorizations"],
    &["rephosphorisations"],
    &["rephosphorizations"],
    &["rephosphorisations"],
];

pub(crate) static ENTRY_REPHOSPHORIZATION_9333856126640113461: VariantsMap = [
    &["rephosphorization"],
    &["rephosphorisation"],
    &["rephosphorization"],
    &["rephosphorisation"],
];

pub(crate) static ENTRY_REPHOSPHORIZES_10207595657667846100: VariantsMap = [
    &["rephosphorizes"],
    &["rephosphorises"],
    &["rephosphorizes"],
    &["rephosphorises"],
];

pub(crate) static ENTRY_REPHOSPHORIZE_8849140144759637290: VariantsMap = [
    &["rephosphorize"],
    &["rephosphorise"],
    &["rephosphorize"],
    &["rephosphorise"],
];

pub(crate) static ENTRY_REPOLYMERIZATIONS_12357293932990101773: VariantsMap = [
    &["repolymerizations"],
    &["repolymerisations"],
    &["repolymerizations"],
    &["repolymerisations"],
];

pub(crate) static ENTRY_REPOLYMERIZATION_4569616079512322793: VariantsMap = [
    &["repolymerization"],
    &["repolymerisation"],
    &["repolymerization"],
    &["repolymerisation"],
];

pub(crate) static ENTRY_REPOLYMERIZES_5749554008771698648: VariantsMap = [
    &["repolymerizes"],
    &["repolymerises"],
    &["repolymerizes"],
    &["repolymerises"],
];

pub(crate) static ENTRY_REPOLYMERIZE_17274626487116515248: VariantsMap = [
    &["repolymerize"],
    &["repolymerise"],
    &["repolymerize"],
    &["repolymerise"],
];

pub(crate) static ENTRY_REPOPULARIZE_14940546663082185084: VariantsMap = [
    &["repopularize"],
    &["repopularise"],
    &["repopularize"],
    &["repopularise"],
];

pub(crate) static ENTRY_REPRIVATIZATIONS_16407372455946700494: VariantsMap = [
    &["reprivatizations"],
    &["reprivatisations"],
    &["reprivatizations"],
    &["reprivatisations"],
];

pub(crate) static ENTRY_REPRIVATIZATION_17472098476399059170: VariantsMap = [
    &["reprivatization"],
    &["reprivatisation"],
    &["reprivatization"],
    &["reprivatisation"],
];

pub(crate) static ENTRY_REPRIVATIZED_10983370266238812583: VariantsMap = [
    &["reprivatized"],
    &["reprivatised"],
    &["reprivatized"],
    &["reprivatised"],
];

pub(crate) static ENTRY_REPRIVATIZES_3010080685531048079: VariantsMap = [
    &["reprivatizes"],
    &["reprivatises"],
    &["reprivatizes"],
    &["reprivatises"],
];

pub(crate) static ENTRY_REPRIVATIZE_9664078646546954379: VariantsMap = [
    &["reprivatize"],
    &["reprivatise"],
    &["reprivatize"],
    &["reprivatise"],
];

pub(crate) static ENTRY_REPRIVATIZING_12502052463163065567: VariantsMap = [
    &["reprivatizing"],
    &["reprivatising"],
    &["reprivatizing"],
    &["reprivatising"],
];

pub(crate) static ENTRY_REPRIZED_9731045061331574876: VariantsMap =
    [&["reprized"], &["reprised"], &["reprized"], &["reprised"]];

pub(crate) static ENTRY_REPROGRAMS_17888173972796244259: VariantsMap = [
    &["reprograms"],
    &["reprograms"],
    &["reprograms"],
    &["reprograms"],
];

pub(crate) static ENTRY_REPROGRAM_11078775064421802261: VariantsMap = [
    &["reprogram"],
    &["reprogram"],
    &["reprogram"],
    &["reprogram"],
];

pub(crate) static ENTRY_REPUBLICANIZATIONS_3818904481431306569: VariantsMap = [
    &["republicanizations"],
    &["republicanisations"],
    &["republicanizations"],
    &["republicanisations"],
];

pub(crate) static ENTRY_REPUBLICANIZATION_10038049154044772944: VariantsMap = [
    &["republicanization"],
    &["republicanisation"],
    &["republicanization"],
    &["republicanisation"],
];

pub(crate) static ENTRY_REPUBLICANIZED_13862085982527150471: VariantsMap = [
    &["republicanized"],
    &["republicanised"],
    &["republicanized"],
    &["republicanised"],
];

pub(crate) static ENTRY_REPUBLICANIZERS_16705289270906196892: VariantsMap = [
    &["republicanizers"],
    &["republicanisers"],
    &["republicanizers"],
    &["republicanisers"],
];

pub(crate) static ENTRY_REPUBLICANIZER_15179876901660882417: VariantsMap = [
    &["republicanizer"],
    &["republicaniser"],
    &["republicanizer"],
    &["republicaniser"],
];

pub(crate) static ENTRY_REPUBLICANIZES_3772351389249623570: VariantsMap = [
    &["republicanizes"],
    &["republicanises"],
    &["republicanizes"],
    &["republicanises"],
];

pub(crate) static ENTRY_REPUBLICANIZE_15644682830452937216: VariantsMap = [
    &["republicanize"],
    &["republicanise"],
    &["republicanize"],
    &["republicanise"],
];

pub(crate) static ENTRY_REPUBLICANIZING_13352721204980193511: VariantsMap = [
    &["republicanizing"],
    &["republicanising"],
    &["republicanizing"],
    &["republicanising"],
];

pub(crate) static ENTRY_REPULVERIZES_16931782906920663266: VariantsMap = [
    &["repulverizes"],
    &["repulverises"],
    &["repulverizes"],
    &["repulverises"],
];

pub(crate) static ENTRY_REPULVERIZE_16485974152085073820: VariantsMap = [
    &["repulverize"],
    &["repulverise"],
    &["repulverize"],
    &["repulverise"],
];

pub(crate) static ENTRY_REROYALIZES_1631845483021508078: VariantsMap = [
    &["reroyalizes"],
    &["reroyalises"],
    &["reroyalizes"],
    &["reroyalises"],
];

pub(crate) static ENTRY_REROYALIZE_1484093252419274152: VariantsMap = [
    &["reroyalize"],
    &["reroyalise"],
    &["reroyalize"],
    &["reroyalise"],
];

pub(crate) static ENTRY_RESEIZER_15625229687087097248: VariantsMap =
    [&["reseizer"], &["reseiser"], &["reseizer"], &["reseiser"]];

pub(crate) static ENTRY_RESEIZE_15699853521189401525: VariantsMap =
    [&["reseize"], &["reseise"], &["reseize"], &["reseise"]];

pub(crate) static ENTRY_RESENSITIZATIONS_1355216907329993341: VariantsMap = [
    &["resensitizations"],
    &["resensitisations"],
    &["resensitizations"],
    &["resensitisations"],
];

pub(crate) static ENTRY_RESENSITIZATION_328250918864571061: VariantsMap = [
    &["resensitization"],
    &["resensitisation"],
    &["resensitization"],
    &["resensitisation"],
];

pub(crate) static ENTRY_RESENSITIZES_174065648769692022: VariantsMap = [
    &["resensitizes"],
    &["resensitises"],
    &["resensitizes"],
    &["resensitises"],
];

pub(crate) static ENTRY_RESENSITIZE_8699626569397120118: VariantsMap = [
    &["resensitize"],
    &["resensitise"],
    &["resensitize"],
    &["resensitise"],
];

pub(crate) static ENTRY_RESEPULCHERS_5499679363891548693: VariantsMap = [
    &["resepulchers"],
    &["resepulchres"],
    &["resepulchres"],
    &["resepulchres"],
];

pub(crate) static ENTRY_RESEPULCHER_17387769772026974673: VariantsMap = [
    &["resepulcher"],
    &["resepulchre"],
    &["resepulchre"],
    &["resepulchre"],
];

pub(crate) static ENTRY_RESHES_5020890085510396612: VariantsMap =
    [&["reshes"], &["reshoes"], &["reshoes"], &["reshoes"]];

pub(crate) static ENTRY_RESINIZED_4777093769847272514: VariantsMap = [
    &["resinized"],
    &["resinised"],
    &["resinized"],
    &["resinised"],
];

pub(crate) static ENTRY_RESINIZES_10912813887426118565: VariantsMap = [
    &["resinizes"],
    &["resinises"],
    &["resinizes"],
    &["resinises"],
];

pub(crate) static ENTRY_RESINIZE_1480770915914903907: VariantsMap =
    [&["resinize"], &["resinise"], &["resinize"], &["resinise"]];

pub(crate) static ENTRY_RESINIZING_6093523061083374265: VariantsMap = [
    &["resinizing"],
    &["resinising"],
    &["resinizing"],
    &["resinising"],
];

pub(crate) static ENTRY_RESOLEMNIZES_15124492163143131014: VariantsMap = [
    &["resolemnizes"],
    &["resolemnises"],
    &["resolemnizes"],
    &["resolemnises"],
];

pub(crate) static ENTRY_RESOLEMNIZE_7621946404155195924: VariantsMap = [
    &["resolemnize"],
    &["resolemnise"],
    &["resolemnize"],
    &["resolemnise"],
];

pub(crate) static ENTRY_RESPECTABILIZED_8954718152460687227: VariantsMap = [
    &["respectabilized"],
    &["respectabilised"],
    &["respectabilized"],
    &["respectabilised"],
];

pub(crate) static ENTRY_RESPECTABILIZES_14381893260923468938: VariantsMap = [
    &["respectabilizes"],
    &["respectabilises"],
    &["respectabilizes"],
    &["respectabilises"],
];

pub(crate) static ENTRY_RESPECTABILIZE_10595326802229476923: VariantsMap = [
    &["respectabilize"],
    &["respectabilise"],
    &["respectabilize"],
    &["respectabilise"],
];

pub(crate) static ENTRY_RESPECTABILIZING_6174060590866761157: VariantsMap = [
    &["respectabilizing"],
    &["respectabilising"],
    &["respectabilizing"],
    &["respectabilising"],
];

pub(crate) static ENTRY_RESTANDARDIZATIONS_11635991554309473900: VariantsMap = [
    &["restandardizations"],
    &["restandardisations"],
    &["restandardizations"],
    &["restandardisations"],
];

pub(crate) static ENTRY_RESTANDARDIZATION_9030893141063647769: VariantsMap = [
    &["restandardization"],
    &["restandardisation"],
    &["restandardization"],
    &["restandardisation"],
];

pub(crate) static ENTRY_RESTANDARDIZES_15236443555135015074: VariantsMap = [
    &["restandardizes"],
    &["restandardises"],
    &["restandardizes"],
    &["restandardises"],
];

pub(crate) static ENTRY_RESTANDARDIZE_6569003756104157164: VariantsMap = [
    &["restandardize"],
    &["restandardise"],
    &["restandardize"],
    &["restandardise"],
];

pub(crate) static ENTRY_RESTERILIZES_14558059425194970009: VariantsMap = [
    &["resterilizes"],
    &["resterilises"],
    &["resterilizes"],
    &["resterilises"],
];

pub(crate) static ENTRY_RESTERILIZE_1058883548124310506: VariantsMap = [
    &["resterilize"],
    &["resterilise"],
    &["resterilize"],
    &["resterilise"],
];

pub(crate) static ENTRY_RESTIGMATIZES_10031838899695361673: VariantsMap = [
    &["restigmatizes"],
    &["restigmatises"],
    &["restigmatizes"],
    &["restigmatises"],
];

pub(crate) static ENTRY_RESTIGMATIZE_9870430244279744417: VariantsMap = [
    &["restigmatize"],
    &["restigmatise"],
    &["restigmatize"],
    &["restigmatise"],
];

pub(crate) static ENTRY_RESURRECTIONIZED_16010155854797625509: VariantsMap = [
    &["resurrectionized"],
    &["resurrectionised"],
    &["resurrectionized"],
    &["resurrectionised"],
];

pub(crate) static ENTRY_RESURRECTIONIZES_4867863049510136884: VariantsMap = [
    &["resurrectionizes"],
    &["resurrectionises"],
    &["resurrectionizes"],
    &["resurrectionises"],
];

pub(crate) static ENTRY_RESURRECTIONIZE_18191101438815173543: VariantsMap = [
    &["resurrectionize"],
    &["resurrectionise"],
    &["resurrectionize"],
    &["resurrectionise"],
];

pub(crate) static ENTRY_RESURRECTIONIZING_9856716748644242638: VariantsMap = [
    &["resurrectionizing"],
    &["resurrectionising"],
    &["resurrectionizing"],
    &["resurrectionising"],
];

pub(crate) static ENTRY_RESYMBOLIZATIONS_2380115742438706012: VariantsMap = [
    &["resymbolizations"],
    &["resymbolisations"],
    &["resymbolizations"],
    &["resymbolisations"],
];

pub(crate) static ENTRY_RESYMBOLIZATION_2100868676093885176: VariantsMap = [
    &["resymbolization"],
    &["resymbolisation"],
    &["resymbolization"],
    &["resymbolisation"],
];

pub(crate) static ENTRY_RESYMBOLIZES_7954720080205261516: VariantsMap = [
    &["resymbolizes"],
    &["resymbolises"],
    &["resymbolizes"],
    &["resymbolises"],
];

pub(crate) static ENTRY_RESYMBOLIZE_8753563960356797081: VariantsMap = [
    &["resymbolize"],
    &["resymbolise"],
    &["resymbolize"],
    &["resymbolise"],
];

pub(crate) static ENTRY_RESYNCHRONIZATIONS_14065477339743221001: VariantsMap = [
    &["resynchronizations"],
    &["resynchronisations"],
    &["resynchronizations"],
    &["resynchronisations"],
];

pub(crate) static ENTRY_RESYNCHRONIZATION_12193175582486124507: VariantsMap = [
    &["resynchronization"],
    &["resynchronisation"],
    &["resynchronization"],
    &["resynchronisation"],
];

pub(crate) static ENTRY_RESYNCHRONIZED_4863905219189490366: VariantsMap = [
    &["resynchronized"],
    &["resynchronised"],
    &["resynchronized"],
    &["resynchronised"],
];

pub(crate) static ENTRY_RESYNCHRONIZES_9271033675927450378: VariantsMap = [
    &["resynchronizes"],
    &["resynchronises"],
    &["resynchronizes"],
    &["resynchronises"],
];

pub(crate) static ENTRY_RESYNCHRONIZE_545307253918691066: VariantsMap = [
    &["resynchronize"],
    &["resynchronise"],
    &["resynchronize"],
    &["resynchronise"],
];

pub(crate) static ENTRY_RESYNCHRONIZING_16185596301498314052: VariantsMap = [
    &["resynchronizing"],
    &["resynchronising"],
    &["resynchronizing"],
    &["resynchronising"],
];

pub(crate) static ENTRY_RESYNTHESIZES_401853670456804331: VariantsMap = [
    &["resynthesizes"],
    &["resynthesises"],
    &["resynthesizes"],
    &["resynthesises"],
];

pub(crate) static ENTRY_RESYNTHESIZE_4007881474356038538: VariantsMap = [
    &["resynthesize"],
    &["resynthesise"],
    &["resynthesize"],
    &["resynthesise"],
];

pub(crate) static ENTRY_RETINIZES_11324886815290155312: VariantsMap = [
    &["retinizes"],
    &["retinises"],
    &["retinizes"],
    &["retinises"],
];

pub(crate) static ENTRY_RETINIZE_17581287987493530595: VariantsMap =
    [&["retinize"], &["retinise"], &["retinize"], &["retinise"]];

pub(crate) static ENTRY_RETINULE_483575137353236213: VariantsMap = [
    &["retinule"],
    &["retinulae"],
    &["retinulae"],
    &["retinulae"],
];

pub(crate) static ENTRY_RETRANQUILIZES_13108673185455158074: VariantsMap = [
    &["retranquilizes"],
    &["retranquilises"],
    &["retranquilizes"],
    &["retranquilises"],
];

pub(crate) static ENTRY_RETRANQUILIZE_2393764178790597866: VariantsMap = [
    &["retranquilize"],
    &["retranquilise"],
    &["retranquilize"],
    &["retranquilise"],
];

pub(crate) static ENTRY_RETROCECAL_12918263239510680574: VariantsMap = [
    &["retrocecal"],
    &["retrocaecal"],
    &["retrocaecal"],
    &["retrocaecal"],
];

pub(crate) static ENTRY_REUTILIZATION_9745892820516663582: VariantsMap = [
    &["reutilization"],
    &["reutilisation"],
    &["reutilization"],
    &["reutilisation"],
];

pub(crate) static ENTRY_REUTILIZED_18168564318255574596: VariantsMap = [
    &["reutilized"],
    &["reutilised"],
    &["reutilized"],
    &["reutilised"],
];

pub(crate) static ENTRY_REUTILIZES_8457401336909667479: VariantsMap = [
    &["reutilizes"],
    &["reutilises"],
    &["reutilizes"],
    &["reutilises"],
];

pub(crate) static ENTRY_REUTILIZE_13673617136512063543: VariantsMap = [
    &["reutilize"],
    &["reutilise"],
    &["reutilize"],
    &["reutilise"],
];

pub(crate) static ENTRY_REUTILIZING_9731337986765731618: VariantsMap = [
    &["reutilizing"],
    &["reutilising"],
    &["reutilizing"],
    &["reutilising"],
];

pub(crate) static ENTRY_REVALORIZATIONS_5122168154265204918: VariantsMap = [
    &["revalorizations"],
    &["revalorisations"],
    &["revalorizations"],
    &["revalorisations"],
];

pub(crate) static ENTRY_REVALORIZATION_5701449448493716997: VariantsMap = [
    &["revalorization"],
    &["revalorisation"],
    &["revalorization"],
    &["revalorisation"],
];

pub(crate) static ENTRY_REVALORIZED_6828044791293710522: VariantsMap = [
    &["revalorized"],
    &["revalorised"],
    &["revalorized"],
    &["revalorised"],
];

pub(crate) static ENTRY_REVALORIZES_10083482437118858511: VariantsMap = [
    &["revalorizes"],
    &["revalorises"],
    &["revalorizes"],
    &["revalorises"],
];

pub(crate) static ENTRY_REVALORIZE_13432734546345955232: VariantsMap = [
    &["revalorize"],
    &["revalorise"],
    &["revalorize"],
    &["revalorise"],
];

pub(crate) static ENTRY_REVALORIZING_5229021357735833367: VariantsMap = [
    &["revalorizing"],
    &["revalorising"],
    &["revalorizing"],
    &["revalorising"],
];

pub(crate) static ENTRY_REVAPORIZATIONS_18170062103842338938: VariantsMap = [
    &["revaporizations"],
    &["revapourisations"],
    &["revaporizations"],
    &["revapourisations"],
];

pub(crate) static ENTRY_REVAPORIZATION_5713403552715329985: VariantsMap = [
    &["revaporization"],
    &["revapourisation"],
    &["revaporization"],
    &["revapourisation"],
];

pub(crate) static ENTRY_REVAPORIZES_4392344872150334367: VariantsMap = [
    &["revaporizes"],
    &["revaporises"],
    &["revaporizes"],
    &["revaporises"],
];

pub(crate) static ENTRY_REVAPORIZE_1420746351021754910: VariantsMap = [
    &["revaporize"],
    &["revaporise"],
    &["revaporize"],
    &["revaporise"],
];

pub(crate) static ENTRY_REVELATIONIZES_7348701606986945383: VariantsMap = [
    &["revelationizes"],
    &["revelationises"],
    &["revelationizes"],
    &["revelationises"],
];

pub(crate) static ENTRY_REVELATIONIZE_2525772824776587394: VariantsMap = [
    &["revelationize"],
    &["revelationise"],
    &["revelationize"],
    &["revelationise"],
];

pub(crate) static ENTRY_REVELED_10192387357620140676: VariantsMap =
    [&["reveled"], &["revelled"], &["revelled"], &["revelled"]];

pub(crate) static ENTRY_REVELERS_9470175687026840: VariantsMap = [
    &["revelers"],
    &["revellers"],
    &["revellers"],
    &["revellers"],
];

pub(crate) static ENTRY_REVELER_8384109924943712265: VariantsMap =
    [&["reveler"], &["reveller"], &["reveller"], &["reveller"]];

pub(crate) static ENTRY_REVELINGS_4220623056617091529: VariantsMap = [
    &["revelings"],
    &["revellings"],
    &["revellings"],
    &["revellings"],
];

pub(crate) static ENTRY_REVELING_59082295884336446: VariantsMap = [
    &["reveling"],
    &["revelling"],
    &["revelling"],
    &["revelling"],
];

pub(crate) static ENTRY_REVIGOR_2801049938904171472: VariantsMap =
    [&["revigor"], &["revigour"], &["revigour"], &["revigour"]];

pub(crate) static ENTRY_REVISUALIZATIONS_12115779584679618149: VariantsMap = [
    &["revisualizations"],
    &["revisualisations"],
    &["revisualizations"],
    &["revisualisations"],
];

pub(crate) static ENTRY_REVISUALIZATION_4385706580546598224: VariantsMap = [
    &["revisualization"],
    &["revisualisation"],
    &["revisualization"],
    &["revisualisation"],
];

pub(crate) static ENTRY_REVISUALIZES_12799696931941951677: VariantsMap = [
    &["revisualizes"],
    &["revisualises"],
    &["revisualizes"],
    &["revisualises"],
];

pub(crate) static ENTRY_REVISUALIZE_1804017224578296798: VariantsMap = [
    &["revisualize"],
    &["revisualise"],
    &["revisualize"],
    &["revisualise"],
];

pub(crate) static ENTRY_REVITALIZATIONS_18307091255909150620: VariantsMap = [
    &["revitalizations"],
    &["revitalisations"],
    &["revitalizations"],
    &["revitalisations"],
];

pub(crate) static ENTRY_REVITALIZATION_16085757167990752927: VariantsMap = [
    &["revitalization"],
    &["revitalisation"],
    &["revitalization"],
    &["revitalisation"],
];

pub(crate) static ENTRY_REVITALIZED_150745644348740042: VariantsMap = [
    &["revitalized"],
    &["revitalised"],
    &["revitalized"],
    &["revitalised"],
];

pub(crate) static ENTRY_REVITALIZERS_3771612271540013270: VariantsMap = [
    &["revitalizers"],
    &["revitalisers"],
    &["revitalizers"],
    &["revitalisers"],
];

pub(crate) static ENTRY_REVITALIZER_3537189352148158886: VariantsMap = [
    &["revitalizer"],
    &["revitaliser"],
    &["revitalizer"],
    &["revitaliser"],
];

pub(crate) static ENTRY_REVITALIZES_636040321623977777: VariantsMap = [
    &["revitalizes"],
    &["revitalises"],
    &["revitalizes"],
    &["revitalises"],
];

pub(crate) static ENTRY_REVITALIZE_6139669234338764878: VariantsMap = [
    &["revitalize"],
    &["revitalise"],
    &["revitalize"],
    &["revitalise"],
];

pub(crate) static ENTRY_REVITALIZING_2708402192275645435: VariantsMap = [
    &["revitalizing"],
    &["revitalising"],
    &["revitalizing"],
    &["revitalising"],
];

pub(crate) static ENTRY_REVIVALIZES_10827402937094948947: VariantsMap = [
    &["revivalizes"],
    &["revivalises"],
    &["revivalizes"],
    &["revivalises"],
];

pub(crate) static ENTRY_REVIVALIZE_9628710875428300128: VariantsMap = [
    &["revivalize"],
    &["revivalise"],
    &["revivalize"],
    &["revivalise"],
];

pub(crate) static ENTRY_REVOLATILIZES_12548329149855212611: VariantsMap = [
    &["revolatilizes"],
    &["revolatilises"],
    &["revolatilizes"],
    &["revolatilises"],
];

pub(crate) static ENTRY_REVOLATILIZE_15213340201484859604: VariantsMap = [
    &["revolatilize"],
    &["revolatilise"],
    &["revolatilize"],
    &["revolatilise"],
];

pub(crate) static ENTRY_REVOLUTIONIZED_17229010415616229254: VariantsMap = [
    &["revolutionized"],
    &["revolutionised"],
    &["revolutionized"],
    &["revolutionised"],
];

pub(crate) static ENTRY_REVOLUTIONIZEMENTS_9485600286916070301: VariantsMap = [
    &["revolutionizements"],
    &["revolutionisements"],
    &["revolutionizements"],
    &["revolutionisements"],
];

pub(crate) static ENTRY_REVOLUTIONIZEMENT_16990519803204481080: VariantsMap = [
    &["revolutionizement"],
    &["revolutionisement"],
    &["revolutionizement"],
    &["revolutionisement"],
];

pub(crate) static ENTRY_REVOLUTIONIZERS_16952271029767079136: VariantsMap = [
    &["revolutionizers"],
    &["revolutionisers"],
    &["revolutionizers"],
    &["revolutionisers"],
];

pub(crate) static ENTRY_REVOLUTIONIZER_13676086032738364882: VariantsMap = [
    &["revolutionizer"],
    &["revolutioniser"],
    &["revolutionizer"],
    &["revolutioniser"],
];

pub(crate) static ENTRY_REVOLUTIONIZES_11138653471155510637: VariantsMap = [
    &["revolutionizes"],
    &["revolutionises"],
    &["revolutionizes"],
    &["revolutionises"],
];

pub(crate) static ENTRY_REVOLUTIONIZE_3470055274275469616: VariantsMap = [
    &["revolutionize"],
    &["revolutionise"],
    &["revolutionize"],
    &["revolutionise"],
];

pub(crate) static ENTRY_REVOLUTIONIZING_12791238819359973912: VariantsMap = [
    &["revolutionizing"],
    &["revolutionising"],
    &["revolutionizing"],
    &["revolutionising"],
];

pub(crate) static ENTRY_REXFORD_592979619748065087: VariantsMap =
    [&["rexford"], &["rexfourd"], &["rexfourd"], &["rexfourd"]];

pub(crate) static ENTRY_RHAPHE_3287184404322248274: VariantsMap =
    [&["rhaphe"], &["rhaphae"], &["rhaphae"], &["rhaphae"]];

pub(crate) static ENTRY_RHAPSODIZED_16882300059855716248: VariantsMap = [
    &["rhapsodized"],
    &["rhapsodised"],
    &["rhapsodized"],
    &["rhapsodised"],
];

pub(crate) static ENTRY_RHAPSODIZES_8543334345807282409: VariantsMap = [
    &["rhapsodizes"],
    &["rhapsodises"],
    &["rhapsodizes"],
    &["rhapsodises"],
];

pub(crate) static ENTRY_RHAPSODIZE_8592901551161811550: VariantsMap = [
    &["rhapsodize"],
    &["rhapsodise"],
    &["rhapsodize"],
    &["rhapsodise"],
];

pub(crate) static ENTRY_RHAPSODIZING_9325748671831046103: VariantsMap = [
    &["rhapsodizing"],
    &["rhapsodising"],
    &["rhapsodizing"],
    &["rhapsodising"],
];

pub(crate) static ENTRY_RHEADINE_17572840070808796479: VariantsMap = [
    &["rheadine"],
    &["rhoeadine"],
    &["rhoeadine"],
    &["rhoeadine"],
];

pub(crate) static ENTRY_RHEBOSIS_15346112661104796425: VariantsMap = [
    &["rhebosis"],
    &["rhaebosis"],
    &["rhaebosis"],
    &["rhaebosis"],
];

pub(crate) static ENTRY_RHETIAN_534728823910367064: VariantsMap =
    [&["rhetian"], &["rhaetian"], &["rhaetian"], &["rhaetian"]];

pub(crate) static ENTRY_RHETIC_12924080598897141505: VariantsMap =
    [&["rhetic"], &["rhaetic"], &["rhaetic"], &["rhaetic"]];

pub(crate) static ENTRY_RHETORIZED_11335389769662920882: VariantsMap = [
    &["rhetorized"],
    &["rhetorised"],
    &["rhetorized"],
    &["rhetorised"],
];

pub(crate) static ENTRY_RHETORIZES_11133222000386712600: VariantsMap = [
    &["rhetorizes"],
    &["rhetorises"],
    &["rhetorizes"],
    &["rhetorises"],
];

pub(crate) static ENTRY_RHETORIZE_2537262982948879204: VariantsMap = [
    &["rhetorize"],
    &["rhetorise"],
    &["rhetorize"],
    &["rhetorise"],
];

pub(crate) static ENTRY_RHETORIZING_12662060917901718915: VariantsMap = [
    &["rhetorizing"],
    &["rhetorising"],
    &["rhetorizing"],
    &["rhetorising"],
];

pub(crate) static ENTRY_RHEUMATIZED_6912521646064787206: VariantsMap = [
    &["rheumatized"],
    &["rheumatised"],
    &["rheumatized"],
    &["rheumatised"],
];

pub(crate) static ENTRY_RHEUMATIZES_16882230147167842816: VariantsMap = [
    &["rheumatizes"],
    &["rheumatises"],
    &["rheumatizes"],
    &["rheumatises"],
];

pub(crate) static ENTRY_RHEUMATIZE_17276783343159397264: VariantsMap = [
    &["rheumatize"],
    &["rheumatise"],
    &["rheumatize"],
    &["rheumatise"],
];

pub(crate) static ENTRY_RHEUMATIZING_5948133421182699653: VariantsMap = [
    &["rheumatizing"],
    &["rheumatising"],
    &["rheumatizing"],
    &["rheumatising"],
];

pub(crate) static ENTRY_RHINOCELE_174829405093096946: VariantsMap = [
    &["rhinocele"],
    &["rhinocoele"],
    &["rhinocoele"],
    &["rhinocoele"],
];

pub(crate) static ENTRY_RHINOCELIAN_16591957799590718552: VariantsMap = [
    &["rhinocelian"],
    &["rhinocoelian"],
    &["rhinocoelian"],
    &["rhinocoelian"],
];

pub(crate) static ENTRY_RHINORRHEAL_6431844651516367333: VariantsMap = [
    &["rhinorrheal"],
    &["rhinorrhoeal"],
    &["rhinorrhoeal"],
    &["rhinorrhoeal"],
];

pub(crate) static ENTRY_RHINORRHEA_7736143842252392789: VariantsMap = [
    &["rhinorrhea"],
    &["rhinorrhoea"],
    &["rhinorrhoea"],
    &["rhinorrhoea"],
];

pub(crate) static ENTRY_RHODANIZED_1994856248412297421: VariantsMap = [
    &["rhodanized"],
    &["rhodanised"],
    &["rhodanized"],
    &["rhodanised"],
];

pub(crate) static ENTRY_RHODANIZES_16723502090569823135: VariantsMap = [
    &["rhodanizes"],
    &["rhodanises"],
    &["rhodanizes"],
    &["rhodanises"],
];

pub(crate) static ENTRY_RHODANIZE_4028147647059435010: VariantsMap = [
    &["rhodanize"],
    &["rhodanise"],
    &["rhodanize"],
    &["rhodanise"],
];

pub(crate) static ENTRY_RHODANIZING_6600196086306540651: VariantsMap = [
    &["rhodanizing"],
    &["rhodanising"],
    &["rhodanizing"],
    &["rhodanising"],
];

pub(crate) static ENTRY_RHOTACIZED_2852510490082790029: VariantsMap = [
    &["rhotacized"],
    &["rhotacised"],
    &["rhotacized"],
    &["rhotacised"],
];

pub(crate) static ENTRY_RHOTACIZES_7282806474686539140: VariantsMap = [
    &["rhotacizes"],
    &["rhotacises"],
    &["rhotacizes"],
    &["rhotacises"],
];

pub(crate) static ENTRY_RHOTACIZE_2252201772265866826: VariantsMap = [
    &["rhotacize"],
    &["rhotacise"],
    &["rhotacize"],
    &["rhotacise"],
];

pub(crate) static ENTRY_RHOTACIZING_5983232023338121234: VariantsMap = [
    &["rhotacizing"],
    &["rhotacising"],
    &["rhotacizing"],
    &["rhotacising"],
];

pub(crate) static ENTRY_RHYTHMICIZES_6750605402374538800: VariantsMap = [
    &["rhythmicizes"],
    &["rhythmicises"],
    &["rhythmicizes"],
    &["rhythmicises"],
];

pub(crate) static ENTRY_RHYTHMICIZE_2568291653869163877: VariantsMap = [
    &["rhythmicize"],
    &["rhythmicise"],
    &["rhythmicize"],
    &["rhythmicise"],
];

pub(crate) static ENTRY_RHYTHMIZABLES_16724509145153469612: VariantsMap = [
    &["rhythmizables"],
    &["rhythmisables"],
    &["rhythmizables"],
    &["rhythmisables"],
];

pub(crate) static ENTRY_RHYTHMIZABLE_1579755278846162123: VariantsMap = [
    &["rhythmizable"],
    &["rhythmisable"],
    &["rhythmizable"],
    &["rhythmisable"],
];

pub(crate) static ENTRY_RHYTHMIZATIONS_2864181387444036458: VariantsMap = [
    &["rhythmizations"],
    &["rhythmisations"],
    &["rhythmizations"],
    &["rhythmisations"],
];

pub(crate) static ENTRY_RHYTHMIZATION_6091508663979892277: VariantsMap = [
    &["rhythmization"],
    &["rhythmisation"],
    &["rhythmization"],
    &["rhythmisation"],
];

pub(crate) static ENTRY_RHYTHMIZED_12905954271885700288: VariantsMap = [
    &["rhythmized"],
    &["rhythmised"],
    &["rhythmized"],
    &["rhythmised"],
];

pub(crate) static ENTRY_RHYTHMIZES_15972108371856453286: VariantsMap = [
    &["rhythmizes"],
    &["rhythmises"],
    &["rhythmizes"],
    &["rhythmises"],
];

pub(crate) static ENTRY_RHYTHMIZE_9209031730374842797: VariantsMap = [
    &["rhythmize"],
    &["rhythmise"],
    &["rhythmize"],
    &["rhythmise"],
];

pub(crate) static ENTRY_RHYTHMIZING_1031028778051496999: VariantsMap = [
    &["rhythmizing"],
    &["rhythmising"],
    &["rhythmizing"],
    &["rhythmising"],
];

pub(crate) static ENTRY_RIDICULIZES_6019689684453486199: VariantsMap = [
    &["ridiculizes"],
    &["ridiculises"],
    &["ridiculizes"],
    &["ridiculises"],
];

pub(crate) static ENTRY_RIDICULIZE_11800231737801084094: VariantsMap = [
    &["ridiculize"],
    &["ridiculise"],
    &["ridiculize"],
    &["ridiculise"],
];

pub(crate) static ENTRY_RIGIDIZED_10283429518521342894: VariantsMap = [
    &["rigidized"],
    &["rigidised"],
    &["rigidized"],
    &["rigidised"],
];

pub(crate) static ENTRY_RIGIDIZES_14178846988626829524: VariantsMap = [
    &["rigidizes"],
    &["rigidises"],
    &["rigidizes"],
    &["rigidises"],
];

pub(crate) static ENTRY_RIGIDIZE_13876511868517551670: VariantsMap =
    [&["rigidize"], &["rigidise"], &["rigidize"], &["rigidise"]];

pub(crate) static ENTRY_RIGIDIZING_12179399956370664115: VariantsMap = [
    &["rigidizing"],
    &["rigidising"],
    &["rigidizing"],
    &["rigidising"],
];

pub(crate) static ENTRY_RIGORISM_13132314746805145944: VariantsMap = [
    &["rigorism"],
    &["rigourism"],
    &["rigourism"],
    &["rigourism"],
];

pub(crate) static ENTRY_RIGORISTIC_2875620626641348885: VariantsMap = [
    &["rigoristic"],
    &["rigouristic"],
    &["rigouristic"],
    &["rigouristic"],
];

pub(crate) static ENTRY_RIGORIST_9002163466917196639: VariantsMap = [
    &["rigorist"],
    &["rigourist"],
    &["rigourist"],
    &["rigourist"],
];

pub(crate) static ENTRY_RIGORS_3068318220888831390: VariantsMap =
    [&["rigors"], &["rigours"], &["rigours"], &["rigours"]];

pub(crate) static ENTRY_RIGOR_13840324324485661310: VariantsMap =
    [&["rigor"], &["rigour"], &["rigour"], &["rigour"]];

pub(crate) static ENTRY_RIOTIZES_2377945734094166848: VariantsMap =
    [&["riotizes"], &["riotises"], &["riotizes"], &["riotises"]];

pub(crate) static ENTRY_RIOTIZE_9780442096384725615: VariantsMap =
    [&["riotize"], &["riotise"], &["riotize"], &["riotise"]];

pub(crate) static ENTRY_RITORNELLES_14904170523270958508: VariantsMap = [
    &["ritornelles"],
    &["ritournelles"],
    &["ritournelles"],
    &["ritournelles"],
];

pub(crate) static ENTRY_RITORNELLE_7468653839028445523: VariantsMap = [
    &["ritornelle"],
    &["ritournelle"],
    &["ritournelle"],
    &["ritournelle"],
];

pub(crate) static ENTRY_RITUALIZATIONS_8869257737053182647: VariantsMap = [
    &["ritualizations"],
    &["ritualisations"],
    &["ritualizations"],
    &["ritualisations"],
];

pub(crate) static ENTRY_RITUALIZATION_17342697987838586636: VariantsMap = [
    &["ritualization"],
    &["ritualisation"],
    &["ritualization"],
    &["ritualisation"],
];

pub(crate) static ENTRY_RITUALIZED_4837360641797207469: VariantsMap = [
    &["ritualized"],
    &["ritualised"],
    &["ritualized"],
    &["ritualised"],
];

pub(crate) static ENTRY_RITUALIZES_17901433018773934503: VariantsMap = [
    &["ritualizes"],
    &["ritualises"],
    &["ritualizes"],
    &["ritualises"],
];

pub(crate) static ENTRY_RITUALIZE_12932718365597780903: VariantsMap = [
    &["ritualize"],
    &["ritualise"],
    &["ritualize"],
    &["ritualise"],
];

pub(crate) static ENTRY_RITUALIZING_17963863299966783179: VariantsMap = [
    &["ritualizing"],
    &["ritualising"],
    &["ritualizing"],
    &["ritualising"],
];

pub(crate) static ENTRY_RIVALED_10007684086261671851: VariantsMap =
    [&["rivaled"], &["rivalled"], &["rivalled"], &["rivalled"]];

pub(crate) static ENTRY_RIVALESSES_17509619766008391554: VariantsMap = [
    &["rivalesses"],
    &["rivallesses"],
    &["rivallesses"],
    &["rivallesses"],
];

pub(crate) static ENTRY_RIVALESS_5502653831370349272: VariantsMap = [
    &["rivaless"],
    &["rivalless"],
    &["rivalless"],
    &["rivalless"],
];

pub(crate) static ENTRY_RIVALING_9971938631235821729: VariantsMap = [
    &["rivaling"],
    &["rivalling"],
    &["rivalling"],
    &["rivalling"],
];

pub(crate) static ENTRY_RIVALIZED_8927862304000561016: VariantsMap = [
    &["rivalized"],
    &["rivalised"],
    &["rivalized"],
    &["rivalised"],
];

pub(crate) static ENTRY_RIVALIZES_16489774221336799701: VariantsMap = [
    &["rivalizes"],
    &["rivalises"],
    &["rivalizes"],
    &["rivalises"],
];

pub(crate) static ENTRY_RIVALIZE_1647304959804156795: VariantsMap =
    [&["rivalize"], &["rivalise"], &["rivalize"], &["rivalise"]];

pub(crate) static ENTRY_RIVALIZING_2604324608436302981: VariantsMap = [
    &["rivalizing"],
    &["rivalising"],
    &["rivalizing"],
    &["rivalising"],
];

pub(crate) static ENTRY_ROBOTIZATIONS_17425010007834309500: VariantsMap = [
    &["robotizations"],
    &["robotisations"],
    &["robotizations"],
    &["robotisations"],
];

pub(crate) static ENTRY_ROBOTIZATION_10850862175275622758: VariantsMap = [
    &["robotization"],
    &["robotisation"],
    &["robotization"],
    &["robotisation"],
];

pub(crate) static ENTRY_ROBOTIZED_5530996200469975174: VariantsMap = [
    &["robotized"],
    &["robotised"],
    &["robotized"],
    &["robotised"],
];

pub(crate) static ENTRY_ROBOTIZES_6429276732898466559: VariantsMap = [
    &["robotizes"],
    &["robotises"],
    &["robotizes"],
    &["robotises"],
];

pub(crate) static ENTRY_ROBOTIZE_12113166233450095442: VariantsMap =
    [&["robotize"], &["robotise"], &["robotize"], &["robotise"]];

pub(crate) static ENTRY_ROBOTIZING_16303228955863605624: VariantsMap = [
    &["robotizing"],
    &["robotising"],
    &["robotizing"],
    &["robotising"],
];

pub(crate) static ENTRY_ROED_4005322299752850400: VariantsMap =
    [&["roed"], &["rooed"], &["rooed"], &["rooed"]];

pub(crate) static ENTRY_ROENTGENIZE_2577537657952804248: VariantsMap = [
    &["roentgenize"],
    &["roentgenise"],
    &["roentgenize"],
    &["roentgenise"],
];

pub(crate) static ENTRY_ROER_2952923842519664515: VariantsMap =
    [&["roer"], &["rore"], &["rore"], &["rore"]];

pub(crate) static ENTRY_ROMANIAS_12237588174128982109: VariantsMap = [
    &["romanias"],
    &["roumanias"],
    &["roumanias"],
    &["roumanias"],
];

pub(crate) static ENTRY_ROMANIA_4320567788734412103: VariantsMap =
    [&["romania"], &["roumania"], &["roumania"], &["roumania"]];

pub(crate) static ENTRY_ROMANIZATIONS_870204756988951102: VariantsMap = [
    &["romanizations"],
    &["romanisations"],
    &["romanizations"],
    &["romanisations"],
];

pub(crate) static ENTRY_ROMANIZATION_8560046577492680615: VariantsMap = [
    &["romanization"],
    &["romanisation"],
    &["romanization"],
    &["romanisation"],
];

pub(crate) static ENTRY_ROMANIZED_11325302352054785292: VariantsMap = [
    &["romanized"],
    &["romanised"],
    &["romanized"],
    &["romanised"],
];

pub(crate) static ENTRY_ROMANIZERS_16309654375180006599: VariantsMap = [
    &["romanizers"],
    &["romanisers"],
    &["romanizers"],
    &["romanisers"],
];

pub(crate) static ENTRY_ROMANIZER_11428635145822485637: VariantsMap = [
    &["romanizer"],
    &["romaniser"],
    &["romanizer"],
    &["romaniser"],
];

pub(crate) static ENTRY_ROMANIZES_14316864401141443537: VariantsMap = [
    &["romanizes"],
    &["romanises"],
    &["romanizes"],
    &["romanises"],
];

pub(crate) static ENTRY_ROMANIZE_17828022341300623695: VariantsMap =
    [&["romanize"], &["romanise"], &["romanize"], &["romanise"]];

pub(crate) static ENTRY_ROMANIZING_6533972516331684265: VariantsMap = [
    &["romanizing"],
    &["romanising"],
    &["romanizing"],
    &["romanising"],
];

pub(crate) static ENTRY_ROMANTICIZATIONS_14917933992160685773: VariantsMap = [
    &["romanticizations"],
    &["romanticisations"],
    &["romanticizations"],
    &["romanticisations"],
];

pub(crate) static ENTRY_ROMANTICIZATION_98519846053872295: VariantsMap = [
    &["romanticization"],
    &["romanticisation"],
    &["romanticization"],
    &["romanticisation"],
];

pub(crate) static ENTRY_ROMANTICIZED_6690263810463145292: VariantsMap = [
    &["romanticized"],
    &["romanticised"],
    &["romanticized"],
    &["romanticised"],
];

pub(crate) static ENTRY_ROMANTICIZES_7010079394357286132: VariantsMap = [
    &["romanticizes"],
    &["romanticises"],
    &["romanticizes"],
    &["romanticises"],
];

pub(crate) static ENTRY_ROMANTICIZE_12085162654923168482: VariantsMap = [
    &["romanticize"],
    &["romanticise"],
    &["romanticize"],
    &["romanticise"],
];

pub(crate) static ENTRY_ROMANTICIZING_7886244968785418156: VariantsMap = [
    &["romanticizing"],
    &["romanticising"],
    &["romanticizing"],
    &["romanticising"],
];

pub(crate) static ENTRY_ROUTINIZATIONS_2795005236388921160: VariantsMap = [
    &["routinizations"],
    &["routinisations"],
    &["routinizations"],
    &["routinisations"],
];

pub(crate) static ENTRY_ROUTINIZATION_17863253035896437203: VariantsMap = [
    &["routinization"],
    &["routinisation"],
    &["routinization"],
    &["routinisation"],
];

pub(crate) static ENTRY_ROUTINIZED_4682046108054080633: VariantsMap = [
    &["routinized"],
    &["routinised"],
    &["routinized"],
    &["routinised"],
];

pub(crate) static ENTRY_ROUTINIZES_17936070643930576806: VariantsMap = [
    &["routinizes"],
    &["routinises"],
    &["routinizes"],
    &["routinises"],
];

pub(crate) static ENTRY_ROUTINIZE_7572489982015879408: VariantsMap = [
    &["routinize"],
    &["routinise"],
    &["routinize"],
    &["routinise"],
];

pub(crate) static ENTRY_ROUTINIZING_807124837692788271: VariantsMap = [
    &["routinizing"],
    &["routinising"],
    &["routinizing"],
    &["routinising"],
];

pub(crate) static ENTRY_ROWELED_12947825968091277960: VariantsMap =
    [&["roweled"], &["rowelled"], &["rowelled"], &["rowelled"]];

pub(crate) static ENTRY_ROWELING_3646767635271162596: VariantsMap = [
    &["roweling"],
    &["rowelling"],
    &["rowelling"],
    &["rowelling"],
];

pub(crate) static ENTRY_ROYALIZATIONS_6505735151644810987: VariantsMap = [
    &["royalizations"],
    &["royalisations"],
    &["royalizations"],
    &["royalisations"],
];

pub(crate) static ENTRY_ROYALIZATION_16468895854636177158: VariantsMap = [
    &["royalization"],
    &["royalisation"],
    &["royalization"],
    &["royalisation"],
];

pub(crate) static ENTRY_ROYALIZED_14657222300341657167: VariantsMap = [
    &["royalized"],
    &["royalised"],
    &["royalized"],
    &["royalised"],
];

pub(crate) static ENTRY_ROYALIZES_17689369586059121910: VariantsMap = [
    &["royalizes"],
    &["royalises"],
    &["royalizes"],
    &["royalises"],
];

pub(crate) static ENTRY_ROYALIZE_5734251532222541359: VariantsMap =
    [&["royalize"], &["royalise"], &["royalize"], &["royalise"]];

pub(crate) static ENTRY_ROYALIZING_3947400302119184294: VariantsMap = [
    &["royalizing"],
    &["royalising"],
    &["royalizing"],
    &["royalising"],
];

pub(crate) static ENTRY_RUBBERIZATION_14360156161763362735: VariantsMap = [
    &["rubberization"],
    &["rubberisation"],
    &["rubberization"],
    &["rubberisation"],
];

pub(crate) static ENTRY_RUBBERIZED_14611155806859179613: VariantsMap = [
    &["rubberized"],
    &["rubberised"],
    &["rubberized"],
    &["rubberised"],
];

pub(crate) static ENTRY_RUBBERIZES_2448401715198131266: VariantsMap = [
    &["rubberizes"],
    &["rubberises"],
    &["rubberizes"],
    &["rubberises"],
];

pub(crate) static ENTRY_RUBBERIZE_12684219161328931610: VariantsMap = [
    &["rubberize"],
    &["rubberise"],
    &["rubberize"],
    &["rubberise"],
];

pub(crate) static ENTRY_RUBBERIZING_11711303490733810019: VariantsMap = [
    &["rubberizing"],
    &["rubberising"],
    &["rubberizing"],
    &["rubberising"],
];

pub(crate) static ENTRY_RUBLES_7609381998397963857: VariantsMap =
    [&["rubles"], &["roubles"], &["roubles"], &["roubles"]];

pub(crate) static ENTRY_RUBLE_8353986414758489699: VariantsMap =
    [&["ruble"], &["rouble"], &["rouble"], &["rouble"]];

pub(crate) static ENTRY_RUBRICIZES_17489389230499978799: VariantsMap = [
    &["rubricizes"],
    &["rubricises"],
    &["rubricizes"],
    &["rubricises"],
];

pub(crate) static ENTRY_RUBRICIZE_18249275085584055504: VariantsMap = [
    &["rubricize"],
    &["rubricise"],
    &["rubricize"],
    &["rubricise"],
];

pub(crate) static ENTRY_RUFFIANIZES_10939149941590833833: VariantsMap = [
    &["ruffianizes"],
    &["ruffianises"],
    &["ruffianizes"],
    &["ruffianises"],
];

pub(crate) static ENTRY_RUFFIANIZE_17478335968439303687: VariantsMap = [
    &["ruffianize"],
    &["ruffianise"],
    &["ruffianize"],
    &["ruffianise"],
];

pub(crate) static ENTRY_RUGGEDIZATIONS_15043895672134591753: VariantsMap = [
    &["ruggedizations"],
    &["ruggedisations"],
    &["ruggedizations"],
    &["ruggedisations"],
];

pub(crate) static ENTRY_RUGGEDIZATION_4464441313619036075: VariantsMap = [
    &["ruggedization"],
    &["ruggedisation"],
    &["ruggedization"],
    &["ruggedisation"],
];

pub(crate) static ENTRY_RUGGEDIZED_1442579612275114612: VariantsMap = [
    &["ruggedized"],
    &["ruggedised"],
    &["ruggedized"],
    &["ruggedised"],
];

pub(crate) static ENTRY_RUGGEDIZES_4636586194651066833: VariantsMap = [
    &["ruggedizes"],
    &["ruggedises"],
    &["ruggedizes"],
    &["ruggedises"],
];

pub(crate) static ENTRY_RUGGEDIZE_217104043935831127: VariantsMap = [
    &["ruggedize"],
    &["ruggedise"],
    &["ruggedize"],
    &["ruggedise"],
];

pub(crate) static ENTRY_RUGGEDIZING_16816901556445020337: VariantsMap = [
    &["ruggedizing"],
    &["ruggedising"],
    &["ruggedizing"],
    &["ruggedising"],
];

pub(crate) static ENTRY_RUMORED_440192285504422993: VariantsMap =
    [&["rumored"], &["rumoured"], &["rumoured"], &["rumoured"]];

pub(crate) static ENTRY_RUMORERS_18193676553916096837: VariantsMap = [
    &["rumorers"],
    &["rumourers"],
    &["rumourers"],
    &["rumourers"],
];

pub(crate) static ENTRY_RUMORER_13710023131538812640: VariantsMap =
    [&["rumorer"], &["rumourer"], &["rumourer"], &["rumourer"]];

pub(crate) static ENTRY_RUMORING_6988773240152687435: VariantsMap = [
    &["rumoring"],
    &["rumouring"],
    &["rumouring"],
    &["rumouring"],
];

pub(crate) static ENTRY_RUMORMONGERS_3640300238053765249: VariantsMap = [
    &["rumormongers"],
    &["rumourmongers"],
    &["rumourmongers"],
    &["rumourmongers"],
];

pub(crate) static ENTRY_RUMORMONGER_16571412941503356230: VariantsMap = [
    &["rumormonger"],
    &["rumourmonger"],
    &["rumourmonger"],
    &["rumourmonger"],
];

pub(crate) static ENTRY_RUMORS_12062925234185208276: VariantsMap =
    [&["rumors"], &["rumours"], &["rumours"], &["rumours"]];

pub(crate) static ENTRY_RUMOR_14879871972679734791: VariantsMap =
    [&["rumor"], &["rumour"], &["rumour"], &["rumour"]];

pub(crate) static ENTRY_RURALIZATIONS_13674767207069067961: VariantsMap = [
    &["ruralizations"],
    &["ruralisations"],
    &["ruralizations"],
    &["ruralisations"],
];

pub(crate) static ENTRY_RURALIZATION_12580175398492738873: VariantsMap = [
    &["ruralization"],
    &["ruralisation"],
    &["ruralization"],
    &["ruralisation"],
];

pub(crate) static ENTRY_RURALIZED_3311773382035084319: VariantsMap = [
    &["ruralized"],
    &["ruralised"],
    &["ruralized"],
    &["ruralised"],
];

pub(crate) static ENTRY_RURALIZES_1476309458742854492: VariantsMap = [
    &["ruralizes"],
    &["ruralises"],
    &["ruralizes"],
    &["ruralises"],
];

pub(crate) static ENTRY_RURALIZE_15119229364207745147: VariantsMap =
    [&["ruralize"], &["ruralise"], &["ruralize"], &["ruralise"]];

pub(crate) static ENTRY_RURALIZING_421101365792616220: VariantsMap = [
    &["ruralizing"],
    &["ruralising"],
    &["ruralizing"],
    &["ruralising"],
];

pub(crate) static ENTRY_RUSSIANIZATIONS_16674015372829185946: VariantsMap = [
    &["russianizations"],
    &["russianisations"],
    &["russianizations"],
    &["russianisations"],
];

pub(crate) static ENTRY_RUSSIANIZATION_15115261889071660936: VariantsMap = [
    &["russianization"],
    &["russianisation"],
    &["russianization"],
    &["russianisation"],
];

pub(crate) static ENTRY_RUSSIANIZED_16004967225929046214: VariantsMap = [
    &["russianized"],
    &["russianised"],
    &["russianized"],
    &["russianised"],
];

pub(crate) static ENTRY_RUSSIANIZES_3164883107359350862: VariantsMap = [
    &["russianizes"],
    &["russianises"],
    &["russianizes"],
    &["russianises"],
];

pub(crate) static ENTRY_RUSSIANIZE_282987153219396042: VariantsMap = [
    &["russianize"],
    &["russianise"],
    &["russianize"],
    &["russianise"],
];

pub(crate) static ENTRY_RUSSIANIZING_18238432049983406277: VariantsMap = [
    &["russianizing"],
    &["russianising"],
    &["russianizing"],
    &["russianising"],
];

pub(crate) static ENTRY_RUSTICIZED_1941250008396625115: VariantsMap = [
    &["rusticized"],
    &["rusticised"],
    &["rusticized"],
    &["rusticised"],
];

pub(crate) static ENTRY_RUSTICIZES_600312242923138898: VariantsMap = [
    &["rusticizes"],
    &["rusticises"],
    &["rusticizes"],
    &["rusticises"],
];

pub(crate) static ENTRY_RUSTICIZE_944744519473975444: VariantsMap = [
    &["rusticize"],
    &["rusticise"],
    &["rusticize"],
    &["rusticise"],
];

pub(crate) static ENTRY_RUSTICIZING_7143440747019626934: VariantsMap = [
    &["rusticizing"],
    &["rusticising"],
    &["rusticizing"],
    &["rusticising"],
];

pub(crate) static ENTRY_SABBATHIZES_17109057526061439868: VariantsMap = [
    &["sabbathizes"],
    &["sabbathises"],
    &["sabbathizes"],
    &["sabbathises"],
];

pub(crate) static ENTRY_SABBATHIZE_11967605322963658497: VariantsMap = [
    &["sabbathize"],
    &["sabbathise"],
    &["sabbathize"],
    &["sabbathise"],
];

pub(crate) static ENTRY_SABBATIZED_15483584318942973231: VariantsMap = [
    &["sabbatized"],
    &["sabbatised"],
    &["sabbatized"],
    &["sabbatised"],
];

pub(crate) static ENTRY_SABBATIZES_14966685950973844938: VariantsMap = [
    &["sabbatizes"],
    &["sabbatises"],
    &["sabbatizes"],
    &["sabbatises"],
];

pub(crate) static ENTRY_SABBATIZE_15657255968552732741: VariantsMap = [
    &["sabbatize"],
    &["sabbatise"],
    &["sabbatize"],
    &["sabbatise"],
];

pub(crate) static ENTRY_SABBATIZING_7613295799085050565: VariantsMap = [
    &["sabbatizing"],
    &["sabbatising"],
    &["sabbatizing"],
    &["sabbatising"],
];

pub(crate) static ENTRY_SABEANS_16355459180629636797: VariantsMap =
    [&["sabeans"], &["sabaeans"], &["sabaeans"], &["sabaeans"]];

pub(crate) static ENTRY_SABEAN_17515878016028553161: VariantsMap =
    [&["sabean"], &["sabaean"], &["sabaean"], &["sabaean"]];

pub(crate) static ENTRY_SABERBILL_14244790750611534132: VariantsMap = [
    &["saberbill"],
    &["sabrebill"],
    &["sabrebill"],
    &["sabrebill"],
];

pub(crate) static ENTRY_SABERED_354016476875728649: VariantsMap =
    [&["sabered"], &["sabred"], &["sabred"], &["sabred"]];

pub(crate) static ENTRY_SABERING_4510522223387135900: VariantsMap =
    [&["sabering"], &["sabring"], &["sabring"], &["sabring"]];

pub(crate) static ENTRY_SABERLIKES_8784912257296046319: VariantsMap = [
    &["saberlikes"],
    &["sabrelikes"],
    &["sabrelikes"],
    &["sabrelikes"],
];

pub(crate) static ENTRY_SABERLIKE_9533101026022249155: VariantsMap = [
    &["saberlike"],
    &["sabrelike"],
    &["sabrelike"],
    &["sabrelike"],
];

pub(crate) static ENTRY_SABERS_17469384891487410695: VariantsMap =
    [&["sabers"], &["sabres"], &["sabres"], &["sabres"]];

pub(crate) static ENTRY_SABERTOOTH_4035092162600296855: VariantsMap = [
    &["sabertooth"],
    &["sabretooth"],
    &["sabretooth"],
    &["sabretooth"],
];

pub(crate) static ENTRY_SABER_11215537798592835960: VariantsMap =
    [&["saber"], &["sabre"], &["sabre"], &["sabre"]];

pub(crate) static ENTRY_SACCHARIZATIONS_7465718845212875510: VariantsMap = [
    &["saccharizations"],
    &["saccharisations"],
    &["saccharizations"],
    &["saccharisations"],
];

pub(crate) static ENTRY_SACCHARIZATION_16067598677360548774: VariantsMap = [
    &["saccharization"],
    &["saccharisation"],
    &["saccharization"],
    &["saccharisation"],
];

pub(crate) static ENTRY_SACCHARIZED_2066975935540578216: VariantsMap = [
    &["saccharized"],
    &["saccharised"],
    &["saccharized"],
    &["saccharised"],
];

pub(crate) static ENTRY_SACCHARIZES_12303619626250431982: VariantsMap = [
    &["saccharizes"],
    &["saccharises"],
    &["saccharizes"],
    &["saccharises"],
];

pub(crate) static ENTRY_SACCHARIZE_15985938828367437759: VariantsMap = [
    &["saccharize"],
    &["saccharise"],
    &["saccharize"],
    &["saccharise"],
];

pub(crate) static ENTRY_SACCHARIZING_9152474624171075193: VariantsMap = [
    &["saccharizing"],
    &["saccharising"],
    &["saccharizing"],
    &["saccharising"],
];

pub(crate) static ENTRY_SACERDOTALIZED_3947529897566908444: VariantsMap = [
    &["sacerdotalized"],
    &["sacerdotalised"],
    &["sacerdotalized"],
    &["sacerdotalised"],
];

pub(crate) static ENTRY_SACERDOTALIZES_9709179734322016707: VariantsMap = [
    &["sacerdotalizes"],
    &["sacerdotalises"],
    &["sacerdotalizes"],
    &["sacerdotalises"],
];

pub(crate) static ENTRY_SACERDOTALIZE_3961802349220485517: VariantsMap = [
    &["sacerdotalize"],
    &["sacerdotalise"],
    &["sacerdotalize"],
    &["sacerdotalise"],
];

pub(crate) static ENTRY_SACERDOTALIZING_2005953003908602761: VariantsMap = [
    &["sacerdotalizing"],
    &["sacerdotalising"],
    &["sacerdotalizing"],
    &["sacerdotalising"],
];

pub(crate) static ENTRY_SACRALIZATIONS_14552724704204688953: VariantsMap = [
    &["sacralizations"],
    &["sacralisations"],
    &["sacralizations"],
    &["sacralisations"],
];

pub(crate) static ENTRY_SACRALIZATION_10975549769050558226: VariantsMap = [
    &["sacralization"],
    &["sacralisation"],
    &["sacralization"],
    &["sacralisation"],
];

pub(crate) static ENTRY_SACRALIZED_7406626079934925607: VariantsMap = [
    &["sacralized"],
    &["sacralised"],
    &["sacralized"],
    &["sacralised"],
];

pub(crate) static ENTRY_SACRALIZES_12289949097436420802: VariantsMap = [
    &["sacralizes"],
    &["sacralises"],
    &["sacralizes"],
    &["sacralises"],
];

pub(crate) static ENTRY_SACRALIZE_9629490668937081632: VariantsMap = [
    &["sacralize"],
    &["sacralise"],
    &["sacralize"],
    &["sacralise"],
];

pub(crate) static ENTRY_SACRALIZING_13224927129267811542: VariantsMap = [
    &["sacralizing"],
    &["sacralising"],
    &["sacralizing"],
    &["sacralising"],
];

pub(crate) static ENTRY_SACRAMENTIZES_94291517496052865: VariantsMap = [
    &["sacramentizes"],
    &["sacramentises"],
    &["sacramentizes"],
    &["sacramentises"],
];

pub(crate) static ENTRY_SACRAMENTIZE_4727143733704695641: VariantsMap = [
    &["sacramentize"],
    &["sacramentise"],
    &["sacramentize"],
    &["sacramentise"],
];

pub(crate) static ENTRY_SAFIER_9789114026361208044: VariantsMap =
    [&["safier"], &["safire"], &["safire"], &["safire"]];

pub(crate) static ENTRY_SAILORIZINGS_12371047336413895803: VariantsMap = [
    &["sailorizings"],
    &["sailorisings"],
    &["sailorizings"],
    &["sailorisings"],
];

pub(crate) static ENTRY_SAILORIZING_15355602670663398084: VariantsMap = [
    &["sailorizing"],
    &["sailorising"],
    &["sailorizing"],
    &["sailorising"],
];

pub(crate) static ENTRY_SALABLER_12436535119147435528: VariantsMap = [
    &["salabler"],
    &["saleabler"],
    &["saleabler"],
    &["saleabler"],
];

pub(crate) static ENTRY_SALABLEST_11800233581075881251: VariantsMap = [
    &["salablest"],
    &["saleablest"],
    &["saleablest"],
    &["saleablest"],
];

pub(crate) static ENTRY_SALABLE_9416288983668269251: VariantsMap =
    [&["salable"], &["saleable"], &["saleable"], &["saleable"]];

pub(crate) static ENTRY_SALINIZATION_13266963897300307508: VariantsMap = [
    &["salinization"],
    &["salinisation"],
    &["salinization"],
    &["salinisation"],
];

pub(crate) static ENTRY_SALINIZES_10928451094016890368: VariantsMap = [
    &["salinizes"],
    &["salinises"],
    &["salinizes"],
    &["salinises"],
];

pub(crate) static ENTRY_SALINIZE_4347778676362138703: VariantsMap =
    [&["salinize"], &["salinise"], &["salinize"], &["salinise"]];

pub(crate) static ENTRY_SALTIERS_5634822252830887819: VariantsMap =
    [&["saltiers"], &["saltires"], &["saltires"], &["saltires"]];

pub(crate) static ENTRY_SALTIERWISE_17950423467476799477: VariantsMap = [
    &["saltierwise"],
    &["saltirewise"],
    &["saltirewise"],
    &["saltirewise"],
];

pub(crate) static ENTRY_SALTPETERS_6897362156960271547: VariantsMap = [
    &["saltpeters"],
    &["saltpetres"],
    &["saltpetres"],
    &["saltpetres"],
];

pub(crate) static ENTRY_SALTPETER_173602624950229471: VariantsMap = [
    &["saltpeter"],
    &["saltpetre"],
    &["saltpetre"],
    &["saltpetre"],
];

pub(crate) static ENTRY_SANCTUARIZED_637812459100527648: VariantsMap = [
    &["sanctuarized"],
    &["sanctuarised"],
    &["sanctuarized"],
    &["sanctuarised"],
];

pub(crate) static ENTRY_SANCTUARIZES_11733292486141379371: VariantsMap = [
    &["sanctuarizes"],
    &["sanctuarises"],
    &["sanctuarizes"],
    &["sanctuarises"],
];

pub(crate) static ENTRY_SANCTUARIZE_2357144985856368070: VariantsMap = [
    &["sanctuarize"],
    &["sanctuarise"],
    &["sanctuarize"],
    &["sanctuarise"],
];

pub(crate) static ENTRY_SANCTUARIZING_8432215645688259160: VariantsMap = [
    &["sanctuarizing"],
    &["sanctuarising"],
    &["sanctuarizing"],
    &["sanctuarising"],
];

pub(crate) static ENTRY_SANDALED_9300809745501373029: VariantsMap = [
    &["sandaled"],
    &["sandalled"],
    &["sandalled"],
    &["sandalled"],
];

pub(crate) static ENTRY_SANDALING_9906711963656843788: VariantsMap = [
    &["sandaling"],
    &["sandalling"],
    &["sandalling"],
    &["sandalling"],
];

pub(crate) static ENTRY_SANFERD_3004088950569415557: VariantsMap =
    [&["sanferd"], &["sanfred"], &["sanfred"], &["sanfred"]];

pub(crate) static ENTRY_SANFORIZES_1821656617081894930: VariantsMap = [
    &["sanforizes"],
    &["sanforises"],
    &["sanforizes"],
    &["sanforises"],
];

pub(crate) static ENTRY_SANFORIZE_11059351431020143233: VariantsMap = [
    &["sanforize"],
    &["sanforise"],
    &["sanforize"],
    &["sanforise"],
];

pub(crate) static ENTRY_SANFORIZING_11411332451649842663: VariantsMap = [
    &["sanforizing"],
    &["sanforising"],
    &["sanforizing"],
    &["sanforising"],
];

pub(crate) static ENTRY_SANITIZATIONS_2020024074797942758: VariantsMap = [
    &["sanitizations"],
    &["sanitisations"],
    &["sanitizations"],
    &["sanitisations"],
];

pub(crate) static ENTRY_SANITIZATION_6597368949679247898: VariantsMap = [
    &["sanitization"],
    &["sanitisation"],
    &["sanitization"],
    &["sanitisation"],
];

pub(crate) static ENTRY_SANITIZED_16038727043373480177: VariantsMap = [
    &["sanitized"],
    &["sanitised"],
    &["sanitized"],
    &["sanitised"],
];

pub(crate) static ENTRY_SANITIZERS_15061258670919139218: VariantsMap = [
    &["sanitizers"],
    &["sanitisers"],
    &["sanitizers"],
    &["sanitisers"],
];

pub(crate) static ENTRY_SANITIZER_2612058493574762426: VariantsMap = [
    &["sanitizer"],
    &["sanitiser"],
    &["sanitizer"],
    &["sanitiser"],
];

pub(crate) static ENTRY_SANITIZES_6782686809683998201: VariantsMap = [
    &["sanitizes"],
    &["sanitises"],
    &["sanitizes"],
    &["sanitises"],
];

pub(crate) static ENTRY_SANITIZE_13579713832357769834: VariantsMap =
    [&["sanitize"], &["sanitise"], &["sanitize"], &["sanitise"]];

pub(crate) static ENTRY_SANITIZING_8219973274341078569: VariantsMap = [
    &["sanitizing"],
    &["sanitising"],
    &["sanitizing"],
    &["sanitising"],
];

pub(crate) static ENTRY_SANSKRITIZE_15760731619975739051: VariantsMap = [
    &["sanskritize"],
    &["sanskritise"],
    &["sanskritize"],
    &["sanskritise"],
];

pub(crate) static ENTRY_SAPIENTIZES_16514816122173887376: VariantsMap = [
    &["sapientizes"],
    &["sapientises"],
    &["sapientizes"],
    &["sapientises"],
];

pub(crate) static ENTRY_SAPIENTIZE_13669220548988379710: VariantsMap = [
    &["sapientize"],
    &["sapientise"],
    &["sapientize"],
    &["sapientise"],
];

pub(crate) static ENTRY_SAPORS_4058358747036807109: VariantsMap =
    [&["sapors"], &["sapours"], &["sapours"], &["sapours"]];

pub(crate) static ENTRY_SAPOR_11915420262708866035: VariantsMap =
    [&["sapor"], &["sapour"], &["sapour"], &["sapour"]];

pub(crate) static ENTRY_SAPREMIAS_1881316800069031084: VariantsMap = [
    &["sapremias"],
    &["sapraemias"],
    &["sapraemias"],
    &["sapraemias"],
];

pub(crate) static ENTRY_SAPREMIA_12542934405933026855: VariantsMap = [
    &["sapremia"],
    &["sapraemia"],
    &["sapraemia"],
    &["sapraemia"],
];

pub(crate) static ENTRY_SAPREMIC_10220063281186365505: VariantsMap = [
    &["sapremic"],
    &["sapraemic"],
    &["sapraemic"],
    &["sapraemic"],
];

pub(crate) static ENTRY_SARCINE_17958233134687681150: VariantsMap =
    [&["sarcine"], &["sarcinae"], &["sarcinae"], &["sarcinae"]];

pub(crate) static ENTRY_SASSANIDE_2666523513348378135: VariantsMap = [
    &["sassanide"],
    &["sassanidae"],
    &["sassanidae"],
    &["sassanidae"],
];

pub(crate) static ENTRY_SATANIZES_15523201590267219023: VariantsMap = [
    &["satanizes"],
    &["satanises"],
    &["satanizes"],
    &["satanises"],
];

pub(crate) static ENTRY_SATANIZE_13800030973770952717: VariantsMap =
    [&["satanize"], &["satanise"], &["satanize"], &["satanise"]];

pub(crate) static ENTRY_SATELLITIZED_12147676221618104985: VariantsMap = [
    &["satellitized"],
    &["satellitised"],
    &["satellitized"],
    &["satellitised"],
];

pub(crate) static ENTRY_SATELLITIZES_14259618482943348896: VariantsMap = [
    &["satellitizes"],
    &["satellitises"],
    &["satellitizes"],
    &["satellitises"],
];

pub(crate) static ENTRY_SATELLITIZE_9577005869118714843: VariantsMap = [
    &["satellitize"],
    &["satellitise"],
    &["satellitize"],
    &["satellitise"],
];

pub(crate) static ENTRY_SATELLITIZING_7035209722236285234: VariantsMap = [
    &["satellitizing"],
    &["satellitising"],
    &["satellitizing"],
    &["satellitising"],
];

pub(crate) static ENTRY_SATINIZES_13360217491878629150: VariantsMap = [
    &["satinizes"],
    &["satinises"],
    &["satinizes"],
    &["satinises"],
];

pub(crate) static ENTRY_SATINIZE_5954102382726369151: VariantsMap =
    [&["satinize"], &["satinise"], &["satinize"], &["satinise"]];

pub(crate) static ENTRY_SATIRIZABLES_17724622533636018383: VariantsMap = [
    &["satirizables"],
    &["satirisables"],
    &["satirizables"],
    &["satirisables"],
];

pub(crate) static ENTRY_SATIRIZABLE_16109104170385816610: VariantsMap = [
    &["satirizable"],
    &["satirisable"],
    &["satirizable"],
    &["satirisable"],
];

pub(crate) static ENTRY_SATIRIZATION_7570569320271471416: VariantsMap = [
    &["satirization"],
    &["satirisation"],
    &["satirization"],
    &["satirisation"],
];

pub(crate) static ENTRY_SATIRIZED_2609000629009969840: VariantsMap = [
    &["satirized"],
    &["satirised"],
    &["satirized"],
    &["satirised"],
];

pub(crate) static ENTRY_SATIRIZERS_12978388605451018478: VariantsMap = [
    &["satirizers"],
    &["satirisers"],
    &["satirizers"],
    &["satirisers"],
];

pub(crate) static ENTRY_SATIRIZER_2790987711694827808: VariantsMap = [
    &["satirizer"],
    &["satiriser"],
    &["satirizer"],
    &["satiriser"],
];

pub(crate) static ENTRY_SATIRIZES_5832579008425684994: VariantsMap = [
    &["satirizes"],
    &["satirises"],
    &["satirizes"],
    &["satirises"],
];

pub(crate) static ENTRY_SATIRIZE_6448100415548150058: VariantsMap =
    [&["satirize"], &["satirise"], &["satirize"], &["satirise"]];

pub(crate) static ENTRY_SATIRIZING_4490066541734347659: VariantsMap = [
    &["satirizing"],
    &["satirising"],
    &["satirizing"],
    &["satirising"],
];

pub(crate) static ENTRY_SATIVE_17240933363041642707: VariantsMap =
    [&["sative"], &["sativae"], &["sativae"], &["sativae"]];

pub(crate) static ENTRY_SAVAGIZES_2456827584264233392: VariantsMap = [
    &["savagizes"],
    &["savagises"],
    &["savagizes"],
    &["savagises"],
];

pub(crate) static ENTRY_SAVAGIZE_9253788959378260781: VariantsMap =
    [&["savagize"], &["savagise"], &["savagize"], &["savagise"]];

pub(crate) static ENTRY_SAVIORESS_16737550475718607104: VariantsMap = [
    &["savioress"],
    &["saviouress"],
    &["saviouress"],
    &["saviouress"],
];

pub(crate) static ENTRY_SAVIORHOODS_17183410712600577741: VariantsMap = [
    &["saviorhoods"],
    &["saviourhoods"],
    &["saviourhoods"],
    &["saviourhoods"],
];

pub(crate) static ENTRY_SAVIORHOOD_13479211680309492690: VariantsMap = [
    &["saviorhood"],
    &["saviourhood"],
    &["saviourhood"],
    &["saviourhood"],
];

pub(crate) static ENTRY_SAVIORSHIPS_10540252863037861490: VariantsMap = [
    &["saviorships"],
    &["saviourships"],
    &["saviourships"],
    &["saviourships"],
];

pub(crate) static ENTRY_SAVIORSHIP_17492156220076413092: VariantsMap = [
    &["saviorship"],
    &["saviourship"],
    &["saviourship"],
    &["saviourship"],
];

pub(crate) static ENTRY_SAVIORS_678195616807904094: VariantsMap =
    [&["saviors"], &["saviours"], &["saviours"], &["saviours"]];

pub(crate) static ENTRY_SAVIOR_9168066282007531402: VariantsMap =
    [&["savior"], &["saviour"], &["saviour"], &["saviour"]];

pub(crate) static ENTRY_SAVORED_10072117720481381746: VariantsMap =
    [&["savored"], &["savoured"], &["savoured"], &["savoured"]];

pub(crate) static ENTRY_SAVORERS_1332704043262552655: VariantsMap = [
    &["savorers"],
    &["savourers"],
    &["savourers"],
    &["savourers"],
];

pub(crate) static ENTRY_SAVORER_8012219220700235569: VariantsMap =
    [&["savorer"], &["savourer"], &["savourer"], &["savourer"]];

pub(crate) static ENTRY_SAVORIER_3288635659178747397: VariantsMap = [
    &["savorier"],
    &["savourier"],
    &["savourier"],
    &["savourier"],
];

pub(crate) static ENTRY_SAVORIEST_5279619332722860135: VariantsMap = [
    &["savoriest"],
    &["savouriest"],
    &["savouriest"],
    &["savouriest"],
];

pub(crate) static ENTRY_SAVORIES_17238888817605202369: VariantsMap = [
    &["savories"],
    &["savouries"],
    &["savouries"],
    &["savouries"],
];

pub(crate) static ENTRY_SAVORILIES_12504192655922635406: VariantsMap = [
    &["savorilies"],
    &["savourilies"],
    &["savourilies"],
    &["savourilies"],
];

pub(crate) static ENTRY_SAVORILY_9272760762798011467: VariantsMap = [
    &["savorily"],
    &["savourily"],
    &["savourily"],
    &["savourily"],
];

pub(crate) static ENTRY_SAVORINESSES_8162276890626615: VariantsMap = [
    &["savorinesses"],
    &["savourinesses"],
    &["savourinesses"],
    &["savourinesses"],
];

pub(crate) static ENTRY_SAVORINESS_14234013341609684681: VariantsMap = [
    &["savoriness"],
    &["savouriness"],
    &["savouriness"],
    &["savouriness"],
];

pub(crate) static ENTRY_SAVORINGLIER_6030440039940731860: VariantsMap = [
    &["savoringlier"],
    &["savouringlier"],
    &["savouringlier"],
    &["savouringlier"],
];

pub(crate) static ENTRY_SAVORINGLIEST_3273409680061825250: VariantsMap = [
    &["savoringliest"],
    &["savouringliest"],
    &["savouringliest"],
    &["savouringliest"],
];

pub(crate) static ENTRY_SAVORINGLIES_6159637740908517522: VariantsMap = [
    &["savoringlies"],
    &["savouringlies"],
    &["savouringlies"],
    &["savouringlies"],
];

pub(crate) static ENTRY_SAVORINGLY_16392721850542159930: VariantsMap = [
    &["savoringly"],
    &["savouringly"],
    &["savouringly"],
    &["savouringly"],
];

pub(crate) static ENTRY_SAVORING_7676890325408701864: VariantsMap = [
    &["savoring"],
    &["savouring"],
    &["savouring"],
    &["savouring"],
];

pub(crate) static ENTRY_SAVORLESSER_5411670158498378508: VariantsMap = [
    &["savorlesser"],
    &["savourlesser"],
    &["savourlesser"],
    &["savourlesser"],
];

pub(crate) static ENTRY_SAVORLESSEST_13669214750218952880: VariantsMap = [
    &["savorlessest"],
    &["savourlessest"],
    &["savourlessest"],
    &["savourlessest"],
];

pub(crate) static ENTRY_SAVORLESSES_968943861955442838: VariantsMap = [
    &["savorlesses"],
    &["savourlesses"],
    &["savourlesses"],
    &["savourlesses"],
];

pub(crate) static ENTRY_SAVORLESS_16913507828862527408: VariantsMap = [
    &["savorless"],
    &["savourless"],
    &["savourless"],
    &["savourless"],
];

pub(crate) static ENTRY_SAVORLY_4451952026972836425: VariantsMap =
    [&["savorly"], &["savourly"], &["savourly"], &["savourly"]];

pub(crate) static ENTRY_SAVOROUSER_7582639087690097285: VariantsMap = [
    &["savorouser"],
    &["savourouser"],
    &["savourouser"],
    &["savourouser"],
];

pub(crate) static ENTRY_SAVOROUSEST_7872022404790033872: VariantsMap = [
    &["savorousest"],
    &["savourousest"],
    &["savourousest"],
    &["savourousest"],
];

pub(crate) static ENTRY_SAVOROUS_6562669852519896030: VariantsMap = [
    &["savorous"],
    &["savourous"],
    &["savourous"],
    &["savourous"],
];

pub(crate) static ENTRY_SAVORS_13144818916465986619: VariantsMap =
    [&["savors"], &["savours"], &["savours"], &["savours"]];

pub(crate) static ENTRY_SAVORY_10419005726511351932: VariantsMap =
    [&["savory"], &["savoury"], &["savoury"], &["savoury"]];

pub(crate) static ENTRY_SAVOR_2009903601214458496: VariantsMap =
    [&["savor"], &["savour"], &["savour"], &["savour"]];

pub(crate) static ENTRY_SAXONIZATIONS_15660259626164087490: VariantsMap = [
    &["saxonizations"],
    &["saxonisations"],
    &["saxonizations"],
    &["saxonisations"],
];

pub(crate) static ENTRY_SAXONIZATION_674457868558304958: VariantsMap = [
    &["saxonization"],
    &["saxonisation"],
    &["saxonization"],
    &["saxonisation"],
];

pub(crate) static ENTRY_SAXONIZED_9838442939668117474: VariantsMap = [
    &["saxonized"],
    &["saxonised"],
    &["saxonized"],
    &["saxonised"],
];

pub(crate) static ENTRY_SAXONIZES_7697261235217292710: VariantsMap = [
    &["saxonizes"],
    &["saxonises"],
    &["saxonizes"],
    &["saxonises"],
];

pub(crate) static ENTRY_SAXONIZE_13364212151002980649: VariantsMap =
    [&["saxonize"], &["saxonise"], &["saxonize"], &["saxonise"]];

pub(crate) static ENTRY_SAXONIZING_8544121589253566200: VariantsMap = [
    &["saxonizing"],
    &["saxonising"],
    &["saxonizing"],
    &["saxonising"],
];

pub(crate) static ENTRY_SCANDALED_13447508330318483061: VariantsMap = [
    &["scandaled"],
    &["scandalled"],
    &["scandalled"],
    &["scandalled"],
];

pub(crate) static ENTRY_SCANDALING_17381730195382733089: VariantsMap = [
    &["scandaling"],
    &["scandalling"],
    &["scandalling"],
    &["scandalling"],
];

pub(crate) static ENTRY_SCANDALIZATIONS_18070074398119088194: VariantsMap = [
    &["scandalizations"],
    &["scandalisations"],
    &["scandalizations"],
    &["scandalisations"],
];

pub(crate) static ENTRY_SCANDALIZATION_9222246912531140529: VariantsMap = [
    &["scandalization"],
    &["scandalisation"],
    &["scandalization"],
    &["scandalisation"],
];

pub(crate) static ENTRY_SCANDALIZED_1748801122543387716: VariantsMap = [
    &["scandalized"],
    &["scandalised"],
    &["scandalized"],
    &["scandalised"],
];

pub(crate) static ENTRY_SCANDALIZERS_10866026711851385946: VariantsMap = [
    &["scandalizers"],
    &["scandalisers"],
    &["scandalizers"],
    &["scandalisers"],
];

pub(crate) static ENTRY_SCANDALIZER_8949328602594471198: VariantsMap = [
    &["scandalizer"],
    &["scandaliser"],
    &["scandalizer"],
    &["scandaliser"],
];

pub(crate) static ENTRY_SCANDALIZES_16055760817318112159: VariantsMap = [
    &["scandalizes"],
    &["scandalises"],
    &["scandalizes"],
    &["scandalises"],
];

pub(crate) static ENTRY_SCANDALIZE_13541782947542016266: VariantsMap = [
    &["scandalize"],
    &["scandalise"],
    &["scandalize"],
    &["scandalise"],
];

pub(crate) static ENTRY_SCANDALIZING_11160701382824581155: VariantsMap = [
    &["scandalizing"],
    &["scandalising"],
    &["scandalizing"],
    &["scandalising"],
];

pub(crate) static ENTRY_SCAPED_5422571681233921706: VariantsMap =
    [&["scaped"], &["scapaed"], &["scapaed"], &["scapaed"]];

pub(crate) static ENTRY_SCENARIOIZATIONS_6488389628134041935: VariantsMap = [
    &["scenarioizations"],
    &["scenarioisations"],
    &["scenarioizations"],
    &["scenarioisations"],
];

pub(crate) static ENTRY_SCENARIOIZATION_16935700652672688357: VariantsMap = [
    &["scenarioization"],
    &["scenarioisation"],
    &["scenarioization"],
    &["scenarioisation"],
];

pub(crate) static ENTRY_SCENARIOIZES_17849661175418143802: VariantsMap = [
    &["scenarioizes"],
    &["scenarioises"],
    &["scenarioizes"],
    &["scenarioises"],
];

pub(crate) static ENTRY_SCENARIOIZE_6929875542220577836: VariantsMap = [
    &["scenarioize"],
    &["scenarioise"],
    &["scenarioize"],
    &["scenarioise"],
];

pub(crate) static ENTRY_SCENARIZATIONS_8416960904420962205: VariantsMap = [
    &["scenarizations"],
    &["scenarisations"],
    &["scenarizations"],
    &["scenarisations"],
];

pub(crate) static ENTRY_SCENARIZATION_16780333325852212901: VariantsMap = [
    &["scenarization"],
    &["scenarisation"],
    &["scenarization"],
    &["scenarisation"],
];

pub(crate) static ENTRY_SCENARIZED_16018713122754577556: VariantsMap = [
    &["scenarized"],
    &["scenarised"],
    &["scenarized"],
    &["scenarised"],
];

pub(crate) static ENTRY_SCENARIZES_5261391273725049523: VariantsMap = [
    &["scenarizes"],
    &["scenarises"],
    &["scenarizes"],
    &["scenarises"],
];

pub(crate) static ENTRY_SCENARIZE_612234156285031284: VariantsMap = [
    &["scenarize"],
    &["scenarise"],
    &["scenarize"],
    &["scenarise"],
];

pub(crate) static ENTRY_SCENARIZING_14502398664421762166: VariantsMap = [
    &["scenarizing"],
    &["scenarising"],
    &["scenarizing"],
    &["scenarising"],
];

pub(crate) static ENTRY_SCENA_7141663492630230804: VariantsMap =
    [&["scena"], &["scaena"], &["scaena"], &["scaena"]];

pub(crate) static ENTRY_SCEPTERDOM_17153671406151972298: VariantsMap = [
    &["scepterdom"],
    &["sceptredom"],
    &["sceptredom"],
    &["sceptredom"],
];

pub(crate) static ENTRY_SCEPTERED_2583853657518887848: VariantsMap =
    [&["sceptered"], &["sceptred"], &["sceptred"], &["sceptred"]];

pub(crate) static ENTRY_SCEPTERING_12898998411155997054: VariantsMap = [
    &["sceptering"],
    &["sceptring"],
    &["sceptring"],
    &["sceptring"],
];

pub(crate) static ENTRY_SCEPTERLESSES_259863808993366250: VariantsMap = [
    &["scepterlesses"],
    &["sceptrelesses"],
    &["sceptrelesses"],
    &["sceptrelesses"],
];

pub(crate) static ENTRY_SCEPTERLESS_1514965292752739127: VariantsMap = [
    &["scepterless"],
    &["sceptreless"],
    &["sceptreless"],
    &["sceptreless"],
];

pub(crate) static ENTRY_SCEPTERS_11825573776001921342: VariantsMap =
    [&["scepters"], &["sceptres"], &["sceptres"], &["sceptres"]];

pub(crate) static ENTRY_SCEPTER_10836268721579569022: VariantsMap =
    [&["scepter"], &["sceptre"], &["sceptre"], &["sceptre"]];

pub(crate) static ENTRY_SCEVOR_10280777061871375909: VariantsMap =
    [&["scevor"], &["scevour"], &["scevour"], &["scevour"]];

pub(crate) static ENTRY_SCHEDULIZES_7182811045941826740: VariantsMap = [
    &["schedulizes"],
    &["schedulises"],
    &["schedulizes"],
    &["schedulises"],
];

pub(crate) static ENTRY_SCHEDULIZE_10874935272495009679: VariantsMap = [
    &["schedulize"],
    &["schedulise"],
    &["schedulize"],
    &["schedulise"],
];

pub(crate) static ENTRY_SCHEMATIZATIONS_6437769711305203183: VariantsMap = [
    &["schematizations"],
    &["schematisations"],
    &["schematizations"],
    &["schematisations"],
];

pub(crate) static ENTRY_SCHEMATIZATION_1676990775754888542: VariantsMap = [
    &["schematization"],
    &["schematisation"],
    &["schematization"],
    &["schematisation"],
];

pub(crate) static ENTRY_SCHEMATIZED_16870559659839470180: VariantsMap = [
    &["schematized"],
    &["schematised"],
    &["schematized"],
    &["schematised"],
];

pub(crate) static ENTRY_SCHEMATIZERS_6139126226910745642: VariantsMap = [
    &["schematizers"],
    &["schematisers"],
    &["schematizers"],
    &["schematisers"],
];

pub(crate) static ENTRY_SCHEMATIZER_9401704870795199962: VariantsMap = [
    &["schematizer"],
    &["schematiser"],
    &["schematizer"],
    &["schematiser"],
];

pub(crate) static ENTRY_SCHEMATIZES_5455806020883567582: VariantsMap = [
    &["schematizes"],
    &["schematises"],
    &["schematizes"],
    &["schematises"],
];

pub(crate) static ENTRY_SCHEMATIZE_16415111007074766296: VariantsMap = [
    &["schematize"],
    &["schematise"],
    &["schematize"],
    &["schematise"],
];

pub(crate) static ENTRY_SCHEMATIZING_17927667405052965293: VariantsMap = [
    &["schematizing"],
    &["schematising"],
    &["schematizing"],
    &["schematising"],
];

pub(crate) static ENTRY_SCHILLERIZATIONS_2065739841216795641: VariantsMap = [
    &["schillerizations"],
    &["schillerisations"],
    &["schillerizations"],
    &["schillerisations"],
];

pub(crate) static ENTRY_SCHILLERIZATION_134316338122380470: VariantsMap = [
    &["schillerization"],
    &["schillerisation"],
    &["schillerization"],
    &["schillerisation"],
];

pub(crate) static ENTRY_SCHILLERIZED_12056315487174553805: VariantsMap = [
    &["schillerized"],
    &["schillerised"],
    &["schillerized"],
    &["schillerised"],
];

pub(crate) static ENTRY_SCHILLERIZES_15680797582738987873: VariantsMap = [
    &["schillerizes"],
    &["schillerises"],
    &["schillerizes"],
    &["schillerises"],
];

pub(crate) static ENTRY_SCHILLERIZE_16984821653905669407: VariantsMap = [
    &["schillerize"],
    &["schillerise"],
    &["schillerize"],
    &["schillerise"],
];

pub(crate) static ENTRY_SCHILLERIZING_6452935797140422184: VariantsMap = [
    &["schillerizing"],
    &["schillerising"],
    &["schillerizing"],
    &["schillerising"],
];

pub(crate) static ENTRY_SCHISMATIZED_16555774757396136554: VariantsMap = [
    &["schismatized"],
    &["schismatised"],
    &["schismatized"],
    &["schismatised"],
];

pub(crate) static ENTRY_SCHISMATIZES_15571943244118334631: VariantsMap = [
    &["schismatizes"],
    &["schismatises"],
    &["schismatizes"],
    &["schismatises"],
];

pub(crate) static ENTRY_SCHISMATIZE_789908240245008611: VariantsMap = [
    &["schismatize"],
    &["schismatise"],
    &["schismatize"],
    &["schismatise"],
];

pub(crate) static ENTRY_SCHISMATIZING_159281964687958140: VariantsMap = [
    &["schismatizing"],
    &["schismatising"],
    &["schismatizing"],
    &["schismatising"],
];

pub(crate) static ENTRY_SCHISTOCELIA_10700792843711130495: VariantsMap = [
    &["schistocelia"],
    &["schistocoelia"],
    &["schistocoelia"],
    &["schistocoelia"],
];

pub(crate) static ENTRY_SCIENTIZED_8795047136761378602: VariantsMap = [
    &["scientized"],
    &["scientised"],
    &["scientized"],
    &["scientised"],
];

pub(crate) static ENTRY_SCIENTIZES_14454037718685233406: VariantsMap = [
    &["scientizes"],
    &["scientises"],
    &["scientizes"],
    &["scientises"],
];

pub(crate) static ENTRY_SCIENTIZE_3015765919608850300: VariantsMap = [
    &["scientize"],
    &["scientise"],
    &["scientize"],
    &["scientise"],
];

pub(crate) static ENTRY_SCIENTIZING_15664058513727181609: VariantsMap = [
    &["scientizing"],
    &["scientising"],
    &["scientizing"],
    &["scientising"],
];

pub(crate) static ENTRY_SCLERE_3253698441819495003: VariantsMap =
    [&["sclere"], &["sclerae"], &["sclerae"], &["sclerae"]];

pub(crate) static ENTRY_SCLEROTIZATION_12132292602417583411: VariantsMap = [
    &["sclerotization"],
    &["sclerotisation"],
    &["sclerotization"],
    &["sclerotisation"],
];

pub(crate) static ENTRY_SCLEROTIZED_6920544013290794768: VariantsMap = [
    &["sclerotized"],
    &["sclerotised"],
    &["sclerotized"],
    &["sclerotised"],
];

pub(crate) static ENTRY_SCLEROTIZES_7771756203222170673: VariantsMap = [
    &["sclerotizes"],
    &["sclerotises"],
    &["sclerotizes"],
    &["sclerotises"],
];

pub(crate) static ENTRY_SCLEROTIZE_11947136539548445360: VariantsMap = [
    &["sclerotize"],
    &["sclerotise"],
    &["sclerotize"],
    &["sclerotise"],
];

pub(crate) static ENTRY_SCLEROTIZING_14715970191611020497: VariantsMap = [
    &["sclerotizing"],
    &["sclerotising"],
    &["sclerotizing"],
    &["sclerotising"],
];

pub(crate) static ENTRY_SCORSED_17476659339722088518: VariantsMap =
    [&["scorsed"], &["scoursed"], &["scoursed"], &["scoursed"]];

pub(crate) static ENTRY_SCORSES_2194337448738300709: VariantsMap =
    [&["scorses"], &["scourses"], &["scourses"], &["scourses"]];

pub(crate) static ENTRY_SCORSE_6425350851486428184: VariantsMap =
    [&["scorse"], &["scourse"], &["scourse"], &["scourse"]];

pub(crate) static ENTRY_SCORSING_14138313440896393142: VariantsMap = [
    &["scorsing"],
    &["scoursing"],
    &["scoursing"],
    &["scoursing"],
];

pub(crate) static ENTRY_SCOTTICIZED_17337295302968105240: VariantsMap = [
    &["scotticized"],
    &["scotticised"],
    &["scotticized"],
    &["scotticised"],
];

pub(crate) static ENTRY_SCOTTICIZES_4917016627492614689: VariantsMap = [
    &["scotticizes"],
    &["scotticises"],
    &["scotticizes"],
    &["scotticises"],
];

pub(crate) static ENTRY_SCOTTICIZE_9983137950923071608: VariantsMap = [
    &["scotticize"],
    &["scotticise"],
    &["scotticize"],
    &["scotticise"],
];

pub(crate) static ENTRY_SCOTTICIZING_13323308695498031831: VariantsMap = [
    &["scotticizing"],
    &["scotticising"],
    &["scotticizing"],
    &["scotticising"],
];

pub(crate) static ENTRY_SCRIPTURALIZES_14898839521389524664: VariantsMap = [
    &["scripturalizes"],
    &["scripturalises"],
    &["scripturalizes"],
    &["scripturalises"],
];

pub(crate) static ENTRY_SCRIPTURALIZE_15833657682700552011: VariantsMap = [
    &["scripturalize"],
    &["scripturalise"],
    &["scripturalize"],
    &["scripturalise"],
];

pub(crate) static ENTRY_SCRUTINIZATIONS_15493523410837117880: VariantsMap = [
    &["scrutinizations"],
    &["scrutinisations"],
    &["scrutinizations"],
    &["scrutinisations"],
];

pub(crate) static ENTRY_SCRUTINIZATION_16840609583662225122: VariantsMap = [
    &["scrutinization"],
    &["scrutinisation"],
    &["scrutinization"],
    &["scrutinisation"],
];

pub(crate) static ENTRY_SCRUTINIZED_2329669763243403883: VariantsMap = [
    &["scrutinized"],
    &["scrutinised"],
    &["scrutinized"],
    &["scrutinised"],
];

pub(crate) static ENTRY_SCRUTINIZERS_4674596638392471916: VariantsMap = [
    &["scrutinizers"],
    &["scrutinisers"],
    &["scrutinizers"],
    &["scrutinisers"],
];

pub(crate) static ENTRY_SCRUTINIZER_1548201174107564828: VariantsMap = [
    &["scrutinizer"],
    &["scrutiniser"],
    &["scrutinizer"],
    &["scrutiniser"],
];

pub(crate) static ENTRY_SCRUTINIZES_7393741262112863368: VariantsMap = [
    &["scrutinizes"],
    &["scrutinises"],
    &["scrutinizes"],
    &["scrutinises"],
];

pub(crate) static ENTRY_SCRUTINIZE_11520578540425679510: VariantsMap = [
    &["scrutinize"],
    &["scrutinise"],
    &["scrutinize"],
    &["scrutinise"],
];

pub(crate) static ENTRY_SCRUTINIZINGLIES_5389671481721987146: VariantsMap = [
    &["scrutinizinglies"],
    &["scrutinisinglies"],
    &["scrutinizinglies"],
    &["scrutinisinglies"],
];

pub(crate) static ENTRY_SCRUTINIZINGLY_13749041840105641359: VariantsMap = [
    &["scrutinizingly"],
    &["scrutinisingly"],
    &["scrutinizingly"],
    &["scrutinisingly"],
];

pub(crate) static ENTRY_SCRUTINIZING_3883358635901547505: VariantsMap = [
    &["scrutinizing"],
    &["scrutinising"],
    &["scrutinizing"],
    &["scrutinising"],
];

pub(crate) static ENTRY_SEBORRHEAS_17664504842211561857: VariantsMap = [
    &["seborrheas"],
    &["seborrhoeas"],
    &["seborrheas"],
    &["seborrhoeas"],
];

pub(crate) static ENTRY_SEBORRHEA_8596487171579042968: VariantsMap = [
    &["seborrhea"],
    &["seborrhoea"],
    &["seborrhea"],
    &["seborrhoea"],
];

pub(crate) static ENTRY_SEBORRHEIC_14630913311363871280: VariantsMap = [
    &["seborrheic"],
    &["seborrhoeic"],
    &["seborrheic"],
    &["seborrhoeic"],
];

pub(crate) static ENTRY_SECTARIANIZATION_12976072257453381050: VariantsMap = [
    &["sectarianization"],
    &["sectarianisation"],
    &["sectarianization"],
    &["sectarianisation"],
];

pub(crate) static ENTRY_SECTARIANIZED_6103010511807662986: VariantsMap = [
    &["sectarianized"],
    &["sectarianised"],
    &["sectarianized"],
    &["sectarianised"],
];

pub(crate) static ENTRY_SECTARIANIZES_7057053753718900411: VariantsMap = [
    &["sectarianizes"],
    &["sectarianises"],
    &["sectarianizes"],
    &["sectarianises"],
];

pub(crate) static ENTRY_SECTARIANIZE_16393083304666129607: VariantsMap = [
    &["sectarianize"],
    &["sectarianise"],
    &["sectarianize"],
    &["sectarianise"],
];

pub(crate) static ENTRY_SECTARIANIZING_3380018019808154089: VariantsMap = [
    &["sectarianizing"],
    &["sectarianising"],
    &["sectarianizing"],
    &["sectarianising"],
];

pub(crate) static ENTRY_SECTIONALIZATIONS_16931298674891549325: VariantsMap = [
    &["sectionalizations"],
    &["sectionalisations"],
    &["sectionalizations"],
    &["sectionalisations"],
];

pub(crate) static ENTRY_SECTIONALIZATION_8994143807969832046: VariantsMap = [
    &["sectionalization"],
    &["sectionalisation"],
    &["sectionalization"],
    &["sectionalisation"],
];

pub(crate) static ENTRY_SECTIONALIZED_5043821153558608530: VariantsMap = [
    &["sectionalized"],
    &["sectionalised"],
    &["sectionalized"],
    &["sectionalised"],
];

pub(crate) static ENTRY_SECTIONALIZES_11528039426529780489: VariantsMap = [
    &["sectionalizes"],
    &["sectionalises"],
    &["sectionalizes"],
    &["sectionalises"],
];

pub(crate) static ENTRY_SECTIONALIZE_2892469613560393091: VariantsMap = [
    &["sectionalize"],
    &["sectionalise"],
    &["sectionalize"],
    &["sectionalise"],
];

pub(crate) static ENTRY_SECTIONALIZING_17081195346063464372: VariantsMap = [
    &["sectionalizing"],
    &["sectionalising"],
    &["sectionalizing"],
    &["sectionalising"],
];

pub(crate) static ENTRY_SECTIONIZATIONS_7729239148133443161: VariantsMap = [
    &["sectionizations"],
    &["sectionisations"],
    &["sectionizations"],
    &["sectionisations"],
];

pub(crate) static ENTRY_SECTIONIZATION_3542203323287588618: VariantsMap = [
    &["sectionization"],
    &["sectionisation"],
    &["sectionization"],
    &["sectionisation"],
];

pub(crate) static ENTRY_SECTIONIZED_9100640351478690576: VariantsMap = [
    &["sectionized"],
    &["sectionised"],
    &["sectionized"],
    &["sectionised"],
];

pub(crate) static ENTRY_SECTIONIZES_8159979574067150824: VariantsMap = [
    &["sectionizes"],
    &["sectionises"],
    &["sectionizes"],
    &["sectionises"],
];

pub(crate) static ENTRY_SECTIONIZE_135702157013527579: VariantsMap = [
    &["sectionize"],
    &["sectionise"],
    &["sectionize"],
    &["sectionise"],
];

pub(crate) static ENTRY_SECTIONIZING_10971605985402823462: VariantsMap = [
    &["sectionizing"],
    &["sectionising"],
    &["sectionizing"],
    &["sectionising"],
];

pub(crate) static ENTRY_SECTORIZATIONS_9647595832033172889: VariantsMap = [
    &["sectorizations"],
    &["sectorisations"],
    &["sectorizations"],
    &["sectorisations"],
];

pub(crate) static ENTRY_SECTORIZATION_12059149390774064762: VariantsMap = [
    &["sectorization"],
    &["sectorisation"],
    &["sectorization"],
    &["sectorisation"],
];

pub(crate) static ENTRY_SECTORIZED_663771891983790592: VariantsMap = [
    &["sectorized"],
    &["sectorised"],
    &["sectorized"],
    &["sectorised"],
];

pub(crate) static ENTRY_SECTORIZES_10751018475745966003: VariantsMap = [
    &["sectorizes"],
    &["sectorises"],
    &["sectorizes"],
    &["sectorises"],
];

pub(crate) static ENTRY_SECTORIZE_4436943247784100905: VariantsMap = [
    &["sectorize"],
    &["sectorise"],
    &["sectorize"],
    &["sectorise"],
];

pub(crate) static ENTRY_SECTORIZING_17569875759145214364: VariantsMap = [
    &["sectorizing"],
    &["sectorising"],
    &["sectorizing"],
    &["sectorising"],
];

pub(crate) static ENTRY_SECULARIZATIONS_4846586083503105748: VariantsMap = [
    &["secularizations"],
    &["secularisations"],
    &["secularizations"],
    &["secularisations"],
];

pub(crate) static ENTRY_SECULARIZATION_1401194994331432655: VariantsMap = [
    &["secularization"],
    &["secularisation"],
    &["secularization"],
    &["secularisation"],
];

pub(crate) static ENTRY_SECULARIZED_161249998284362054: VariantsMap = [
    &["secularized"],
    &["secularised"],
    &["secularized"],
    &["secularised"],
];

pub(crate) static ENTRY_SECULARIZERS_12036202493887613006: VariantsMap = [
    &["secularizers"],
    &["secularisers"],
    &["secularizers"],
    &["secularisers"],
];

pub(crate) static ENTRY_SECULARIZER_703425234980326759: VariantsMap = [
    &["secularizer"],
    &["seculariser"],
    &["secularizer"],
    &["seculariser"],
];

pub(crate) static ENTRY_SECULARIZES_14861150832754880137: VariantsMap = [
    &["secularizes"],
    &["secularises"],
    &["secularizes"],
    &["secularises"],
];

pub(crate) static ENTRY_SECULARIZE_7264705334185351711: VariantsMap = [
    &["secularize"],
    &["secularise"],
    &["secularize"],
    &["secularise"],
];

pub(crate) static ENTRY_SECULARIZING_13366387235044393553: VariantsMap = [
    &["secularizing"],
    &["secularising"],
    &["secularizing"],
    &["secularising"],
];

pub(crate) static ENTRY_SECULUMS_12763686042400892321: VariantsMap = [
    &["seculums"],
    &["saeculums"],
    &["saeculums"],
    &["saeculums"],
];

pub(crate) static ENTRY_SECULUM_12179969068630184099: VariantsMap =
    [&["seculum"], &["saeculum"], &["saeculum"], &["saeculum"]];

pub(crate) static ENTRY_SECURITIZATIONS_5197658227648288767: VariantsMap = [
    &["securitizations"],
    &["securitisations"],
    &["securitizations"],
    &["securitisations"],
];

pub(crate) static ENTRY_SECURITIZATION_5956894235563326762: VariantsMap = [
    &["securitization"],
    &["securitisation"],
    &["securitization"],
    &["securitisation"],
];

pub(crate) static ENTRY_SECURITIZED_6896218099194090741: VariantsMap = [
    &["securitized"],
    &["securitised"],
    &["securitized"],
    &["securitised"],
];

pub(crate) static ENTRY_SECURITIZES_8193678999474929494: VariantsMap = [
    &["securitizes"],
    &["securitises"],
    &["securitizes"],
    &["securitises"],
];

pub(crate) static ENTRY_SECURITIZE_2115071445948266576: VariantsMap = [
    &["securitize"],
    &["securitise"],
    &["securitize"],
    &["securitise"],
];

pub(crate) static ENTRY_SECURITIZING_10755138514200328235: VariantsMap = [
    &["securitizing"],
    &["securitising"],
    &["securitizing"],
    &["securitising"],
];

pub(crate) static ENTRY_SEED_14453242621235594627: VariantsMap =
    [&["seed"], &["saeed"], &["saeed"], &["saeed"]];

pub(crate) static ENTRY_SEIZABLE_1855846888387564832: VariantsMap =
    [&["seizable"], &["seisable"], &["seizable"], &["seisable"]];

pub(crate) static ENTRY_SEIZERS_7950705537771035669: VariantsMap =
    [&["seizers"], &["seisers"], &["seizers"], &["seisers"]];

pub(crate) static ENTRY_SEIZER_9955492685377349774: VariantsMap =
    [&["seizer"], &["seiser"], &["seizer"], &["seiser"]];

pub(crate) static ENTRY_SEIZINGS_13728841224695757549: VariantsMap =
    [&["seizings"], &["seisings"], &["seizings"], &["seisings"]];

pub(crate) static ENTRY_SEIZINS_14830746986050367965: VariantsMap =
    [&["seizins"], &["seisins"], &["seizins"], &["seisins"]];

pub(crate) static ENTRY_SEIZIN_6525758187177594826: VariantsMap =
    [&["seizin"], &["seisin"], &["seizin"], &["seisin"]];

pub(crate) static ENTRY_SELLE_11301556179355309569: VariantsMap =
    [&["selle"], &["sellae"], &["sellae"], &["sellae"]];

pub(crate) static ENTRY_SEMENOV_14619117840146490347: VariantsMap =
    [&["semenov"], &["semaenov"], &["semaenov"], &["semaenov"]];

pub(crate) static ENTRY_SEMIANESTHETIC_823301937707971043: VariantsMap = [
    &["semianesthetic"],
    &["semianaesthetic"],
    &["semianaesthetic"],
    &["semianaesthetic"],
];

pub(crate) static ENTRY_SEMICARBONIZES_3707173180511878930: VariantsMap = [
    &["semicarbonizes"],
    &["semicarbonises"],
    &["semicarbonizes"],
    &["semicarbonises"],
];

pub(crate) static ENTRY_SEMICARBONIZE_13810009207773718216: VariantsMap = [
    &["semicarbonize"],
    &["semicarbonise"],
    &["semicarbonize"],
    &["semicarbonise"],
];

pub(crate) static ENTRY_SEMICIVILIZATIONS_7291536769974182399: VariantsMap = [
    &["semicivilizations"],
    &["semicivilisations"],
    &["semicivilizations"],
    &["semicivilisations"],
];

pub(crate) static ENTRY_SEMICIVILIZATION_13989863526603166121: VariantsMap = [
    &["semicivilization"],
    &["semicivilisation"],
    &["semicivilization"],
    &["semicivilisation"],
];

pub(crate) static ENTRY_SEMICIVILIZEDS_623045016921370057: VariantsMap = [
    &["semicivilizeds"],
    &["semiciviliseds"],
    &["semicivilizeds"],
    &["semiciviliseds"],
];

pub(crate) static ENTRY_SEMICIVILIZED_15979322498261290823: VariantsMap = [
    &["semicivilized"],
    &["semicivilised"],
    &["semicivilized"],
    &["semicivilised"],
];

pub(crate) static ENTRY_SEMIFOSSILIZEDS_9469407920545194818: VariantsMap = [
    &["semifossilizeds"],
    &["semifossiliseds"],
    &["semifossilizeds"],
    &["semifossiliseds"],
];

pub(crate) static ENTRY_SEMIFOSSILIZED_3016621275622865217: VariantsMap = [
    &["semifossilized"],
    &["semifossilised"],
    &["semifossilized"],
    &["semifossilised"],
];

pub(crate) static ENTRY_SEMIHONORS_17348811193976953216: VariantsMap = [
    &["semihonors"],
    &["semihonours"],
    &["semihonours"],
    &["semihonours"],
];

pub(crate) static ENTRY_SEMIHONOR_15368829156943900844: VariantsMap = [
    &["semihonor"],
    &["semihonour"],
    &["semihonour"],
    &["semihonour"],
];

pub(crate) static ENTRY_SEMIHUMANIZEDS_8011721709170453644: VariantsMap = [
    &["semihumanizeds"],
    &["semihumaniseds"],
    &["semihumanizeds"],
    &["semihumaniseds"],
];

pub(crate) static ENTRY_SEMIHUMANIZED_2914623020115279300: VariantsMap = [
    &["semihumanized"],
    &["semihumanised"],
    &["semihumanized"],
    &["semihumanised"],
];

pub(crate) static ENTRY_SEMIMERCERIZEDS_8976044764636489500: VariantsMap = [
    &["semimercerizeds"],
    &["semimerceriseds"],
    &["semimercerizeds"],
    &["semimerceriseds"],
];

pub(crate) static ENTRY_SEMIMERCERIZED_9589423828734279207: VariantsMap = [
    &["semimercerized"],
    &["semimercerised"],
    &["semimercerized"],
    &["semimercerised"],
];

pub(crate) static ENTRY_SEMIMINERALIZEDS_10516461058680893657: VariantsMap = [
    &["semimineralizeds"],
    &["semimineraliseds"],
    &["semimineralizeds"],
    &["semimineraliseds"],
];

pub(crate) static ENTRY_SEMIMINERALIZED_7730798044526104284: VariantsMap = [
    &["semimineralized"],
    &["semimineralised"],
    &["semimineralized"],
    &["semimineralised"],
];

pub(crate) static ENTRY_SEMINARIZES_16026061575781055708: VariantsMap = [
    &["seminarizes"],
    &["seminarises"],
    &["seminarizes"],
    &["seminarises"],
];

pub(crate) static ENTRY_SEMINARIZE_5202720038995798338: VariantsMap = [
    &["seminarize"],
    &["seminarise"],
    &["seminarize"],
    &["seminarise"],
];

pub(crate) static ENTRY_SEMINATIONALIZATIONS_1834004725503573613: VariantsMap = [
    &["seminationalizations"],
    &["seminationalisations"],
    &["seminationalizations"],
    &["seminationalisations"],
];

pub(crate) static ENTRY_SEMINATIONALIZATION_825484772724238043: VariantsMap = [
    &["seminationalization"],
    &["seminationalisation"],
    &["seminationalization"],
    &["seminationalisation"],
];

pub(crate) static ENTRY_SEMIORGANIZEDS_16199433115149437804: VariantsMap = [
    &["semiorganizeds"],
    &["semiorganiseds"],
    &["semiorganizeds"],
    &["semiorganiseds"],
];

pub(crate) static ENTRY_SEMIORGANIZED_18310435920283296471: VariantsMap = [
    &["semiorganized"],
    &["semiorganised"],
    &["semiorganized"],
    &["semiorganised"],
];

pub(crate) static ENTRY_SEMIOXIDIZEDS_10078920474925941546: VariantsMap = [
    &["semioxidizeds"],
    &["semioxidiseds"],
    &["semioxidizeds"],
    &["semioxidiseds"],
];

pub(crate) static ENTRY_SEMIOXIDIZED_2254782022495988687: VariantsMap = [
    &["semioxidized"],
    &["semioxidised"],
    &["semioxidized"],
    &["semioxidised"],
];

pub(crate) static ENTRY_SEMIOXYGENIZEDS_3977169223060896833: VariantsMap = [
    &["semioxygenizeds"],
    &["semioxygeniseds"],
    &["semioxygenizeds"],
    &["semioxygeniseds"],
];

pub(crate) static ENTRY_SEMIOXYGENIZED_15102443189044001018: VariantsMap = [
    &["semioxygenized"],
    &["semioxygenised"],
    &["semioxygenized"],
    &["semioxygenised"],
];

pub(crate) static ENTRY_SEMIPROFESSIONALIZEDS_5400190535233560894: VariantsMap = [
    &["semiprofessionalizeds"],
    &["semiprofessionaliseds"],
    &["semiprofessionalizeds"],
    &["semiprofessionaliseds"],
];

pub(crate) static ENTRY_SEMIPROFESSIONALIZED_928014397042474559: VariantsMap = [
    &["semiprofessionalized"],
    &["semiprofessionalised"],
    &["semiprofessionalized"],
    &["semiprofessionalised"],
];

pub(crate) static ENTRY_SEMITE_11088742112426344288: VariantsMap =
    [&["semite"], &["semitae"], &["semitae"], &["semitae"]];

pub(crate) static ENTRY_SEMITICIZES_1495676230430654195: VariantsMap = [
    &["semiticizes"],
    &["semiticises"],
    &["semiticizes"],
    &["semiticises"],
];

pub(crate) static ENTRY_SEMITICIZE_14062898150721821296: VariantsMap = [
    &["semiticize"],
    &["semiticise"],
    &["semiticize"],
    &["semiticise"],
];

pub(crate) static ENTRY_SEMITIZATIONS_12431457653239318845: VariantsMap = [
    &["semitizations"],
    &["semitisations"],
    &["semitizations"],
    &["semitisations"],
];

pub(crate) static ENTRY_SEMITIZATION_8277205050971024513: VariantsMap = [
    &["semitization"],
    &["semitisation"],
    &["semitization"],
    &["semitisation"],
];

pub(crate) static ENTRY_SEMITIZED_11743352918617854492: VariantsMap = [
    &["semitized"],
    &["semitised"],
    &["semitized"],
    &["semitised"],
];

pub(crate) static ENTRY_SEMITIZES_6676886808639923004: VariantsMap = [
    &["semitizes"],
    &["semitises"],
    &["semitizes"],
    &["semitises"],
];

pub(crate) static ENTRY_SEMITIZE_8166397051897052089: VariantsMap =
    [&["semitize"], &["semitise"], &["semitize"], &["semitise"]];

pub(crate) static ENTRY_SEMITIZING_8744181270211508639: VariantsMap = [
    &["semitizing"],
    &["semitising"],
    &["semitizing"],
    &["semitising"],
];

pub(crate) static ENTRY_SEMIVULCANIZEDS_8588430062086262347: VariantsMap = [
    &["semivulcanizeds"],
    &["semivulcaniseds"],
    &["semivulcanizeds"],
    &["semivulcaniseds"],
];

pub(crate) static ENTRY_SEMIVULCANIZED_282808961308474752: VariantsMap = [
    &["semivulcanized"],
    &["semivulcanised"],
    &["semivulcanized"],
    &["semivulcanised"],
];

pub(crate) static ENTRY_SEMPER_10634656891860887703: VariantsMap =
    [&["semper"], &["sempre"], &["sempre"], &["sempre"]];

pub(crate) static ENTRY_SENILIZES_2053465569367189725: VariantsMap = [
    &["senilizes"],
    &["senilises"],
    &["senilizes"],
    &["senilises"],
];

pub(crate) static ENTRY_SENILIZE_12369499446345492928: VariantsMap =
    [&["senilize"], &["senilise"], &["senilize"], &["senilise"]];

pub(crate) static ENTRY_SENSATIONALIZED_806729255320749316: VariantsMap = [
    &["sensationalized"],
    &["sensationalised"],
    &["sensationalized"],
    &["sensationalised"],
];

pub(crate) static ENTRY_SENSATIONALIZES_1873975152603613564: VariantsMap = [
    &["sensationalizes"],
    &["sensationalises"],
    &["sensationalizes"],
    &["sensationalises"],
];

pub(crate) static ENTRY_SENSATIONALIZE_4701218119855164579: VariantsMap = [
    &["sensationalize"],
    &["sensationalise"],
    &["sensationalize"],
    &["sensationalise"],
];

pub(crate) static ENTRY_SENSATIONALIZING_16018544793631553710: VariantsMap = [
    &["sensationalizing"],
    &["sensationalising"],
    &["sensationalizing"],
    &["sensationalising"],
];

pub(crate) static ENTRY_SENSITIZATIONS_3771550480827878176: VariantsMap = [
    &["sensitizations"],
    &["sensitisations"],
    &["sensitizations"],
    &["sensitisations"],
];

pub(crate) static ENTRY_SENSITIZATION_17980445782706254952: VariantsMap = [
    &["sensitization"],
    &["sensitisation"],
    &["sensitization"],
    &["sensitisation"],
];

pub(crate) static ENTRY_SENSITIZED_3723688270446372923: VariantsMap = [
    &["sensitized"],
    &["sensitised"],
    &["sensitized"],
    &["sensitised"],
];

pub(crate) static ENTRY_SENSITIZERS_837347902048952541: VariantsMap = [
    &["sensitizers"],
    &["sensitisers"],
    &["sensitizers"],
    &["sensitisers"],
];

pub(crate) static ENTRY_SENSITIZER_13590195476574032900: VariantsMap = [
    &["sensitizer"],
    &["sensitiser"],
    &["sensitizer"],
    &["sensitiser"],
];

pub(crate) static ENTRY_SENSITIZES_1732547089436557908: VariantsMap = [
    &["sensitizes"],
    &["sensitises"],
    &["sensitizes"],
    &["sensitises"],
];

pub(crate) static ENTRY_SENSITIZE_16896529045122621888: VariantsMap = [
    &["sensitize"],
    &["sensitise"],
    &["sensitize"],
    &["sensitise"],
];

pub(crate) static ENTRY_SENSITIZING_2002820405955253385: VariantsMap = [
    &["sensitizing"],
    &["sensitising"],
    &["sensitizing"],
    &["sensitising"],
];

pub(crate) static ENTRY_SENSIZES_14356006171802679244: VariantsMap =
    [&["sensizes"], &["sensises"], &["sensizes"], &["sensises"]];

pub(crate) static ENTRY_SENSIZE_8524073416014383146: VariantsMap =
    [&["sensize"], &["sensise"], &["sensize"], &["sensise"]];

pub(crate) static ENTRY_SENSUALIZATIONS_5360556874155531727: VariantsMap = [
    &["sensualizations"],
    &["sensualisations"],
    &["sensualizations"],
    &["sensualisations"],
];

pub(crate) static ENTRY_SENSUALIZATION_1493652745290082889: VariantsMap = [
    &["sensualization"],
    &["sensualisation"],
    &["sensualization"],
    &["sensualisation"],
];

pub(crate) static ENTRY_SENSUALIZED_5037909159991545251: VariantsMap = [
    &["sensualized"],
    &["sensualised"],
    &["sensualized"],
    &["sensualised"],
];

pub(crate) static ENTRY_SENSUALIZES_276828862031219211: VariantsMap = [
    &["sensualizes"],
    &["sensualises"],
    &["sensualizes"],
    &["sensualises"],
];

pub(crate) static ENTRY_SENSUALIZE_430137685449901167: VariantsMap = [
    &["sensualize"],
    &["sensualise"],
    &["sensualize"],
    &["sensualise"],
];

pub(crate) static ENTRY_SENSUALIZING_5522084897844086892: VariantsMap = [
    &["sensualizing"],
    &["sensualising"],
    &["sensualizing"],
    &["sensualising"],
];

pub(crate) static ENTRY_SENTIMENTALIZATIONS_13391940016403046982: VariantsMap = [
    &["sentimentalizations"],
    &["sentimentalisations"],
    &["sentimentalizations"],
    &["sentimentalisations"],
];

pub(crate) static ENTRY_SENTIMENTALIZATION_5296627102104537727: VariantsMap = [
    &["sentimentalization"],
    &["sentimentalisation"],
    &["sentimentalization"],
    &["sentimentalisation"],
];

pub(crate) static ENTRY_SENTIMENTALIZED_16225167419707712005: VariantsMap = [
    &["sentimentalized"],
    &["sentimentalised"],
    &["sentimentalized"],
    &["sentimentalised"],
];

pub(crate) static ENTRY_SENTIMENTALIZERS_13129655732030104575: VariantsMap = [
    &["sentimentalizers"],
    &["sentimentalisers"],
    &["sentimentalizers"],
    &["sentimentalisers"],
];

pub(crate) static ENTRY_SENTIMENTALIZER_4660675232906083328: VariantsMap = [
    &["sentimentalizer"],
    &["sentimentaliser"],
    &["sentimentalizer"],
    &["sentimentaliser"],
];

pub(crate) static ENTRY_SENTIMENTALIZES_16806348349169501348: VariantsMap = [
    &["sentimentalizes"],
    &["sentimentalises"],
    &["sentimentalizes"],
    &["sentimentalises"],
];

pub(crate) static ENTRY_SENTIMENTALIZE_12182871308532479588: VariantsMap = [
    &["sentimentalize"],
    &["sentimentalise"],
    &["sentimentalize"],
    &["sentimentalise"],
];

pub(crate) static ENTRY_SENTIMENTALIZING_5876768100471681381: VariantsMap = [
    &["sentimentalizing"],
    &["sentimentalising"],
    &["sentimentalizing"],
    &["sentimentalising"],
];

pub(crate) static ENTRY_SENTINELED_6442518344888461295: VariantsMap = [
    &["sentineled"],
    &["sentinelled"],
    &["sentinelled"],
    &["sentinelled"],
];

pub(crate) static ENTRY_SENTINELING_14720322458455305272: VariantsMap = [
    &["sentineling"],
    &["sentinelling"],
    &["sentinelling"],
    &["sentinelling"],
];

pub(crate) static ENTRY_SEPALEDDER_6673085543385038929: VariantsMap = [
    &["sepaledder"],
    &["sepalledder"],
    &["sepalledder"],
    &["sepalledder"],
];

pub(crate) static ENTRY_SEPALEDDEST_12097552973541005872: VariantsMap = [
    &["sepaleddest"],
    &["sepalleddest"],
    &["sepalleddest"],
    &["sepalleddest"],
];

pub(crate) static ENTRY_SEPALED_15484596063198794816: VariantsMap =
    [&["sepaled"], &["sepalled"], &["sepalled"], &["sepalled"]];

pub(crate) static ENTRY_SEPTEMBRIZERS_10748414663128787013: VariantsMap = [
    &["septembrizers"],
    &["septembrisers"],
    &["septembrizers"],
    &["septembrisers"],
];

pub(crate) static ENTRY_SEPTEMBRIZER_16399780356335894385: VariantsMap = [
    &["septembrizer"],
    &["septembriser"],
    &["septembrizer"],
    &["septembriser"],
];

pub(crate) static ENTRY_SEPTEMIA_9642046550000795259: VariantsMap = [
    &["septemia"],
    &["septaemia"],
    &["septaemia"],
    &["septaemia"],
];

pub(crate) static ENTRY_SEPTICEMIAS_8755899979809830376: VariantsMap = [
    &["septicemias"],
    &["septicaemias"],
    &["septicemias"],
    &["septicaemias"],
];

pub(crate) static ENTRY_SEPTICEMIA_15776803637197261182: VariantsMap = [
    &["septicemia"],
    &["septicaemia"],
    &["septicemia"],
    &["septicaemia"],
];

pub(crate) static ENTRY_SEPTICEMIC_16980008368837900987: VariantsMap = [
    &["septicemic"],
    &["septicaemic"],
    &["septicemic"],
    &["septicaemic"],
];

pub(crate) static ENTRY_SEPTICIZATIONS_13575411557314464650: VariantsMap = [
    &["septicizations"],
    &["septicisations"],
    &["septicizations"],
    &["septicisations"],
];

pub(crate) static ENTRY_SEPTICIZATION_3461417299775827388: VariantsMap = [
    &["septicization"],
    &["septicisation"],
    &["septicization"],
    &["septicisation"],
];

pub(crate) static ENTRY_SEPTICOLORED_11519724559149837993: VariantsMap = [
    &["septicolored"],
    &["septicoloured"],
    &["septicoloured"],
    &["septicoloured"],
];

pub(crate) static ENTRY_SEPULCHERED_6261011539804735837: VariantsMap = [
    &["sepulchered"],
    &["sepulchred"],
    &["sepulchred"],
    &["sepulchred"],
];

pub(crate) static ENTRY_SEPULCHERING_13256373528547912718: VariantsMap = [
    &["sepulchering"],
    &["sepulchring"],
    &["sepulchring"],
    &["sepulchring"],
];

pub(crate) static ENTRY_SEPULCHERS_1058787016282390839: VariantsMap = [
    &["sepulchers"],
    &["sepulchres"],
    &["sepulchres"],
    &["sepulchres"],
];

pub(crate) static ENTRY_SEPULCHER_18098224318037396545: VariantsMap = [
    &["sepulcher"],
    &["sepulchre"],
    &["sepulchre"],
    &["sepulchre"],
];

pub(crate) static ENTRY_SEPULCHRALIZES_1315744044961412030: VariantsMap = [
    &["sepulchralizes"],
    &["sepulchralises"],
    &["sepulchralizes"],
    &["sepulchralises"],
];

pub(crate) static ENTRY_SEPULCHRALIZE_3486930743664728261: VariantsMap = [
    &["sepulchralize"],
    &["sepulchralise"],
    &["sepulchralize"],
    &["sepulchralise"],
];

pub(crate) static ENTRY_SEQUENTIALIZED_5743547481042663813: VariantsMap = [
    &["sequentialized"],
    &["sequentialised"],
    &["sequentialized"],
    &["sequentialised"],
];

pub(crate) static ENTRY_SEQUENTIALIZES_6402661231343709343: VariantsMap = [
    &["sequentializes"],
    &["sequentialises"],
    &["sequentializes"],
    &["sequentialises"],
];

pub(crate) static ENTRY_SEQUENTIALIZE_4889381684174254167: VariantsMap = [
    &["sequentialize"],
    &["sequentialise"],
    &["sequentialize"],
    &["sequentialise"],
];

pub(crate) static ENTRY_SEQUENTIALIZING_10448549330716259346: VariantsMap = [
    &["sequentializing"],
    &["sequentialising"],
    &["sequentializing"],
    &["sequentialising"],
];

pub(crate) static ENTRY_SERENIZES_14020572670898554700: VariantsMap = [
    &["serenizes"],
    &["serenises"],
    &["serenizes"],
    &["serenises"],
];

pub(crate) static ENTRY_SERENIZE_12001453234621020080: VariantsMap =
    [&["serenize"], &["serenise"], &["serenize"], &["serenise"]];

pub(crate) static ENTRY_SERIALIZABILITY_2901340955314747428: VariantsMap = [
    &["serializability"],
    &["serialisability"],
    &["serializability"],
    &["serialisability"],
];

pub(crate) static ENTRY_SERIALIZABLE_14197036745650348974: VariantsMap = [
    &["serializable"],
    &["serialisable"],
    &["serializable"],
    &["serialisable"],
];

pub(crate) static ENTRY_SERIALIZATIONS_706918596756843003: VariantsMap = [
    &["serializations"],
    &["serialisations"],
    &["serializations"],
    &["serialisations"],
];

pub(crate) static ENTRY_SERIALIZATION_9018956433699872037: VariantsMap = [
    &["serialization"],
    &["serialisation"],
    &["serialization"],
    &["serialisation"],
];

pub(crate) static ENTRY_SERIALIZED_8728958192744003140: VariantsMap = [
    &["serialized"],
    &["serialised"],
    &["serialized"],
    &["serialised"],
];

pub(crate) static ENTRY_SERIALIZES_3430793096929337696: VariantsMap = [
    &["serializes"],
    &["serialises"],
    &["serializes"],
    &["serialises"],
];

pub(crate) static ENTRY_SERIALIZE_14877336825166275236: VariantsMap = [
    &["serialize"],
    &["serialise"],
    &["serialize"],
    &["serialise"],
];

pub(crate) static ENTRY_SERIALIZING_2676257449327141209: VariantsMap = [
    &["serializing"],
    &["serialising"],
    &["serializing"],
    &["serialising"],
];

pub(crate) static ENTRY_SERICITIZATIONS_5772088053388220545: VariantsMap = [
    &["sericitizations"],
    &["sericitisations"],
    &["sericitizations"],
    &["sericitisations"],
];

pub(crate) static ENTRY_SERICITIZATION_6928797851395804305: VariantsMap = [
    &["sericitization"],
    &["sericitisation"],
    &["sericitization"],
    &["sericitisation"],
];

pub(crate) static ENTRY_SERMONIZED_16528095817328710811: VariantsMap = [
    &["sermonized"],
    &["sermonised"],
    &["sermonized"],
    &["sermonised"],
];

pub(crate) static ENTRY_SERMONIZERS_8038249026909210325: VariantsMap = [
    &["sermonizers"],
    &["sermonisers"],
    &["sermonizers"],
    &["sermonisers"],
];

pub(crate) static ENTRY_SERMONIZER_16673411385474735084: VariantsMap = [
    &["sermonizer"],
    &["sermoniser"],
    &["sermonizer"],
    &["sermoniser"],
];

pub(crate) static ENTRY_SERMONIZES_6019643563928317531: VariantsMap = [
    &["sermonizes"],
    &["sermonises"],
    &["sermonizes"],
    &["sermonises"],
];

pub(crate) static ENTRY_SERMONIZE_18313527686432697628: VariantsMap = [
    &["sermonize"],
    &["sermonise"],
    &["sermonize"],
    &["sermonise"],
];

pub(crate) static ENTRY_SERMONIZING_11733933952570021776: VariantsMap = [
    &["sermonizing"],
    &["sermonising"],
    &["sermonizing"],
    &["sermonising"],
];

pub(crate) static ENTRY_SEROSE_15041909330080212209: VariantsMap =
    [&["serose"], &["serosae"], &["serosae"], &["serosae"]];

pub(crate) static ENTRY_SERPENTINIZATIONS_3391153694184367633: VariantsMap = [
    &["serpentinizations"],
    &["serpentinisations"],
    &["serpentinizations"],
    &["serpentinisations"],
];

pub(crate) static ENTRY_SERPENTINIZATION_9829957253632791760: VariantsMap = [
    &["serpentinization"],
    &["serpentinisation"],
    &["serpentinization"],
    &["serpentinisation"],
];

pub(crate) static ENTRY_SERPENTINIZED_12473002222530130063: VariantsMap = [
    &["serpentinized"],
    &["serpentinised"],
    &["serpentinized"],
    &["serpentinised"],
];

pub(crate) static ENTRY_SERPENTINIZES_16474636750177010671: VariantsMap = [
    &["serpentinizes"],
    &["serpentinises"],
    &["serpentinizes"],
    &["serpentinises"],
];

pub(crate) static ENTRY_SERPENTINIZE_1811085745125406816: VariantsMap = [
    &["serpentinize"],
    &["serpentinise"],
    &["serpentinize"],
    &["serpentinise"],
];

pub(crate) static ENTRY_SERPENTINIZING_9060243995269023975: VariantsMap = [
    &["serpentinizing"],
    &["serpentinising"],
    &["serpentinizing"],
    &["serpentinising"],
];

pub(crate) static ENTRY_SERPENTIZED_5901889149718624116: VariantsMap = [
    &["serpentized"],
    &["serpentised"],
    &["serpentized"],
    &["serpentised"],
];

pub(crate) static ENTRY_SERPENTIZES_15216974143628036729: VariantsMap = [
    &["serpentizes"],
    &["serpentises"],
    &["serpentizes"],
    &["serpentises"],
];

pub(crate) static ENTRY_SERPENTIZE_9368493021913509820: VariantsMap = [
    &["serpentize"],
    &["serpentise"],
    &["serpentize"],
    &["serpentise"],
];

pub(crate) static ENTRY_SERPENTIZING_16905186458845868642: VariantsMap = [
    &["serpentizing"],
    &["serpentising"],
    &["serpentizing"],
    &["serpentising"],
];

pub(crate) static ENTRY_SERRE_6762410384344039142: VariantsMap =
    [&["serre"], &["serrae"], &["serrae"], &["serrae"]];

pub(crate) static ENTRY_SERVILIZES_7385999730899631756: VariantsMap = [
    &["servilizes"],
    &["servilises"],
    &["servilizes"],
    &["servilises"],
];

pub(crate) static ENTRY_SERVILIZE_4512021424516865543: VariantsMap = [
    &["servilize"],
    &["servilise"],
    &["servilize"],
    &["servilise"],
];

pub(crate) static ENTRY_SETA_4750865609556121705: VariantsMap =
    [&["seta"], &["saeta"], &["saeta"], &["saeta"]];

pub(crate) static ENTRY_SETULE_15910434941710819225: VariantsMap =
    [&["setule"], &["setulae"], &["setulae"], &["setulae"]];

pub(crate) static ENTRY_SEVERALIZES_5073872488479172899: VariantsMap = [
    &["severalizes"],
    &["severalises"],
    &["severalizes"],
    &["severalises"],
];

pub(crate) static ENTRY_SEVERALIZE_14052775679136748529: VariantsMap = [
    &["severalize"],
    &["severalise"],
    &["severalize"],
    &["severalise"],
];

pub(crate) static ENTRY_SEVERIZATIONS_5864988201028711544: VariantsMap = [
    &["severizations"],
    &["severisations"],
    &["severizations"],
    &["severisations"],
];

pub(crate) static ENTRY_SEVERIZATION_1893546899787607297: VariantsMap = [
    &["severization"],
    &["severisation"],
    &["severization"],
    &["severisation"],
];

pub(crate) static ENTRY_SEVERIZES_16060800636195176489: VariantsMap = [
    &["severizes"],
    &["severises"],
    &["severizes"],
    &["severises"],
];

pub(crate) static ENTRY_SEVERIZE_10295931794707417929: VariantsMap =
    [&["severize"], &["severise"], &["severize"], &["severise"]];

pub(crate) static ENTRY_SEXUALIZATIONS_15890042718324864455: VariantsMap = [
    &["sexualizations"],
    &["sexualisations"],
    &["sexualizations"],
    &["sexualisations"],
];

pub(crate) static ENTRY_SEXUALIZATION_6593254506734364117: VariantsMap = [
    &["sexualization"],
    &["sexualisation"],
    &["sexualization"],
    &["sexualisation"],
];

pub(crate) static ENTRY_SEXUALIZED_7233396045217103694: VariantsMap = [
    &["sexualized"],
    &["sexualised"],
    &["sexualized"],
    &["sexualised"],
];

pub(crate) static ENTRY_SEXUALIZES_17468618530381395484: VariantsMap = [
    &["sexualizes"],
    &["sexualises"],
    &["sexualizes"],
    &["sexualises"],
];

pub(crate) static ENTRY_SEXUALIZE_17072767684675942947: VariantsMap = [
    &["sexualize"],
    &["sexualise"],
    &["sexualize"],
    &["sexualise"],
];

pub(crate) static ENTRY_SEXUALIZING_6218289575449577000: VariantsMap = [
    &["sexualizing"],
    &["sexualising"],
    &["sexualizing"],
    &["sexualising"],
];

pub(crate) static ENTRY_SE_11935408519795320676: VariantsMap =
    [&["se"], &["sae"], &["sae"], &["sae"]];

pub(crate) static ENTRY_SE_7678721039302187964: VariantsMap =
    [&["se"], &["soe"], &["soe"], &["soe"]];

pub(crate) static ENTRY_SHAKESPEARIZES_13232054948447801950: VariantsMap = [
    &["shakespearizes"],
    &["shakespearises"],
    &["shakespearizes"],
    &["shakespearises"],
];

pub(crate) static ENTRY_SHAKESPEARIZE_16270945198431067427: VariantsMap = [
    &["shakespearize"],
    &["shakespearise"],
    &["shakespearize"],
    &["shakespearise"],
];

pub(crate) static ENTRY_SHEIKHS_15546350165137358568: VariantsMap =
    [&["sheikhs"], &["sheikhs"], &["sheiks"], &["sheikhs"]];

pub(crate) static ENTRY_SHEIKH_9141106394100021739: VariantsMap =
    [&["sheikh"], &["sheikh"], &["sheik"], &["sheikh"]];

pub(crate) static ENTRY_SHEPHERDIZES_6181398903864334578: VariantsMap = [
    &["shepherdizes"],
    &["shepherdises"],
    &["shepherdizes"],
    &["shepherdises"],
];

pub(crate) static ENTRY_SHEPHERDIZE_1030130588786935026: VariantsMap = [
    &["shepherdize"],
    &["shepherdise"],
    &["shepherdize"],
    &["shepherdise"],
];

pub(crate) static ENTRY_SHERARDIZED_18190646217667716189: VariantsMap = [
    &["sherardized"],
    &["sherardised"],
    &["sherardized"],
    &["sherardised"],
];

pub(crate) static ENTRY_SHERARDIZES_13290046997374044082: VariantsMap = [
    &["sherardizes"],
    &["sherardises"],
    &["sherardizes"],
    &["sherardises"],
];

pub(crate) static ENTRY_SHERARDIZE_1843370089394724312: VariantsMap = [
    &["sherardize"],
    &["sherardise"],
    &["sherardize"],
    &["sherardise"],
];

pub(crate) static ENTRY_SHERARDIZING_16862661672440469221: VariantsMap = [
    &["sherardizing"],
    &["sherardising"],
    &["sherardizing"],
    &["sherardising"],
];

pub(crate) static ENTRY_SHERE_2828859166071306026: VariantsMap =
    [&["shere"], &["shree"], &["shree"], &["shree"]];

pub(crate) static ENTRY_SHER_11001556963296793208: VariantsMap =
    [&["sher"], &["shoer"], &["shoer"], &["shoer"]];

pub(crate) static ENTRY_SHINTOIZES_13727928026222091373: VariantsMap = [
    &["shintoizes"],
    &["shintoises"],
    &["shintoizes"],
    &["shintoises"],
];

pub(crate) static ENTRY_SHINTOIZE_8949418280207264230: VariantsMap = [
    &["shintoize"],
    &["shintoise"],
    &["shintoize"],
    &["shintoise"],
];

pub(crate) static ENTRY_SHKODER_16753247486709071984: VariantsMap =
    [&["shkoder"], &["shkodaer"], &["shkodaer"], &["shkodaer"]];

pub(crate) static ENTRY_SHOVELED_10216188925046182061: VariantsMap = [
    &["shoveled"],
    &["shovelled"],
    &["shovelled"],
    &["shovelled"],
];

pub(crate) static ENTRY_SHOVELERS_9645466719000067881: VariantsMap = [
    &["shovelers"],
    &["shovellers"],
    &["shovellers"],
    &["shovellers"],
];

pub(crate) static ENTRY_SHOVELER_16005482335483577091: VariantsMap = [
    &["shoveler"],
    &["shoveller"],
    &["shoveller"],
    &["shoveller"],
];

pub(crate) static ENTRY_SHOVELING_6097820986538846736: VariantsMap = [
    &["shoveling"],
    &["shovelling"],
    &["shovelling"],
    &["shovelling"],
];

pub(crate) static ENTRY_SHRIVELED_14279328409283350057: VariantsMap = [
    &["shriveled"],
    &["shrivelled"],
    &["shrivelled"],
    &["shrivelled"],
];

pub(crate) static ENTRY_SHRIVELING_7338996136982496684: VariantsMap = [
    &["shriveling"],
    &["shrivelling"],
    &["shrivelling"],
    &["shrivelling"],
];

pub(crate) static ENTRY_SIALORRHEA_9719044074471805009: VariantsMap = [
    &["sialorrhea"],
    &["sialorrhoea"],
    &["sialorrhoea"],
    &["sialorrhoea"],
];

pub(crate) static ENTRY_SIDEREALIZES_1405854832835173047: VariantsMap = [
    &["siderealizes"],
    &["siderealises"],
    &["siderealizes"],
    &["siderealises"],
];

pub(crate) static ENTRY_SIDEREALIZE_12293095375311999620: VariantsMap = [
    &["siderealize"],
    &["siderealise"],
    &["siderealize"],
    &["siderealise"],
];

pub(crate) static ENTRY_SIGNALED_3243424452669156037: VariantsMap = [
    &["signaled"],
    &["signalled"],
    &["signalled"],
    &["signalled"],
];

pub(crate) static ENTRY_SIGNALERS_12534746997930214169: VariantsMap = [
    &["signalers"],
    &["signallers"],
    &["signallers"],
    &["signallers"],
];

pub(crate) static ENTRY_SIGNALER_16546374588847832384: VariantsMap = [
    &["signaler"],
    &["signaller"],
    &["signaller"],
    &["signaller"],
];

pub(crate) static ENTRY_SIGNALING_10001000836087480137: VariantsMap = [
    &["signaling"],
    &["signalling"],
    &["signalling"],
    &["signalling"],
];

pub(crate) static ENTRY_SIGNALIZATION_13938195653404510955: VariantsMap = [
    &["signalization"],
    &["signalisation"],
    &["signalization"],
    &["signalisation"],
];

pub(crate) static ENTRY_SIGNALIZED_5398549010551729806: VariantsMap = [
    &["signalized"],
    &["signalised"],
    &["signalized"],
    &["signalised"],
];

pub(crate) static ENTRY_SIGNALIZES_1856971438891156446: VariantsMap = [
    &["signalizes"],
    &["signalises"],
    &["signalizes"],
    &["signalises"],
];

pub(crate) static ENTRY_SIGNALIZE_12255243066024468014: VariantsMap = [
    &["signalize"],
    &["signalise"],
    &["signalize"],
    &["signalise"],
];

pub(crate) static ENTRY_SIGNALIZING_2418286646902711346: VariantsMap = [
    &["signalizing"],
    &["signalising"],
    &["signalizing"],
    &["signalising"],
];

pub(crate) static ENTRY_SILED_12381586547309486387: VariantsMap =
    [&["siled"], &["siloed"], &["siloed"], &["siloed"]];

pub(crate) static ENTRY_SILICATIZATIONS_14537460292946065713: VariantsMap = [
    &["silicatizations"],
    &["silicatisations"],
    &["silicatizations"],
    &["silicatisations"],
];

pub(crate) static ENTRY_SILICATIZATION_8334937031623361793: VariantsMap = [
    &["silicatization"],
    &["silicatisation"],
    &["silicatization"],
    &["silicatisation"],
];

pub(crate) static ENTRY_SILICIDIZES_8451599320490244745: VariantsMap = [
    &["silicidizes"],
    &["silicidises"],
    &["silicidizes"],
    &["silicidises"],
];

pub(crate) static ENTRY_SILICIDIZE_10105932126743433094: VariantsMap = [
    &["silicidize"],
    &["silicidise"],
    &["silicidize"],
    &["silicidise"],
];

pub(crate) static ENTRY_SILICONIZES_13223727835681004529: VariantsMap = [
    &["siliconizes"],
    &["siliconises"],
    &["siliconizes"],
    &["siliconises"],
];

pub(crate) static ENTRY_SILICONIZE_13405622030239987984: VariantsMap = [
    &["siliconize"],
    &["siliconise"],
    &["siliconize"],
    &["siliconise"],
];

pub(crate) static ENTRY_SILICULE_8819087303829031645: VariantsMap = [
    &["silicule"],
    &["siliculae"],
    &["siliculae"],
    &["siliculae"],
];

pub(crate) static ENTRY_SILIQUE_14167905731780673955: VariantsMap =
    [&["silique"], &["siliquae"], &["siliquae"], &["siliquae"]];

pub(crate) static ENTRY_SILVERIZED_6745009401833341902: VariantsMap = [
    &["silverized"],
    &["silverised"],
    &["silverized"],
    &["silverised"],
];

pub(crate) static ENTRY_SILVERIZERS_6400030913024008221: VariantsMap = [
    &["silverizers"],
    &["silverisers"],
    &["silverizers"],
    &["silverisers"],
];

pub(crate) static ENTRY_SILVERIZER_9176727189423966849: VariantsMap = [
    &["silverizer"],
    &["silveriser"],
    &["silverizer"],
    &["silveriser"],
];

pub(crate) static ENTRY_SILVERIZES_8743524383539922781: VariantsMap = [
    &["silverizes"],
    &["silverises"],
    &["silverizes"],
    &["silverises"],
];

pub(crate) static ENTRY_SILVERIZE_17319102720364227407: VariantsMap = [
    &["silverize"],
    &["silverise"],
    &["silverize"],
    &["silverise"],
];

pub(crate) static ENTRY_SILVERIZING_5788670803723424943: VariantsMap = [
    &["silverizing"],
    &["silverising"],
    &["silverizing"],
    &["silverising"],
];

pub(crate) static ENTRY_SIMILARIZES_1632917830904082830: VariantsMap = [
    &["similarizes"],
    &["similarises"],
    &["similarizes"],
    &["similarises"],
];

pub(crate) static ENTRY_SIMILARIZE_16496852244210265562: VariantsMap = [
    &["similarize"],
    &["similarise"],
    &["similarize"],
    &["similarise"],
];

pub(crate) static ENTRY_SIMILIZED_9710059990909892597: VariantsMap = [
    &["similized"],
    &["similised"],
    &["similized"],
    &["similised"],
];

pub(crate) static ENTRY_SIMILIZES_901429705138016982: VariantsMap = [
    &["similizes"],
    &["similises"],
    &["similizes"],
    &["similises"],
];

pub(crate) static ENTRY_SIMILIZE_8574054999037710134: VariantsMap =
    [&["similize"], &["similise"], &["similize"], &["similise"]];

pub(crate) static ENTRY_SIMILIZING_5963188162030464608: VariantsMap = [
    &["similizing"],
    &["similising"],
    &["similizing"],
    &["similising"],
];

pub(crate) static ENTRY_SIMONIZE_16191243326536881919: VariantsMap =
    [&["simonize"], &["simonise"], &["simonize"], &["simonise"]];

pub(crate) static ENTRY_SINE_2527591790023124121: VariantsMap =
    [&["sine"], &["sinae"], &["sinae"], &["sinae"]];

pub(crate) static ENTRY_SINGULARIZATIONS_13878245436318237762: VariantsMap = [
    &["singularizations"],
    &["singularisations"],
    &["singularizations"],
    &["singularisations"],
];

pub(crate) static ENTRY_SINGULARIZATION_8500018865289525170: VariantsMap = [
    &["singularization"],
    &["singularisation"],
    &["singularization"],
    &["singularisation"],
];

pub(crate) static ENTRY_SINGULARIZED_15088538269088551750: VariantsMap = [
    &["singularized"],
    &["singularised"],
    &["singularized"],
    &["singularised"],
];

pub(crate) static ENTRY_SINGULARIZES_9740292182667737407: VariantsMap = [
    &["singularizes"],
    &["singularises"],
    &["singularizes"],
    &["singularises"],
];

pub(crate) static ENTRY_SINGULARIZE_11329575142831190791: VariantsMap = [
    &["singularize"],
    &["singularise"],
    &["singularize"],
    &["singularise"],
];

pub(crate) static ENTRY_SINGULARIZING_922470838749445662: VariantsMap = [
    &["singularizing"],
    &["singularising"],
    &["singularizing"],
    &["singularising"],
];

pub(crate) static ENTRY_SINICIZED_10860435760613269568: VariantsMap = [
    &["sinicized"],
    &["sinicised"],
    &["sinicized"],
    &["sinicised"],
];

pub(crate) static ENTRY_SINICIZES_8865802893263500137: VariantsMap = [
    &["sinicizes"],
    &["sinicises"],
    &["sinicizes"],
    &["sinicises"],
];

pub(crate) static ENTRY_SINICIZE_18094969636027054415: VariantsMap =
    [&["sinicize"], &["sinicise"], &["sinicize"], &["sinicise"]];

pub(crate) static ENTRY_SINICIZING_356924263573679617: VariantsMap = [
    &["sinicizing"],
    &["sinicising"],
    &["sinicizing"],
    &["sinicising"],
];

pub(crate) static ENTRY_SIPHONED_18424232856912206813: VariantsMap =
    [&["siphoned"], &["siphoned"], &["siphoned"], &["siphoned"]];

pub(crate) static ENTRY_SIPHONING_18027669453640804145: VariantsMap = [
    &["siphoning"],
    &["siphoning"],
    &["siphoning"],
    &["siphoning"],
];

pub(crate) static ENTRY_SIPHONLESSES_11205420378358153772: VariantsMap = [
    &["siphonlesses"],
    &["siphonlesses"],
    &["siphonlesses"],
    &["siphonlesses"],
];

pub(crate) static ENTRY_SIPHONLESS_7516308130535648893: VariantsMap = [
    &["siphonless"],
    &["siphonless"],
    &["siphonless"],
    &["siphonless"],
];

pub(crate) static ENTRY_SIPHONLIKES_6790689669445612801: VariantsMap = [
    &["siphonlikes"],
    &["siphonlikes"],
    &["siphonlikes"],
    &["siphonlikes"],
];

pub(crate) static ENTRY_SIPHONLIKE_2457173542292581609: VariantsMap = [
    &["siphonlike"],
    &["siphonlike"],
    &["siphonlike"],
    &["siphonlike"],
];

pub(crate) static ENTRY_SIPHONOPHORE_15949385627332107665: VariantsMap = [
    &["siphonophore"],
    &["siphonophore"],
    &["siphonophore"],
    &["siphonophore"],
];

pub(crate) static ENTRY_SIPHONOSTELE_10717604967543113626: VariantsMap = [
    &["siphonostele"],
    &["siphonostele"],
    &["siphonostele"],
    &["siphonostele"],
];

pub(crate) static ENTRY_SIPHONOSTELIC_6553079768516739732: VariantsMap = [
    &["siphonostelic"],
    &["siphonostelic"],
    &["siphonostelic"],
    &["siphonostelic"],
];

pub(crate) static ENTRY_SIPHONOSTELY_14373795432163872344: VariantsMap = [
    &["siphonostely"],
    &["siphonostely"],
    &["siphonostely"],
    &["siphonostely"],
];

pub(crate) static ENTRY_SIPHONS_3803350051205365845: VariantsMap =
    [&["siphons"], &["siphons"], &["siphons"], &["siphons"]];

pub(crate) static ENTRY_SIPHON_3485864798732184416: VariantsMap =
    [&["siphon"], &["siphon"], &["siphon"], &["siphon"]];

pub(crate) static ENTRY_SIRENIZED_17241413740995154727: VariantsMap = [
    &["sirenized"],
    &["sirenised"],
    &["sirenized"],
    &["sirenised"],
];

pub(crate) static ENTRY_SIRENIZES_6775435871825963686: VariantsMap = [
    &["sirenizes"],
    &["sirenises"],
    &["sirenizes"],
    &["sirenises"],
];

pub(crate) static ENTRY_SIRENIZE_4401588392569843591: VariantsMap =
    [&["sirenize"], &["sirenise"], &["sirenize"], &["sirenise"]];

pub(crate) static ENTRY_SIRENIZING_14907055541353627309: VariantsMap = [
    &["sirenizing"],
    &["sirenising"],
    &["sirenizing"],
    &["sirenising"],
];

pub(crate) static ENTRY_SISTERIZES_3585073858517133756: VariantsMap = [
    &["sisterizes"],
    &["sisterises"],
    &["sisterizes"],
    &["sisterises"],
];

pub(crate) static ENTRY_SISTERIZE_18228472873291960908: VariantsMap = [
    &["sisterize"],
    &["sisterise"],
    &["sisterize"],
    &["sisterise"],
];

pub(crate) static ENTRY_SISTERN_3589216592434306959: VariantsMap =
    [&["sistern"], &["sistren"], &["sistren"], &["sistren"]];

pub(crate) static ENTRY_SIZABLY_12301409967193602959: VariantsMap =
    [&["sizably"], &["sizeably"], &["sizably"], &["sizeably"]];

pub(crate) static ENTRY_SIZEL_12038396317173133117: VariantsMap =
    [&["sizel"], &["sisel"], &["sizel"], &["sisel"]];

pub(crate) static ENTRY_SKEER_10694090215216405498: VariantsMap =
    [&["skeer"], &["skere"], &["skere"], &["skere"]];

pub(crate) static ENTRY_SKELETONIZATIONS_18147907457760273537: VariantsMap = [
    &["skeletonizations"],
    &["skeletonisations"],
    &["skeletonizations"],
    &["skeletonisations"],
];

pub(crate) static ENTRY_SKELETONIZATION_14703001244565805609: VariantsMap = [
    &["skeletonization"],
    &["skeletonisation"],
    &["skeletonization"],
    &["skeletonisation"],
];

pub(crate) static ENTRY_SKELETONIZED_4399400631763960495: VariantsMap = [
    &["skeletonized"],
    &["skeletonised"],
    &["skeletonized"],
    &["skeletonised"],
];

pub(crate) static ENTRY_SKELETONIZERS_2179019747423126437: VariantsMap = [
    &["skeletonizers"],
    &["skeletonisers"],
    &["skeletonizers"],
    &["skeletonisers"],
];

pub(crate) static ENTRY_SKELETONIZER_11148122379923017190: VariantsMap = [
    &["skeletonizer"],
    &["skeletoniser"],
    &["skeletonizer"],
    &["skeletoniser"],
];

pub(crate) static ENTRY_SKELETONIZES_11609077896679678595: VariantsMap = [
    &["skeletonizes"],
    &["skeletonises"],
    &["skeletonizes"],
    &["skeletonises"],
];

pub(crate) static ENTRY_SKELETONIZE_14753576006665240012: VariantsMap = [
    &["skeletonize"],
    &["skeletonise"],
    &["skeletonize"],
    &["skeletonise"],
];

pub(crate) static ENTRY_SKELETONIZING_17453924223738698796: VariantsMap = [
    &["skeletonizing"],
    &["skeletonising"],
    &["skeletonizing"],
    &["skeletonising"],
];

pub(crate) static ENTRY_SKEPTICALER_10497826709555834276: VariantsMap = [
    &["skepticaler"],
    &["scepticaler"],
    &["skepticaler"],
    &["scepticaler"],
];

pub(crate) static ENTRY_SKEPTICALEST_4980384681338816222: VariantsMap = [
    &["skepticalest"],
    &["scepticalest"],
    &["skepticalest"],
    &["scepticalest"],
];

pub(crate) static ENTRY_SKEPTICALLY_1022245430766512126: VariantsMap = [
    &["skeptically"],
    &["sceptically"],
    &["skeptically"],
    &["sceptically"],
];

pub(crate) static ENTRY_SKEPTICAL_17849179356584176691: VariantsMap = [
    &["skeptical"],
    &["sceptical"],
    &["skeptical"],
    &["sceptical"],
];

pub(crate) static ENTRY_SKEPTICER_17239131044137588151: VariantsMap = [
    &["skepticer"],
    &["scepticer"],
    &["skepticer"],
    &["scepticer"],
];

pub(crate) static ENTRY_SKEPTICEST_7590086531147625946: VariantsMap = [
    &["skepticest"],
    &["scepticest"],
    &["skepticest"],
    &["scepticest"],
];

pub(crate) static ENTRY_SKEPTICISMS_4642865009100445057: VariantsMap = [
    &["skepticisms"],
    &["scepticisms"],
    &["skepticisms"],
    &["scepticisms"],
];

pub(crate) static ENTRY_SKEPTICISM_14105128952227011757: VariantsMap = [
    &["skepticism"],
    &["scepticism"],
    &["skepticism"],
    &["scepticism"],
];

pub(crate) static ENTRY_SKEPTICIZES_12906322393300835503: VariantsMap = [
    &["skepticizes"],
    &["skepticises"],
    &["skepticizes"],
    &["skepticises"],
];

pub(crate) static ENTRY_SKEPTICIZE_9491002066487960132: VariantsMap = [
    &["skepticize"],
    &["skepticise"],
    &["skepticize"],
    &["skepticise"],
];

pub(crate) static ENTRY_SKEPTICS_10828965990171531904: VariantsMap =
    [&["skeptics"], &["sceptics"], &["skeptics"], &["sceptics"]];

pub(crate) static ENTRY_SKEPTIC_9815313097030140436: VariantsMap =
    [&["skeptic"], &["sceptic"], &["skeptic"], &["sceptic"]];

pub(crate) static ENTRY_SKILLFULLY_1794448316056971900: VariantsMap = [
    &["skillfully"],
    &["skilfully"],
    &["skilfully"],
    &["skilfully"],
];

pub(crate) static ENTRY_SKILLFULNESS_6885795773212202933: VariantsMap = [
    &["skillfulness"],
    &["skilfulness"],
    &["skilfulness"],
    &["skilfulness"],
];

pub(crate) static ENTRY_SKILLFUL_2422177896744237002: VariantsMap =
    [&["skillful"], &["skilful"], &["skilful"], &["skilful"]];

pub(crate) static ENTRY_SKYERS_14692226131287693314: VariantsMap =
    [&["skyers"], &["skyres"], &["skyres"], &["skyres"]];

pub(crate) static ENTRY_SKYER_219848130793374202: VariantsMap =
    [&["skyer"], &["skyre"], &["skyre"], &["skyre"]];

pub(crate) static ENTRY_SLAVICIZES_9333045619587626033: VariantsMap = [
    &["slavicizes"],
    &["slavicises"],
    &["slavicizes"],
    &["slavicises"],
];

pub(crate) static ENTRY_SLAVICIZE_4863650478255717151: VariantsMap = [
    &["slavicize"],
    &["slavicise"],
    &["slavicize"],
    &["slavicise"],
];

pub(crate) static ENTRY_SLAVIZATIONS_15770441737620994218: VariantsMap = [
    &["slavizations"],
    &["slavisations"],
    &["slavizations"],
    &["slavisations"],
];

pub(crate) static ENTRY_SLAVIZATION_11709614021110971430: VariantsMap = [
    &["slavization"],
    &["slavisation"],
    &["slavization"],
    &["slavisation"],
];

pub(crate) static ENTRY_SLAVIZES_3510132077149346979: VariantsMap =
    [&["slavizes"], &["slavises"], &["slavizes"], &["slavises"]];

pub(crate) static ENTRY_SLAVIZE_18312974609644738377: VariantsMap =
    [&["slavize"], &["slavise"], &["slavize"], &["slavise"]];

pub(crate) static ENTRY_SLAVONICIZED_8850052358113287660: VariantsMap = [
    &["slavonicized"],
    &["slavonicised"],
    &["slavonicized"],
    &["slavonicised"],
];

pub(crate) static ENTRY_SLAVONICIZES_16371616437362071351: VariantsMap = [
    &["slavonicizes"],
    &["slavonicises"],
    &["slavonicizes"],
    &["slavonicises"],
];

pub(crate) static ENTRY_SLAVONICIZE_6476323453849856832: VariantsMap = [
    &["slavonicize"],
    &["slavonicise"],
    &["slavonicize"],
    &["slavonicise"],
];

pub(crate) static ENTRY_SLAVONICIZING_12706848732597660283: VariantsMap = [
    &["slavonicizing"],
    &["slavonicising"],
    &["slavonicizing"],
    &["slavonicising"],
];

pub(crate) static ENTRY_SLAVONIZED_9750176016831413177: VariantsMap = [
    &["slavonized"],
    &["slavonised"],
    &["slavonized"],
    &["slavonised"],
];

pub(crate) static ENTRY_SLAVONIZES_1386680960388327198: VariantsMap = [
    &["slavonizes"],
    &["slavonises"],
    &["slavonizes"],
    &["slavonises"],
];

pub(crate) static ENTRY_SLAVONIZE_3789552220052397911: VariantsMap = [
    &["slavonize"],
    &["slavonise"],
    &["slavonize"],
    &["slavonise"],
];

pub(crate) static ENTRY_SLAVONIZING_15622203327519072554: VariantsMap = [
    &["slavonizing"],
    &["slavonising"],
    &["slavonizing"],
    &["slavonising"],
];

pub(crate) static ENTRY_SLENDERIZED_12017380378072055827: VariantsMap = [
    &["slenderized"],
    &["slenderised"],
    &["slenderized"],
    &["slenderised"],
];

pub(crate) static ENTRY_SLENDERIZES_3290303620172743698: VariantsMap = [
    &["slenderizes"],
    &["slenderises"],
    &["slenderizes"],
    &["slenderises"],
];

pub(crate) static ENTRY_SLENDERIZE_8450406323160278788: VariantsMap = [
    &["slenderize"],
    &["slenderise"],
    &["slenderize"],
    &["slenderise"],
];

pub(crate) static ENTRY_SLENDERIZING_16035225838163229483: VariantsMap = [
    &["slenderizing"],
    &["slenderising"],
    &["slenderizing"],
    &["slenderising"],
];

pub(crate) static ENTRY_SLE_17010563809824244033: VariantsMap =
    [&["sle"], &["slae"], &["slae"], &["slae"]];

pub(crate) static ENTRY_SLIER_9265750496896058833: VariantsMap =
    [&["slier"], &["slyer"], &["slyer"], &["slyer"]];

pub(crate) static ENTRY_SLIEST_15096652467551200006: VariantsMap =
    [&["sliest"], &["slyest"], &["slyest"], &["slyest"]];

pub(crate) static ENTRY_SLOGANIZED_9832955101225402459: VariantsMap = [
    &["sloganized"],
    &["sloganised"],
    &["sloganized"],
    &["sloganised"],
];

pub(crate) static ENTRY_SLOGANIZES_3411813491582108245: VariantsMap = [
    &["sloganizes"],
    &["sloganises"],
    &["sloganizes"],
    &["sloganises"],
];

pub(crate) static ENTRY_SLOGANIZE_17724147607334488119: VariantsMap = [
    &["sloganize"],
    &["sloganise"],
    &["sloganize"],
    &["sloganise"],
];

pub(crate) static ENTRY_SLOGANIZINGS_15730703019261096083: VariantsMap = [
    &["sloganizings"],
    &["sloganisings"],
    &["sloganizings"],
    &["sloganisings"],
];

pub(crate) static ENTRY_SLOGANIZING_15622195225709846156: VariantsMap = [
    &["sloganizing"],
    &["sloganising"],
    &["sloganizing"],
    &["sloganising"],
];

pub(crate) static ENTRY_SLUGGARDIZED_1660128103363949603: VariantsMap = [
    &["sluggardized"],
    &["sluggardised"],
    &["sluggardized"],
    &["sluggardised"],
];

pub(crate) static ENTRY_SLUGGARDIZES_12896575143246072039: VariantsMap = [
    &["sluggardizes"],
    &["sluggardises"],
    &["sluggardizes"],
    &["sluggardises"],
];

pub(crate) static ENTRY_SLUGGARDIZE_9332680492168745395: VariantsMap = [
    &["sluggardize"],
    &["sluggardise"],
    &["sluggardize"],
    &["sluggardise"],
];

pub(crate) static ENTRY_SLUGGARDIZING_10482718795351653891: VariantsMap = [
    &["sluggardizing"],
    &["sluggardising"],
    &["sluggardizing"],
    &["sluggardising"],
];

pub(crate) static ENTRY_SLYLY_17796644133630896913: VariantsMap =
    [&["slyly"], &["slyly"], &["slyly"], &["slyly"]];

pub(crate) static ENTRY_SMIDGENS_12067204132214853089: VariantsMap =
    [&["smidgens"], &["smidgens"], &["smidgens"], &["smidgens"]];

pub(crate) static ENTRY_SMIDGEN_1020835176028070080: VariantsMap =
    [&["smidgen"], &["smidgen"], &["smidgen"], &["smidgen"]];

pub(crate) static ENTRY_SMOLDERED_525255363028764433: VariantsMap = [
    &["smoldered"],
    &["smouldered"],
    &["smouldered"],
    &["smouldered"],
];

pub(crate) static ENTRY_SMOLDERING_1321144217497101015: VariantsMap = [
    &["smoldering"],
    &["smouldering"],
    &["smouldering"],
    &["smouldering"],
];

pub(crate) static ENTRY_SMOLDERS_5811778710193840809: VariantsMap = [
    &["smolders"],
    &["smoulders"],
    &["smoulders"],
    &["smoulders"],
];

pub(crate) static ENTRY_SMOLDER_18206679862651421040: VariantsMap =
    [&["smolder"], &["smoulder"], &["smoulder"], &["smoulder"]];

pub(crate) static ENTRY_SNIVELED_4241225854345991490: VariantsMap = [
    &["sniveled"],
    &["snivelled"],
    &["snivelled"],
    &["snivelled"],
];

pub(crate) static ENTRY_SNIVELERS_10785023557653793627: VariantsMap = [
    &["snivelers"],
    &["snivellers"],
    &["snivellers"],
    &["snivellers"],
];

pub(crate) static ENTRY_SNIVELER_7636471678868749639: VariantsMap = [
    &["sniveler"],
    &["sniveller"],
    &["sniveller"],
    &["sniveller"],
];

pub(crate) static ENTRY_SNIVELINGS_8577178711179056074: VariantsMap = [
    &["snivelings"],
    &["snivellings"],
    &["snivellings"],
    &["snivellings"],
];

pub(crate) static ENTRY_SNIVELING_5513010514012383062: VariantsMap = [
    &["sniveling"],
    &["snivelling"],
    &["snivelling"],
    &["snivelling"],
];

pub(crate) static ENTRY_SNOBSNIVELING_2007838763037803063: VariantsMap = [
    &["snobsniveling"],
    &["snobsnivelling"],
    &["snobsnivelling"],
    &["snobsnivelling"],
];

pub(crate) static ENTRY_SNORKELED_8473613528721477540: VariantsMap = [
    &["snorkeled"],
    &["snorkelled"],
    &["snorkelled"],
    &["snorkelled"],
];

pub(crate) static ENTRY_SNORKELING_13852650475536131090: VariantsMap = [
    &["snorkeling"],
    &["snorkelling"],
    &["snorkelling"],
    &["snorkelling"],
];

pub(crate) static ENTRY_SNOWPLOWS_6320103518456053512: VariantsMap = [
    &["snowplows"],
    &["snowploughs"],
    &["snowplows"],
    &["snowploughs"],
];

pub(crate) static ENTRY_SNOWPLOW_2634183079313653004: VariantsMap = [
    &["snowplow"],
    &["snowplough"],
    &["snowplow"],
    &["snowplough"],
];

pub(crate) static ENTRY_SNOWSHED_5252480350190238030: VariantsMap = [
    &["snowshed"],
    &["snowshoed"],
    &["snowshoed"],
    &["snowshoed"],
];

pub(crate) static ENTRY_SNUFFCOLORED_9191723066471236543: VariantsMap = [
    &["snuffcolored"],
    &["snuffcoloured"],
    &["snuffcoloured"],
    &["snuffcoloured"],
];

pub(crate) static ENTRY_SOBERIZED_14314548196946162318: VariantsMap = [
    &["soberized"],
    &["soberised"],
    &["soberized"],
    &["soberised"],
];

pub(crate) static ENTRY_SOBERIZES_12819350931337248082: VariantsMap = [
    &["soberizes"],
    &["soberises"],
    &["soberizes"],
    &["soberises"],
];

pub(crate) static ENTRY_SOBERIZE_7002273929401547239: VariantsMap =
    [&["soberize"], &["soberise"], &["soberize"], &["soberise"]];

pub(crate) static ENTRY_SOBERIZING_10979506276481353733: VariantsMap = [
    &["soberizing"],
    &["soberising"],
    &["soberizing"],
    &["soberising"],
];

pub(crate) static ENTRY_SOCIALIZATIONS_2850800344346221828: VariantsMap = [
    &["socializations"],
    &["socialisations"],
    &["socializations"],
    &["socialisations"],
];

pub(crate) static ENTRY_SOCIALIZATION_4031789440864790681: VariantsMap = [
    &["socialization"],
    &["socialisation"],
    &["socialization"],
    &["socialisation"],
];

pub(crate) static ENTRY_SOCIALIZED_6519290214037545163: VariantsMap = [
    &["socialized"],
    &["socialised"],
    &["socialized"],
    &["socialised"],
];

pub(crate) static ENTRY_SOCIALIZER_13597908573496978215: VariantsMap = [
    &["socializer"],
    &["socialiser"],
    &["socializer"],
    &["socialiser"],
];

pub(crate) static ENTRY_SOCIALIZES_17008876412249563437: VariantsMap = [
    &["socializes"],
    &["socialises"],
    &["socializes"],
    &["socialises"],
];

pub(crate) static ENTRY_SOCIALIZE_7608316723437121057: VariantsMap = [
    &["socialize"],
    &["socialise"],
    &["socialize"],
    &["socialise"],
];

pub(crate) static ENTRY_SOCIALIZING_5892971976061278726: VariantsMap = [
    &["socializing"],
    &["socialising"],
    &["socializing"],
    &["socialising"],
];

pub(crate) static ENTRY_SOCKDOLOGIZING_8246826191842133500: VariantsMap = [
    &["sockdologizing"],
    &["sockdologising"],
    &["sockdologizing"],
    &["sockdologising"],
];

pub(crate) static ENTRY_SOCRATIZED_6374519054168187154: VariantsMap = [
    &["socratized"],
    &["socratised"],
    &["socratized"],
    &["socratised"],
];

pub(crate) static ENTRY_SOCRATIZES_1074905976057709485: VariantsMap = [
    &["socratizes"],
    &["socratises"],
    &["socratizes"],
    &["socratises"],
];

pub(crate) static ENTRY_SOCRATIZE_7163114728746981046: VariantsMap = [
    &["socratize"],
    &["socratise"],
    &["socratize"],
    &["socratise"],
];

pub(crate) static ENTRY_SOCRATIZING_13388626729978739793: VariantsMap = [
    &["socratizing"],
    &["socratising"],
    &["socratizing"],
    &["socratising"],
];

pub(crate) static ENTRY_SODOMIZED_14987743408591553330: VariantsMap = [
    &["sodomized"],
    &["sodomised"],
    &["sodomized"],
    &["sodomised"],
];

pub(crate) static ENTRY_SODOMIZES_13961547799680688282: VariantsMap = [
    &["sodomizes"],
    &["sodomises"],
    &["sodomizes"],
    &["sodomises"],
];

pub(crate) static ENTRY_SODOMIZE_8989273429049313613: VariantsMap =
    [&["sodomize"], &["sodomise"], &["sodomize"], &["sodomise"]];

pub(crate) static ENTRY_SODOMIZING_17930954299621224444: VariantsMap = [
    &["sodomizing"],
    &["sodomising"],
    &["sodomizing"],
    &["sodomising"],
];

pub(crate) static ENTRY_SOLARIZATIONS_11436810758858977879: VariantsMap = [
    &["solarizations"],
    &["solarisations"],
    &["solarizations"],
    &["solarisations"],
];

pub(crate) static ENTRY_SOLARIZATION_4885912231243718586: VariantsMap = [
    &["solarization"],
    &["solarisation"],
    &["solarization"],
    &["solarisation"],
];

pub(crate) static ENTRY_SOLARIZED_4040826558854876151: VariantsMap = [
    &["solarized"],
    &["solarised"],
    &["solarized"],
    &["solarised"],
];

pub(crate) static ENTRY_SOLARIZES_4506803855717626619: VariantsMap = [
    &["solarizes"],
    &["solarises"],
    &["solarizes"],
    &["solarises"],
];

pub(crate) static ENTRY_SOLARIZE_5717478759034003221: VariantsMap =
    [&["solarize"], &["solarise"], &["solarize"], &["solarise"]];

pub(crate) static ENTRY_SOLARIZING_8595599809624415698: VariantsMap = [
    &["solarizing"],
    &["solarising"],
    &["solarizing"],
    &["solarising"],
];

pub(crate) static ENTRY_SOLDIERIZES_8050837834439993245: VariantsMap = [
    &["soldierizes"],
    &["soldierises"],
    &["soldierizes"],
    &["soldierises"],
];

pub(crate) static ENTRY_SOLDIERIZE_9036042748338606942: VariantsMap = [
    &["soldierize"],
    &["soldierise"],
    &["soldierize"],
    &["soldierise"],
];

pub(crate) static ENTRY_SOLECIZED_12860558242481667749: VariantsMap = [
    &["solecized"],
    &["solecised"],
    &["solecized"],
    &["solecised"],
];

pub(crate) static ENTRY_SOLECIZES_1903589863923647169: VariantsMap = [
    &["solecizes"],
    &["solecises"],
    &["solecizes"],
    &["solecises"],
];

pub(crate) static ENTRY_SOLECIZE_1902296975492568965: VariantsMap =
    [&["solecize"], &["solecise"], &["solecize"], &["solecise"]];

pub(crate) static ENTRY_SOLECIZING_4096581158238808815: VariantsMap = [
    &["solecizing"],
    &["solecising"],
    &["solecizing"],
    &["solecising"],
];

pub(crate) static ENTRY_SOLEMNIZATIONS_10033372229920712112: VariantsMap = [
    &["solemnizations"],
    &["solemnisations"],
    &["solemnizations"],
    &["solemnisations"],
];

pub(crate) static ENTRY_SOLEMNIZATION_11065823287402873495: VariantsMap = [
    &["solemnization"],
    &["solemnisation"],
    &["solemnization"],
    &["solemnisation"],
];

pub(crate) static ENTRY_SOLEMNIZED_224034548114018910: VariantsMap = [
    &["solemnized"],
    &["solemnised"],
    &["solemnized"],
    &["solemnised"],
];

pub(crate) static ENTRY_SOLEMNIZERS_7502930185041648303: VariantsMap = [
    &["solemnizers"],
    &["solemnisers"],
    &["solemnizers"],
    &["solemnisers"],
];

pub(crate) static ENTRY_SOLEMNIZER_14558116154158912985: VariantsMap = [
    &["solemnizer"],
    &["solemniser"],
    &["solemnizer"],
    &["solemniser"],
];

pub(crate) static ENTRY_SOLEMNIZES_12952089326401148902: VariantsMap = [
    &["solemnizes"],
    &["solemnises"],
    &["solemnizes"],
    &["solemnises"],
];

pub(crate) static ENTRY_SOLEMNIZE_15679717866562504473: VariantsMap = [
    &["solemnize"],
    &["solemnise"],
    &["solemnize"],
    &["solemnise"],
];

pub(crate) static ENTRY_SOLEMNIZING_630145090956262150: VariantsMap = [
    &["solemnizing"],
    &["solemnising"],
    &["solemnizing"],
    &["solemnising"],
];

pub(crate) static ENTRY_SOLILOQUIZATION_18296763197929133122: VariantsMap = [
    &["soliloquization"],
    &["soliloquisation"],
    &["soliloquization"],
    &["soliloquisation"],
];

pub(crate) static ENTRY_SOLILOQUIZED_4881410725010799917: VariantsMap = [
    &["soliloquized"],
    &["soliloquised"],
    &["soliloquized"],
    &["soliloquised"],
];

pub(crate) static ENTRY_SOLILOQUIZERS_4675842551561535988: VariantsMap = [
    &["soliloquizers"],
    &["soliloquisers"],
    &["soliloquizers"],
    &["soliloquisers"],
];

pub(crate) static ENTRY_SOLILOQUIZER_8690726398071022002: VariantsMap = [
    &["soliloquizer"],
    &["soliloquiser"],
    &["soliloquizer"],
    &["soliloquiser"],
];

pub(crate) static ENTRY_SOLILOQUIZES_409834577954225605: VariantsMap = [
    &["soliloquizes"],
    &["soliloquises"],
    &["soliloquizes"],
    &["soliloquises"],
];

pub(crate) static ENTRY_SOLILOQUIZE_14417000719223788095: VariantsMap = [
    &["soliloquize"],
    &["soliloquise"],
    &["soliloquize"],
    &["soliloquise"],
];

pub(crate) static ENTRY_SOLILOQUIZINGLY_11096800081567827210: VariantsMap = [
    &["soliloquizingly"],
    &["soliloquisingly"],
    &["soliloquizingly"],
    &["soliloquisingly"],
];

pub(crate) static ENTRY_SOLILOQUIZINGS_16981301693070525140: VariantsMap = [
    &["soliloquizings"],
    &["soliloquisings"],
    &["soliloquizings"],
    &["soliloquisings"],
];

pub(crate) static ENTRY_SOLILOQUIZING_9233664287673036156: VariantsMap = [
    &["soliloquizing"],
    &["soliloquising"],
    &["soliloquizing"],
    &["soliloquising"],
];

pub(crate) static ENTRY_SOLMIZATIONS_13644603279878977752: VariantsMap = [
    &["solmizations"],
    &["solmisations"],
    &["solmizations"],
    &["solmisations"],
];

pub(crate) static ENTRY_SOLMIZATION_12587274322609700335: VariantsMap = [
    &["solmization"],
    &["solmisation"],
    &["solmization"],
    &["solmisation"],
];

pub(crate) static ENTRY_SOLONIZATIONS_3376302484656071644: VariantsMap = [
    &["solonizations"],
    &["solonisations"],
    &["solonizations"],
    &["solonisations"],
];

pub(crate) static ENTRY_SOLONIZATION_10730000459604020887: VariantsMap = [
    &["solonization"],
    &["solonisation"],
    &["solonization"],
    &["solonisation"],
];

pub(crate) static ENTRY_SOLUBILIZATIONS_4955462430772240177: VariantsMap = [
    &["solubilizations"],
    &["solubilisations"],
    &["solubilizations"],
    &["solubilisations"],
];

pub(crate) static ENTRY_SOLUBILIZATION_10580055016658346926: VariantsMap = [
    &["solubilization"],
    &["solubilisation"],
    &["solubilization"],
    &["solubilisation"],
];

pub(crate) static ENTRY_SOLUBILIZED_10156344475132002791: VariantsMap = [
    &["solubilized"],
    &["solubilised"],
    &["solubilized"],
    &["solubilised"],
];

pub(crate) static ENTRY_SOLUBILIZES_12208892698399982158: VariantsMap = [
    &["solubilizes"],
    &["solubilises"],
    &["solubilizes"],
    &["solubilises"],
];

pub(crate) static ENTRY_SOLUBILIZE_1673521634914384541: VariantsMap = [
    &["solubilize"],
    &["solubilise"],
    &["solubilize"],
    &["solubilise"],
];

pub(crate) static ENTRY_SOLUBILIZING_5913383570927297322: VariantsMap = [
    &["solubilizing"],
    &["solubilising"],
    &["solubilizing"],
    &["solubilising"],
];

pub(crate) static ENTRY_SOLUTIZERS_10254868232218021370: VariantsMap = [
    &["solutizers"],
    &["solutisers"],
    &["solutizers"],
    &["solutisers"],
];

pub(crate) static ENTRY_SOLUTIZER_7736710185825875415: VariantsMap = [
    &["solutizer"],
    &["solutiser"],
    &["solutizer"],
    &["solutiser"],
];

pub(crate) static ENTRY_SOLUTIZES_17457446370787935768: VariantsMap = [
    &["solutizes"],
    &["solutises"],
    &["solutizes"],
    &["solutises"],
];

pub(crate) static ENTRY_SOLUTIZE_4089193342836063440: VariantsMap =
    [&["solutize"], &["solutise"], &["solutize"], &["solutise"]];

pub(crate) static ENTRY_SOMBERER_5923083299459142321: VariantsMap =
    [&["somberer"], &["sombrer"], &["sombrer"], &["sombrer"]];

pub(crate) static ENTRY_SOMBEREST_13920553234454816213: VariantsMap =
    [&["somberest"], &["sombrest"], &["sombrest"], &["sombrest"]];

pub(crate) static ENTRY_SOMBERISH_9199090735234253330: VariantsMap = [
    &["somberish"],
    &["sombreish"],
    &["sombreish"],
    &["sombreish"],
];

pub(crate) static ENTRY_SOMBERLY_8543050585429649865: VariantsMap =
    [&["somberly"], &["sombrely"], &["sombrely"], &["sombrely"]];

pub(crate) static ENTRY_SOMBERNESSES_37120742853890215: VariantsMap = [
    &["sombernesses"],
    &["sombrenesses"],
    &["sombrenesses"],
    &["sombrenesses"],
];

pub(crate) static ENTRY_SOMBERNESS_15776453114536814910: VariantsMap = [
    &["somberness"],
    &["sombreness"],
    &["sombreness"],
    &["sombreness"],
];

pub(crate) static ENTRY_SOMBER_7545143144533743661: VariantsMap =
    [&["somber"], &["sombre"], &["sombre"], &["sombre"]];

pub(crate) static ENTRY_SOMESTHESIA_696036815504224013: VariantsMap = [
    &["somesthesia"],
    &["somaesthesia"],
    &["somaesthesia"],
    &["somaesthesia"],
];

pub(crate) static ENTRY_SOMESTHESIS_9625244055976929614: VariantsMap = [
    &["somesthesis"],
    &["somaesthesis"],
    &["somaesthesis"],
    &["somaesthesis"],
];

pub(crate) static ENTRY_SOMNILOQUIZED_1808918933902905273: VariantsMap = [
    &["somniloquized"],
    &["somniloquised"],
    &["somniloquized"],
    &["somniloquised"],
];

pub(crate) static ENTRY_SOMNILOQUIZES_6303227745377820257: VariantsMap = [
    &["somniloquizes"],
    &["somniloquises"],
    &["somniloquizes"],
    &["somniloquises"],
];

pub(crate) static ENTRY_SOMNILOQUIZE_4534972985140538230: VariantsMap = [
    &["somniloquize"],
    &["somniloquise"],
    &["somniloquize"],
    &["somniloquise"],
];

pub(crate) static ENTRY_SOMNILOQUIZING_3623890958713154097: VariantsMap = [
    &["somniloquizing"],
    &["somniloquising"],
    &["somniloquizing"],
    &["somniloquising"],
];

pub(crate) static ENTRY_SONANTIZEDS_14474845156317286221: VariantsMap = [
    &["sonantizeds"],
    &["sonantiseds"],
    &["sonantizeds"],
    &["sonantiseds"],
];

pub(crate) static ENTRY_SONANTIZED_8552816854534321230: VariantsMap = [
    &["sonantized"],
    &["sonantised"],
    &["sonantized"],
    &["sonantised"],
];

pub(crate) static ENTRY_SONNETIZATION_3238230146445769080: VariantsMap = [
    &["sonnetization"],
    &["sonnetisation"],
    &["sonnetization"],
    &["sonnetisation"],
];

pub(crate) static ENTRY_SONNETIZED_10277905536142803942: VariantsMap = [
    &["sonnetized"],
    &["sonnetised"],
    &["sonnetized"],
    &["sonnetised"],
];

pub(crate) static ENTRY_SONNETIZES_3719563389684057577: VariantsMap = [
    &["sonnetizes"],
    &["sonnetises"],
    &["sonnetizes"],
    &["sonnetises"],
];

pub(crate) static ENTRY_SONNETIZE_16502381925297255059: VariantsMap = [
    &["sonnetize"],
    &["sonnetise"],
    &["sonnetize"],
    &["sonnetise"],
];

pub(crate) static ENTRY_SONNETIZING_10321042710859016957: VariantsMap = [
    &["sonnetizing"],
    &["sonnetising"],
    &["sonnetizing"],
    &["sonnetising"],
];

pub(crate) static ENTRY_SORBITIZATIONS_13164463647504490756: VariantsMap = [
    &["sorbitizations"],
    &["sorbitisations"],
    &["sorbitizations"],
    &["sorbitisations"],
];

pub(crate) static ENTRY_SORBITIZATION_286678615652162287: VariantsMap = [
    &["sorbitization"],
    &["sorbitisation"],
    &["sorbitization"],
    &["sorbitisation"],
];

pub(crate) static ENTRY_SORBITIZED_14569008759464807319: VariantsMap = [
    &["sorbitized"],
    &["sorbitised"],
    &["sorbitized"],
    &["sorbitised"],
];

pub(crate) static ENTRY_SORBITIZES_10577485183083089288: VariantsMap = [
    &["sorbitizes"],
    &["sorbitises"],
    &["sorbitizes"],
    &["sorbitises"],
];

pub(crate) static ENTRY_SORBITIZE_6846144076367658714: VariantsMap = [
    &["sorbitize"],
    &["sorbitise"],
    &["sorbitize"],
    &["sorbitise"],
];

pub(crate) static ENTRY_SORBITIZING_5713523379346241024: VariantsMap = [
    &["sorbitizing"],
    &["sorbitising"],
    &["sorbitizing"],
    &["sorbitising"],
];

pub(crate) static ENTRY_SORDINES_4854100779964973237: VariantsMap = [
    &["sordines"],
    &["sourdines"],
    &["sourdines"],
    &["sourdines"],
];

pub(crate) static ENTRY_SORDINE_10174285465421407112: VariantsMap =
    [&["sordine"], &["sourdine"], &["sourdine"], &["sourdine"]];

pub(crate) static ENTRY_SORD_12541754408432709068: VariantsMap =
    [&["sord"], &["sourd"], &["sourd"], &["sourd"]];

pub(crate) static ENTRY_SORORIZED_11733033323347420043: VariantsMap = [
    &["sororized"],
    &["sororised"],
    &["sororized"],
    &["sororised"],
];

pub(crate) static ENTRY_SORORIZES_9620501314832330750: VariantsMap = [
    &["sororizes"],
    &["sororises"],
    &["sororizes"],
    &["sororises"],
];

pub(crate) static ENTRY_SORORIZE_16170717109896239759: VariantsMap =
    [&["sororize"], &["sororise"], &["sororize"], &["sororise"]];

pub(crate) static ENTRY_SORORIZING_4125981476974090908: VariantsMap = [
    &["sororizing"],
    &["sororising"],
    &["sororizing"],
    &["sororising"],
];

pub(crate) static ENTRY_SORY_18130745314578295052: VariantsMap =
    [&["sory"], &["soury"], &["soury"], &["soury"]];

pub(crate) static ENTRY_SOUFFLED_4248191495032262509: VariantsMap = [
    &["souffled"],
    &["soufflaed"],
    &["soufflaed"],
    &["soufflaed"],
];

pub(crate) static ENTRY_SOULTER_2831536725912973940: VariantsMap =
    [&["soulter"], &["soultre"], &["soultre"], &["soultre"]];

pub(crate) static ENTRY_SOUTHERNIZED_13583675455448911323: VariantsMap = [
    &["southernized"],
    &["southernised"],
    &["southernized"],
    &["southernised"],
];

pub(crate) static ENTRY_SOUTHERNIZES_16080540880462627833: VariantsMap = [
    &["southernizes"],
    &["southernises"],
    &["southernizes"],
    &["southernises"],
];

pub(crate) static ENTRY_SOUTHERNIZE_5352868721449585244: VariantsMap = [
    &["southernize"],
    &["southernise"],
    &["southernize"],
    &["southernise"],
];

pub(crate) static ENTRY_SOUTHERNIZING_8286693634683754384: VariantsMap = [
    &["southernizing"],
    &["southernising"],
    &["southernizing"],
    &["southernising"],
];

pub(crate) static ENTRY_SOVIETIZATIONS_4958691907677433643: VariantsMap = [
    &["sovietizations"],
    &["sovietisations"],
    &["sovietizations"],
    &["sovietisations"],
];

pub(crate) static ENTRY_SOVIETIZATION_12298078635242896286: VariantsMap = [
    &["sovietization"],
    &["sovietisation"],
    &["sovietization"],
    &["sovietisation"],
];

pub(crate) static ENTRY_SOVIETIZED_14659307059412841290: VariantsMap = [
    &["sovietized"],
    &["sovietised"],
    &["sovietized"],
    &["sovietised"],
];

pub(crate) static ENTRY_SOVIETIZES_17217850242167584748: VariantsMap = [
    &["sovietizes"],
    &["sovietises"],
    &["sovietizes"],
    &["sovietises"],
];

pub(crate) static ENTRY_SOVIETIZE_4186406491577376479: VariantsMap = [
    &["sovietize"],
    &["sovietise"],
    &["sovietize"],
    &["sovietise"],
];

pub(crate) static ENTRY_SOVIETIZING_1809586830086781112: VariantsMap = [
    &["sovietizing"],
    &["sovietising"],
    &["sovietizing"],
    &["sovietising"],
];

pub(crate) static ENTRY_SPANEMIA_922888539006433588: VariantsMap = [
    &["spanemia"],
    &["spanaemia"],
    &["spanaemia"],
    &["spanaemia"],
];

pub(crate) static ENTRY_SPANEMIC_3971348550038618561: VariantsMap = [
    &["spanemic"],
    &["spanaemic"],
    &["spanaemic"],
    &["spanaemic"],
];

pub(crate) static ENTRY_SPANIARDIZATIONS_1586989072442973142: VariantsMap = [
    &["spaniardizations"],
    &["spaniardisations"],
    &["spaniardizations"],
    &["spaniardisations"],
];

pub(crate) static ENTRY_SPANIARDIZATION_11817299560808553859: VariantsMap = [
    &["spaniardization"],
    &["spaniardisation"],
    &["spaniardization"],
    &["spaniardisation"],
];

pub(crate) static ENTRY_SPANIARDIZES_9329878137611411598: VariantsMap = [
    &["spaniardizes"],
    &["spaniardises"],
    &["spaniardizes"],
    &["spaniardises"],
];

pub(crate) static ENTRY_SPANIARDIZE_3885557966001306111: VariantsMap = [
    &["spaniardize"],
    &["spaniardise"],
    &["spaniardize"],
    &["spaniardise"],
];

pub(crate) static ENTRY_SPANIOLIZED_5875906605727578891: VariantsMap = [
    &["spaniolized"],
    &["spaniolised"],
    &["spaniolized"],
    &["spaniolised"],
];

pub(crate) static ENTRY_SPANIOLIZES_10707148102344223944: VariantsMap = [
    &["spaniolizes"],
    &["spaniolises"],
    &["spaniolizes"],
    &["spaniolises"],
];

pub(crate) static ENTRY_SPANIOLIZE_2565179938529738131: VariantsMap = [
    &["spaniolize"],
    &["spaniolise"],
    &["spaniolize"],
    &["spaniolise"],
];

pub(crate) static ENTRY_SPANIOLIZING_11882230655915610816: VariantsMap = [
    &["spaniolizing"],
    &["spaniolising"],
    &["spaniolizing"],
    &["spaniolising"],
];

pub(crate) static ENTRY_SPANISHIZES_18186475755228969865: VariantsMap = [
    &["spanishizes"],
    &["spanishises"],
    &["spanishizes"],
    &["spanishises"],
];

pub(crate) static ENTRY_SPANISHIZE_11603707337679635198: VariantsMap = [
    &["spanishize"],
    &["spanishise"],
    &["spanishize"],
    &["spanishise"],
];

pub(crate) static ENTRY_SPANOPNEA_145137094678149677: VariantsMap = [
    &["spanopnea"],
    &["spanopnoea"],
    &["spanopnoea"],
    &["spanopnoea"],
];

pub(crate) static ENTRY_SPARERS_16992181547853461019: VariantsMap =
    [&["sparers"], &["sparres"], &["sparres"], &["sparres"]];

pub(crate) static ENTRY_SPARTANIZES_9419600589579198560: VariantsMap = [
    &["spartanizes"],
    &["spartanises"],
    &["spartanizes"],
    &["spartanises"],
];

pub(crate) static ENTRY_SPARTANIZE_4628148206066142517: VariantsMap = [
    &["spartanize"],
    &["spartanise"],
    &["spartanize"],
    &["spartanise"],
];

pub(crate) static ENTRY_SPATIALIZATIONS_1671848756975382904: VariantsMap = [
    &["spatializations"],
    &["spatialisations"],
    &["spatializations"],
    &["spatialisations"],
];

pub(crate) static ENTRY_SPATIALIZATION_4087066301429942262: VariantsMap = [
    &["spatialization"],
    &["spatialisation"],
    &["spatialization"],
    &["spatialisation"],
];

pub(crate) static ENTRY_SPATIALIZES_12158813954747942290: VariantsMap = [
    &["spatializes"],
    &["spatialises"],
    &["spatializes"],
    &["spatialises"],
];

pub(crate) static ENTRY_SPATIALIZE_15447037881145049281: VariantsMap = [
    &["spatialize"],
    &["spatialise"],
    &["spatialize"],
    &["spatialise"],
];

pub(crate) static ENTRY_SPECIALIZATIONS_8996872983896742236: VariantsMap = [
    &["specializations"],
    &["specialisations"],
    &["specializations"],
    &["specialisations"],
];

pub(crate) static ENTRY_SPECIALIZATION_6120455718688591089: VariantsMap = [
    &["specialization"],
    &["specialisation"],
    &["specialization"],
    &["specialisation"],
];

pub(crate) static ENTRY_SPECIALIZED_16208307633714518784: VariantsMap = [
    &["specialized"],
    &["specialised"],
    &["specialized"],
    &["specialised"],
];

pub(crate) static ENTRY_SPECIALIZERS_9633520764605881875: VariantsMap = [
    &["specializers"],
    &["specialisers"],
    &["specializers"],
    &["specialisers"],
];

pub(crate) static ENTRY_SPECIALIZER_11921648751057504779: VariantsMap = [
    &["specializer"],
    &["specialiser"],
    &["specializer"],
    &["specialiser"],
];

pub(crate) static ENTRY_SPECIALIZES_8324377090323742106: VariantsMap = [
    &["specializes"],
    &["specialises"],
    &["specializes"],
    &["specialises"],
];

pub(crate) static ENTRY_SPECIALIZE_11882111573270244369: VariantsMap = [
    &["specialize"],
    &["specialise"],
    &["specialize"],
    &["specialise"],
];

pub(crate) static ENTRY_SPECIALIZING_313518186697576164: VariantsMap = [
    &["specializing"],
    &["specialising"],
    &["specializing"],
    &["specialising"],
];

pub(crate) static ENTRY_SPECIALTIES_4384906624021484771: VariantsMap = [
    &["specialties"],
    &["specialities"],
    &["specialties"],
    &["specialities"],
];

pub(crate) static ENTRY_SPECIALTY_7072505085373556831: VariantsMap = [
    &["specialty"],
    &["speciality"],
    &["specialty"],
    &["speciality"],
];

pub(crate) static ENTRY_SPECIFICIZES_11252709195406863154: VariantsMap = [
    &["specificizes"],
    &["specificises"],
    &["specificizes"],
    &["specificises"],
];

pub(crate) static ENTRY_SPECIFICIZE_8694015960566697924: VariantsMap = [
    &["specificize"],
    &["specificise"],
    &["specificize"],
    &["specificise"],
];

pub(crate) static ENTRY_SPECIMENIZES_8054030914250793962: VariantsMap = [
    &["specimenizes"],
    &["specimenises"],
    &["specimenizes"],
    &["specimenises"],
];

pub(crate) static ENTRY_SPECIMENIZE_15854679138652311678: VariantsMap = [
    &["specimenize"],
    &["specimenise"],
    &["specimenize"],
    &["specimenise"],
];

pub(crate) static ENTRY_SPECTERED_12261702122507455629: VariantsMap =
    [&["spectered"], &["spectred"], &["spectred"], &["spectred"]];

pub(crate) static ENTRY_SPECTERLIKES_2606014956854784004: VariantsMap = [
    &["specterlikes"],
    &["spectrelikes"],
    &["spectrelikes"],
    &["spectrelikes"],
];

pub(crate) static ENTRY_SPECTERLIKE_14755283384607298035: VariantsMap = [
    &["specterlike"],
    &["spectrelike"],
    &["spectrelike"],
    &["spectrelike"],
];

pub(crate) static ENTRY_SPECTERS_5015013310557036380: VariantsMap =
    [&["specters"], &["spectres"], &["spectres"], &["spectres"]];

pub(crate) static ENTRY_SPECTER_6975611216022022799: VariantsMap =
    [&["specter"], &["spectre"], &["spectre"], &["spectre"]];

pub(crate) static ENTRY_SPECTROCOLORIMETRY_10424259053223609880: VariantsMap = [
    &["spectrocolorimetry"],
    &["spectrocolourimetry"],
    &["spectrocolourimetry"],
    &["spectrocolourimetry"],
];

pub(crate) static ENTRY_SPEER_7360372930438810102: VariantsMap =
    [&["speer"], &["spere"], &["spere"], &["spere"]];

pub(crate) static ENTRY_SPELEAN_12346771822163467823: VariantsMap =
    [&["spelean"], &["spelaean"], &["spelaean"], &["spelaean"]];

pub(crate) static ENTRY_SPELEOLOGICAL_5030814757410755163: VariantsMap = [
    &["speleological"],
    &["speleological"],
    &["speleological"],
    &["speleological"],
];

pub(crate) static ENTRY_SPELEOTHEMS_7444361922553408895: VariantsMap = [
    &["speleothems"],
    &["spelaeothems"],
    &["spelaeothems"],
    &["spelaeothems"],
];

pub(crate) static ENTRY_SPELEOTHEM_16440817073388704217: VariantsMap = [
    &["speleothem"],
    &["spelaeothem"],
    &["spelaeothem"],
    &["spelaeothem"],
];

pub(crate) static ENTRY_SPERMATORRHEAS_5238224579203778804: VariantsMap = [
    &["spermatorrheas"],
    &["spermatorrhoeas"],
    &["spermatorrhoeas"],
    &["spermatorrhoeas"],
];

pub(crate) static ENTRY_SPERMATORRHEA_8028285969078435945: VariantsMap = [
    &["spermatorrhea"],
    &["spermatorrhoea"],
    &["spermatorrhoea"],
    &["spermatorrhoea"],
];

pub(crate) static ENTRY_SPERONARES_17413089710620250879: VariantsMap = [
    &["speronares"],
    &["speronaroes"],
    &["speronaroes"],
    &["speronaroes"],
];

pub(crate) static ENTRY_SPHENETHMOIDAL_15095592789700320199: VariantsMap = [
    &["sphenethmoidal"],
    &["sphenoethmoidal"],
    &["sphenoethmoidal"],
    &["sphenoethmoidal"],
];

pub(crate) static ENTRY_SPHENETHMOID_3344554427813149122: VariantsMap = [
    &["sphenethmoid"],
    &["sphenoethmoid"],
    &["sphenoethmoid"],
    &["sphenoethmoid"],
];

pub(crate) static ENTRY_SPHEROCRYSTAL_13932713915466541286: VariantsMap = [
    &["spherocrystal"],
    &["sphaerocrystal"],
    &["sphaerocrystal"],
    &["sphaerocrystal"],
];

pub(crate) static ENTRY_SPHEROIDIZATIONS_14295978134258099517: VariantsMap = [
    &["spheroidizations"],
    &["spheroidisations"],
    &["spheroidizations"],
    &["spheroidisations"],
];

pub(crate) static ENTRY_SPHEROIDIZATION_5744466853986400727: VariantsMap = [
    &["spheroidization"],
    &["spheroidisation"],
    &["spheroidization"],
    &["spheroidisation"],
];

pub(crate) static ENTRY_SPHEROIDIZED_13765691704944125686: VariantsMap = [
    &["spheroidized"],
    &["spheroidised"],
    &["spheroidized"],
    &["spheroidised"],
];

pub(crate) static ENTRY_SPHEROIDIZES_14751177492930435556: VariantsMap = [
    &["spheroidizes"],
    &["spheroidises"],
    &["spheroidizes"],
    &["spheroidises"],
];

pub(crate) static ENTRY_SPHEROIDIZE_14518292079831405966: VariantsMap = [
    &["spheroidize"],
    &["spheroidise"],
    &["spheroidize"],
    &["spheroidise"],
];

pub(crate) static ENTRY_SPHEROIDIZING_16138304032840348269: VariantsMap = [
    &["spheroidizing"],
    &["spheroidising"],
    &["spheroidizing"],
    &["spheroidising"],
];

pub(crate) static ENTRY_SPHEROSOME_9093290394436122389: VariantsMap = [
    &["spherosome"],
    &["sphaerosome"],
    &["sphaerosome"],
    &["sphaerosome"],
];

pub(crate) static ENTRY_SPIERS_9403741506204571610: VariantsMap =
    [&["spiers"], &["spires"], &["spires"], &["spires"]];

pub(crate) static ENTRY_SPINULE_14289210505662966609: VariantsMap =
    [&["spinule"], &["spinulae"], &["spinulae"], &["spinulae"]];

pub(crate) static ENTRY_SPIRALED_16325472687253851967: VariantsMap = [
    &["spiraled"],
    &["spiralled"],
    &["spiralled"],
    &["spiralled"],
];

pub(crate) static ENTRY_SPIRALING_17847046296192692592: VariantsMap = [
    &["spiraling"],
    &["spiralling"],
    &["spiralling"],
    &["spiralling"],
];

pub(crate) static ENTRY_SPIRALIZATIONS_13076784845071161777: VariantsMap = [
    &["spiralizations"],
    &["spiralisations"],
    &["spiralizations"],
    &["spiralisations"],
];

pub(crate) static ENTRY_SPIRALIZATION_14526564309233419768: VariantsMap = [
    &["spiralization"],
    &["spiralisation"],
    &["spiralization"],
    &["spiralisation"],
];

pub(crate) static ENTRY_SPIRALIZES_10710220071293796216: VariantsMap = [
    &["spiralizes"],
    &["spiralises"],
    &["spiralizes"],
    &["spiralises"],
];

pub(crate) static ENTRY_SPIRALIZE_3447519808027951591: VariantsMap = [
    &["spiralize"],
    &["spiralise"],
    &["spiralize"],
    &["spiralise"],
];

pub(crate) static ENTRY_SPIREAS_2974152297943195596: VariantsMap =
    [&["spireas"], &["spiraeas"], &["spireas"], &["spiraeas"]];

pub(crate) static ENTRY_SPIREA_8481146863445432200: VariantsMap =
    [&["spirea"], &["spiraea"], &["spirea"], &["spiraea"]];

pub(crate) static ENTRY_SPIRITIZES_8526314939083109501: VariantsMap = [
    &["spiritizes"],
    &["spiritises"],
    &["spiritizes"],
    &["spiritises"],
];

pub(crate) static ENTRY_SPIRITIZE_9805541284124148336: VariantsMap = [
    &["spiritize"],
    &["spiritise"],
    &["spiritize"],
    &["spiritise"],
];

pub(crate) static ENTRY_SPIRITUALIZATIONS_17245892670567210801: VariantsMap = [
    &["spiritualizations"],
    &["spiritualisations"],
    &["spiritualizations"],
    &["spiritualisations"],
];

pub(crate) static ENTRY_SPIRITUALIZATION_9220466398088529072: VariantsMap = [
    &["spiritualization"],
    &["spiritualisation"],
    &["spiritualization"],
    &["spiritualisation"],
];

pub(crate) static ENTRY_SPIRITUALIZED_15163734331617007407: VariantsMap = [
    &["spiritualized"],
    &["spiritualised"],
    &["spiritualized"],
    &["spiritualised"],
];

pub(crate) static ENTRY_SPIRITUALIZERS_9374370261250047870: VariantsMap = [
    &["spiritualizers"],
    &["spiritualisers"],
    &["spiritualizers"],
    &["spiritualisers"],
];

pub(crate) static ENTRY_SPIRITUALIZER_3452155405302964460: VariantsMap = [
    &["spiritualizer"],
    &["spiritualiser"],
    &["spiritualizer"],
    &["spiritualiser"],
];

pub(crate) static ENTRY_SPIRITUALIZES_15228536253347259988: VariantsMap = [
    &["spiritualizes"],
    &["spiritualises"],
    &["spiritualizes"],
    &["spiritualises"],
];

pub(crate) static ENTRY_SPIRITUALIZE_12814212072235396435: VariantsMap = [
    &["spiritualize"],
    &["spiritualise"],
    &["spiritualize"],
    &["spiritualise"],
];

pub(crate) static ENTRY_SPIRITUALIZING_3491733202887639865: VariantsMap = [
    &["spiritualizing"],
    &["spiritualising"],
    &["spiritualizing"],
    &["spiritualising"],
];

pub(crate) static ENTRY_SPIROCHETAL_15517952665892700942: VariantsMap = [
    &["spirochetal"],
    &["spirochaetal"],
    &["spirochaetal"],
    &["spirochaetal"],
];

pub(crate) static ENTRY_SPIROCHETES_7149420395283644676: VariantsMap = [
    &["spirochetes"],
    &["spirochaetes"],
    &["spirochetes"],
    &["spirochaetes"],
];

pub(crate) static ENTRY_SPIROCHETE_7516750690687611615: VariantsMap = [
    &["spirochete"],
    &["spirochaete"],
    &["spirochete"],
    &["spirochaete"],
];

pub(crate) static ENTRY_SPIROCHETOSES_8527932054069113609: VariantsMap = [
    &["spirochetoses"],
    &["spirochaetoses"],
    &["spirochaetoses"],
    &["spirochaetoses"],
];

pub(crate) static ENTRY_SPIROCHETOSIS_15823604220446153605: VariantsMap = [
    &["spirochetosis"],
    &["spirochaetosis"],
    &["spirochaetosis"],
    &["spirochaetosis"],
];

pub(crate) static ENTRY_SPIROCHETOTIC_7192851043013496969: VariantsMap = [
    &["spirochetotic"],
    &["spirochaetotic"],
    &["spirochaetotic"],
    &["spirochaetotic"],
];

pub(crate) static ENTRY_SPLANCHNOCELE_13922332607993579794: VariantsMap = [
    &["splanchnocele"],
    &["splanchnocoele"],
    &["splanchnocoele"],
    &["splanchnocoele"],
];

pub(crate) static ENTRY_SPLENDORPROOF_5461754752834589608: VariantsMap = [
    &["splendorproof"],
    &["splendourproof"],
    &["splendourproof"],
    &["splendourproof"],
];

pub(crate) static ENTRY_SPLENDORS_5940678279727313679: VariantsMap = [
    &["splendors"],
    &["splendours"],
    &["splendours"],
    &["splendours"],
];

pub(crate) static ENTRY_SPLENDOR_8664416655036864719: VariantsMap = [
    &["splendor"],
    &["splendour"],
    &["splendour"],
    &["splendour"],
];

pub(crate) static ENTRY_SPLENECTOMIZED_614544978128859415: VariantsMap = [
    &["splenectomized"],
    &["splenectomised"],
    &["splenectomized"],
    &["splenectomised"],
];

pub(crate) static ENTRY_SPLENIZATIONS_4900696190905604499: VariantsMap = [
    &["splenizations"],
    &["splenisations"],
    &["splenizations"],
    &["splenisations"],
];

pub(crate) static ENTRY_SPLENIZATION_18282593558114333381: VariantsMap = [
    &["splenization"],
    &["splenisation"],
    &["splenization"],
    &["splenisation"],
];

pub(crate) static ENTRY_SPOILED_924892233379569654: VariantsMap = [
    &["spoiled"],
    &["spoiled", "spoilt"],
    &["spoiled"],
    &["spoiled", "spoilt"],
];

pub(crate) static ENTRY_SPYER_12225595747130603215: VariantsMap =
    [&["spyer"], &["spyre"], &["spyre"], &["spyre"]];

pub(crate) static ENTRY_SQUAME_3213388851075891116: VariantsMap =
    [&["squame"], &["squamae"], &["squamae"], &["squamae"]];

pub(crate) static ENTRY_SQUAMULE_6064011923198120224: VariantsMap = [
    &["squamule"],
    &["squamulae"],
    &["squamulae"],
    &["squamulae"],
];

pub(crate) static ENTRY_SQUIER_15203146461303476056: VariantsMap =
    [&["squier"], &["squire"], &["squire"], &["squire"]];

pub(crate) static ENTRY_SQUIRRELED_18389953608476203741: VariantsMap = [
    &["squirreled"],
    &["squirrelled"],
    &["squirrelled"],
    &["squirrelled"],
];

pub(crate) static ENTRY_SQUIRRELING_2889119631030338646: VariantsMap = [
    &["squirreling"],
    &["squirrelling"],
    &["squirrelling"],
    &["squirrelling"],
];

pub(crate) static ENTRY_STABILIZABLE_4932218987124928483: VariantsMap = [
    &["stabilizable"],
    &["stabilisable"],
    &["stabilizable"],
    &["stabilisable"],
];

pub(crate) static ENTRY_STABILIZATIONS_11866129248341293272: VariantsMap = [
    &["stabilizations"],
    &["stabilisations"],
    &["stabilizations"],
    &["stabilisations"],
];

pub(crate) static ENTRY_STABILIZATION_8501631360615854418: VariantsMap = [
    &["stabilization"],
    &["stabilisation"],
    &["stabilization"],
    &["stabilisation"],
];

pub(crate) static ENTRY_STABILIZATORS_14857459698219243705: VariantsMap = [
    &["stabilizators"],
    &["stabilisators"],
    &["stabilizators"],
    &["stabilisators"],
];

pub(crate) static ENTRY_STABILIZATOR_18070208100981423639: VariantsMap = [
    &["stabilizator"],
    &["stabilisator"],
    &["stabilizator"],
    &["stabilisator"],
];

pub(crate) static ENTRY_STABILIZED_11637850169426450316: VariantsMap = [
    &["stabilized"],
    &["stabilised"],
    &["stabilized"],
    &["stabilised"],
];

pub(crate) static ENTRY_STABILIZERS_6342146151996925299: VariantsMap = [
    &["stabilizers"],
    &["stabilisers"],
    &["stabilizers"],
    &["stabilisers"],
];

pub(crate) static ENTRY_STABILIZER_10839686795364476539: VariantsMap = [
    &["stabilizer"],
    &["stabiliser"],
    &["stabilizer"],
    &["stabiliser"],
];

pub(crate) static ENTRY_STABILIZES_14273493638532544927: VariantsMap = [
    &["stabilizes"],
    &["stabilises"],
    &["stabilizes"],
    &["stabilises"],
];

pub(crate) static ENTRY_STABILIZE_11592021559489637588: VariantsMap = [
    &["stabilize"],
    &["stabilise"],
    &["stabilize"],
    &["stabilise"],
];

pub(crate) static ENTRY_STABILIZING_12133357303799134695: VariantsMap = [
    &["stabilizing"],
    &["stabilising"],
    &["stabilizing"],
    &["stabilising"],
];

pub(crate) static ENTRY_STALLIONIZES_6605755236481804236: VariantsMap = [
    &["stallionizes"],
    &["stallionises"],
    &["stallionizes"],
    &["stallionises"],
];

pub(crate) static ENTRY_STALLIONIZE_12958078712384484715: VariantsMap = [
    &["stallionize"],
    &["stallionise"],
    &["stallionize"],
    &["stallionise"],
];

pub(crate) static ENTRY_STALWARTIZES_11962685134317049994: VariantsMap = [
    &["stalwartizes"],
    &["stalwartises"],
    &["stalwartizes"],
    &["stalwartises"],
];

pub(crate) static ENTRY_STALWARTIZE_12610260529647003762: VariantsMap = [
    &["stalwartize"],
    &["stalwartise"],
    &["stalwartize"],
    &["stalwartise"],
];

pub(crate) static ENTRY_STAMMELCOLOR_10970254609910766177: VariantsMap = [
    &["stammelcolor"],
    &["stammelcolour"],
    &["stammelcolour"],
    &["stammelcolour"],
];

pub(crate) static ENTRY_STANDARDIZABLES_826096383236335749: VariantsMap = [
    &["standardizables"],
    &["standardisables"],
    &["standardizables"],
    &["standardisables"],
];

pub(crate) static ENTRY_STANDARDIZABLE_2567320277491222618: VariantsMap = [
    &["standardizable"],
    &["standardisable"],
    &["standardizable"],
    &["standardisable"],
];

pub(crate) static ENTRY_STANDARDIZATIONS_332063199494197132: VariantsMap = [
    &["standardizations"],
    &["standardisations"],
    &["standardizations"],
    &["standardisations"],
];

pub(crate) static ENTRY_STANDARDIZATION_15383021445373007707: VariantsMap = [
    &["standardization"],
    &["standardisation"],
    &["standardization"],
    &["standardisation"],
];

pub(crate) static ENTRY_STANDARDIZED_7943764922032376919: VariantsMap = [
    &["standardized"],
    &["standardised"],
    &["standardized"],
    &["standardised"],
];

pub(crate) static ENTRY_STANDARDIZERS_10454017961970777389: VariantsMap = [
    &["standardizers"],
    &["standardisers"],
    &["standardizers"],
    &["standardisers"],
];

pub(crate) static ENTRY_STANDARDIZER_6962886130708807895: VariantsMap = [
    &["standardizer"],
    &["standardiser"],
    &["standardizer"],
    &["standardiser"],
];

pub(crate) static ENTRY_STANDARDIZES_7893289976137443900: VariantsMap = [
    &["standardizes"],
    &["standardises"],
    &["standardizes"],
    &["standardises"],
];

pub(crate) static ENTRY_STANDARDIZE_16594334550448089105: VariantsMap = [
    &["standardize"],
    &["standardise"],
    &["standardize"],
    &["standardise"],
];

pub(crate) static ENTRY_STANDARDIZING_8802579594080422420: VariantsMap = [
    &["standardizing"],
    &["standardising"],
    &["standardizing"],
    &["standardising"],
];

pub(crate) static ENTRY_STANZES_12485556301551814937: VariantsMap =
    [&["stanzes"], &["stanzoes"], &["stanzoes"], &["stanzoes"]];

pub(crate) static ENTRY_STAPEDECTOMIZED_9197906406180557938: VariantsMap = [
    &["stapedectomized"],
    &["stapedectomised"],
    &["stapedectomized"],
    &["stapedectomised"],
];

pub(crate) static ENTRY_STAPHYLEDEMA_8250830785224943987: VariantsMap = [
    &["staphyledema"],
    &["staphyloedema"],
    &["staphyloedema"],
    &["staphyloedema"],
];

pub(crate) static ENTRY_STATISTICIZES_13089056342446105826: VariantsMap = [
    &["statisticizes"],
    &["statisticises"],
    &["statisticizes"],
    &["statisticises"],
];

pub(crate) static ENTRY_STATISTICIZE_11912040955141081885: VariantsMap = [
    &["statisticize"],
    &["statisticise"],
    &["statisticize"],
    &["statisticise"],
];

pub(crate) static ENTRY_STEARRHEA_11431771010957771750: VariantsMap = [
    &["stearrhea"],
    &["stearrhoea"],
    &["stearrhoea"],
    &["stearrhoea"],
];

pub(crate) static ENTRY_STEATORRHEAS_8820213659684170958: VariantsMap = [
    &["steatorrheas"],
    &["steatorrhoeas"],
    &["steatorrhoeas"],
    &["steatorrhoeas"],
];

pub(crate) static ENTRY_STEATORRHEA_16005206938373142642: VariantsMap = [
    &["steatorrhea"],
    &["steatorrhoea"],
    &["steatorrhoea"],
    &["steatorrhoea"],
];

pub(crate) static ENTRY_STELE_8010967670342221719: VariantsMap =
    [&["stele"], &["stelae"], &["stelae"], &["stelae"]];

pub(crate) static ENTRY_STENCILED_18358466251443584244: VariantsMap = [
    &["stenciled"],
    &["stencilled"],
    &["stencilled"],
    &["stencilled"],
];

pub(crate) static ENTRY_STENCILERS_1017708152015244225: VariantsMap = [
    &["stencilers"],
    &["stencillers"],
    &["stencillers"],
    &["stencillers"],
];

pub(crate) static ENTRY_STENCILER_12441732772591791835: VariantsMap = [
    &["stenciler"],
    &["stenciller"],
    &["stenciller"],
    &["stenciller"],
];

pub(crate) static ENTRY_STENCILING_16009278311382010932: VariantsMap = [
    &["stenciling"],
    &["stencilling"],
    &["stencilling"],
    &["stencilling"],
];

pub(crate) static ENTRY_STENCILIZE_1883877954556953319: VariantsMap = [
    &["stencilize"],
    &["stencilise"],
    &["stencilize"],
    &["stencilise"],
];

pub(crate) static ENTRY_STENOPEIC_2539738485702057539: VariantsMap = [
    &["stenopeic"],
    &["stenopaeic"],
    &["stenopaeic"],
    &["stenopaeic"],
];

pub(crate) static ENTRY_STENTORS_9771830217471162933: VariantsMap = [
    &["stentors"],
    &["stentours"],
    &["stentours"],
    &["stentours"],
];

pub(crate) static ENTRY_STENTOR_10286318464720816144: VariantsMap =
    [&["stentor"], &["stentour"], &["stentour"], &["stentour"]];

pub(crate) static ENTRY_STERCOREMIA_10730723271527231669: VariantsMap = [
    &["stercoremia"],
    &["stercoraemia"],
    &["stercoraemia"],
    &["stercoraemia"],
];

pub(crate) static ENTRY_STERE_13708659892245045900: VariantsMap =
    [&["stere"], &["stree"], &["stree"], &["stree"]];

pub(crate) static ENTRY_STERILIZABILITIES_16689990744951863819: VariantsMap = [
    &["sterilizabilities"],
    &["sterilisabilities"],
    &["sterilizabilities"],
    &["sterilisabilities"],
];

pub(crate) static ENTRY_STERILIZABILITY_11176247869362156533: VariantsMap = [
    &["sterilizability"],
    &["sterilisability"],
    &["sterilizability"],
    &["sterilisability"],
];

pub(crate) static ENTRY_STERILIZABLER_2981777391612929274: VariantsMap = [
    &["sterilizabler"],
    &["sterilisabler"],
    &["sterilizabler"],
    &["sterilisabler"],
];

pub(crate) static ENTRY_STERILIZABLEST_12402421338830249014: VariantsMap = [
    &["sterilizablest"],
    &["sterilisablest"],
    &["sterilizablest"],
    &["sterilisablest"],
];

pub(crate) static ENTRY_STERILIZABLES_9392344777525592572: VariantsMap = [
    &["sterilizables"],
    &["sterilisables"],
    &["sterilizables"],
    &["sterilisables"],
];

pub(crate) static ENTRY_STERILIZABLE_12001563571902655950: VariantsMap = [
    &["sterilizable"],
    &["sterilisable"],
    &["sterilizable"],
    &["sterilisable"],
];

pub(crate) static ENTRY_STERILIZATIONS_6145032887986296344: VariantsMap = [
    &["sterilizations"],
    &["sterilisations"],
    &["sterilizations"],
    &["sterilisations"],
];

pub(crate) static ENTRY_STERILIZATION_8065625074540222478: VariantsMap = [
    &["sterilization"],
    &["sterilisation"],
    &["sterilization"],
    &["sterilisation"],
];

pub(crate) static ENTRY_STERILIZED_17543306694251609885: VariantsMap = [
    &["sterilized"],
    &["sterilised"],
    &["sterilized"],
    &["sterilised"],
];

pub(crate) static ENTRY_STERILIZERS_3377446126211900294: VariantsMap = [
    &["sterilizers"],
    &["sterilisers"],
    &["sterilizers"],
    &["sterilisers"],
];

pub(crate) static ENTRY_STERILIZER_14841880991277730478: VariantsMap = [
    &["sterilizer"],
    &["steriliser"],
    &["sterilizer"],
    &["steriliser"],
];

pub(crate) static ENTRY_STERILIZES_4362381845943247126: VariantsMap = [
    &["sterilizes"],
    &["sterilises"],
    &["sterilizes"],
    &["sterilises"],
];

pub(crate) static ENTRY_STERILIZE_1847097589172243146: VariantsMap = [
    &["sterilize"],
    &["sterilise"],
    &["sterilize"],
    &["sterilise"],
];

pub(crate) static ENTRY_STERILIZING_8492025091236842001: VariantsMap = [
    &["sterilizing"],
    &["sterilising"],
    &["sterilizing"],
    &["sterilising"],
];

pub(crate) static ENTRY_STERT_2568239910800832856: VariantsMap =
    [&["stert"], &["stret"], &["stret"], &["stret"]];

pub(crate) static ENTRY_STIGMATIZATIONS_4419626284437647049: VariantsMap = [
    &["stigmatizations"],
    &["stigmatisations"],
    &["stigmatizations"],
    &["stigmatisations"],
];

pub(crate) static ENTRY_STIGMATIZATION_15367665650808291201: VariantsMap = [
    &["stigmatization"],
    &["stigmatisation"],
    &["stigmatization"],
    &["stigmatisation"],
];

pub(crate) static ENTRY_STIGMATIZED_2708765122033987200: VariantsMap = [
    &["stigmatized"],
    &["stigmatised"],
    &["stigmatized"],
    &["stigmatised"],
];

pub(crate) static ENTRY_STIGMATIZERS_3465759938789898503: VariantsMap = [
    &["stigmatizers"],
    &["stigmatisers"],
    &["stigmatizers"],
    &["stigmatisers"],
];

pub(crate) static ENTRY_STIGMATIZER_12628918335125666337: VariantsMap = [
    &["stigmatizer"],
    &["stigmatiser"],
    &["stigmatizer"],
    &["stigmatiser"],
];

pub(crate) static ENTRY_STIGMATIZES_14729433263129115837: VariantsMap = [
    &["stigmatizes"],
    &["stigmatises"],
    &["stigmatizes"],
    &["stigmatises"],
];

pub(crate) static ENTRY_STIGMATIZE_5799619399576330013: VariantsMap = [
    &["stigmatize"],
    &["stigmatise"],
    &["stigmatize"],
    &["stigmatise"],
];

pub(crate) static ENTRY_STIGMATIZING_1440308166481676994: VariantsMap = [
    &["stigmatizing"],
    &["stigmatising"],
    &["stigmatizing"],
    &["stigmatising"],
];

pub(crate) static ENTRY_STILBESTROLS_4304462747026806842: VariantsMap = [
    &["stilbestrols"],
    &["stilboestrols"],
    &["stilboestrols"],
    &["stilboestrols"],
];

pub(crate) static ENTRY_STILBESTROL_16450491116589325148: VariantsMap = [
    &["stilbestrol"],
    &["stilboestrol"],
    &["stilboestrol"],
    &["stilboestrol"],
];

pub(crate) static ENTRY_STIPULE_18061101307220428275: VariantsMap =
    [&["stipule"], &["stipulae"], &["stipulae"], &["stipulae"]];

pub(crate) static ENTRY_STOMATODEUM_6433297792284142688: VariantsMap = [
    &["stomatodeum"],
    &["stomatodaeum"],
    &["stomatodaeum"],
    &["stomatodaeum"],
];

pub(crate) static ENTRY_STOMODEAL_3023016665616811727: VariantsMap = [
    &["stomodeal"],
    &["stomodaeal"],
    &["stomodaeal"],
    &["stomodaeal"],
];

pub(crate) static ENTRY_STOMODEA_15996517343876980077: VariantsMap = [
    &["stomodea"],
    &["stomodaea"],
    &["stomodaea"],
    &["stomodaea"],
];

pub(crate) static ENTRY_STOMODEUMS_12837659428832608446: VariantsMap = [
    &["stomodeums"],
    &["stomodaeums"],
    &["stomodaeums"],
    &["stomodaeums"],
];

pub(crate) static ENTRY_STOMODEUM_7621915820620375624: VariantsMap = [
    &["stomodeum"],
    &["stomodaeum"],
    &["stomodaeum"],
    &["stomodaeum"],
];

pub(crate) static ENTRY_STORIER_1555627284462772417: VariantsMap =
    [&["storier"], &["stourier"], &["stourier"], &["stourier"]];

pub(crate) static ENTRY_STOR_3765799085742567098: VariantsMap =
    [&["stor"], &["stour"], &["stour"], &["stour"]];

pub(crate) static ENTRY_STOWERS_113381365985354937: VariantsMap =
    [&["stowers"], &["stowres"], &["stowres"], &["stowres"]];

pub(crate) static ENTRY_STOWER_9642465002851641994: VariantsMap =
    [&["stower"], &["stowre"], &["stowre"], &["stowre"]];

pub(crate) static ENTRY_STROBILE_2455104557109757172: VariantsMap = [
    &["strobile"],
    &["strobilae"],
    &["strobilae"],
    &["strobilae"],
];

pub(crate) static ENTRY_STROBILIZATIONS_18024846533503451402: VariantsMap = [
    &["strobilizations"],
    &["strobilisations"],
    &["strobilizations"],
    &["strobilisations"],
];

pub(crate) static ENTRY_STROBILIZATION_16555130605778279996: VariantsMap = [
    &["strobilization"],
    &["strobilisation"],
    &["strobilization"],
    &["strobilisation"],
];

pub(crate) static ENTRY_STRUCTURALIZATIONS_2871497142594857048: VariantsMap = [
    &["structuralizations"],
    &["structuralisations"],
    &["structuralizations"],
    &["structuralisations"],
];

pub(crate) static ENTRY_STRUCTURALIZATION_1517772601489028195: VariantsMap = [
    &["structuralization"],
    &["structuralisation"],
    &["structuralization"],
    &["structuralisation"],
];

pub(crate) static ENTRY_STRUCTURALIZES_2020936801127552663: VariantsMap = [
    &["structuralizes"],
    &["structuralises"],
    &["structuralizes"],
    &["structuralises"],
];

pub(crate) static ENTRY_STRUCTURALIZE_14863509506371740395: VariantsMap = [
    &["structuralize"],
    &["structuralise"],
    &["structuralize"],
    &["structuralise"],
];

pub(crate) static ENTRY_STRYCHNINIZATIONS_13851139297011899199: VariantsMap = [
    &["strychninizations"],
    &["strychninisations"],
    &["strychninizations"],
    &["strychninisations"],
];

pub(crate) static ENTRY_STRYCHNINIZATION_4279485397335566578: VariantsMap = [
    &["strychninization"],
    &["strychninisation"],
    &["strychninization"],
    &["strychninisation"],
];

pub(crate) static ENTRY_STRYCHNINIZES_18398688944091938655: VariantsMap = [
    &["strychninizes"],
    &["strychninises"],
    &["strychninizes"],
    &["strychninises"],
];

pub(crate) static ENTRY_STRYCHNINIZE_9141667085528007172: VariantsMap = [
    &["strychninize"],
    &["strychninise"],
    &["strychninize"],
    &["strychninise"],
];

pub(crate) static ENTRY_STUMOR_17411403876305618946: VariantsMap =
    [&["stumor"], &["stumour"], &["stumour"], &["stumour"]];

pub(crate) static ENTRY_STYLIZATIONS_2138820429543216253: VariantsMap = [
    &["stylizations"],
    &["stylisations"],
    &["stylizations"],
    &["stylisations"],
];

pub(crate) static ENTRY_STYLIZATION_6235644091145662258: VariantsMap = [
    &["stylization"],
    &["stylisation"],
    &["stylization"],
    &["stylisation"],
];

pub(crate) static ENTRY_STYLIZED_4847869505285666329: VariantsMap =
    [&["stylized"], &["stylised"], &["stylized"], &["stylised"]];

pub(crate) static ENTRY_STYLIZERS_15139738520592840604: VariantsMap = [
    &["stylizers"],
    &["stylisers"],
    &["stylizers"],
    &["stylisers"],
];

pub(crate) static ENTRY_STYLIZER_13982978292394626940: VariantsMap =
    [&["stylizer"], &["styliser"], &["stylizer"], &["styliser"]];

pub(crate) static ENTRY_STYLIZES_2600387667375095470: VariantsMap =
    [&["stylizes"], &["stylises"], &["stylizes"], &["stylises"]];

pub(crate) static ENTRY_STYLIZE_13371282579615467796: VariantsMap =
    [&["stylize"], &["stylise"], &["stylize"], &["stylise"]];

pub(crate) static ENTRY_STYLIZING_10937898920006317214: VariantsMap = [
    &["stylizing"],
    &["stylising"],
    &["stylizing"],
    &["stylising"],
];

pub(crate) static ENTRY_STYLOPIZED_2650877490960920576: VariantsMap = [
    &["stylopized"],
    &["stylopised"],
    &["stylopized"],
    &["stylopised"],
];

pub(crate) static ENTRY_SUBARMORS_17961946408548270853: VariantsMap = [
    &["subarmors"],
    &["subarmours"],
    &["subarmours"],
    &["subarmours"],
];

pub(crate) static ENTRY_SUBARMOR_14689004097074153351: VariantsMap = [
    &["subarmor"],
    &["subarmour"],
    &["subarmour"],
    &["subarmour"],
];

pub(crate) static ENTRY_SUBCALIBER_10763578646516555123: VariantsMap = [
    &["subcaliber"],
    &["subcalibre"],
    &["subcalibre"],
    &["subcalibre"],
];

pub(crate) static ENTRY_SUBCATEGORIZING_559546594663443201: VariantsMap = [
    &["subcategorizing"],
    &["subcategorising"],
    &["subcategorizing"],
    &["subcategorising"],
];

pub(crate) static ENTRY_SUBCENTER_16599153427473361658: VariantsMap = [
    &["subcenter"],
    &["subcentre"],
    &["subcentre"],
    &["subcentre"],
];

pub(crate) static ENTRY_SUBDUER_1073236083878073402: VariantsMap =
    [&["subduer"], &["subdure"], &["subdure"], &["subdure"]];

pub(crate) static ENTRY_SUBERATE_13033646582163882584: VariantsMap = [
    &["suberate"],
    &["subaerate"],
    &["subaerate"],
    &["subaerate"],
];

pub(crate) static ENTRY_SUBERIZATIONS_11122919473658548263: VariantsMap = [
    &["suberizations"],
    &["suberisations"],
    &["suberizations"],
    &["suberisations"],
];

pub(crate) static ENTRY_SUBERIZATION_13270039726229410996: VariantsMap = [
    &["suberization"],
    &["suberisation"],
    &["suberization"],
    &["suberisation"],
];

pub(crate) static ENTRY_SUBERIZED_5285782219644888811: VariantsMap = [
    &["suberized"],
    &["suberised"],
    &["suberized"],
    &["suberised"],
];

pub(crate) static ENTRY_SUBERIZES_13278889375914696842: VariantsMap = [
    &["suberizes"],
    &["suberises"],
    &["suberizes"],
    &["suberises"],
];

pub(crate) static ENTRY_SUBERIZE_9315879378118843248: VariantsMap =
    [&["suberize"], &["suberise"], &["suberize"], &["suberise"]];

pub(crate) static ENTRY_SUBERIZING_18249078846570846131: VariantsMap = [
    &["suberizing"],
    &["suberising"],
    &["suberizing"],
    &["suberising"],
];

pub(crate) static ENTRY_SUBESOPHAGEAL_6106301781363912390: VariantsMap = [
    &["subesophageal"],
    &["suboesophageal"],
    &["suboesophageal"],
    &["suboesophageal"],
];

pub(crate) static ENTRY_SUBETHERIC_3831523759918158602: VariantsMap = [
    &["subetheric"],
    &["subaetheric"],
    &["subaetheric"],
    &["subaetheric"],
];

pub(crate) static ENTRY_SUBFLAVORS_4181079619994568530: VariantsMap = [
    &["subflavors"],
    &["subflavours"],
    &["subflavours"],
    &["subflavours"],
];

pub(crate) static ENTRY_SUBFLAVOR_8131995189965449489: VariantsMap = [
    &["subflavor"],
    &["subflavour"],
    &["subflavour"],
    &["subflavour"],
];

pub(crate) static ENTRY_SUBITIZED_7501997579797246264: VariantsMap = [
    &["subitized"],
    &["subitised"],
    &["subitized"],
    &["subitised"],
];

pub(crate) static ENTRY_SUBITIZES_14667322345356948294: VariantsMap = [
    &["subitizes"],
    &["subitises"],
    &["subitizes"],
    &["subitises"],
];

pub(crate) static ENTRY_SUBITIZE_2500800531029112377: VariantsMap =
    [&["subitize"], &["subitise"], &["subitize"], &["subitise"]];

pub(crate) static ENTRY_SUBITIZING_14779207785252328909: VariantsMap = [
    &["subitizing"],
    &["subitising"],
    &["subitizing"],
    &["subitising"],
];

pub(crate) static ENTRY_SUBJECTIVIZATIONS_2654941212096447523: VariantsMap = [
    &["subjectivizations"],
    &["subjectivisations"],
    &["subjectivizations"],
    &["subjectivisations"],
];

pub(crate) static ENTRY_SUBJECTIVIZATION_6885863457754335689: VariantsMap = [
    &["subjectivization"],
    &["subjectivisation"],
    &["subjectivization"],
    &["subjectivisation"],
];

pub(crate) static ENTRY_SUBJECTIVIZED_2336514392929461039: VariantsMap = [
    &["subjectivized"],
    &["subjectivised"],
    &["subjectivized"],
    &["subjectivised"],
];

pub(crate) static ENTRY_SUBJECTIVIZES_15781894181825728740: VariantsMap = [
    &["subjectivizes"],
    &["subjectivises"],
    &["subjectivizes"],
    &["subjectivises"],
];

pub(crate) static ENTRY_SUBJECTIVIZE_9063057077838112531: VariantsMap = [
    &["subjectivize"],
    &["subjectivise"],
    &["subjectivize"],
    &["subjectivise"],
];

pub(crate) static ENTRY_SUBJECTIVIZING_10470471665341546903: VariantsMap = [
    &["subjectivizing"],
    &["subjectivising"],
    &["subjectivizing"],
    &["subjectivising"],
];

pub(crate) static ENTRY_SUBLIMIZED_15642013700880675817: VariantsMap = [
    &["sublimized"],
    &["sublimised"],
    &["sublimized"],
    &["sublimised"],
];

pub(crate) static ENTRY_SUBLIMIZES_15236401821727981401: VariantsMap = [
    &["sublimizes"],
    &["sublimises"],
    &["sublimizes"],
    &["sublimises"],
];

pub(crate) static ENTRY_SUBLIMIZE_4455186032578780941: VariantsMap = [
    &["sublimize"],
    &["sublimise"],
    &["sublimize"],
    &["sublimise"],
];

pub(crate) static ENTRY_SUBLIMIZING_1361129763961634185: VariantsMap = [
    &["sublimizing"],
    &["sublimising"],
    &["sublimizing"],
    &["sublimising"],
];

pub(crate) static ENTRY_SUBMINIATURIZATION_10556185094969044985: VariantsMap = [
    &["subminiaturization"],
    &["subminiaturisation"],
    &["subminiaturization"],
    &["subminiaturisation"],
];

pub(crate) static ENTRY_SUBMINIATURIZED_16328822871246757770: VariantsMap = [
    &["subminiaturized"],
    &["subminiaturised"],
    &["subminiaturized"],
    &["subminiaturised"],
];

pub(crate) static ENTRY_SUBMINIATURIZES_7040258188390121080: VariantsMap = [
    &["subminiaturizes"],
    &["subminiaturises"],
    &["subminiaturizes"],
    &["subminiaturises"],
];

pub(crate) static ENTRY_SUBMINIATURIZE_5999865733995238861: VariantsMap = [
    &["subminiaturize"],
    &["subminiaturise"],
    &["subminiaturize"],
    &["subminiaturise"],
];

pub(crate) static ENTRY_SUBMINIATURIZING_8376505957619603505: VariantsMap = [
    &["subminiaturizing"],
    &["subminiaturising"],
    &["subminiaturizing"],
    &["subminiaturising"],
];

pub(crate) static ENTRY_SUBPULVERIZERS_11573273933022945510: VariantsMap = [
    &["subpulverizers"],
    &["subpulverisers"],
    &["subpulverizers"],
    &["subpulverisers"],
];

pub(crate) static ENTRY_SUBPULVERIZER_12169609575785620518: VariantsMap = [
    &["subpulverizer"],
    &["subpulveriser"],
    &["subpulverizer"],
    &["subpulveriser"],
];

pub(crate) static ENTRY_SUBSIDIZABLES_3230006499890888386: VariantsMap = [
    &["subsidizables"],
    &["subsidisables"],
    &["subsidizables"],
    &["subsidisables"],
];

pub(crate) static ENTRY_SUBSIDIZABLE_7909557660059621352: VariantsMap = [
    &["subsidizable"],
    &["subsidisable"],
    &["subsidizable"],
    &["subsidisable"],
];

pub(crate) static ENTRY_SUBSIDIZATIONS_4486482297001394355: VariantsMap = [
    &["subsidizations"],
    &["subsidisations"],
    &["subsidizations"],
    &["subsidisations"],
];

pub(crate) static ENTRY_SUBSIDIZATION_7432910440349917685: VariantsMap = [
    &["subsidization"],
    &["subsidisation"],
    &["subsidization"],
    &["subsidisation"],
];

pub(crate) static ENTRY_SUBSIDIZED_12233822221943616893: VariantsMap = [
    &["subsidized"],
    &["subsidised"],
    &["subsidized"],
    &["subsidised"],
];

pub(crate) static ENTRY_SUBSIDIZERS_16869546055076390406: VariantsMap = [
    &["subsidizers"],
    &["subsidisers"],
    &["subsidizers"],
    &["subsidisers"],
];

pub(crate) static ENTRY_SUBSIDIZER_1594720106549650311: VariantsMap = [
    &["subsidizer"],
    &["subsidiser"],
    &["subsidizer"],
    &["subsidiser"],
];

pub(crate) static ENTRY_SUBSIDIZES_12108807615198513181: VariantsMap = [
    &["subsidizes"],
    &["subsidises"],
    &["subsidizes"],
    &["subsidises"],
];

pub(crate) static ENTRY_SUBSIDIZE_8108840583723309870: VariantsMap = [
    &["subsidize"],
    &["subsidise"],
    &["subsidize"],
    &["subsidise"],
];

pub(crate) static ENTRY_SUBSIDIZING_2003367098489373574: VariantsMap = [
    &["subsidizing"],
    &["subsidising"],
    &["subsidizing"],
    &["subsidising"],
];

pub(crate) static ENTRY_SUBSPECIALIZES_16872835233018448770: VariantsMap = [
    &["subspecializes"],
    &["subspecialises"],
    &["subspecializes"],
    &["subspecialises"],
];

pub(crate) static ENTRY_SUBSPECIALIZE_13734659418809213289: VariantsMap = [
    &["subspecialize"],
    &["subspecialise"],
    &["subspecialize"],
    &["subspecialise"],
];

pub(crate) static ENTRY_SUBSPECIALTIES_2578544006462378304: VariantsMap = [
    &["subspecialties"],
    &["subspecialities"],
    &["subspecialities"],
    &["subspecialities"],
];

pub(crate) static ENTRY_SUBSPECIALTY_8060605560355986087: VariantsMap = [
    &["subspecialty"],
    &["subspeciality"],
    &["subspeciality"],
    &["subspeciality"],
];

pub(crate) static ENTRY_SUBSTANDARDIZES_12565775678053536739: VariantsMap = [
    &["substandardizes"],
    &["substandardises"],
    &["substandardizes"],
    &["substandardises"],
];

pub(crate) static ENTRY_SUBSTANDARDIZE_2480873768266314489: VariantsMap = [
    &["substandardize"],
    &["substandardise"],
    &["substandardize"],
    &["substandardise"],
];

pub(crate) static ENTRY_SUBSTANTIALIZED_9556338489115014542: VariantsMap = [
    &["substantialized"],
    &["substantialised"],
    &["substantialized"],
    &["substantialised"],
];

pub(crate) static ENTRY_SUBSTANTIALIZES_3032789098283567833: VariantsMap = [
    &["substantializes"],
    &["substantialises"],
    &["substantializes"],
    &["substantialises"],
];

pub(crate) static ENTRY_SUBSTANTIALIZE_1127374552134288399: VariantsMap = [
    &["substantialize"],
    &["substantialise"],
    &["substantialize"],
    &["substantialise"],
];

pub(crate) static ENTRY_SUBSTANTIALIZING_3707317163949415405: VariantsMap = [
    &["substantializing"],
    &["substantialising"],
    &["substantializing"],
    &["substantialising"],
];

pub(crate) static ENTRY_SUBSTANTIVIZED_9375791663725833847: VariantsMap = [
    &["substantivized"],
    &["substantivised"],
    &["substantivized"],
    &["substantivised"],
];

pub(crate) static ENTRY_SUBSTANTIVIZES_11922834391647562292: VariantsMap = [
    &["substantivizes"],
    &["substantivises"],
    &["substantivizes"],
    &["substantivises"],
];

pub(crate) static ENTRY_SUBSTANTIVIZE_8369841284330486062: VariantsMap = [
    &["substantivize"],
    &["substantivise"],
    &["substantivize"],
    &["substantivise"],
];

pub(crate) static ENTRY_SUBSTANTIVIZING_16343156662998297538: VariantsMap = [
    &["substantivizing"],
    &["substantivising"],
    &["substantivizing"],
    &["substantivising"],
];

pub(crate) static ENTRY_SUBSTERILIZATION_3889547521413232121: VariantsMap = [
    &["substerilization"],
    &["substerilisation"],
    &["substerilization"],
    &["substerilisation"],
];

pub(crate) static ENTRY_SUBTERRANEANIZES_11453052809587097988: VariantsMap = [
    &["subterraneanizes"],
    &["subterraneanises"],
    &["subterraneanizes"],
    &["subterraneanises"],
];

pub(crate) static ENTRY_SUBTERRANEANIZE_4933036662972416297: VariantsMap = [
    &["subterraneanize"],
    &["subterraneanise"],
    &["subterraneanize"],
    &["subterraneanise"],
];

pub(crate) static ENTRY_SUBTILIZATIONS_17765701698989538260: VariantsMap = [
    &["subtilizations"],
    &["subtilisations"],
    &["subtilizations"],
    &["subtilisations"],
];

pub(crate) static ENTRY_SUBTILIZATION_1777218873123835692: VariantsMap = [
    &["subtilization"],
    &["subtilisation"],
    &["subtilization"],
    &["subtilisation"],
];

pub(crate) static ENTRY_SUBTILIZED_6481039469260968556: VariantsMap = [
    &["subtilized"],
    &["subtilised"],
    &["subtilized"],
    &["subtilised"],
];

pub(crate) static ENTRY_SUBTILIZERS_6535260454278612470: VariantsMap = [
    &["subtilizers"],
    &["subtilisers"],
    &["subtilizers"],
    &["subtilisers"],
];

pub(crate) static ENTRY_SUBTILIZER_13298729605235827690: VariantsMap = [
    &["subtilizer"],
    &["subtiliser"],
    &["subtilizer"],
    &["subtiliser"],
];

pub(crate) static ENTRY_SUBTILIZES_13403038892595792400: VariantsMap = [
    &["subtilizes"],
    &["subtilises"],
    &["subtilizes"],
    &["subtilises"],
];

pub(crate) static ENTRY_SUBTILIZE_14600672625543696252: VariantsMap = [
    &["subtilize"],
    &["subtilise"],
    &["subtilize"],
    &["subtilise"],
];

pub(crate) static ENTRY_SUBTILIZING_2257348183132014726: VariantsMap = [
    &["subtilizing"],
    &["subtilising"],
    &["subtilizing"],
    &["subtilising"],
];

pub(crate) static ENTRY_SUBTOTALED_2297106669732865188: VariantsMap = [
    &["subtotaled"],
    &["subtotalled"],
    &["subtotalled"],
    &["subtotalled"],
];

pub(crate) static ENTRY_SUBTOTALING_6150888332120898834: VariantsMap = [
    &["subtotaling"],
    &["subtotalling"],
    &["subtotalling"],
    &["subtotalling"],
];

pub(crate) static ENTRY_SUBURBANIZATIONS_11288460981948975469: VariantsMap = [
    &["suburbanizations"],
    &["suburbanisations"],
    &["suburbanizations"],
    &["suburbanisations"],
];

pub(crate) static ENTRY_SUBURBANIZATION_3414694287850191476: VariantsMap = [
    &["suburbanization"],
    &["suburbanisation"],
    &["suburbanization"],
    &["suburbanisation"],
];

pub(crate) static ENTRY_SUBURBANIZED_14463903828300157975: VariantsMap = [
    &["suburbanized"],
    &["suburbanised"],
    &["suburbanized"],
    &["suburbanised"],
];

pub(crate) static ENTRY_SUBURBANIZES_1453459705211408783: VariantsMap = [
    &["suburbanizes"],
    &["suburbanises"],
    &["suburbanizes"],
    &["suburbanises"],
];

pub(crate) static ENTRY_SUBURBANIZE_8705753901311457396: VariantsMap = [
    &["suburbanize"],
    &["suburbanise"],
    &["suburbanize"],
    &["suburbanise"],
];

pub(crate) static ENTRY_SUBURBANIZING_10298908135687396391: VariantsMap = [
    &["suburbanizing"],
    &["suburbanising"],
    &["suburbanizing"],
    &["suburbanising"],
];

pub(crate) static ENTRY_SUBVITALIZATION_2234121536923804898: VariantsMap = [
    &["subvitalization"],
    &["subvitalisation"],
    &["subvitalization"],
    &["subvitalisation"],
];

pub(crate) static ENTRY_SUBVITALIZEDDER_16935286009271794249: VariantsMap = [
    &["subvitalizedder"],
    &["subvitalisedder"],
    &["subvitalizedder"],
    &["subvitalisedder"],
];

pub(crate) static ENTRY_SUBVITALIZEDDEST_14140395937370435021: VariantsMap = [
    &["subvitalizeddest"],
    &["subvitaliseddest"],
    &["subvitalizeddest"],
    &["subvitaliseddest"],
];

pub(crate) static ENTRY_SUBVITALIZEDS_16695614298676695891: VariantsMap = [
    &["subvitalizeds"],
    &["subvitaliseds"],
    &["subvitalizeds"],
    &["subvitaliseds"],
];

pub(crate) static ENTRY_SUBVITALIZED_11390686209800763194: VariantsMap = [
    &["subvitalized"],
    &["subvitalised"],
    &["subvitalized"],
    &["subvitalised"],
];

pub(crate) static ENTRY_SUCCORABLES_10056192329668029969: VariantsMap = [
    &["succorables"],
    &["succourables"],
    &["succourables"],
    &["succourables"],
];

pub(crate) static ENTRY_SUCCORABLE_8193040169819434674: VariantsMap = [
    &["succorable"],
    &["succourable"],
    &["succourable"],
    &["succourable"],
];

pub(crate) static ENTRY_SUCCORED_5734881716933621932: VariantsMap = [
    &["succored"],
    &["succoured"],
    &["succoured"],
    &["succoured"],
];

pub(crate) static ENTRY_SUCCORERS_1481818548982553037: VariantsMap = [
    &["succorers"],
    &["succourers"],
    &["succourers"],
    &["succourers"],
];

pub(crate) static ENTRY_SUCCORER_13160971653163440928: VariantsMap = [
    &["succorer"],
    &["succourer"],
    &["succourer"],
    &["succourer"],
];

pub(crate) static ENTRY_SUCCORFUL_6831680557192624315: VariantsMap = [
    &["succorful"],
    &["succourful"],
    &["succourful"],
    &["succourful"],
];

pub(crate) static ENTRY_SUCCORING_2368336012653392444: VariantsMap = [
    &["succoring"],
    &["succouring"],
    &["succouring"],
    &["succouring"],
];

pub(crate) static ENTRY_SUCCORLESSES_14511871674951354789: VariantsMap = [
    &["succorlesses"],
    &["succourlesses"],
    &["succourlesses"],
    &["succourlesses"],
];

pub(crate) static ENTRY_SUCCORLESS_1279983428236022133: VariantsMap = [
    &["succorless"],
    &["succourless"],
    &["succourless"],
    &["succourless"],
];

pub(crate) static ENTRY_SUCCORRHEA_11639508368864631200: VariantsMap = [
    &["succorrhea"],
    &["succorrhoea"],
    &["succorrhoea"],
    &["succorrhoea"],
];

pub(crate) static ENTRY_SUCCORS_12549649896393872866: VariantsMap =
    [&["succors"], &["succours"], &["succours"], &["succours"]];

pub(crate) static ENTRY_SUCCOR_17748336429959042470: VariantsMap =
    [&["succor"], &["succour"], &["succour"], &["succour"]];

pub(crate) static ENTRY_SUCCUBE_6000773581681008450: VariantsMap =
    [&["succube"], &["succubae"], &["succubae"], &["succubae"]];

pub(crate) static ENTRY_SUERS_10799148117412208703: VariantsMap =
    [&["suers"], &["sures"], &["sures"], &["sures"]];

pub(crate) static ENTRY_SUGGESTIONIZES_8428442750421813025: VariantsMap = [
    &["suggestionizes"],
    &["suggestionises"],
    &["suggestionizes"],
    &["suggestionises"],
];

pub(crate) static ENTRY_SUGGESTIONIZE_14021259995286429862: VariantsMap = [
    &["suggestionize"],
    &["suggestionise"],
    &["suggestionize"],
    &["suggestionise"],
];

pub(crate) static ENTRY_SULCALIZED_13504221656842077518: VariantsMap = [
    &["sulcalized"],
    &["sulcalised"],
    &["sulcalized"],
    &["sulcalised"],
];

pub(crate) static ENTRY_SULCALIZES_9396799022900306191: VariantsMap = [
    &["sulcalizes"],
    &["sulcalises"],
    &["sulcalizes"],
    &["sulcalises"],
];

pub(crate) static ENTRY_SULCALIZE_2938309778844562772: VariantsMap = [
    &["sulcalize"],
    &["sulcalise"],
    &["sulcalize"],
    &["sulcalise"],
];

pub(crate) static ENTRY_SULCALIZING_15642492133518955698: VariantsMap = [
    &["sulcalizing"],
    &["sulcalising"],
    &["sulcalizing"],
    &["sulcalising"],
];

pub(crate) static ENTRY_SULFATES_8796950330452912058: VariantsMap = [
    &["sulfates"],
    &["sulphates"],
    &["sulphates"],
    &["sulphates"],
];

pub(crate) static ENTRY_SULFATE_5597431207872465349: VariantsMap =
    [&["sulfate"], &["sulphate"], &["sulphate"], &["sulphate"]];

pub(crate) static ENTRY_SULFATIZES_11692908458573934003: VariantsMap = [
    &["sulfatizes"],
    &["sulfatises"],
    &["sulfatizes"],
    &["sulfatises"],
];

pub(crate) static ENTRY_SULFATIZE_16108553705217849389: VariantsMap = [
    &["sulfatize"],
    &["sulfatise"],
    &["sulfatize"],
    &["sulfatise"],
];

pub(crate) static ENTRY_SULFIDES_13405158617155232434: VariantsMap = [
    &["sulfides"],
    &["sulphides"],
    &["sulphides"],
    &["sulphides"],
];

pub(crate) static ENTRY_SULFIDE_9727735702512693147: VariantsMap =
    [&["sulfide"], &["sulphide"], &["sulphide"], &["sulphide"]];

pub(crate) static ENTRY_SULFURED_11124029077762090229: VariantsMap = [
    &["sulfured"],
    &["sulphured"],
    &["sulphured"],
    &["sulphured"],
];

pub(crate) static ENTRY_SULFURIC_10293656358970420214: VariantsMap = [
    &["sulfuric"],
    &["sulphuric"],
    &["sulphuric"],
    &["sulphuric"],
];

pub(crate) static ENTRY_SULFURING_14046967905068039328: VariantsMap = [
    &["sulfuring"],
    &["sulphuring"],
    &["sulphuring"],
    &["sulphuring"],
];

pub(crate) static ENTRY_SULFURIZATIONS_9408911189702855813: VariantsMap = [
    &["sulfurizations"],
    &["sulphurisations"],
    &["sulphurizations"],
    &["sulphurisations"],
];

pub(crate) static ENTRY_SULFURIZATION_797568185517141197: VariantsMap = [
    &["sulfurization"],
    &["sulphurisation"],
    &["sulphurization"],
    &["sulphurisation"],
];

pub(crate) static ENTRY_SULFURIZED_3822416265235130962: VariantsMap = [
    &["sulfurized"],
    &["sulphurised"],
    &["sulphurized"],
    &["sulphurised"],
];

pub(crate) static ENTRY_SULFURIZES_932516641833566211: VariantsMap = [
    &["sulfurizes"],
    &["sulphurises"],
    &["sulphurizes"],
    &["sulphurises"],
];

pub(crate) static ENTRY_SULFURIZE_8846852934236096730: VariantsMap = [
    &["sulfurize"],
    &["sulphurise"],
    &["sulphurize"],
    &["sulphurise"],
];

pub(crate) static ENTRY_SULFURIZING_12427710021489862632: VariantsMap = [
    &["sulfurizing"],
    &["sulphurising"],
    &["sulphurizing"],
    &["sulphurising"],
];

pub(crate) static ENTRY_SULFUROUS_15394058625634122012: VariantsMap = [
    &["sulfurous"],
    &["sulphurous"],
    &["sulphurous"],
    &["sulphurous"],
];

pub(crate) static ENTRY_SULFURS_6162252460689699663: VariantsMap =
    [&["sulfurs"], &["sulphurs"], &["sulphurs"], &["sulphurs"]];

pub(crate) static ENTRY_SULFUR_3036232781385162519: VariantsMap =
    [&["sulfur"], &["sulphur"], &["sulphur"], &["sulphur"]];

pub(crate) static ENTRY_SULTANIZES_5504812872942776048: VariantsMap = [
    &["sultanizes"],
    &["sultanises"],
    &["sultanizes"],
    &["sultanises"],
];

pub(crate) static ENTRY_SULTANIZE_4089644632105301224: VariantsMap = [
    &["sultanize"],
    &["sultanise"],
    &["sultanize"],
    &["sultanise"],
];

pub(crate) static ENTRY_SUMMARIZABLE_11797340382217227203: VariantsMap = [
    &["summarizable"],
    &["summarisable"],
    &["summarizable"],
    &["summarisable"],
];

pub(crate) static ENTRY_SUMMARIZATIONS_6327594643920428186: VariantsMap = [
    &["summarizations"],
    &["summarisations"],
    &["summarizations"],
    &["summarisations"],
];

pub(crate) static ENTRY_SUMMARIZATION_9281770067935535362: VariantsMap = [
    &["summarization"],
    &["summarisation"],
    &["summarization"],
    &["summarisation"],
];

pub(crate) static ENTRY_SUMMARIZED_16717521893464613077: VariantsMap = [
    &["summarized"],
    &["summarised"],
    &["summarized"],
    &["summarised"],
];

pub(crate) static ENTRY_SUMMARIZERS_8415819060575461568: VariantsMap = [
    &["summarizers"],
    &["summarisers"],
    &["summarizers"],
    &["summarisers"],
];

pub(crate) static ENTRY_SUMMARIZER_11266733895685449964: VariantsMap = [
    &["summarizer"],
    &["summariser"],
    &["summarizer"],
    &["summariser"],
];

pub(crate) static ENTRY_SUMMARIZES_7904661076957850623: VariantsMap = [
    &["summarizes"],
    &["summarises"],
    &["summarizes"],
    &["summarises"],
];

pub(crate) static ENTRY_SUMMARIZE_7205302793340192646: VariantsMap = [
    &["summarize"],
    &["summarise"],
    &["summarize"],
    &["summarise"],
];

pub(crate) static ENTRY_SUMMARIZING_12169215762339627229: VariantsMap = [
    &["summarizing"],
    &["summarising"],
    &["summarizing"],
    &["summarising"],
];

pub(crate) static ENTRY_SUMMERIZES_3040653270422312241: VariantsMap = [
    &["summerizes"],
    &["summerises"],
    &["summerizes"],
    &["summerises"],
];

pub(crate) static ENTRY_SUMMERIZE_10663979453286201359: VariantsMap = [
    &["summerize"],
    &["summerise"],
    &["summerize"],
    &["summerise"],
];

pub(crate) static ENTRY_SUPERACKNOWLEDGMENTS_4098865423626000036: VariantsMap = [
    &["superacknowledgments"],
    &["superacknowledgements"],
    &["superacknowledgements"],
    &["superacknowledgements"],
];

pub(crate) static ENTRY_SUPERACKNOWLEDGMENT_16445420068922742152: VariantsMap = [
    &["superacknowledgment"],
    &["superacknowledgement"],
    &["superacknowledgement"],
    &["superacknowledgement"],
];

pub(crate) static ENTRY_SUPERCANONIZATIONS_1119676930445903493: VariantsMap = [
    &["supercanonizations"],
    &["supercanonisations"],
    &["supercanonizations"],
    &["supercanonisations"],
];

pub(crate) static ENTRY_SUPERCANONIZATION_17683305064053601136: VariantsMap = [
    &["supercanonization"],
    &["supercanonisation"],
    &["supercanonization"],
    &["supercanonisation"],
];

pub(crate) static ENTRY_SUPERCARBONIZATIONS_3247843337047706639: VariantsMap = [
    &["supercarbonizations"],
    &["supercarbonisations"],
    &["supercarbonizations"],
    &["supercarbonisations"],
];

pub(crate) static ENTRY_SUPERCARBONIZATION_6095551176388121901: VariantsMap = [
    &["supercarbonization"],
    &["supercarbonisation"],
    &["supercarbonization"],
    &["supercarbonisation"],
];

pub(crate) static ENTRY_SUPERCARBONIZES_4714606489710886222: VariantsMap = [
    &["supercarbonizes"],
    &["supercarbonises"],
    &["supercarbonizes"],
    &["supercarbonises"],
];

pub(crate) static ENTRY_SUPERCARBONIZE_9134949404520115058: VariantsMap = [
    &["supercarbonize"],
    &["supercarbonise"],
    &["supercarbonize"],
    &["supercarbonise"],
];

pub(crate) static ENTRY_SUPERCIVILIZATIONS_13936444365054891455: VariantsMap = [
    &["supercivilizations"],
    &["supercivilisations"],
    &["supercivilizations"],
    &["supercivilisations"],
];

pub(crate) static ENTRY_SUPERCIVILIZATION_17594967252879848979: VariantsMap = [
    &["supercivilization"],
    &["supercivilisation"],
    &["supercivilization"],
    &["supercivilisation"],
];

pub(crate) static ENTRY_SUPERCIVILIZEDS_9933421721846909294: VariantsMap = [
    &["supercivilizeds"],
    &["superciviliseds"],
    &["supercivilizeds"],
    &["superciviliseds"],
];

pub(crate) static ENTRY_SUPERCIVILIZED_14265601213590631881: VariantsMap = [
    &["supercivilized"],
    &["supercivilised"],
    &["supercivilized"],
    &["supercivilised"],
];

pub(crate) static ENTRY_SUPEREMPHASIZES_9334071145444228469: VariantsMap = [
    &["superemphasizes"],
    &["superemphasises"],
    &["superemphasizes"],
    &["superemphasises"],
];

pub(crate) static ENTRY_SUPEREMPHASIZE_14765293780803106865: VariantsMap = [
    &["superemphasize"],
    &["superemphasise"],
    &["superemphasize"],
    &["superemphasise"],
];

pub(crate) static ENTRY_SUPERFETATIONS_13845937589834211720: VariantsMap = [
    &["superfetations"],
    &["superfoetations"],
    &["superfoetations"],
    &["superfoetations"],
];

pub(crate) static ENTRY_SUPERFETATION_8769492329398167353: VariantsMap = [
    &["superfetation"],
    &["superfoetation"],
    &["superfoetation"],
    &["superfoetation"],
];

pub(crate) static ENTRY_SUPERFICIALIZED_3400177078863086539: VariantsMap = [
    &["superficialized"],
    &["superficialised"],
    &["superficialized"],
    &["superficialised"],
];

pub(crate) static ENTRY_SUPERFICIALIZES_8682644560012007515: VariantsMap = [
    &["superficializes"],
    &["superficialises"],
    &["superficializes"],
    &["superficialises"],
];

pub(crate) static ENTRY_SUPERFICIALIZE_4878826183094302727: VariantsMap = [
    &["superficialize"],
    &["superficialise"],
    &["superficialize"],
    &["superficialise"],
];

pub(crate) static ENTRY_SUPERFICIALIZING_17281557816321612365: VariantsMap = [
    &["superficializing"],
    &["superficialising"],
    &["superficializing"],
    &["superficialising"],
];

pub(crate) static ENTRY_SUPERHUMANIZED_13295231816777999016: VariantsMap = [
    &["superhumanized"],
    &["superhumanised"],
    &["superhumanized"],
    &["superhumanised"],
];

pub(crate) static ENTRY_SUPERHUMANIZES_8763034129839149008: VariantsMap = [
    &["superhumanizes"],
    &["superhumanises"],
    &["superhumanizes"],
    &["superhumanises"],
];

pub(crate) static ENTRY_SUPERHUMANIZE_3907028277789439524: VariantsMap = [
    &["superhumanize"],
    &["superhumanise"],
    &["superhumanize"],
    &["superhumanise"],
];

pub(crate) static ENTRY_SUPERHUMANIZING_13287141753608663171: VariantsMap = [
    &["superhumanizing"],
    &["superhumanising"],
    &["superhumanizing"],
    &["superhumanising"],
];

pub(crate) static ENTRY_SUPERNATURALIZED_1928759394283114442: VariantsMap = [
    &["supernaturalized"],
    &["supernaturalised"],
    &["supernaturalized"],
    &["supernaturalised"],
];

pub(crate) static ENTRY_SUPERNATURALIZES_13003909341630049259: VariantsMap = [
    &["supernaturalizes"],
    &["supernaturalises"],
    &["supernaturalizes"],
    &["supernaturalises"],
];

pub(crate) static ENTRY_SUPERNATURALIZE_1888217581153989902: VariantsMap = [
    &["supernaturalize"],
    &["supernaturalise"],
    &["supernaturalize"],
    &["supernaturalise"],
];

pub(crate) static ENTRY_SUPERNATURALIZING_12355223763201031189: VariantsMap = [
    &["supernaturalizing"],
    &["supernaturalising"],
    &["supernaturalizing"],
    &["supernaturalising"],
];

pub(crate) static ENTRY_SUPERORGANIZATIONS_7920692777226694340: VariantsMap = [
    &["superorganizations"],
    &["superorganisations"],
    &["superorganizations"],
    &["superorganisations"],
];

pub(crate) static ENTRY_SUPERORGANIZATION_16256428592681090251: VariantsMap = [
    &["superorganization"],
    &["superorganisation"],
    &["superorganization"],
    &["superorganisation"],
];

pub(crate) static ENTRY_SUPERORGANIZES_6908853305975248236: VariantsMap = [
    &["superorganizes"],
    &["superorganises"],
    &["superorganizes"],
    &["superorganises"],
];

pub(crate) static ENTRY_SUPERORGANIZE_6873964070386925575: VariantsMap = [
    &["superorganize"],
    &["superorganise"],
    &["superorganize"],
    &["superorganise"],
];

pub(crate) static ENTRY_SUPERSENSITIZATIONS_16229529539567958697: VariantsMap = [
    &["supersensitizations"],
    &["supersensitisations"],
    &["supersensitizations"],
    &["supersensitisations"],
];

pub(crate) static ENTRY_SUPERSENSITIZATION_13265729929436654234: VariantsMap = [
    &["supersensitization"],
    &["supersensitisation"],
    &["supersensitization"],
    &["supersensitisation"],
];

pub(crate) static ENTRY_SUPERSENSITIZED_5251978935582245961: VariantsMap = [
    &["supersensitized"],
    &["supersensitised"],
    &["supersensitized"],
    &["supersensitised"],
];

pub(crate) static ENTRY_SUPERSENSITIZE_13394449974043516101: VariantsMap = [
    &["supersensitize"],
    &["supersensitise"],
    &["supersensitize"],
    &["supersensitise"],
];

pub(crate) static ENTRY_SUPERSENSITIZING_3421712530072007911: VariantsMap = [
    &["supersensitizing"],
    &["supersensitising"],
    &["supersensitizing"],
    &["supersensitising"],
];

pub(crate) static ENTRY_SUPERSPECIALIZES_2203952443654557156: VariantsMap = [
    &["superspecializes"],
    &["superspecialises"],
    &["superspecializes"],
    &["superspecialises"],
];

pub(crate) static ENTRY_SUPERSPECIALIZE_14865803918277147544: VariantsMap = [
    &["superspecialize"],
    &["superspecialise"],
    &["superspecialize"],
    &["superspecialise"],
];

pub(crate) static ENTRY_SUPERSUBTILIZEDS_13035467917751159683: VariantsMap = [
    &["supersubtilizeds"],
    &["supersubtiliseds"],
    &["supersubtilizeds"],
    &["supersubtiliseds"],
];

pub(crate) static ENTRY_SUPERSUBTILIZED_191391172908983614: VariantsMap = [
    &["supersubtilized"],
    &["supersubtilised"],
    &["supersubtilized"],
    &["supersubtilised"],
];

pub(crate) static ENTRY_SUPERSULPHURIZES_17967493374873041386: VariantsMap = [
    &["supersulphurizes"],
    &["supersulphurises"],
    &["supersulphurizes"],
    &["supersulphurises"],
];

pub(crate) static ENTRY_SUPERSULPHURIZE_7872635294612482254: VariantsMap = [
    &["supersulphurize"],
    &["supersulphurise"],
    &["supersulphurize"],
    &["supersulphurise"],
];

pub(crate) static ENTRY_SURGERIZES_12042123533998947443: VariantsMap = [
    &["surgerizes"],
    &["surgerises"],
    &["surgerizes"],
    &["surgerises"],
];

pub(crate) static ENTRY_SURGERIZE_1472434802402972710: VariantsMap = [
    &["surgerize"],
    &["surgerise"],
    &["surgerize"],
    &["surgerise"],
];

pub(crate) static ENTRY_SURPRIZAL_13355491429284184035: VariantsMap = [
    &["surprizal"],
    &["surprisal"],
    &["surprizal"],
    &["surprisal"],
];

pub(crate) static ENTRY_SURSIZE_13083590681279299029: VariantsMap =
    [&["sursize"], &["sursise"], &["sursize"], &["sursise"]];

pub(crate) static ENTRY_SWIVELED_12677672287636743928: VariantsMap = [
    &["swiveled"],
    &["swivelled"],
    &["swivelled"],
    &["swivelled"],
];

pub(crate) static ENTRY_SWIVELING_14921165234587300041: VariantsMap = [
    &["swiveling"],
    &["swivelling"],
    &["swivelling"],
    &["swivelling"],
];

pub(crate) static ENTRY_SYCOPHANTIZED_17903678022051333437: VariantsMap = [
    &["sycophantized"],
    &["sycophantised"],
    &["sycophantized"],
    &["sycophantised"],
];

pub(crate) static ENTRY_SYCOPHANTIZES_7655400992232908749: VariantsMap = [
    &["sycophantizes"],
    &["sycophantises"],
    &["sycophantizes"],
    &["sycophantises"],
];

pub(crate) static ENTRY_SYCOPHANTIZE_10383539428432006516: VariantsMap = [
    &["sycophantize"],
    &["sycophantise"],
    &["sycophantize"],
    &["sycophantise"],
];

pub(crate) static ENTRY_SYCOPHANTIZING_14455754812538167914: VariantsMap = [
    &["sycophantizing"],
    &["sycophantising"],
    &["sycophantizing"],
    &["sycophantising"],
];

pub(crate) static ENTRY_SYLLABIZED_12280190710023663969: VariantsMap = [
    &["syllabized"],
    &["syllabised"],
    &["syllabized"],
    &["syllabised"],
];

pub(crate) static ENTRY_SYLLABIZES_7491957200438406322: VariantsMap = [
    &["syllabizes"],
    &["syllabises"],
    &["syllabizes"],
    &["syllabises"],
];

pub(crate) static ENTRY_SYLLABIZE_8311221770764080536: VariantsMap = [
    &["syllabize"],
    &["syllabise"],
    &["syllabize"],
    &["syllabise"],
];

pub(crate) static ENTRY_SYLLABIZING_5950775546479042598: VariantsMap = [
    &["syllabizing"],
    &["syllabising"],
    &["syllabizing"],
    &["syllabising"],
];

pub(crate) static ENTRY_SYLLOGIZATIONS_14385881756548234112: VariantsMap = [
    &["syllogizations"],
    &["syllogisations"],
    &["syllogizations"],
    &["syllogisations"],
];

pub(crate) static ENTRY_SYLLOGIZATION_6273384756475739006: VariantsMap = [
    &["syllogization"],
    &["syllogisation"],
    &["syllogization"],
    &["syllogisation"],
];

pub(crate) static ENTRY_SYLLOGIZED_9577236679427493870: VariantsMap = [
    &["syllogized"],
    &["syllogised"],
    &["syllogized"],
    &["syllogised"],
];

pub(crate) static ENTRY_SYLLOGIZERS_7670389343290303641: VariantsMap = [
    &["syllogizers"],
    &["syllogisers"],
    &["syllogizers"],
    &["syllogisers"],
];

pub(crate) static ENTRY_SYLLOGIZER_15171477961371626417: VariantsMap = [
    &["syllogizer"],
    &["syllogiser"],
    &["syllogizer"],
    &["syllogiser"],
];

pub(crate) static ENTRY_SYLLOGIZES_6778886382501204195: VariantsMap = [
    &["syllogizes"],
    &["syllogises"],
    &["syllogizes"],
    &["syllogises"],
];

pub(crate) static ENTRY_SYLLOGIZE_8982419159006310572: VariantsMap = [
    &["syllogize"],
    &["syllogise"],
    &["syllogize"],
    &["syllogise"],
];

pub(crate) static ENTRY_SYLLOGIZING_14604366328538691091: VariantsMap = [
    &["syllogizing"],
    &["syllogising"],
    &["syllogizing"],
    &["syllogising"],
];

pub(crate) static ENTRY_SYLVANIZES_8364417100363860769: VariantsMap = [
    &["sylvanizes"],
    &["sylvanises"],
    &["sylvanizes"],
    &["sylvanises"],
];

pub(crate) static ENTRY_SYLVANIZE_6218277727635267502: VariantsMap = [
    &["sylvanize"],
    &["sylvanise"],
    &["sylvanize"],
    &["sylvanise"],
];

pub(crate) static ENTRY_SYLVIINE_1558661518759171190: VariantsMap = [
    &["sylviine"],
    &["sylviinae"],
    &["sylviinae"],
    &["sylviinae"],
];

pub(crate) static ENTRY_SYMBOLED_8647395887479826115: VariantsMap = [
    &["symboled"],
    &["symbolled"],
    &["symbolled"],
    &["symbolled"],
];

pub(crate) static ENTRY_SYMBOLING_7617437864969100096: VariantsMap = [
    &["symboling"],
    &["symbolling"],
    &["symbolling"],
    &["symbolling"],
];

pub(crate) static ENTRY_SYMBOLIZATIONS_11456355786708744140: VariantsMap = [
    &["symbolizations"],
    &["symbolisations"],
    &["symbolizations"],
    &["symbolisations"],
];

pub(crate) static ENTRY_SYMBOLIZATION_183719897408488449: VariantsMap = [
    &["symbolization"],
    &["symbolisation"],
    &["symbolization"],
    &["symbolisation"],
];

pub(crate) static ENTRY_SYMBOLIZED_10774231202089876919: VariantsMap = [
    &["symbolized"],
    &["symbolised"],
    &["symbolized"],
    &["symbolised"],
];

pub(crate) static ENTRY_SYMBOLIZERS_891087008054921613: VariantsMap = [
    &["symbolizers"],
    &["symbolisers"],
    &["symbolizers"],
    &["symbolisers"],
];

pub(crate) static ENTRY_SYMBOLIZER_4027009846211024737: VariantsMap = [
    &["symbolizer"],
    &["symboliser"],
    &["symbolizer"],
    &["symboliser"],
];

pub(crate) static ENTRY_SYMBOLIZES_16079471803221884218: VariantsMap = [
    &["symbolizes"],
    &["symbolises"],
    &["symbolizes"],
    &["symbolises"],
];

pub(crate) static ENTRY_SYMBOLIZE_10234132787766621474: VariantsMap = [
    &["symbolize"],
    &["symbolise"],
    &["symbolize"],
    &["symbolise"],
];

pub(crate) static ENTRY_SYMBOLIZING_3483608355906583358: VariantsMap = [
    &["symbolizing"],
    &["symbolising"],
    &["symbolizing"],
    &["symbolising"],
];

pub(crate) static ENTRY_SYMMETRICALLY_6141818263074127947: VariantsMap = [
    &["symmetrically"],
    &["symmetrically"],
    &["symmetrically"],
    &["symmetrically"],
];

pub(crate) static ENTRY_SYMMETRIZATIONS_6985293843333697661: VariantsMap = [
    &["symmetrizations"],
    &["symmetrisations"],
    &["symmetrizations"],
    &["symmetrisations"],
];

pub(crate) static ENTRY_SYMMETRIZATION_15193129513805117628: VariantsMap = [
    &["symmetrization"],
    &["symmetrisation"],
    &["symmetrization"],
    &["symmetrisation"],
];

pub(crate) static ENTRY_SYMMETRIZED_15665190699389382501: VariantsMap = [
    &["symmetrized"],
    &["symmetrised"],
    &["symmetrized"],
    &["symmetrised"],
];

pub(crate) static ENTRY_SYMMETRIZES_13244460606866139100: VariantsMap = [
    &["symmetrizes"],
    &["symmetrises"],
    &["symmetrizes"],
    &["symmetrises"],
];

pub(crate) static ENTRY_SYMMETRIZE_16248404151674446594: VariantsMap = [
    &["symmetrize"],
    &["symmetrise"],
    &["symmetrize"],
    &["symmetrise"],
];

pub(crate) static ENTRY_SYMMETRIZING_3371155737907396072: VariantsMap = [
    &["symmetrizing"],
    &["symmetrising"],
    &["symmetrizing"],
    &["symmetrising"],
];

pub(crate) static ENTRY_SYMPATHIZED_6861363094123974820: VariantsMap = [
    &["sympathized"],
    &["sympathised"],
    &["sympathized"],
    &["sympathised"],
];

pub(crate) static ENTRY_SYMPATHIZERS_13386252484170054055: VariantsMap = [
    &["sympathizers"],
    &["sympathisers"],
    &["sympathizers"],
    &["sympathisers"],
];

pub(crate) static ENTRY_SYMPATHIZER_13267697269507764406: VariantsMap = [
    &["sympathizer"],
    &["sympathiser"],
    &["sympathizer"],
    &["sympathiser"],
];

pub(crate) static ENTRY_SYMPATHIZES_12347458223414813053: VariantsMap = [
    &["sympathizes"],
    &["sympathises"],
    &["sympathizes"],
    &["sympathises"],
];

pub(crate) static ENTRY_SYMPATHIZE_14904500675501907799: VariantsMap = [
    &["sympathize"],
    &["sympathise"],
    &["sympathize"],
    &["sympathise"],
];

pub(crate) static ENTRY_SYMPATHIZINGLIER_6375343851035596544: VariantsMap = [
    &["sympathizinglier"],
    &["sympathisinglier"],
    &["sympathizinglier"],
    &["sympathisinglier"],
];

pub(crate) static ENTRY_SYMPATHIZINGLIEST_2489322714478535735: VariantsMap = [
    &["sympathizingliest"],
    &["sympathisingliest"],
    &["sympathizingliest"],
    &["sympathisingliest"],
];

pub(crate) static ENTRY_SYMPATHIZINGLY_3895503812492133479: VariantsMap = [
    &["sympathizingly"],
    &["sympathisingly"],
    &["sympathizingly"],
    &["sympathisingly"],
];

pub(crate) static ENTRY_SYMPATHIZINGS_14912483334972090994: VariantsMap = [
    &["sympathizings"],
    &["sympathisings"],
    &["sympathizings"],
    &["sympathisings"],
];

pub(crate) static ENTRY_SYMPATHIZING_15316845270723087051: VariantsMap = [
    &["sympathizing"],
    &["sympathising"],
    &["sympathizing"],
    &["sympathising"],
];

pub(crate) static ENTRY_SYMPHONIZATION_18317507523394103294: VariantsMap = [
    &["symphonization"],
    &["symphonisation"],
    &["symphonization"],
    &["symphonisation"],
];

pub(crate) static ENTRY_SYMPHONIZED_2043962099079758147: VariantsMap = [
    &["symphonized"],
    &["symphonised"],
    &["symphonized"],
    &["symphonised"],
];

pub(crate) static ENTRY_SYMPHONIZE_16989149248275555829: VariantsMap = [
    &["symphonize"],
    &["symphonise"],
    &["symphonize"],
    &["symphonise"],
];

pub(crate) static ENTRY_SYMPHONIZING_1647574775766247984: VariantsMap = [
    &["symphonizing"],
    &["symphonising"],
    &["symphonizing"],
    &["symphonising"],
];

pub(crate) static ENTRY_SYMPTOMATIZED_4111737967123760822: VariantsMap = [
    &["symptomatized"],
    &["symptomatised"],
    &["symptomatized"],
    &["symptomatised"],
];

pub(crate) static ENTRY_SYMPTOMATIZES_709089293223559225: VariantsMap = [
    &["symptomatizes"],
    &["symptomatises"],
    &["symptomatizes"],
    &["symptomatises"],
];

pub(crate) static ENTRY_SYMPTOMATIZE_6373443412857664838: VariantsMap = [
    &["symptomatize"],
    &["symptomatise"],
    &["symptomatize"],
    &["symptomatise"],
];

pub(crate) static ENTRY_SYMPTOMATIZING_5206952739753002785: VariantsMap = [
    &["symptomatizing"],
    &["symptomatising"],
    &["symptomatizing"],
    &["symptomatising"],
];

pub(crate) static ENTRY_SYMPTOMIZES_2271031168315508299: VariantsMap = [
    &["symptomizes"],
    &["symptomises"],
    &["symptomizes"],
    &["symptomises"],
];

pub(crate) static ENTRY_SYMPTOMIZE_14715848522228834460: VariantsMap = [
    &["symptomize"],
    &["symptomise"],
    &["symptomize"],
    &["symptomise"],
];

pub(crate) static ENTRY_SYNALEPHAS_3091471690052949119: VariantsMap = [
    &["synalephas"],
    &["synaloephas"],
    &["synaloephas"],
    &["synaloephas"],
];

pub(crate) static ENTRY_SYNALEPHA_16666023941858348102: VariantsMap = [
    &["synalepha"],
    &["synaloepha"],
    &["synaloepha"],
    &["synaloepha"],
];

pub(crate) static ENTRY_SYNALEPHE_10251411566424510733: VariantsMap = [
    &["synalephe"],
    &["synaloephe"],
    &["synaloephe"],
    &["synaloephe"],
];

pub(crate) static ENTRY_SYNCHRONIZABLES_6259281414279265566: VariantsMap = [
    &["synchronizables"],
    &["synchronisables"],
    &["synchronizables"],
    &["synchronisables"],
];

pub(crate) static ENTRY_SYNCHRONIZABLE_5225268197215049174: VariantsMap = [
    &["synchronizable"],
    &["synchronisable"],
    &["synchronizable"],
    &["synchronisable"],
];

pub(crate) static ENTRY_SYNCHRONIZATIONS_11173757005398448736: VariantsMap = [
    &["synchronizations"],
    &["synchronisations"],
    &["synchronizations"],
    &["synchronisations"],
];

pub(crate) static ENTRY_SYNCHRONIZATION_15433063296853954842: VariantsMap = [
    &["synchronization"],
    &["synchronisation"],
    &["synchronization"],
    &["synchronisation"],
];

pub(crate) static ENTRY_SYNCHRONIZED_11809698306854658807: VariantsMap = [
    &["synchronized"],
    &["synchronised"],
    &["synchronized"],
    &["synchronised"],
];

pub(crate) static ENTRY_SYNCHRONIZERS_5513142999037450686: VariantsMap = [
    &["synchronizers"],
    &["synchronisers"],
    &["synchronizers"],
    &["synchronisers"],
];

pub(crate) static ENTRY_SYNCHRONIZER_16183643797162044552: VariantsMap = [
    &["synchronizer"],
    &["synchroniser"],
    &["synchronizer"],
    &["synchroniser"],
];

pub(crate) static ENTRY_SYNCHRONIZES_14508130385940854115: VariantsMap = [
    &["synchronizes"],
    &["synchronises"],
    &["synchronizes"],
    &["synchronises"],
];

pub(crate) static ENTRY_SYNCHRONIZE_4051274325149144681: VariantsMap = [
    &["synchronize"],
    &["synchronise"],
    &["synchronize"],
    &["synchronise"],
];

pub(crate) static ENTRY_SYNCHRONIZING_10768676641182362541: VariantsMap = [
    &["synchronizing"],
    &["synchronising"],
    &["synchronizing"],
    &["synchronising"],
];

pub(crate) static ENTRY_SYNCRETIZED_2883269728087305484: VariantsMap = [
    &["syncretized"],
    &["syncretised"],
    &["syncretized"],
    &["syncretised"],
];

pub(crate) static ENTRY_SYNCRETIZES_10622149550205968342: VariantsMap = [
    &["syncretizes"],
    &["syncretises"],
    &["syncretizes"],
    &["syncretises"],
];

pub(crate) static ENTRY_SYNCRETIZE_882464552271583194: VariantsMap = [
    &["syncretize"],
    &["syncretise"],
    &["syncretize"],
    &["syncretise"],
];

pub(crate) static ENTRY_SYNCRETIZING_4094600194477609283: VariantsMap = [
    &["syncretizing"],
    &["syncretising"],
    &["syncretizing"],
    &["syncretising"],
];

pub(crate) static ENTRY_SYNDICALIZES_6354822701141617267: VariantsMap = [
    &["syndicalizes"],
    &["syndicalises"],
    &["syndicalizes"],
    &["syndicalises"],
];

pub(crate) static ENTRY_SYNDICALIZE_9263618425732181107: VariantsMap = [
    &["syndicalize"],
    &["syndicalise"],
    &["syndicalize"],
    &["syndicalise"],
];

pub(crate) static ENTRY_SYNECIOUS_2488312687708968247: VariantsMap = [
    &["synecious"],
    &["synoecious"],
    &["synoecious"],
    &["synoecious"],
];

pub(crate) static ENTRY_SYNECOLOGIES_8832429084009892084: VariantsMap = [
    &["synecologies"],
    &["synoecologies"],
    &["synoecologies"],
    &["synoecologies"],
];

pub(crate) static ENTRY_SYNECOLOGY_6453378821906719817: VariantsMap = [
    &["synecology"],
    &["synoecology"],
    &["synoecology"],
    &["synoecology"],
];

pub(crate) static ENTRY_SYNERESES_13126424202136241020: VariantsMap = [
    &["synereses"],
    &["synaereses"],
    &["synaereses"],
    &["synaereses"],
];

pub(crate) static ENTRY_SYNERESIS_10309821654309135710: VariantsMap = [
    &["syneresis"],
    &["synaeresis"],
    &["synaeresis"],
    &["synaeresis"],
];

pub(crate) static ENTRY_SYNERGIZED_13406458228702999875: VariantsMap = [
    &["synergized"],
    &["synergised"],
    &["synergized"],
    &["synergised"],
];

pub(crate) static ENTRY_SYNERGIZES_17525458019004180925: VariantsMap = [
    &["synergizes"],
    &["synergises"],
    &["synergizes"],
    &["synergises"],
];

pub(crate) static ENTRY_SYNERGIZE_5752966859548761839: VariantsMap = [
    &["synergize"],
    &["synergise"],
    &["synergize"],
    &["synergise"],
];

pub(crate) static ENTRY_SYNERGIZING_7507828822392518971: VariantsMap = [
    &["synergizing"],
    &["synergising"],
    &["synergizing"],
    &["synergising"],
];

pub(crate) static ENTRY_SYNESTHESIAS_7150977045966888877: VariantsMap = [
    &["synesthesias"],
    &["synaesthesias"],
    &["synaesthesias"],
    &["synaesthesias"],
];

pub(crate) static ENTRY_SYNESTHESIA_4530326969815539991: VariantsMap = [
    &["synesthesia"],
    &["synaesthesia"],
    &["synaesthesia"],
    &["synaesthesia"],
];

pub(crate) static ENTRY_SYNESTHETICER_13349227782355059881: VariantsMap = [
    &["synestheticer"],
    &["synaestheticer"],
    &["synaestheticer"],
    &["synaestheticer"],
];

pub(crate) static ENTRY_SYNESTHETICEST_9784873845724873096: VariantsMap = [
    &["synestheticest"],
    &["synaestheticest"],
    &["synaestheticest"],
    &["synaestheticest"],
];

pub(crate) static ENTRY_SYNESTHETIC_17660261808766860040: VariantsMap = [
    &["synesthetic"],
    &["synaesthetic"],
    &["synaesthetic"],
    &["synaesthetic"],
];

pub(crate) static ENTRY_SYNETIC_6742608842823378317: VariantsMap =
    [&["synetic"], &["synoetic"], &["synoetic"], &["synoetic"]];

pub(crate) static ENTRY_SYNOECIZED_17602852031281858968: VariantsMap = [
    &["synoecized"],
    &["synoecised"],
    &["synoecized"],
    &["synoecised"],
];

pub(crate) static ENTRY_SYNOECIZES_11901914731015412038: VariantsMap = [
    &["synoecizes"],
    &["synoecises"],
    &["synoecizes"],
    &["synoecises"],
];

pub(crate) static ENTRY_SYNOECIZE_3344223646530853168: VariantsMap = [
    &["synoecize"],
    &["synoecise"],
    &["synoecize"],
    &["synoecise"],
];

pub(crate) static ENTRY_SYNOECIZING_1090383705013158957: VariantsMap = [
    &["synoecizing"],
    &["synoecising"],
    &["synoecizing"],
    &["synoecising"],
];

pub(crate) static ENTRY_SYNONYMIZED_15711127227445279789: VariantsMap = [
    &["synonymized"],
    &["synonymised"],
    &["synonymized"],
    &["synonymised"],
];

pub(crate) static ENTRY_SYNONYMIZES_12611470414491051552: VariantsMap = [
    &["synonymizes"],
    &["synonymises"],
    &["synonymizes"],
    &["synonymises"],
];

pub(crate) static ENTRY_SYNONYMIZE_12944042058907607588: VariantsMap = [
    &["synonymize"],
    &["synonymise"],
    &["synonymize"],
    &["synonymise"],
];

pub(crate) static ENTRY_SYNONYMIZING_15525725868933153025: VariantsMap = [
    &["synonymizing"],
    &["synonymising"],
    &["synonymizing"],
    &["synonymising"],
];

pub(crate) static ENTRY_SYNOPSIZED_13456249660267777970: VariantsMap = [
    &["synopsized"],
    &["synopsised"],
    &["synopsized"],
    &["synopsised"],
];

pub(crate) static ENTRY_SYNOPSIZES_3670003564639771417: VariantsMap = [
    &["synopsizes"],
    &["synopsises"],
    &["synopsizes"],
    &["synopsises"],
];

pub(crate) static ENTRY_SYNOPSIZE_17024762574525177281: VariantsMap = [
    &["synopsize"],
    &["synopsise"],
    &["synopsize"],
    &["synopsise"],
];

pub(crate) static ENTRY_SYNOPSIZING_16020823300312837540: VariantsMap = [
    &["synopsizing"],
    &["synopsising"],
    &["synopsizing"],
    &["synopsising"],
];

pub(crate) static ENTRY_SYNTHESIZATIONS_1034524582277813291: VariantsMap = [
    &["synthesizations"],
    &["synthesisations"],
    &["synthesizations"],
    &["synthesisations"],
];

pub(crate) static ENTRY_SYNTHESIZATION_13196049594166668291: VariantsMap = [
    &["synthesization"],
    &["synthesisation"],
    &["synthesization"],
    &["synthesisation"],
];

pub(crate) static ENTRY_SYNTHESIZED_2719272835003500056: VariantsMap = [
    &["synthesized"],
    &["synthesised"],
    &["synthesized"],
    &["synthesised"],
];

pub(crate) static ENTRY_SYNTHESIZERS_6048422950398681894: VariantsMap = [
    &["synthesizers"],
    &["synthesizers"],
    &["synthesizers"],
    &["synthesizers"],
];

pub(crate) static ENTRY_SYNTHESIZER_8049018325598125114: VariantsMap = [
    &["synthesizer"],
    &["synthesizer"],
    &["synthesizer"],
    &["synthesizer"],
];

pub(crate) static ENTRY_SYNTHESIZES_8265650206703294571: VariantsMap = [
    &["synthesizes"],
    &["synthesises"],
    &["synthesizes"],
    &["synthesises"],
];

pub(crate) static ENTRY_SYNTHESIZE_12842132831652901179: VariantsMap = [
    &["synthesize"],
    &["synthesise"],
    &["synthesize"],
    &["synthesise"],
];

pub(crate) static ENTRY_SYNTHESIZING_16486290831466977941: VariantsMap = [
    &["synthesizing"],
    &["synthesising"],
    &["synthesizing"],
    &["synthesising"],
];

pub(crate) static ENTRY_SYNTHETIZATION_2620902099305510053: VariantsMap = [
    &["synthetization"],
    &["synthetisation"],
    &["synthetization"],
    &["synthetisation"],
];

pub(crate) static ENTRY_SYNTHETIZERS_4526066773883425812: VariantsMap = [
    &["synthetizers"],
    &["synthetisers"],
    &["synthetizers"],
    &["synthetisers"],
];

pub(crate) static ENTRY_SYNTHETIZER_8576848661966983685: VariantsMap = [
    &["synthetizer"],
    &["synthetiser"],
    &["synthetizer"],
    &["synthetiser"],
];

pub(crate) static ENTRY_SYNTONIZATION_4336252829609097315: VariantsMap = [
    &["syntonization"],
    &["syntonisation"],
    &["syntonization"],
    &["syntonisation"],
];

pub(crate) static ENTRY_SYNTONIZED_8335662339289943784: VariantsMap = [
    &["syntonized"],
    &["syntonised"],
    &["syntonized"],
    &["syntonised"],
];

pub(crate) static ENTRY_SYNTONIZES_15432398599799360313: VariantsMap = [
    &["syntonizes"],
    &["syntonises"],
    &["syntonizes"],
    &["syntonises"],
];

pub(crate) static ENTRY_SYNTONIZE_2546944290925786520: VariantsMap = [
    &["syntonize"],
    &["syntonise"],
    &["syntonize"],
    &["syntonise"],
];

pub(crate) static ENTRY_SYNTONIZING_4468391907517453561: VariantsMap = [
    &["syntonizing"],
    &["syntonising"],
    &["syntonizing"],
    &["syntonising"],
];

pub(crate) static ENTRY_SYPHILIZATIONS_2454124626789606498: VariantsMap = [
    &["syphilizations"],
    &["syphilisations"],
    &["syphilizations"],
    &["syphilisations"],
];

pub(crate) static ENTRY_SYPHILIZATION_685514641017091080: VariantsMap = [
    &["syphilization"],
    &["syphilisation"],
    &["syphilization"],
    &["syphilisation"],
];

pub(crate) static ENTRY_SYPHILIZED_5261656973931907777: VariantsMap = [
    &["syphilized"],
    &["syphilised"],
    &["syphilized"],
    &["syphilised"],
];

pub(crate) static ENTRY_SYPHILIZE_11883878391147817953: VariantsMap = [
    &["syphilize"],
    &["syphilise"],
    &["syphilize"],
    &["syphilise"],
];

pub(crate) static ENTRY_SYPHILIZING_18203920249482546717: VariantsMap = [
    &["syphilizing"],
    &["syphilising"],
    &["syphilizing"],
    &["syphilising"],
];

pub(crate) static ENTRY_SYRIANIZES_14522632119731991691: VariantsMap = [
    &["syrianizes"],
    &["syrianises"],
    &["syrianizes"],
    &["syrianises"],
];

pub(crate) static ENTRY_SYRIANIZE_17228276156196119846: VariantsMap = [
    &["syrianize"],
    &["syrianise"],
    &["syrianize"],
    &["syrianise"],
];

pub(crate) static ENTRY_SYRINGOCELE_10888948771227714414: VariantsMap = [
    &["syringocele"],
    &["syringocoele"],
    &["syringocoele"],
    &["syringocoele"],
];

pub(crate) static ENTRY_SYRUPS_6494928060225946043: VariantsMap =
    [&["syrups"], &["syrups"], &["syrups"], &["syrups"]];

pub(crate) static ENTRY_SYRUP_11479307931259416998: VariantsMap =
    [&["syrup"], &["syrup"], &["syrup"], &["syrup"]];

pub(crate) static ENTRY_SYSTEMATIZATIONS_3352523032353611097: VariantsMap = [
    &["systematizations"],
    &["systematisations"],
    &["systematizations"],
    &["systematisations"],
];

pub(crate) static ENTRY_SYSTEMATIZATION_3107776542992770160: VariantsMap = [
    &["systematization"],
    &["systematisation"],
    &["systematization"],
    &["systematisation"],
];

pub(crate) static ENTRY_SYSTEMATIZED_4844953296714238844: VariantsMap = [
    &["systematized"],
    &["systematised"],
    &["systematized"],
    &["systematised"],
];

pub(crate) static ENTRY_SYSTEMATIZERS_15772744122736196869: VariantsMap = [
    &["systematizers"],
    &["systematisers"],
    &["systematizers"],
    &["systematisers"],
];

pub(crate) static ENTRY_SYSTEMATIZER_5303654505244699756: VariantsMap = [
    &["systematizer"],
    &["systematiser"],
    &["systematizer"],
    &["systematiser"],
];

pub(crate) static ENTRY_SYSTEMATIZES_14036170375607791421: VariantsMap = [
    &["systematizes"],
    &["systematises"],
    &["systematizes"],
    &["systematises"],
];

pub(crate) static ENTRY_SYSTEMATIZE_16900057715370037545: VariantsMap = [
    &["systematize"],
    &["systematise"],
    &["systematize"],
    &["systematise"],
];

pub(crate) static ENTRY_SYSTEMATIZING_13014106459165883860: VariantsMap = [
    &["systematizing"],
    &["systematising"],
    &["systematizing"],
    &["systematising"],
];

pub(crate) static ENTRY_SYSTEMIZABLER_14523778083190592144: VariantsMap = [
    &["systemizabler"],
    &["systemisabler"],
    &["systemizabler"],
    &["systemisabler"],
];

pub(crate) static ENTRY_SYSTEMIZABLEST_17247488239403991289: VariantsMap = [
    &["systemizablest"],
    &["systemisablest"],
    &["systemizablest"],
    &["systemisablest"],
];

pub(crate) static ENTRY_SYSTEMIZABLES_10780606996651648121: VariantsMap = [
    &["systemizables"],
    &["systemisables"],
    &["systemizables"],
    &["systemisables"],
];

pub(crate) static ENTRY_SYSTEMIZABLE_12189882081280949549: VariantsMap = [
    &["systemizable"],
    &["systemisable"],
    &["systemizable"],
    &["systemisable"],
];

pub(crate) static ENTRY_SYSTEMIZATIONS_4121671049363517727: VariantsMap = [
    &["systemizations"],
    &["systemisations"],
    &["systemizations"],
    &["systemisations"],
];

pub(crate) static ENTRY_SYSTEMIZATION_14190190500089956604: VariantsMap = [
    &["systemization"],
    &["systemisation"],
    &["systemization"],
    &["systemisation"],
];

pub(crate) static ENTRY_SYSTEMIZED_6678000876435289660: VariantsMap = [
    &["systemized"],
    &["systemised"],
    &["systemized"],
    &["systemised"],
];

pub(crate) static ENTRY_SYSTEMIZERS_127559560082533162: VariantsMap = [
    &["systemizers"],
    &["systemisers"],
    &["systemizers"],
    &["systemisers"],
];

pub(crate) static ENTRY_SYSTEMIZER_11174811386299123332: VariantsMap = [
    &["systemizer"],
    &["systemiser"],
    &["systemizer"],
    &["systemiser"],
];

pub(crate) static ENTRY_SYSTEMIZES_17547677193703511225: VariantsMap = [
    &["systemizes"],
    &["systemises"],
    &["systemizes"],
    &["systemises"],
];

pub(crate) static ENTRY_SYSTEMIZE_6906592582631805748: VariantsMap = [
    &["systemize"],
    &["systemise"],
    &["systemize"],
    &["systemise"],
];

pub(crate) static ENTRY_SYSTEMIZING_11854782298171599250: VariantsMap = [
    &["systemizing"],
    &["systemising"],
    &["systemizing"],
    &["systemising"],
];

pub(crate) static ENTRY_TABORED_11641595972971132305: VariantsMap =
    [&["tabored"], &["taboured"], &["taboured"], &["taboured"]];

pub(crate) static ENTRY_TABORERS_2809101557456620449: VariantsMap = [
    &["taborers"],
    &["tabourers"],
    &["tabourers"],
    &["tabourers"],
];

pub(crate) static ENTRY_TABORER_13534394124897973316: VariantsMap =
    [&["taborer"], &["tabourer"], &["tabourer"], &["tabourer"]];

pub(crate) static ENTRY_TABORETS_12270021431498110056: VariantsMap = [
    &["taborets"],
    &["tabourets"],
    &["tabourets"],
    &["tabourets"],
];

pub(crate) static ENTRY_TABORET_390741665248154587: VariantsMap =
    [&["taboret"], &["tabouret"], &["tabouret"], &["tabouret"]];

pub(crate) static ENTRY_TABORINE_3147952014201829383: VariantsMap = [
    &["taborine"],
    &["tabourine"],
    &["tabourine"],
    &["tabourine"],
];

pub(crate) static ENTRY_TABORING_16755842556933914882: VariantsMap = [
    &["taboring"],
    &["tabouring"],
    &["tabouring"],
    &["tabouring"],
];

pub(crate) static ENTRY_TABORINS_6392269866504402204: VariantsMap = [
    &["taborins"],
    &["tabourins"],
    &["tabourins"],
    &["tabourins"],
];

pub(crate) static ENTRY_TABORIN_5348657649342981597: VariantsMap =
    [&["taborin"], &["tabourin"], &["tabourin"], &["tabourin"]];

pub(crate) static ENTRY_TABULARIZATIONS_13558146837461796765: VariantsMap = [
    &["tabularizations"],
    &["tabularisations"],
    &["tabularizations"],
    &["tabularisations"],
];

pub(crate) static ENTRY_TABULARIZATION_12129488971307934801: VariantsMap = [
    &["tabularization"],
    &["tabularisation"],
    &["tabularization"],
    &["tabularisation"],
];

pub(crate) static ENTRY_TABULARIZED_17222285384170548479: VariantsMap = [
    &["tabularized"],
    &["tabularised"],
    &["tabularized"],
    &["tabularised"],
];

pub(crate) static ENTRY_TABULARIZES_1451938906251727691: VariantsMap = [
    &["tabularizes"],
    &["tabularises"],
    &["tabularizes"],
    &["tabularises"],
];

pub(crate) static ENTRY_TABULARIZE_4197635393214144129: VariantsMap = [
    &["tabularize"],
    &["tabularise"],
    &["tabularize"],
    &["tabularise"],
];

pub(crate) static ENTRY_TABULARIZING_6952271340201339560: VariantsMap = [
    &["tabularizing"],
    &["tabularising"],
    &["tabularizing"],
    &["tabularising"],
];

pub(crate) static ENTRY_TABULE_12901214361938682762: VariantsMap =
    [&["tabule"], &["tabulae"], &["tabulae"], &["tabulae"]];

pub(crate) static ENTRY_TACHYPNEAS_4617184722695613958: VariantsMap = [
    &["tachypneas"],
    &["tachypnoeas"],
    &["tachypnoeas"],
    &["tachypnoeas"],
];

pub(crate) static ENTRY_TACHYPNEA_2816290035207751824: VariantsMap = [
    &["tachypnea"],
    &["tachypnoea"],
    &["tachypnoea"],
    &["tachypnoea"],
];

pub(crate) static ENTRY_TACHYPNEIC_363899473331751956: VariantsMap = [
    &["tachypneic"],
    &["tachypnoeic"],
    &["tachypnoeic"],
    &["tachypnoeic"],
];

pub(crate) static ENTRY_TAFFETIZED_13217162182378469791: VariantsMap = [
    &["taffetized"],
    &["taffetised"],
    &["taffetized"],
    &["taffetised"],
];

pub(crate) static ENTRY_TAILORIZATIONS_12806791765528330193: VariantsMap = [
    &["tailorizations"],
    &["tailorisations"],
    &["tailorizations"],
    &["tailorisations"],
];

pub(crate) static ENTRY_TAILORIZATION_8550094274360323304: VariantsMap = [
    &["tailorization"],
    &["tailorisation"],
    &["tailorization"],
    &["tailorisation"],
];

pub(crate) static ENTRY_TAILORIZES_11228159220737478922: VariantsMap = [
    &["tailorizes"],
    &["tailorises"],
    &["tailorizes"],
    &["tailorises"],
];

pub(crate) static ENTRY_TAILORIZE_16488488043819591099: VariantsMap = [
    &["tailorize"],
    &["tailorise"],
    &["tailorize"],
    &["tailorise"],
];

pub(crate) static ENTRY_TALMUDIZATIONS_7131355692075902201: VariantsMap = [
    &["talmudizations"],
    &["talmudisations"],
    &["talmudizations"],
    &["talmudisations"],
];

pub(crate) static ENTRY_TALMUDIZATION_14002522770997155406: VariantsMap = [
    &["talmudization"],
    &["talmudisation"],
    &["talmudization"],
    &["talmudisation"],
];

pub(crate) static ENTRY_TALMUDIZES_9309757235637123822: VariantsMap = [
    &["talmudizes"],
    &["talmudises"],
    &["talmudizes"],
    &["talmudises"],
];

pub(crate) static ENTRY_TALMUDIZE_2141569203942597251: VariantsMap = [
    &["talmudize"],
    &["talmudise"],
    &["talmudize"],
    &["talmudise"],
];

pub(crate) static ENTRY_TAMBURAS_3622963385462333423: VariantsMap = [
    &["tamburas"],
    &["tambouras"],
    &["tambouras"],
    &["tambouras"],
];

pub(crate) static ENTRY_TAMBURA_10774020505110351537: VariantsMap =
    [&["tambura"], &["tamboura"], &["tamboura"], &["tamboura"]];

pub(crate) static ENTRY_TAMMANYIZES_12831368891226385045: VariantsMap = [
    &["tammanyizes"],
    &["tammanyises"],
    &["tammanyizes"],
    &["tammanyises"],
];

pub(crate) static ENTRY_TAMMANYIZE_7790980244874688921: VariantsMap = [
    &["tammanyize"],
    &["tammanyise"],
    &["tammanyize"],
    &["tammanyise"],
];

pub(crate) static ENTRY_TANALIZED_12866045393181097657: VariantsMap = [
    &["tanalized"],
    &["tanalised"],
    &["tanalized"],
    &["tanalised"],
];

pub(crate) static ENTRY_TANDEMIZES_6195252162933518434: VariantsMap = [
    &["tandemizes"],
    &["tandemises"],
    &["tandemizes"],
    &["tandemises"],
];

pub(crate) static ENTRY_TANDEMIZE_12627845627665749987: VariantsMap = [
    &["tandemize"],
    &["tandemise"],
    &["tandemize"],
    &["tandemise"],
];

pub(crate) static ENTRY_TANTALIZATIONS_4202766685588417911: VariantsMap = [
    &["tantalizations"],
    &["tantalisations"],
    &["tantalizations"],
    &["tantalisations"],
];

pub(crate) static ENTRY_TANTALIZATION_11251308735880559440: VariantsMap = [
    &["tantalization"],
    &["tantalisation"],
    &["tantalization"],
    &["tantalisation"],
];

pub(crate) static ENTRY_TANTALIZED_8361102485824684408: VariantsMap = [
    &["tantalized"],
    &["tantalised"],
    &["tantalized"],
    &["tantalised"],
];

pub(crate) static ENTRY_TANTALIZERS_15046066302558840427: VariantsMap = [
    &["tantalizers"],
    &["tantalisers"],
    &["tantalizers"],
    &["tantalisers"],
];

pub(crate) static ENTRY_TANTALIZER_16233188677397603167: VariantsMap = [
    &["tantalizer"],
    &["tantaliser"],
    &["tantalizer"],
    &["tantaliser"],
];

pub(crate) static ENTRY_TANTALIZES_11631837874131073727: VariantsMap = [
    &["tantalizes"],
    &["tantalises"],
    &["tantalizes"],
    &["tantalises"],
];

pub(crate) static ENTRY_TANTALIZE_18432661058571036826: VariantsMap = [
    &["tantalize"],
    &["tantalise"],
    &["tantalize"],
    &["tantalise"],
];

pub(crate) static ENTRY_TANTALIZINGLIER_7583695578673101293: VariantsMap = [
    &["tantalizinglier"],
    &["tantalisinglier"],
    &["tantalizinglier"],
    &["tantalisinglier"],
];

pub(crate) static ENTRY_TANTALIZINGLIEST_10330928641973270079: VariantsMap = [
    &["tantalizingliest"],
    &["tantalisingliest"],
    &["tantalizingliest"],
    &["tantalisingliest"],
];

pub(crate) static ENTRY_TANTALIZINGLIES_9817814848083768632: VariantsMap = [
    &["tantalizinglies"],
    &["tantalisinglies"],
    &["tantalizinglies"],
    &["tantalisinglies"],
];

pub(crate) static ENTRY_TANTALIZINGLY_6966920924649933678: VariantsMap = [
    &["tantalizingly"],
    &["tantalisingly"],
    &["tantalizingly"],
    &["tantalisingly"],
];

pub(crate) static ENTRY_TANTALIZINGNESSES_7303683745241052669: VariantsMap = [
    &["tantalizingnesses"],
    &["tantalisingnesses"],
    &["tantalizingnesses"],
    &["tantalisingnesses"],
];

pub(crate) static ENTRY_TANTALIZINGNESS_15204799924965484070: VariantsMap = [
    &["tantalizingness"],
    &["tantalisingness"],
    &["tantalizingness"],
    &["tantalisingness"],
];

pub(crate) static ENTRY_TANTALIZINGS_2351246836151437376: VariantsMap = [
    &["tantalizings"],
    &["tantalisings"],
    &["tantalizings"],
    &["tantalisings"],
];

pub(crate) static ENTRY_TANTALIZING_1104308605989653249: VariantsMap = [
    &["tantalizing"],
    &["tantalising"],
    &["tantalizing"],
    &["tantalising"],
];

pub(crate) static ENTRY_TARIFFIZES_17636207388435873185: VariantsMap = [
    &["tariffizes"],
    &["tariffises"],
    &["tariffizes"],
    &["tariffises"],
];

pub(crate) static ENTRY_TARIFFIZE_6403869543544376740: VariantsMap = [
    &["tariffize"],
    &["tariffise"],
    &["tariffize"],
    &["tariffise"],
];

pub(crate) static ENTRY_TARTARIZATIONS_4539095683795989062: VariantsMap = [
    &["tartarizations"],
    &["tartarisations"],
    &["tartarizations"],
    &["tartarisations"],
];

pub(crate) static ENTRY_TARTARIZATION_7985288754441644773: VariantsMap = [
    &["tartarization"],
    &["tartarisation"],
    &["tartarization"],
    &["tartarisation"],
];

pub(crate) static ENTRY_TARTARIZED_17484118332732038381: VariantsMap = [
    &["tartarized"],
    &["tartarised"],
    &["tartarized"],
    &["tartarised"],
];

pub(crate) static ENTRY_TARTARIZES_5464843505270674625: VariantsMap = [
    &["tartarizes"],
    &["tartarises"],
    &["tartarizes"],
    &["tartarises"],
];

pub(crate) static ENTRY_TARTARIZE_5229224382783206477: VariantsMap = [
    &["tartarize"],
    &["tartarise"],
    &["tartarize"],
    &["tartarise"],
];

pub(crate) static ENTRY_TARTARIZING_6992530598749611494: VariantsMap = [
    &["tartarizing"],
    &["tartarising"],
    &["tartarizing"],
    &["tartarising"],
];

pub(crate) static ENTRY_TASSELED_4679022262489379669: VariantsMap = [
    &["tasseled"],
    &["tasselled"],
    &["tasselled"],
    &["tasselled"],
];

pub(crate) static ENTRY_TASSELING_10007583439810610023: VariantsMap = [
    &["tasseling"],
    &["tasselling"],
    &["tasselling"],
    &["tasselling"],
];

pub(crate) static ENTRY_TASSELS_13976945035735097519: VariantsMap =
    [&["tassels"], &["tassels"], &["tassels"], &["tassels"]];

pub(crate) static ENTRY_TAUTOLOGIZED_1863604812276127359: VariantsMap = [
    &["tautologized"],
    &["tautologised"],
    &["tautologized"],
    &["tautologised"],
];

pub(crate) static ENTRY_TAUTOLOGIZES_13343636725490349506: VariantsMap = [
    &["tautologizes"],
    &["tautologises"],
    &["tautologizes"],
    &["tautologises"],
];

pub(crate) static ENTRY_TAUTOLOGIZE_11478929002088519989: VariantsMap = [
    &["tautologize"],
    &["tautologise"],
    &["tautologize"],
    &["tautologise"],
];

pub(crate) static ENTRY_TAUTOLOGIZING_15254400746085954202: VariantsMap = [
    &["tautologizing"],
    &["tautologising"],
    &["tautologizing"],
    &["tautologising"],
];

pub(crate) static ENTRY_TAVERNIZES_6063364600175481171: VariantsMap = [
    &["tavernizes"],
    &["tavernises"],
    &["tavernizes"],
    &["tavernises"],
];

pub(crate) static ENTRY_TAVERNIZE_6260853173296204981: VariantsMap = [
    &["tavernize"],
    &["tavernise"],
    &["tavernize"],
    &["tavernise"],
];

pub(crate) static ENTRY_TAXIDERMIZED_13935298856865523155: VariantsMap = [
    &["taxidermized"],
    &["taxidermised"],
    &["taxidermized"],
    &["taxidermised"],
];

pub(crate) static ENTRY_TAXIDERMIZES_719088270981053986: VariantsMap = [
    &["taxidermizes"],
    &["taxidermises"],
    &["taxidermizes"],
    &["taxidermises"],
];

pub(crate) static ENTRY_TAXIDERMIZE_15950544350323027010: VariantsMap = [
    &["taxidermize"],
    &["taxidermise"],
    &["taxidermize"],
    &["taxidermise"],
];

pub(crate) static ENTRY_TAXIDERMIZING_5626284540207255110: VariantsMap = [
    &["taxidermizing"],
    &["taxidermising"],
    &["taxidermizing"],
    &["taxidermising"],
];

pub(crate) static ENTRY_TAYLORIZES_566769959974370306: VariantsMap = [
    &["taylorizes"],
    &["taylorises"],
    &["taylorizes"],
    &["taylorises"],
];

pub(crate) static ENTRY_TAYLORIZE_3865542100918562173: VariantsMap = [
    &["taylorize"],
    &["taylorise"],
    &["taylorize"],
    &["taylorise"],
];

pub(crate) static ENTRY_TEASELED_2404281669479955994: VariantsMap =
    [&["teaseled"], &["teaseled"], &["teaseled"], &["teaseled"]];

pub(crate) static ENTRY_TEASELERS_12811270860239416974: VariantsMap = [
    &["teaselers"],
    &["teaselers"],
    &["teaselers"],
    &["teaselers"],
];

pub(crate) static ENTRY_TEASELER_15816628167253312937: VariantsMap =
    [&["teaseler"], &["teaseler"], &["teaseler"], &["teaseler"]];

pub(crate) static ENTRY_TEASELINGS_7138615751835008671: VariantsMap = [
    &["teaselings"],
    &["teaselings"],
    &["teaselings"],
    &["teaselings"],
];

pub(crate) static ENTRY_TEASELING_3193421888859226649: VariantsMap = [
    &["teaseling"],
    &["teaseling"],
    &["teaseling"],
    &["teaseling"],
];

pub(crate) static ENTRY_TEASELING_6449109682441957740: VariantsMap = [
    &["teaseling"],
    &["teaseling"],
    &["teaseling"],
    &["teaseling"],
];

pub(crate) static ENTRY_TEBILIZED_16281892748394878341: VariantsMap = [
    &["tebilized"],
    &["tebilised"],
    &["tebilized"],
    &["tebilised"],
];

pub(crate) static ENTRY_TEBILIZES_1009779906267613643: VariantsMap = [
    &["tebilizes"],
    &["tebilises"],
    &["tebilizes"],
    &["tebilises"],
];

pub(crate) static ENTRY_TEBILIZE_12357160300142853828: VariantsMap =
    [&["tebilize"], &["tebilise"], &["tebilize"], &["tebilise"]];

pub(crate) static ENTRY_TEBILIZING_6941003510869745519: VariantsMap = [
    &["tebilizing"],
    &["tebilising"],
    &["tebilizing"],
    &["tebilising"],
];

pub(crate) static ENTRY_TECHNICALIZATION_3557036272115507954: VariantsMap = [
    &["technicalization"],
    &["technicalisation"],
    &["technicalization"],
    &["technicalisation"],
];

pub(crate) static ENTRY_TECHNICALIZES_5739924387814270714: VariantsMap = [
    &["technicalizes"],
    &["technicalises"],
    &["technicalizes"],
    &["technicalises"],
];

pub(crate) static ENTRY_TECHNICALIZE_8472562129396247230: VariantsMap = [
    &["technicalize"],
    &["technicalise"],
    &["technicalize"],
    &["technicalise"],
];

pub(crate) static ENTRY_TECHNICIZED_1670496041758587203: VariantsMap = [
    &["technicized"],
    &["technicised"],
    &["technicized"],
    &["technicised"],
];

pub(crate) static ENTRY_TECHNICIZES_12876743451060139748: VariantsMap = [
    &["technicizes"],
    &["technicises"],
    &["technicizes"],
    &["technicises"],
];

pub(crate) static ENTRY_TECHNICIZE_2858109795308766008: VariantsMap = [
    &["technicize"],
    &["technicise"],
    &["technicize"],
    &["technicise"],
];

pub(crate) static ENTRY_TECHNICIZING_12855780479462350606: VariantsMap = [
    &["technicizing"],
    &["technicising"],
    &["technicizing"],
    &["technicising"],
];

pub(crate) static ENTRY_TECHNICOLORED_7154232169686816579: VariantsMap = [
    &["technicolored"],
    &["technicolored"],
    &["technicolored"],
    &["technicolored"],
];

pub(crate) static ENTRY_TECHNICOLORS_2621716821548091481: VariantsMap = [
    &["technicolors"],
    &["technicolors"],
    &["technicolors"],
    &["technicolors"],
];

pub(crate) static ENTRY_TECHNICOLOR_15713729011025864853: VariantsMap = [
    &["technicolor"],
    &["technicolor"],
    &["technicolor"],
    &["technicolor"],
];

pub(crate) static ENTRY_TECHNICOLOR_5654403922354832142: VariantsMap = [
    &["technicolor"],
    &["technicolor"],
    &["technicolor"],
    &["technicolor"],
];

pub(crate) static ENTRY_TECHNOLOGIZE_18224160162322835759: VariantsMap = [
    &["technologize"],
    &["technologise"],
    &["technologize"],
    &["technologise"],
];

pub(crate) static ENTRY_TEERS_11274051796412043660: VariantsMap =
    [&["teers"], &["teres"], &["teres"], &["teres"]];

pub(crate) static ENTRY_TEER_13683881861614668793: VariantsMap =
    [&["teer"], &["teaer"], &["teaer"], &["teaer"]];

pub(crate) static ENTRY_TEETOTALED_7326361194719148925: VariantsMap = [
    &["teetotaled"],
    &["teetotalled"],
    &["teetotalled"],
    &["teetotalled"],
];

pub(crate) static ENTRY_TEETOTALERS_5250373658369188480: VariantsMap = [
    &["teetotalers"],
    &["teetotallers"],
    &["teetotallers"],
    &["teetotallers"],
];

pub(crate) static ENTRY_TEETOTALER_9642485742897840895: VariantsMap = [
    &["teetotaler"],
    &["teetotaller"],
    &["teetotaller"],
    &["teetotaller"],
];

pub(crate) static ENTRY_TEETOTALING_7136232887691143617: VariantsMap = [
    &["teetotaling"],
    &["teetotalling"],
    &["teetotalling"],
    &["teetotalling"],
];

pub(crate) static ENTRY_TEGU_580355573665292940: VariantsMap =
    [&["tegu"], &["taegu"], &["taegu"], &["taegu"]];

pub(crate) static ENTRY_TELEPATHIZED_421824987955665986: VariantsMap = [
    &["telepathized"],
    &["telepathised"],
    &["telepathized"],
    &["telepathised"],
];

pub(crate) static ENTRY_TELEPATHIZES_15648096053049257080: VariantsMap = [
    &["telepathizes"],
    &["telepathises"],
    &["telepathizes"],
    &["telepathises"],
];

pub(crate) static ENTRY_TELEPATHIZE_13335072343576542252: VariantsMap = [
    &["telepathize"],
    &["telepathise"],
    &["telepathize"],
    &["telepathise"],
];

pub(crate) static ENTRY_TELEPATHIZING_13360070708521360949: VariantsMap = [
    &["telepathizing"],
    &["telepathising"],
    &["telepathizing"],
    &["telepathising"],
];

pub(crate) static ENTRY_TELESTHESIAS_3007363512145448149: VariantsMap = [
    &["telesthesias"],
    &["telaesthesias"],
    &["telaesthesias"],
    &["telaesthesias"],
];

pub(crate) static ENTRY_TELESTHESIA_3608004104658756833: VariantsMap = [
    &["telesthesia"],
    &["telaesthesia"],
    &["telaesthesia"],
    &["telaesthesia"],
];

pub(crate) static ENTRY_TELESTHETICER_3205209910306797838: VariantsMap = [
    &["telestheticer"],
    &["telaestheticer"],
    &["telaestheticer"],
    &["telaestheticer"],
];

pub(crate) static ENTRY_TELESTHETICEST_1745115383802501612: VariantsMap = [
    &["telestheticest"],
    &["telaestheticest"],
    &["telaestheticest"],
    &["telaestheticest"],
];

pub(crate) static ENTRY_TELESTHETIC_1552205400640102007: VariantsMap = [
    &["telesthetic"],
    &["telaesthetic"],
    &["telaesthetic"],
    &["telaesthetic"],
];

pub(crate) static ENTRY_TELE_4870161772147898913: VariantsMap =
    [&["tele"], &["telae"], &["telae"], &["telae"]];

pub(crate) static ENTRY_TELLURIZED_2742921626249039404: VariantsMap = [
    &["tellurized"],
    &["tellurised"],
    &["tellurized"],
    &["tellurised"],
];

pub(crate) static ENTRY_TELLURIZES_17233285317678254256: VariantsMap = [
    &["tellurizes"],
    &["tellurises"],
    &["tellurizes"],
    &["tellurises"],
];

pub(crate) static ENTRY_TELLURIZE_5057943107852940207: VariantsMap = [
    &["tellurize"],
    &["tellurise"],
    &["tellurize"],
    &["tellurise"],
];

pub(crate) static ENTRY_TELLURIZING_2423876315883018831: VariantsMap = [
    &["tellurizing"],
    &["tellurising"],
    &["tellurizing"],
    &["tellurising"],
];

pub(crate) static ENTRY_TELS_10786558087438067092: VariantsMap =
    [&["tels"], &["taels"], &["taels"], &["taels"]];

pub(crate) static ENTRY_TEMPLIZES_45876823756782777: VariantsMap = [
    &["templizes"],
    &["templises"],
    &["templizes"],
    &["templises"],
];

pub(crate) static ENTRY_TEMPLIZE_11960826038010417307: VariantsMap =
    [&["templize"], &["templise"], &["templize"], &["templise"]];

pub(crate) static ENTRY_TEMPORALIZED_12716643461351758871: VariantsMap = [
    &["temporalized"],
    &["temporalised"],
    &["temporalized"],
    &["temporalised"],
];

pub(crate) static ENTRY_TEMPORALIZES_16816934998491265240: VariantsMap = [
    &["temporalizes"],
    &["temporalises"],
    &["temporalizes"],
    &["temporalises"],
];

pub(crate) static ENTRY_TEMPORALIZE_6928564539981991859: VariantsMap = [
    &["temporalize"],
    &["temporalise"],
    &["temporalize"],
    &["temporalise"],
];

pub(crate) static ENTRY_TEMPORALIZING_6073863398214069624: VariantsMap = [
    &["temporalizing"],
    &["temporalising"],
    &["temporalizing"],
    &["temporalising"],
];

pub(crate) static ENTRY_TEMPORIZATIONS_2987472207501959609: VariantsMap = [
    &["temporizations"],
    &["temporisations"],
    &["temporizations"],
    &["temporisations"],
];

pub(crate) static ENTRY_TEMPORIZATION_4135233642498941184: VariantsMap = [
    &["temporization"],
    &["temporisation"],
    &["temporization"],
    &["temporisation"],
];

pub(crate) static ENTRY_TEMPORIZED_4964570364177704531: VariantsMap = [
    &["temporized"],
    &["temporised"],
    &["temporized"],
    &["temporised"],
];

pub(crate) static ENTRY_TEMPORIZERS_18437130794992057942: VariantsMap = [
    &["temporizers"],
    &["temporisers"],
    &["temporizers"],
    &["temporisers"],
];

pub(crate) static ENTRY_TEMPORIZER_6688110462298171935: VariantsMap = [
    &["temporizer"],
    &["temporiser"],
    &["temporizer"],
    &["temporiser"],
];

pub(crate) static ENTRY_TEMPORIZES_11341794494418625299: VariantsMap = [
    &["temporizes"],
    &["temporises"],
    &["temporizes"],
    &["temporises"],
];

pub(crate) static ENTRY_TEMPORIZE_7694977824627458983: VariantsMap = [
    &["temporize"],
    &["temporise"],
    &["temporize"],
    &["temporise"],
];

pub(crate) static ENTRY_TEMPORIZINGLIER_9849548925384135646: VariantsMap = [
    &["temporizinglier"],
    &["temporisinglier"],
    &["temporizinglier"],
    &["temporisinglier"],
];

pub(crate) static ENTRY_TEMPORIZINGLIEST_11242662133505129984: VariantsMap = [
    &["temporizingliest"],
    &["temporisingliest"],
    &["temporizingliest"],
    &["temporisingliest"],
];

pub(crate) static ENTRY_TEMPORIZINGLY_6983715160792083876: VariantsMap = [
    &["temporizingly"],
    &["temporisingly"],
    &["temporizingly"],
    &["temporisingly"],
];

pub(crate) static ENTRY_TEMPORIZINGS_16954412101165281486: VariantsMap = [
    &["temporizings"],
    &["temporisings"],
    &["temporizings"],
    &["temporisings"],
];

pub(crate) static ENTRY_TEMPORIZING_16023698398897725311: VariantsMap = [
    &["temporizing"],
    &["temporising"],
    &["temporizing"],
    &["temporising"],
];

pub(crate) static ENTRY_TENDERIZATIONS_17721506842521904935: VariantsMap = [
    &["tenderizations"],
    &["tenderisations"],
    &["tenderizations"],
    &["tenderisations"],
];

pub(crate) static ENTRY_TENDERIZATION_7750334074937606325: VariantsMap = [
    &["tenderization"],
    &["tenderisation"],
    &["tenderization"],
    &["tenderisation"],
];

pub(crate) static ENTRY_TENDERIZED_13718535317658548812: VariantsMap = [
    &["tenderized"],
    &["tenderised"],
    &["tenderized"],
    &["tenderised"],
];

pub(crate) static ENTRY_TENDERIZERS_13914793532536564520: VariantsMap = [
    &["tenderizers"],
    &["tenderisers"],
    &["tenderizers"],
    &["tenderisers"],
];

pub(crate) static ENTRY_TENDERIZER_17224224602025748842: VariantsMap = [
    &["tenderizer"],
    &["tenderiser"],
    &["tenderizer"],
    &["tenderiser"],
];

pub(crate) static ENTRY_TENDERIZES_13464919051528220037: VariantsMap = [
    &["tenderizes"],
    &["tenderises"],
    &["tenderizes"],
    &["tenderises"],
];

pub(crate) static ENTRY_TENDERIZE_3531288944634226086: VariantsMap = [
    &["tenderize"],
    &["tenderise"],
    &["tenderize"],
    &["tenderise"],
];

pub(crate) static ENTRY_TENDERIZING_9684594006719958471: VariantsMap = [
    &["tenderizing"],
    &["tenderising"],
    &["tenderizing"],
    &["tenderising"],
];

pub(crate) static ENTRY_TENDRILED_3703626707361065691: VariantsMap = [
    &["tendriled"],
    &["tendrilled"],
    &["tendrilled"],
    &["tendrilled"],
];

pub(crate) static ENTRY_TENEMENTIZATIONS_1184744289790632274: VariantsMap = [
    &["tenementizations"],
    &["tenementisations"],
    &["tenementizations"],
    &["tenementisations"],
];

pub(crate) static ENTRY_TENEMENTIZATION_16373597570752442861: VariantsMap = [
    &["tenementization"],
    &["tenementisation"],
    &["tenementization"],
    &["tenementisation"],
];

pub(crate) static ENTRY_TENEMENTIZES_2482418667298355530: VariantsMap = [
    &["tenementizes"],
    &["tenementises"],
    &["tenementizes"],
    &["tenementises"],
];

pub(crate) static ENTRY_TENEMENTIZE_15184658096585226001: VariantsMap = [
    &["tenementize"],
    &["tenementise"],
    &["tenementize"],
    &["tenementise"],
];

pub(crate) static ENTRY_TENIACIDAL_541970291786449225: VariantsMap = [
    &["teniacidal"],
    &["taeniacidal"],
    &["taeniacidal"],
    &["taeniacidal"],
];

pub(crate) static ENTRY_TENIACIDES_9085014004304381530: VariantsMap = [
    &["teniacides"],
    &["taeniacides"],
    &["taeniacides"],
    &["taeniacides"],
];

pub(crate) static ENTRY_TENIACIDE_9272287110828061667: VariantsMap = [
    &["teniacide"],
    &["taeniacide"],
    &["taeniacide"],
    &["taeniacide"],
];

pub(crate) static ENTRY_TENIAE_2460733953776370015: VariantsMap =
    [&["teniae"], &["taeniae"], &["taeniae"], &["taeniae"]];

pub(crate) static ENTRY_TENIAFUGES_8258613951057794683: VariantsMap = [
    &["teniafuges"],
    &["taeniafuges"],
    &["taeniafuges"],
    &["taeniafuges"],
];

pub(crate) static ENTRY_TENIAFUGE_11053879169809004952: VariantsMap = [
    &["teniafuge"],
    &["taeniafuge"],
    &["taeniafuge"],
    &["taeniafuge"],
];

pub(crate) static ENTRY_TENIASES_4082434292313003269: VariantsMap = [
    &["teniases"],
    &["taeniases"],
    &["taeniases"],
    &["taeniases"],
];

pub(crate) static ENTRY_TENIASIS_11176202135157856401: VariantsMap = [
    &["teniasis"],
    &["taeniasis"],
    &["taeniasis"],
    &["taeniasis"],
];

pub(crate) static ENTRY_TENIAS_15863770479015006574: VariantsMap =
    [&["tenias"], &["taenias"], &["taenias"], &["taenias"]];

pub(crate) static ENTRY_TENIA_3590031604576778490: VariantsMap =
    [&["tenia"], &["taenia"], &["taenia"], &["taenia"]];

pub(crate) static ENTRY_TENIOID_6487095486830194346: VariantsMap =
    [&["tenioid"], &["taenioid"], &["taenioid"], &["taenioid"]];

pub(crate) static ENTRY_TENTHMETER_191273811277521832: VariantsMap = [
    &["tenthmeter"],
    &["tenthmetre"],
    &["tenthmetre"],
    &["tenthmetre"],
];

pub(crate) static ENTRY_TERF_10018438021336944491: VariantsMap =
    [&["terf"], &["tref"], &["tref"], &["tref"]];

pub(crate) static ENTRY_TERMATIC_12196187078337402107: VariantsMap =
    [&["termatic"], &["trematic"], &["trematic"], &["trematic"]];

pub(crate) static ENTRY_TERMA_17003310983688444980: VariantsMap =
    [&["terma"], &["trema"], &["trema"], &["trema"]];

pub(crate) static ENTRY_TERMINALIZATIONS_397057651180534160: VariantsMap = [
    &["terminalizations"],
    &["terminalisations"],
    &["terminalizations"],
    &["terminalisations"],
];

pub(crate) static ENTRY_TERMINALIZATION_227245526230759228: VariantsMap = [
    &["terminalization"],
    &["terminalisation"],
    &["terminalization"],
    &["terminalisation"],
];

pub(crate) static ENTRY_TERMINALIZEDS_13721584241698605404: VariantsMap = [
    &["terminalizeds"],
    &["terminaliseds"],
    &["terminalizeds"],
    &["terminaliseds"],
];

pub(crate) static ENTRY_TERMINALIZED_4320197084396986952: VariantsMap = [
    &["terminalized"],
    &["terminalised"],
    &["terminalized"],
    &["terminalised"],
];

pub(crate) static ENTRY_TERNIZES_9684916395709955397: VariantsMap =
    [&["ternizes"], &["ternises"], &["ternizes"], &["ternises"]];

pub(crate) static ENTRY_TERNIZE_12838808144005550317: VariantsMap =
    [&["ternize"], &["ternise"], &["ternize"], &["ternise"]];

pub(crate) static ENTRY_TERRESTRIALIZES_17535593305487765718: VariantsMap = [
    &["terrestrializes"],
    &["terrestrialises"],
    &["terrestrializes"],
    &["terrestrialises"],
];

pub(crate) static ENTRY_TERRESTRIALIZE_1578168346523607051: VariantsMap = [
    &["terrestrialize"],
    &["terrestrialise"],
    &["terrestrialize"],
    &["terrestrialise"],
];

pub(crate) static ENTRY_TERRE_7897526856583781149: VariantsMap =
    [&["terre"], &["terrae"], &["terrae"], &["terrae"]];

pub(crate) static ENTRY_TERRITORIALIZATIONS_17071036319359279295: VariantsMap = [
    &["territorializations"],
    &["territorialisations"],
    &["territorializations"],
    &["territorialisations"],
];

pub(crate) static ENTRY_TERRITORIALIZATION_5626612094734884596: VariantsMap = [
    &["territorialization"],
    &["territorialisation"],
    &["territorialization"],
    &["territorialisation"],
];

pub(crate) static ENTRY_TERRITORIALIZED_9407140238111760381: VariantsMap = [
    &["territorialized"],
    &["territorialised"],
    &["territorialized"],
    &["territorialised"],
];

pub(crate) static ENTRY_TERRITORIALIZES_10880031642015296195: VariantsMap = [
    &["territorializes"],
    &["territorialises"],
    &["territorializes"],
    &["territorialises"],
];

pub(crate) static ENTRY_TERRITORIALIZE_10884994209419008460: VariantsMap = [
    &["territorialize"],
    &["territorialise"],
    &["territorialize"],
    &["territorialise"],
];

pub(crate) static ENTRY_TERRITORIALIZING_7810154802700054163: VariantsMap = [
    &["territorializing"],
    &["territorialising"],
    &["territorializing"],
    &["territorialising"],
];

pub(crate) static ENTRY_TERRORIZATIONS_5594943151771816976: VariantsMap = [
    &["terrorizations"],
    &["terrorisations"],
    &["terrorizations"],
    &["terrorisations"],
];

pub(crate) static ENTRY_TERRORIZATION_12021859426492103552: VariantsMap = [
    &["terrorization"],
    &["terrorisation"],
    &["terrorization"],
    &["terrorisation"],
];

pub(crate) static ENTRY_TERRORIZED_4215828528050644298: VariantsMap = [
    &["terrorized"],
    &["terrorised"],
    &["terrorized"],
    &["terrorised"],
];

pub(crate) static ENTRY_TERRORIZERS_10990127721251926592: VariantsMap = [
    &["terrorizers"],
    &["terrorisers"],
    &["terrorizers"],
    &["terrorisers"],
];

pub(crate) static ENTRY_TERRORIZER_11495874779372458995: VariantsMap = [
    &["terrorizer"],
    &["terroriser"],
    &["terrorizer"],
    &["terroriser"],
];

pub(crate) static ENTRY_TERRORIZES_14794147503379380662: VariantsMap = [
    &["terrorizes"],
    &["terrorises"],
    &["terrorizes"],
    &["terrorises"],
];

pub(crate) static ENTRY_TERRORIZE_4433495255228210158: VariantsMap = [
    &["terrorize"],
    &["terrorise"],
    &["terrorize"],
    &["terrorise"],
];

pub(crate) static ENTRY_TERRORIZING_10081605138431727816: VariantsMap = [
    &["terrorizing"],
    &["terrorising"],
    &["terrorizing"],
    &["terrorising"],
];

pub(crate) static ENTRY_TERTS_13499660719155856568: VariantsMap =
    [&["terts"], &["trets"], &["trets"], &["trets"]];

pub(crate) static ENTRY_TESTE_1918146112764431205: VariantsMap =
    [&["teste"], &["testae"], &["testae"], &["testae"]];

pub(crate) static ENTRY_TESTIMONIALIZATIONS_4398798063194809999: VariantsMap = [
    &["testimonializations"],
    &["testimonialisations"],
    &["testimonializations"],
    &["testimonialisations"],
];

pub(crate) static ENTRY_TESTIMONIALIZATION_12919331762639910549: VariantsMap = [
    &["testimonialization"],
    &["testimonialisation"],
    &["testimonialization"],
    &["testimonialisation"],
];

pub(crate) static ENTRY_TESTIMONIALIZED_1092271798636725121: VariantsMap = [
    &["testimonialized"],
    &["testimonialised"],
    &["testimonialized"],
    &["testimonialised"],
];

pub(crate) static ENTRY_TESTIMONIALIZERS_8453724888025105330: VariantsMap = [
    &["testimonializers"],
    &["testimonialisers"],
    &["testimonializers"],
    &["testimonialisers"],
];

pub(crate) static ENTRY_TESTIMONIALIZER_6224529587979908189: VariantsMap = [
    &["testimonializer"],
    &["testimonialiser"],
    &["testimonializer"],
    &["testimonialiser"],
];

pub(crate) static ENTRY_TESTIMONIALIZES_6019622939234728555: VariantsMap = [
    &["testimonializes"],
    &["testimonialises"],
    &["testimonializes"],
    &["testimonialises"],
];

pub(crate) static ENTRY_TESTIMONIALIZE_11938560871448602026: VariantsMap = [
    &["testimonialize"],
    &["testimonialise"],
    &["testimonialize"],
    &["testimonialise"],
];

pub(crate) static ENTRY_TESTIMONIALIZING_9654494111547138024: VariantsMap = [
    &["testimonializing"],
    &["testimonialising"],
    &["testimonializing"],
    &["testimonialising"],
];

pub(crate) static ENTRY_TES_2695854084624117978: VariantsMap =
    [&["tes"], &["taes"], &["taes"], &["taes"]];

pub(crate) static ENTRY_TETANIZATIONS_4717934429082095797: VariantsMap = [
    &["tetanizations"],
    &["tetanisations"],
    &["tetanizations"],
    &["tetanisations"],
];

pub(crate) static ENTRY_TETANIZATION_644441807826043153: VariantsMap = [
    &["tetanization"],
    &["tetanisation"],
    &["tetanization"],
    &["tetanisation"],
];

pub(crate) static ENTRY_TETANIZED_4812837442844439806: VariantsMap = [
    &["tetanized"],
    &["tetanised"],
    &["tetanized"],
    &["tetanised"],
];

pub(crate) static ENTRY_TETANIZES_14522346757244125769: VariantsMap = [
    &["tetanizes"],
    &["tetanises"],
    &["tetanizes"],
    &["tetanises"],
];

pub(crate) static ENTRY_TETANIZE_16968084563752369509: VariantsMap =
    [&["tetanize"], &["tetanise"], &["tetanize"], &["tetanise"]];

pub(crate) static ENTRY_TETANIZING_10656947870602533649: VariantsMap = [
    &["tetanizing"],
    &["tetanising"],
    &["tetanizing"],
    &["tetanising"],
];

pub(crate) static ENTRY_TETRACHLORETHYLENES_4836279453043134015: VariantsMap = [
    &["tetrachlorethylenes"],
    &["tetrachloroethylenes"],
    &["tetrachloroethylenes"],
    &["tetrachloroethylenes"],
];

pub(crate) static ENTRY_TETRACHLORETHYLENE_16525989969636196009: VariantsMap = [
    &["tetrachlorethylene"],
    &["tetrachloroethylene"],
    &["tetrachloroethylene"],
    &["tetrachloroethylene"],
];

pub(crate) static ENTRY_TEUTONIZATION_6292454241854286943: VariantsMap = [
    &["teutonization"],
    &["teutonisation"],
    &["teutonization"],
    &["teutonisation"],
];

pub(crate) static ENTRY_TEUTONIZED_11271380910684387893: VariantsMap = [
    &["teutonized"],
    &["teutonised"],
    &["teutonized"],
    &["teutonised"],
];

pub(crate) static ENTRY_TEUTONIZES_4927618306679970592: VariantsMap = [
    &["teutonizes"],
    &["teutonises"],
    &["teutonizes"],
    &["teutonises"],
];

pub(crate) static ENTRY_TEUTONIZE_11056261029352359900: VariantsMap = [
    &["teutonize"],
    &["teutonise"],
    &["teutonize"],
    &["teutonise"],
];

pub(crate) static ENTRY_TEUTONIZING_11530030305824710733: VariantsMap = [
    &["teutonizing"],
    &["teutonising"],
    &["teutonizing"],
    &["teutonising"],
];

pub(crate) static ENTRY_TEXTURIZED_13336952192214416477: VariantsMap = [
    &["texturized"],
    &["texturised"],
    &["texturized"],
    &["texturised"],
];

pub(crate) static ENTRY_TEXTURIZES_11082666773590293557: VariantsMap = [
    &["texturizes"],
    &["texturises"],
    &["texturizes"],
    &["texturises"],
];

pub(crate) static ENTRY_TEXTURIZE_16745696432837818203: VariantsMap = [
    &["texturize"],
    &["texturise"],
    &["texturize"],
    &["texturise"],
];

pub(crate) static ENTRY_TEXTURIZING_13353456070689850489: VariantsMap = [
    &["texturizing"],
    &["texturising"],
    &["texturizing"],
    &["texturising"],
];

pub(crate) static ENTRY_TE_3678231452906120781: VariantsMap =
    [&["te"], &["tae"], &["tae"], &["tae"]];

pub(crate) static ENTRY_THALAMOCELE_6877568201362530055: VariantsMap = [
    &["thalamocele"],
    &["thalamocoele"],
    &["thalamocoele"],
    &["thalamocoele"],
];

pub(crate) static ENTRY_THALASSEMIAS_12002727284526494170: VariantsMap = [
    &["thalassemias"],
    &["thalassaemias"],
    &["thalassaemias"],
    &["thalassaemias"],
];

pub(crate) static ENTRY_THALASSEMIA_4313522697929453494: VariantsMap = [
    &["thalassemia"],
    &["thalassaemia"],
    &["thalassaemia"],
    &["thalassaemia"],
];

pub(crate) static ENTRY_THALASSEMIC_6553136861220895911: VariantsMap = [
    &["thalassemic"],
    &["thalassaemic"],
    &["thalassaemic"],
    &["thalassaemic"],
];

pub(crate) static ENTRY_THEATERGOERS_5559625776188799969: VariantsMap = [
    &["theatergoers"],
    &["theatregoers"],
    &["theatregoers"],
    &["theatregoers"],
];

pub(crate) static ENTRY_THEATERGOER_13508908798164743655: VariantsMap = [
    &["theatergoer"],
    &["theatregoer"],
    &["theatregoer"],
    &["theatregoer"],
];

pub(crate) static ENTRY_THEATERGOINGS_15343856177156795772: VariantsMap = [
    &["theatergoings"],
    &["theatregoings"],
    &["theatregoings"],
    &["theatregoings"],
];

pub(crate) static ENTRY_THEATERGOING_2013024560518217436: VariantsMap = [
    &["theatergoing"],
    &["theatregoing"],
    &["theatregoing"],
    &["theatregoing"],
];

pub(crate) static ENTRY_THEATERLESSES_13355329845366484082: VariantsMap = [
    &["theaterlesses"],
    &["theatrelesses"],
    &["theatrelesses"],
    &["theatrelesses"],
];

pub(crate) static ENTRY_THEATERLESS_9897874198880950215: VariantsMap = [
    &["theaterless"],
    &["theatreless"],
    &["theatreless"],
    &["theatreless"],
];

pub(crate) static ENTRY_THEATERLIKES_9843968538207930637: VariantsMap = [
    &["theaterlikes"],
    &["theatrelikes"],
    &["theatrelikes"],
    &["theatrelikes"],
];

pub(crate) static ENTRY_THEATERLIKE_17383240736384944394: VariantsMap = [
    &["theaterlike"],
    &["theatrelike"],
    &["theatrelike"],
    &["theatrelike"],
];

pub(crate) static ENTRY_THEATERS_7003357064188297631: VariantsMap =
    [&["theaters"], &["theatres"], &["theatres"], &["theatres"]];

pub(crate) static ENTRY_THEATER_7475041782659424938: VariantsMap =
    [&["theater"], &["theatre"], &["theatre"], &["theatre"]];

pub(crate) static ENTRY_THEATRICALIZATIONS_9847157477732689589: VariantsMap = [
    &["theatricalizations"],
    &["theatricalisations"],
    &["theatricalizations"],
    &["theatricalisations"],
];

pub(crate) static ENTRY_THEATRICALIZATION_5100192476801019805: VariantsMap = [
    &["theatricalization"],
    &["theatricalisation"],
    &["theatricalization"],
    &["theatricalisation"],
];

pub(crate) static ENTRY_THEATRICALIZED_1898586809778434070: VariantsMap = [
    &["theatricalized"],
    &["theatricalised"],
    &["theatricalized"],
    &["theatricalised"],
];

pub(crate) static ENTRY_THEATRICALIZES_13227757208676141045: VariantsMap = [
    &["theatricalizes"],
    &["theatricalises"],
    &["theatricalizes"],
    &["theatricalises"],
];

pub(crate) static ENTRY_THEATRICALIZE_7879311001018696669: VariantsMap = [
    &["theatricalize"],
    &["theatricalise"],
    &["theatricalize"],
    &["theatricalise"],
];

pub(crate) static ENTRY_THEATRICALIZING_18213572522629992498: VariantsMap = [
    &["theatricalizing"],
    &["theatricalising"],
    &["theatricalizing"],
    &["theatricalising"],
];

pub(crate) static ENTRY_THEATRICIZED_4634839439233392959: VariantsMap = [
    &["theatricized"],
    &["theatricised"],
    &["theatricized"],
    &["theatricised"],
];

pub(crate) static ENTRY_THEATRICIZES_2910136151023698070: VariantsMap = [
    &["theatricizes"],
    &["theatricises"],
    &["theatricizes"],
    &["theatricises"],
];

pub(crate) static ENTRY_THEATRICIZE_11791979948757453878: VariantsMap = [
    &["theatricize"],
    &["theatricise"],
    &["theatricize"],
    &["theatricise"],
];

pub(crate) static ENTRY_THEATRICIZING_18012556106152152017: VariantsMap = [
    &["theatricizing"],
    &["theatricising"],
    &["theatricizing"],
    &["theatricising"],
];

pub(crate) static ENTRY_THEOLOGIZATIONS_8755931201308113045: VariantsMap = [
    &["theologizations"],
    &["theologisations"],
    &["theologizations"],
    &["theologisations"],
];

pub(crate) static ENTRY_THEOLOGIZATION_7152403949351806099: VariantsMap = [
    &["theologization"],
    &["theologisation"],
    &["theologization"],
    &["theologisation"],
];

pub(crate) static ENTRY_THEOLOGIZED_10310177154314243592: VariantsMap = [
    &["theologized"],
    &["theologised"],
    &["theologized"],
    &["theologised"],
];

pub(crate) static ENTRY_THEOLOGIZERS_14696166776167600970: VariantsMap = [
    &["theologizers"],
    &["theologisers"],
    &["theologizers"],
    &["theologisers"],
];

pub(crate) static ENTRY_THEOLOGIZER_10090989839655321620: VariantsMap = [
    &["theologizer"],
    &["theologiser"],
    &["theologizer"],
    &["theologiser"],
];

pub(crate) static ENTRY_THEOLOGIZES_11032972148839634053: VariantsMap = [
    &["theologizes"],
    &["theologises"],
    &["theologizes"],
    &["theologises"],
];

pub(crate) static ENTRY_THEOLOGIZE_12039512331849672306: VariantsMap = [
    &["theologize"],
    &["theologise"],
    &["theologize"],
    &["theologise"],
];

pub(crate) static ENTRY_THEOLOGIZING_7504945621285245915: VariantsMap = [
    &["theologizing"],
    &["theologising"],
    &["theologizing"],
    &["theologising"],
];

pub(crate) static ENTRY_THEONE_15120851021086460108: VariantsMap =
    [&["theone"], &["theonoe"], &["theonoe"], &["theonoe"]];

pub(crate) static ENTRY_THEORIZATIONS_14753566303904725274: VariantsMap = [
    &["theorizations"],
    &["theorisations"],
    &["theorizations"],
    &["theorisations"],
];

pub(crate) static ENTRY_THEORIZATION_12059838448730918530: VariantsMap = [
    &["theorization"],
    &["theorisation"],
    &["theorization"],
    &["theorisation"],
];

pub(crate) static ENTRY_THEORIZED_15807114832316720521: VariantsMap = [
    &["theorized"],
    &["theorised"],
    &["theorized"],
    &["theorised"],
];

pub(crate) static ENTRY_THEORIZERS_11381755780951206742: VariantsMap = [
    &["theorizers"],
    &["theorisers"],
    &["theorizers"],
    &["theorisers"],
];

pub(crate) static ENTRY_THEORIZER_16504744998921729475: VariantsMap = [
    &["theorizer"],
    &["theoriser"],
    &["theorizer"],
    &["theoriser"],
];

pub(crate) static ENTRY_THEORIZES_8680815198827974415: VariantsMap = [
    &["theorizes"],
    &["theorises"],
    &["theorizes"],
    &["theorises"],
];

pub(crate) static ENTRY_THEORIZE_7590366607759932540: VariantsMap =
    [&["theorize"], &["theorise"], &["theorize"], &["theorise"]];

pub(crate) static ENTRY_THEORIZING_12129998359159098514: VariantsMap = [
    &["theorizing"],
    &["theorising"],
    &["theorizing"],
    &["theorising"],
];

pub(crate) static ENTRY_THEOSOPHIZED_13107432553508855295: VariantsMap = [
    &["theosophized"],
    &["theosophised"],
    &["theosophized"],
    &["theosophised"],
];

pub(crate) static ENTRY_THEOSOPHIZES_8474550672328978106: VariantsMap = [
    &["theosophizes"],
    &["theosophises"],
    &["theosophizes"],
    &["theosophises"],
];

pub(crate) static ENTRY_THEOSOPHIZE_4763429583533636802: VariantsMap = [
    &["theosophize"],
    &["theosophise"],
    &["theosophize"],
    &["theosophise"],
];

pub(crate) static ENTRY_THEOSOPHIZING_8407612924930104080: VariantsMap = [
    &["theosophizing"],
    &["theosophising"],
    &["theosophizing"],
    &["theosophising"],
];

pub(crate) static ENTRY_THERAP_9544025308390036027: VariantsMap =
    [&["therap"], &["threap"], &["threap"], &["threap"]];

pub(crate) static ENTRY_THERENESSES_10801981187729653982: VariantsMap = [
    &["therenesses"],
    &["threenesses"],
    &["threenesses"],
    &["threenesses"],
];

pub(crate) static ENTRY_THERENESS_9852552452824690186: VariantsMap = [
    &["thereness"],
    &["threeness"],
    &["threeness"],
    &["threeness"],
];

pub(crate) static ENTRY_THERMALIZATIONS_8288894113771008081: VariantsMap = [
    &["thermalizations"],
    &["thermalisations"],
    &["thermalizations"],
    &["thermalisations"],
];

pub(crate) static ENTRY_THERMALIZATION_16496082479527814110: VariantsMap = [
    &["thermalization"],
    &["thermalisation"],
    &["thermalization"],
    &["thermalisation"],
];

pub(crate) static ENTRY_THERMALIZED_2624600087787570463: VariantsMap = [
    &["thermalized"],
    &["thermalised"],
    &["thermalized"],
    &["thermalised"],
];

pub(crate) static ENTRY_THERMALIZES_9233370697763280406: VariantsMap = [
    &["thermalizes"],
    &["thermalises"],
    &["thermalizes"],
    &["thermalises"],
];

pub(crate) static ENTRY_THERMALIZE_13967008816461896974: VariantsMap = [
    &["thermalize"],
    &["thermalise"],
    &["thermalize"],
    &["thermalise"],
];

pub(crate) static ENTRY_THERMALIZING_2527773938442619633: VariantsMap = [
    &["thermalizing"],
    &["thermalising"],
    &["thermalizing"],
    &["thermalising"],
];

pub(crate) static ENTRY_THERMESTHESIA_3863490653735583135: VariantsMap = [
    &["thermesthesia"],
    &["thermaesthesia"],
    &["thermaesthesia"],
    &["thermaesthesia"],
];

pub(crate) static ENTRY_THERME_4628895801679564218: VariantsMap =
    [&["therme"], &["thermae"], &["thermae"], &["thermae"]];

pub(crate) static ENTRY_THERMOANESTHESIAS_9860040313830784109: VariantsMap = [
    &["thermoanesthesias"],
    &["thermoanaesthesias"],
    &["thermoanaesthesias"],
    &["thermoanaesthesias"],
];

pub(crate) static ENTRY_THERMOANESTHESIA_10535525771166290918: VariantsMap = [
    &["thermoanesthesia"],
    &["thermoanaesthesia"],
    &["thermoanaesthesia"],
    &["thermoanaesthesia"],
];

pub(crate) static ENTRY_THERMOMETERIZES_15743806572499862572: VariantsMap = [
    &["thermometerizes"],
    &["thermometerises"],
    &["thermometerizes"],
    &["thermometerises"],
];

pub(crate) static ENTRY_THERMOMETERIZE_5609847558691367828: VariantsMap = [
    &["thermometerize"],
    &["thermometerise"],
    &["thermometerize"],
    &["thermometerise"],
];

pub(crate) static ENTRY_THERMOPOLYMERIZATIONS_11816137734797485190: VariantsMap = [
    &["thermopolymerizations"],
    &["thermopolymerisations"],
    &["thermopolymerizations"],
    &["thermopolymerisations"],
];

pub(crate) static ENTRY_THERMOPOLYMERIZATION_10152681254881200049: VariantsMap = [
    &["thermopolymerization"],
    &["thermopolymerisation"],
    &["thermopolymerization"],
    &["thermopolymerisation"],
];

pub(crate) static ENTRY_THERMOSIPHONS_4618042359977478493: VariantsMap = [
    &["thermosiphons"],
    &["thermosyphons"],
    &["thermosyphons"],
    &["thermosyphons"],
];

pub(crate) static ENTRY_THERMOSIPHON_13567630129328954909: VariantsMap = [
    &["thermosiphon"],
    &["thermosyphon"],
    &["thermosyphon"],
    &["thermosyphon"],
];

pub(crate) static ENTRY_THESMOTHETE_15046146759292701834: VariantsMap = [
    &["thesmothete"],
    &["thesmothetae"],
    &["thesmothetae"],
    &["thesmothetae"],
];

pub(crate) static ENTRY_THRONIZES_15599592934515323866: VariantsMap = [
    &["thronizes"],
    &["thronises"],
    &["thronizes"],
    &["thronises"],
];

pub(crate) static ENTRY_THRONIZE_281314801217953052: VariantsMap =
    [&["thronize"], &["thronise"], &["thronize"], &["thronise"]];

pub(crate) static ENTRY_THROUGH_14009312703153313360: VariantsMap =
    [&["through"], &["through"], &["through"], &["through"]];

pub(crate) static ENTRY_THRUWAYS_9243384191667191710: VariantsMap = [
    &["thruways"],
    &["throughways"],
    &["throughways"],
    &["throughways"],
];

pub(crate) static ENTRY_THRUWAY_390000294149739545: VariantsMap = [
    &["thruway"],
    &["throughway"],
    &["throughway"],
    &["throughway"],
];

pub(crate) static ENTRY_THYMECTOMIZE_11505114453378889137: VariantsMap = [
    &["thymectomize"],
    &["thymectomise"],
    &["thymectomize"],
    &["thymectomise"],
];

pub(crate) static ENTRY_THYROIDECTOMIZED_14073280712975578866: VariantsMap = [
    &["thyroidectomized"],
    &["thyroidectomised"],
    &["thyroidectomized"],
    &["thyroidectomised"],
];

pub(crate) static ENTRY_THYROIDIZATIONS_15631291795213610526: VariantsMap = [
    &["thyroidizations"],
    &["thyroidisations"],
    &["thyroidizations"],
    &["thyroidisations"],
];

pub(crate) static ENTRY_THYROIDIZATION_3396351276247323991: VariantsMap = [
    &["thyroidization"],
    &["thyroidisation"],
    &["thyroidization"],
    &["thyroidisation"],
];

pub(crate) static ENTRY_TIDBITS_16344615149357827521: VariantsMap =
    [&["tidbits"], &["titbits"], &["tidbits"], &["titbits"]];

pub(crate) static ENTRY_TIDBIT_7805000089381014190: VariantsMap =
    [&["tidbit"], &["titbit"], &["tidbit"], &["titbit"]];

pub(crate) static ENTRY_TILLFORD_8277631863674555040: VariantsMap = [
    &["tillford"],
    &["tillfourd"],
    &["tillfourd"],
    &["tillfourd"],
];

pub(crate) static ENTRY_TIMONIZED_8552612423976383697: VariantsMap = [
    &["timonized"],
    &["timonised"],
    &["timonized"],
    &["timonised"],
];

pub(crate) static ENTRY_TIMONIZES_16937469115549830749: VariantsMap = [
    &["timonizes"],
    &["timonises"],
    &["timonizes"],
    &["timonises"],
];

pub(crate) static ENTRY_TIMONIZE_17549986461978761475: VariantsMap =
    [&["timonize"], &["timonise"], &["timonize"], &["timonise"]];

pub(crate) static ENTRY_TIMONIZING_4835714890422549178: VariantsMap = [
    &["timonizing"],
    &["timonising"],
    &["timonizing"],
    &["timonising"],
];

pub(crate) static ENTRY_TIMOR_2690216955682569292: VariantsMap =
    [&["timor"], &["timour"], &["timour"], &["timour"]];

pub(crate) static ENTRY_TINSELED_3866509100193036989: VariantsMap = [
    &["tinseled"],
    &["tinselled"],
    &["tinselled"],
    &["tinselled"],
];

pub(crate) static ENTRY_TINSELIER_11585655450397053875: VariantsMap = [
    &["tinselier"],
    &["tinsellier"],
    &["tinsellier"],
    &["tinsellier"],
];

pub(crate) static ENTRY_TINSELIEST_10668984252057983847: VariantsMap = [
    &["tinseliest"],
    &["tinselliest"],
    &["tinselliest"],
    &["tinselliest"],
];

pub(crate) static ENTRY_TINSELING_2103793771113344037: VariantsMap = [
    &["tinseling"],
    &["tinselling"],
    &["tinselling"],
    &["tinselling"],
];

pub(crate) static ENTRY_TIRES_4841205171088418079: VariantsMap =
    [&["tires"], &["tyres"], &["tires"], &["tyres"]];

pub(crate) static ENTRY_TIRE_6240813028329445155: VariantsMap =
    [&["tire"], &["tyre"], &["tire"], &["tyre"]];

pub(crate) static ENTRY_TITERS_11786621739929986321: VariantsMap =
    [&["titers"], &["titres"], &["titres"], &["titres"]];

pub(crate) static ENTRY_TITER_8889184709551132501: VariantsMap =
    [&["titer"], &["titre"], &["titre"], &["titre"]];

pub(crate) static ENTRY_TITTUPED_2906437008152483513: VariantsMap = [
    &["tittuped"],
    &["tittupped"],
    &["tittupped"],
    &["tittupped"],
];

pub(crate) static ENTRY_TITTUPING_10006138755530945025: VariantsMap = [
    &["tittuping"],
    &["tittupping"],
    &["tittupping"],
    &["tittupping"],
];

pub(crate) static ENTRY_TITTUPY_15226672837677900507: VariantsMap =
    [&["tittupy"], &["tittuppy"], &["tittuppy"], &["tittuppy"]];

pub(crate) static ENTRY_TONICIZES_14086969720152558778: VariantsMap = [
    &["tonicizes"],
    &["tonicises"],
    &["tonicizes"],
    &["tonicises"],
];

pub(crate) static ENTRY_TONICIZE_14493332215083535444: VariantsMap =
    [&["tonicize"], &["tonicise"], &["tonicize"], &["tonicise"]];

pub(crate) static ENTRY_TOPESTHESIA_942978545009231732: VariantsMap = [
    &["topesthesia"],
    &["topaesthesia"],
    &["topaesthesia"],
    &["topaesthesia"],
];

pub(crate) static ENTRY_TORET_9300193947670512159: VariantsMap =
    [&["toret"], &["touret"], &["touret"], &["touret"]];

pub(crate) static ENTRY_TORPORIZES_13334911738014548028: VariantsMap = [
    &["torporizes"],
    &["torporises"],
    &["torporizes"],
    &["torporises"],
];

pub(crate) static ENTRY_TORPORIZE_18069353743945116344: VariantsMap = [
    &["torporize"],
    &["torporise"],
    &["torporize"],
    &["torporise"],
];

pub(crate) static ENTRY_TORYIZES_5132670899591153786: VariantsMap =
    [&["toryizes"], &["toryises"], &["toryizes"], &["toryises"]];

pub(crate) static ENTRY_TORYIZE_995538363033283697: VariantsMap =
    [&["toryize"], &["toryise"], &["toryize"], &["toryise"]];

pub(crate) static ENTRY_TOTALED_16465945397491592065: VariantsMap =
    [&["totaled"], &["totalled"], &["totalled"], &["totalled"]];

pub(crate) static ENTRY_TOTALERS_10161072248298040391: VariantsMap = [
    &["totalers"],
    &["totallers"],
    &["totallers"],
    &["totallers"],
];

pub(crate) static ENTRY_TOTALER_13889474056076724285: VariantsMap =
    [&["totaler"], &["totaller"], &["totaller"], &["totaller"]];

pub(crate) static ENTRY_TOTALING_5708433697317878112: VariantsMap = [
    &["totaling"],
    &["totalling"],
    &["totalling"],
    &["totalling"],
];

pub(crate) static ENTRY_TOTALITARIANIZE_17279194250687480990: VariantsMap = [
    &["totalitarianize"],
    &["totalitarianise"],
    &["totalitarianize"],
    &["totalitarianise"],
];

pub(crate) static ENTRY_TOTALIZATIONS_12539779961057448289: VariantsMap = [
    &["totalizations"],
    &["totalisations"],
    &["totalizations"],
    &["totalisations"],
];

pub(crate) static ENTRY_TOTALIZATION_677434854617719224: VariantsMap = [
    &["totalization"],
    &["totalisation"],
    &["totalization"],
    &["totalisation"],
];

pub(crate) static ENTRY_TOTALIZATORS_1298582278316075613: VariantsMap = [
    &["totalizators"],
    &["totalisators"],
    &["totalisators"],
    &["totalisators"],
];

pub(crate) static ENTRY_TOTALIZATOR_4519528537104362408: VariantsMap = [
    &["totalizator"],
    &["totalisator"],
    &["totalisator"],
    &["totalisator"],
];

pub(crate) static ENTRY_TOTALIZED_5947312301455804043: VariantsMap = [
    &["totalized"],
    &["totalised"],
    &["totalized"],
    &["totalised"],
];

pub(crate) static ENTRY_TOTALIZERS_4514710132472904320: VariantsMap = [
    &["totalizers"],
    &["totalisers"],
    &["totalizers"],
    &["totalisers"],
];

pub(crate) static ENTRY_TOTALIZER_9458208321837577997: VariantsMap = [
    &["totalizer"],
    &["totaliser"],
    &["totalizer"],
    &["totaliser"],
];

pub(crate) static ENTRY_TOTALIZES_9293041034438278469: VariantsMap = [
    &["totalizes"],
    &["totalises"],
    &["totalizes"],
    &["totalises"],
];

pub(crate) static ENTRY_TOTALIZE_15116326015710861314: VariantsMap =
    [&["totalize"], &["totalise"], &["totalize"], &["totalise"]];

pub(crate) static ENTRY_TOTALIZING_2151125471228422884: VariantsMap = [
    &["totalizing"],
    &["totalising"],
    &["totalizing"],
    &["totalising"],
];

pub(crate) static ENTRY_TOTEMIZATIONS_3935483205280312961: VariantsMap = [
    &["totemizations"],
    &["totemisations"],
    &["totemizations"],
    &["totemisations"],
];

pub(crate) static ENTRY_TOTEMIZATION_5945650529175210425: VariantsMap = [
    &["totemization"],
    &["totemisation"],
    &["totemization"],
    &["totemisation"],
];

pub(crate) static ENTRY_TOURIZES_17389788493732868673: VariantsMap =
    [&["tourizes"], &["tourises"], &["tourizes"], &["tourises"]];

pub(crate) static ENTRY_TOURIZE_8892565616062448746: VariantsMap =
    [&["tourize"], &["tourise"], &["tourize"], &["tourise"]];

pub(crate) static ENTRY_TOWELED_10940852459488171030: VariantsMap =
    [&["toweled"], &["towelled"], &["towelled"], &["towelled"]];

pub(crate) static ENTRY_TOWELINGS_6040236374111337509: VariantsMap = [
    &["towelings"],
    &["towellings"],
    &["towellings"],
    &["towellings"],
];

pub(crate) static ENTRY_TOWELING_1180280283599091589: VariantsMap = [
    &["toweling"],
    &["towelling"],
    &["towelling"],
    &["towelling"],
];

pub(crate) static ENTRY_TOXANEMIA_17135685765577589935: VariantsMap = [
    &["toxanemia"],
    &["toxanaemia"],
    &["toxanaemia"],
    &["toxanaemia"],
];

pub(crate) static ENTRY_TOXEMIAS_6987620895652086802: VariantsMap =
    [&["toxemias"], &["toxaemias"], &["toxemias"], &["toxaemias"]];

pub(crate) static ENTRY_TOXEMIA_8507561579843698401: VariantsMap =
    [&["toxemia"], &["toxaemia"], &["toxemia"], &["toxaemia"]];

pub(crate) static ENTRY_TOXEMIC_11112870586226499459: VariantsMap =
    [&["toxemic"], &["toxaemic"], &["toxemic"], &["toxaemic"]];

pub(crate) static ENTRY_TOXICEMIA_8873423138860871823: VariantsMap = [
    &["toxicemia"],
    &["toxicaemia"],
    &["toxicaemia"],
    &["toxicaemia"],
];

pub(crate) static ENTRY_TOXICOHEMIA_4773459108436354364: VariantsMap = [
    &["toxicohemia"],
    &["toxicohaemia"],
    &["toxicohaemia"],
    &["toxicohaemia"],
];

pub(crate) static ENTRY_TOXIHEMIA_3647608395377073910: VariantsMap = [
    &["toxihemia"],
    &["toxihaemia"],
    &["toxihaemia"],
    &["toxihaemia"],
];

pub(crate) static ENTRY_TOXINEMIA_15164755111459298400: VariantsMap = [
    &["toxinemia"],
    &["toxinaemia"],
    &["toxinaemia"],
    &["toxinaemia"],
];

pub(crate) static ENTRY_TRABEATE_483987459575339818: VariantsMap = [
    &["trabeate"],
    &["trabeatae"],
    &["trabeatae"],
    &["trabeatae"],
];

pub(crate) static ENTRY_TRABECULE_15772862836097815: VariantsMap = [
    &["trabecule"],
    &["trabeculae"],
    &["trabeculae"],
    &["trabeculae"],
];

pub(crate) static ENTRY_TRACTORIZATIONS_339031056491180798: VariantsMap = [
    &["tractorizations"],
    &["tractorisations"],
    &["tractorizations"],
    &["tractorisations"],
];

pub(crate) static ENTRY_TRACTORIZATION_10992127938217075731: VariantsMap = [
    &["tractorization"],
    &["tractorisation"],
    &["tractorization"],
    &["tractorisation"],
];

pub(crate) static ENTRY_TRACTORIZES_15847189337277496859: VariantsMap = [
    &["tractorizes"],
    &["tractorises"],
    &["tractorizes"],
    &["tractorises"],
];

pub(crate) static ENTRY_TRACTORIZE_2241099676594242440: VariantsMap = [
    &["tractorize"],
    &["tractorise"],
    &["tractorize"],
    &["tractorise"],
];

pub(crate) static ENTRY_TRADITIONALIZED_7379142112845457397: VariantsMap = [
    &["traditionalized"],
    &["traditionalised"],
    &["traditionalized"],
    &["traditionalised"],
];

pub(crate) static ENTRY_TRADITIONALIZES_4915966875918551718: VariantsMap = [
    &["traditionalizes"],
    &["traditionalises"],
    &["traditionalizes"],
    &["traditionalises"],
];

pub(crate) static ENTRY_TRADITIONALIZE_2456697841812175322: VariantsMap = [
    &["traditionalize"],
    &["traditionalise"],
    &["traditionalize"],
    &["traditionalise"],
];

pub(crate) static ENTRY_TRADITIONIZES_8267674418394695252: VariantsMap = [
    &["traditionizes"],
    &["traditionises"],
    &["traditionizes"],
    &["traditionises"],
];

pub(crate) static ENTRY_TRADITIONIZE_5364897103719523136: VariantsMap = [
    &["traditionize"],
    &["traditionise"],
    &["traditionize"],
    &["traditionise"],
];

pub(crate) static ENTRY_TRAGICIZES_3989913928010417742: VariantsMap = [
    &["tragicizes"],
    &["tragicises"],
    &["tragicizes"],
    &["tragicises"],
];

pub(crate) static ENTRY_TRAGICIZE_13682460226835988470: VariantsMap = [
    &["tragicize"],
    &["tragicise"],
    &["tragicize"],
    &["tragicise"],
];

pub(crate) static ENTRY_TRAGICOLORED_2720904369140832474: VariantsMap = [
    &["tragicolored"],
    &["tragicoloured"],
    &["tragicoloured"],
    &["tragicoloured"],
];

pub(crate) static ENTRY_TRAITORIZES_6117010440470228630: VariantsMap = [
    &["traitorizes"],
    &["traitorises"],
    &["traitorizes"],
    &["traitorises"],
];

pub(crate) static ENTRY_TRAITORIZE_13903037963874437628: VariantsMap = [
    &["traitorize"],
    &["traitorise"],
    &["traitorize"],
    &["traitorise"],
];

pub(crate) static ENTRY_TRAMMELED_8060808627087874636: VariantsMap = [
    &["trammeled"],
    &["trammelled"],
    &["trammelled"],
    &["trammelled"],
];

pub(crate) static ENTRY_TRAMMELERS_17026265261107245670: VariantsMap = [
    &["trammelers"],
    &["trammellers"],
    &["trammellers"],
    &["trammellers"],
];

pub(crate) static ENTRY_TRAMMELER_9827725773053804702: VariantsMap = [
    &["trammeler"],
    &["trammeller"],
    &["trammeller"],
    &["trammeller"],
];

pub(crate) static ENTRY_TRAMMELING_6888018546127671609: VariantsMap = [
    &["trammeling"],
    &["trammelling"],
    &["trammelling"],
    &["trammelling"],
];

pub(crate) static ENTRY_TRANQUILITIES_14597029814491190009: VariantsMap = [
    &["tranquilities"],
    &["tranquillities"],
    &["tranquilities"],
    &["tranquillities"],
];

pub(crate) static ENTRY_TRANQUILITY_17026669099016984269: VariantsMap = [
    &["tranquility"],
    &["tranquillity"],
    &["tranquility"],
    &["tranquillity"],
];

pub(crate) static ENTRY_TRANQUILIZATIONS_12380036249843910188: VariantsMap = [
    &["tranquilizations"],
    &["tranquilisations"],
    &["tranquilizations"],
    &["tranquilisations"],
];

pub(crate) static ENTRY_TRANQUILIZATION_5521617584193917818: VariantsMap = [
    &["tranquilization"],
    &["tranquilisation"],
    &["tranquilization"],
    &["tranquilisation"],
];

pub(crate) static ENTRY_TRANQUILIZED_12211443123255939369: VariantsMap = [
    &["tranquilized"],
    &["tranquillised"],
    &["tranquilized"],
    &["tranquillised"],
];

pub(crate) static ENTRY_TRANQUILIZERS_9011655985998697530: VariantsMap = [
    &["tranquilizers"],
    &["tranquillisers"],
    &["tranquilizers"],
    &["tranquillisers"],
];

pub(crate) static ENTRY_TRANQUILIZER_4580963450554408865: VariantsMap = [
    &["tranquilizer"],
    &["tranquilliser"],
    &["tranquilizer"],
    &["tranquilliser"],
];

pub(crate) static ENTRY_TRANQUILIZES_8944342824362588640: VariantsMap = [
    &["tranquilizes"],
    &["tranquillises"],
    &["tranquilizes"],
    &["tranquillises"],
];

pub(crate) static ENTRY_TRANQUILIZE_2318549175902793795: VariantsMap = [
    &["tranquilize"],
    &["tranquillise"],
    &["tranquilize"],
    &["tranquillise"],
];

pub(crate) static ENTRY_TRANQUILIZINGLY_8937506465456562211: VariantsMap = [
    &["tranquilizingly"],
    &["tranquilisingly"],
    &["tranquilizingly"],
    &["tranquilisingly"],
];

pub(crate) static ENTRY_TRANQUILIZINGS_14161142259051334768: VariantsMap = [
    &["tranquilizings"],
    &["tranquillisings"],
    &["tranquilizings"],
    &["tranquillisings"],
];

pub(crate) static ENTRY_TRANQUILIZING_16473900108179388526: VariantsMap = [
    &["tranquilizing"],
    &["tranquillising"],
    &["tranquilizing"],
    &["tranquillising"],
];

pub(crate) static ENTRY_TRANQUILLIZATIONS_15246245753023469100: VariantsMap = [
    &["tranquillizations"],
    &["tranquillisations"],
    &["tranquillizations"],
    &["tranquillisations"],
];

pub(crate) static ENTRY_TRANQUILLIZATION_3282376332675248379: VariantsMap = [
    &["tranquillization"],
    &["tranquillisation"],
    &["tranquillization"],
    &["tranquillisation"],
];

pub(crate) static ENTRY_TRANQUILLIZINGLY_12353888190974020557: VariantsMap = [
    &["tranquillizingly"],
    &["tranquillisingly"],
    &["tranquillizingly"],
    &["tranquillisingly"],
];

pub(crate) static ENTRY_TRANSCENDENTALIZATION_6781743576453143825: VariantsMap = [
    &["transcendentalization"],
    &["transcendentalisation"],
    &["transcendentalization"],
    &["transcendentalisation"],
];

pub(crate) static ENTRY_TRANSCENDENTALIZED_13133269603388695422: VariantsMap = [
    &["transcendentalized"],
    &["transcendentalised"],
    &["transcendentalized"],
    &["transcendentalised"],
];

pub(crate) static ENTRY_TRANSCENDENTALIZES_12319891228277271967: VariantsMap = [
    &["transcendentalizes"],
    &["transcendentalises"],
    &["transcendentalizes"],
    &["transcendentalises"],
];

pub(crate) static ENTRY_TRANSCENDENTALIZE_13136573359465624270: VariantsMap = [
    &["transcendentalize"],
    &["transcendentalise"],
    &["transcendentalize"],
    &["transcendentalise"],
];

pub(crate) static ENTRY_TRANSCENDENTALIZING_8443717951335927533: VariantsMap = [
    &["transcendentalizing"],
    &["transcendentalising"],
    &["transcendentalizing"],
    &["transcendentalising"],
];

pub(crate) static ENTRY_TRANSCOLORATIONS_15325443151749901762: VariantsMap = [
    &["transcolorations"],
    &["transcolourations"],
    &["transcolourations"],
    &["transcolourations"],
];

pub(crate) static ENTRY_TRANSCOLORATION_12023847350297738149: VariantsMap = [
    &["transcoloration"],
    &["transcolouration"],
    &["transcolouration"],
    &["transcolouration"],
];

pub(crate) static ENTRY_TRANSCOLORRER_685668977539818943: VariantsMap = [
    &["transcolorrer"],
    &["transcolourer"],
    &["transcolourer"],
    &["transcolourer"],
];

pub(crate) static ENTRY_TRANSCOLORREST_14875749018909758575: VariantsMap = [
    &["transcolorrest"],
    &["transcolourest"],
    &["transcolourest"],
    &["transcolourest"],
];

pub(crate) static ENTRY_TRANSCOLOR_14513330795644506999: VariantsMap = [
    &["transcolor"],
    &["transcolour"],
    &["transcolour"],
    &["transcolour"],
];

pub(crate) static ENTRY_TRANSISTORIZATIONS_14253078267757725459: VariantsMap = [
    &["transistorizations"],
    &["transistorisations"],
    &["transistorizations"],
    &["transistorisations"],
];

pub(crate) static ENTRY_TRANSISTORIZATION_2213289518183297786: VariantsMap = [
    &["transistorization"],
    &["transistorisation"],
    &["transistorization"],
    &["transistorisation"],
];

pub(crate) static ENTRY_TRANSISTORIZED_6257541205718300499: VariantsMap = [
    &["transistorized"],
    &["transistorised"],
    &["transistorized"],
    &["transistorised"],
];

pub(crate) static ENTRY_TRANSISTORIZES_5429831375135101974: VariantsMap = [
    &["transistorizes"],
    &["transistorises"],
    &["transistorizes"],
    &["transistorises"],
];

pub(crate) static ENTRY_TRANSISTORIZE_10887604825192662062: VariantsMap = [
    &["transistorize"],
    &["transistorise"],
    &["transistorize"],
    &["transistorise"],
];

pub(crate) static ENTRY_TRANSISTORIZING_15414761324720715044: VariantsMap = [
    &["transistorizing"],
    &["transistorising"],
    &["transistorizing"],
    &["transistorising"],
];

pub(crate) static ENTRY_TRANSPARENTIZES_428422769291744990: VariantsMap = [
    &["transparentizes"],
    &["transparentises"],
    &["transparentizes"],
    &["transparentises"],
];

pub(crate) static ENTRY_TRANSPARENTIZE_6759875278002638428: VariantsMap = [
    &["transparentize"],
    &["transparentise"],
    &["transparentize"],
    &["transparentise"],
];

pub(crate) static ENTRY_TRAUMATIZATIONS_4401483376475543285: VariantsMap = [
    &["traumatizations"],
    &["traumatisations"],
    &["traumatizations"],
    &["traumatisations"],
];

pub(crate) static ENTRY_TRAUMATIZATION_15736086621227074923: VariantsMap = [
    &["traumatization"],
    &["traumatisation"],
    &["traumatization"],
    &["traumatisation"],
];

pub(crate) static ENTRY_TRAUMATIZED_625907274700949941: VariantsMap = [
    &["traumatized"],
    &["traumatised"],
    &["traumatized"],
    &["traumatised"],
];

pub(crate) static ENTRY_TRAUMATIZES_1060950316018981423: VariantsMap = [
    &["traumatizes"],
    &["traumatises"],
    &["traumatizes"],
    &["traumatises"],
];

pub(crate) static ENTRY_TRAUMATIZE_7046895873965760654: VariantsMap = [
    &["traumatize"],
    &["traumatise"],
    &["traumatize"],
    &["traumatise"],
];

pub(crate) static ENTRY_TRAUMATIZING_11107301809578264309: VariantsMap = [
    &["traumatizing"],
    &["traumatising"],
    &["traumatizing"],
    &["traumatising"],
];

pub(crate) static ENTRY_TRAVELED_435534264813308465: VariantsMap = [
    &["traveled"],
    &["travelled"],
    &["travelled"],
    &["travelled"],
];

pub(crate) static ENTRY_TRAVELERS_16181301710981832055: VariantsMap = [
    &["travelers"],
    &["travellers"],
    &["travellers"],
    &["travellers"],
];

pub(crate) static ENTRY_TRAVELER_10167238839538419147: VariantsMap = [
    &["traveler"],
    &["traveller"],
    &["traveller"],
    &["traveller"],
];

pub(crate) static ENTRY_TRAVELINGS_6548611322609842336: VariantsMap = [
    &["travelings"],
    &["travellings"],
    &["travellings"],
    &["travellings"],
];

pub(crate) static ENTRY_TRAVELING_3424866904821184310: VariantsMap = [
    &["traveling"],
    &["travelling"],
    &["travelling"],
    &["travelling"],
];

pub(crate) static ENTRY_TRAVELOGUES_17520213145795989298: VariantsMap = [
    &["travelogues"],
    &["travelogues"],
    &["travelogues"],
    &["travelogues"],
];

pub(crate) static ENTRY_TRAVELOGUE_2518512371096354483: VariantsMap = [
    &["travelogue"],
    &["travelogue"],
    &["travelogue"],
    &["travelogue"],
];

pub(crate) static ENTRY_TRIALED_10369074344397465464: VariantsMap =
    [&["trialed"], &["trialled"], &["trialled"], &["trialled"]];

pub(crate) static ENTRY_TRIALING_1943354202061564251: VariantsMap = [
    &["trialing"],
    &["trialling"],
    &["trialling"],
    &["trialling"],
];

pub(crate) static ENTRY_TRIALIZATION_7429749590733864558: VariantsMap = [
    &["trialization"],
    &["trialisation"],
    &["trialization"],
    &["trialisation"],
];

pub(crate) static ENTRY_TRIANGULARIZATIONS_2847254552707906191: VariantsMap = [
    &["triangularizations"],
    &["triangularisations"],
    &["triangularizations"],
    &["triangularisations"],
];

pub(crate) static ENTRY_TRIANGULARIZATION_11880935622434099592: VariantsMap = [
    &["triangularization"],
    &["triangularisation"],
    &["triangularization"],
    &["triangularisation"],
];

pub(crate) static ENTRY_TRIANGULARIZED_316621578848709902: VariantsMap = [
    &["triangularized"],
    &["triangularised"],
    &["triangularized"],
    &["triangularised"],
];

pub(crate) static ENTRY_TRIANGULARIZES_16630166476295389567: VariantsMap = [
    &["triangularizes"],
    &["triangularises"],
    &["triangularizes"],
    &["triangularises"],
];

pub(crate) static ENTRY_TRIANGULARIZE_5069515505643652473: VariantsMap = [
    &["triangularize"],
    &["triangularise"],
    &["triangularize"],
    &["triangularise"],
];

pub(crate) static ENTRY_TRIANGULARIZING_7147507037724540086: VariantsMap = [
    &["triangularizing"],
    &["triangularising"],
    &["triangularizing"],
    &["triangularising"],
];

pub(crate) static ENTRY_TRICHINIZATIONS_13242264320111003982: VariantsMap = [
    &["trichinizations"],
    &["trichinisations"],
    &["trichinizations"],
    &["trichinisations"],
];

pub(crate) static ENTRY_TRICHINIZATION_12518130469368987248: VariantsMap = [
    &["trichinization"],
    &["trichinisation"],
    &["trichinization"],
    &["trichinisation"],
];

pub(crate) static ENTRY_TRICHINIZED_10756252058763715248: VariantsMap = [
    &["trichinized"],
    &["trichinised"],
    &["trichinized"],
    &["trichinised"],
];

pub(crate) static ENTRY_TRICHINIZES_6073383250924787697: VariantsMap = [
    &["trichinizes"],
    &["trichinises"],
    &["trichinizes"],
    &["trichinises"],
];

pub(crate) static ENTRY_TRICHINIZE_3923291936760431626: VariantsMap = [
    &["trichinize"],
    &["trichinise"],
    &["trichinize"],
    &["trichinise"],
];

pub(crate) static ENTRY_TRICHINIZING_2159439015116993657: VariantsMap = [
    &["trichinizing"],
    &["trichinising"],
    &["trichinizing"],
    &["trichinising"],
];

pub(crate) static ENTRY_TRICHLORETHYLENES_6072021734774211936: VariantsMap = [
    &["trichlorethylenes"],
    &["trichloroethylenes"],
    &["trichloroethylenes"],
    &["trichloroethylenes"],
];

pub(crate) static ENTRY_TRICHLORETHYLENE_1062872366464151876: VariantsMap = [
    &["trichlorethylene"],
    &["trichloroethylene"],
    &["trichloroethylene"],
    &["trichloroethylene"],
];

pub(crate) static ENTRY_TRICHOTOMIZED_9184703386860666893: VariantsMap = [
    &["trichotomized"],
    &["trichotomised"],
    &["trichotomized"],
    &["trichotomised"],
];

pub(crate) static ENTRY_TRICHOTOMIZES_12020126936108650104: VariantsMap = [
    &["trichotomizes"],
    &["trichotomises"],
    &["trichotomizes"],
    &["trichotomises"],
];

pub(crate) static ENTRY_TRICHOTOMIZE_15473320973771264574: VariantsMap = [
    &["trichotomize"],
    &["trichotomise"],
    &["trichotomize"],
    &["trichotomise"],
];

pub(crate) static ENTRY_TRICHOTOMIZING_8784936411896560417: VariantsMap = [
    &["trichotomizing"],
    &["trichotomising"],
    &["trichotomizing"],
    &["trichotomising"],
];

pub(crate) static ENTRY_TRICOLORED_12832711238932201350: VariantsMap = [
    &["tricolored"],
    &["tricoloured"],
    &["tricoloured"],
    &["tricoloured"],
];

pub(crate) static ENTRY_TRICOLORS_317578575228167243: VariantsMap = [
    &["tricolors"],
    &["tricolours"],
    &["tricolours"],
    &["tricolours"],
];

pub(crate) static ENTRY_TRICOLOR_6878353089897790870: VariantsMap = [
    &["tricolor"],
    &["tricolour"],
    &["tricolour"],
    &["tricolour"],
];

pub(crate) static ENTRY_TRIECIOUSLY_7922278146886669503: VariantsMap = [
    &["trieciously"],
    &["trioeciously"],
    &["trioeciously"],
    &["trioeciously"],
];

pub(crate) static ENTRY_TRIECIOUS_3842029489913770676: VariantsMap = [
    &["triecious"],
    &["trioecious"],
    &["trioecious"],
    &["trioecious"],
];

pub(crate) static ENTRY_TRIENE_598294200440119271: VariantsMap =
    [&["triene"], &["triaene"], &["triaene"], &["triaene"]];

pub(crate) static ENTRY_TRIFLUORIDE_17366033347483454107: VariantsMap = [
    &["trifluoride"],
    &["trifluouride"],
    &["trifluouride"],
    &["trifluouride"],
];

pub(crate) static ENTRY_TRILLIONIZES_13953946126184031801: VariantsMap = [
    &["trillionizes"],
    &["trillionises"],
    &["trillionizes"],
    &["trillionises"],
];

pub(crate) static ENTRY_TRILLIONIZE_4734097264302557230: VariantsMap = [
    &["trillionize"],
    &["trillionise"],
    &["trillionize"],
    &["trillionise"],
];

pub(crate) static ENTRY_TRIMERIZATIONS_10322066681410269501: VariantsMap = [
    &["trimerizations"],
    &["trimerisations"],
    &["trimerizations"],
    &["trimerisations"],
];

pub(crate) static ENTRY_TRIMERIZATION_12367654888953950560: VariantsMap = [
    &["trimerization"],
    &["trimerisation"],
    &["trimerization"],
    &["trimerisation"],
];

pub(crate) static ENTRY_TRIPYLEAN_1116498160287785389: VariantsMap = [
    &["tripylean"],
    &["tripylaean"],
    &["tripylaean"],
    &["tripylaean"],
];

pub(crate) static ENTRY_TRIVIALIZATIONS_17093718113863109033: VariantsMap = [
    &["trivializations"],
    &["trivialisations"],
    &["trivializations"],
    &["trivialisations"],
];

pub(crate) static ENTRY_TRIVIALIZATION_11133234604148815742: VariantsMap = [
    &["trivialization"],
    &["trivialisation"],
    &["trivialization"],
    &["trivialisation"],
];

pub(crate) static ENTRY_TRIVIALIZED_8435647137273948084: VariantsMap = [
    &["trivialized"],
    &["trivialised"],
    &["trivialized"],
    &["trivialised"],
];

pub(crate) static ENTRY_TRIVIALIZES_11774779970344017336: VariantsMap = [
    &["trivializes"],
    &["trivialises"],
    &["trivializes"],
    &["trivialises"],
];

pub(crate) static ENTRY_TRIVIALIZE_13642761010371027521: VariantsMap = [
    &["trivialize"],
    &["trivialise"],
    &["trivialize"],
    &["trivialise"],
];

pub(crate) static ENTRY_TRIVIALIZING_17871312244441571781: VariantsMap = [
    &["trivializing"],
    &["trivialising"],
    &["trivializing"],
    &["trivialising"],
];

pub(crate) static ENTRY_TROLLEYED_2326301207880015686: VariantsMap = [
    &["trolleyed"],
    &["trolleyed"],
    &["trolleyed"],
    &["trolleyed"],
];

pub(crate) static ENTRY_TROLLEYING_17091158982650946031: VariantsMap = [
    &["trolleying"],
    &["trolleying"],
    &["trolleying"],
    &["trolleying"],
];

pub(crate) static ENTRY_TROLLEYS_15846935468965102939: VariantsMap =
    [&["trolleys"], &["trolleys"], &["trolleys"], &["trolleys"]];

pub(crate) static ENTRY_TROLLEY_2675453022762314926: VariantsMap =
    [&["trolley"], &["trolley"], &["trolley"], &["trolley"]];

pub(crate) static ENTRY_TROPEOLIN_11129034624822593004: VariantsMap = [
    &["tropeolin"],
    &["tropaeolin"],
    &["tropaeolin"],
    &["tropaeolin"],
];

pub(crate) static ENTRY_TROPICALIZATIONS_3375832420561780384: VariantsMap = [
    &["tropicalizations"],
    &["tropicalisations"],
    &["tropicalizations"],
    &["tropicalisations"],
];

pub(crate) static ENTRY_TROPICALIZATION_18295465115231295361: VariantsMap = [
    &["tropicalization"],
    &["tropicalisation"],
    &["tropicalization"],
    &["tropicalisation"],
];

pub(crate) static ENTRY_TROPICALIZED_589331846440359754: VariantsMap = [
    &["tropicalized"],
    &["tropicalised"],
    &["tropicalized"],
    &["tropicalised"],
];

pub(crate) static ENTRY_TROPICALIZES_14959220215274917474: VariantsMap = [
    &["tropicalizes"],
    &["tropicalises"],
    &["tropicalizes"],
    &["tropicalises"],
];

pub(crate) static ENTRY_TROPICALIZE_7545317329361009163: VariantsMap = [
    &["tropicalize"],
    &["tropicalise"],
    &["tropicalize"],
    &["tropicalise"],
];

pub(crate) static ENTRY_TROPICALIZING_948054175332116966: VariantsMap = [
    &["tropicalizing"],
    &["tropicalising"],
    &["tropicalizing"],
    &["tropicalising"],
];

pub(crate) static ENTRY_TROWELED_16175988571968784498: VariantsMap = [
    &["troweled"],
    &["trowelled"],
    &["trowelled"],
    &["trowelled"],
];

pub(crate) static ENTRY_TROWELERS_4785737354793055182: VariantsMap = [
    &["trowelers"],
    &["trowellers"],
    &["trowellers"],
    &["trowellers"],
];

pub(crate) static ENTRY_TROWELER_2942313313867997998: VariantsMap = [
    &["troweler"],
    &["troweller"],
    &["troweller"],
    &["troweller"],
];

pub(crate) static ENTRY_TROWELING_8006341101894809093: VariantsMap = [
    &["troweling"],
    &["trowelling"],
    &["trowelling"],
    &["trowelling"],
];

pub(crate) static ENTRY_TRUBENIZED_13292664579470291193: VariantsMap = [
    &["trubenized"],
    &["trubenised"],
    &["trubenized"],
    &["trubenised"],
];

pub(crate) static ENTRY_TRUBENIZES_4849728788218049461: VariantsMap = [
    &["trubenizes"],
    &["trubenises"],
    &["trubenizes"],
    &["trubenises"],
];

pub(crate) static ENTRY_TRUBENIZE_3208348265396414813: VariantsMap = [
    &["trubenize"],
    &["trubenise"],
    &["trubenize"],
    &["trubenise"],
];

pub(crate) static ENTRY_TRUBENIZING_6908243337876686290: VariantsMap = [
    &["trubenizing"],
    &["trubenising"],
    &["trubenizing"],
    &["trubenising"],
];

pub(crate) static ENTRY_TRYPSINIZES_16656487916141363425: VariantsMap = [
    &["trypsinizes"],
    &["trypsinises"],
    &["trypsinizes"],
    &["trypsinises"],
];

pub(crate) static ENTRY_TRYPSINIZE_10045098514426963634: VariantsMap = [
    &["trypsinize"],
    &["trypsinise"],
    &["trypsinize"],
    &["trypsinise"],
];

pub(crate) static ENTRY_TSORIS_4355452546295467104: VariantsMap =
    [&["tsoris"], &["tsouris"], &["tsouris"], &["tsouris"]];

pub(crate) static ENTRY_TUBERCULARIZATION_16282213177072308407: VariantsMap = [
    &["tubercularization"],
    &["tubercularisation"],
    &["tubercularization"],
    &["tubercularisation"],
];

pub(crate) static ENTRY_TUBERCULARIZED_12127734432961771885: VariantsMap = [
    &["tubercularized"],
    &["tubercularised"],
    &["tubercularized"],
    &["tubercularised"],
];

pub(crate) static ENTRY_TUBERCULARIZE_375454583803761936: VariantsMap = [
    &["tubercularize"],
    &["tubercularise"],
    &["tubercularize"],
    &["tubercularise"],
];

pub(crate) static ENTRY_TUBERCULARIZING_11598479791968421505: VariantsMap = [
    &["tubercularizing"],
    &["tubercularising"],
    &["tubercularizing"],
    &["tubercularising"],
];

pub(crate) static ENTRY_TUBERCULINIZATIONS_11324544919726547747: VariantsMap = [
    &["tuberculinizations"],
    &["tuberculinisations"],
    &["tuberculinizations"],
    &["tuberculinisations"],
];

pub(crate) static ENTRY_TUBERCULINIZATION_16825164027674017455: VariantsMap = [
    &["tuberculinization"],
    &["tuberculinisation"],
    &["tuberculinization"],
    &["tuberculinisation"],
];

pub(crate) static ENTRY_TUBERCULINIZED_3468601096407728731: VariantsMap = [
    &["tuberculinized"],
    &["tuberculinised"],
    &["tuberculinized"],
    &["tuberculinised"],
];

pub(crate) static ENTRY_TUBERCULINIZES_17100839746190670900: VariantsMap = [
    &["tuberculinizes"],
    &["tuberculinises"],
    &["tuberculinizes"],
    &["tuberculinises"],
];

pub(crate) static ENTRY_TUBERCULINIZE_3111780340548733278: VariantsMap = [
    &["tuberculinize"],
    &["tuberculinise"],
    &["tuberculinize"],
    &["tuberculinise"],
];

pub(crate) static ENTRY_TUBERCULINIZING_7306410957129592563: VariantsMap = [
    &["tuberculinizing"],
    &["tuberculinising"],
    &["tuberculinizing"],
    &["tuberculinising"],
];

pub(crate) static ENTRY_TUBERCULIZATIONS_7601410696098087935: VariantsMap = [
    &["tuberculizations"],
    &["tuberculisations"],
    &["tuberculizations"],
    &["tuberculisations"],
];

pub(crate) static ENTRY_TUBERCULIZATION_9178477451489860203: VariantsMap = [
    &["tuberculization"],
    &["tuberculisation"],
    &["tuberculization"],
    &["tuberculisation"],
];

pub(crate) static ENTRY_TUBERCULIZED_17282098119918700945: VariantsMap = [
    &["tuberculized"],
    &["tuberculised"],
    &["tuberculized"],
    &["tuberculised"],
];

pub(crate) static ENTRY_TUBERCULIZES_15600354817268651196: VariantsMap = [
    &["tuberculizes"],
    &["tuberculises"],
    &["tuberculizes"],
    &["tuberculises"],
];

pub(crate) static ENTRY_TUBERCULIZE_13543988884309523486: VariantsMap = [
    &["tuberculize"],
    &["tuberculise"],
    &["tuberculize"],
    &["tuberculise"],
];

pub(crate) static ENTRY_TUBERCULIZING_15007965539279942136: VariantsMap = [
    &["tuberculizing"],
    &["tuberculising"],
    &["tuberculizing"],
    &["tuberculising"],
];

pub(crate) static ENTRY_TUBERIZATIONS_436245966155449153: VariantsMap = [
    &["tuberizations"],
    &["tuberisations"],
    &["tuberizations"],
    &["tuberisations"],
];

pub(crate) static ENTRY_TUBERIZATION_18013492797265472869: VariantsMap = [
    &["tuberization"],
    &["tuberisation"],
    &["tuberization"],
    &["tuberisation"],
];

pub(crate) static ENTRY_TUBERIZES_8957289704531228507: VariantsMap = [
    &["tuberizes"],
    &["tuberises"],
    &["tuberizes"],
    &["tuberises"],
];

pub(crate) static ENTRY_TUBERIZE_13289124791090367946: VariantsMap =
    [&["tuberize"], &["tuberise"], &["tuberize"], &["tuberise"]];

pub(crate) static ENTRY_TUBULIZATIONS_7424978890605027489: VariantsMap = [
    &["tubulizations"],
    &["tubulisations"],
    &["tubulizations"],
    &["tubulisations"],
];

pub(crate) static ENTRY_TUBULIZATION_7106526619239771563: VariantsMap = [
    &["tubulization"],
    &["tubulisation"],
    &["tubulization"],
    &["tubulisation"],
];

pub(crate) static ENTRY_TULAREMIAS_3114003671274129745: VariantsMap = [
    &["tularemias"],
    &["tularaemias"],
    &["tularemias"],
    &["tularaemias"],
];

pub(crate) static ENTRY_TULAREMIA_15946480059849647392: VariantsMap = [
    &["tularemia"],
    &["tularaemia"],
    &["tularemia"],
    &["tularaemia"],
];

pub(crate) static ENTRY_TULAREMIC_3583808281242513322: VariantsMap = [
    &["tularemic"],
    &["tularaemic"],
    &["tularaemic"],
    &["tularaemic"],
];

pub(crate) static ENTRY_TUMORED_16843203498038722198: VariantsMap =
    [&["tumored"], &["tumoured"], &["tumoured"], &["tumoured"]];

pub(crate) static ENTRY_TUMORS_823212688865744384: VariantsMap =
    [&["tumors"], &["tumours"], &["tumours"], &["tumours"]];

pub(crate) static ENTRY_TUMOR_18208195035577206669: VariantsMap =
    [&["tumor"], &["tumour"], &["tumour"], &["tumour"]];

pub(crate) static ENTRY_TUNNELED_11370086013695475785: VariantsMap = [
    &["tunneled"],
    &["tunnelled"],
    &["tunnelled"],
    &["tunnelled"],
];

pub(crate) static ENTRY_TUNNELERS_17425429561485837672: VariantsMap = [
    &["tunnelers"],
    &["tunnellers"],
    &["tunnellers"],
    &["tunnellers"],
];

pub(crate) static ENTRY_TUNNELER_14964877288873936262: VariantsMap = [
    &["tunneler"],
    &["tunneller"],
    &["tunneller"],
    &["tunneller"],
];

pub(crate) static ENTRY_TUNNELINGS_14406089909159685424: VariantsMap = [
    &["tunnelings"],
    &["tunnellings"],
    &["tunnellings"],
    &["tunnellings"],
];

pub(crate) static ENTRY_TUNNELING_8449736644402875370: VariantsMap = [
    &["tunneling"],
    &["tunnelling"],
    &["tunnelling"],
    &["tunnelling"],
];

pub(crate) static ENTRY_TURDINE_10805567808377549809: VariantsMap =
    [&["turdine"], &["turdinae"], &["turdinae"], &["turdinae"]];

pub(crate) static ENTRY_TURKICIZED_18091702444540416526: VariantsMap = [
    &["turkicized"],
    &["turkicised"],
    &["turkicized"],
    &["turkicised"],
];

pub(crate) static ENTRY_TURKICIZES_12157500324270664376: VariantsMap = [
    &["turkicizes"],
    &["turkicises"],
    &["turkicizes"],
    &["turkicises"],
];

pub(crate) static ENTRY_TURKICIZE_11200064558982110888: VariantsMap = [
    &["turkicize"],
    &["turkicise"],
    &["turkicize"],
    &["turkicise"],
];

pub(crate) static ENTRY_TURKICIZING_15914584795237502956: VariantsMap = [
    &["turkicizing"],
    &["turkicising"],
    &["turkicizing"],
    &["turkicising"],
];

pub(crate) static ENTRY_TURKIZES_12975476878808536800: VariantsMap =
    [&["turkizes"], &["turkises"], &["turkizes"], &["turkises"]];

pub(crate) static ENTRY_TURKIZE_9146975708135188734: VariantsMap =
    [&["turkize"], &["turkise"], &["turkize"], &["turkise"]];

pub(crate) static ENTRY_TUSCANIZES_17789792843875455131: VariantsMap = [
    &["tuscanizes"],
    &["tuscanises"],
    &["tuscanizes"],
    &["tuscanises"],
];

pub(crate) static ENTRY_TUSCANIZE_2884073206787212893: VariantsMap = [
    &["tuscanize"],
    &["tuscanise"],
    &["tuscanize"],
    &["tuscanise"],
];

pub(crate) static ENTRY_TUTELE_12348649899581353745: VariantsMap =
    [&["tutele"], &["tutelae"], &["tutelae"], &["tutelae"]];

pub(crate) static ENTRY_TUTORIZATIONS_15234613627004287155: VariantsMap = [
    &["tutorizations"],
    &["tutorisations"],
    &["tutorizations"],
    &["tutorisations"],
];

pub(crate) static ENTRY_TUTORIZATION_4877249596838258085: VariantsMap = [
    &["tutorization"],
    &["tutorisation"],
    &["tutorization"],
    &["tutorisation"],
];

pub(crate) static ENTRY_TUTORIZED_12837178324286735725: VariantsMap = [
    &["tutorized"],
    &["tutorised"],
    &["tutorized"],
    &["tutorised"],
];

pub(crate) static ENTRY_TUTORIZES_17326633325460663696: VariantsMap = [
    &["tutorizes"],
    &["tutorises"],
    &["tutorizes"],
    &["tutorises"],
];

pub(crate) static ENTRY_TUTORIZE_6972247317790274058: VariantsMap =
    [&["tutorize"], &["tutorise"], &["tutorize"], &["tutorise"]];

pub(crate) static ENTRY_TUTORIZING_1794860608282634904: VariantsMap = [
    &["tutorizing"],
    &["tutorising"],
    &["tutorizing"],
    &["tutorising"],
];

pub(crate) static ENTRY_TWIERS_16061495920010970718: VariantsMap =
    [&["twiers"], &["twires"], &["twires"], &["twires"]];

pub(crate) static ENTRY_TWIER_15217813909340355710: VariantsMap =
    [&["twier"], &["twire"], &["twire"], &["twire"]];

pub(crate) static ENTRY_TYLERIZES_14012127742705433613: VariantsMap = [
    &["tylerizes"],
    &["tylerises"],
    &["tylerizes"],
    &["tylerises"],
];

pub(crate) static ENTRY_TYLERIZE_17929226921575671617: VariantsMap =
    [&["tylerize"], &["tylerise"], &["tylerize"], &["tylerise"]];

pub(crate) static ENTRY_TYPHEMIA_10653684295720787141: VariantsMap = [
    &["typhemia"],
    &["typhoemia"],
    &["typhoemia"],
    &["typhoemia"],
];

pub(crate) static ENTRY_TYPHEMIA_11619953963433812261: VariantsMap = [
    &["typhemia"],
    &["typhaemia"],
    &["typhaemia"],
    &["typhaemia"],
];

pub(crate) static ENTRY_TYPHLENTERITIS_2891708862956049172: VariantsMap = [
    &["typhlenteritis"],
    &["typhloenteritis"],
    &["typhloenteritis"],
    &["typhloenteritis"],
];

pub(crate) static ENTRY_TYPHOEMIA_10411131729213561042: VariantsMap = [
    &["typhoemia"],
    &["typhoaemia"],
    &["typhoaemia"],
    &["typhoaemia"],
];

pub(crate) static ENTRY_TYRANNIZED_10508710200970438760: VariantsMap = [
    &["tyrannized"],
    &["tyrannised"],
    &["tyrannized"],
    &["tyrannised"],
];

pub(crate) static ENTRY_TYRANNIZERS_17260544957894670455: VariantsMap = [
    &["tyrannizers"],
    &["tyrannisers"],
    &["tyrannizers"],
    &["tyrannisers"],
];

pub(crate) static ENTRY_TYRANNIZER_1819969736083775933: VariantsMap = [
    &["tyrannizer"],
    &["tyranniser"],
    &["tyrannizer"],
    &["tyranniser"],
];

pub(crate) static ENTRY_TYRANNIZES_9564723788181665646: VariantsMap = [
    &["tyrannizes"],
    &["tyrannises"],
    &["tyrannizes"],
    &["tyrannises"],
];

pub(crate) static ENTRY_TYRANNIZE_1000053221538931404: VariantsMap = [
    &["tyrannize"],
    &["tyrannise"],
    &["tyrannize"],
    &["tyrannise"],
];

pub(crate) static ENTRY_TYRANNIZINGLIER_1267872557850447455: VariantsMap = [
    &["tyrannizinglier"],
    &["tyrannisinglier"],
    &["tyrannizinglier"],
    &["tyrannisinglier"],
];

pub(crate) static ENTRY_TYRANNIZINGLIEST_6866185442199362789: VariantsMap = [
    &["tyrannizingliest"],
    &["tyrannisingliest"],
    &["tyrannizingliest"],
    &["tyrannisingliest"],
];

pub(crate) static ENTRY_TYRANNIZINGLY_3301246314614084531: VariantsMap = [
    &["tyrannizingly"],
    &["tyrannisingly"],
    &["tyrannizingly"],
    &["tyrannisingly"],
];

pub(crate) static ENTRY_TYRANNIZINGS_338643871377770319: VariantsMap = [
    &["tyrannizings"],
    &["tyrannisings"],
    &["tyrannizings"],
    &["tyrannisings"],
];

pub(crate) static ENTRY_TYRANNIZING_1392868749194607551: VariantsMap = [
    &["tyrannizing"],
    &["tyrannising"],
    &["tyrannizing"],
    &["tyrannising"],
];

pub(crate) static ENTRY_TYROS_10684341243330634223: VariantsMap =
    [&["tyros"], &["tyros"], &["tyros"], &["tyros"]];

pub(crate) static ENTRY_TYRO_1794051950789040929: VariantsMap =
    [&["tyro"], &["tyro"], &["tyro"], &["tyro"]];

pub(crate) static ENTRY_ULTRACENTRALIZERS_9421251802721659846: VariantsMap = [
    &["ultracentralizers"],
    &["ultracentralisers"],
    &["ultracentralizers"],
    &["ultracentralisers"],
];

pub(crate) static ENTRY_ULTRACENTRALIZER_1110134519737018003: VariantsMap = [
    &["ultracentralizer"],
    &["ultracentraliser"],
    &["ultracentralizer"],
    &["ultracentraliser"],
];

pub(crate) static ENTRY_ULTRAHONORABLES_7561547150076074006: VariantsMap = [
    &["ultrahonorables"],
    &["ultrahonourables"],
    &["ultrahonourables"],
    &["ultrahonourables"],
];

pub(crate) static ENTRY_ULTRAHONORABLE_2858828412730743831: VariantsMap = [
    &["ultrahonorable"],
    &["ultrahonourable"],
    &["ultrahonourable"],
    &["ultrahonourable"],
];

pub(crate) static ENTRY_ULTRASPECIALIZATIONS_5732795204754657259: VariantsMap = [
    &["ultraspecializations"],
    &["ultraspecialisations"],
    &["ultraspecializations"],
    &["ultraspecialisations"],
];

pub(crate) static ENTRY_ULTRASPECIALIZATION_8391905615350246381: VariantsMap = [
    &["ultraspecialization"],
    &["ultraspecialisation"],
    &["ultraspecialization"],
    &["ultraspecialisation"],
];

pub(crate) static ENTRY_ULTRASTANDARDIZATIONS_8293107802581753490: VariantsMap = [
    &["ultrastandardizations"],
    &["ultrastandardisations"],
    &["ultrastandardizations"],
    &["ultrastandardisations"],
];

pub(crate) static ENTRY_ULTRASTANDARDIZATION_16460010141823176416: VariantsMap = [
    &["ultrastandardization"],
    &["ultrastandardisation"],
    &["ultrastandardization"],
    &["ultrastandardisation"],
];

pub(crate) static ENTRY_UNACCLIMATIZED_14600148678249666016: VariantsMap = [
    &["unacclimatized"],
    &["unacclimatised"],
    &["unacclimatized"],
    &["unacclimatised"],
];

pub(crate) static ENTRY_UNAGONIZE_3985839663605404087: VariantsMap = [
    &["unagonize"],
    &["unagonise"],
    &["unagonize"],
    &["unagonise"],
];

pub(crate) static ENTRY_UNALCOHOLIZEDDER_13026382719695767769: VariantsMap = [
    &["unalcoholizedder"],
    &["unalcoholisedder"],
    &["unalcoholizedder"],
    &["unalcoholisedder"],
];

pub(crate) static ENTRY_UNALCOHOLIZEDDEST_17661502425886015635: VariantsMap = [
    &["unalcoholizeddest"],
    &["unalcoholiseddest"],
    &["unalcoholizeddest"],
    &["unalcoholiseddest"],
];

pub(crate) static ENTRY_UNALCOHOLIZEDS_12566648296272969844: VariantsMap = [
    &["unalcoholizeds"],
    &["unalcoholiseds"],
    &["unalcoholizeds"],
    &["unalcoholiseds"],
];

pub(crate) static ENTRY_UNALCOHOLIZED_7475486806446169449: VariantsMap = [
    &["unalcoholized"],
    &["unalcoholised"],
    &["unalcoholized"],
    &["unalcoholised"],
];

pub(crate) static ENTRY_UNALPHABETIZED_12264077727491901794: VariantsMap = [
    &["unalphabetized"],
    &["unalphabetised"],
    &["unalphabetized"],
    &["unalphabetised"],
];

pub(crate) static ENTRY_UNAMORTIZATIONS_7833890650778444360: VariantsMap = [
    &["unamortizations"],
    &["unamortisations"],
    &["unamortizations"],
    &["unamortisations"],
];

pub(crate) static ENTRY_UNAMORTIZATION_9895086701973992419: VariantsMap = [
    &["unamortization"],
    &["unamortisation"],
    &["unamortization"],
    &["unamortisation"],
];

pub(crate) static ENTRY_UNAMORTIZED_11972025435236260926: VariantsMap = [
    &["unamortized"],
    &["unamortised"],
    &["unamortized"],
    &["unamortised"],
];

pub(crate) static ENTRY_UNANALYZABLE_10185255751864420777: VariantsMap = [
    &["unanalyzable"],
    &["unanalysable"],
    &["unanalyzable"],
    &["unanalysable"],
];

pub(crate) static ENTRY_UNANALYZED_17631303651139984908: VariantsMap = [
    &["unanalyzed"],
    &["unanalysed"],
    &["unanalyzed"],
    &["unanalysed"],
];

pub(crate) static ENTRY_UNANATOMIZABLE_11481192287759636901: VariantsMap = [
    &["unanatomizable"],
    &["unanatomisable"],
    &["unanatomizable"],
    &["unanatomisable"],
];

pub(crate) static ENTRY_UNANATOMIZED_5758539222957914530: VariantsMap = [
    &["unanatomized"],
    &["unanatomised"],
    &["unanatomized"],
    &["unanatomised"],
];

pub(crate) static ENTRY_UNANEMIC_4893591374506498656: VariantsMap = [
    &["unanemic"],
    &["unanaemic"],
    &["unanaemic"],
    &["unanaemic"],
];

pub(crate) static ENTRY_UNANIMALIZEDS_2714346462835359758: VariantsMap = [
    &["unanimalizeds"],
    &["unanimaliseds"],
    &["unanimalizeds"],
    &["unanimaliseds"],
];

pub(crate) static ENTRY_UNANIMALIZED_17517705032004401767: VariantsMap = [
    &["unanimalized"],
    &["unanimalised"],
    &["unanimalized"],
    &["unanimalised"],
];

pub(crate) static ENTRY_UNANTAGONIZABLER_1805720993301381014: VariantsMap = [
    &["unantagonizabler"],
    &["unantagonisabler"],
    &["unantagonizabler"],
    &["unantagonisabler"],
];

pub(crate) static ENTRY_UNANTAGONIZABLEST_3735825461795500564: VariantsMap = [
    &["unantagonizablest"],
    &["unantagonisablest"],
    &["unantagonizablest"],
    &["unantagonisablest"],
];

pub(crate) static ENTRY_UNANTAGONIZABLES_18175548170494914576: VariantsMap = [
    &["unantagonizables"],
    &["unantagonisables"],
    &["unantagonizables"],
    &["unantagonisables"],
];

pub(crate) static ENTRY_UNANTAGONIZABLE_4447516271806860740: VariantsMap = [
    &["unantagonizable"],
    &["unantagonisable"],
    &["unantagonizable"],
    &["unantagonisable"],
];

pub(crate) static ENTRY_UNANTAGONIZEDDER_18165233424269243283: VariantsMap = [
    &["unantagonizedder"],
    &["unantagonisedder"],
    &["unantagonizedder"],
    &["unantagonisedder"],
];

pub(crate) static ENTRY_UNANTAGONIZEDDEST_5550155987501146316: VariantsMap = [
    &["unantagonizeddest"],
    &["unantagoniseddest"],
    &["unantagonizeddest"],
    &["unantagoniseddest"],
];

pub(crate) static ENTRY_UNANTAGONIZED_5216901107304039571: VariantsMap = [
    &["unantagonized"],
    &["unantagonised"],
    &["unantagonized"],
    &["unantagonised"],
];

pub(crate) static ENTRY_UNANTAGONIZINGER_13162794461334815421: VariantsMap = [
    &["unantagonizinger"],
    &["unantagonisinger"],
    &["unantagonizinger"],
    &["unantagonisinger"],
];

pub(crate) static ENTRY_UNANTAGONIZINGEST_1520014316091664854: VariantsMap = [
    &["unantagonizingest"],
    &["unantagonisingest"],
    &["unantagonizingest"],
    &["unantagonisingest"],
];

pub(crate) static ENTRY_UNANTAGONIZING_9261939565808222087: VariantsMap = [
    &["unantagonizing"],
    &["unantagonising"],
    &["unantagonizing"],
    &["unantagonising"],
];

pub(crate) static ENTRY_UNAPOLOGIZING_8023597989278305648: VariantsMap = [
    &["unapologizing"],
    &["unapologising"],
    &["unapologizing"],
    &["unapologising"],
];

pub(crate) static ENTRY_UNAPOSTATIZEDS_16772014085952263940: VariantsMap = [
    &["unapostatizeds"],
    &["unapostatiseds"],
    &["unapostatizeds"],
    &["unapostatiseds"],
];

pub(crate) static ENTRY_UNAPOSTATIZED_7778978492175304009: VariantsMap = [
    &["unapostatized"],
    &["unapostatised"],
    &["unapostatized"],
    &["unapostatised"],
];

pub(crate) static ENTRY_UNAPPETIZINGER_8263527658294102086: VariantsMap = [
    &["unappetizinger"],
    &["unappetisinger"],
    &["unappetizinger"],
    &["unappetisinger"],
];

pub(crate) static ENTRY_UNAPPETIZINGEST_10792936073593456042: VariantsMap = [
    &["unappetizingest"],
    &["unappetisingest"],
    &["unappetizingest"],
    &["unappetisingest"],
];

pub(crate) static ENTRY_UNAPPETIZINGLIER_5664751833539432448: VariantsMap = [
    &["unappetizinglier"],
    &["unappetisinglier"],
    &["unappetizinglier"],
    &["unappetisinglier"],
];

pub(crate) static ENTRY_UNAPPETIZINGLIEST_17210870251486801769: VariantsMap = [
    &["unappetizingliest"],
    &["unappetisingliest"],
    &["unappetizingliest"],
    &["unappetisingliest"],
];

pub(crate) static ENTRY_UNAPPETIZINGLY_3201479097994435826: VariantsMap = [
    &["unappetizingly"],
    &["unappetisingly"],
    &["unappetizingly"],
    &["unappetisingly"],
];

pub(crate) static ENTRY_UNAPPETIZING_17929454627207091337: VariantsMap = [
    &["unappetizing"],
    &["unappetising"],
    &["unappetizing"],
    &["unappetising"],
];

pub(crate) static ENTRY_UNAPPRIZED_6163150503750732162: VariantsMap = [
    &["unapprized"],
    &["unapprised"],
    &["unapprized"],
    &["unapprised"],
];

pub(crate) static ENTRY_UNARBORED_10184848105069432838: VariantsMap = [
    &["unarbored"],
    &["unarboured"],
    &["unarboured"],
    &["unarboured"],
];

pub(crate) static ENTRY_UNARMOREDDER_4492879592434092039: VariantsMap = [
    &["unarmoredder"],
    &["unarmouredder"],
    &["unarmouredder"],
    &["unarmouredder"],
];

pub(crate) static ENTRY_UNARMOREDDEST_5729736686969793724: VariantsMap = [
    &["unarmoreddest"],
    &["unarmoureddest"],
    &["unarmoureddest"],
    &["unarmoureddest"],
];

pub(crate) static ENTRY_UNARMORED_2648707804512127765: VariantsMap = [
    &["unarmored"],
    &["unarmoured"],
    &["unarmoured"],
    &["unarmoured"],
];

pub(crate) static ENTRY_UNAUTHORIZEDDER_6601639422567613002: VariantsMap = [
    &["unauthorizedder"],
    &["unauthorisedder"],
    &["unauthorizedder"],
    &["unauthorisedder"],
];

pub(crate) static ENTRY_UNAUTHORIZEDDEST_4803048533625012750: VariantsMap = [
    &["unauthorizeddest"],
    &["unauthoriseddest"],
    &["unauthorizeddest"],
    &["unauthoriseddest"],
];

pub(crate) static ENTRY_UNAUTHORIZEDLY_10077114453746645352: VariantsMap = [
    &["unauthorizedly"],
    &["unauthorisedly"],
    &["unauthorizedly"],
    &["unauthorisedly"],
];

pub(crate) static ENTRY_UNAUTHORIZEDNESS_6472820454762316069: VariantsMap = [
    &["unauthorizedness"],
    &["unauthorisedness"],
    &["unauthorizedness"],
    &["unauthorisedness"],
];

pub(crate) static ENTRY_UNAUTHORIZED_1030895852257832941: VariantsMap = [
    &["unauthorized"],
    &["unauthorised"],
    &["unauthorized"],
    &["unauthorised"],
];

pub(crate) static ENTRY_UNAUTHORIZES_17588435880504437850: VariantsMap = [
    &["unauthorizes"],
    &["unauthorises"],
    &["unauthorizes"],
    &["unauthorises"],
];

pub(crate) static ENTRY_UNAUTHORIZE_1583120497916853288: VariantsMap = [
    &["unauthorize"],
    &["unauthorise"],
    &["unauthorize"],
    &["unauthorise"],
];

pub(crate) static ENTRY_UNBAPTIZED_7114930556734248374: VariantsMap = [
    &["unbaptized"],
    &["unbaptised"],
    &["unbaptized"],
    &["unbaptised"],
];

pub(crate) static ENTRY_UNBAPTIZES_10354617340461951966: VariantsMap = [
    &["unbaptizes"],
    &["unbaptises"],
    &["unbaptizes"],
    &["unbaptises"],
];

pub(crate) static ENTRY_UNBAPTIZE_2007112232120526430: VariantsMap = [
    &["unbaptize"],
    &["unbaptise"],
    &["unbaptize"],
    &["unbaptise"],
];

pub(crate) static ENTRY_UNBAPTIZING_8254180624736921315: VariantsMap = [
    &["unbaptizing"],
    &["unbaptising"],
    &["unbaptizing"],
    &["unbaptising"],
];

pub(crate) static ENTRY_UNBARBARIZED_4841774978519823120: VariantsMap = [
    &["unbarbarized"],
    &["unbarbarised"],
    &["unbarbarized"],
    &["unbarbarised"],
];

pub(crate) static ENTRY_UNBARBARIZE_18442703460791352976: VariantsMap = [
    &["unbarbarize"],
    &["unbarbarise"],
    &["unbarbarize"],
    &["unbarbarise"],
];

pub(crate) static ENTRY_UNBARBARIZING_7934844739514827618: VariantsMap = [
    &["unbarbarizing"],
    &["unbarbarising"],
    &["unbarbarizing"],
    &["unbarbarising"],
];

pub(crate) static ENTRY_UNBARRICADED_6576411157510102243: VariantsMap = [
    &["unbarricaded"],
    &["unbarricadoed"],
    &["unbarricadoed"],
    &["unbarricadoed"],
];

pub(crate) static ENTRY_UNBASTARDIZEDDER_394854340525866069: VariantsMap = [
    &["unbastardizedder"],
    &["unbastardisedder"],
    &["unbastardizedder"],
    &["unbastardisedder"],
];

pub(crate) static ENTRY_UNBASTARDIZEDDEST_14646212897935089229: VariantsMap = [
    &["unbastardizeddest"],
    &["unbastardiseddest"],
    &["unbastardizeddest"],
    &["unbastardiseddest"],
];

pub(crate) static ENTRY_UNBASTARDIZED_3379280974151775201: VariantsMap = [
    &["unbastardized"],
    &["unbastardised"],
    &["unbastardized"],
    &["unbastardised"],
];

pub(crate) static ENTRY_UNBRUTALIZED_1523087329944301575: VariantsMap = [
    &["unbrutalized"],
    &["unbrutalised"],
    &["unbrutalized"],
    &["unbrutalised"],
];

pub(crate) static ENTRY_UNBRUTALIZES_5482040690111908246: VariantsMap = [
    &["unbrutalizes"],
    &["unbrutalises"],
    &["unbrutalizes"],
    &["unbrutalises"],
];

pub(crate) static ENTRY_UNBRUTALIZE_17065857289068718766: VariantsMap = [
    &["unbrutalize"],
    &["unbrutalise"],
    &["unbrutalize"],
    &["unbrutalise"],
];

pub(crate) static ENTRY_UNBRUTALIZING_6665598309600919361: VariantsMap = [
    &["unbrutalizing"],
    &["unbrutalising"],
    &["unbrutalizing"],
    &["unbrutalising"],
];

pub(crate) static ENTRY_UNBRUTIZED_13887610461628810713: VariantsMap = [
    &["unbrutized"],
    &["unbrutised"],
    &["unbrutized"],
    &["unbrutised"],
];

pub(crate) static ENTRY_UNBRUTIZES_8490136628242832874: VariantsMap = [
    &["unbrutizes"],
    &["unbrutises"],
    &["unbrutizes"],
    &["unbrutises"],
];

pub(crate) static ENTRY_UNBRUTIZE_8757257384632965724: VariantsMap = [
    &["unbrutize"],
    &["unbrutise"],
    &["unbrutize"],
    &["unbrutise"],
];

pub(crate) static ENTRY_UNBRUTIZING_806322460612871582: VariantsMap = [
    &["unbrutizing"],
    &["unbrutising"],
    &["unbrutizing"],
    &["unbrutising"],
];

pub(crate) static ENTRY_UNCANCELEDDER_1822139248734979732: VariantsMap = [
    &["uncanceledder"],
    &["uncancelledder"],
    &["uncancelledder"],
    &["uncancelledder"],
];

pub(crate) static ENTRY_UNCANCELEDDEST_2175636256977122000: VariantsMap = [
    &["uncanceleddest"],
    &["uncancelleddest"],
    &["uncancelleddest"],
    &["uncancelleddest"],
];

pub(crate) static ENTRY_UNCANCELED_10644523307563396416: VariantsMap = [
    &["uncanceled"],
    &["uncancelled"],
    &["uncancelled"],
    &["uncancelled"],
];

pub(crate) static ENTRY_UNCANDOR_5207953205214088481: VariantsMap = [
    &["uncandor"],
    &["uncandour"],
    &["uncandour"],
    &["uncandour"],
];

pub(crate) static ENTRY_UNCANONIZATION_2201545706272739551: VariantsMap = [
    &["uncanonization"],
    &["uncanonisation"],
    &["uncanonization"],
    &["uncanonisation"],
];

pub(crate) static ENTRY_UNCANONIZED_14726062427399498221: VariantsMap = [
    &["uncanonized"],
    &["uncanonised"],
    &["uncanonized"],
    &["uncanonised"],
];

pub(crate) static ENTRY_UNCANONIZES_9447116594202466407: VariantsMap = [
    &["uncanonizes"],
    &["uncanonises"],
    &["uncanonizes"],
    &["uncanonises"],
];

pub(crate) static ENTRY_UNCANONIZE_14994860079175039706: VariantsMap = [
    &["uncanonize"],
    &["uncanonise"],
    &["uncanonize"],
    &["uncanonise"],
];

pub(crate) static ENTRY_UNCANONIZING_4301993812611231009: VariantsMap = [
    &["uncanonizing"],
    &["uncanonising"],
    &["uncanonizing"],
    &["uncanonising"],
];

pub(crate) static ENTRY_UNCANTONIZEDS_10622385437791373383: VariantsMap = [
    &["uncantonizeds"],
    &["uncantoniseds"],
    &["uncantonizeds"],
    &["uncantoniseds"],
];

pub(crate) static ENTRY_UNCANTONIZED_3780031636037658309: VariantsMap = [
    &["uncantonized"],
    &["uncantonised"],
    &["uncantonized"],
    &["uncantonised"],
];

pub(crate) static ENTRY_UNCAPITALIZEDDER_15898505255980224646: VariantsMap = [
    &["uncapitalizedder"],
    &["uncapitalisedder"],
    &["uncapitalizedder"],
    &["uncapitalisedder"],
];

pub(crate) static ENTRY_UNCAPITALIZEDDEST_5510422959972350228: VariantsMap = [
    &["uncapitalizeddest"],
    &["uncapitaliseddest"],
    &["uncapitalizeddest"],
    &["uncapitaliseddest"],
];

pub(crate) static ENTRY_UNCAPITALIZED_6472912780712347860: VariantsMap = [
    &["uncapitalized"],
    &["uncapitalised"],
    &["uncapitalized"],
    &["uncapitalised"],
];

pub(crate) static ENTRY_UNCARAMELIZED_5424340709113979062: VariantsMap = [
    &["uncaramelized"],
    &["uncaramelised"],
    &["uncaramelized"],
    &["uncaramelised"],
];

pub(crate) static ENTRY_UNCATECHIZEDNESS_4331333175951017514: VariantsMap = [
    &["uncatechizedness"],
    &["uncatechisedness"],
    &["uncatechizedness"],
    &["uncatechisedness"],
];

pub(crate) static ENTRY_UNCATECHIZEDS_18151531885968775832: VariantsMap = [
    &["uncatechizeds"],
    &["uncatechiseds"],
    &["uncatechizeds"],
    &["uncatechiseds"],
];

pub(crate) static ENTRY_UNCATECHIZED_471552697184504321: VariantsMap = [
    &["uncatechized"],
    &["uncatechised"],
    &["uncatechized"],
    &["uncatechised"],
];

pub(crate) static ENTRY_UNCATEGORIZEDDER_10884232809970429610: VariantsMap = [
    &["uncategorizedder"],
    &["uncategorisedder"],
    &["uncategorizedder"],
    &["uncategorisedder"],
];

pub(crate) static ENTRY_UNCATEGORIZEDDEST_12893814694726934833: VariantsMap = [
    &["uncategorizeddest"],
    &["uncategoriseddest"],
    &["uncategorizeddest"],
    &["uncategoriseddest"],
];

pub(crate) static ENTRY_UNCATEGORIZED_1908101284533338669: VariantsMap = [
    &["uncategorized"],
    &["uncategorised"],
    &["uncategorized"],
    &["uncategorised"],
];

pub(crate) static ENTRY_UNCATHOLICIZED_4600831380867755451: VariantsMap = [
    &["uncatholicized"],
    &["uncatholicised"],
    &["uncatholicized"],
    &["uncatholicised"],
];

pub(crate) static ENTRY_UNCATHOLICIZES_6093318458474574467: VariantsMap = [
    &["uncatholicizes"],
    &["uncatholicises"],
    &["uncatholicizes"],
    &["uncatholicises"],
];

pub(crate) static ENTRY_UNCATHOLICIZE_551995962418758886: VariantsMap = [
    &["uncatholicize"],
    &["uncatholicise"],
    &["uncatholicize"],
    &["uncatholicise"],
];

pub(crate) static ENTRY_UNCATHOLICIZING_3296529327544351990: VariantsMap = [
    &["uncatholicizing"],
    &["uncatholicising"],
    &["uncatholicizing"],
    &["uncatholicising"],
];

pub(crate) static ENTRY_UNCAUTERIZEDS_11640317330948644398: VariantsMap = [
    &["uncauterizeds"],
    &["uncauteriseds"],
    &["uncauterizeds"],
    &["uncauteriseds"],
];

pub(crate) static ENTRY_UNCAUTERIZED_13322201167603831983: VariantsMap = [
    &["uncauterized"],
    &["uncauterised"],
    &["uncauterized"],
    &["uncauterised"],
];

pub(crate) static ENTRY_UNCELESTIALIZEDS_11516400320799709785: VariantsMap = [
    &["uncelestializeds"],
    &["uncelestialiseds"],
    &["uncelestializeds"],
    &["uncelestialiseds"],
];

pub(crate) static ENTRY_UNCELESTIALIZED_6713837851303993314: VariantsMap = [
    &["uncelestialized"],
    &["uncelestialised"],
    &["uncelestialized"],
    &["uncelestialised"],
];

pub(crate) static ENTRY_UNCENTER_5022668129641428633: VariantsMap =
    [&["uncenter"], &["uncentre"], &["uncentre"], &["uncentre"]];

pub(crate) static ENTRY_UNCENTRALIZED_5605282303614363703: VariantsMap = [
    &["uncentralized"],
    &["uncentralised"],
    &["uncentralized"],
    &["uncentralised"],
];

pub(crate) static ENTRY_UNCHARACTERIZEDDER_6498221828694645324: VariantsMap = [
    &["uncharacterizedder"],
    &["uncharacterisedder"],
    &["uncharacterizedder"],
    &["uncharacterisedder"],
];

pub(crate) static ENTRY_UNCHARACTERIZEDDEST_4388817827499986014: VariantsMap = [
    &["uncharacterizeddest"],
    &["uncharacteriseddest"],
    &["uncharacterizeddest"],
    &["uncharacteriseddest"],
];

pub(crate) static ENTRY_UNCHARACTERIZED_15697554808843700392: VariantsMap = [
    &["uncharacterized"],
    &["uncharacterised"],
    &["uncharacterized"],
    &["uncharacterised"],
];

pub(crate) static ENTRY_UNCHASTIZABLE_4405051919316243197: VariantsMap = [
    &["unchastizable"],
    &["unchastisable"],
    &["unchastizable"],
    &["unchastisable"],
];

pub(crate) static ENTRY_UNCHASTIZED_12401944732910362657: VariantsMap = [
    &["unchastized"],
    &["unchastised"],
    &["unchastized"],
    &["unchastised"],
];

pub(crate) static ENTRY_UNCHLORIDIZEDS_385449338440357613: VariantsMap = [
    &["unchloridizeds"],
    &["unchloridiseds"],
    &["unchloridizeds"],
    &["unchloridiseds"],
];

pub(crate) static ENTRY_UNCHLORIDIZED_14175199389689712768: VariantsMap = [
    &["unchloridized"],
    &["unchloridised"],
    &["unchloridized"],
    &["unchloridised"],
];

pub(crate) static ENTRY_UNCHRISTIANIZED_14017558686975729907: VariantsMap = [
    &["unchristianized"],
    &["unchristianised"],
    &["unchristianized"],
    &["unchristianised"],
];

pub(crate) static ENTRY_UNCHRISTIANIZES_12099095202959795788: VariantsMap = [
    &["unchristianizes"],
    &["unchristianises"],
    &["unchristianizes"],
    &["unchristianises"],
];

pub(crate) static ENTRY_UNCHRISTIANIZE_6343100935595500731: VariantsMap = [
    &["unchristianize"],
    &["unchristianise"],
    &["unchristianize"],
    &["unchristianise"],
];

pub(crate) static ENTRY_UNCHRISTIANIZING_14969118364175418495: VariantsMap = [
    &["unchristianizing"],
    &["unchristianising"],
    &["unchristianizing"],
    &["unchristianising"],
];

pub(crate) static ENTRY_UNCIRCULARIZEDDER_12944133233619541189: VariantsMap = [
    &["uncircularizedder"],
    &["uncircularisedder"],
    &["uncircularizedder"],
    &["uncircularisedder"],
];

pub(crate) static ENTRY_UNCIRCULARIZEDDEST_9090461193585593982: VariantsMap = [
    &["uncircularizeddest"],
    &["uncirculariseddest"],
    &["uncircularizeddest"],
    &["uncirculariseddest"],
];

pub(crate) static ENTRY_UNCIRCULARIZEDS_13542263411727476574: VariantsMap = [
    &["uncircularizeds"],
    &["uncirculariseds"],
    &["uncircularizeds"],
    &["uncirculariseds"],
];

pub(crate) static ENTRY_UNCIRCULARIZED_5516328689456799366: VariantsMap = [
    &["uncircularized"],
    &["uncircularised"],
    &["uncircularized"],
    &["uncircularised"],
];

pub(crate) static ENTRY_UNCIVILIZABLER_10123621737542280246: VariantsMap = [
    &["uncivilizabler"],
    &["uncivilisabler"],
    &["uncivilizabler"],
    &["uncivilisabler"],
];

pub(crate) static ENTRY_UNCIVILIZABLEST_6482892165423219182: VariantsMap = [
    &["uncivilizablest"],
    &["uncivilisablest"],
    &["uncivilizablest"],
    &["uncivilisablest"],
];

pub(crate) static ENTRY_UNCIVILIZABLES_4009429130801153745: VariantsMap = [
    &["uncivilizables"],
    &["uncivilisables"],
    &["uncivilizables"],
    &["uncivilisables"],
];

pub(crate) static ENTRY_UNCIVILIZABLE_16446988570314426126: VariantsMap = [
    &["uncivilizable"],
    &["uncivilisable"],
    &["uncivilizable"],
    &["uncivilisable"],
];

pub(crate) static ENTRY_UNCIVILIZEDLY_1281692747978442810: VariantsMap = [
    &["uncivilizedly"],
    &["uncivilisedly"],
    &["uncivilizedly"],
    &["uncivilisedly"],
];

pub(crate) static ENTRY_UNCIVILIZEDNESS_8883593449646355660: VariantsMap = [
    &["uncivilizedness"],
    &["uncivilisedness"],
    &["uncivilizedness"],
    &["uncivilisedness"],
];

pub(crate) static ENTRY_UNCIVILIZED_11842993558173640265: VariantsMap = [
    &["uncivilized"],
    &["uncivilised"],
    &["uncivilized"],
    &["uncivilised"],
];

pub(crate) static ENTRY_UNCIVILIZES_16809125612449158210: VariantsMap = [
    &["uncivilizes"],
    &["uncivilises"],
    &["uncivilizes"],
    &["uncivilises"],
];

pub(crate) static ENTRY_UNCIVILIZE_3952228005440427293: VariantsMap = [
    &["uncivilize"],
    &["uncivilise"],
    &["uncivilize"],
    &["uncivilise"],
];

pub(crate) static ENTRY_UNCLERICALIZES_7600984410124444968: VariantsMap = [
    &["unclericalizes"],
    &["unclericalises"],
    &["unclericalizes"],
    &["unclericalises"],
];

pub(crate) static ENTRY_UNCLERICALIZE_10491140255704276060: VariantsMap = [
    &["unclericalize"],
    &["unclericalise"],
    &["unclericalize"],
    &["unclericalise"],
];

pub(crate) static ENTRY_UNCOGNIZABLE_14160489995106158884: VariantsMap = [
    &["uncognizable"],
    &["uncognisable"],
    &["uncognizable"],
    &["uncognisable"],
];

pub(crate) static ENTRY_UNCOLONIZED_793048061484833307: VariantsMap = [
    &["uncolonized"],
    &["uncolonised"],
    &["uncolonized"],
    &["uncolonised"],
];

pub(crate) static ENTRY_UNCOLONIZES_8621451791889938290: VariantsMap = [
    &["uncolonizes"],
    &["uncolonises"],
    &["uncolonizes"],
    &["uncolonises"],
];

pub(crate) static ENTRY_UNCOLONIZE_16324652224120342941: VariantsMap = [
    &["uncolonize"],
    &["uncolonise"],
    &["uncolonize"],
    &["uncolonise"],
];

pub(crate) static ENTRY_UNCOLONIZING_8737005258550725588: VariantsMap = [
    &["uncolonizing"],
    &["uncolonising"],
    &["uncolonizing"],
    &["uncolonising"],
];

pub(crate) static ENTRY_UNCOLORABLER_17292750876767117491: VariantsMap = [
    &["uncolorabler"],
    &["uncolourabler"],
    &["uncolourabler"],
    &["uncolourabler"],
];

pub(crate) static ENTRY_UNCOLORABLEST_7092331381236258847: VariantsMap = [
    &["uncolorablest"],
    &["uncolourablest"],
    &["uncolourablest"],
    &["uncolourablest"],
];

pub(crate) static ENTRY_UNCOLORABLES_8980215200270465076: VariantsMap = [
    &["uncolorables"],
    &["uncolourables"],
    &["uncolourables"],
    &["uncolourables"],
];

pub(crate) static ENTRY_UNCOLORABLE_4153423912585578276: VariantsMap = [
    &["uncolorable"],
    &["uncolourable"],
    &["uncolourable"],
    &["uncolourable"],
];

pub(crate) static ENTRY_UNCOLORABLIER_18378872394705595553: VariantsMap = [
    &["uncolorablier"],
    &["uncolourablier"],
    &["uncolourablier"],
    &["uncolourablier"],
];

pub(crate) static ENTRY_UNCOLORABLIEST_7529954443419348402: VariantsMap = [
    &["uncolorabliest"],
    &["uncolourabliest"],
    &["uncolourabliest"],
    &["uncolourabliest"],
];

pub(crate) static ENTRY_UNCOLORABLIES_13195393864962337812: VariantsMap = [
    &["uncolorablies"],
    &["uncolourablies"],
    &["uncolourablies"],
    &["uncolourablies"],
];

pub(crate) static ENTRY_UNCOLORABLY_3052740007631630517: VariantsMap = [
    &["uncolorably"],
    &["uncolourably"],
    &["uncolourably"],
    &["uncolourably"],
];

pub(crate) static ENTRY_UNCOLOREDDER_7581046306117193660: VariantsMap = [
    &["uncoloredder"],
    &["uncolouredder"],
    &["uncolouredder"],
    &["uncolouredder"],
];

pub(crate) static ENTRY_UNCOLOREDDEST_2266252169475963598: VariantsMap = [
    &["uncoloreddest"],
    &["uncoloureddest"],
    &["uncoloureddest"],
    &["uncoloureddest"],
];

pub(crate) static ENTRY_UNCOLOREDLIER_1339679359641458561: VariantsMap = [
    &["uncoloredlier"],
    &["uncolouredlier"],
    &["uncolouredlier"],
    &["uncolouredlier"],
];

pub(crate) static ENTRY_UNCOLOREDLIEST_1084139031301806119: VariantsMap = [
    &["uncoloredliest"],
    &["uncolouredliest"],
    &["uncolouredliest"],
    &["uncolouredliest"],
];

pub(crate) static ENTRY_UNCOLOREDLY_14489589125749046875: VariantsMap = [
    &["uncoloredly"],
    &["uncolouredly"],
    &["uncolouredly"],
    &["uncolouredly"],
];

pub(crate) static ENTRY_UNCOLOREDNESSES_10914401521990992291: VariantsMap = [
    &["uncolorednesses"],
    &["uncolourednesses"],
    &["uncolourednesses"],
    &["uncolourednesses"],
];

pub(crate) static ENTRY_UNCOLOREDNESS_13585750041493123595: VariantsMap = [
    &["uncoloredness"],
    &["uncolouredness"],
    &["uncolouredness"],
    &["uncolouredness"],
];

pub(crate) static ENTRY_UNCOLOREDS_17448592794042459595: VariantsMap = [
    &["uncoloreds"],
    &["uncoloureds"],
    &["uncoloureds"],
    &["uncoloureds"],
];

pub(crate) static ENTRY_UNCOLORED_5376239934140006972: VariantsMap = [
    &["uncolored"],
    &["uncoloured"],
    &["uncoloured"],
    &["uncoloured"],
];

pub(crate) static ENTRY_UNCONCERTED_12056905702324932430: VariantsMap = [
    &["unconcerted"],
    &["unconcreted"],
    &["unconcreted"],
    &["unconcreted"],
];

pub(crate) static ENTRY_UNCONVENTIONALIZES_15104067497605581394: VariantsMap = [
    &["unconventionalizes"],
    &["unconventionalises"],
    &["unconventionalizes"],
    &["unconventionalises"],
];

pub(crate) static ENTRY_UNCONVENTIONALIZE_3086010869676785607: VariantsMap = [
    &["unconventionalize"],
    &["unconventionalise"],
    &["unconventionalize"],
    &["unconventionalise"],
];

pub(crate) static ENTRY_UNCRITICIZABLER_17254678315858537421: VariantsMap = [
    &["uncriticizabler"],
    &["uncriticisabler"],
    &["uncriticizabler"],
    &["uncriticisabler"],
];

pub(crate) static ENTRY_UNCRITICIZABLEST_12461946144251713170: VariantsMap = [
    &["uncriticizablest"],
    &["uncriticisablest"],
    &["uncriticizablest"],
    &["uncriticisablest"],
];

pub(crate) static ENTRY_UNCRITICIZABLES_1774501697582082300: VariantsMap = [
    &["uncriticizables"],
    &["uncriticisables"],
    &["uncriticizables"],
    &["uncriticisables"],
];

pub(crate) static ENTRY_UNCRITICIZABLE_5988050938990112074: VariantsMap = [
    &["uncriticizable"],
    &["uncriticisable"],
    &["uncriticizable"],
    &["uncriticisable"],
];

pub(crate) static ENTRY_UNCRITICIZABLY_15048536753630299272: VariantsMap = [
    &["uncriticizably"],
    &["uncriticisably"],
    &["uncriticizably"],
    &["uncriticisably"],
];

pub(crate) static ENTRY_UNCRITICIZED_278671110568990284: VariantsMap = [
    &["uncriticized"],
    &["uncriticised"],
    &["uncriticized"],
    &["uncriticised"],
];

pub(crate) static ENTRY_UNCRITICIZINGLY_3491212942449906984: VariantsMap = [
    &["uncriticizingly"],
    &["uncriticisingly"],
    &["uncriticizingly"],
    &["uncriticisingly"],
];

pub(crate) static ENTRY_UNCRITICIZING_16870256726875456150: VariantsMap = [
    &["uncriticizing"],
    &["uncriticising"],
    &["uncriticizing"],
    &["uncriticising"],
];

pub(crate) static ENTRY_UNCRYSTALLIZABILITIES_3244595590594411060: VariantsMap = [
    &["uncrystallizabilities"],
    &["uncrystallisabilities"],
    &["uncrystallizabilities"],
    &["uncrystallisabilities"],
];

pub(crate) static ENTRY_UNCRYSTALLIZABILITY_11201467748814217685: VariantsMap = [
    &["uncrystallizability"],
    &["uncrystallisability"],
    &["uncrystallizability"],
    &["uncrystallisability"],
];

pub(crate) static ENTRY_UNCRYSTALLIZABLER_3580664972194989519: VariantsMap = [
    &["uncrystallizabler"],
    &["uncrystallisabler"],
    &["uncrystallizabler"],
    &["uncrystallisabler"],
];

pub(crate) static ENTRY_UNCRYSTALLIZABLEST_12020400672527082645: VariantsMap = [
    &["uncrystallizablest"],
    &["uncrystallisablest"],
    &["uncrystallizablest"],
    &["uncrystallisablest"],
];

pub(crate) static ENTRY_UNCRYSTALLIZABLES_9036384453456811297: VariantsMap = [
    &["uncrystallizables"],
    &["uncrystallisables"],
    &["uncrystallizables"],
    &["uncrystallisables"],
];

pub(crate) static ENTRY_UNCRYSTALLIZABLE_8887681379037019389: VariantsMap = [
    &["uncrystallizable"],
    &["uncrystallisable"],
    &["uncrystallizable"],
    &["uncrystallisable"],
];

pub(crate) static ENTRY_UNCRYSTALLIZED_17631452865900152396: VariantsMap = [
    &["uncrystallized"],
    &["uncrystallised"],
    &["uncrystallized"],
    &["uncrystallised"],
];

pub(crate) static ENTRY_UNCURRICULARIZEDS_9305723134204411782: VariantsMap = [
    &["uncurricularizeds"],
    &["uncurriculariseds"],
    &["uncurricularizeds"],
    &["uncurriculariseds"],
];

pub(crate) static ENTRY_UNCURRICULARIZED_3643432582785827881: VariantsMap = [
    &["uncurricularized"],
    &["uncurricularised"],
    &["uncurricularized"],
    &["uncurricularised"],
];

pub(crate) static ENTRY_UNDEFENSES_6841055240379604765: VariantsMap = [
    &["undefenses"],
    &["undefences"],
    &["undefences"],
    &["undefences"],
];

pub(crate) static ENTRY_UNDEFENSE_17516267082874975159: VariantsMap = [
    &["undefense"],
    &["undefence"],
    &["undefence"],
    &["undefence"],
];

pub(crate) static ENTRY_UNDEMAGNETIZABLES_14205057507765717155: VariantsMap = [
    &["undemagnetizables"],
    &["undemagnetisables"],
    &["undemagnetizables"],
    &["undemagnetisables"],
];

pub(crate) static ENTRY_UNDEMAGNETIZABLE_9221760784135532695: VariantsMap = [
    &["undemagnetizable"],
    &["undemagnetisable"],
    &["undemagnetizable"],
    &["undemagnetisable"],
];

pub(crate) static ENTRY_UNDEMOCRATIZATION_3147337646074026875: VariantsMap = [
    &["undemocratization"],
    &["undemocratisation"],
    &["undemocratization"],
    &["undemocratisation"],
];

pub(crate) static ENTRY_UNDEMOCRATIZED_12454645037887379138: VariantsMap = [
    &["undemocratized"],
    &["undemocratised"],
    &["undemocratized"],
    &["undemocratised"],
];

pub(crate) static ENTRY_UNDEMOCRATIZES_7922361479467248866: VariantsMap = [
    &["undemocratizes"],
    &["undemocratises"],
    &["undemocratizes"],
    &["undemocratises"],
];

pub(crate) static ENTRY_UNDEMOCRATIZE_5865450725521639549: VariantsMap = [
    &["undemocratize"],
    &["undemocratise"],
    &["undemocratize"],
    &["undemocratise"],
];

pub(crate) static ENTRY_UNDEMOCRATIZING_3638836602448829184: VariantsMap = [
    &["undemocratizing"],
    &["undemocratising"],
    &["undemocratizing"],
    &["undemocratising"],
];

pub(crate) static ENTRY_UNDENOMINATIONALIZES_17484696335581871493: VariantsMap = [
    &["undenominationalizes"],
    &["undenominationalises"],
    &["undenominationalizes"],
    &["undenominationalises"],
];

pub(crate) static ENTRY_UNDENOMINATIONALIZE_3072439986846169544: VariantsMap = [
    &["undenominationalize"],
    &["undenominationalise"],
    &["undenominationalize"],
    &["undenominationalise"],
];

pub(crate) static ENTRY_UNDERCAPITALIZATIONS_15413528605787492170: VariantsMap = [
    &["undercapitalizations"],
    &["undercapitalisations"],
    &["undercapitalizations"],
    &["undercapitalisations"],
];

pub(crate) static ENTRY_UNDERCAPITALIZATION_8460263852916102032: VariantsMap = [
    &["undercapitalization"],
    &["undercapitalisation"],
    &["undercapitalization"],
    &["undercapitalisation"],
];

pub(crate) static ENTRY_UNDERCAPITALIZED_14438718972230406682: VariantsMap = [
    &["undercapitalized"],
    &["undercapitalised"],
    &["undercapitalized"],
    &["undercapitalised"],
];

pub(crate) static ENTRY_UNDERCAPITALIZES_14774979177213178352: VariantsMap = [
    &["undercapitalizes"],
    &["undercapitalises"],
    &["undercapitalizes"],
    &["undercapitalises"],
];

pub(crate) static ENTRY_UNDERCAPITALIZE_18099217300236175519: VariantsMap = [
    &["undercapitalize"],
    &["undercapitalise"],
    &["undercapitalize"],
    &["undercapitalise"],
];

pub(crate) static ENTRY_UNDERCAPITALIZING_13409262727547250690: VariantsMap = [
    &["undercapitalizing"],
    &["undercapitalising"],
    &["undercapitalizing"],
    &["undercapitalising"],
];

pub(crate) static ENTRY_UNDERCOLORED_8574607569897245160: VariantsMap = [
    &["undercolored"],
    &["undercoloured"],
    &["undercoloured"],
    &["undercoloured"],
];

pub(crate) static ENTRY_UNDERCOLORINGS_8932749399301090002: VariantsMap = [
    &["undercolorings"],
    &["undercolourings"],
    &["undercolourings"],
    &["undercolourings"],
];

pub(crate) static ENTRY_UNDERCOLORING_1186796377206381483: VariantsMap = [
    &["undercoloring"],
    &["undercolouring"],
    &["undercolouring"],
    &["undercolouring"],
];

pub(crate) static ENTRY_UNDERCOLORS_13161743376725576886: VariantsMap = [
    &["undercolors"],
    &["undercolours"],
    &["undercolours"],
    &["undercolours"],
];

pub(crate) static ENTRY_UNDERCOLOR_1027999095899511970: VariantsMap = [
    &["undercolor"],
    &["undercolour"],
    &["undercolour"],
    &["undercolour"],
];

pub(crate) static ENTRY_UNDEREMPHASIZED_16225182233832818906: VariantsMap = [
    &["underemphasized"],
    &["underemphasised"],
    &["underemphasized"],
    &["underemphasised"],
];

pub(crate) static ENTRY_UNDEREMPHASIZES_15383330958221639486: VariantsMap = [
    &["underemphasizes"],
    &["underemphasises"],
    &["underemphasizes"],
    &["underemphasises"],
];

pub(crate) static ENTRY_UNDEREMPHASIZE_113262683283266999: VariantsMap = [
    &["underemphasize"],
    &["underemphasise"],
    &["underemphasize"],
    &["underemphasise"],
];

pub(crate) static ENTRY_UNDEREMPHASIZING_8500735646633380499: VariantsMap = [
    &["underemphasizing"],
    &["underemphasising"],
    &["underemphasizing"],
    &["underemphasising"],
];

pub(crate) static ENTRY_UNDERGOER_3088049738904644403: VariantsMap = [
    &["undergoer"],
    &["undergore"],
    &["undergore"],
    &["undergore"],
];

pub(crate) static ENTRY_UNDERLABORERS_17760031799064124243: VariantsMap = [
    &["underlaborers"],
    &["underlabourers"],
    &["underlabourers"],
    &["underlabourers"],
];

pub(crate) static ENTRY_UNDERLABORER_11220879972499550950: VariantsMap = [
    &["underlaborer"],
    &["underlabourer"],
    &["underlabourer"],
    &["underlabourer"],
];

pub(crate) static ENTRY_UNDERORGANIZATIONS_12286569977525174410: VariantsMap = [
    &["underorganizations"],
    &["underorganisations"],
    &["underorganizations"],
    &["underorganisations"],
];

pub(crate) static ENTRY_UNDERORGANIZATION_10009598596379538989: VariantsMap = [
    &["underorganization"],
    &["underorganisation"],
    &["underorganization"],
    &["underorganisation"],
];

pub(crate) static ENTRY_UNDEROXIDIZED_2770429837622229926: VariantsMap = [
    &["underoxidized"],
    &["underoxidised"],
    &["underoxidized"],
    &["underoxidised"],
];

pub(crate) static ENTRY_UNDEROXIDIZES_14772434272924509932: VariantsMap = [
    &["underoxidizes"],
    &["underoxidises"],
    &["underoxidizes"],
    &["underoxidises"],
];

pub(crate) static ENTRY_UNDEROXIDIZE_6035673128957984405: VariantsMap = [
    &["underoxidize"],
    &["underoxidise"],
    &["underoxidize"],
    &["underoxidise"],
];

pub(crate) static ENTRY_UNDEROXIDIZING_5388968909302695001: VariantsMap = [
    &["underoxidizing"],
    &["underoxidising"],
    &["underoxidizing"],
    &["underoxidising"],
];

pub(crate) static ENTRY_UNDERPRIZED_8679591291804814785: VariantsMap = [
    &["underprized"],
    &["underprised"],
    &["underprized"],
    &["underprised"],
];

pub(crate) static ENTRY_UNDERPRIZES_17322055758636776705: VariantsMap = [
    &["underprizes"],
    &["underprises"],
    &["underprizes"],
    &["underprises"],
];

pub(crate) static ENTRY_UNDERPRIZE_14018313629368366509: VariantsMap = [
    &["underprize"],
    &["underprise"],
    &["underprize"],
    &["underprise"],
];

pub(crate) static ENTRY_UNDERPRIZING_14871696714578944018: VariantsMap = [
    &["underprizing"],
    &["underprising"],
    &["underprizing"],
    &["underprising"],
];

pub(crate) static ENTRY_UNDERREALIZED_4300059467226466630: VariantsMap = [
    &["underrealized"],
    &["underrealised"],
    &["underrealized"],
    &["underrealised"],
];

pub(crate) static ENTRY_UNDERREALIZES_16394967831846757976: VariantsMap = [
    &["underrealizes"],
    &["underrealises"],
    &["underrealizes"],
    &["underrealises"],
];

pub(crate) static ENTRY_UNDERREALIZE_17524145276470925370: VariantsMap = [
    &["underrealize"],
    &["underrealise"],
    &["underrealize"],
    &["underrealise"],
];

pub(crate) static ENTRY_UNDERREALIZING_6376345855147929055: VariantsMap = [
    &["underrealizing"],
    &["underrealising"],
    &["underrealizing"],
    &["underrealising"],
];

pub(crate) static ENTRY_UNDERSAVIORS_7688724448035832319: VariantsMap = [
    &["undersaviors"],
    &["undersaviours"],
    &["undersaviours"],
    &["undersaviours"],
];

pub(crate) static ENTRY_UNDERSAVIOR_2090602886568177317: VariantsMap = [
    &["undersavior"],
    &["undersaviour"],
    &["undersaviour"],
    &["undersaviour"],
];

pub(crate) static ENTRY_UNDERUTILIZATIONS_16994081773856805411: VariantsMap = [
    &["underutilizations"],
    &["underutilisations"],
    &["underutilizations"],
    &["underutilisations"],
];

pub(crate) static ENTRY_UNDERUTILIZATION_14694691541150582602: VariantsMap = [
    &["underutilization"],
    &["underutilisation"],
    &["underutilization"],
    &["underutilisation"],
];

pub(crate) static ENTRY_UNDERUTILIZED_11374623631374378006: VariantsMap = [
    &["underutilized"],
    &["underutilised"],
    &["underutilized"],
    &["underutilised"],
];

pub(crate) static ENTRY_UNDERUTILIZES_10200345077765075455: VariantsMap = [
    &["underutilizes"],
    &["underutilises"],
    &["underutilizes"],
    &["underutilises"],
];

pub(crate) static ENTRY_UNDERUTILIZE_12788386196891414227: VariantsMap = [
    &["underutilize"],
    &["underutilise"],
    &["underutilize"],
    &["underutilise"],
];

pub(crate) static ENTRY_UNDERUTILIZING_8716553292659107585: VariantsMap = [
    &["underutilizing"],
    &["underutilising"],
    &["underutilizing"],
    &["underutilising"],
];

pub(crate) static ENTRY_UNDERVITALIZEDS_6753695904801318252: VariantsMap = [
    &["undervitalizeds"],
    &["undervitaliseds"],
    &["undervitalizeds"],
    &["undervitaliseds"],
];

pub(crate) static ENTRY_UNDERVITALIZED_5414632877340114792: VariantsMap = [
    &["undervitalized"],
    &["undervitalised"],
    &["undervitalized"],
    &["undervitalised"],
];

pub(crate) static ENTRY_UNDIALYZEDS_8300878326723839717: VariantsMap = [
    &["undialyzeds"],
    &["undialyseds"],
    &["undialyseds"],
    &["undialyseds"],
];

pub(crate) static ENTRY_UNDIALYZED_6937122698553980061: VariantsMap = [
    &["undialyzed"],
    &["undialysed"],
    &["undialysed"],
    &["undialysed"],
];

pub(crate) static ENTRY_UNDIPHTHONGIZES_1596685277229183988: VariantsMap = [
    &["undiphthongizes"],
    &["undiphthongises"],
    &["undiphthongizes"],
    &["undiphthongises"],
];

pub(crate) static ENTRY_UNDIPHTHONGIZE_3039948312517507404: VariantsMap = [
    &["undiphthongize"],
    &["undiphthongise"],
    &["undiphthongize"],
    &["undiphthongise"],
];

pub(crate) static ENTRY_UNDISCOLOREDDER_9889756595104883661: VariantsMap = [
    &["undiscoloredder"],
    &["undiscolouredder"],
    &["undiscolouredder"],
    &["undiscolouredder"],
];

pub(crate) static ENTRY_UNDISCOLOREDDEST_17082256163046268738: VariantsMap = [
    &["undiscoloreddest"],
    &["undiscoloureddest"],
    &["undiscoloureddest"],
    &["undiscoloureddest"],
];

pub(crate) static ENTRY_UNDISCOLOREDS_3407916046171759215: VariantsMap = [
    &["undiscoloreds"],
    &["undiscoloureds"],
    &["undiscoloureds"],
    &["undiscoloureds"],
];

pub(crate) static ENTRY_UNDISCOLORED_11284105783683995277: VariantsMap = [
    &["undiscolored"],
    &["undiscoloured"],
    &["undiscoloured"],
    &["undiscoloured"],
];

pub(crate) static ENTRY_UNDISHONORED_9663612534816223685: VariantsMap = [
    &["undishonored"],
    &["undishonoured"],
    &["undishonoured"],
    &["undishonoured"],
];

pub(crate) static ENTRY_UNDISORGANIZED_6929340290183050050: VariantsMap = [
    &["undisorganized"],
    &["undisorganised"],
    &["undisorganized"],
    &["undisorganised"],
];

pub(crate) static ENTRY_UNDRAMATIZABLER_13792948696025531595: VariantsMap = [
    &["undramatizabler"],
    &["undramatisabler"],
    &["undramatizabler"],
    &["undramatisabler"],
];

pub(crate) static ENTRY_UNDRAMATIZABLEST_16859389726173129688: VariantsMap = [
    &["undramatizablest"],
    &["undramatisablest"],
    &["undramatizablest"],
    &["undramatisablest"],
];

pub(crate) static ENTRY_UNDRAMATIZABLES_13405611959481771902: VariantsMap = [
    &["undramatizables"],
    &["undramatisables"],
    &["undramatizables"],
    &["undramatisables"],
];

pub(crate) static ENTRY_UNDRAMATIZABLE_858223802227706690: VariantsMap = [
    &["undramatizable"],
    &["undramatisable"],
    &["undramatizable"],
    &["undramatisable"],
];

pub(crate) static ENTRY_UNDRAMATIZEDS_8874745974154709414: VariantsMap = [
    &["undramatizeds"],
    &["undramatiseds"],
    &["undramatizeds"],
    &["undramatiseds"],
];

pub(crate) static ENTRY_UNDRAMATIZED_15106387989278045439: VariantsMap = [
    &["undramatized"],
    &["undramatised"],
    &["undramatized"],
    &["undramatised"],
];

pub(crate) static ENTRY_UNDUALIZES_907900132788100323: VariantsMap = [
    &["undualizes"],
    &["undualises"],
    &["undualizes"],
    &["undualises"],
];

pub(crate) static ENTRY_UNDUALIZE_14512061026250797714: VariantsMap = [
    &["undualize"],
    &["undualise"],
    &["undualize"],
    &["undualise"],
];

pub(crate) static ENTRY_UNECONOMIZING_15361850876984202426: VariantsMap = [
    &["uneconomizing"],
    &["uneconomising"],
    &["uneconomizing"],
    &["uneconomising"],
];

pub(crate) static ENTRY_UNENAMOREDDER_15030893414945898832: VariantsMap = [
    &["unenamoredder"],
    &["unenamouredder"],
    &["unenamouredder"],
    &["unenamouredder"],
];

pub(crate) static ENTRY_UNENAMOREDDEST_4443009802859750012: VariantsMap = [
    &["unenamoreddest"],
    &["unenamoureddest"],
    &["unenamoureddest"],
    &["unenamoureddest"],
];

pub(crate) static ENTRY_UNENAMOREDS_2048092433213968436: VariantsMap = [
    &["unenamoreds"],
    &["unenamoureds"],
    &["unenamoureds"],
    &["unenamoureds"],
];

pub(crate) static ENTRY_UNENAMORED_10334414449150181515: VariantsMap = [
    &["unenamored"],
    &["unenamoured"],
    &["unenamoured"],
    &["unenamoured"],
];

pub(crate) static ENTRY_UNENDEAVORED_7088517032114848: VariantsMap = [
    &["unendeavored"],
    &["unendeavoured"],
    &["unendeavoured"],
    &["unendeavoured"],
];

pub(crate) static ENTRY_UNENERGIZEDS_13766204943868625189: VariantsMap = [
    &["unenergizeds"],
    &["unenergiseds"],
    &["unenergizeds"],
    &["unenergiseds"],
];

pub(crate) static ENTRY_UNENERGIZED_6824210473919222731: VariantsMap = [
    &["unenergized"],
    &["unenergised"],
    &["unenergized"],
    &["unenergised"],
];

pub(crate) static ENTRY_UNEPITOMIZEDDER_11044100971858801429: VariantsMap = [
    &["unepitomizedder"],
    &["unepitomisedder"],
    &["unepitomizedder"],
    &["unepitomisedder"],
];

pub(crate) static ENTRY_UNEPITOMIZEDDEST_13090266195761403470: VariantsMap = [
    &["unepitomizeddest"],
    &["unepitomiseddest"],
    &["unepitomizeddest"],
    &["unepitomiseddest"],
];

pub(crate) static ENTRY_UNEPITOMIZED_12749922881696348309: VariantsMap = [
    &["unepitomized"],
    &["unepitomised"],
    &["unepitomized"],
    &["unepitomised"],
];

pub(crate) static ENTRY_UNEQUALEDDER_6427424448868113114: VariantsMap = [
    &["unequaledder"],
    &["unequalledder"],
    &["unequalledder"],
    &["unequalledder"],
];

pub(crate) static ENTRY_UNEQUALEDDEST_2906178077931186884: VariantsMap = [
    &["unequaleddest"],
    &["unequalleddest"],
    &["unequalleddest"],
    &["unequalleddest"],
];

pub(crate) static ENTRY_UNEQUALED_13151580965074494682: VariantsMap = [
    &["unequaled"],
    &["unequalled"],
    &["unequalled"],
    &["unequalled"],
];

pub(crate) static ENTRY_UNEQUALIZED_1264478642545746533: VariantsMap = [
    &["unequalized"],
    &["unequalised"],
    &["unequalized"],
    &["unequalised"],
];

pub(crate) static ENTRY_UNEQUALIZES_4019346570786096058: VariantsMap = [
    &["unequalizes"],
    &["unequalises"],
    &["unequalizes"],
    &["unequalises"],
];

pub(crate) static ENTRY_UNEQUALIZE_1864493647225706635: VariantsMap = [
    &["unequalize"],
    &["unequalise"],
    &["unequalize"],
    &["unequalise"],
];

pub(crate) static ENTRY_UNEQUALIZING_4434056561745779801: VariantsMap = [
    &["unequalizing"],
    &["unequalising"],
    &["unequalizing"],
    &["unequalising"],
];

pub(crate) static ENTRY_UNEULOGIZEDDER_14436657900787507056: VariantsMap = [
    &["uneulogizedder"],
    &["uneulogisedder"],
    &["uneulogizedder"],
    &["uneulogisedder"],
];

pub(crate) static ENTRY_UNEULOGIZEDDEST_12757263395641675477: VariantsMap = [
    &["uneulogizeddest"],
    &["uneulogiseddest"],
    &["uneulogizeddest"],
    &["uneulogiseddest"],
];

pub(crate) static ENTRY_UNEULOGIZEDS_8420268768630297949: VariantsMap = [
    &["uneulogizeds"],
    &["uneulogiseds"],
    &["uneulogizeds"],
    &["uneulogiseds"],
];

pub(crate) static ENTRY_UNEULOGIZED_15906086694931473085: VariantsMap = [
    &["uneulogized"],
    &["uneulogised"],
    &["uneulogized"],
    &["uneulogised"],
];

pub(crate) static ENTRY_UNEVANGELIZEDDER_8418942558979715181: VariantsMap = [
    &["unevangelizedder"],
    &["unevangelisedder"],
    &["unevangelizedder"],
    &["unevangelisedder"],
];

pub(crate) static ENTRY_UNEVANGELIZEDDEST_16823940955538972844: VariantsMap = [
    &["unevangelizeddest"],
    &["unevangeliseddest"],
    &["unevangelizeddest"],
    &["unevangeliseddest"],
];

pub(crate) static ENTRY_UNEVANGELIZEDS_11394973428109629288: VariantsMap = [
    &["unevangelizeds"],
    &["unevangeliseds"],
    &["unevangelizeds"],
    &["unevangeliseds"],
];

pub(crate) static ENTRY_UNEVANGELIZED_493364703036041093: VariantsMap = [
    &["unevangelized"],
    &["unevangelised"],
    &["unevangelized"],
    &["unevangelised"],
];

pub(crate) static ENTRY_UNFAMILIARIZEDDER_14155937485679466752: VariantsMap = [
    &["unfamiliarizedder"],
    &["unfamiliarisedder"],
    &["unfamiliarizedder"],
    &["unfamiliarisedder"],
];

pub(crate) static ENTRY_UNFAMILIARIZEDDEST_1917999470235328318: VariantsMap = [
    &["unfamiliarizeddest"],
    &["unfamiliariseddest"],
    &["unfamiliarizeddest"],
    &["unfamiliariseddest"],
];

pub(crate) static ENTRY_UNFAMILIARIZED_3461949634289269826: VariantsMap = [
    &["unfamiliarized"],
    &["unfamiliarised"],
    &["unfamiliarized"],
    &["unfamiliarised"],
];

pub(crate) static ENTRY_UNFAVORABLENESSES_7937279763475314531: VariantsMap = [
    &["unfavorablenesses"],
    &["unfavourablenesses"],
    &["unfavourablenesses"],
    &["unfavourablenesses"],
];

pub(crate) static ENTRY_UNFAVORABLENESS_9419895507281118929: VariantsMap = [
    &["unfavorableness"],
    &["unfavourableness"],
    &["unfavourableness"],
    &["unfavourableness"],
];

pub(crate) static ENTRY_UNFAVORABLER_8407653781350191045: VariantsMap = [
    &["unfavorabler"],
    &["unfavourabler"],
    &["unfavourabler"],
    &["unfavourabler"],
];

pub(crate) static ENTRY_UNFAVORABLEST_8329180226725391402: VariantsMap = [
    &["unfavorablest"],
    &["unfavourablest"],
    &["unfavourablest"],
    &["unfavourablest"],
];

pub(crate) static ENTRY_UNFAVORABLES_245237680247907199: VariantsMap = [
    &["unfavorables"],
    &["unfavourables"],
    &["unfavourables"],
    &["unfavourables"],
];

pub(crate) static ENTRY_UNFAVORABLE_5650317643174313946: VariantsMap = [
    &["unfavorable"],
    &["unfavourable"],
    &["unfavourable"],
    &["unfavourable"],
];

pub(crate) static ENTRY_UNFAVORABLIER_5445832020764674982: VariantsMap = [
    &["unfavorablier"],
    &["unfavourablier"],
    &["unfavourablier"],
    &["unfavourablier"],
];

pub(crate) static ENTRY_UNFAVORABLIEST_9135988438022295109: VariantsMap = [
    &["unfavorabliest"],
    &["unfavourabliest"],
    &["unfavourabliest"],
    &["unfavourabliest"],
];

pub(crate) static ENTRY_UNFAVORABLY_4995649989227121664: VariantsMap = [
    &["unfavorably"],
    &["unfavourably"],
    &["unfavourably"],
    &["unfavourably"],
];

pub(crate) static ENTRY_UNFAVOREDDER_1591015547238508735: VariantsMap = [
    &["unfavoredder"],
    &["unfavouredder"],
    &["unfavouredder"],
    &["unfavouredder"],
];

pub(crate) static ENTRY_UNFAVOREDDEST_2194563377250381555: VariantsMap = [
    &["unfavoreddest"],
    &["unfavoureddest"],
    &["unfavoureddest"],
    &["unfavoureddest"],
];

pub(crate) static ENTRY_UNFAVORED_4073522488222730170: VariantsMap = [
    &["unfavored"],
    &["unfavoured"],
    &["unfavoured"],
    &["unfavoured"],
];

pub(crate) static ENTRY_UNFAVORINGER_8115927317700614456: VariantsMap = [
    &["unfavoringer"],
    &["unfavouringer"],
    &["unfavouringer"],
    &["unfavouringer"],
];

pub(crate) static ENTRY_UNFAVORINGEST_18384809876281860545: VariantsMap = [
    &["unfavoringest"],
    &["unfavouringest"],
    &["unfavouringest"],
    &["unfavouringest"],
];

pub(crate) static ENTRY_UNFAVORINGS_821556787073286206: VariantsMap = [
    &["unfavorings"],
    &["unfavourings"],
    &["unfavourings"],
    &["unfavourings"],
];

pub(crate) static ENTRY_UNFAVORING_5915402494320502167: VariantsMap = [
    &["unfavoring"],
    &["unfavouring"],
    &["unfavouring"],
    &["unfavouring"],
];

pub(crate) static ENTRY_UNFAVORITER_13011370405101578377: VariantsMap = [
    &["unfavoriter"],
    &["unfavouriter"],
    &["unfavouriter"],
    &["unfavouriter"],
];

pub(crate) static ENTRY_UNFAVORITEST_10894783312557521667: VariantsMap = [
    &["unfavoritest"],
    &["unfavouritest"],
    &["unfavouritest"],
    &["unfavouritest"],
];

pub(crate) static ENTRY_UNFAVORITES_16626569901250523880: VariantsMap = [
    &["unfavorites"],
    &["unfavourites"],
    &["unfavourites"],
    &["unfavourites"],
];

pub(crate) static ENTRY_UNFAVORITE_9839169349258021237: VariantsMap = [
    &["unfavorite"],
    &["unfavourite"],
    &["unfavourite"],
    &["unfavourite"],
];

pub(crate) static ENTRY_UNFEMINIZED_2220407209529111709: VariantsMap = [
    &["unfeminized"],
    &["unfeminised"],
    &["unfeminized"],
    &["unfeminised"],
];

pub(crate) static ENTRY_UNFEMINIZE_2001388748715757690: VariantsMap = [
    &["unfeminize"],
    &["unfeminise"],
    &["unfeminize"],
    &["unfeminise"],
];

pub(crate) static ENTRY_UNFEMINIZING_10216822851481831958: VariantsMap = [
    &["unfeminizing"],
    &["unfeminising"],
    &["unfeminizing"],
    &["unfeminising"],
];

pub(crate) static ENTRY_UNFERTILIZABLER_6121110660744572333: VariantsMap = [
    &["unfertilizabler"],
    &["unfertilisabler"],
    &["unfertilizabler"],
    &["unfertilisabler"],
];

pub(crate) static ENTRY_UNFERTILIZABLEST_11998703244940643531: VariantsMap = [
    &["unfertilizablest"],
    &["unfertilisablest"],
    &["unfertilizablest"],
    &["unfertilisablest"],
];

pub(crate) static ENTRY_UNFERTILIZABLES_2130405461712866243: VariantsMap = [
    &["unfertilizables"],
    &["unfertilisables"],
    &["unfertilizables"],
    &["unfertilisables"],
];

pub(crate) static ENTRY_UNFERTILIZABLE_6992270943983134373: VariantsMap = [
    &["unfertilizable"],
    &["unfertilisable"],
    &["unfertilizable"],
    &["unfertilisable"],
];

pub(crate) static ENTRY_UNFERTILIZEDDER_3962795259989687011: VariantsMap = [
    &["unfertilizedder"],
    &["unfertilisedder"],
    &["unfertilizedder"],
    &["unfertilisedder"],
];

pub(crate) static ENTRY_UNFERTILIZEDDEST_16794644706411544184: VariantsMap = [
    &["unfertilizeddest"],
    &["unfertiliseddest"],
    &["unfertilizeddest"],
    &["unfertiliseddest"],
];

pub(crate) static ENTRY_UNFERTILIZED_1896012193898147315: VariantsMap = [
    &["unfertilized"],
    &["unfertilised"],
    &["unfertilized"],
    &["unfertilised"],
];

pub(crate) static ENTRY_UNFERTILIZING_12441724634999163602: VariantsMap = [
    &["unfertilizing"],
    &["unfertilising"],
    &["unfertilizing"],
    &["unfertilising"],
];

pub(crate) static ENTRY_UNFEUDALIZED_4489675212740440309: VariantsMap = [
    &["unfeudalized"],
    &["unfeudalised"],
    &["unfeudalized"],
    &["unfeudalised"],
];

pub(crate) static ENTRY_UNFEUDALIZES_7666754629620871610: VariantsMap = [
    &["unfeudalizes"],
    &["unfeudalises"],
    &["unfeudalizes"],
    &["unfeudalises"],
];

pub(crate) static ENTRY_UNFEUDALIZE_4948744929952762262: VariantsMap = [
    &["unfeudalize"],
    &["unfeudalise"],
    &["unfeudalize"],
    &["unfeudalise"],
];

pub(crate) static ENTRY_UNFEUDALIZING_6652813473340699512: VariantsMap = [
    &["unfeudalizing"],
    &["unfeudalising"],
    &["unfeudalizing"],
    &["unfeudalising"],
];

pub(crate) static ENTRY_UNFLAVOREDDER_8175850200918329116: VariantsMap = [
    &["unflavoredder"],
    &["unflavouredder"],
    &["unflavouredder"],
    &["unflavouredder"],
];

pub(crate) static ENTRY_UNFLAVOREDDEST_5088848224529312235: VariantsMap = [
    &["unflavoreddest"],
    &["unflavoureddest"],
    &["unflavoureddest"],
    &["unflavoureddest"],
];

pub(crate) static ENTRY_UNFLAVORED_9672896276378072278: VariantsMap = [
    &["unflavored"],
    &["unflavoured"],
    &["unflavoured"],
    &["unflavoured"],
];

pub(crate) static ENTRY_UNFLAVOROUS_15116595106089847138: VariantsMap = [
    &["unflavorous"],
    &["unflavourous"],
    &["unflavourous"],
    &["unflavourous"],
];

pub(crate) static ENTRY_UNFORMALIZEDDER_14165770520440361407: VariantsMap = [
    &["unformalizedder"],
    &["unformalisedder"],
    &["unformalizedder"],
    &["unformalisedder"],
];

pub(crate) static ENTRY_UNFORMALIZEDDEST_17208946494472238886: VariantsMap = [
    &["unformalizeddest"],
    &["unformaliseddest"],
    &["unformalizeddest"],
    &["unformaliseddest"],
];

pub(crate) static ENTRY_UNFORMALIZED_7899916370079121441: VariantsMap = [
    &["unformalized"],
    &["unformalised"],
    &["unformalized"],
    &["unformalised"],
];

pub(crate) static ENTRY_UNFOSSILIZEDDER_14434730201241982353: VariantsMap = [
    &["unfossilizedder"],
    &["unfossilisedder"],
    &["unfossilizedder"],
    &["unfossilisedder"],
];

pub(crate) static ENTRY_UNFOSSILIZEDDEST_13071168100410233552: VariantsMap = [
    &["unfossilizeddest"],
    &["unfossiliseddest"],
    &["unfossilizeddest"],
    &["unfossiliseddest"],
];

pub(crate) static ENTRY_UNFOSSILIZEDS_16301703807130406696: VariantsMap = [
    &["unfossilizeds"],
    &["unfossiliseds"],
    &["unfossilizeds"],
    &["unfossiliseds"],
];

pub(crate) static ENTRY_UNFOSSILIZED_13346837272047276618: VariantsMap = [
    &["unfossilized"],
    &["unfossilised"],
    &["unfossilized"],
    &["unfossilised"],
];

pub(crate) static ENTRY_UNFRATERNIZED_16285087131580785609: VariantsMap = [
    &["unfraternized"],
    &["unfraternised"],
    &["unfraternized"],
    &["unfraternised"],
];

pub(crate) static ENTRY_UNFRATERNIZINGS_12977443623394508497: VariantsMap = [
    &["unfraternizings"],
    &["unfraternisings"],
    &["unfraternizings"],
    &["unfraternisings"],
];

pub(crate) static ENTRY_UNFRATERNIZING_4612503372516640985: VariantsMap = [
    &["unfraternizing"],
    &["unfraternising"],
    &["unfraternizing"],
    &["unfraternising"],
];

pub(crate) static ENTRY_UNGALVANIZEDS_8383279107759676747: VariantsMap = [
    &["ungalvanizeds"],
    &["ungalvaniseds"],
    &["ungalvanizeds"],
    &["ungalvaniseds"],
];

pub(crate) static ENTRY_UNGALVANIZED_8045809390486265382: VariantsMap = [
    &["ungalvanized"],
    &["ungalvanised"],
    &["ungalvanized"],
    &["ungalvanised"],
];

pub(crate) static ENTRY_UNGELATINIZABLES_6386667123269773422: VariantsMap = [
    &["ungelatinizables"],
    &["ungelatinisables"],
    &["ungelatinizables"],
    &["ungelatinisables"],
];

pub(crate) static ENTRY_UNGELATINIZABLE_14072020582199354747: VariantsMap = [
    &["ungelatinizable"],
    &["ungelatinisable"],
    &["ungelatinizable"],
    &["ungelatinisable"],
];

pub(crate) static ENTRY_UNGELATINIZEDS_11671694804301099117: VariantsMap = [
    &["ungelatinizeds"],
    &["ungelatiniseds"],
    &["ungelatinizeds"],
    &["ungelatiniseds"],
];

pub(crate) static ENTRY_UNGELATINIZED_10373227658204020685: VariantsMap = [
    &["ungelatinized"],
    &["ungelatinised"],
    &["ungelatinized"],
    &["ungelatinised"],
];

pub(crate) static ENTRY_UNGENERALIZEDDER_11296864575965360245: VariantsMap = [
    &["ungeneralizedder"],
    &["ungeneralisedder"],
    &["ungeneralizedder"],
    &["ungeneralisedder"],
];

pub(crate) static ENTRY_UNGENERALIZEDDEST_10829752942426843396: VariantsMap = [
    &["ungeneralizeddest"],
    &["ungeneraliseddest"],
    &["ungeneralizeddest"],
    &["ungeneraliseddest"],
];

pub(crate) static ENTRY_UNGENERALIZED_14143149454140309313: VariantsMap = [
    &["ungeneralized"],
    &["ungeneralised"],
    &["ungeneralized"],
    &["ungeneralised"],
];

pub(crate) static ENTRY_UNGENERALIZING_1839845840030566278: VariantsMap = [
    &["ungeneralizing"],
    &["ungeneralising"],
    &["ungeneralizing"],
    &["ungeneralising"],
];

pub(crate) static ENTRY_UNGENTILIZES_4989241345981017864: VariantsMap = [
    &["ungentilizes"],
    &["ungentilises"],
    &["ungentilizes"],
    &["ungentilises"],
];

pub(crate) static ENTRY_UNGENTILIZE_1723028300980426250: VariantsMap = [
    &["ungentilize"],
    &["ungentilise"],
    &["ungentilize"],
    &["ungentilise"],
];

pub(crate) static ENTRY_UNGENTLEMANIZES_14225357015905456046: VariantsMap = [
    &["ungentlemanizes"],
    &["ungentlemanises"],
    &["ungentlemanizes"],
    &["ungentlemanises"],
];

pub(crate) static ENTRY_UNGENTLEMANIZE_18186282254227733891: VariantsMap = [
    &["ungentlemanize"],
    &["ungentlemanise"],
    &["ungentlemanize"],
    &["ungentlemanise"],
];

pub(crate) static ENTRY_UNGLAMOROUSLY_13876889208379675435: VariantsMap = [
    &["unglamorously"],
    &["unglamorously"],
    &["unglamorously"],
    &["unglamorously"],
];

pub(crate) static ENTRY_UNGLAMOROUS_17159152581421977091: VariantsMap = [
    &["unglamorous"],
    &["unglamorous"],
    &["unglamorous"],
    &["unglamorous"],
];

pub(crate) static ENTRY_UNGOSPELIZEDS_9818924277430364811: VariantsMap = [
    &["ungospelizeds"],
    &["ungospeliseds"],
    &["ungospelizeds"],
    &["ungospeliseds"],
];

pub(crate) static ENTRY_UNGOSPELIZED_7104427828857537577: VariantsMap = [
    &["ungospelized"],
    &["ungospelised"],
    &["ungospelized"],
    &["ungospelised"],
];

pub(crate) static ENTRY_UNGRAPHITIZEDS_8135878505595004848: VariantsMap = [
    &["ungraphitizeds"],
    &["ungraphitiseds"],
    &["ungraphitizeds"],
    &["ungraphitiseds"],
];

pub(crate) static ENTRY_UNGRAPHITIZED_11151981879102463629: VariantsMap = [
    &["ungraphitized"],
    &["ungraphitised"],
    &["ungraphitized"],
    &["ungraphitised"],
];

pub(crate) static ENTRY_UNHARBORED_6775117848685665911: VariantsMap = [
    &["unharbored"],
    &["unharboured"],
    &["unharboured"],
    &["unharboured"],
];

pub(crate) static ENTRY_UNHARBOR_3808891720499086153: VariantsMap = [
    &["unharbor"],
    &["unharbour"],
    &["unharbour"],
    &["unharbour"],
];

pub(crate) static ENTRY_UNHARMONIZED_17900579618906076059: VariantsMap = [
    &["unharmonized"],
    &["unharmonised"],
    &["unharmonized"],
    &["unharmonised"],
];

pub(crate) static ENTRY_UNHARMONIZES_18388139136613077997: VariantsMap = [
    &["unharmonizes"],
    &["unharmonises"],
    &["unharmonizes"],
    &["unharmonises"],
];

pub(crate) static ENTRY_UNHARMONIZE_6028907999174872917: VariantsMap = [
    &["unharmonize"],
    &["unharmonise"],
    &["unharmonize"],
    &["unharmonise"],
];

pub(crate) static ENTRY_UNHARMONIZING_5754608021634090726: VariantsMap = [
    &["unharmonizing"],
    &["unharmonising"],
    &["unharmonizing"],
    &["unharmonising"],
];

pub(crate) static ENTRY_UNHEROIZES_14874152198907028504: VariantsMap = [
    &["unheroizes"],
    &["unheroises"],
    &["unheroizes"],
    &["unheroises"],
];

pub(crate) static ENTRY_UNHEROIZE_14719025801623380202: VariantsMap = [
    &["unheroize"],
    &["unheroise"],
    &["unheroize"],
    &["unheroise"],
];

pub(crate) static ENTRY_UNHONORABLES_2602046928790025604: VariantsMap = [
    &["unhonorables"],
    &["unhonourables"],
    &["unhonourables"],
    &["unhonourables"],
];

pub(crate) static ENTRY_UNHONORABLE_2571371106091765213: VariantsMap = [
    &["unhonorable"],
    &["unhonourable"],
    &["unhonourable"],
    &["unhonourable"],
];

pub(crate) static ENTRY_UNHONORABLIES_8756645705579311445: VariantsMap = [
    &["unhonorablies"],
    &["unhonourablies"],
    &["unhonourablies"],
    &["unhonourablies"],
];

pub(crate) static ENTRY_UNHONORABLY_14594026255233946792: VariantsMap = [
    &["unhonorably"],
    &["unhonourably"],
    &["unhonourably"],
    &["unhonourably"],
];

pub(crate) static ENTRY_UNHONOREDDER_5145501164984603406: VariantsMap = [
    &["unhonoredder"],
    &["unhonouredder"],
    &["unhonouredder"],
    &["unhonouredder"],
];

pub(crate) static ENTRY_UNHONOREDDEST_253419705093959263: VariantsMap = [
    &["unhonoreddest"],
    &["unhonoureddest"],
    &["unhonoureddest"],
    &["unhonoureddest"],
];

pub(crate) static ENTRY_UNHONORED_1763420376323415335: VariantsMap = [
    &["unhonored"],
    &["unhonoured"],
    &["unhonoured"],
    &["unhonoured"],
];

pub(crate) static ENTRY_UNHOUSELED_9514624409997890163: VariantsMap = [
    &["unhouseled"],
    &["unhouselled"],
    &["unhouselled"],
    &["unhouselled"],
];

pub(crate) static ENTRY_UNHUMANIZED_11850238111200004906: VariantsMap = [
    &["unhumanized"],
    &["unhumanised"],
    &["unhumanized"],
    &["unhumanised"],
];

pub(crate) static ENTRY_UNHUMANIZES_438461434554460503: VariantsMap = [
    &["unhumanizes"],
    &["unhumanises"],
    &["unhumanizes"],
    &["unhumanises"],
];

pub(crate) static ENTRY_UNHUMANIZE_9275488574912041634: VariantsMap = [
    &["unhumanize"],
    &["unhumanise"],
    &["unhumanize"],
    &["unhumanise"],
];

pub(crate) static ENTRY_UNHUMANIZING_922703227770676812: VariantsMap = [
    &["unhumanizing"],
    &["unhumanising"],
    &["unhumanizing"],
    &["unhumanising"],
];

pub(crate) static ENTRY_UNHUMOREDDER_12582156681544655808: VariantsMap = [
    &["unhumoredder"],
    &["unhumouredder"],
    &["unhumouredder"],
    &["unhumouredder"],
];

pub(crate) static ENTRY_UNHUMOREDDEST_3090681874029593777: VariantsMap = [
    &["unhumoreddest"],
    &["unhumoureddest"],
    &["unhumoureddest"],
    &["unhumoureddest"],
];

pub(crate) static ENTRY_UNHUMORED_9270244412900857495: VariantsMap = [
    &["unhumored"],
    &["unhumoured"],
    &["unhumoured"],
    &["unhumoured"],
];

pub(crate) static ENTRY_UNHUMOROUSLY_2997877439653370896: VariantsMap = [
    &["unhumorously"],
    &["unhumourously"],
    &["unhumourously"],
    &["unhumourously"],
];

pub(crate) static ENTRY_UNHUMOROUS_15431740540620940624: VariantsMap = [
    &["unhumorous"],
    &["unhumourous"],
    &["unhumourous"],
    &["unhumourous"],
];

pub(crate) static ENTRY_UNHYDROLYZEDS_3654098217580741282: VariantsMap = [
    &["unhydrolyzeds"],
    &["unhydrolyseds"],
    &["unhydrolyseds"],
    &["unhydrolyseds"],
];

pub(crate) static ENTRY_UNHYDROLYZED_4176688738875490222: VariantsMap = [
    &["unhydrolyzed"],
    &["unhydrolysed"],
    &["unhydrolysed"],
    &["unhydrolysed"],
];

pub(crate) static ENTRY_UNHYPNOTIZABLER_8305672016674438516: VariantsMap = [
    &["unhypnotizabler"],
    &["unhypnotisabler"],
    &["unhypnotizabler"],
    &["unhypnotisabler"],
];

pub(crate) static ENTRY_UNHYPNOTIZABLEST_10447283984210613307: VariantsMap = [
    &["unhypnotizablest"],
    &["unhypnotisablest"],
    &["unhypnotizablest"],
    &["unhypnotisablest"],
];

pub(crate) static ENTRY_UNHYPNOTIZABLES_6312193248281361674: VariantsMap = [
    &["unhypnotizables"],
    &["unhypnotisables"],
    &["unhypnotizables"],
    &["unhypnotisables"],
];

pub(crate) static ENTRY_UNHYPNOTIZABLE_3023984005494874707: VariantsMap = [
    &["unhypnotizable"],
    &["unhypnotisable"],
    &["unhypnotizable"],
    &["unhypnotisable"],
];

pub(crate) static ENTRY_UNHYPNOTIZED_743015943914592881: VariantsMap = [
    &["unhypnotized"],
    &["unhypnotised"],
    &["unhypnotized"],
    &["unhypnotised"],
];

pub(crate) static ENTRY_UNHYPNOTIZES_193211741624635662: VariantsMap = [
    &["unhypnotizes"],
    &["unhypnotises"],
    &["unhypnotizes"],
    &["unhypnotises"],
];

pub(crate) static ENTRY_UNHYPNOTIZE_14826256691134863152: VariantsMap = [
    &["unhypnotize"],
    &["unhypnotise"],
    &["unhypnotize"],
    &["unhypnotise"],
];

pub(crate) static ENTRY_UNHYPNOTIZING_2116650708300517622: VariantsMap = [
    &["unhypnotizing"],
    &["unhypnotising"],
    &["unhypnotizing"],
    &["unhypnotising"],
];

pub(crate) static ENTRY_UNICOLORATE_9925921492993125409: VariantsMap = [
    &["unicolorate"],
    &["unicolourate"],
    &["unicolourate"],
    &["unicolourate"],
];

pub(crate) static ENTRY_UNICOLORED_13888790365655202389: VariantsMap = [
    &["unicolored"],
    &["unicoloured"],
    &["unicoloured"],
    &["unicoloured"],
];

pub(crate) static ENTRY_UNICOLOROUS_15234607672611841882: VariantsMap = [
    &["unicolorous"],
    &["unicolourous"],
    &["unicolourous"],
    &["unicolourous"],
];

pub(crate) static ENTRY_UNICOLOR_7951294365410695890: VariantsMap = [
    &["unicolor"],
    &["unicolour"],
    &["unicolour"],
    &["unicolour"],
];

pub(crate) static ENTRY_UNIDEALIZEDDER_9531311480747399110: VariantsMap = [
    &["unidealizedder"],
    &["unidealisedder"],
    &["unidealizedder"],
    &["unidealisedder"],
];

pub(crate) static ENTRY_UNIDEALIZEDDEST_6258316838435840632: VariantsMap = [
    &["unidealizeddest"],
    &["unidealiseddest"],
    &["unidealizeddest"],
    &["unidealiseddest"],
];

pub(crate) static ENTRY_UNIDEALIZED_18263684325928084797: VariantsMap = [
    &["unidealized"],
    &["unidealised"],
    &["unidealized"],
    &["unidealised"],
];

pub(crate) static ENTRY_UNIDOLIZEDDER_4579557691614853236: VariantsMap = [
    &["unidolizedder"],
    &["unidolisedder"],
    &["unidolizedder"],
    &["unidolisedder"],
];

pub(crate) static ENTRY_UNIDOLIZEDDEST_16953396813667748727: VariantsMap = [
    &["unidolizeddest"],
    &["unidoliseddest"],
    &["unidolizeddest"],
    &["unidoliseddest"],
];

pub(crate) static ENTRY_UNIDOLIZEDS_10372074101999609838: VariantsMap = [
    &["unidolizeds"],
    &["unidoliseds"],
    &["unidolizeds"],
    &["unidoliseds"],
];

pub(crate) static ENTRY_UNIDOLIZED_4988379165333344084: VariantsMap = [
    &["unidolized"],
    &["unidolised"],
    &["unidolized"],
    &["unidolised"],
];

pub(crate) static ENTRY_UNIFORMIZATIONS_12665372292806972250: VariantsMap = [
    &["uniformizations"],
    &["uniformisations"],
    &["uniformizations"],
    &["uniformisations"],
];

pub(crate) static ENTRY_UNIFORMIZATION_13391023365117343462: VariantsMap = [
    &["uniformization"],
    &["uniformisation"],
    &["uniformization"],
    &["uniformisation"],
];

pub(crate) static ENTRY_UNIFORMIZED_779131196589099729: VariantsMap = [
    &["uniformized"],
    &["uniformised"],
    &["uniformized"],
    &["uniformised"],
];

pub(crate) static ENTRY_UNIFORMIZES_13485704841992152874: VariantsMap = [
    &["uniformizes"],
    &["uniformises"],
    &["uniformizes"],
    &["uniformises"],
];

pub(crate) static ENTRY_UNIFORMIZE_16664384967794257664: VariantsMap = [
    &["uniformize"],
    &["uniformise"],
    &["uniformize"],
    &["uniformise"],
];

pub(crate) static ENTRY_UNIFORMIZING_11410783001199896652: VariantsMap = [
    &["uniformizing"],
    &["uniformising"],
    &["uniformizing"],
    &["uniformising"],
];

pub(crate) static ENTRY_UNILATERALIZATIONS_16769494285291495801: VariantsMap = [
    &["unilateralizations"],
    &["unilateralisations"],
    &["unilateralizations"],
    &["unilateralisations"],
];

pub(crate) static ENTRY_UNILATERALIZATION_4288199725380356569: VariantsMap = [
    &["unilateralization"],
    &["unilateralisation"],
    &["unilateralization"],
    &["unilateralisation"],
];

pub(crate) static ENTRY_UNILATERALIZES_17232043563681281696: VariantsMap = [
    &["unilateralizes"],
    &["unilateralises"],
    &["unilateralizes"],
    &["unilateralises"],
];

pub(crate) static ENTRY_UNILATERALIZE_17363790504930513832: VariantsMap = [
    &["unilateralize"],
    &["unilateralise"],
    &["unilateralize"],
    &["unilateralise"],
];

pub(crate) static ENTRY_UNIMMORTALIZED_17439839362062815218: VariantsMap = [
    &["unimmortalized"],
    &["unimmortalised"],
    &["unimmortalized"],
    &["unimmortalised"],
];

pub(crate) static ENTRY_UNIMMORTALIZES_2326945565115161743: VariantsMap = [
    &["unimmortalizes"],
    &["unimmortalises"],
    &["unimmortalizes"],
    &["unimmortalises"],
];

pub(crate) static ENTRY_UNIMMORTALIZE_2559458109653754603: VariantsMap = [
    &["unimmortalize"],
    &["unimmortalise"],
    &["unimmortalize"],
    &["unimmortalise"],
];

pub(crate) static ENTRY_UNIMMUNIZED_9723702448629673605: VariantsMap = [
    &["unimmunized"],
    &["unimmunised"],
    &["unimmunized"],
    &["unimmunised"],
];

pub(crate) static ENTRY_UNINDIVIDUALIZED_9978336683560948261: VariantsMap = [
    &["unindividualized"],
    &["unindividualised"],
    &["unindividualized"],
    &["unindividualised"],
];

pub(crate) static ENTRY_UNINDIVIDUALIZES_9652328537629869880: VariantsMap = [
    &["unindividualizes"],
    &["unindividualises"],
    &["unindividualizes"],
    &["unindividualises"],
];

pub(crate) static ENTRY_UNINDIVIDUALIZE_15522862361188070635: VariantsMap = [
    &["unindividualize"],
    &["unindividualise"],
    &["unindividualize"],
    &["unindividualise"],
];

pub(crate) static ENTRY_UNINDUSTRIALIZEDS_14309123692343325999: VariantsMap = [
    &["unindustrializeds"],
    &["unindustrialiseds"],
    &["unindustrializeds"],
    &["unindustrialiseds"],
];

pub(crate) static ENTRY_UNINDUSTRIALIZED_16910106454060086905: VariantsMap = [
    &["unindustrialized"],
    &["unindustrialised"],
    &["unindustrialized"],
    &["unindustrialised"],
];

pub(crate) static ENTRY_UNINITIALIZABLE_7902667084930987540: VariantsMap = [
    &["uninitializable"],
    &["uninitialisable"],
    &["uninitializable"],
    &["uninitialisable"],
];

pub(crate) static ENTRY_UNINITIALIZED_13632684259926269346: VariantsMap = [
    &["uninitialized"],
    &["uninitialised"],
    &["uninitialized"],
    &["uninitialised"],
];

pub(crate) static ENTRY_UNIONIZATIONS_8188645564688971694: VariantsMap = [
    &["unionizations"],
    &["unionisations"],
    &["unionizations"],
    &["unionisations"],
];

pub(crate) static ENTRY_UNIONIZATION_2816931840848288400: VariantsMap = [
    &["unionization"],
    &["unionisation"],
    &["unionization"],
    &["unionisation"],
];

pub(crate) static ENTRY_UNIONIZED_4300815435733718278: VariantsMap = [
    &["unionized"],
    &["unionised"],
    &["unionized"],
    &["unionised"],
];

pub(crate) static ENTRY_UNIONIZERS_4535038362799968844: VariantsMap = [
    &["unionizers"],
    &["unionisers"],
    &["unionizers"],
    &["unionisers"],
];

pub(crate) static ENTRY_UNIONIZER_18311427809549346577: VariantsMap = [
    &["unionizer"],
    &["unioniser"],
    &["unionizer"],
    &["unioniser"],
];

pub(crate) static ENTRY_UNIONIZES_1566009791777584230: VariantsMap = [
    &["unionizes"],
    &["unionises"],
    &["unionizes"],
    &["unionises"],
];

pub(crate) static ENTRY_UNIONIZE_10414936899999594660: VariantsMap =
    [&["unionize"], &["unionise"], &["unionize"], &["unionise"]];

pub(crate) static ENTRY_UNIONIZING_7690467481138958046: VariantsMap = [
    &["unionizing"],
    &["unionising"],
    &["unionizing"],
    &["unionising"],
];

pub(crate) static ENTRY_UNITALICIZED_17037791464209006878: VariantsMap = [
    &["unitalicized"],
    &["unitalicised"],
    &["unitalicized"],
    &["unitalicised"],
];

pub(crate) static ENTRY_UNITARIANIZES_6993618606081407804: VariantsMap = [
    &["unitarianizes"],
    &["unitarianises"],
    &["unitarianizes"],
    &["unitarianises"],
];

pub(crate) static ENTRY_UNITARIANIZE_17273315308284727882: VariantsMap = [
    &["unitarianize"],
    &["unitarianise"],
    &["unitarianize"],
    &["unitarianise"],
];

pub(crate) static ENTRY_UNITEMIZED_10435569559841782555: VariantsMap = [
    &["unitemized"],
    &["unitemised"],
    &["unitemized"],
    &["unitemised"],
];

pub(crate) static ENTRY_UNITIZATIONS_13955434829892541568: VariantsMap = [
    &["unitizations"],
    &["unitisations"],
    &["unitizations"],
    &["unitisations"],
];

pub(crate) static ENTRY_UNITIZATION_4383385584028471093: VariantsMap = [
    &["unitization"],
    &["unitisation"],
    &["unitization"],
    &["unitisation"],
];

pub(crate) static ENTRY_UNITIZED_10679179499203160842: VariantsMap =
    [&["unitized"], &["unitised"], &["unitized"], &["unitised"]];

pub(crate) static ENTRY_UNITIZES_13809626517201188910: VariantsMap =
    [&["unitizes"], &["unitises"], &["unitizes"], &["unitises"]];

pub(crate) static ENTRY_UNITIZE_3757352850523028761: VariantsMap =
    [&["unitize"], &["unitise"], &["unitize"], &["unitise"]];

pub(crate) static ENTRY_UNITIZING_5223811169788144692: VariantsMap = [
    &["unitizing"],
    &["unitising"],
    &["unitizing"],
    &["unitising"],
];

pub(crate) static ENTRY_UNIVERSALIZATIONS_13530116854029584990: VariantsMap = [
    &["universalizations"],
    &["universalisations"],
    &["universalizations"],
    &["universalisations"],
];

pub(crate) static ENTRY_UNIVERSALIZATION_2454309767089738201: VariantsMap = [
    &["universalization"],
    &["universalisation"],
    &["universalization"],
    &["universalisation"],
];

pub(crate) static ENTRY_UNIVERSALIZED_7596820744757624427: VariantsMap = [
    &["universalized"],
    &["universalised"],
    &["universalized"],
    &["universalised"],
];

pub(crate) static ENTRY_UNIVERSALIZERS_2548517964365124361: VariantsMap = [
    &["universalizers"],
    &["universalisers"],
    &["universalizers"],
    &["universalisers"],
];

pub(crate) static ENTRY_UNIVERSALIZER_3507098281330240508: VariantsMap = [
    &["universalizer"],
    &["universaliser"],
    &["universalizer"],
    &["universaliser"],
];

pub(crate) static ENTRY_UNIVERSALIZES_7397422123387773820: VariantsMap = [
    &["universalizes"],
    &["universalises"],
    &["universalizes"],
    &["universalises"],
];

pub(crate) static ENTRY_UNIVERSALIZE_14896798826234728638: VariantsMap = [
    &["universalize"],
    &["universalise"],
    &["universalize"],
    &["universalise"],
];

pub(crate) static ENTRY_UNIVERSALIZING_10782273614602618944: VariantsMap = [
    &["universalizing"],
    &["universalising"],
    &["universalizing"],
    &["universalising"],
];

pub(crate) static ENTRY_UNJEOPARDIZED_17486399707788562883: VariantsMap = [
    &["unjeopardized"],
    &["unjeopardised"],
    &["unjeopardized"],
    &["unjeopardised"],
];

pub(crate) static ENTRY_UNJOURNALIZED_4436133202537390136: VariantsMap = [
    &["unjournalized"],
    &["unjournalised"],
    &["unjournalized"],
    &["unjournalised"],
];

pub(crate) static ENTRY_UNKENNELED_14459883499276528555: VariantsMap = [
    &["unkenneled"],
    &["unkennelled"],
    &["unkennelled"],
    &["unkennelled"],
];

pub(crate) static ENTRY_UNKENNELING_3079694918155233686: VariantsMap = [
    &["unkenneling"],
    &["unkennelling"],
    &["unkennelling"],
    &["unkennelling"],
];

pub(crate) static ENTRY_UNLABELEDDER_14520124038825557406: VariantsMap = [
    &["unlabeledder"],
    &["unlabelledder"],
    &["unlabelledder"],
    &["unlabelledder"],
];

pub(crate) static ENTRY_UNLABELEDDEST_17384647877826400058: VariantsMap = [
    &["unlabeleddest"],
    &["unlabelleddest"],
    &["unlabelleddest"],
    &["unlabelleddest"],
];

pub(crate) static ENTRY_UNLABELED_5521478301443297379: VariantsMap = [
    &["unlabeled"],
    &["unlabelled"],
    &["unlabelled"],
    &["unlabelled"],
];

pub(crate) static ENTRY_UNLABIALIZED_18161976242006416543: VariantsMap = [
    &["unlabialized"],
    &["unlabialised"],
    &["unlabialized"],
    &["unlabialised"],
];

pub(crate) static ENTRY_UNLABIALIZES_11090976916776589003: VariantsMap = [
    &["unlabializes"],
    &["unlabialises"],
    &["unlabializes"],
    &["unlabialises"],
];

pub(crate) static ENTRY_UNLABIALIZE_14700231870563288334: VariantsMap = [
    &["unlabialize"],
    &["unlabialise"],
    &["unlabialize"],
    &["unlabialise"],
];

pub(crate) static ENTRY_UNLABIALIZING_17998770221957811654: VariantsMap = [
    &["unlabializing"],
    &["unlabialising"],
    &["unlabializing"],
    &["unlabialising"],
];

pub(crate) static ENTRY_UNLABORABLES_8002074775965731933: VariantsMap = [
    &["unlaborables"],
    &["unlabourables"],
    &["unlabourables"],
    &["unlabourables"],
];

pub(crate) static ENTRY_UNLABORABLE_5597257290729843911: VariantsMap = [
    &["unlaborable"],
    &["unlabourable"],
    &["unlabourable"],
    &["unlabourable"],
];

pub(crate) static ENTRY_UNLABOREDDER_12202991864716052732: VariantsMap = [
    &["unlaboredder"],
    &["unlabouredder"],
    &["unlabouredder"],
    &["unlabouredder"],
];

pub(crate) static ENTRY_UNLABOREDDEST_3561720129928496444: VariantsMap = [
    &["unlaboreddest"],
    &["unlaboureddest"],
    &["unlaboureddest"],
    &["unlaboureddest"],
];

pub(crate) static ENTRY_UNLABORED_1615322569123204547: VariantsMap = [
    &["unlabored"],
    &["unlaboured"],
    &["unlaboured"],
    &["unlaboured"],
];

pub(crate) static ENTRY_UNLABORINGER_17618283927523064423: VariantsMap = [
    &["unlaboringer"],
    &["unlabouringer"],
    &["unlabouringer"],
    &["unlabouringer"],
];

pub(crate) static ENTRY_UNLABORINGEST_11076910916694514810: VariantsMap = [
    &["unlaboringest"],
    &["unlabouringest"],
    &["unlabouringest"],
    &["unlabouringest"],
];

pub(crate) static ENTRY_UNLABORINGS_13595599544117141943: VariantsMap = [
    &["unlaborings"],
    &["unlabourings"],
    &["unlabourings"],
    &["unlabourings"],
];

pub(crate) static ENTRY_UNLABORING_7621181090729553452: VariantsMap = [
    &["unlaboring"],
    &["unlabouring"],
    &["unlabouring"],
    &["unlabouring"],
];

pub(crate) static ENTRY_UNLEARNED_4424673437597791231: VariantsMap = [
    &["unlearned"],
    &["unlearned", "unlearnt"],
    &["unlearned"],
    &["unlearned", "unlearnt"],
];

pub(crate) static ENTRY_UNLEGALIZEDDER_8012198770985007318: VariantsMap = [
    &["unlegalizedder"],
    &["unlegalisedder"],
    &["unlegalizedder"],
    &["unlegalisedder"],
];

pub(crate) static ENTRY_UNLEGALIZEDDEST_17306165656930561184: VariantsMap = [
    &["unlegalizeddest"],
    &["unlegaliseddest"],
    &["unlegalizeddest"],
    &["unlegaliseddest"],
];

pub(crate) static ENTRY_UNLEGALIZED_10345441232305055471: VariantsMap = [
    &["unlegalized"],
    &["unlegalised"],
    &["unlegalized"],
    &["unlegalised"],
];

pub(crate) static ENTRY_UNLEVELED_14811436885559634904: VariantsMap = [
    &["unleveled"],
    &["unlevelled"],
    &["unlevelled"],
    &["unlevelled"],
];

pub(crate) static ENTRY_UNLEVELING_3313982499129049944: VariantsMap = [
    &["unleveling"],
    &["unlevelling"],
    &["unlevelling"],
    &["unlevelling"],
];

pub(crate) static ENTRY_UNLIBERALIZEDDER_4461656846504146142: VariantsMap = [
    &["unliberalizedder"],
    &["unliberalisedder"],
    &["unliberalizedder"],
    &["unliberalisedder"],
];

pub(crate) static ENTRY_UNLIBERALIZEDDEST_14758526200738928936: VariantsMap = [
    &["unliberalizeddest"],
    &["unliberaliseddest"],
    &["unliberalizeddest"],
    &["unliberaliseddest"],
];

pub(crate) static ENTRY_UNLIBERALIZED_3641414538278460652: VariantsMap = [
    &["unliberalized"],
    &["unliberalised"],
    &["unliberalized"],
    &["unliberalised"],
];

pub(crate) static ENTRY_UNLIONIZED_5835800076716610222: VariantsMap = [
    &["unlionized"],
    &["unlionised"],
    &["unlionized"],
    &["unlionised"],
];

pub(crate) static ENTRY_UNLITERALIZED_3082179323060504252: VariantsMap = [
    &["unliteralized"],
    &["unliteralised"],
    &["unliteralized"],
    &["unliteralised"],
];

pub(crate) static ENTRY_UNLOCALIZABLER_7537908645677548744: VariantsMap = [
    &["unlocalizabler"],
    &["unlocalisabler"],
    &["unlocalizabler"],
    &["unlocalisabler"],
];

pub(crate) static ENTRY_UNLOCALIZABLEST_14079275978309136005: VariantsMap = [
    &["unlocalizablest"],
    &["unlocalisablest"],
    &["unlocalizablest"],
    &["unlocalisablest"],
];

pub(crate) static ENTRY_UNLOCALIZABLES_6890565389055859424: VariantsMap = [
    &["unlocalizables"],
    &["unlocalisables"],
    &["unlocalizables"],
    &["unlocalisables"],
];

pub(crate) static ENTRY_UNLOCALIZABLE_14292436275798738192: VariantsMap = [
    &["unlocalizable"],
    &["unlocalisable"],
    &["unlocalizable"],
    &["unlocalisable"],
];

pub(crate) static ENTRY_UNLOCALIZED_4103084257883656085: VariantsMap = [
    &["unlocalized"],
    &["unlocalised"],
    &["unlocalized"],
    &["unlocalised"],
];

pub(crate) static ENTRY_UNLOCALIZES_10056596505491890711: VariantsMap = [
    &["unlocalizes"],
    &["unlocalises"],
    &["unlocalizes"],
    &["unlocalises"],
];

pub(crate) static ENTRY_UNLOCALIZE_124944264009925738: VariantsMap = [
    &["unlocalize"],
    &["unlocalise"],
    &["unlocalize"],
    &["unlocalise"],
];

pub(crate) static ENTRY_UNLOCALIZING_4812710385579738803: VariantsMap = [
    &["unlocalizing"],
    &["unlocalising"],
    &["unlocalizing"],
    &["unlocalising"],
];

pub(crate) static ENTRY_UNMACADAMIZED_3275723831952183615: VariantsMap = [
    &["unmacadamized"],
    &["unmacadamised"],
    &["unmacadamized"],
    &["unmacadamised"],
];

pub(crate) static ENTRY_UNMAGNETIZEDDER_15710200139655009020: VariantsMap = [
    &["unmagnetizedder"],
    &["unmagnetisedder"],
    &["unmagnetizedder"],
    &["unmagnetisedder"],
];

pub(crate) static ENTRY_UNMAGNETIZEDDEST_2932179077945017913: VariantsMap = [
    &["unmagnetizeddest"],
    &["unmagnetiseddest"],
    &["unmagnetizeddest"],
    &["unmagnetiseddest"],
];

pub(crate) static ENTRY_UNMAGNETIZEDS_16811876985713273780: VariantsMap = [
    &["unmagnetizeds"],
    &["unmagnetiseds"],
    &["unmagnetizeds"],
    &["unmagnetiseds"],
];

pub(crate) static ENTRY_UNMAGNETIZED_1016024906065652662: VariantsMap = [
    &["unmagnetized"],
    &["unmagnetised"],
    &["unmagnetized"],
    &["unmagnetised"],
];

pub(crate) static ENTRY_UNMATERIALIZED_6876889534618019929: VariantsMap = [
    &["unmaterialized"],
    &["unmaterialised"],
    &["unmaterialized"],
    &["unmaterialised"],
];

pub(crate) static ENTRY_UNMECHANIZED_16721303431448088542: VariantsMap = [
    &["unmechanized"],
    &["unmechanised"],
    &["unmechanized"],
    &["unmechanised"],
];

pub(crate) static ENTRY_UNMECHANIZES_13574271478828569360: VariantsMap = [
    &["unmechanizes"],
    &["unmechanises"],
    &["unmechanizes"],
    &["unmechanises"],
];

pub(crate) static ENTRY_UNMECHANIZE_12567709989894150163: VariantsMap = [
    &["unmechanize"],
    &["unmechanise"],
    &["unmechanize"],
    &["unmechanise"],
];

pub(crate) static ENTRY_UNMECHANIZING_8319964999572980399: VariantsMap = [
    &["unmechanizing"],
    &["unmechanising"],
    &["unmechanizing"],
    &["unmechanising"],
];

pub(crate) static ENTRY_UNMEDIATIZEDS_10932726138966957967: VariantsMap = [
    &["unmediatizeds"],
    &["unmediatiseds"],
    &["unmediatizeds"],
    &["unmediatiseds"],
];

pub(crate) static ENTRY_UNMEDIATIZED_8755314419661725158: VariantsMap = [
    &["unmediatized"],
    &["unmediatised"],
    &["unmediatized"],
    &["unmediatised"],
];

pub(crate) static ENTRY_UNMEDIEVAL_18446665201522752648: VariantsMap = [
    &["unmedieval"],
    &["unmediaeval"],
    &["unmediaeval"],
    &["unmediaeval"],
];

pub(crate) static ENTRY_UNMELODIZED_5604267675766024708: VariantsMap = [
    &["unmelodized"],
    &["unmelodised"],
    &["unmelodized"],
    &["unmelodised"],
];

pub(crate) static ENTRY_UNMEMORIALIZEDDER_4759079110106574727: VariantsMap = [
    &["unmemorializedder"],
    &["unmemorialisedder"],
    &["unmemorializedder"],
    &["unmemorialisedder"],
];

pub(crate) static ENTRY_UNMEMORIALIZEDDEST_10631489810683710839: VariantsMap = [
    &["unmemorializeddest"],
    &["unmemorialiseddest"],
    &["unmemorializeddest"],
    &["unmemorialiseddest"],
];

pub(crate) static ENTRY_UNMEMORIALIZEDS_7803701197481713742: VariantsMap = [
    &["unmemorializeds"],
    &["unmemorialiseds"],
    &["unmemorializeds"],
    &["unmemorialiseds"],
];

pub(crate) static ENTRY_UNMEMORIALIZED_3865802921441210140: VariantsMap = [
    &["unmemorialized"],
    &["unmemorialised"],
    &["unmemorialized"],
    &["unmemorialised"],
];

pub(crate) static ENTRY_UNMEMORIZED_17008272697746293921: VariantsMap = [
    &["unmemorized"],
    &["unmemorised"],
    &["unmemorized"],
    &["unmemorised"],
];

pub(crate) static ENTRY_UNMERCERIZEDS_15957558455222000048: VariantsMap = [
    &["unmercerizeds"],
    &["unmerceriseds"],
    &["unmercerizeds"],
    &["unmerceriseds"],
];

pub(crate) static ENTRY_UNMERCERIZED_3875470586449512690: VariantsMap = [
    &["unmercerized"],
    &["unmercerised"],
    &["unmercerized"],
    &["unmercerised"],
];

pub(crate) static ENTRY_UNMESMERIZEDDER_6729466480851972942: VariantsMap = [
    &["unmesmerizedder"],
    &["unmesmerisedder"],
    &["unmesmerizedder"],
    &["unmesmerisedder"],
];

pub(crate) static ENTRY_UNMESMERIZEDDEST_1620171434081064380: VariantsMap = [
    &["unmesmerizeddest"],
    &["unmesmeriseddest"],
    &["unmesmerizeddest"],
    &["unmesmeriseddest"],
];

pub(crate) static ENTRY_UNMESMERIZED_17296099928682062139: VariantsMap = [
    &["unmesmerized"],
    &["unmesmerised"],
    &["unmesmerized"],
    &["unmesmerised"],
];

pub(crate) static ENTRY_UNMESMERIZES_13030574456077520578: VariantsMap = [
    &["unmesmerizes"],
    &["unmesmerises"],
    &["unmesmerizes"],
    &["unmesmerises"],
];

pub(crate) static ENTRY_UNMESMERIZE_16375686298282822286: VariantsMap = [
    &["unmesmerize"],
    &["unmesmerise"],
    &["unmesmerize"],
    &["unmesmerise"],
];

pub(crate) static ENTRY_UNMETALIZEDS_4575503008268873870: VariantsMap = [
    &["unmetalizeds"],
    &["unmetalliseds"],
    &["unmetallizeds"],
    &["unmetalliseds"],
];

pub(crate) static ENTRY_UNMETALIZED_6211291008887157429: VariantsMap = [
    &["unmetalized"],
    &["unmetallised"],
    &["unmetallized"],
    &["unmetallised"],
];

pub(crate) static ENTRY_UNMETHODIZEDDER_8100212412642341077: VariantsMap = [
    &["unmethodizedder"],
    &["unmethodisedder"],
    &["unmethodizedder"],
    &["unmethodisedder"],
];

pub(crate) static ENTRY_UNMETHODIZEDDEST_3462202797716679669: VariantsMap = [
    &["unmethodizeddest"],
    &["unmethodiseddest"],
    &["unmethodizeddest"],
    &["unmethodiseddest"],
];

pub(crate) static ENTRY_UNMETHODIZEDS_7986474180166911324: VariantsMap = [
    &["unmethodizeds"],
    &["unmethodiseds"],
    &["unmethodizeds"],
    &["unmethodiseds"],
];

pub(crate) static ENTRY_UNMETHODIZED_10946517892898645417: VariantsMap = [
    &["unmethodized"],
    &["unmethodised"],
    &["unmethodized"],
    &["unmethodised"],
];

pub(crate) static ENTRY_UNMETHODIZINGER_7099500888782377207: VariantsMap = [
    &["unmethodizinger"],
    &["unmethodisinger"],
    &["unmethodizinger"],
    &["unmethodisinger"],
];

pub(crate) static ENTRY_UNMETHODIZINGEST_9585135668735652608: VariantsMap = [
    &["unmethodizingest"],
    &["unmethodisingest"],
    &["unmethodizingest"],
    &["unmethodisingest"],
];

pub(crate) static ENTRY_UNMETHODIZINGS_12701861300369560867: VariantsMap = [
    &["unmethodizings"],
    &["unmethodisings"],
    &["unmethodizings"],
    &["unmethodisings"],
];

pub(crate) static ENTRY_UNMETHODIZING_13344558328835996895: VariantsMap = [
    &["unmethodizing"],
    &["unmethodising"],
    &["unmethodizing"],
    &["unmethodising"],
];

pub(crate) static ENTRY_UNMILITARIZED_1485314695149985787: VariantsMap = [
    &["unmilitarized"],
    &["unmilitarised"],
    &["unmilitarized"],
    &["unmilitarised"],
];

pub(crate) static ENTRY_UNMINERALIZEDDER_17640203002238743394: VariantsMap = [
    &["unmineralizedder"],
    &["unmineralisedder"],
    &["unmineralizedder"],
    &["unmineralisedder"],
];

pub(crate) static ENTRY_UNMINERALIZEDDEST_16144751391346858077: VariantsMap = [
    &["unmineralizeddest"],
    &["unmineraliseddest"],
    &["unmineralizeddest"],
    &["unmineraliseddest"],
];

pub(crate) static ENTRY_UNMINERALIZEDS_18108031203100511951: VariantsMap = [
    &["unmineralizeds"],
    &["unmineraliseds"],
    &["unmineralizeds"],
    &["unmineraliseds"],
];

pub(crate) static ENTRY_UNMINERALIZED_13182690126429279818: VariantsMap = [
    &["unmineralized"],
    &["unmineralised"],
    &["unmineralized"],
    &["unmineralised"],
];

pub(crate) static ENTRY_UNMINIMIZEDDER_9929018702523158132: VariantsMap = [
    &["unminimizedder"],
    &["unminimisedder"],
    &["unminimizedder"],
    &["unminimisedder"],
];

pub(crate) static ENTRY_UNMINIMIZEDDEST_10423241850474892989: VariantsMap = [
    &["unminimizeddest"],
    &["unminimiseddest"],
    &["unminimizeddest"],
    &["unminimiseddest"],
];

pub(crate) static ENTRY_UNMINIMIZED_10804108869596653578: VariantsMap = [
    &["unminimized"],
    &["unminimised"],
    &["unminimized"],
    &["unminimised"],
];

pub(crate) static ENTRY_UNMINIMIZING_7828881953798020330: VariantsMap = [
    &["unminimizing"],
    &["unminimising"],
    &["unminimizing"],
    &["unminimising"],
];

pub(crate) static ENTRY_UNMISSIONIZEDS_15498615692624108021: VariantsMap = [
    &["unmissionizeds"],
    &["unmissioniseds"],
    &["unmissionizeds"],
    &["unmissioniseds"],
];

pub(crate) static ENTRY_UNMISSIONIZED_6055141146647724226: VariantsMap = [
    &["unmissionized"],
    &["unmissionised"],
    &["unmissionized"],
    &["unmissionised"],
];

pub(crate) static ENTRY_UNMITERS_10693236987116708733: VariantsMap =
    [&["unmiters"], &["unmitres"], &["unmitres"], &["unmitres"]];

pub(crate) static ENTRY_UNMITER_4436356488941610561: VariantsMap =
    [&["unmiter"], &["unmitre"], &["unmitre"], &["unmitre"]];

pub(crate) static ENTRY_UNMOBILIZEDDER_11927063159506308450: VariantsMap = [
    &["unmobilizedder"],
    &["unmobilisedder"],
    &["unmobilizedder"],
    &["unmobilisedder"],
];

pub(crate) static ENTRY_UNMOBILIZEDDEST_10224224733783290289: VariantsMap = [
    &["unmobilizeddest"],
    &["unmobiliseddest"],
    &["unmobilizeddest"],
    &["unmobiliseddest"],
];

pub(crate) static ENTRY_UNMOBILIZEDS_14948038683001063666: VariantsMap = [
    &["unmobilizeds"],
    &["unmobiliseds"],
    &["unmobilizeds"],
    &["unmobiliseds"],
];

pub(crate) static ENTRY_UNMOBILIZED_6882258248677469216: VariantsMap = [
    &["unmobilized"],
    &["unmobilised"],
    &["unmobilized"],
    &["unmobilised"],
];

pub(crate) static ENTRY_UNMODERNIZEDDER_2184253259481509851: VariantsMap = [
    &["unmodernizedder"],
    &["unmodernisedder"],
    &["unmodernizedder"],
    &["unmodernisedder"],
];

pub(crate) static ENTRY_UNMODERNIZEDDEST_5884036476751578639: VariantsMap = [
    &["unmodernizeddest"],
    &["unmoderniseddest"],
    &["unmodernizeddest"],
    &["unmoderniseddest"],
];

pub(crate) static ENTRY_UNMODERNIZED_17940257161248789338: VariantsMap = [
    &["unmodernized"],
    &["unmodernised"],
    &["unmodernized"],
    &["unmodernised"],
];

pub(crate) static ENTRY_UNMODERNIZES_15371503983089338847: VariantsMap = [
    &["unmodernizes"],
    &["unmodernises"],
    &["unmodernizes"],
    &["unmodernises"],
];

pub(crate) static ENTRY_UNMODERNIZE_12082713052164864740: VariantsMap = [
    &["unmodernize"],
    &["unmodernise"],
    &["unmodernize"],
    &["unmodernise"],
];

pub(crate) static ENTRY_UNMONOPOLIZEDDER_17142775490849128548: VariantsMap = [
    &["unmonopolizedder"],
    &["unmonopolisedder"],
    &["unmonopolizedder"],
    &["unmonopolisedder"],
];

pub(crate) static ENTRY_UNMONOPOLIZEDDEST_7447523346026484536: VariantsMap = [
    &["unmonopolizeddest"],
    &["unmonopoliseddest"],
    &["unmonopolizeddest"],
    &["unmonopoliseddest"],
];

pub(crate) static ENTRY_UNMONOPOLIZED_5990364325192494246: VariantsMap = [
    &["unmonopolized"],
    &["unmonopolised"],
    &["unmonopolized"],
    &["unmonopolised"],
];

pub(crate) static ENTRY_UNMONOPOLIZES_13270158276860099999: VariantsMap = [
    &["unmonopolizes"],
    &["unmonopolises"],
    &["unmonopolizes"],
    &["unmonopolises"],
];

pub(crate) static ENTRY_UNMONOPOLIZE_8561469392171138113: VariantsMap = [
    &["unmonopolize"],
    &["unmonopolise"],
    &["unmonopolize"],
    &["unmonopolise"],
];

pub(crate) static ENTRY_UNMONOPOLIZINGER_360819679104472363: VariantsMap = [
    &["unmonopolizinger"],
    &["unmonopolisinger"],
    &["unmonopolizinger"],
    &["unmonopolisinger"],
];

pub(crate) static ENTRY_UNMONOPOLIZINGEST_3073556729363282506: VariantsMap = [
    &["unmonopolizingest"],
    &["unmonopolisingest"],
    &["unmonopolizingest"],
    &["unmonopolisingest"],
];

pub(crate) static ENTRY_UNMONOPOLIZINGS_17013019050710709283: VariantsMap = [
    &["unmonopolizings"],
    &["unmonopolisings"],
    &["unmonopolizings"],
    &["unmonopolisings"],
];

pub(crate) static ENTRY_UNMONOPOLIZING_8354787337348046373: VariantsMap = [
    &["unmonopolizing"],
    &["unmonopolising"],
    &["unmonopolizing"],
    &["unmonopolising"],
];

pub(crate) static ENTRY_UNMORALIZED_14682688325335149210: VariantsMap = [
    &["unmoralized"],
    &["unmoralised"],
    &["unmoralized"],
    &["unmoralised"],
];

pub(crate) static ENTRY_UNMORALIZES_5154600717815072047: VariantsMap = [
    &["unmoralizes"],
    &["unmoralises"],
    &["unmoralizes"],
    &["unmoralises"],
];

pub(crate) static ENTRY_UNMORALIZE_16577373069040947378: VariantsMap = [
    &["unmoralize"],
    &["unmoralise"],
    &["unmoralize"],
    &["unmoralise"],
];

pub(crate) static ENTRY_UNMORALIZINGER_7095495741685677317: VariantsMap = [
    &["unmoralizinger"],
    &["unmoralisinger"],
    &["unmoralizinger"],
    &["unmoralisinger"],
];

pub(crate) static ENTRY_UNMORALIZINGEST_558050961128963437: VariantsMap = [
    &["unmoralizingest"],
    &["unmoralisingest"],
    &["unmoralizingest"],
    &["unmoralisingest"],
];

pub(crate) static ENTRY_UNMORALIZINGS_10824587508976338526: VariantsMap = [
    &["unmoralizings"],
    &["unmoralisings"],
    &["unmoralizings"],
    &["unmoralisings"],
];

pub(crate) static ENTRY_UNMORALIZING_2925852403949922365: VariantsMap = [
    &["unmoralizing"],
    &["unmoralising"],
    &["unmoralizing"],
    &["unmoralising"],
];

pub(crate) static ENTRY_UNMOTORIZEDDER_1909498846471688585: VariantsMap = [
    &["unmotorizedder"],
    &["unmotorisedder"],
    &["unmotorizedder"],
    &["unmotorisedder"],
];

pub(crate) static ENTRY_UNMOTORIZEDDEST_13434675976031166453: VariantsMap = [
    &["unmotorizeddest"],
    &["unmotoriseddest"],
    &["unmotorizeddest"],
    &["unmotoriseddest"],
];

pub(crate) static ENTRY_UNMOTORIZED_8115416776448533269: VariantsMap = [
    &["unmotorized"],
    &["unmotorised"],
    &["unmotorized"],
    &["unmotorised"],
];

pub(crate) static ENTRY_UNMUNICIPALIZEDDER_14808890863362223595: VariantsMap = [
    &["unmunicipalizedder"],
    &["unmunicipalisedder"],
    &["unmunicipalizedder"],
    &["unmunicipalisedder"],
];

pub(crate) static ENTRY_UNMUNICIPALIZEDDEST_10995903656105467027: VariantsMap = [
    &["unmunicipalizeddest"],
    &["unmunicipaliseddest"],
    &["unmunicipalizeddest"],
    &["unmunicipaliseddest"],
];

pub(crate) static ENTRY_UNMUNICIPALIZEDS_9334949007165725184: VariantsMap = [
    &["unmunicipalizeds"],
    &["unmunicipaliseds"],
    &["unmunicipalizeds"],
    &["unmunicipaliseds"],
];

pub(crate) static ENTRY_UNMUNICIPALIZED_12122839729704889640: VariantsMap = [
    &["unmunicipalized"],
    &["unmunicipalised"],
    &["unmunicipalized"],
    &["unmunicipalised"],
];

pub(crate) static ENTRY_UNMUTUALIZEDDER_6120773781645783648: VariantsMap = [
    &["unmutualizedder"],
    &["unmutualisedder"],
    &["unmutualizedder"],
    &["unmutualisedder"],
];

pub(crate) static ENTRY_UNMUTUALIZEDDEST_644266925710147172: VariantsMap = [
    &["unmutualizeddest"],
    &["unmutualiseddest"],
    &["unmutualizeddest"],
    &["unmutualiseddest"],
];

pub(crate) static ENTRY_UNMUTUALIZEDS_4071796319304281606: VariantsMap = [
    &["unmutualizeds"],
    &["unmutualiseds"],
    &["unmutualizeds"],
    &["unmutualiseds"],
];

pub(crate) static ENTRY_UNMUTUALIZED_11726828009810562838: VariantsMap = [
    &["unmutualized"],
    &["unmutualised"],
    &["unmutualized"],
    &["unmutualised"],
];

pub(crate) static ENTRY_UNMYSTICIZED_11062556013503200560: VariantsMap = [
    &["unmysticized"],
    &["unmysticised"],
    &["unmysticized"],
    &["unmysticised"],
];

pub(crate) static ENTRY_UNMYSTICIZES_17390241333164575800: VariantsMap = [
    &["unmysticizes"],
    &["unmysticises"],
    &["unmysticizes"],
    &["unmysticises"],
];

pub(crate) static ENTRY_UNMYSTICIZE_12388597900585961073: VariantsMap = [
    &["unmysticize"],
    &["unmysticise"],
    &["unmysticize"],
    &["unmysticise"],
];

pub(crate) static ENTRY_UNMYSTICIZING_12458261619992424221: VariantsMap = [
    &["unmysticizing"],
    &["unmysticising"],
    &["unmysticizing"],
    &["unmysticising"],
];

pub(crate) static ENTRY_UNNATIONALIZEDDER_10308676019005864186: VariantsMap = [
    &["unnationalizedder"],
    &["unnationalisedder"],
    &["unnationalizedder"],
    &["unnationalisedder"],
];

pub(crate) static ENTRY_UNNATIONALIZEDDEST_8402812183279300374: VariantsMap = [
    &["unnationalizeddest"],
    &["unnationaliseddest"],
    &["unnationalizeddest"],
    &["unnationaliseddest"],
];

pub(crate) static ENTRY_UNNATIONALIZED_13305692858549585336: VariantsMap = [
    &["unnationalized"],
    &["unnationalised"],
    &["unnationalized"],
    &["unnationalised"],
];

pub(crate) static ENTRY_UNNATURALIZABLES_13596151371214167721: VariantsMap = [
    &["unnaturalizables"],
    &["unnaturalisables"],
    &["unnaturalizables"],
    &["unnaturalisables"],
];

pub(crate) static ENTRY_UNNATURALIZABLE_16480663493395775143: VariantsMap = [
    &["unnaturalizable"],
    &["unnaturalisable"],
    &["unnaturalizable"],
    &["unnaturalisable"],
];

pub(crate) static ENTRY_UNNATURALIZED_5866490090567009574: VariantsMap = [
    &["unnaturalized"],
    &["unnaturalised"],
    &["unnaturalized"],
    &["unnaturalised"],
];

pub(crate) static ENTRY_UNNATURALIZES_8476052793010992170: VariantsMap = [
    &["unnaturalizes"],
    &["unnaturalises"],
    &["unnaturalizes"],
    &["unnaturalises"],
];

pub(crate) static ENTRY_UNNATURALIZE_16622774998946225122: VariantsMap = [
    &["unnaturalize"],
    &["unnaturalise"],
    &["unnaturalize"],
    &["unnaturalise"],
];

pub(crate) static ENTRY_UNNATURALIZING_6880744307034128987: VariantsMap = [
    &["unnaturalizing"],
    &["unnaturalising"],
    &["unnaturalizing"],
    &["unnaturalising"],
];

pub(crate) static ENTRY_UNNEIGHBORED_8697632354577371299: VariantsMap = [
    &["unneighbored"],
    &["unneighboured"],
    &["unneighboured"],
    &["unneighboured"],
];

pub(crate) static ENTRY_UNNEIGHBORLIER_16454004623478436285: VariantsMap = [
    &["unneighborlier"],
    &["unneighbourlier"],
    &["unneighbourlier"],
    &["unneighbourlier"],
];

pub(crate) static ENTRY_UNNEIGHBORLIEST_5019821008335017472: VariantsMap = [
    &["unneighborliest"],
    &["unneighbourliest"],
    &["unneighbourliest"],
    &["unneighbourliest"],
];

pub(crate) static ENTRY_UNNEIGHBORLIKES_14251473804138837266: VariantsMap = [
    &["unneighborlikes"],
    &["unneighbourlikes"],
    &["unneighbourlikes"],
    &["unneighbourlikes"],
];

pub(crate) static ENTRY_UNNEIGHBORLIKE_930605837147479219: VariantsMap = [
    &["unneighborlike"],
    &["unneighbourlike"],
    &["unneighbourlike"],
    &["unneighbourlike"],
];

pub(crate) static ENTRY_UNNEIGHBORLINESSES_8622001054811759799: VariantsMap = [
    &["unneighborlinesses"],
    &["unneighbourlinesses"],
    &["unneighbourlinesses"],
    &["unneighbourlinesses"],
];

pub(crate) static ENTRY_UNNEIGHBORLINESS_4945316531198682259: VariantsMap = [
    &["unneighborliness"],
    &["unneighbourliness"],
    &["unneighbourliness"],
    &["unneighbourliness"],
];

pub(crate) static ENTRY_UNNEIGHBORLY_5887888161506730946: VariantsMap = [
    &["unneighborly"],
    &["unneighbourly"],
    &["unneighbourly"],
    &["unneighbourly"],
];

pub(crate) static ENTRY_UNNEUTRALIZED_3127903145081496539: VariantsMap = [
    &["unneutralized"],
    &["unneutralised"],
    &["unneutralized"],
    &["unneutralised"],
];

pub(crate) static ENTRY_UNNEUTRALIZE_18018061019251914124: VariantsMap = [
    &["unneutralize"],
    &["unneutralise"],
    &["unneutralize"],
    &["unneutralise"],
];

pub(crate) static ENTRY_UNNEUTRALIZING_12083896961836140168: VariantsMap = [
    &["unneutralizing"],
    &["unneutralising"],
    &["unneutralizing"],
    &["unneutralising"],
];

pub(crate) static ENTRY_UNNITROGENIZEDDER_4668460112104893964: VariantsMap = [
    &["unnitrogenizedder"],
    &["unnitrogenisedder"],
    &["unnitrogenizedder"],
    &["unnitrogenisedder"],
];

pub(crate) static ENTRY_UNNITROGENIZEDDEST_12183639058740360422: VariantsMap = [
    &["unnitrogenizeddest"],
    &["unnitrogeniseddest"],
    &["unnitrogenizeddest"],
    &["unnitrogeniseddest"],
];

pub(crate) static ENTRY_UNNITROGENIZEDS_16568352907153090415: VariantsMap = [
    &["unnitrogenizeds"],
    &["unnitrogeniseds"],
    &["unnitrogenizeds"],
    &["unnitrogeniseds"],
];

pub(crate) static ENTRY_UNNITROGENIZED_11363970866698133470: VariantsMap = [
    &["unnitrogenized"],
    &["unnitrogenised"],
    &["unnitrogenized"],
    &["unnitrogenised"],
];

pub(crate) static ENTRY_UNNONCOLORABLES_15129902177178103036: VariantsMap = [
    &["unnoncolorables"],
    &["unnoncolourables"],
    &["unnoncolourables"],
    &["unnoncolourables"],
];

pub(crate) static ENTRY_UNNONCOLORABLIES_511634610054739335: VariantsMap = [
    &["unnoncolorablies"],
    &["unnoncolourablies"],
    &["unnoncolourablies"],
    &["unnoncolourablies"],
];

pub(crate) static ENTRY_UNNONCOLORABLY_3291489823657748402: VariantsMap = [
    &["unnoncolorably"],
    &["unnoncolourably"],
    &["unnoncolourably"],
    &["unnoncolourably"],
];

pub(crate) static ENTRY_UNNORMALIZEDDER_4485274349407128413: VariantsMap = [
    &["unnormalizedder"],
    &["unnormalisedder"],
    &["unnormalizedder"],
    &["unnormalisedder"],
];

pub(crate) static ENTRY_UNNORMALIZEDDEST_14330056459661112775: VariantsMap = [
    &["unnormalizeddest"],
    &["unnormaliseddest"],
    &["unnormalizeddest"],
    &["unnormaliseddest"],
];

pub(crate) static ENTRY_UNNORMALIZED_4666322878556737891: VariantsMap = [
    &["unnormalized"],
    &["unnormalised"],
    &["unnormalized"],
    &["unnormalised"],
];

pub(crate) static ENTRY_UNNORMALIZES_7328316644426171612: VariantsMap = [
    &["unnormalizes"],
    &["unnormalises"],
    &["unnormalizes"],
    &["unnormalises"],
];

pub(crate) static ENTRY_UNNORMALIZE_6669476142619447499: VariantsMap = [
    &["unnormalize"],
    &["unnormalise"],
    &["unnormalize"],
    &["unnormalise"],
];

pub(crate) static ENTRY_UNNORMALIZINGER_9460951407730348444: VariantsMap = [
    &["unnormalizinger"],
    &["unnormalisinger"],
    &["unnormalizinger"],
    &["unnormalisinger"],
];

pub(crate) static ENTRY_UNNORMALIZINGEST_18164527599111165108: VariantsMap = [
    &["unnormalizingest"],
    &["unnormalisingest"],
    &["unnormalizingest"],
    &["unnormalisingest"],
];

pub(crate) static ENTRY_UNNORMALIZING_2469755702378752753: VariantsMap = [
    &["unnormalizing"],
    &["unnormalising"],
    &["unnormalizing"],
    &["unnormalising"],
];

pub(crate) static ENTRY_UNOPTIMIZED_16942042074875027551: VariantsMap = [
    &["unoptimized"],
    &["unoptimised"],
    &["unoptimized"],
    &["unoptimised"],
];

pub(crate) static ENTRY_UNOPTIMIZES_4650439389608219823: VariantsMap = [
    &["unoptimizes"],
    &["unoptimises"],
    &["unoptimizes"],
    &["unoptimises"],
];

pub(crate) static ENTRY_UNOPTIMIZE_2225906295826486470: VariantsMap = [
    &["unoptimize"],
    &["unoptimise"],
    &["unoptimize"],
    &["unoptimise"],
];

pub(crate) static ENTRY_UNOPTIMIZING_13917033577308167414: VariantsMap = [
    &["unoptimizing"],
    &["unoptimising"],
    &["unoptimizing"],
    &["unoptimising"],
];

pub(crate) static ENTRY_UNORGANIZABLER_12327186123744522228: VariantsMap = [
    &["unorganizabler"],
    &["unorganisabler"],
    &["unorganizabler"],
    &["unorganisabler"],
];

pub(crate) static ENTRY_UNORGANIZABLEST_14186046003153225163: VariantsMap = [
    &["unorganizablest"],
    &["unorganisablest"],
    &["unorganizablest"],
    &["unorganisablest"],
];

pub(crate) static ENTRY_UNORGANIZABLES_7347832752348610754: VariantsMap = [
    &["unorganizables"],
    &["unorganisables"],
    &["unorganizables"],
    &["unorganisables"],
];

pub(crate) static ENTRY_UNORGANIZABLE_11991965426515761260: VariantsMap = [
    &["unorganizable"],
    &["unorganisable"],
    &["unorganizable"],
    &["unorganisable"],
];

pub(crate) static ENTRY_UNORGANIZEDLY_12175435547618889361: VariantsMap = [
    &["unorganizedly"],
    &["unorganisedly"],
    &["unorganizedly"],
    &["unorganisedly"],
];

pub(crate) static ENTRY_UNORGANIZEDNESS_16136998940664713050: VariantsMap = [
    &["unorganizedness"],
    &["unorganisedness"],
    &["unorganizedness"],
    &["unorganisedness"],
];

pub(crate) static ENTRY_UNORGANIZED_11234215167570055764: VariantsMap = [
    &["unorganized"],
    &["unorganised"],
    &["unorganized"],
    &["unorganised"],
];

pub(crate) static ENTRY_UNORGANIZE_13934278640366945691: VariantsMap = [
    &["unorganize"],
    &["unorganise"],
    &["unorganize"],
    &["unorganise"],
];

pub(crate) static ENTRY_UNOXIDIZABLER_1507332604073799190: VariantsMap = [
    &["unoxidizabler"],
    &["unoxidisabler"],
    &["unoxidizabler"],
    &["unoxidisabler"],
];

pub(crate) static ENTRY_UNOXIDIZABLEST_3100338328549585672: VariantsMap = [
    &["unoxidizablest"],
    &["unoxidisablest"],
    &["unoxidizablest"],
    &["unoxidisablest"],
];

pub(crate) static ENTRY_UNOXIDIZABLES_13262035573197556458: VariantsMap = [
    &["unoxidizables"],
    &["unoxidisables"],
    &["unoxidizables"],
    &["unoxidisables"],
];

pub(crate) static ENTRY_UNOXIDIZABLE_1866331079475280360: VariantsMap = [
    &["unoxidizable"],
    &["unoxidisable"],
    &["unoxidizable"],
    &["unoxidisable"],
];

pub(crate) static ENTRY_UNOXIDIZEDDER_12013452575486590169: VariantsMap = [
    &["unoxidizedder"],
    &["unoxidisedder"],
    &["unoxidizedder"],
    &["unoxidisedder"],
];

pub(crate) static ENTRY_UNOXIDIZEDDEST_7098572889716170401: VariantsMap = [
    &["unoxidizeddest"],
    &["unoxidiseddest"],
    &["unoxidizeddest"],
    &["unoxidiseddest"],
];

pub(crate) static ENTRY_UNOXIDIZED_6163194422377055559: VariantsMap = [
    &["unoxidized"],
    &["unoxidised"],
    &["unoxidized"],
    &["unoxidised"],
];

pub(crate) static ENTRY_UNOXYGENIZEDS_9668138306819694641: VariantsMap = [
    &["unoxygenizeds"],
    &["unoxygeniseds"],
    &["unoxygenizeds"],
    &["unoxygeniseds"],
];

pub(crate) static ENTRY_UNOXYGENIZED_3138801117611264462: VariantsMap = [
    &["unoxygenized"],
    &["unoxygenised"],
    &["unoxygenized"],
    &["unoxygenised"],
];

pub(crate) static ENTRY_UNPAGANIZES_7555124108067566716: VariantsMap = [
    &["unpaganizes"],
    &["unpaganises"],
    &["unpaganizes"],
    &["unpaganises"],
];

pub(crate) static ENTRY_UNPAGANIZE_4513523638718785743: VariantsMap = [
    &["unpaganize"],
    &["unpaganise"],
    &["unpaganize"],
    &["unpaganise"],
];

pub(crate) static ENTRY_UNPALISADED_9363420074275544577: VariantsMap = [
    &["unpalisaded"],
    &["unpalisadoed"],
    &["unpalisadoed"],
    &["unpalisadoed"],
];

pub(crate) static ENTRY_UNPANEGYRIZED_18214590288764386066: VariantsMap = [
    &["unpanegyrized"],
    &["unpanegyrised"],
    &["unpanegyrized"],
    &["unpanegyrised"],
];

pub(crate) static ENTRY_UNPARAGONIZEDS_13371268766791176199: VariantsMap = [
    &["unparagonizeds"],
    &["unparagoniseds"],
    &["unparagonizeds"],
    &["unparagoniseds"],
];

pub(crate) static ENTRY_UNPARAGONIZED_14832217974011410500: VariantsMap = [
    &["unparagonized"],
    &["unparagonised"],
    &["unparagonized"],
    &["unparagonised"],
];

pub(crate) static ENTRY_UNPARALYZEDDER_12368724256798535530: VariantsMap = [
    &["unparalyzedder"],
    &["unparalysedder"],
    &["unparalysedder"],
    &["unparalysedder"],
];

pub(crate) static ENTRY_UNPARALYZEDDEST_11163810169190211510: VariantsMap = [
    &["unparalyzeddest"],
    &["unparalyseddest"],
    &["unparalyseddest"],
    &["unparalyseddest"],
];

pub(crate) static ENTRY_UNPARALYZEDS_14494225354968815994: VariantsMap = [
    &["unparalyzeds"],
    &["unparalyseds"],
    &["unparalyseds"],
    &["unparalyseds"],
];

pub(crate) static ENTRY_UNPARALYZED_6958549761941429886: VariantsMap = [
    &["unparalyzed"],
    &["unparalysed"],
    &["unparalysed"],
    &["unparalysed"],
];

pub(crate) static ENTRY_UNPARAMETERIZED_16947457520544710568: VariantsMap = [
    &["unparameterized"],
    &["unparameterised"],
    &["unparameterized"],
    &["unparameterised"],
];

pub(crate) static ENTRY_UNPARAMETRIZED_12259132055588179393: VariantsMap = [
    &["unparametrized"],
    &["unparametrised"],
    &["unparametrized"],
    &["unparametrised"],
];

pub(crate) static ENTRY_UNPARCELEDDER_11844117497562549294: VariantsMap = [
    &["unparceledder"],
    &["unparcelledder"],
    &["unparcelledder"],
    &["unparcelledder"],
];

pub(crate) static ENTRY_UNPARCELEDDEST_10483130332035933664: VariantsMap = [
    &["unparceleddest"],
    &["unparcelleddest"],
    &["unparcelleddest"],
    &["unparcelleddest"],
];

pub(crate) static ENTRY_UNPARCELED_262743817097801452: VariantsMap = [
    &["unparceled"],
    &["unparcelled"],
    &["unparcelled"],
    &["unparcelled"],
];

pub(crate) static ENTRY_UNPARENTHESIZED_7803630114504922502: VariantsMap = [
    &["unparenthesized"],
    &["unparenthesised"],
    &["unparenthesized"],
    &["unparenthesised"],
];

pub(crate) static ENTRY_UNPARTICULARIZEDDER_11469278173298354240: VariantsMap = [
    &["unparticularizedder"],
    &["unparticularisedder"],
    &["unparticularizedder"],
    &["unparticularisedder"],
];

pub(crate) static ENTRY_UNPARTICULARIZEDDEST_8647720932351021234: VariantsMap = [
    &["unparticularizeddest"],
    &["unparticulariseddest"],
    &["unparticularizeddest"],
    &["unparticulariseddest"],
];

pub(crate) static ENTRY_UNPARTICULARIZEDS_11035216646331913261: VariantsMap = [
    &["unparticularizeds"],
    &["unparticulariseds"],
    &["unparticularizeds"],
    &["unparticulariseds"],
];

pub(crate) static ENTRY_UNPARTICULARIZED_13897465210935993798: VariantsMap = [
    &["unparticularized"],
    &["unparticularised"],
    &["unparticularized"],
    &["unparticularised"],
];

pub(crate) static ENTRY_UNPARTICULARIZINGER_11495496854437849250: VariantsMap = [
    &["unparticularizinger"],
    &["unparticularisinger"],
    &["unparticularizinger"],
    &["unparticularisinger"],
];

pub(crate) static ENTRY_UNPARTICULARIZINGEST_10293813669141093640: VariantsMap = [
    &["unparticularizingest"],
    &["unparticularisingest"],
    &["unparticularizingest"],
    &["unparticularisingest"],
];

pub(crate) static ENTRY_UNPARTICULARIZINGS_12705022570599294056: VariantsMap = [
    &["unparticularizings"],
    &["unparticularisings"],
    &["unparticularizings"],
    &["unparticularisings"],
];

pub(crate) static ENTRY_UNPARTICULARIZING_9707431197331693971: VariantsMap = [
    &["unparticularizing"],
    &["unparticularising"],
    &["unparticularizing"],
    &["unparticularising"],
];

pub(crate) static ENTRY_UNPARTIZAN_2554553357403784183: VariantsMap = [
    &["unpartizan"],
    &["unpartisan"],
    &["unpartizan"],
    &["unpartisan"],
];

pub(crate) static ENTRY_UNPASTEURIZED_5265896385107446936: VariantsMap = [
    &["unpasteurized"],
    &["unpasteurised"],
    &["unpasteurized"],
    &["unpasteurised"],
];

pub(crate) static ENTRY_UNPATRONIZABLER_14573100045387724371: VariantsMap = [
    &["unpatronizabler"],
    &["unpatronisabler"],
    &["unpatronizabler"],
    &["unpatronisabler"],
];

pub(crate) static ENTRY_UNPATRONIZABLEST_16886725498057048673: VariantsMap = [
    &["unpatronizablest"],
    &["unpatronisablest"],
    &["unpatronizablest"],
    &["unpatronisablest"],
];

pub(crate) static ENTRY_UNPATRONIZABLES_18262489304591786860: VariantsMap = [
    &["unpatronizables"],
    &["unpatronisables"],
    &["unpatronizables"],
    &["unpatronisables"],
];

pub(crate) static ENTRY_UNPATRONIZABLE_14055227709009863359: VariantsMap = [
    &["unpatronizable"],
    &["unpatronisable"],
    &["unpatronizable"],
    &["unpatronisable"],
];

pub(crate) static ENTRY_UNPATRONIZED_9325244204582847374: VariantsMap = [
    &["unpatronized"],
    &["unpatronised"],
    &["unpatronized"],
    &["unpatronised"],
];

pub(crate) static ENTRY_UNPATRONIZING_6560093157771836424: VariantsMap = [
    &["unpatronizing"],
    &["unpatronising"],
    &["unpatronizing"],
    &["unpatronising"],
];

pub(crate) static ENTRY_UNPAUPERIZEDS_7927657084998837690: VariantsMap = [
    &["unpauperizeds"],
    &["unpauperiseds"],
    &["unpauperizeds"],
    &["unpauperiseds"],
];

pub(crate) static ENTRY_UNPAUPERIZED_4384463109542126829: VariantsMap = [
    &["unpauperized"],
    &["unpauperised"],
    &["unpauperized"],
    &["unpauperised"],
];

pub(crate) static ENTRY_UNPENALIZEDDER_4990731968902937554: VariantsMap = [
    &["unpenalizedder"],
    &["unpenalisedder"],
    &["unpenalizedder"],
    &["unpenalisedder"],
];

pub(crate) static ENTRY_UNPENALIZEDDEST_10380252802297336859: VariantsMap = [
    &["unpenalizeddest"],
    &["unpenaliseddest"],
    &["unpenalizeddest"],
    &["unpenaliseddest"],
];

pub(crate) static ENTRY_UNPENALIZED_725934609298878108: VariantsMap = [
    &["unpenalized"],
    &["unpenalised"],
    &["unpenalized"],
    &["unpenalised"],
];

pub(crate) static ENTRY_UNPERCEPTIVELY_13837914378436327028: VariantsMap = [
    &["unperceptively"],
    &["unpreceptively"],
    &["unpreceptively"],
    &["unpreceptively"],
];

pub(crate) static ENTRY_UNPERSONALIZED_11833179297358942798: VariantsMap = [
    &["unpersonalized"],
    &["unpersonalised"],
    &["unpersonalized"],
    &["unpersonalised"],
];

pub(crate) static ENTRY_UNPERSONALIZING_10320557453890272802: VariantsMap = [
    &["unpersonalizing"],
    &["unpersonalising"],
    &["unpersonalizing"],
    &["unpersonalising"],
];

pub(crate) static ENTRY_UNPHILOSOPHIZED_12661540003568404124: VariantsMap = [
    &["unphilosophized"],
    &["unphilosophised"],
    &["unphilosophized"],
    &["unphilosophised"],
];

pub(crate) static ENTRY_UNPHILOSOPHIZES_5880855030624936917: VariantsMap = [
    &["unphilosophizes"],
    &["unphilosophises"],
    &["unphilosophizes"],
    &["unphilosophises"],
];

pub(crate) static ENTRY_UNPHILOSOPHIZE_7144628023446557783: VariantsMap = [
    &["unphilosophize"],
    &["unphilosophise"],
    &["unphilosophize"],
    &["unphilosophise"],
];

pub(crate) static ENTRY_UNPHOSPHATIZEDDER_10420838305229474623: VariantsMap = [
    &["unphosphatizedder"],
    &["unphosphatisedder"],
    &["unphosphatizedder"],
    &["unphosphatisedder"],
];

pub(crate) static ENTRY_UNPHOSPHATIZEDDEST_8261623546482924636: VariantsMap = [
    &["unphosphatizeddest"],
    &["unphosphatiseddest"],
    &["unphosphatizeddest"],
    &["unphosphatiseddest"],
];

pub(crate) static ENTRY_UNPHOSPHATIZEDS_3767209936877351046: VariantsMap = [
    &["unphosphatizeds"],
    &["unphosphatiseds"],
    &["unphosphatizeds"],
    &["unphosphatiseds"],
];

pub(crate) static ENTRY_UNPHOSPHATIZED_13106493599965727596: VariantsMap = [
    &["unphosphatized"],
    &["unphosphatised"],
    &["unphosphatized"],
    &["unphosphatised"],
];

pub(crate) static ENTRY_UNPICTORIALIZED_5301866355430257659: VariantsMap = [
    &["unpictorialized"],
    &["unpictorialised"],
    &["unpictorialized"],
    &["unpictorialised"],
];

pub(crate) static ENTRY_UNPICTORIALIZE_3126347844933178338: VariantsMap = [
    &["unpictorialize"],
    &["unpictorialise"],
    &["unpictorialize"],
    &["unpictorialise"],
];

pub(crate) static ENTRY_UNPICTORIALIZING_10203584904739205498: VariantsMap = [
    &["unpictorializing"],
    &["unpictorialising"],
    &["unpictorializing"],
    &["unpictorialising"],
];

pub(crate) static ENTRY_UNPLAGIARIZEDDER_2844070019396842238: VariantsMap = [
    &["unplagiarizedder"],
    &["unplagiarisedder"],
    &["unplagiarizedder"],
    &["unplagiarisedder"],
];

pub(crate) static ENTRY_UNPLAGIARIZEDDEST_10297070360250990028: VariantsMap = [
    &["unplagiarizeddest"],
    &["unplagiariseddest"],
    &["unplagiarizeddest"],
    &["unplagiariseddest"],
];

pub(crate) static ENTRY_UNPLAGIARIZEDS_16363973607034012033: VariantsMap = [
    &["unplagiarizeds"],
    &["unplagiariseds"],
    &["unplagiarizeds"],
    &["unplagiariseds"],
];

pub(crate) static ENTRY_UNPLAGIARIZED_569462043008408881: VariantsMap = [
    &["unplagiarized"],
    &["unplagiarised"],
    &["unplagiarized"],
    &["unplagiarised"],
];

pub(crate) static ENTRY_UNPLURALIZED_730997926914844312: VariantsMap = [
    &["unpluralized"],
    &["unpluralised"],
    &["unpluralized"],
    &["unpluralised"],
];

pub(crate) static ENTRY_UNPOETICIZEDDER_16553304193349405175: VariantsMap = [
    &["unpoeticizedder"],
    &["unpoeticisedder"],
    &["unpoeticizedder"],
    &["unpoeticisedder"],
];

pub(crate) static ENTRY_UNPOETICIZEDDEST_11199398706019278294: VariantsMap = [
    &["unpoeticizeddest"],
    &["unpoeticiseddest"],
    &["unpoeticizeddest"],
    &["unpoeticiseddest"],
];

pub(crate) static ENTRY_UNPOETICIZEDS_17118411588245987939: VariantsMap = [
    &["unpoeticizeds"],
    &["unpoeticiseds"],
    &["unpoeticizeds"],
    &["unpoeticiseds"],
];

pub(crate) static ENTRY_UNPOETICIZED_3981988256882871001: VariantsMap = [
    &["unpoeticized"],
    &["unpoeticised"],
    &["unpoeticized"],
    &["unpoeticised"],
];

pub(crate) static ENTRY_UNPOETIZED_18184155777880410653: VariantsMap = [
    &["unpoetized"],
    &["unpoetised"],
    &["unpoetized"],
    &["unpoetised"],
];

pub(crate) static ENTRY_UNPOETIZES_7036862048295060125: VariantsMap = [
    &["unpoetizes"],
    &["unpoetises"],
    &["unpoetizes"],
    &["unpoetises"],
];

pub(crate) static ENTRY_UNPOETIZE_11031261235007991496: VariantsMap = [
    &["unpoetize"],
    &["unpoetise"],
    &["unpoetize"],
    &["unpoetise"],
];

pub(crate) static ENTRY_UNPOLARIZABLES_906462527546243871: VariantsMap = [
    &["unpolarizables"],
    &["unpolarisables"],
    &["unpolarizables"],
    &["unpolarisables"],
];

pub(crate) static ENTRY_UNPOLARIZABLE_17741525376413399461: VariantsMap = [
    &["unpolarizable"],
    &["unpolarisable"],
    &["unpolarizable"],
    &["unpolarisable"],
];

pub(crate) static ENTRY_UNPOLARIZEDDER_18443570066569643692: VariantsMap = [
    &["unpolarizedder"],
    &["unpolarisedder"],
    &["unpolarizedder"],
    &["unpolarisedder"],
];

pub(crate) static ENTRY_UNPOLARIZEDDEST_13477670326494096714: VariantsMap = [
    &["unpolarizeddest"],
    &["unpolariseddest"],
    &["unpolarizeddest"],
    &["unpolariseddest"],
];

pub(crate) static ENTRY_UNPOLARIZEDS_1059673460729973543: VariantsMap = [
    &["unpolarizeds"],
    &["unpolariseds"],
    &["unpolarizeds"],
    &["unpolariseds"],
];

pub(crate) static ENTRY_UNPOLARIZED_2025887269421260061: VariantsMap = [
    &["unpolarized"],
    &["unpolarised"],
    &["unpolarized"],
    &["unpolarised"],
];

pub(crate) static ENTRY_UNPOLYMERIZEDDER_13246460519378073245: VariantsMap = [
    &["unpolymerizedder"],
    &["unpolymerisedder"],
    &["unpolymerizedder"],
    &["unpolymerisedder"],
];

pub(crate) static ENTRY_UNPOLYMERIZEDDEST_6621171249833858730: VariantsMap = [
    &["unpolymerizeddest"],
    &["unpolymeriseddest"],
    &["unpolymerizeddest"],
    &["unpolymeriseddest"],
];

pub(crate) static ENTRY_UNPOLYMERIZEDS_11993450819958873813: VariantsMap = [
    &["unpolymerizeds"],
    &["unpolymeriseds"],
    &["unpolymerizeds"],
    &["unpolymeriseds"],
];

pub(crate) static ENTRY_UNPOLYMERIZED_12019370435077113473: VariantsMap = [
    &["unpolymerized"],
    &["unpolymerised"],
    &["unpolymerized"],
    &["unpolymerised"],
];

pub(crate) static ENTRY_UNPOPULARIZED_11819251259971662834: VariantsMap = [
    &["unpopularized"],
    &["unpopularised"],
    &["unpopularized"],
    &["unpopularised"],
];

pub(crate) static ENTRY_UNPOPULARIZES_11095429734262523629: VariantsMap = [
    &["unpopularizes"],
    &["unpopularises"],
    &["unpopularizes"],
    &["unpopularises"],
];

pub(crate) static ENTRY_UNPOPULARIZE_399092079636575360: VariantsMap = [
    &["unpopularize"],
    &["unpopularise"],
    &["unpopularize"],
    &["unpopularise"],
];

pub(crate) static ENTRY_UNPRACTICEDDER_17255783698342166608: VariantsMap = [
    &["unpracticedder"],
    &["unpractisedder"],
    &["unpractisedder"],
    &["unpractisedder"],
];

pub(crate) static ENTRY_UNPRACTICEDDEST_12496382526145371505: VariantsMap = [
    &["unpracticeddest"],
    &["unpractiseddest"],
    &["unpractiseddest"],
    &["unpractiseddest"],
];

pub(crate) static ENTRY_UNPRACTICED_6794067215889205747: VariantsMap = [
    &["unpracticed"],
    &["unpractised"],
    &["unpractised"],
    &["unpractised"],
];

pub(crate) static ENTRY_UNPRESSURIZED_5109647751733072461: VariantsMap = [
    &["unpressurized"],
    &["unpressurised"],
    &["unpressurized"],
    &["unpressurised"],
];

pub(crate) static ENTRY_UNPROTESTANTIZED_12530485034019770123: VariantsMap = [
    &["unprotestantized"],
    &["unprotestantised"],
    &["unprotestantized"],
    &["unprotestantised"],
];

pub(crate) static ENTRY_UNPROTESTANTIZES_4530211699671168989: VariantsMap = [
    &["unprotestantizes"],
    &["unprotestantises"],
    &["unprotestantizes"],
    &["unprotestantises"],
];

pub(crate) static ENTRY_UNPROTESTANTIZE_5546605125187361751: VariantsMap = [
    &["unprotestantize"],
    &["unprotestantise"],
    &["unprotestantize"],
    &["unprotestantise"],
];

pub(crate) static ENTRY_UNPROTESTANTIZING_14528978671585766161: VariantsMap = [
    &["unprotestantizing"],
    &["unprotestantising"],
    &["unprotestantizing"],
    &["unprotestantising"],
];

pub(crate) static ENTRY_UNPUBLICIZED_11411018472574932653: VariantsMap = [
    &["unpublicized"],
    &["unpublicised"],
    &["unpublicized"],
    &["unpublicised"],
];

pub(crate) static ENTRY_UNPULVERIZEDDER_5484774944919909274: VariantsMap = [
    &["unpulverizedder"],
    &["unpulverisedder"],
    &["unpulverizedder"],
    &["unpulverisedder"],
];

pub(crate) static ENTRY_UNPULVERIZEDDEST_8625344905804142571: VariantsMap = [
    &["unpulverizeddest"],
    &["unpulveriseddest"],
    &["unpulverizeddest"],
    &["unpulveriseddest"],
];

pub(crate) static ENTRY_UNPULVERIZED_3203903971461779566: VariantsMap = [
    &["unpulverized"],
    &["unpulverised"],
    &["unpulverized"],
    &["unpulverised"],
];

pub(crate) static ENTRY_UNPULVERIZES_7678149392200211776: VariantsMap = [
    &["unpulverizes"],
    &["unpulverises"],
    &["unpulverizes"],
    &["unpulverises"],
];

pub(crate) static ENTRY_UNPULVERIZE_4306052034176949975: VariantsMap = [
    &["unpulverize"],
    &["unpulverise"],
    &["unpulverize"],
    &["unpulverise"],
];

pub(crate) static ENTRY_UNQUANTIZED_2276689698541240314: VariantsMap = [
    &["unquantized"],
    &["unquantised"],
    &["unquantized"],
    &["unquantised"],
];

pub(crate) static ENTRY_UNRADICALIZES_10451136333567222975: VariantsMap = [
    &["unradicalizes"],
    &["unradicalises"],
    &["unradicalizes"],
    &["unradicalises"],
];

pub(crate) static ENTRY_UNRADICALIZE_955382331879439831: VariantsMap = [
    &["unradicalize"],
    &["unradicalise"],
    &["unradicalize"],
    &["unradicalise"],
];

pub(crate) static ENTRY_UNRANCOREDDER_3817724469012828292: VariantsMap = [
    &["unrancoredder"],
    &["unrancouredder"],
    &["unrancouredder"],
    &["unrancouredder"],
];

pub(crate) static ENTRY_UNRANCOREDDEST_11592021472933036375: VariantsMap = [
    &["unrancoreddest"],
    &["unrancoureddest"],
    &["unrancoureddest"],
    &["unrancoureddest"],
];

pub(crate) static ENTRY_UNRANCOREDS_3912120812229597055: VariantsMap = [
    &["unrancoreds"],
    &["unrancoureds"],
    &["unrancoureds"],
    &["unrancoureds"],
];

pub(crate) static ENTRY_UNRANCORED_5635330286579157636: VariantsMap = [
    &["unrancored"],
    &["unrancoured"],
    &["unrancoured"],
    &["unrancoured"],
];

pub(crate) static ENTRY_UNRANCOROUS_1719417862290606862: VariantsMap = [
    &["unrancorous"],
    &["unrancourous"],
    &["unrancourous"],
    &["unrancourous"],
];

pub(crate) static ENTRY_UNRATIONALIZED_125325346924816385: VariantsMap = [
    &["unrationalized"],
    &["unrationalised"],
    &["unrationalized"],
    &["unrationalised"],
];

pub(crate) static ENTRY_UNRATIONALIZING_6157188971216094486: VariantsMap = [
    &["unrationalizing"],
    &["unrationalising"],
    &["unrationalizing"],
    &["unrationalising"],
];

pub(crate) static ENTRY_UNRAVELED_903111391532922846: VariantsMap = [
    &["unraveled"],
    &["unravelled"],
    &["unravelled"],
    &["unravelled"],
];

pub(crate) static ENTRY_UNRAVELERS_12461798051374270996: VariantsMap = [
    &["unravelers"],
    &["unravellers"],
    &["unravellers"],
    &["unravellers"],
];

pub(crate) static ENTRY_UNRAVELER_8361573843424236468: VariantsMap = [
    &["unraveler"],
    &["unraveller"],
    &["unraveller"],
    &["unraveller"],
];

pub(crate) static ENTRY_UNRAVELING_765040154842555334: VariantsMap = [
    &["unraveling"],
    &["unravelling"],
    &["unravelling"],
    &["unravelling"],
];

pub(crate) static ENTRY_UNREALIZABLES_11601733641828871347: VariantsMap = [
    &["unrealizables"],
    &["unrealisables"],
    &["unrealizables"],
    &["unrealisables"],
];

pub(crate) static ENTRY_UNREALIZABLE_11418766116297521465: VariantsMap = [
    &["unrealizable"],
    &["unrealisable"],
    &["unrealizable"],
    &["unrealisable"],
];

pub(crate) static ENTRY_UNREALIZED_13998697549380132918: VariantsMap = [
    &["unrealized"],
    &["unrealised"],
    &["unrealized"],
    &["unrealised"],
];

pub(crate) static ENTRY_UNREALIZES_16009560303031337105: VariantsMap = [
    &["unrealizes"],
    &["unrealises"],
    &["unrealizes"],
    &["unrealises"],
];

pub(crate) static ENTRY_UNREALIZE_13293507645818343125: VariantsMap = [
    &["unrealize"],
    &["unrealise"],
    &["unrealize"],
    &["unrealise"],
];

pub(crate) static ENTRY_UNREALIZINGS_7526494100193070690: VariantsMap = [
    &["unrealizings"],
    &["unrealisings"],
    &["unrealizings"],
    &["unrealisings"],
];

pub(crate) static ENTRY_UNREALIZING_14733349295903954205: VariantsMap = [
    &["unrealizing"],
    &["unrealising"],
    &["unrealizing"],
    &["unrealising"],
];

pub(crate) static ENTRY_UNRECOGNIZABLER_16831988820104346693: VariantsMap = [
    &["unrecognizabler"],
    &["unrecognisabler"],
    &["unrecognizabler"],
    &["unrecognisabler"],
];

pub(crate) static ENTRY_UNRECOGNIZABLEST_3385202348855994373: VariantsMap = [
    &["unrecognizablest"],
    &["unrecognisablest"],
    &["unrecognizablest"],
    &["unrecognisablest"],
];

pub(crate) static ENTRY_UNRECOGNIZABLE_7821646033253824562: VariantsMap = [
    &["unrecognizable"],
    &["unrecognisable"],
    &["unrecognizable"],
    &["unrecognisable"],
];

pub(crate) static ENTRY_UNRECOGNIZABLY_16907513329485194946: VariantsMap = [
    &["unrecognizably"],
    &["unrecognisably"],
    &["unrecognizably"],
    &["unrecognisably"],
];

pub(crate) static ENTRY_UNRECOGNIZED_291281988118866118: VariantsMap = [
    &["unrecognized"],
    &["unrecognised"],
    &["unrecognized"],
    &["unrecognised"],
];

pub(crate) static ENTRY_UNRECOGNIZINGLY_15939972486893394420: VariantsMap = [
    &["unrecognizingly"],
    &["unrecognisingly"],
    &["unrecognizingly"],
    &["unrecognisingly"],
];

pub(crate) static ENTRY_UNRECOGNIZING_13216348411080336247: VariantsMap = [
    &["unrecognizing"],
    &["unrecognising"],
    &["unrecognizing"],
    &["unrecognising"],
];

pub(crate) static ENTRY_UNRECONNOITEREDDER_17279023728979016058: VariantsMap = [
    &["unreconnoiteredder"],
    &["unreconnoitredder"],
    &["unreconnoitredder"],
    &["unreconnoitredder"],
];

pub(crate) static ENTRY_UNRECONNOITEREDDEST_7283425295463639954: VariantsMap = [
    &["unreconnoitereddest"],
    &["unreconnoitreddest"],
    &["unreconnoitreddest"],
    &["unreconnoitreddest"],
];

pub(crate) static ENTRY_UNRECONNOITEREDS_1865811208169191767: VariantsMap = [
    &["unreconnoitereds"],
    &["unreconnoitreds"],
    &["unreconnoitreds"],
    &["unreconnoitreds"],
];

pub(crate) static ENTRY_UNRECONNOITERED_13885276521917349849: VariantsMap = [
    &["unreconnoitered"],
    &["unreconnoitred"],
    &["unreconnoitred"],
    &["unreconnoitred"],
];

pub(crate) static ENTRY_UNREGULARIZED_7607836970895525487: VariantsMap = [
    &["unregularized"],
    &["unregularised"],
    &["unregularized"],
    &["unregularised"],
];

pub(crate) static ENTRY_UNREORGANIZEDDER_13944138977099129044: VariantsMap = [
    &["unreorganizedder"],
    &["unreorganisedder"],
    &["unreorganizedder"],
    &["unreorganisedder"],
];

pub(crate) static ENTRY_UNREORGANIZEDDEST_6133551850899844304: VariantsMap = [
    &["unreorganizeddest"],
    &["unreorganiseddest"],
    &["unreorganizeddest"],
    &["unreorganiseddest"],
];

pub(crate) static ENTRY_UNREORGANIZED_15643801344688977172: VariantsMap = [
    &["unreorganized"],
    &["unreorganised"],
    &["unreorganized"],
    &["unreorganised"],
];

pub(crate) static ENTRY_UNREVELATIONIZES_7331467037457288853: VariantsMap = [
    &["unrevelationizes"],
    &["unrevelationises"],
    &["unrevelationizes"],
    &["unrevelationises"],
];

pub(crate) static ENTRY_UNREVELATIONIZE_4135354342146461062: VariantsMap = [
    &["unrevelationize"],
    &["unrevelationise"],
    &["unrevelationize"],
    &["unrevelationise"],
];

pub(crate) static ENTRY_UNRIVALEDDER_8854788039016975855: VariantsMap = [
    &["unrivaledder"],
    &["unrivalledder"],
    &["unrivalledder"],
    &["unrivalledder"],
];

pub(crate) static ENTRY_UNRIVALEDDEST_18237777950481518710: VariantsMap = [
    &["unrivaleddest"],
    &["unrivalleddest"],
    &["unrivalleddest"],
    &["unrivalleddest"],
];

pub(crate) static ENTRY_UNRIVALED_7537208612931158340: VariantsMap = [
    &["unrivaled"],
    &["unrivalled"],
    &["unrivalled"],
    &["unrivalled"],
];

pub(crate) static ENTRY_UNROMANIZED_16023433417294923847: VariantsMap = [
    &["unromanized"],
    &["unromanised"],
    &["unromanized"],
    &["unromanised"],
];

pub(crate) static ENTRY_UNROMANTICIZEDDER_14224183937969515578: VariantsMap = [
    &["unromanticizedder"],
    &["unromanticisedder"],
    &["unromanticizedder"],
    &["unromanticisedder"],
];

pub(crate) static ENTRY_UNROMANTICIZEDDEST_4370230398020789302: VariantsMap = [
    &["unromanticizeddest"],
    &["unromanticiseddest"],
    &["unromanticizeddest"],
    &["unromanticiseddest"],
];

pub(crate) static ENTRY_UNROMANTICIZEDS_13982309102621522933: VariantsMap = [
    &["unromanticizeds"],
    &["unromanticiseds"],
    &["unromanticizeds"],
    &["unromanticiseds"],
];

pub(crate) static ENTRY_UNROMANTICIZED_9116532491725444580: VariantsMap = [
    &["unromanticized"],
    &["unromanticised"],
    &["unromanticized"],
    &["unromanticised"],
];

pub(crate) static ENTRY_UNROYALIZEDS_546156597779010632: VariantsMap = [
    &["unroyalizeds"],
    &["unroyaliseds"],
    &["unroyalizeds"],
    &["unroyaliseds"],
];

pub(crate) static ENTRY_UNROYALIZED_4739257089152987612: VariantsMap = [
    &["unroyalized"],
    &["unroyalised"],
    &["unroyalized"],
    &["unroyalised"],
];

pub(crate) static ENTRY_UNRUMOREDDER_2068713489527969729: VariantsMap = [
    &["unrumoredder"],
    &["unrumouredder"],
    &["unrumouredder"],
    &["unrumouredder"],
];

pub(crate) static ENTRY_UNRUMOREDDEST_13156480564204110238: VariantsMap = [
    &["unrumoreddest"],
    &["unrumoureddest"],
    &["unrumoureddest"],
    &["unrumoureddest"],
];

pub(crate) static ENTRY_UNRUMORED_9567717996555253392: VariantsMap = [
    &["unrumored"],
    &["unrumoured"],
    &["unrumoured"],
    &["unrumoured"],
];

pub(crate) static ENTRY_UNSABEREDDER_6684241841706286704: VariantsMap = [
    &["unsaberedder"],
    &["unsabredder"],
    &["unsabredder"],
    &["unsabredder"],
];

pub(crate) static ENTRY_UNSABEREDDEST_18251233635069875174: VariantsMap = [
    &["unsabereddest"],
    &["unsabreddest"],
    &["unsabreddest"],
    &["unsabreddest"],
];

pub(crate) static ENTRY_UNSABERED_12373905418079294291: VariantsMap =
    [&["unsabered"], &["unsabred"], &["unsabred"], &["unsabred"]];

pub(crate) static ENTRY_UNSATIRIZABLE_3145098919717260943: VariantsMap = [
    &["unsatirizable"],
    &["unsatirisable"],
    &["unsatirizable"],
    &["unsatirisable"],
];

pub(crate) static ENTRY_UNSATIRIZEDDER_16298087524992431097: VariantsMap = [
    &["unsatirizedder"],
    &["unsatirisedder"],
    &["unsatirizedder"],
    &["unsatirisedder"],
];

pub(crate) static ENTRY_UNSATIRIZEDDEST_1911445418808524947: VariantsMap = [
    &["unsatirizeddest"],
    &["unsatiriseddest"],
    &["unsatirizeddest"],
    &["unsatiriseddest"],
];

pub(crate) static ENTRY_UNSATIRIZED_10918619380161599373: VariantsMap = [
    &["unsatirized"],
    &["unsatirised"],
    &["unsatirized"],
    &["unsatirised"],
];

pub(crate) static ENTRY_UNSATIRIZES_13785980925145652389: VariantsMap = [
    &["unsatirizes"],
    &["unsatirises"],
    &["unsatirizes"],
    &["unsatirises"],
];

pub(crate) static ENTRY_UNSATIRIZE_8851857183483386343: VariantsMap = [
    &["unsatirize"],
    &["unsatirise"],
    &["unsatirize"],
    &["unsatirise"],
];

pub(crate) static ENTRY_UNSAVOREDDER_15068022672465287063: VariantsMap = [
    &["unsavoredder"],
    &["unsavouredder"],
    &["unsavouredder"],
    &["unsavouredder"],
];

pub(crate) static ENTRY_UNSAVOREDDEST_17270994326222090025: VariantsMap = [
    &["unsavoreddest"],
    &["unsavoureddest"],
    &["unsavoureddest"],
    &["unsavoureddest"],
];

pub(crate) static ENTRY_UNSAVOREDLY_1848146764107083498: VariantsMap = [
    &["unsavoredly"],
    &["unsavouredly"],
    &["unsavouredly"],
    &["unsavouredly"],
];

pub(crate) static ENTRY_UNSAVOREDNESS_2191242243682590718: VariantsMap = [
    &["unsavoredness"],
    &["unsavouredness"],
    &["unsavouredness"],
    &["unsavouredness"],
];

pub(crate) static ENTRY_UNSAVORED_11475616474446054221: VariantsMap = [
    &["unsavored"],
    &["unsavoured"],
    &["unsavoured"],
    &["unsavoured"],
];

pub(crate) static ENTRY_UNSAVORIER_7566012794202894976: VariantsMap = [
    &["unsavorier"],
    &["unsavourier"],
    &["unsavourier"],
    &["unsavourier"],
];

pub(crate) static ENTRY_UNSAVORIEST_18354309014937328323: VariantsMap = [
    &["unsavoriest"],
    &["unsavouriest"],
    &["unsavouriest"],
    &["unsavouriest"],
];

pub(crate) static ENTRY_UNSAVORIES_13570256108415909776: VariantsMap = [
    &["unsavories"],
    &["unsavouries"],
    &["unsavouries"],
    &["unsavouries"],
];

pub(crate) static ENTRY_UNSAVORILIER_9113239881471687179: VariantsMap = [
    &["unsavorilier"],
    &["unsavourilier"],
    &["unsavourilier"],
    &["unsavourilier"],
];

pub(crate) static ENTRY_UNSAVORILIEST_4268592476904671461: VariantsMap = [
    &["unsavoriliest"],
    &["unsavouriliest"],
    &["unsavouriliest"],
    &["unsavouriliest"],
];

pub(crate) static ENTRY_UNSAVORILIES_17139583247048205448: VariantsMap = [
    &["unsavorilies"],
    &["unsavourilies"],
    &["unsavourilies"],
    &["unsavourilies"],
];

pub(crate) static ENTRY_UNSAVORILY_15922738901841500332: VariantsMap = [
    &["unsavorily"],
    &["unsavourily"],
    &["unsavourily"],
    &["unsavourily"],
];

pub(crate) static ENTRY_UNSAVORINESSES_9146175498090621820: VariantsMap = [
    &["unsavorinesses"],
    &["unsavourinesses"],
    &["unsavourinesses"],
    &["unsavourinesses"],
];

pub(crate) static ENTRY_UNSAVORINESS_10308314055531850628: VariantsMap = [
    &["unsavoriness"],
    &["unsavouriness"],
    &["unsavouriness"],
    &["unsavouriness"],
];

pub(crate) static ENTRY_UNSAVORY_14080716095107745994: VariantsMap = [
    &["unsavory"],
    &["unsavoury"],
    &["unsavoury"],
    &["unsavoury"],
];

pub(crate) static ENTRY_UNSCANDALIZEDDER_18111310313303038296: VariantsMap = [
    &["unscandalizedder"],
    &["unscandalisedder"],
    &["unscandalizedder"],
    &["unscandalisedder"],
];

pub(crate) static ENTRY_UNSCANDALIZEDDEST_16242039314569406272: VariantsMap = [
    &["unscandalizeddest"],
    &["unscandaliseddest"],
    &["unscandalizeddest"],
    &["unscandaliseddest"],
];

pub(crate) static ENTRY_UNSCANDALIZED_13546507575715226266: VariantsMap = [
    &["unscandalized"],
    &["unscandalised"],
    &["unscandalized"],
    &["unscandalised"],
];

pub(crate) static ENTRY_UNSCANDALIZES_2398862153730255258: VariantsMap = [
    &["unscandalizes"],
    &["unscandalises"],
    &["unscandalizes"],
    &["unscandalises"],
];

pub(crate) static ENTRY_UNSCANDALIZE_16053982694142286033: VariantsMap = [
    &["unscandalize"],
    &["unscandalise"],
    &["unscandalize"],
    &["unscandalise"],
];

pub(crate) static ENTRY_UNSCEPTEREDDER_12181291417107771822: VariantsMap = [
    &["unscepteredder"],
    &["unsceptredder"],
    &["unsceptredder"],
    &["unsceptredder"],
];

pub(crate) static ENTRY_UNSCEPTEREDDEST_17540039512158448742: VariantsMap = [
    &["unsceptereddest"],
    &["unsceptreddest"],
    &["unsceptreddest"],
    &["unsceptreddest"],
];

pub(crate) static ENTRY_UNSCEPTERED_15452211318470868971: VariantsMap = [
    &["unsceptered"],
    &["unsceptred"],
    &["unsceptred"],
    &["unsceptred"],
];

pub(crate) static ENTRY_UNSCEPTERS_12034158920508538724: VariantsMap = [
    &["unscepters"],
    &["unsceptres"],
    &["unsceptres"],
    &["unsceptres"],
];

pub(crate) static ENTRY_UNSCEPTER_4166508186468970951: VariantsMap = [
    &["unscepter"],
    &["unsceptre"],
    &["unsceptre"],
    &["unsceptre"],
];

pub(crate) static ENTRY_UNSCHEMATIZEDDER_14428713257920703614: VariantsMap = [
    &["unschematizedder"],
    &["unschematisedder"],
    &["unschematizedder"],
    &["unschematisedder"],
];

pub(crate) static ENTRY_UNSCHEMATIZEDDEST_18287776028283084494: VariantsMap = [
    &["unschematizeddest"],
    &["unschematiseddest"],
    &["unschematizeddest"],
    &["unschematiseddest"],
];

pub(crate) static ENTRY_UNSCHEMATIZEDS_6728956752645304288: VariantsMap = [
    &["unschematizeds"],
    &["unschematiseds"],
    &["unschematizeds"],
    &["unschematiseds"],
];

pub(crate) static ENTRY_UNSCHEMATIZED_10049986821140403897: VariantsMap = [
    &["unschematized"],
    &["unschematised"],
    &["unschematized"],
    &["unschematised"],
];

pub(crate) static ENTRY_UNSCORED_47447901486425280: VariantsMap = [
    &["unscored"],
    &["unscoured"],
    &["unscoured"],
    &["unscoured"],
];

pub(crate) static ENTRY_UNSCORING_1751337690368155193: VariantsMap = [
    &["unscoring"],
    &["unscouring"],
    &["unscouring"],
    &["unscouring"],
];

pub(crate) static ENTRY_UNSCRUTINIZEDDER_6435886601825655981: VariantsMap = [
    &["unscrutinizedder"],
    &["unscrutinisedder"],
    &["unscrutinizedder"],
    &["unscrutinisedder"],
];

pub(crate) static ENTRY_UNSCRUTINIZEDDEST_12242353205786815739: VariantsMap = [
    &["unscrutinizeddest"],
    &["unscrutiniseddest"],
    &["unscrutinizeddest"],
    &["unscrutiniseddest"],
];

pub(crate) static ENTRY_UNSCRUTINIZED_11149142688617945574: VariantsMap = [
    &["unscrutinized"],
    &["unscrutinised"],
    &["unscrutinized"],
    &["unscrutinised"],
];

pub(crate) static ENTRY_UNSCRUTINIZINGER_5676669904103635154: VariantsMap = [
    &["unscrutinizinger"],
    &["unscrutinisinger"],
    &["unscrutinizinger"],
    &["unscrutinisinger"],
];

pub(crate) static ENTRY_UNSCRUTINIZINGEST_18196137909826699146: VariantsMap = [
    &["unscrutinizingest"],
    &["unscrutinisingest"],
    &["unscrutinizingest"],
    &["unscrutinisingest"],
];

pub(crate) static ENTRY_UNSCRUTINIZINGLIER_3953405087476382875: VariantsMap = [
    &["unscrutinizinglier"],
    &["unscrutinisinglier"],
    &["unscrutinizinglier"],
    &["unscrutinisinglier"],
];

pub(crate) static ENTRY_UNSCRUTINIZINGLIEST_15514859191792249061: VariantsMap = [
    &["unscrutinizingliest"],
    &["unscrutinisingliest"],
    &["unscrutinizingliest"],
    &["unscrutinisingliest"],
];

pub(crate) static ENTRY_UNSCRUTINIZINGLY_10127047352540752813: VariantsMap = [
    &["unscrutinizingly"],
    &["unscrutinisingly"],
    &["unscrutinizingly"],
    &["unscrutinisingly"],
];

pub(crate) static ENTRY_UNSCRUTINIZING_4062568311194108442: VariantsMap = [
    &["unscrutinizing"],
    &["unscrutinising"],
    &["unscrutinizing"],
    &["unscrutinising"],
];

pub(crate) static ENTRY_UNSECTARIANIZES_18248497066495696520: VariantsMap = [
    &["unsectarianizes"],
    &["unsectarianises"],
    &["unsectarianizes"],
    &["unsectarianises"],
];

pub(crate) static ENTRY_UNSECTARIANIZE_7363850891406916279: VariantsMap = [
    &["unsectarianize"],
    &["unsectarianise"],
    &["unsectarianize"],
    &["unsectarianise"],
];

pub(crate) static ENTRY_UNSECTIONALIZED_14160946284121325933: VariantsMap = [
    &["unsectionalized"],
    &["unsectionalised"],
    &["unsectionalized"],
    &["unsectionalised"],
];

pub(crate) static ENTRY_UNSECULARIZEDDER_2842961345958441791: VariantsMap = [
    &["unsecularizedder"],
    &["unsecularisedder"],
    &["unsecularizedder"],
    &["unsecularisedder"],
];

pub(crate) static ENTRY_UNSECULARIZEDDEST_12149248990561677937: VariantsMap = [
    &["unsecularizeddest"],
    &["unseculariseddest"],
    &["unsecularizeddest"],
    &["unseculariseddest"],
];

pub(crate) static ENTRY_UNSECULARIZED_14199565598148621175: VariantsMap = [
    &["unsecularized"],
    &["unsecularised"],
    &["unsecularized"],
    &["unsecularised"],
];

pub(crate) static ENTRY_UNSECULARIZES_13447532511726190479: VariantsMap = [
    &["unsecularizes"],
    &["unsecularises"],
    &["unsecularizes"],
    &["unsecularises"],
];

pub(crate) static ENTRY_UNSECULARIZE_14132148258894262887: VariantsMap = [
    &["unsecularize"],
    &["unsecularise"],
    &["unsecularize"],
    &["unsecularise"],
];

pub(crate) static ENTRY_UNSENSITIZED_1745594334360308084: VariantsMap = [
    &["unsensitized"],
    &["unsensitised"],
    &["unsensitized"],
    &["unsensitised"],
];

pub(crate) static ENTRY_UNSENSITIZES_13345318411364622184: VariantsMap = [
    &["unsensitizes"],
    &["unsensitises"],
    &["unsensitizes"],
    &["unsensitises"],
];

pub(crate) static ENTRY_UNSENSITIZE_7473555488224076656: VariantsMap = [
    &["unsensitize"],
    &["unsensitise"],
    &["unsensitize"],
    &["unsensitise"],
];

pub(crate) static ENTRY_UNSENSITIZING_13954263948551463374: VariantsMap = [
    &["unsensitizing"],
    &["unsensitising"],
    &["unsensitizing"],
    &["unsensitising"],
];

pub(crate) static ENTRY_UNSENSUALIZED_1487257633805307913: VariantsMap = [
    &["unsensualized"],
    &["unsensualised"],
    &["unsensualized"],
    &["unsensualised"],
];

pub(crate) static ENTRY_UNSENSUALIZES_7920151341600586361: VariantsMap = [
    &["unsensualizes"],
    &["unsensualises"],
    &["unsensualizes"],
    &["unsensualises"],
];

pub(crate) static ENTRY_UNSENSUALIZE_3872317908881106198: VariantsMap = [
    &["unsensualize"],
    &["unsensualise"],
    &["unsensualize"],
    &["unsensualise"],
];

pub(crate) static ENTRY_UNSENSUALIZING_17972016725852543610: VariantsMap = [
    &["unsensualizing"],
    &["unsensualising"],
    &["unsensualizing"],
    &["unsensualising"],
];

pub(crate) static ENTRY_UNSENTIMENTALIZED_10901313714433298415: VariantsMap = [
    &["unsentimentalized"],
    &["unsentimentalised"],
    &["unsentimentalized"],
    &["unsentimentalised"],
];

pub(crate) static ENTRY_UNSENTIMENTALIZES_12335131210195268447: VariantsMap = [
    &["unsentimentalizes"],
    &["unsentimentalises"],
    &["unsentimentalizes"],
    &["unsentimentalises"],
];

pub(crate) static ENTRY_UNSENTIMENTALIZE_15546981073227478616: VariantsMap = [
    &["unsentimentalize"],
    &["unsentimentalise"],
    &["unsentimentalize"],
    &["unsentimentalise"],
];

pub(crate) static ENTRY_UNSEPULCHERED_8119587175553677223: VariantsMap = [
    &["unsepulchered"],
    &["unsepulchred"],
    &["unsepulchred"],
    &["unsepulchred"],
];

pub(crate) static ENTRY_UNSEPULCHERS_8204420699755543106: VariantsMap = [
    &["unsepulchers"],
    &["unsepulchres"],
    &["unsepulchres"],
    &["unsepulchres"],
];

pub(crate) static ENTRY_UNSEPULCHER_2014873108753613465: VariantsMap = [
    &["unsepulcher"],
    &["unsepulchre"],
    &["unsepulchre"],
    &["unsepulchre"],
];

pub(crate) static ENTRY_UNSERIALIZED_659557943907801624: VariantsMap = [
    &["unserialized"],
    &["unserialised"],
    &["unserialized"],
    &["unserialised"],
];

pub(crate) static ENTRY_UNSHED_5262139668880542294: VariantsMap =
    [&["unshed"], &["unshoed"], &["unshoed"], &["unshoed"]];

pub(crate) static ENTRY_UNSIGNALIZEDDER_705937437443397616: VariantsMap = [
    &["unsignalizedder"],
    &["unsignalisedder"],
    &["unsignalizedder"],
    &["unsignalisedder"],
];

pub(crate) static ENTRY_UNSIGNALIZEDDEST_14660298846752223251: VariantsMap = [
    &["unsignalizeddest"],
    &["unsignaliseddest"],
    &["unsignalizeddest"],
    &["unsignaliseddest"],
];

pub(crate) static ENTRY_UNSIGNALIZEDS_4457009391245218633: VariantsMap = [
    &["unsignalizeds"],
    &["unsignaliseds"],
    &["unsignalizeds"],
    &["unsignaliseds"],
];

pub(crate) static ENTRY_UNSIGNALIZED_14483193965409880939: VariantsMap = [
    &["unsignalized"],
    &["unsignalised"],
    &["unsignalized"],
    &["unsignalised"],
];

pub(crate) static ENTRY_UNSIPHONS_11966284679782715486: VariantsMap = [
    &["unsiphons"],
    &["unsyphons"],
    &["unsyphons"],
    &["unsyphons"],
];

pub(crate) static ENTRY_UNSIPHON_2201477182742736895: VariantsMap =
    [&["unsiphon"], &["unsyphon"], &["unsyphon"], &["unsyphon"]];

pub(crate) static ENTRY_UNSOCIALIZEDDER_856229867973138497: VariantsMap = [
    &["unsocializedder"],
    &["unsocialisedder"],
    &["unsocializedder"],
    &["unsocialisedder"],
];

pub(crate) static ENTRY_UNSOCIALIZEDDEST_8753817887210581029: VariantsMap = [
    &["unsocializeddest"],
    &["unsocialiseddest"],
    &["unsocializeddest"],
    &["unsocialiseddest"],
];

pub(crate) static ENTRY_UNSOCIALIZED_14989628692775218168: VariantsMap = [
    &["unsocialized"],
    &["unsocialised"],
    &["unsocialized"],
    &["unsocialised"],
];

pub(crate) static ENTRY_UNSOCIALIZING_4910985306707895534: VariantsMap = [
    &["unsocializing"],
    &["unsocialising"],
    &["unsocializing"],
    &["unsocialising"],
];

pub(crate) static ENTRY_UNSOLEMNIZEDDER_11258782760404945860: VariantsMap = [
    &["unsolemnizedder"],
    &["unsolemnisedder"],
    &["unsolemnizedder"],
    &["unsolemnisedder"],
];

pub(crate) static ENTRY_UNSOLEMNIZEDDEST_12652695066155929748: VariantsMap = [
    &["unsolemnizeddest"],
    &["unsolemniseddest"],
    &["unsolemnizeddest"],
    &["unsolemniseddest"],
];

pub(crate) static ENTRY_UNSOLEMNIZED_16387242389688387024: VariantsMap = [
    &["unsolemnized"],
    &["unsolemnised"],
    &["unsolemnized"],
    &["unsolemnised"],
];

pub(crate) static ENTRY_UNSOLEMNIZES_16920004258925216679: VariantsMap = [
    &["unsolemnizes"],
    &["unsolemnises"],
    &["unsolemnizes"],
    &["unsolemnises"],
];

pub(crate) static ENTRY_UNSOLEMNIZE_11168537395109875287: VariantsMap = [
    &["unsolemnize"],
    &["unsolemnise"],
    &["unsolemnize"],
    &["unsolemnise"],
];

pub(crate) static ENTRY_UNSOMBERLY_15086202074328462192: VariantsMap = [
    &["unsomberly"],
    &["unsombrely"],
    &["unsombrely"],
    &["unsombrely"],
];

pub(crate) static ENTRY_UNSOMBERNESS_5216333562398296695: VariantsMap = [
    &["unsomberness"],
    &["unsombreness"],
    &["unsombreness"],
    &["unsombreness"],
];

pub(crate) static ENTRY_UNSOMBER_5660053662769742895: VariantsMap =
    [&["unsomber"], &["unsombre"], &["unsombre"], &["unsombre"]];

pub(crate) static ENTRY_UNSPECIALIZEDDER_9071034409026977091: VariantsMap = [
    &["unspecializedder"],
    &["unspecialisedder"],
    &["unspecializedder"],
    &["unspecialisedder"],
];

pub(crate) static ENTRY_UNSPECIALIZEDDEST_8581399916465856628: VariantsMap = [
    &["unspecializeddest"],
    &["unspecialiseddest"],
    &["unspecializeddest"],
    &["unspecialiseddest"],
];

pub(crate) static ENTRY_UNSPECIALIZED_5465071604094517809: VariantsMap = [
    &["unspecialized"],
    &["unspecialised"],
    &["unspecialized"],
    &["unspecialised"],
];

pub(crate) static ENTRY_UNSPECIALIZINGER_16940094743315712229: VariantsMap = [
    &["unspecializinger"],
    &["unspecialisinger"],
    &["unspecializinger"],
    &["unspecialisinger"],
];

pub(crate) static ENTRY_UNSPECIALIZINGEST_18418227812211404765: VariantsMap = [
    &["unspecializingest"],
    &["unspecialisingest"],
    &["unspecializingest"],
    &["unspecialisingest"],
];

pub(crate) static ENTRY_UNSPECIALIZING_9421997668487501018: VariantsMap = [
    &["unspecializing"],
    &["unspecialising"],
    &["unspecializing"],
    &["unspecialising"],
];

pub(crate) static ENTRY_UNSPECTERLIKES_7509114770076619624: VariantsMap = [
    &["unspecterlikes"],
    &["unspectrelikes"],
    &["unspectrelikes"],
    &["unspectrelikes"],
];

pub(crate) static ENTRY_UNSPECTERLIKE_2141876370934724325: VariantsMap = [
    &["unspecterlike"],
    &["unspectrelike"],
    &["unspectrelike"],
    &["unspectrelike"],
];

pub(crate) static ENTRY_UNSPIRITUALIZED_1702102857886189847: VariantsMap = [
    &["unspiritualized"],
    &["unspiritualised"],
    &["unspiritualized"],
    &["unspiritualised"],
];

pub(crate) static ENTRY_UNSPIRITUALIZES_6758197377913290909: VariantsMap = [
    &["unspiritualizes"],
    &["unspiritualises"],
    &["unspiritualizes"],
    &["unspiritualises"],
];

pub(crate) static ENTRY_UNSPIRITUALIZE_372925422412985909: VariantsMap = [
    &["unspiritualize"],
    &["unspiritualise"],
    &["unspiritualize"],
    &["unspiritualise"],
];

pub(crate) static ENTRY_UNSPIRITUALIZING_9667822503310703185: VariantsMap = [
    &["unspiritualizing"],
    &["unspiritualising"],
    &["unspiritualizing"],
    &["unspiritualising"],
];

pub(crate) static ENTRY_UNSPLENDOROUSLY_4500859628733032967: VariantsMap = [
    &["unsplendorously"],
    &["unsplendourously"],
    &["unsplendourously"],
    &["unsplendourously"],
];

pub(crate) static ENTRY_UNSPLENDOROUS_8544602661563641204: VariantsMap = [
    &["unsplendorous"],
    &["unsplendourous"],
    &["unsplendourous"],
    &["unsplendourous"],
];

pub(crate) static ENTRY_UNSTABILIZED_12732354267194876239: VariantsMap = [
    &["unstabilized"],
    &["unstabilised"],
    &["unstabilized"],
    &["unstabilised"],
];

pub(crate) static ENTRY_UNSTABILIZING_7613851599613717731: VariantsMap = [
    &["unstabilizing"],
    &["unstabilising"],
    &["unstabilizing"],
    &["unstabilising"],
];

pub(crate) static ENTRY_UNSTANDARDIZABLE_3270324052895078989: VariantsMap = [
    &["unstandardizable"],
    &["unstandardisable"],
    &["unstandardizable"],
    &["unstandardisable"],
];

pub(crate) static ENTRY_UNSTANDARDIZEDDER_6565607621393721916: VariantsMap = [
    &["unstandardizedder"],
    &["unstandardisedder"],
    &["unstandardizedder"],
    &["unstandardisedder"],
];

pub(crate) static ENTRY_UNSTANDARDIZEDDEST_4054711965309446578: VariantsMap = [
    &["unstandardizeddest"],
    &["unstandardiseddest"],
    &["unstandardizeddest"],
    &["unstandardiseddest"],
];

pub(crate) static ENTRY_UNSTANDARDIZED_12491554302043952151: VariantsMap = [
    &["unstandardized"],
    &["unstandardised"],
    &["unstandardized"],
    &["unstandardised"],
];

pub(crate) static ENTRY_UNSTERILIZED_10084050054715413010: VariantsMap = [
    &["unsterilized"],
    &["unsterilised"],
    &["unsterilized"],
    &["unsterilised"],
];

pub(crate) static ENTRY_UNSTIGMATIZEDDER_1556903362413866083: VariantsMap = [
    &["unstigmatizedder"],
    &["unstigmatisedder"],
    &["unstigmatizedder"],
    &["unstigmatisedder"],
];

pub(crate) static ENTRY_UNSTIGMATIZEDDEST_3672863394691019431: VariantsMap = [
    &["unstigmatizeddest"],
    &["unstigmatiseddest"],
    &["unstigmatizeddest"],
    &["unstigmatiseddest"],
];

pub(crate) static ENTRY_UNSTIGMATIZEDS_2110294383752462220: VariantsMap = [
    &["unstigmatizeds"],
    &["unstigmatiseds"],
    &["unstigmatizeds"],
    &["unstigmatiseds"],
];

pub(crate) static ENTRY_UNSTIGMATIZED_9617189081690540365: VariantsMap = [
    &["unstigmatized"],
    &["unstigmatised"],
    &["unstigmatized"],
    &["unstigmatised"],
];

pub(crate) static ENTRY_UNSTOICIZES_5409151828444702636: VariantsMap = [
    &["unstoicizes"],
    &["unstoicises"],
    &["unstoicizes"],
    &["unstoicises"],
];

pub(crate) static ENTRY_UNSTOICIZE_5593462469547952299: VariantsMap = [
    &["unstoicize"],
    &["unstoicise"],
    &["unstoicize"],
    &["unstoicise"],
];

pub(crate) static ENTRY_UNSUBSIDIZED_4767425605608650705: VariantsMap = [
    &["unsubsidized"],
    &["unsubsidised"],
    &["unsubsidized"],
    &["unsubsidised"],
];

pub(crate) static ENTRY_UNSUBSTANTIALIZED_16840433461130643933: VariantsMap = [
    &["unsubstantialized"],
    &["unsubstantialised"],
    &["unsubstantialized"],
    &["unsubstantialised"],
];

pub(crate) static ENTRY_UNSUBSTANTIALIZES_16087693605789653784: VariantsMap = [
    &["unsubstantializes"],
    &["unsubstantialises"],
    &["unsubstantializes"],
    &["unsubstantialises"],
];

pub(crate) static ENTRY_UNSUBSTANTIALIZE_7167575127151537643: VariantsMap = [
    &["unsubstantialize"],
    &["unsubstantialise"],
    &["unsubstantialize"],
    &["unsubstantialise"],
];

pub(crate) static ENTRY_UNSUBSTANTIALIZING_5715571309095915572: VariantsMap = [
    &["unsubstantializing"],
    &["unsubstantialising"],
    &["unsubstantializing"],
    &["unsubstantialising"],
];

pub(crate) static ENTRY_UNSUCCORABLES_7445917141274035146: VariantsMap = [
    &["unsuccorables"],
    &["unsuccourables"],
    &["unsuccourables"],
    &["unsuccourables"],
];

pub(crate) static ENTRY_UNSUCCORABLE_14166115535199719478: VariantsMap = [
    &["unsuccorable"],
    &["unsuccourable"],
    &["unsuccourable"],
    &["unsuccourable"],
];

pub(crate) static ENTRY_UNSUCCORED_8876180192974098027: VariantsMap = [
    &["unsuccored"],
    &["unsuccoured"],
    &["unsuccoured"],
    &["unsuccoured"],
];

pub(crate) static ENTRY_UNSULPHURIZEDS_12878019452075350923: VariantsMap = [
    &["unsulphurizeds"],
    &["unsulphuriseds"],
    &["unsulphurizeds"],
    &["unsulphuriseds"],
];

pub(crate) static ENTRY_UNSULPHURIZED_17918992173910340976: VariantsMap = [
    &["unsulphurized"],
    &["unsulphurised"],
    &["unsulphurized"],
    &["unsulphurised"],
];

pub(crate) static ENTRY_UNSUMMARIZABLE_12043279703030794088: VariantsMap = [
    &["unsummarizable"],
    &["unsummarisable"],
    &["unsummarizable"],
    &["unsummarisable"],
];

pub(crate) static ENTRY_UNSUMMARIZEDDER_1909102770740554249: VariantsMap = [
    &["unsummarizedder"],
    &["unsummarisedder"],
    &["unsummarizedder"],
    &["unsummarisedder"],
];

pub(crate) static ENTRY_UNSUMMARIZEDDEST_11938489051378385243: VariantsMap = [
    &["unsummarizeddest"],
    &["unsummariseddest"],
    &["unsummarizeddest"],
    &["unsummariseddest"],
];

pub(crate) static ENTRY_UNSUMMARIZED_12298858164299539938: VariantsMap = [
    &["unsummarized"],
    &["unsummarised"],
    &["unsummarized"],
    &["unsummarised"],
];

pub(crate) static ENTRY_UNSUPERNATURALIZED_138394761197753453: VariantsMap = [
    &["unsupernaturalized"],
    &["unsupernaturalised"],
    &["unsupernaturalized"],
    &["unsupernaturalised"],
];

pub(crate) static ENTRY_UNSUPERNATURALIZES_10254282064098281782: VariantsMap = [
    &["unsupernaturalizes"],
    &["unsupernaturalises"],
    &["unsupernaturalizes"],
    &["unsupernaturalises"],
];

pub(crate) static ENTRY_UNSUPERNATURALIZE_10992801829063966196: VariantsMap = [
    &["unsupernaturalize"],
    &["unsupernaturalise"],
    &["unsupernaturalize"],
    &["unsupernaturalise"],
];

pub(crate) static ENTRY_UNSYMBOLIZEDDER_5607794258564831297: VariantsMap = [
    &["unsymbolizedder"],
    &["unsymbolisedder"],
    &["unsymbolizedder"],
    &["unsymbolisedder"],
];

pub(crate) static ENTRY_UNSYMBOLIZEDDEST_5231089008393444113: VariantsMap = [
    &["unsymbolizeddest"],
    &["unsymboliseddest"],
    &["unsymbolizeddest"],
    &["unsymboliseddest"],
];

pub(crate) static ENTRY_UNSYMBOLIZED_12442949087766027580: VariantsMap = [
    &["unsymbolized"],
    &["unsymbolised"],
    &["unsymbolized"],
    &["unsymbolised"],
];

pub(crate) static ENTRY_UNSYMMETRIZEDS_16967469102765366856: VariantsMap = [
    &["unsymmetrizeds"],
    &["unsymmetriseds"],
    &["unsymmetrizeds"],
    &["unsymmetriseds"],
];

pub(crate) static ENTRY_UNSYMMETRIZED_17823967768468208874: VariantsMap = [
    &["unsymmetrized"],
    &["unsymmetrised"],
    &["unsymmetrized"],
    &["unsymmetrised"],
];

pub(crate) static ENTRY_UNSYMPATHIZABILITIES_10871972451749839275: VariantsMap = [
    &["unsympathizabilities"],
    &["unsympathisabilities"],
    &["unsympathizabilities"],
    &["unsympathisabilities"],
];

pub(crate) static ENTRY_UNSYMPATHIZABILITY_8670082626189206465: VariantsMap = [
    &["unsympathizability"],
    &["unsympathisability"],
    &["unsympathizability"],
    &["unsympathisability"],
];

pub(crate) static ENTRY_UNSYMPATHIZABLES_17966199469317566401: VariantsMap = [
    &["unsympathizables"],
    &["unsympathisables"],
    &["unsympathizables"],
    &["unsympathisables"],
];

pub(crate) static ENTRY_UNSYMPATHIZABLE_1492652348373590024: VariantsMap = [
    &["unsympathizable"],
    &["unsympathisable"],
    &["unsympathizable"],
    &["unsympathisable"],
];

pub(crate) static ENTRY_UNSYMPATHIZEDDER_2799017229074261659: VariantsMap = [
    &["unsympathizedder"],
    &["unsympathisedder"],
    &["unsympathizedder"],
    &["unsympathisedder"],
];

pub(crate) static ENTRY_UNSYMPATHIZEDDEST_3121473820642946837: VariantsMap = [
    &["unsympathizeddest"],
    &["unsympathiseddest"],
    &["unsympathizeddest"],
    &["unsympathiseddest"],
];

pub(crate) static ENTRY_UNSYMPATHIZED_11591186610900438376: VariantsMap = [
    &["unsympathized"],
    &["unsympathised"],
    &["unsympathized"],
    &["unsympathised"],
];

pub(crate) static ENTRY_UNSYMPATHIZINGER_653153874121707552: VariantsMap = [
    &["unsympathizinger"],
    &["unsympathisinger"],
    &["unsympathizinger"],
    &["unsympathisinger"],
];

pub(crate) static ENTRY_UNSYMPATHIZINGEST_13140732246250859755: VariantsMap = [
    &["unsympathizingest"],
    &["unsympathisingest"],
    &["unsympathizingest"],
    &["unsympathisingest"],
];

pub(crate) static ENTRY_UNSYMPATHIZINGLIER_13699392946495371982: VariantsMap = [
    &["unsympathizinglier"],
    &["unsympathisinglier"],
    &["unsympathizinglier"],
    &["unsympathisinglier"],
];

pub(crate) static ENTRY_UNSYMPATHIZINGLIEST_1266776181731729210: VariantsMap = [
    &["unsympathizingliest"],
    &["unsympathisingliest"],
    &["unsympathizingliest"],
    &["unsympathisingliest"],
];

pub(crate) static ENTRY_UNSYMPATHIZINGLY_615018246483482543: VariantsMap = [
    &["unsympathizingly"],
    &["unsympathisingly"],
    &["unsympathizingly"],
    &["unsympathisingly"],
];

pub(crate) static ENTRY_UNSYMPATHIZINGS_12442450452539388270: VariantsMap = [
    &["unsympathizings"],
    &["unsympathisings"],
    &["unsympathizings"],
    &["unsympathisings"],
];

pub(crate) static ENTRY_UNSYMPATHIZING_17910112294386472908: VariantsMap = [
    &["unsympathizing"],
    &["unsympathising"],
    &["unsympathizing"],
    &["unsympathising"],
];

pub(crate) static ENTRY_UNSYNCHRONIZEDDER_14730878662606801638: VariantsMap = [
    &["unsynchronizedder"],
    &["unsynchronisedder"],
    &["unsynchronizedder"],
    &["unsynchronisedder"],
];

pub(crate) static ENTRY_UNSYNCHRONIZEDDEST_15177448949665547626: VariantsMap = [
    &["unsynchronizeddest"],
    &["unsynchroniseddest"],
    &["unsynchronizeddest"],
    &["unsynchroniseddest"],
];

pub(crate) static ENTRY_UNSYNCHRONIZED_12193751578059218406: VariantsMap = [
    &["unsynchronized"],
    &["unsynchronised"],
    &["unsynchronized"],
    &["unsynchronised"],
];

pub(crate) static ENTRY_UNSYNTHESIZEDDER_479663997349491379: VariantsMap = [
    &["unsynthesizedder"],
    &["unsynthesisedder"],
    &["unsynthesizedder"],
    &["unsynthesisedder"],
];

pub(crate) static ENTRY_UNSYNTHESIZEDDEST_16230758731030483885: VariantsMap = [
    &["unsynthesizeddest"],
    &["unsynthesiseddest"],
    &["unsynthesizeddest"],
    &["unsynthesiseddest"],
];

pub(crate) static ENTRY_UNSYNTHESIZED_18216819107912450745: VariantsMap = [
    &["unsynthesized"],
    &["unsynthesised"],
    &["unsynthesized"],
    &["unsynthesised"],
];

pub(crate) static ENTRY_UNSYSTEMATIZEDDER_1302648680013691438: VariantsMap = [
    &["unsystematizedder"],
    &["unsystematisedder"],
    &["unsystematizedder"],
    &["unsystematisedder"],
];

pub(crate) static ENTRY_UNSYSTEMATIZEDDEST_13096641924022288041: VariantsMap = [
    &["unsystematizeddest"],
    &["unsystematiseddest"],
    &["unsystematizeddest"],
    &["unsystematiseddest"],
];

pub(crate) static ENTRY_UNSYSTEMATIZEDLY_10792111716627672784: VariantsMap = [
    &["unsystematizedly"],
    &["unsystematisedly"],
    &["unsystematizedly"],
    &["unsystematisedly"],
];

pub(crate) static ENTRY_UNSYSTEMATIZED_14693004019922481080: VariantsMap = [
    &["unsystematized"],
    &["unsystematised"],
    &["unsystematized"],
    &["unsystematised"],
];

pub(crate) static ENTRY_UNSYSTEMATIZINGER_16173262785830006988: VariantsMap = [
    &["unsystematizinger"],
    &["unsystematisinger"],
    &["unsystematizinger"],
    &["unsystematisinger"],
];

pub(crate) static ENTRY_UNSYSTEMATIZINGEST_7531122843621325837: VariantsMap = [
    &["unsystematizingest"],
    &["unsystematisingest"],
    &["unsystematizingest"],
    &["unsystematisingest"],
];

pub(crate) static ENTRY_UNSYSTEMATIZING_17458304099489437827: VariantsMap = [
    &["unsystematizing"],
    &["unsystematising"],
    &["unsystematizing"],
    &["unsystematising"],
];

pub(crate) static ENTRY_UNSYSTEMIZABLES_539302938187104170: VariantsMap = [
    &["unsystemizables"],
    &["unsystemisables"],
    &["unsystemizables"],
    &["unsystemisables"],
];

pub(crate) static ENTRY_UNSYSTEMIZABLE_13398089433943014635: VariantsMap = [
    &["unsystemizable"],
    &["unsystemisable"],
    &["unsystemizable"],
    &["unsystemisable"],
];

pub(crate) static ENTRY_UNTANTALIZEDDER_9017568026967264940: VariantsMap = [
    &["untantalizedder"],
    &["untantalisedder"],
    &["untantalizedder"],
    &["untantalisedder"],
];

pub(crate) static ENTRY_UNTANTALIZEDDEST_17151831953922163616: VariantsMap = [
    &["untantalizeddest"],
    &["untantaliseddest"],
    &["untantalizeddest"],
    &["untantaliseddest"],
];

pub(crate) static ENTRY_UNTANTALIZED_17464672990124408329: VariantsMap = [
    &["untantalized"],
    &["untantalised"],
    &["untantalized"],
    &["untantalised"],
];

pub(crate) static ENTRY_UNTANTALIZINGER_419332726477913928: VariantsMap = [
    &["untantalizinger"],
    &["untantalisinger"],
    &["untantalizinger"],
    &["untantalisinger"],
];

pub(crate) static ENTRY_UNTANTALIZINGEST_5960038359849071682: VariantsMap = [
    &["untantalizingest"],
    &["untantalisingest"],
    &["untantalizingest"],
    &["untantalisingest"],
];

pub(crate) static ENTRY_UNTANTALIZINGS_15651718507232611764: VariantsMap = [
    &["untantalizings"],
    &["untantalisings"],
    &["untantalizings"],
    &["untantalisings"],
];

pub(crate) static ENTRY_UNTANTALIZING_8959423826533397051: VariantsMap = [
    &["untantalizing"],
    &["untantalising"],
    &["untantalizing"],
    &["untantalising"],
];

pub(crate) static ENTRY_UNTARTARIZEDS_8407791349105830225: VariantsMap = [
    &["untartarizeds"],
    &["untartariseds"],
    &["untartarizeds"],
    &["untartariseds"],
];

pub(crate) static ENTRY_UNTARTARIZED_3133720179395977215: VariantsMap = [
    &["untartarized"],
    &["untartarised"],
    &["untartarized"],
    &["untartarised"],
];

pub(crate) static ENTRY_UNTECHNICALIZES_3126412773353612904: VariantsMap = [
    &["untechnicalizes"],
    &["untechnicalises"],
    &["untechnicalizes"],
    &["untechnicalises"],
];

pub(crate) static ENTRY_UNTECHNICALIZE_13274966953497077306: VariantsMap = [
    &["untechnicalize"],
    &["untechnicalise"],
    &["untechnicalize"],
    &["untechnicalise"],
];

pub(crate) static ENTRY_UNTEMPORIZINGS_2315283902611343260: VariantsMap = [
    &["untemporizings"],
    &["untemporisings"],
    &["untemporizings"],
    &["untemporisings"],
];

pub(crate) static ENTRY_UNTEMPORIZING_5353772823642385999: VariantsMap = [
    &["untemporizing"],
    &["untemporising"],
    &["untemporizing"],
    &["untemporising"],
];

pub(crate) static ENTRY_UNTERRORIZED_4367682942057022296: VariantsMap = [
    &["unterrorized"],
    &["unterrorised"],
    &["unterrorized"],
    &["unterrorised"],
];

pub(crate) static ENTRY_UNTHEORIZABLES_16215355028071233497: VariantsMap = [
    &["untheorizables"],
    &["untheorisables"],
    &["untheorizables"],
    &["untheorisables"],
];

pub(crate) static ENTRY_UNTHEORIZABLE_2154526804700643766: VariantsMap = [
    &["untheorizable"],
    &["untheorisable"],
    &["untheorizable"],
    &["untheorisable"],
];

pub(crate) static ENTRY_UNTRAMMELEDDER_14704643385630931751: VariantsMap = [
    &["untrammeledder"],
    &["untrammelledder"],
    &["untrammelledder"],
    &["untrammelledder"],
];

pub(crate) static ENTRY_UNTRAMMELEDDEST_9165425453399950000: VariantsMap = [
    &["untrammeleddest"],
    &["untrammelleddest"],
    &["untrammelleddest"],
    &["untrammelleddest"],
];

pub(crate) static ENTRY_UNTRAMMELED_10950501341680868626: VariantsMap = [
    &["untrammeled"],
    &["untrammelled"],
    &["untrammelled"],
    &["untrammelled"],
];

pub(crate) static ENTRY_UNTRANQUILIZED_6652837859667827274: VariantsMap = [
    &["untranquilized"],
    &["untranquilised"],
    &["untranquilized"],
    &["untranquilised"],
];

pub(crate) static ENTRY_UNTRANQUILLIZED_11685243952236058416: VariantsMap = [
    &["untranquillized"],
    &["untranquillised"],
    &["untranquillized"],
    &["untranquillised"],
];

pub(crate) static ENTRY_UNTRANQUILLIZE_5773855129723549449: VariantsMap = [
    &["untranquillize"],
    &["untranquillise"],
    &["untranquillize"],
    &["untranquillise"],
];

pub(crate) static ENTRY_UNTYRANNIZED_1381270595557515408: VariantsMap = [
    &["untyrannized"],
    &["untyrannised"],
    &["untyrannized"],
    &["untyrannised"],
];

pub(crate) static ENTRY_UNUTILIZABLES_8540746522822486622: VariantsMap = [
    &["unutilizables"],
    &["unutilisables"],
    &["unutilizables"],
    &["unutilisables"],
];

pub(crate) static ENTRY_UNUTILIZABLE_3295844226688802618: VariantsMap = [
    &["unutilizable"],
    &["unutilisable"],
    &["unutilizable"],
    &["unutilisable"],
];

pub(crate) static ENTRY_UNUTILIZED_1068022609704657690: VariantsMap = [
    &["unutilized"],
    &["unutilised"],
    &["unutilized"],
    &["unutilised"],
];

pub(crate) static ENTRY_UNVAPORIZEDS_3053547386158063137: VariantsMap = [
    &["unvaporizeds"],
    &["unvaporiseds"],
    &["unvaporizeds"],
    &["unvaporiseds"],
];

pub(crate) static ENTRY_UNVAPORIZED_9453095998519615936: VariantsMap = [
    &["unvaporized"],
    &["unvaporised"],
    &["unvaporized"],
    &["unvaporised"],
];

pub(crate) static ENTRY_UNVECTORIZABLE_6179247702715111446: VariantsMap = [
    &["unvectorizable"],
    &["unvectorisable"],
    &["unvectorizable"],
    &["unvectorisable"],
];

pub(crate) static ENTRY_UNVERBALIZED_15207072139205961298: VariantsMap = [
    &["unverbalized"],
    &["unverbalised"],
    &["unverbalized"],
    &["unverbalised"],
];

pub(crate) static ENTRY_UNVICTIMIZED_13147930702000821440: VariantsMap = [
    &["unvictimized"],
    &["unvictimised"],
    &["unvictimized"],
    &["unvictimised"],
];

pub(crate) static ENTRY_UNVISUALIZEDDER_17148048408574308157: VariantsMap = [
    &["unvisualizedder"],
    &["unvisualisedder"],
    &["unvisualizedder"],
    &["unvisualisedder"],
];

pub(crate) static ENTRY_UNVISUALIZEDDEST_3766144370146755628: VariantsMap = [
    &["unvisualizeddest"],
    &["unvisualiseddest"],
    &["unvisualizeddest"],
    &["unvisualiseddest"],
];

pub(crate) static ENTRY_UNVISUALIZED_10629125161003204005: VariantsMap = [
    &["unvisualized"],
    &["unvisualised"],
    &["unvisualized"],
    &["unvisualised"],
];

pub(crate) static ENTRY_UNVITALIZEDS_3502721533025861731: VariantsMap = [
    &["unvitalizeds"],
    &["unvitaliseds"],
    &["unvitalizeds"],
    &["unvitaliseds"],
];

pub(crate) static ENTRY_UNVITALIZED_3227640869725648957: VariantsMap = [
    &["unvitalized"],
    &["unvitalised"],
    &["unvitalized"],
    &["unvitalised"],
];

pub(crate) static ENTRY_UNVITRIOLIZEDS_6279669080760237108: VariantsMap = [
    &["unvitriolizeds"],
    &["unvitrioliseds"],
    &["unvitriolizeds"],
    &["unvitrioliseds"],
];

pub(crate) static ENTRY_UNVITRIOLIZED_18178005376251422334: VariantsMap = [
    &["unvitriolized"],
    &["unvitriolised"],
    &["unvitriolized"],
    &["unvitriolised"],
];

pub(crate) static ENTRY_UNVOCALIZEDDER_14054075246195872904: VariantsMap = [
    &["unvocalizedder"],
    &["unvocalisedder"],
    &["unvocalizedder"],
    &["unvocalisedder"],
];

pub(crate) static ENTRY_UNVOCALIZEDDEST_11194321700060332314: VariantsMap = [
    &["unvocalizeddest"],
    &["unvocaliseddest"],
    &["unvocalizeddest"],
    &["unvocaliseddest"],
];

pub(crate) static ENTRY_UNVOCALIZEDS_9772690236419527892: VariantsMap = [
    &["unvocalizeds"],
    &["unvocaliseds"],
    &["unvocalizeds"],
    &["unvocaliseds"],
];

pub(crate) static ENTRY_UNVOCALIZED_11577467705658915530: VariantsMap = [
    &["unvocalized"],
    &["unvocalised"],
    &["unvocalized"],
    &["unvocalised"],
];

pub(crate) static ENTRY_UNVOLATILIZEDDER_3893053978188165962: VariantsMap = [
    &["unvolatilizedder"],
    &["unvolatilisedder"],
    &["unvolatilizedder"],
    &["unvolatilisedder"],
];

pub(crate) static ENTRY_UNVOLATILIZEDDEST_2981075151788794586: VariantsMap = [
    &["unvolatilizeddest"],
    &["unvolatiliseddest"],
    &["unvolatilizeddest"],
    &["unvolatiliseddest"],
];

pub(crate) static ENTRY_UNVOLATILIZED_510948108982730129: VariantsMap = [
    &["unvolatilized"],
    &["unvolatilised"],
    &["unvolatilized"],
    &["unvolatilised"],
];

pub(crate) static ENTRY_UNVOLATILIZES_11377758185893284437: VariantsMap = [
    &["unvolatilizes"],
    &["unvolatilises"],
    &["unvolatilizes"],
    &["unvolatilises"],
];

pub(crate) static ENTRY_UNVOLATILIZE_11661168719592780567: VariantsMap = [
    &["unvolatilize"],
    &["unvolatilise"],
    &["unvolatilize"],
    &["unvolatilise"],
];

pub(crate) static ENTRY_UNVULCANIZEDDER_9219302424160022442: VariantsMap = [
    &["unvulcanizedder"],
    &["unvulcanisedder"],
    &["unvulcanizedder"],
    &["unvulcanisedder"],
];

pub(crate) static ENTRY_UNVULCANIZEDDEST_13602333265783224219: VariantsMap = [
    &["unvulcanizeddest"],
    &["unvulcaniseddest"],
    &["unvulcanizeddest"],
    &["unvulcaniseddest"],
];

pub(crate) static ENTRY_UNVULCANIZEDS_14843559940845440326: VariantsMap = [
    &["unvulcanizeds"],
    &["unvulcaniseds"],
    &["unvulcanizeds"],
    &["unvulcaniseds"],
];

pub(crate) static ENTRY_UNVULCANIZED_4883353722370077258: VariantsMap = [
    &["unvulcanized"],
    &["unvulcanised"],
    &["unvulcanized"],
    &["unvulcanised"],
];

pub(crate) static ENTRY_UNVULGARIZED_9965815826975289580: VariantsMap = [
    &["unvulgarized"],
    &["unvulgarised"],
    &["unvulgarized"],
    &["unvulgarised"],
];

pub(crate) static ENTRY_UNVULGARIZES_9567873413092075624: VariantsMap = [
    &["unvulgarizes"],
    &["unvulgarises"],
    &["unvulgarizes"],
    &["unvulgarises"],
];

pub(crate) static ENTRY_UNVULGARIZE_7587382011777787660: VariantsMap = [
    &["unvulgarize"],
    &["unvulgarise"],
    &["unvulgarize"],
    &["unvulgarise"],
];

pub(crate) static ENTRY_UNVULGARIZING_13060747384314447095: VariantsMap = [
    &["unvulgarizing"],
    &["unvulgarising"],
    &["unvulgarizing"],
    &["unvulgarising"],
];

pub(crate) static ENTRY_UNWESTERNIZEDS_7464751557548933854: VariantsMap = [
    &["unwesternizeds"],
    &["unwesterniseds"],
    &["unwesternizeds"],
    &["unwesterniseds"],
];

pub(crate) static ENTRY_UNWESTERNIZED_16804384595354754797: VariantsMap = [
    &["unwesternized"],
    &["unwesternised"],
    &["unwesternized"],
    &["unwesternised"],
];

pub(crate) static ENTRY_UNWOMANIZED_10013478943540238931: VariantsMap = [
    &["unwomanized"],
    &["unwomanised"],
    &["unwomanized"],
    &["unwomanised"],
];

pub(crate) static ENTRY_UNWOMANIZES_2686931929978088595: VariantsMap = [
    &["unwomanizes"],
    &["unwomanises"],
    &["unwomanizes"],
    &["unwomanises"],
];

pub(crate) static ENTRY_UNWOMANIZE_1985503055403674491: VariantsMap = [
    &["unwomanize"],
    &["unwomanise"],
    &["unwomanize"],
    &["unwomanise"],
];

pub(crate) static ENTRY_UPDRAFTS_3266150290118937286: VariantsMap = [
    &["updrafts"],
    &["updraughts"],
    &["updrafts"],
    &["updraughts"],
];

pub(crate) static ENTRY_UPDRAFT_2544941178284387496: VariantsMap =
    [&["updraft"], &["updraught"], &["updraft"], &["updraught"]];

pub(crate) static ENTRY_URALITIZATIONS_5627846874760536030: VariantsMap = [
    &["uralitizations"],
    &["uralitisations"],
    &["uralitizations"],
    &["uralitisations"],
];

pub(crate) static ENTRY_URALITIZATION_2328489967231120643: VariantsMap = [
    &["uralitization"],
    &["uralitisation"],
    &["uralitization"],
    &["uralitisation"],
];

pub(crate) static ENTRY_URALITIZED_204002861074668809: VariantsMap = [
    &["uralitized"],
    &["uralitised"],
    &["uralitized"],
    &["uralitised"],
];

pub(crate) static ENTRY_URALITIZES_16267515381011421047: VariantsMap = [
    &["uralitizes"],
    &["uralitises"],
    &["uralitizes"],
    &["uralitises"],
];

pub(crate) static ENTRY_URALITIZE_3773590098260410307: VariantsMap = [
    &["uralitize"],
    &["uralitise"],
    &["uralitize"],
    &["uralitise"],
];

pub(crate) static ENTRY_URALITIZING_10355237273114377488: VariantsMap = [
    &["uralitizing"],
    &["uralitising"],
    &["uralitizing"],
    &["uralitising"],
];

pub(crate) static ENTRY_URATEMIA_14232416398105000456: VariantsMap = [
    &["uratemia"],
    &["urataemia"],
    &["urataemia"],
    &["urataemia"],
];

pub(crate) static ENTRY_URBANIZATIONS_8711148164069228358: VariantsMap = [
    &["urbanizations"],
    &["urbanisations"],
    &["urbanizations"],
    &["urbanisations"],
];

pub(crate) static ENTRY_URBANIZATION_12387885989461849064: VariantsMap = [
    &["urbanization"],
    &["urbanisation"],
    &["urbanization"],
    &["urbanisation"],
];

pub(crate) static ENTRY_URBANIZED_8452856878168803812: VariantsMap = [
    &["urbanized"],
    &["urbanised"],
    &["urbanized"],
    &["urbanised"],
];

pub(crate) static ENTRY_URBANIZES_10930122484117694307: VariantsMap = [
    &["urbanizes"],
    &["urbanises"],
    &["urbanizes"],
    &["urbanises"],
];

pub(crate) static ENTRY_URBANIZE_7137294181980044513: VariantsMap =
    [&["urbanize"], &["urbanise"], &["urbanize"], &["urbanise"]];

pub(crate) static ENTRY_URBANIZING_14508129715867395456: VariantsMap = [
    &["urbanizing"],
    &["urbanising"],
    &["urbanizing"],
    &["urbanising"],
];

pub(crate) static ENTRY_UREDEMA_4080149276415718183: VariantsMap =
    [&["uredema"], &["uroedema"], &["uroedema"], &["uroedema"]];

pub(crate) static ENTRY_UREMIAS_12816641380732423378: VariantsMap =
    [&["uremias"], &["uraemias"], &["uremias"], &["uraemias"]];

pub(crate) static ENTRY_UREMIA_18083383868084280126: VariantsMap =
    [&["uremia"], &["uraemia"], &["uremia"], &["uraemia"]];

pub(crate) static ENTRY_UREMIC_1443341952685545241: VariantsMap =
    [&["uremic"], &["uraemic"], &["uremic"], &["uraemic"]];

pub(crate) static ENTRY_URETHRORRHEA_4573312718933151955: VariantsMap = [
    &["urethrorrhea"],
    &["urethrorrhoea"],
    &["urethrorrhoea"],
    &["urethrorrhoea"],
];

pub(crate) static ENTRY_URICEMIA_10236250755038957119: VariantsMap = [
    &["uricemia"],
    &["uricaemia"],
    &["uricaemia"],
    &["uricaemia"],
];

pub(crate) static ENTRY_URICEMIC_10169615382969686007: VariantsMap = [
    &["uricemic"],
    &["uricaemic"],
    &["uricaemic"],
    &["uricaemic"],
];

pub(crate) static ENTRY_URINEMIA_16117298491410487282: VariantsMap = [
    &["urinemia"],
    &["urinaemia"],
    &["urinaemia"],
    &["urinaemia"],
];

pub(crate) static ENTRY_URINEMIC_16880578158575836043: VariantsMap = [
    &["urinemic"],
    &["urinaemic"],
    &["urinaemic"],
    &["urinaemic"],
];

pub(crate) static ENTRY_UROHEMATIN_13360943616892094038: VariantsMap = [
    &["urohematin"],
    &["urohaematin"],
    &["urohaematin"],
    &["urohaematin"],
];

pub(crate) static ENTRY_UROPHEIN_6391807598160189992: VariantsMap = [
    &["urophein"],
    &["urophaein"],
    &["urophaein"],
    &["urophaein"],
];

pub(crate) static ENTRY_USABILITY_14697152389699662448: VariantsMap = [
    &["usability"],
    &["usability"],
    &["usability"],
    &["usability"],
];

pub(crate) static ENTRY_UTILITARIANIZED_4163007102774670957: VariantsMap = [
    &["utilitarianized"],
    &["utilitarianised"],
    &["utilitarianized"],
    &["utilitarianised"],
];

pub(crate) static ENTRY_UTILITARIANIZES_18334315752484546497: VariantsMap = [
    &["utilitarianizes"],
    &["utilitarianises"],
    &["utilitarianizes"],
    &["utilitarianises"],
];

pub(crate) static ENTRY_UTILITARIANIZE_16499671456877398727: VariantsMap = [
    &["utilitarianize"],
    &["utilitarianise"],
    &["utilitarianize"],
    &["utilitarianise"],
];

pub(crate) static ENTRY_UTILITARIANIZING_15409066625405044535: VariantsMap = [
    &["utilitarianizing"],
    &["utilitarianising"],
    &["utilitarianizing"],
    &["utilitarianising"],
];

pub(crate) static ENTRY_UTILIZABILITIES_11881898061855249496: VariantsMap = [
    &["utilizabilities"],
    &["utilisabilities"],
    &["utilizabilities"],
    &["utilisabilities"],
];

pub(crate) static ENTRY_UTILIZABILITY_12860697351170482431: VariantsMap = [
    &["utilizability"],
    &["utilisability"],
    &["utilizability"],
    &["utilisability"],
];

pub(crate) static ENTRY_UTILIZABLES_10040108748299984073: VariantsMap = [
    &["utilizables"],
    &["utilisables"],
    &["utilizables"],
    &["utilisables"],
];

pub(crate) static ENTRY_UTILIZABLE_6658429424042092500: VariantsMap = [
    &["utilizable"],
    &["utilisable"],
    &["utilizable"],
    &["utilisable"],
];

pub(crate) static ENTRY_UTILIZATIONS_5213929250198924058: VariantsMap = [
    &["utilizations"],
    &["utilisations"],
    &["utilizations"],
    &["utilisations"],
];

pub(crate) static ENTRY_UTILIZATION_6568984108837424526: VariantsMap = [
    &["utilization"],
    &["utilisation"],
    &["utilization"],
    &["utilisation"],
];

pub(crate) static ENTRY_UTILIZED_18374385558160803150: VariantsMap =
    [&["utilized"], &["utilised"], &["utilized"], &["utilised"]];

pub(crate) static ENTRY_UTILIZERS_7421512610729195706: VariantsMap = [
    &["utilizers"],
    &["utilisers"],
    &["utilizers"],
    &["utilisers"],
];

pub(crate) static ENTRY_UTILIZER_12640552973480950568: VariantsMap =
    [&["utilizer"], &["utiliser"], &["utilizer"], &["utiliser"]];

pub(crate) static ENTRY_UTILIZES_17217644256000960699: VariantsMap =
    [&["utilizes"], &["utilises"], &["utilizes"], &["utilises"]];

pub(crate) static ENTRY_UTILIZE_10044375682174548784: VariantsMap =
    [&["utilize"], &["utilise"], &["utilize"], &["utilise"]];

pub(crate) static ENTRY_UTILIZING_6570837818573449537: VariantsMap = [
    &["utilizing"],
    &["utilising"],
    &["utilizing"],
    &["utilising"],
];

pub(crate) static ENTRY_UTOPIANIZED_5257825936015196627: VariantsMap = [
    &["utopianized"],
    &["utopianised"],
    &["utopianized"],
    &["utopianised"],
];

pub(crate) static ENTRY_UTOPIANIZERS_16589758661481842229: VariantsMap = [
    &["utopianizers"],
    &["utopianisers"],
    &["utopianizers"],
    &["utopianisers"],
];

pub(crate) static ENTRY_UTOPIANIZER_9926780539300230048: VariantsMap = [
    &["utopianizer"],
    &["utopianiser"],
    &["utopianizer"],
    &["utopianiser"],
];

pub(crate) static ENTRY_UTOPIANIZES_7436002859222682332: VariantsMap = [
    &["utopianizes"],
    &["utopianises"],
    &["utopianizes"],
    &["utopianises"],
];

pub(crate) static ENTRY_UTOPIANIZE_3909405410781325408: VariantsMap = [
    &["utopianize"],
    &["utopianise"],
    &["utopianize"],
    &["utopianise"],
];

pub(crate) static ENTRY_UTOPIANIZING_10367314140698776591: VariantsMap = [
    &["utopianizing"],
    &["utopianising"],
    &["utopianizing"],
    &["utopianising"],
];

pub(crate) static ENTRY_VAAGMER_17502048229443235773: VariantsMap =
    [&["vaagmer"], &["vaagmaer"], &["vaagmaer"], &["vaagmaer"]];

pub(crate) static ENTRY_VACCINIZATIONS_1922009171419608969: VariantsMap = [
    &["vaccinizations"],
    &["vaccinisations"],
    &["vaccinizations"],
    &["vaccinisations"],
];

pub(crate) static ENTRY_VACCINIZATION_8106181806810108402: VariantsMap = [
    &["vaccinization"],
    &["vaccinisation"],
    &["vaccinization"],
    &["vaccinisation"],
];

pub(crate) static ENTRY_VACUOLIZATIONS_10347160945935413661: VariantsMap = [
    &["vacuolizations"],
    &["vacuolisations"],
    &["vacuolizations"],
    &["vacuolisations"],
];

pub(crate) static ENTRY_VACUOLIZATION_11646539416302232322: VariantsMap = [
    &["vacuolization"],
    &["vacuolisation"],
    &["vacuolization"],
    &["vacuolisation"],
];

pub(crate) static ENTRY_VACUUMIZED_4493282451537357801: VariantsMap = [
    &["vacuumized"],
    &["vacuumised"],
    &["vacuumized"],
    &["vacuumised"],
];

pub(crate) static ENTRY_VACUUMIZES_17532454384376281205: VariantsMap = [
    &["vacuumizes"],
    &["vacuumises"],
    &["vacuumizes"],
    &["vacuumises"],
];

pub(crate) static ENTRY_VACUUMIZE_13526087569368801646: VariantsMap = [
    &["vacuumize"],
    &["vacuumise"],
    &["vacuumize"],
    &["vacuumise"],
];

pub(crate) static ENTRY_VACUUMIZING_14054787523141533264: VariantsMap = [
    &["vacuumizing"],
    &["vacuumising"],
    &["vacuumizing"],
    &["vacuumising"],
];

pub(crate) static ENTRY_VAGABONDIZED_15281278738005878763: VariantsMap = [
    &["vagabondized"],
    &["vagabondised"],
    &["vagabondized"],
    &["vagabondised"],
];

pub(crate) static ENTRY_VAGABONDIZERS_3747353708553114039: VariantsMap = [
    &["vagabondizers"],
    &["vagabondisers"],
    &["vagabondizers"],
    &["vagabondisers"],
];

pub(crate) static ENTRY_VAGABONDIZER_10845102064298248541: VariantsMap = [
    &["vagabondizer"],
    &["vagabondiser"],
    &["vagabondizer"],
    &["vagabondiser"],
];

pub(crate) static ENTRY_VAGABONDIZES_16914905745572024859: VariantsMap = [
    &["vagabondizes"],
    &["vagabondises"],
    &["vagabondizes"],
    &["vagabondises"],
];

pub(crate) static ENTRY_VAGABONDIZE_1828506949789504418: VariantsMap = [
    &["vagabondize"],
    &["vagabondise"],
    &["vagabondize"],
    &["vagabondise"],
];

pub(crate) static ENTRY_VAGABONDIZING_536301653145662259: VariantsMap = [
    &["vagabondizing"],
    &["vagabondising"],
    &["vagabondizing"],
    &["vagabondising"],
];

pub(crate) static ENTRY_VAGINULE_10192361025884867710: VariantsMap = [
    &["vaginule"],
    &["vaginulae"],
    &["vaginulae"],
    &["vaginulae"],
];

pub(crate) static ENTRY_VAGRANTIZES_5103890612140781248: VariantsMap = [
    &["vagrantizes"],
    &["vagrantises"],
    &["vagrantizes"],
    &["vagrantises"],
];

pub(crate) static ENTRY_VAGRANTIZE_16327806044259598431: VariantsMap = [
    &["vagrantize"],
    &["vagrantise"],
    &["vagrantize"],
    &["vagrantise"],
];

pub(crate) static ENTRY_VALORIZATIONS_18099999439268061636: VariantsMap = [
    &["valorizations"],
    &["valorisations"],
    &["valorizations"],
    &["valorisations"],
];

pub(crate) static ENTRY_VALORIZATION_13227626070656104535: VariantsMap = [
    &["valorization"],
    &["valorisation"],
    &["valorization"],
    &["valorisation"],
];

pub(crate) static ENTRY_VALORIZED_18268036447448640796: VariantsMap = [
    &["valorized"],
    &["valorised"],
    &["valorized"],
    &["valorised"],
];

pub(crate) static ENTRY_VALORIZES_8203138506905157861: VariantsMap = [
    &["valorizes"],
    &["valorises"],
    &["valorizes"],
    &["valorises"],
];

pub(crate) static ENTRY_VALORIZE_2044080804493227048: VariantsMap =
    [&["valorize"], &["valorise"], &["valorize"], &["valorise"]];

pub(crate) static ENTRY_VALORIZING_1072198845281593214: VariantsMap = [
    &["valorizing"],
    &["valorising"],
    &["valorizing"],
    &["valorising"],
];

pub(crate) static ENTRY_VALOROUSNESS_9703103708455235988: VariantsMap = [
    &["valorousness"],
    &["valourousness"],
    &["valourousness"],
    &["valourousness"],
];

pub(crate) static ENTRY_VALORS_9234945520471825890: VariantsMap =
    [&["valors"], &["valours"], &["valours"], &["valours"]];

pub(crate) static ENTRY_VALOR_10381241029341969425: VariantsMap =
    [&["valor"], &["valour"], &["valour"], &["valour"]];

pub(crate) static ENTRY_VALVULE_8551640593569568914: VariantsMap =
    [&["valvule"], &["valvulae"], &["valvulae"], &["valvulae"]];

pub(crate) static ENTRY_VAMPIRIZED_14222402737807902965: VariantsMap = [
    &["vampirized"],
    &["vampirised"],
    &["vampirized"],
    &["vampirised"],
];

pub(crate) static ENTRY_VAMPIRIZES_16562346264831458764: VariantsMap = [
    &["vampirizes"],
    &["vampirises"],
    &["vampirizes"],
    &["vampirises"],
];

pub(crate) static ENTRY_VAMPIRIZE_17453207416415996069: VariantsMap = [
    &["vampirize"],
    &["vampirise"],
    &["vampirize"],
    &["vampirise"],
];

pub(crate) static ENTRY_VAMPIRIZING_9793272166226198060: VariantsMap = [
    &["vampirizing"],
    &["vampirising"],
    &["vampirizing"],
    &["vampirising"],
];

pub(crate) static ENTRY_VANDALIZATIONS_15625432211900495710: VariantsMap = [
    &["vandalizations"],
    &["vandalisations"],
    &["vandalizations"],
    &["vandalisations"],
];

pub(crate) static ENTRY_VANDALIZATION_6495560549083632958: VariantsMap = [
    &["vandalization"],
    &["vandalisation"],
    &["vandalization"],
    &["vandalisation"],
];

pub(crate) static ENTRY_VANDALIZED_4895140872617125953: VariantsMap = [
    &["vandalized"],
    &["vandalised"],
    &["vandalized"],
    &["vandalised"],
];

pub(crate) static ENTRY_VANDALIZES_7396543552418251345: VariantsMap = [
    &["vandalizes"],
    &["vandalises"],
    &["vandalizes"],
    &["vandalises"],
];

pub(crate) static ENTRY_VANDALIZE_3654743374834615371: VariantsMap = [
    &["vandalize"],
    &["vandalise"],
    &["vandalize"],
    &["vandalise"],
];

pub(crate) static ENTRY_VANDALIZING_2999607049988004510: VariantsMap = [
    &["vandalizing"],
    &["vandalising"],
    &["vandalizing"],
    &["vandalising"],
];

pub(crate) static ENTRY_VAPORABILITIES_16210230667077421998: VariantsMap = [
    &["vaporabilities"],
    &["vapourabilities"],
    &["vapourabilities"],
    &["vapourabilities"],
];

pub(crate) static ENTRY_VAPORABILITY_12774606556739795339: VariantsMap = [
    &["vaporability"],
    &["vapourability"],
    &["vapourability"],
    &["vapourability"],
];

pub(crate) static ENTRY_VAPORABLES_11612330563163535423: VariantsMap = [
    &["vaporables"],
    &["vapourables"],
    &["vapourables"],
    &["vapourables"],
];

pub(crate) static ENTRY_VAPORABLE_5501212841170621386: VariantsMap = [
    &["vaporable"],
    &["vapourable"],
    &["vapourable"],
    &["vapourable"],
];

pub(crate) static ENTRY_VAPORED_8090866757673721955: VariantsMap =
    [&["vapored"], &["vapoured"], &["vapoured"], &["vapoured"]];

pub(crate) static ENTRY_VAPORERS_1337800929973980777: VariantsMap = [
    &["vaporers"],
    &["vapourers"],
    &["vapourers"],
    &["vapourers"],
];

pub(crate) static ENTRY_VAPORER_15606043365547492909: VariantsMap =
    [&["vaporer"], &["vapourer"], &["vapourer"], &["vapourer"]];

pub(crate) static ENTRY_VAPORESCENT_5937298821672753827: VariantsMap = [
    &["vaporescent"],
    &["vapourescent"],
    &["vapourescent"],
    &["vapourescent"],
];

pub(crate) static ENTRY_VAPORIER_10870396883532803185: VariantsMap = [
    &["vaporier"],
    &["vapourier"],
    &["vapourier"],
    &["vapourier"],
];

pub(crate) static ENTRY_VAPORIEST_14983690178384093877: VariantsMap = [
    &["vaporiest"],
    &["vapouriest"],
    &["vapouriest"],
    &["vapouriest"],
];

pub(crate) static ENTRY_VAPORIFIC_4203042838768085117: VariantsMap = [
    &["vaporific"],
    &["vapourific"],
    &["vapourific"],
    &["vapourific"],
];

pub(crate) static ENTRY_VAPORIMETER_6307567735178986275: VariantsMap = [
    &["vaporimeter"],
    &["vapourimeter"],
    &["vapourimeter"],
    &["vapourimeter"],
];

pub(crate) static ENTRY_VAPORINGLY_17882474581404052992: VariantsMap = [
    &["vaporingly"],
    &["vapouringly"],
    &["vapouringly"],
    &["vapouringly"],
];

pub(crate) static ENTRY_VAPORINGS_1485515244068360371: VariantsMap = [
    &["vaporings"],
    &["vapourings"],
    &["vapourings"],
    &["vapourings"],
];

pub(crate) static ENTRY_VAPORING_420257298669421065: VariantsMap = [
    &["vaporing"],
    &["vapouring"],
    &["vapouring"],
    &["vapouring"],
];

pub(crate) static ENTRY_VAPORISHER_1025608314806119016: VariantsMap = [
    &["vaporisher"],
    &["vapourisher"],
    &["vapourisher"],
    &["vapourisher"],
];

pub(crate) static ENTRY_VAPORISHEST_2688111660339631646: VariantsMap = [
    &["vaporishest"],
    &["vapourishest"],
    &["vapourishest"],
    &["vapourishest"],
];

pub(crate) static ENTRY_VAPORISHNESSES_6785939461569914269: VariantsMap = [
    &["vaporishnesses"],
    &["vapourishnesses"],
    &["vapourishnesses"],
    &["vapourishnesses"],
];

pub(crate) static ENTRY_VAPORISHNESS_15785186011197470564: VariantsMap = [
    &["vaporishness"],
    &["vapourishness"],
    &["vapourishness"],
    &["vapourishness"],
];

pub(crate) static ENTRY_VAPORISH_1792709436180269388: VariantsMap = [
    &["vaporish"],
    &["vapourish"],
    &["vapourish"],
    &["vapourish"],
];

pub(crate) static ENTRY_VAPORIZABLER_2686036342147244593: VariantsMap = [
    &["vaporizabler"],
    &["vaporisabler"],
    &["vaporizabler"],
    &["vaporisabler"],
];

pub(crate) static ENTRY_VAPORIZABLEST_6961996652683939422: VariantsMap = [
    &["vaporizablest"],
    &["vaporisablest"],
    &["vaporizablest"],
    &["vaporisablest"],
];

pub(crate) static ENTRY_VAPORIZABLES_602114803906365139: VariantsMap = [
    &["vaporizables"],
    &["vaporisables"],
    &["vaporizables"],
    &["vaporisables"],
];

pub(crate) static ENTRY_VAPORIZABLE_11495926926379792888: VariantsMap = [
    &["vaporizable"],
    &["vaporisable"],
    &["vaporizable"],
    &["vaporisable"],
];

pub(crate) static ENTRY_VAPORIZATIONS_16022234579712511195: VariantsMap = [
    &["vaporizations"],
    &["vaporisations"],
    &["vaporizations"],
    &["vaporisations"],
];

pub(crate) static ENTRY_VAPORIZATION_18013020655663665183: VariantsMap = [
    &["vaporization"],
    &["vaporisation"],
    &["vaporization"],
    &["vaporisation"],
];

pub(crate) static ENTRY_VAPORIZED_15975626787835074281: VariantsMap = [
    &["vaporized"],
    &["vaporised"],
    &["vaporized"],
    &["vaporised"],
];

pub(crate) static ENTRY_VAPORIZERS_5986565178581788761: VariantsMap = [
    &["vaporizers"],
    &["vaporisers"],
    &["vaporizers"],
    &["vaporisers"],
];

pub(crate) static ENTRY_VAPORIZER_2660185636167297891: VariantsMap = [
    &["vaporizer"],
    &["vaporiser"],
    &["vaporizer"],
    &["vaporiser"],
];

pub(crate) static ENTRY_VAPORIZES_9602890245599971042: VariantsMap = [
    &["vaporizes"],
    &["vaporises"],
    &["vaporizes"],
    &["vaporises"],
];

pub(crate) static ENTRY_VAPORIZE_3098164633633455886: VariantsMap =
    [&["vaporize"], &["vaporise"], &["vaporize"], &["vaporise"]];

pub(crate) static ENTRY_VAPORIZING_11567514291379105650: VariantsMap = [
    &["vaporizing"],
    &["vaporising"],
    &["vaporizing"],
    &["vaporising"],
];

pub(crate) static ENTRY_VAPORLESSES_5837573394417037459: VariantsMap = [
    &["vaporlesses"],
    &["vapourlesses"],
    &["vapourlesses"],
    &["vapourlesses"],
];

pub(crate) static ENTRY_VAPORLESS_12823347514087919905: VariantsMap = [
    &["vaporless"],
    &["vapourless"],
    &["vapourless"],
    &["vapourless"],
];

pub(crate) static ENTRY_VAPORLIKES_4827403622949682642: VariantsMap = [
    &["vaporlikes"],
    &["vapourlikes"],
    &["vapourlikes"],
    &["vapourlikes"],
];

pub(crate) static ENTRY_VAPORLIKE_12611878629021498077: VariantsMap = [
    &["vaporlike"],
    &["vapourlike"],
    &["vapourlike"],
    &["vapourlike"],
];

pub(crate) static ENTRY_VAPOROSE_6449688285161662447: VariantsMap = [
    &["vaporose"],
    &["vapourose"],
    &["vapourose"],
    &["vapourose"],
];

pub(crate) static ENTRY_VAPOROUSLY_4033817846371416657: VariantsMap = [
    &["vaporously"],
    &["vapourously"],
    &["vapourously"],
    &["vapourously"],
];

pub(crate) static ENTRY_VAPORS_10654457609159557123: VariantsMap =
    [&["vapors"], &["vapours"], &["vapours"], &["vapours"]];

pub(crate) static ENTRY_VAPORWARE_9698524933063954413: VariantsMap = [
    &["vaporware"],
    &["vapourware"],
    &["vapourware"],
    &["vapourware"],
];

pub(crate) static ENTRY_VAPORY_2699803825003632190: VariantsMap =
    [&["vapory"], &["vapoury"], &["vapoury"], &["vapoury"]];

pub(crate) static ENTRY_VAPOR_2186715544993402811: VariantsMap =
    [&["vapor"], &["vapour"], &["vapour"], &["vapour"]];

pub(crate) static ENTRY_VARICOLOREDDER_17739587046028260965: VariantsMap = [
    &["varicoloredder"],
    &["varicolouredder"],
    &["varicolouredder"],
    &["varicolouredder"],
];

pub(crate) static ENTRY_VARICOLOREDDEST_13804238764633913841: VariantsMap = [
    &["varicoloreddest"],
    &["varicoloureddest"],
    &["varicoloureddest"],
    &["varicoloureddest"],
];

pub(crate) static ENTRY_VARICOLOREDS_11023757870916070482: VariantsMap = [
    &["varicoloreds"],
    &["varicoloureds"],
    &["varicoloureds"],
    &["varicoloureds"],
];

pub(crate) static ENTRY_VARICOLORED_14826810108614522572: VariantsMap = [
    &["varicolored"],
    &["varicoloured"],
    &["varicoloured"],
    &["varicoloured"],
];

pub(crate) static ENTRY_VARICOLOROUS_12718480012886049444: VariantsMap = [
    &["varicolorous"],
    &["varicolourous"],
    &["varicolourous"],
    &["varicolourous"],
];

pub(crate) static ENTRY_VASCULARIZATIONS_10231044964090450051: VariantsMap = [
    &["vascularizations"],
    &["vascularisations"],
    &["vascularizations"],
    &["vascularisations"],
];

pub(crate) static ENTRY_VASCULARIZATION_1873656875493637800: VariantsMap = [
    &["vascularization"],
    &["vascularisation"],
    &["vascularization"],
    &["vascularisation"],
];

pub(crate) static ENTRY_VASCULARIZED_15040037911474250866: VariantsMap = [
    &["vascularized"],
    &["vascularised"],
    &["vascularized"],
    &["vascularised"],
];

pub(crate) static ENTRY_VASCULARIZES_7450544747817806685: VariantsMap = [
    &["vascularizes"],
    &["vascularises"],
    &["vascularizes"],
    &["vascularises"],
];

pub(crate) static ENTRY_VASCULARIZE_18409549429241791397: VariantsMap = [
    &["vascularize"],
    &["vascularise"],
    &["vascularize"],
    &["vascularise"],
];

pub(crate) static ENTRY_VASCULARIZING_13147736200759695458: VariantsMap = [
    &["vascularizing"],
    &["vascularising"],
    &["vascularizing"],
    &["vascularising"],
];

pub(crate) static ENTRY_VASECTOMIZED_9802783923443016839: VariantsMap = [
    &["vasectomized"],
    &["vasectomised"],
    &["vasectomized"],
    &["vasectomised"],
];

pub(crate) static ENTRY_VASECTOMIZE_14117059244189610141: VariantsMap = [
    &["vasectomize"],
    &["vasectomise"],
    &["vasectomize"],
    &["vasectomise"],
];

pub(crate) static ENTRY_VASECTOMIZING_9067814547217523949: VariantsMap = [
    &["vasectomizing"],
    &["vasectomising"],
    &["vasectomizing"],
    &["vasectomising"],
];

pub(crate) static ENTRY_VASSALIZATION_11913810286930660962: VariantsMap = [
    &["vassalization"],
    &["vassalisation"],
    &["vassalization"],
    &["vassalisation"],
];

pub(crate) static ENTRY_VASSALIZED_14302164483296963637: VariantsMap = [
    &["vassalized"],
    &["vassalised"],
    &["vassalized"],
    &["vassalised"],
];

pub(crate) static ENTRY_VASSALIZES_404335759200109889: VariantsMap = [
    &["vassalizes"],
    &["vassalises"],
    &["vassalizes"],
    &["vassalises"],
];

pub(crate) static ENTRY_VASSALIZE_15684651890209783105: VariantsMap = [
    &["vassalize"],
    &["vassalise"],
    &["vassalize"],
    &["vassalise"],
];

pub(crate) static ENTRY_VASSALIZING_10504927354705456811: VariantsMap = [
    &["vassalizing"],
    &["vassalising"],
    &["vassalizing"],
    &["vassalising"],
];

pub(crate) static ENTRY_VATICANIZATIONS_4284951110958617053: VariantsMap = [
    &["vaticanizations"],
    &["vaticanisations"],
    &["vaticanizations"],
    &["vaticanisations"],
];

pub(crate) static ENTRY_VATICANIZATION_9714400903507160409: VariantsMap = [
    &["vaticanization"],
    &["vaticanisation"],
    &["vaticanization"],
    &["vaticanisation"],
];

pub(crate) static ENTRY_VATICANIZES_15643199634116450854: VariantsMap = [
    &["vaticanizes"],
    &["vaticanises"],
    &["vaticanizes"],
    &["vaticanises"],
];

pub(crate) static ENTRY_VATICANIZE_447252295327213484: VariantsMap = [
    &["vaticanize"],
    &["vaticanise"],
    &["vaticanize"],
    &["vaticanise"],
];

pub(crate) static ENTRY_VAVASORS_13483440249798277072: VariantsMap = [
    &["vavasors"],
    &["vavasours"],
    &["vavasours"],
    &["vavasours"],
];

pub(crate) static ENTRY_VAVASOR_13335526244828687938: VariantsMap =
    [&["vavasor"], &["vavasour"], &["vavasour"], &["vavasour"]];

pub(crate) static ENTRY_VECTORIZABLE_7700511871799517175: VariantsMap = [
    &["vectorizable"],
    &["vectorisable"],
    &["vectorizable"],
    &["vectorisable"],
];

pub(crate) static ENTRY_VECTORIZATIONS_15801982123847128215: VariantsMap = [
    &["vectorizations"],
    &["vectorisations"],
    &["vectorizations"],
    &["vectorisations"],
];

pub(crate) static ENTRY_VECTORIZATION_10787111062319216653: VariantsMap = [
    &["vectorization"],
    &["vectorisation"],
    &["vectorization"],
    &["vectorisation"],
];

pub(crate) static ENTRY_VECTORIZED_11582193843268490434: VariantsMap = [
    &["vectorized"],
    &["vectorised"],
    &["vectorized"],
    &["vectorised"],
];

pub(crate) static ENTRY_VECTORIZERED_12945770792403996963: VariantsMap = [
    &["vectorizered"],
    &["vectorisered"],
    &["vectorizered"],
    &["vectorisered"],
];

pub(crate) static ENTRY_VECTORIZERING_7399862757873995787: VariantsMap = [
    &["vectorizering"],
    &["vectorisering"],
    &["vectorizering"],
    &["vectorisering"],
];

pub(crate) static ENTRY_VECTORIZERS_10774848315320864388: VariantsMap = [
    &["vectorizers"],
    &["vectorisers"],
    &["vectorizers"],
    &["vectorisers"],
];

pub(crate) static ENTRY_VECTORIZER_10024278019728920356: VariantsMap = [
    &["vectorizer"],
    &["vectoriser"],
    &["vectorizer"],
    &["vectoriser"],
];

pub(crate) static ENTRY_VECTORIZES_10986965122273304100: VariantsMap = [
    &["vectorizes"],
    &["vectorises"],
    &["vectorizes"],
    &["vectorises"],
];

pub(crate) static ENTRY_VECTORIZE_7621545906945634571: VariantsMap = [
    &["vectorize"],
    &["vectorise"],
    &["vectorize"],
    &["vectorise"],
];

pub(crate) static ENTRY_VECTORIZING_9813119268612536101: VariantsMap = [
    &["vectorizing"],
    &["vectorising"],
    &["vectorizing"],
    &["vectorising"],
];

pub(crate) static ENTRY_VEERY_16377240070055312686: VariantsMap =
    [&["veery"], &["verey"], &["verey"], &["verey"]];

pub(crate) static ENTRY_VEGETABLIZES_13431862844399419063: VariantsMap = [
    &["vegetablizes"],
    &["vegetablises"],
    &["vegetablizes"],
    &["vegetablises"],
];

pub(crate) static ENTRY_VEGETABLIZE_240867435962121524: VariantsMap = [
    &["vegetablize"],
    &["vegetablise"],
    &["vegetablize"],
    &["vegetablise"],
];

pub(crate) static ENTRY_VELARIZATIONS_16578843012905334995: VariantsMap = [
    &["velarizations"],
    &["velarisations"],
    &["velarizations"],
    &["velarisations"],
];

pub(crate) static ENTRY_VELARIZATION_6695615417336752356: VariantsMap = [
    &["velarization"],
    &["velarisation"],
    &["velarization"],
    &["velarisation"],
];

pub(crate) static ENTRY_VELARIZED_6812327040601340521: VariantsMap = [
    &["velarized"],
    &["velarised"],
    &["velarized"],
    &["velarised"],
];

pub(crate) static ENTRY_VELARIZES_15540494560951794576: VariantsMap = [
    &["velarizes"],
    &["velarises"],
    &["velarizes"],
    &["velarises"],
];

pub(crate) static ENTRY_VELARIZE_11928218775132434386: VariantsMap =
    [&["velarize"], &["velarise"], &["velarize"], &["velarise"]];

pub(crate) static ENTRY_VELARIZING_1563679261014512608: VariantsMap = [
    &["velarizing"],
    &["velarising"],
    &["velarizing"],
    &["velarising"],
];

pub(crate) static ENTRY_VENALIZATIONS_18162172463769168949: VariantsMap = [
    &["venalizations"],
    &["venalisations"],
    &["venalizations"],
    &["venalisations"],
];

pub(crate) static ENTRY_VENALIZATION_10105179936386523824: VariantsMap = [
    &["venalization"],
    &["venalisation"],
    &["venalization"],
    &["venalisation"],
];

pub(crate) static ENTRY_VENALIZES_17167448239623843588: VariantsMap = [
    &["venalizes"],
    &["venalises"],
    &["venalizes"],
    &["venalises"],
];

pub(crate) static ENTRY_VENALIZE_16371697667188046045: VariantsMap =
    [&["venalize"], &["venalise"], &["venalize"], &["venalise"]];

pub(crate) static ENTRY_VENDORS_1436950525202030326: VariantsMap =
    [&["vendors"], &["vendors"], &["vendors"], &["vendors"]];

pub(crate) static ENTRY_VENDOR_614257521164925268: VariantsMap =
    [&["vendor"], &["vendor"], &["vendor"], &["vendor"]];

pub(crate) static ENTRY_VENOMIZATIONS_15562672786718899376: VariantsMap = [
    &["venomizations"],
    &["venomisations"],
    &["venomizations"],
    &["venomisations"],
];

pub(crate) static ENTRY_VENOMIZATION_3248380214395011937: VariantsMap = [
    &["venomization"],
    &["venomisation"],
    &["venomization"],
    &["venomisation"],
];

pub(crate) static ENTRY_VENOMIZES_1220144968938148346: VariantsMap = [
    &["venomizes"],
    &["venomises"],
    &["venomizes"],
    &["venomises"],
];

pub(crate) static ENTRY_VENOMIZE_13397367997497163317: VariantsMap =
    [&["venomize"], &["venomise"], &["venomize"], &["venomise"]];

pub(crate) static ENTRY_VENTERS_10581975041225097234: VariantsMap =
    [&["venters"], &["ventres"], &["ventres"], &["ventres"]];

pub(crate) static ENTRY_VENTER_3246201295857892913: VariantsMap =
    [&["venter"], &["ventre"], &["ventre"], &["ventre"]];

pub(crate) static ENTRY_VENTRILOQUIZED_3898326028561445962: VariantsMap = [
    &["ventriloquized"],
    &["ventriloquised"],
    &["ventriloquized"],
    &["ventriloquised"],
];

pub(crate) static ENTRY_VENTRILOQUIZES_221071050486777356: VariantsMap = [
    &["ventriloquizes"],
    &["ventriloquises"],
    &["ventriloquizes"],
    &["ventriloquises"],
];

pub(crate) static ENTRY_VENTRILOQUIZE_6075592572709749127: VariantsMap = [
    &["ventriloquize"],
    &["ventriloquise"],
    &["ventriloquize"],
    &["ventriloquise"],
];

pub(crate) static ENTRY_VENTRILOQUIZING_17870016245092386407: VariantsMap = [
    &["ventriloquizing"],
    &["ventriloquising"],
    &["ventriloquizing"],
    &["ventriloquising"],
];

pub(crate) static ENTRY_VENULE_15331508582682614848: VariantsMap =
    [&["venule"], &["venulae"], &["venulae"], &["venulae"]];

pub(crate) static ENTRY_VERBALIZATIONS_2148556691017306909: VariantsMap = [
    &["verbalizations"],
    &["verbalisations"],
    &["verbalizations"],
    &["verbalisations"],
];

pub(crate) static ENTRY_VERBALIZATION_17014780536966514150: VariantsMap = [
    &["verbalization"],
    &["verbalisation"],
    &["verbalization"],
    &["verbalisation"],
];

pub(crate) static ENTRY_VERBALIZED_10494008423617804243: VariantsMap = [
    &["verbalized"],
    &["verbalised"],
    &["verbalized"],
    &["verbalised"],
];

pub(crate) static ENTRY_VERBALIZERS_6929664897053786061: VariantsMap = [
    &["verbalizers"],
    &["verbalisers"],
    &["verbalizers"],
    &["verbalisers"],
];

pub(crate) static ENTRY_VERBALIZER_4530481668094425579: VariantsMap = [
    &["verbalizer"],
    &["verbaliser"],
    &["verbalizer"],
    &["verbaliser"],
];

pub(crate) static ENTRY_VERBALIZES_11158219462754520064: VariantsMap = [
    &["verbalizes"],
    &["verbalises"],
    &["verbalizes"],
    &["verbalises"],
];

pub(crate) static ENTRY_VERBALIZE_1198319365461788046: VariantsMap = [
    &["verbalize"],
    &["verbalise"],
    &["verbalize"],
    &["verbalise"],
];

pub(crate) static ENTRY_VERBALIZING_3065579017212147213: VariantsMap = [
    &["verbalizing"],
    &["verbalising"],
    &["verbalizing"],
    &["verbalising"],
];

pub(crate) static ENTRY_VERMEILED_17836589369144520864: VariantsMap = [
    &["vermeiled"],
    &["vermeilled"],
    &["vermeilled"],
    &["vermeilled"],
];

pub(crate) static ENTRY_VERMEILES_8456241915430697238: VariantsMap = [
    &["vermeiles"],
    &["vermeilles"],
    &["vermeilles"],
    &["vermeilles"],
];

pub(crate) static ENTRY_VERMEILING_17221139503778611025: VariantsMap = [
    &["vermeiling"],
    &["vermeilling"],
    &["vermeilling"],
    &["vermeilling"],
];

pub(crate) static ENTRY_VERMILIONIZES_3945706269410456994: VariantsMap = [
    &["vermilionizes"],
    &["vermilionises"],
    &["vermilionizes"],
    &["vermilionises"],
];

pub(crate) static ENTRY_VERMILIONIZE_507242095798633515: VariantsMap = [
    &["vermilionize"],
    &["vermilionise"],
    &["vermilionize"],
    &["vermilionise"],
];

pub(crate) static ENTRY_VERNACULARIZATIONS_18117165289653141930: VariantsMap = [
    &["vernacularizations"],
    &["vernacularisations"],
    &["vernacularizations"],
    &["vernacularisations"],
];

pub(crate) static ENTRY_VERNACULARIZATION_13966126810584473659: VariantsMap = [
    &["vernacularization"],
    &["vernacularisation"],
    &["vernacularization"],
    &["vernacularisation"],
];

pub(crate) static ENTRY_VERNACULARIZED_12976593463419560760: VariantsMap = [
    &["vernacularized"],
    &["vernacularised"],
    &["vernacularized"],
    &["vernacularised"],
];

pub(crate) static ENTRY_VERNACULARIZES_15421918173517522502: VariantsMap = [
    &["vernacularizes"],
    &["vernacularises"],
    &["vernacularizes"],
    &["vernacularises"],
];

pub(crate) static ENTRY_VERNACULARIZE_2429868034092124522: VariantsMap = [
    &["vernacularize"],
    &["vernacularise"],
    &["vernacularize"],
    &["vernacularise"],
];

pub(crate) static ENTRY_VERNACULARIZING_12054872340898509491: VariantsMap = [
    &["vernacularizing"],
    &["vernacularising"],
    &["vernacularizing"],
    &["vernacularising"],
];

pub(crate) static ENTRY_VERNALIZATIONS_16909117428759612836: VariantsMap = [
    &["vernalizations"],
    &["vernalisations"],
    &["vernalizations"],
    &["vernalisations"],
];

pub(crate) static ENTRY_VERNALIZATION_8602093814476102861: VariantsMap = [
    &["vernalization"],
    &["vernalisation"],
    &["vernalization"],
    &["vernalisation"],
];

pub(crate) static ENTRY_VERNALIZED_7603884031730520040: VariantsMap = [
    &["vernalized"],
    &["vernalised"],
    &["vernalized"],
    &["vernalised"],
];

pub(crate) static ENTRY_VERNALIZES_4553921016291793785: VariantsMap = [
    &["vernalizes"],
    &["vernalises"],
    &["vernalizes"],
    &["vernalises"],
];

pub(crate) static ENTRY_VERNALIZE_5219754446623447026: VariantsMap = [
    &["vernalize"],
    &["vernalise"],
    &["vernalize"],
    &["vernalise"],
];

pub(crate) static ENTRY_VERNALIZING_3592189555940731803: VariantsMap = [
    &["vernalizing"],
    &["vernalising"],
    &["vernalizing"],
    &["vernalising"],
];

pub(crate) static ENTRY_VERSICOLORATE_10320999794267613649: VariantsMap = [
    &["versicolorate"],
    &["versicolourate"],
    &["versicolourate"],
    &["versicolourate"],
];

pub(crate) static ENTRY_VERSICOLORED_8040480056728281804: VariantsMap = [
    &["versicolored"],
    &["versicoloured"],
    &["versicoloured"],
    &["versicoloured"],
];

pub(crate) static ENTRY_VERSICOLOROUS_233687980256971301: VariantsMap = [
    &["versicolorous"],
    &["versicolourous"],
    &["versicolourous"],
    &["versicolourous"],
];

pub(crate) static ENTRY_VERSICOLOR_14351830468170420943: VariantsMap = [
    &["versicolor"],
    &["versicolour"],
    &["versicolour"],
    &["versicolour"],
];

pub(crate) static ENTRY_VERSIONIZES_7018911115976618102: VariantsMap = [
    &["versionizes"],
    &["versionises"],
    &["versionizes"],
    &["versionises"],
];

pub(crate) static ENTRY_VERSIONIZE_12827553166085838878: VariantsMap = [
    &["versionize"],
    &["versionise"],
    &["versionize"],
    &["versionise"],
];

pub(crate) static ENTRY_VESICULE_16844954968158523223: VariantsMap = [
    &["vesicule"],
    &["vesiculae"],
    &["vesiculae"],
    &["vesiculae"],
];

pub(crate) static ENTRY_VESTRYIZES_6797183257216810494: VariantsMap = [
    &["vestryizes"],
    &["vestryises"],
    &["vestryizes"],
    &["vestryises"],
];

pub(crate) static ENTRY_VESTRYIZE_5233128555052687391: VariantsMap = [
    &["vestryize"],
    &["vestryise"],
    &["vestryize"],
    &["vestryise"],
];

pub(crate) static ENTRY_VETERANIZES_12354557690927578928: VariantsMap = [
    &["veteranizes"],
    &["veteranises"],
    &["veteranizes"],
    &["veteranises"],
];

pub(crate) static ENTRY_VETERANIZE_10475186833571792476: VariantsMap = [
    &["veteranize"],
    &["veteranise"],
    &["veteranize"],
    &["veteranise"],
];

pub(crate) static ENTRY_VETER_13271994869120784461: VariantsMap =
    [&["veter"], &["vetoer"], &["vetoer"], &["vetoer"]];

pub(crate) static ENTRY_VE_5155558316755050493: VariantsMap =
    [&["ve"], &["voe"], &["voe"], &["voe"]];

pub(crate) static ENTRY_VIALED_6673508382112164229: VariantsMap =
    [&["vialed"], &["vialled"], &["vialled"], &["vialled"]];

pub(crate) static ENTRY_VIALING_8784593913542250179: VariantsMap =
    [&["vialing"], &["vialling"], &["vialling"], &["vialling"]];

pub(crate) static ENTRY_VICTIMIZABLES_6241000807340860355: VariantsMap = [
    &["victimizables"],
    &["victimisables"],
    &["victimizables"],
    &["victimisables"],
];

pub(crate) static ENTRY_VICTIMIZABLE_6325841584128803768: VariantsMap = [
    &["victimizable"],
    &["victimisable"],
    &["victimizable"],
    &["victimisable"],
];

pub(crate) static ENTRY_VICTIMIZATIONS_5670211910093257144: VariantsMap = [
    &["victimizations"],
    &["victimisations"],
    &["victimizations"],
    &["victimisations"],
];

pub(crate) static ENTRY_VICTIMIZATION_6473682179195269391: VariantsMap = [
    &["victimization"],
    &["victimisation"],
    &["victimization"],
    &["victimisation"],
];

pub(crate) static ENTRY_VICTIMIZED_16785627582641973610: VariantsMap = [
    &["victimized"],
    &["victimised"],
    &["victimized"],
    &["victimised"],
];

pub(crate) static ENTRY_VICTIMIZERS_1678778459889759577: VariantsMap = [
    &["victimizers"],
    &["victimisers"],
    &["victimizers"],
    &["victimisers"],
];

pub(crate) static ENTRY_VICTIMIZER_15193367442648599657: VariantsMap = [
    &["victimizer"],
    &["victimiser"],
    &["victimizer"],
    &["victimiser"],
];

pub(crate) static ENTRY_VICTIMIZES_10527897189755188591: VariantsMap = [
    &["victimizes"],
    &["victimises"],
    &["victimizes"],
    &["victimises"],
];

pub(crate) static ENTRY_VICTIMIZE_17964381173204803563: VariantsMap = [
    &["victimize"],
    &["victimise"],
    &["victimize"],
    &["victimise"],
];

pub(crate) static ENTRY_VICTIMIZING_2512377935106454315: VariantsMap = [
    &["victimizing"],
    &["victimising"],
    &["victimizing"],
    &["victimising"],
];

pub(crate) static ENTRY_VICTORIANIZES_4206206383857008164: VariantsMap = [
    &["victorianizes"],
    &["victorianises"],
    &["victorianizes"],
    &["victorianises"],
];

pub(crate) static ENTRY_VICTORIANIZE_278741780816601909: VariantsMap = [
    &["victorianize"],
    &["victorianise"],
    &["victorianize"],
    &["victorianise"],
];

pub(crate) static ENTRY_VICTUALAGES_7832395254409182637: VariantsMap = [
    &["victualages"],
    &["victuallages"],
    &["victuallages"],
    &["victuallages"],
];

pub(crate) static ENTRY_VICTUALAGE_550065404232068014: VariantsMap = [
    &["victualage"],
    &["victuallage"],
    &["victuallage"],
    &["victuallage"],
];

pub(crate) static ENTRY_VICTUALED_15540819304108381987: VariantsMap = [
    &["victualed"],
    &["victualled"],
    &["victualled"],
    &["victualled"],
];

pub(crate) static ENTRY_VICTUALERS_12039289652841636588: VariantsMap = [
    &["victualers"],
    &["victuallers"],
    &["victuallers"],
    &["victuallers"],
];

pub(crate) static ENTRY_VICTUALER_6653512003545303549: VariantsMap = [
    &["victualer"],
    &["victualler"],
    &["victualler"],
    &["victualler"],
];

pub(crate) static ENTRY_VICTUALESS_5827356037504397036: VariantsMap = [
    &["victualess"],
    &["victualless"],
    &["victualless"],
    &["victualless"],
];

pub(crate) static ENTRY_VICTUALING_15440302570998416657: VariantsMap = [
    &["victualing"],
    &["victualling"],
    &["victualling"],
    &["victualling"],
];

pub(crate) static ENTRY_VIDEODISCS_16872815408295672812: VariantsMap = [
    &["videodiscs"],
    &["videodiscs"],
    &["videodiscs"],
    &["videodiscs"],
];

pub(crate) static ENTRY_VIDEODISC_6353050125875667178: VariantsMap = [
    &["videodisc"],
    &["videodisc"],
    &["videodisc"],
    &["videodisc"],
];

pub(crate) static ENTRY_VIERS_14228033346609932442: VariantsMap =
    [&["viers"], &["vires"], &["vires"], &["vires"]];

pub(crate) static ENTRY_VIER_13580000022985666082: VariantsMap =
    [&["vier"], &["vire"], &["vire"], &["vire"]];

pub(crate) static ENTRY_VIETNAMIZATION_15878813039655610439: VariantsMap = [
    &["vietnamization"],
    &["vietnamisation"],
    &["vietnamization"],
    &["vietnamisation"],
];

pub(crate) static ENTRY_VIETNAMIZED_12635785661712716002: VariantsMap = [
    &["vietnamized"],
    &["vietnamised"],
    &["vietnamized"],
    &["vietnamised"],
];

pub(crate) static ENTRY_VIETNAMIZES_5960161263908738812: VariantsMap = [
    &["vietnamizes"],
    &["vietnamises"],
    &["vietnamizes"],
    &["vietnamises"],
];

pub(crate) static ENTRY_VIETNAMIZE_10929007049885521412: VariantsMap = [
    &["vietnamize"],
    &["vietnamise"],
    &["vietnamize"],
    &["vietnamise"],
];

pub(crate) static ENTRY_VIETNAMIZING_2857912616716494009: VariantsMap = [
    &["vietnamizing"],
    &["vietnamising"],
    &["vietnamizing"],
    &["vietnamising"],
];

pub(crate) static ENTRY_VIGORLESS_6116200848533060992: VariantsMap = [
    &["vigorless"],
    &["vigourless"],
    &["vigourless"],
    &["vigourless"],
];

pub(crate) static ENTRY_VIGORS_2946830186019355206: VariantsMap =
    [&["vigors"], &["vigours"], &["vigours"], &["vigours"]];

pub(crate) static ENTRY_VIGOR_15557932597045951621: VariantsMap =
    [&["vigor"], &["vigour"], &["vigour"], &["vigour"]];

pub(crate) static ENTRY_VILLAGIZATIONS_9645056958423616662: VariantsMap = [
    &["villagizations"],
    &["villagisations"],
    &["villagizations"],
    &["villagisations"],
];

pub(crate) static ENTRY_VILLAGIZATION_6704300146786129340: VariantsMap = [
    &["villagization"],
    &["villagisation"],
    &["villagization"],
    &["villagisation"],
];

pub(crate) static ENTRY_VIREMIAS_11493695761490485429: VariantsMap = [
    &["viremias"],
    &["viraemias"],
    &["viraemias"],
    &["viraemias"],
];

pub(crate) static ENTRY_VIREMIA_18098587143582639437: VariantsMap =
    [&["viremia"], &["viraemia"], &["viraemia"], &["viraemia"]];

pub(crate) static ENTRY_VIREMIC_15410392453836001545: VariantsMap =
    [&["viremic"], &["viraemic"], &["viraemic"], &["viraemic"]];

pub(crate) static ENTRY_VIRILIZATIONS_18121305511677110671: VariantsMap = [
    &["virilizations"],
    &["virilisations"],
    &["virilizations"],
    &["virilisations"],
];

pub(crate) static ENTRY_VIRILIZATION_12310404704293015767: VariantsMap = [
    &["virilization"],
    &["virilisation"],
    &["virilization"],
    &["virilisation"],
];

pub(crate) static ENTRY_VIRILIZED_4676286724956217154: VariantsMap = [
    &["virilized"],
    &["virilised"],
    &["virilized"],
    &["virilised"],
];

pub(crate) static ENTRY_VIRILIZING_10763847981856232025: VariantsMap = [
    &["virilizing"],
    &["virilising"],
    &["virilizing"],
    &["virilising"],
];

pub(crate) static ENTRY_VIRTUALIZATION_12995073314893119762: VariantsMap = [
    &["virtualization"],
    &["virtualisation"],
    &["virtualisation"],
    &["virtualisation"],
];

pub(crate) static ENTRY_VIRTUALIZES_8235670628188929025: VariantsMap = [
    &["virtualizes"],
    &["virtualises"],
    &["virtualizes"],
    &["virtualises"],
];

pub(crate) static ENTRY_VIRTUALIZE_18433638723664756869: VariantsMap = [
    &["virtualize"],
    &["virtualise"],
    &["virtualize"],
    &["virtualise"],
];

pub(crate) static ENTRY_VIRTUOSI_16194921273122969553: VariantsMap =
    [&["virtuosi"], &["virtuosi"], &["virtuosi"], &["virtuosi"]];

pub(crate) static ENTRY_VISIONIZES_5651557240049522584: VariantsMap = [
    &["visionizes"],
    &["visionises"],
    &["visionizes"],
    &["visionises"],
];

pub(crate) static ENTRY_VISIONIZE_17590832811892481012: VariantsMap = [
    &["visionize"],
    &["visionise"],
    &["visionize"],
    &["visionise"],
];

pub(crate) static ENTRY_VISORS_134473816422776887: VariantsMap =
    [&["visors"], &["visors"], &["visors"], &["visors"]];

pub(crate) static ENTRY_VISOR_6793712644535862367: VariantsMap =
    [&["visor"], &["visor"], &["visor"], &["visor"]];

pub(crate) static ENTRY_VISUALIZABLE_4488080677314869313: VariantsMap = [
    &["visualizable"],
    &["visualisable"],
    &["visualizable"],
    &["visualisable"],
];

pub(crate) static ENTRY_VISUALIZATIONS_18350724909305357812: VariantsMap = [
    &["visualizations"],
    &["visualisations"],
    &["visualizations"],
    &["visualisations"],
];

pub(crate) static ENTRY_VISUALIZATION_17562130536164744176: VariantsMap = [
    &["visualization"],
    &["visualisation"],
    &["visualization"],
    &["visualisation"],
];

pub(crate) static ENTRY_VISUALIZED_4674981066915252884: VariantsMap = [
    &["visualized"],
    &["visualised"],
    &["visualized"],
    &["visualised"],
];

pub(crate) static ENTRY_VISUALIZERS_17582533695928893219: VariantsMap = [
    &["visualizers"],
    &["visualisers"],
    &["visualizers"],
    &["visualisers"],
];

pub(crate) static ENTRY_VISUALIZER_2048106900160833279: VariantsMap = [
    &["visualizer"],
    &["visualiser"],
    &["visualizer"],
    &["visualiser"],
];

pub(crate) static ENTRY_VISUALIZES_127948688781322581: VariantsMap = [
    &["visualizes"],
    &["visualises"],
    &["visualizes"],
    &["visualises"],
];

pub(crate) static ENTRY_VISUALIZE_11481052441218524608: VariantsMap = [
    &["visualize"],
    &["visualise"],
    &["visualize"],
    &["visualise"],
];

pub(crate) static ENTRY_VISUALIZING_8899358108480045240: VariantsMap = [
    &["visualizing"],
    &["visualising"],
    &["visualizing"],
    &["visualising"],
];

pub(crate) static ENTRY_VITALIZATIONS_10201411925742357344: VariantsMap = [
    &["vitalizations"],
    &["vitalisations"],
    &["vitalizations"],
    &["vitalisations"],
];

pub(crate) static ENTRY_VITALIZATION_6622991581175063916: VariantsMap = [
    &["vitalization"],
    &["vitalisation"],
    &["vitalization"],
    &["vitalisation"],
];

pub(crate) static ENTRY_VITALIZED_4801592680431520472: VariantsMap = [
    &["vitalized"],
    &["vitalised"],
    &["vitalized"],
    &["vitalised"],
];

pub(crate) static ENTRY_VITALIZERS_16513879370855291377: VariantsMap = [
    &["vitalizers"],
    &["vitalisers"],
    &["vitalizers"],
    &["vitalisers"],
];

pub(crate) static ENTRY_VITALIZER_6854541332740985774: VariantsMap = [
    &["vitalizer"],
    &["vitaliser"],
    &["vitalizer"],
    &["vitaliser"],
];

pub(crate) static ENTRY_VITALIZES_3154160873090627908: VariantsMap = [
    &["vitalizes"],
    &["vitalises"],
    &["vitalizes"],
    &["vitalises"],
];

pub(crate) static ENTRY_VITALIZE_6481155641390081467: VariantsMap =
    [&["vitalize"], &["vitalise"], &["vitalize"], &["vitalise"]];

pub(crate) static ENTRY_VITALIZINGLY_3721526376897688302: VariantsMap = [
    &["vitalizingly"],
    &["vitalisingly"],
    &["vitalizingly"],
    &["vitalisingly"],
];

pub(crate) static ENTRY_VITALIZINGS_3549538285617044596: VariantsMap = [
    &["vitalizings"],
    &["vitalisings"],
    &["vitalizings"],
    &["vitalisings"],
];

pub(crate) static ENTRY_VITALIZING_5684293940323598911: VariantsMap = [
    &["vitalizing"],
    &["vitalising"],
    &["vitalizing"],
    &["vitalising"],
];

pub(crate) static ENTRY_VITAMINIZATION_8611340282933462961: VariantsMap = [
    &["vitaminization"],
    &["vitaminisation"],
    &["vitaminization"],
    &["vitaminisation"],
];

pub(crate) static ENTRY_VITAMINIZED_4419964457316336553: VariantsMap = [
    &["vitaminized"],
    &["vitaminised"],
    &["vitaminized"],
    &["vitaminised"],
];

pub(crate) static ENTRY_VITAMINIZES_5130824241734522496: VariantsMap = [
    &["vitaminizes"],
    &["vitaminises"],
    &["vitaminizes"],
    &["vitaminises"],
];

pub(crate) static ENTRY_VITAMINIZE_9229796811292738647: VariantsMap = [
    &["vitaminize"],
    &["vitaminise"],
    &["vitaminize"],
    &["vitaminise"],
];

pub(crate) static ENTRY_VITAMINIZING_9349914309549143713: VariantsMap = [
    &["vitaminizing"],
    &["vitaminising"],
    &["vitaminizing"],
    &["vitaminising"],
];

pub(crate) static ENTRY_VITRIOLIZABLES_2644365146835371145: VariantsMap = [
    &["vitriolizables"],
    &["vitriolisables"],
    &["vitriolizables"],
    &["vitriolisables"],
];

pub(crate) static ENTRY_VITRIOLIZABLE_17310862678824970477: VariantsMap = [
    &["vitriolizable"],
    &["vitriolisable"],
    &["vitriolizable"],
    &["vitriolisable"],
];

pub(crate) static ENTRY_VITRIOLIZATIONS_10025992055840934495: VariantsMap = [
    &["vitriolizations"],
    &["vitriolisations"],
    &["vitriolizations"],
    &["vitriolisations"],
];

pub(crate) static ENTRY_VITRIOLIZATION_4706708016116909857: VariantsMap = [
    &["vitriolization"],
    &["vitriolisation"],
    &["vitriolization"],
    &["vitriolisation"],
];

pub(crate) static ENTRY_VITRIOLIZED_1910528837394386896: VariantsMap = [
    &["vitriolized"],
    &["vitriolised"],
    &["vitriolized"],
    &["vitriolised"],
];

pub(crate) static ENTRY_VITRIOLIZERS_11660516492851129479: VariantsMap = [
    &["vitriolizers"],
    &["vitriolisers"],
    &["vitriolizers"],
    &["vitriolisers"],
];

pub(crate) static ENTRY_VITRIOLIZER_3565340187130070331: VariantsMap = [
    &["vitriolizer"],
    &["vitrioliser"],
    &["vitriolizer"],
    &["vitrioliser"],
];

pub(crate) static ENTRY_VITRIOLIZES_6916423318398411349: VariantsMap = [
    &["vitriolizes"],
    &["vitriolises"],
    &["vitriolizes"],
    &["vitriolises"],
];

pub(crate) static ENTRY_VITRIOLIZE_2463142402858277228: VariantsMap = [
    &["vitriolize"],
    &["vitriolise"],
    &["vitriolize"],
    &["vitriolise"],
];

pub(crate) static ENTRY_VITRIOLIZING_3937845223854221826: VariantsMap = [
    &["vitriolizing"],
    &["vitriolising"],
    &["vitriolizing"],
    &["vitriolising"],
];

pub(crate) static ENTRY_VIVANDIER_12796368736143739188: VariantsMap = [
    &["vivandier"],
    &["vivandire"],
    &["vivandire"],
    &["vivandire"],
];

pub(crate) static ENTRY_VIVERRINE_13661408646720182258: VariantsMap = [
    &["viverrine"],
    &["viverrinae"],
    &["viverrinae"],
    &["viverrinae"],
];

pub(crate) static ENTRY_VIVERS_10514623990192410896: VariantsMap =
    [&["vivers"], &["vivres"], &["vivres"], &["vivres"]];

pub(crate) static ENTRY_VIVER_8964657704628755516: VariantsMap =
    [&["viver"], &["vivre"], &["vivre"], &["vivre"]];

pub(crate) static ENTRY_VIZARDS_9340526966771883402: VariantsMap =
    [&["vizards"], &["visards"], &["vizards"], &["visards"]];

pub(crate) static ENTRY_VIZARD_2639323971974804824: VariantsMap =
    [&["vizard"], &["visard"], &["vizard"], &["visard"]];

pub(crate) static ENTRY_VIZIED_795958706997274905: VariantsMap =
    [&["vizied"], &["visied"], &["vizied"], &["visied"]];

pub(crate) static ENTRY_VIZIES_8365615820765009417: VariantsMap =
    [&["vizies"], &["visies"], &["vizies"], &["visies"]];

pub(crate) static ENTRY_VOCALIZATIONS_17133298955574595735: VariantsMap = [
    &["vocalizations"],
    &["vocalisations"],
    &["vocalizations"],
    &["vocalisations"],
];

pub(crate) static ENTRY_VOCALIZATION_3101814292430397767: VariantsMap = [
    &["vocalization"],
    &["vocalisation"],
    &["vocalization"],
    &["vocalisation"],
];

pub(crate) static ENTRY_VOCALIZED_10488165785915354680: VariantsMap = [
    &["vocalized"],
    &["vocalised"],
    &["vocalized"],
    &["vocalised"],
];

pub(crate) static ENTRY_VOCALIZERS_16676498064430857034: VariantsMap = [
    &["vocalizers"],
    &["vocalisers"],
    &["vocalizers"],
    &["vocalisers"],
];

pub(crate) static ENTRY_VOCALIZER_16276723661570906787: VariantsMap = [
    &["vocalizer"],
    &["vocaliser"],
    &["vocalizer"],
    &["vocaliser"],
];

pub(crate) static ENTRY_VOCALIZES_9022405961253042006: VariantsMap = [
    &["vocalizes"],
    &["vocalises"],
    &["vocalizes"],
    &["vocalises"],
];

pub(crate) static ENTRY_VOCALIZE_4185858433777108713: VariantsMap =
    [&["vocalize"], &["vocalise"], &["vocalize"], &["vocalise"]];

pub(crate) static ENTRY_VOCALIZING_6360195233059633529: VariantsMap = [
    &["vocalizing"],
    &["vocalising"],
    &["vocalizing"],
    &["vocalising"],
];

pub(crate) static ENTRY_VOCATIONALIZATIONS_645102237578435655: VariantsMap = [
    &["vocationalizations"],
    &["vocationalisations"],
    &["vocationalizations"],
    &["vocationalisations"],
];

pub(crate) static ENTRY_VOCATIONALIZATION_16884053563133857076: VariantsMap = [
    &["vocationalization"],
    &["vocationalisation"],
    &["vocationalization"],
    &["vocationalisation"],
];

pub(crate) static ENTRY_VOCATIONALIZES_4008731000111938679: VariantsMap = [
    &["vocationalizes"],
    &["vocationalises"],
    &["vocationalizes"],
    &["vocationalises"],
];

pub(crate) static ENTRY_VOCATIONALIZE_484999010571215919: VariantsMap = [
    &["vocationalize"],
    &["vocationalise"],
    &["vocationalize"],
    &["vocationalise"],
];

pub(crate) static ENTRY_VOLATILIZABLER_15124316039469427064: VariantsMap = [
    &["volatilizabler"],
    &["volatilisabler"],
    &["volatilizabler"],
    &["volatilisabler"],
];

pub(crate) static ENTRY_VOLATILIZABLEST_1211109177921536207: VariantsMap = [
    &["volatilizablest"],
    &["volatilisablest"],
    &["volatilizablest"],
    &["volatilisablest"],
];

pub(crate) static ENTRY_VOLATILIZABLES_10994615031924961365: VariantsMap = [
    &["volatilizables"],
    &["volatilisables"],
    &["volatilizables"],
    &["volatilisables"],
];

pub(crate) static ENTRY_VOLATILIZABLE_10168029689535730959: VariantsMap = [
    &["volatilizable"],
    &["volatilisable"],
    &["volatilizable"],
    &["volatilisable"],
];

pub(crate) static ENTRY_VOLATILIZATIONS_8168537470161802057: VariantsMap = [
    &["volatilizations"],
    &["volatilisations"],
    &["volatilizations"],
    &["volatilisations"],
];

pub(crate) static ENTRY_VOLATILIZATION_3221641183281199106: VariantsMap = [
    &["volatilization"],
    &["volatilisation"],
    &["volatilization"],
    &["volatilisation"],
];

pub(crate) static ENTRY_VOLATILIZED_13699473491173599192: VariantsMap = [
    &["volatilized"],
    &["volatilised"],
    &["volatilized"],
    &["volatilised"],
];

pub(crate) static ENTRY_VOLATILIZERS_13014590752496196530: VariantsMap = [
    &["volatilizers"],
    &["volatilisers"],
    &["volatilizers"],
    &["volatilisers"],
];

pub(crate) static ENTRY_VOLATILIZER_967038296345618448: VariantsMap = [
    &["volatilizer"],
    &["volatiliser"],
    &["volatilizer"],
    &["volatiliser"],
];

pub(crate) static ENTRY_VOLATILIZES_14953405067501371419: VariantsMap = [
    &["volatilizes"],
    &["volatilises"],
    &["volatilizes"],
    &["volatilises"],
];

pub(crate) static ENTRY_VOLATILIZE_16270565871743863998: VariantsMap = [
    &["volatilize"],
    &["volatilise"],
    &["volatilize"],
    &["volatilise"],
];

pub(crate) static ENTRY_VOLATILIZING_9187797455588347418: VariantsMap = [
    &["volatilizing"],
    &["volatilising"],
    &["volatilizing"],
    &["volatilising"],
];

pub(crate) static ENTRY_VOLCANIZATIONS_11356670470517236039: VariantsMap = [
    &["volcanizations"],
    &["volcanisations"],
    &["volcanizations"],
    &["volcanisations"],
];

pub(crate) static ENTRY_VOLCANIZATION_8985433655421469811: VariantsMap = [
    &["volcanization"],
    &["volcanisation"],
    &["volcanization"],
    &["volcanisation"],
];

pub(crate) static ENTRY_VOLCANIZED_7831688113853222131: VariantsMap = [
    &["volcanized"],
    &["volcanised"],
    &["volcanized"],
    &["volcanised"],
];

pub(crate) static ENTRY_VOLCANIZES_14691477153026326923: VariantsMap = [
    &["volcanizes"],
    &["volcanises"],
    &["volcanizes"],
    &["volcanises"],
];

pub(crate) static ENTRY_VOLCANIZE_15707442069580141816: VariantsMap = [
    &["volcanize"],
    &["volcanise"],
    &["volcanize"],
    &["volcanise"],
];

pub(crate) static ENTRY_VOLCANIZING_16325307602678280336: VariantsMap = [
    &["volcanizing"],
    &["volcanising"],
    &["volcanizing"],
    &["volcanising"],
];

pub(crate) static ENTRY_VOLTIZES_13001217679494650700: VariantsMap =
    [&["voltizes"], &["voltises"], &["voltizes"], &["voltises"]];

pub(crate) static ENTRY_VOLTIZE_3168582630243886919: VariantsMap =
    [&["voltize"], &["voltise"], &["voltize"], &["voltise"]];

pub(crate) static ENTRY_VOWELIZATIONS_9949470389871637399: VariantsMap = [
    &["vowelizations"],
    &["vowelisations"],
    &["vowelizations"],
    &["vowelisations"],
];

pub(crate) static ENTRY_VOWELIZATION_8028405167364651675: VariantsMap = [
    &["vowelization"],
    &["vowelisation"],
    &["vowelization"],
    &["vowelisation"],
];

pub(crate) static ENTRY_VOWELIZED_13363070483633135702: VariantsMap = [
    &["vowelized"],
    &["vowelised"],
    &["vowelized"],
    &["vowelised"],
];

pub(crate) static ENTRY_VOWELIZES_15733936200840210114: VariantsMap = [
    &["vowelizes"],
    &["vowelises"],
    &["vowelizes"],
    &["vowelises"],
];

pub(crate) static ENTRY_VOWELIZE_11831882778950051901: VariantsMap =
    [&["vowelize"], &["vowelise"], &["vowelize"], &["vowelise"]];

pub(crate) static ENTRY_VOWELIZING_15780479645088969618: VariantsMap = [
    &["vowelizing"],
    &["vowelising"],
    &["vowelizing"],
    &["vowelising"],
];

pub(crate) static ENTRY_VULCANIZABLER_5626985747083053444: VariantsMap = [
    &["vulcanizabler"],
    &["vulcanisabler"],
    &["vulcanizabler"],
    &["vulcanisabler"],
];

pub(crate) static ENTRY_VULCANIZABLEST_7532718328423894637: VariantsMap = [
    &["vulcanizablest"],
    &["vulcanisablest"],
    &["vulcanizablest"],
    &["vulcanisablest"],
];

pub(crate) static ENTRY_VULCANIZABLES_1003331057376447528: VariantsMap = [
    &["vulcanizables"],
    &["vulcanisables"],
    &["vulcanizables"],
    &["vulcanisables"],
];

pub(crate) static ENTRY_VULCANIZABLE_12933258001910720543: VariantsMap = [
    &["vulcanizable"],
    &["vulcanisable"],
    &["vulcanizable"],
    &["vulcanisable"],
];

pub(crate) static ENTRY_VULCANIZATES_4114082830948149633: VariantsMap = [
    &["vulcanizates"],
    &["vulcanisates"],
    &["vulcanizates"],
    &["vulcanisates"],
];

pub(crate) static ENTRY_VULCANIZATE_11388221665594117242: VariantsMap = [
    &["vulcanizate"],
    &["vulcanisate"],
    &["vulcanizate"],
    &["vulcanisate"],
];

pub(crate) static ENTRY_VULCANIZATIONS_15847832065617865889: VariantsMap = [
    &["vulcanizations"],
    &["vulcanisations"],
    &["vulcanizations"],
    &["vulcanisations"],
];

pub(crate) static ENTRY_VULCANIZATION_7905884940104482341: VariantsMap = [
    &["vulcanization"],
    &["vulcanisation"],
    &["vulcanization"],
    &["vulcanisation"],
];

pub(crate) static ENTRY_VULCANIZED_14313743718177692805: VariantsMap = [
    &["vulcanized"],
    &["vulcanised"],
    &["vulcanized"],
    &["vulcanised"],
];

pub(crate) static ENTRY_VULCANIZERS_17322632051634463265: VariantsMap = [
    &["vulcanizers"],
    &["vulcanisers"],
    &["vulcanizers"],
    &["vulcanisers"],
];

pub(crate) static ENTRY_VULCANIZER_9826867449740889574: VariantsMap = [
    &["vulcanizer"],
    &["vulcaniser"],
    &["vulcanizer"],
    &["vulcaniser"],
];

pub(crate) static ENTRY_VULCANIZES_16377609962408860153: VariantsMap = [
    &["vulcanizes"],
    &["vulcanises"],
    &["vulcanizes"],
    &["vulcanises"],
];

pub(crate) static ENTRY_VULCANIZE_6585960079549072743: VariantsMap = [
    &["vulcanize"],
    &["vulcanise"],
    &["vulcanize"],
    &["vulcanise"],
];

pub(crate) static ENTRY_VULCANIZING_13984517742257009109: VariantsMap = [
    &["vulcanizing"],
    &["vulcanising"],
    &["vulcanizing"],
    &["vulcanising"],
];

pub(crate) static ENTRY_VULGARIZATIONS_8843218827275212658: VariantsMap = [
    &["vulgarizations"],
    &["vulgarisations"],
    &["vulgarizations"],
    &["vulgarisations"],
];

pub(crate) static ENTRY_VULGARIZATION_15527570270767072109: VariantsMap = [
    &["vulgarization"],
    &["vulgarisation"],
    &["vulgarization"],
    &["vulgarisation"],
];

pub(crate) static ENTRY_VULGARIZED_8073979986420271297: VariantsMap = [
    &["vulgarized"],
    &["vulgarised"],
    &["vulgarized"],
    &["vulgarised"],
];

pub(crate) static ENTRY_VULGARIZERS_15985805307582944778: VariantsMap = [
    &["vulgarizers"],
    &["vulgarisers"],
    &["vulgarizers"],
    &["vulgarisers"],
];

pub(crate) static ENTRY_VULGARIZER_9773650239919878284: VariantsMap = [
    &["vulgarizer"],
    &["vulgariser"],
    &["vulgarizer"],
    &["vulgariser"],
];

pub(crate) static ENTRY_VULGARIZES_645579138050710392: VariantsMap = [
    &["vulgarizes"],
    &["vulgarises"],
    &["vulgarizes"],
    &["vulgarises"],
];

pub(crate) static ENTRY_VULGARIZE_6707031466678228051: VariantsMap = [
    &["vulgarize"],
    &["vulgarise"],
    &["vulgarize"],
    &["vulgarise"],
];

pub(crate) static ENTRY_VULGARIZING_6396108281264937628: VariantsMap = [
    &["vulgarizing"],
    &["vulgarising"],
    &["vulgarizing"],
    &["vulgarising"],
];

pub(crate) static ENTRY_WACKES_510047826766852133: VariantsMap =
    [&["wackes"], &["wackoes"], &["wackoes"], &["wackoes"]];

pub(crate) static ENTRY_WAGNERIZES_16225753643669617315: VariantsMap = [
    &["wagnerizes"],
    &["wagnerises"],
    &["wagnerizes"],
    &["wagnerises"],
];

pub(crate) static ENTRY_WAGNERIZE_5769761765957663761: VariantsMap = [
    &["wagnerize"],
    &["wagnerise"],
    &["wagnerize"],
    &["wagnerise"],
];

pub(crate) static ENTRY_WAGONED_18404896035191047132: VariantsMap =
    [&["wagoned"], &["wagoned"], &["wagoned"], &["wagoned"]];

pub(crate) static ENTRY_WAGONEER_7695357654896841244: VariantsMap =
    [&["wagoneer"], &["wagoneer"], &["wagoneer"], &["wagoneer"]];

pub(crate) static ENTRY_WAGONERS_6388316509001104344: VariantsMap =
    [&["wagoners"], &["wagoners"], &["wagoners"], &["wagoners"]];

pub(crate) static ENTRY_WAGONER_11432045632874199662: VariantsMap =
    [&["wagoner"], &["wagoner"], &["wagoner"], &["wagoner"]];

pub(crate) static ENTRY_WAGONETTES_2415032088297891551: VariantsMap = [
    &["wagonettes"],
    &["wagonettes"],
    &["wagonettes"],
    &["wagonettes"],
];

pub(crate) static ENTRY_WAGONETTE_3903149371449355531: VariantsMap = [
    &["wagonette"],
    &["wagonette"],
    &["wagonette"],
    &["wagonette"],
];

pub(crate) static ENTRY_WAGONING_2887560265469426881: VariantsMap =
    [&["wagoning"], &["wagoning"], &["wagoning"], &["wagoning"]];

pub(crate) static ENTRY_WAGONS_11395031855637672578: VariantsMap =
    [&["wagons"], &["wagons"], &["wagons"], &["wagons"]];

pub(crate) static ENTRY_WAGON_5335298714004042393: VariantsMap =
    [&["wagon"], &["wagon"], &["wagon"], &["wagon"]];

pub(crate) static ENTRY_WANTONIZED_10968755963901267296: VariantsMap = [
    &["wantonized"],
    &["wantonised"],
    &["wantonized"],
    &["wantonised"],
];

pub(crate) static ENTRY_WANTONIZES_2129137010298333861: VariantsMap = [
    &["wantonizes"],
    &["wantonises"],
    &["wantonizes"],
    &["wantonises"],
];

pub(crate) static ENTRY_WANTONIZE_4641875869566290004: VariantsMap = [
    &["wantonize"],
    &["wantonise"],
    &["wantonize"],
    &["wantonise"],
];

pub(crate) static ENTRY_WANTONIZING_3889295691274401356: VariantsMap = [
    &["wantonizing"],
    &["wantonising"],
    &["wantonizing"],
    &["wantonising"],
];

pub(crate) static ENTRY_WARER_11382540724162869048: VariantsMap =
    [&["warer"], &["warre"], &["warre"], &["warre"]];

pub(crate) static ENTRY_WARFORD_16540495906064731465: VariantsMap =
    [&["warford"], &["warfourd"], &["warfourd"], &["warfourd"]];

pub(crate) static ENTRY_WARRANTIZE_4993893254884557601: VariantsMap = [
    &["warrantize"],
    &["warrantise"],
    &["warrantize"],
    &["warrantise"],
];

pub(crate) static ENTRY_WATERCOLORED_551761815331700825: VariantsMap = [
    &["watercolored"],
    &["watercoloured"],
    &["watercoloured"],
    &["watercoloured"],
];

pub(crate) static ENTRY_WATERCOLORING_7585263825752051770: VariantsMap = [
    &["watercoloring"],
    &["watercolouring"],
    &["watercolouring"],
    &["watercolouring"],
];

pub(crate) static ENTRY_WATERCOLORISTS_16203366413065930985: VariantsMap = [
    &["watercolorists"],
    &["watercolourists"],
    &["watercolourists"],
    &["watercolourists"],
];

pub(crate) static ENTRY_WATERCOLORIST_15171920726508503979: VariantsMap = [
    &["watercolorist"],
    &["watercolourist"],
    &["watercolourist"],
    &["watercolourist"],
];

pub(crate) static ENTRY_WATERCOLORS_9935320064817263087: VariantsMap = [
    &["watercolors"],
    &["watercolours"],
    &["watercolours"],
    &["watercolours"],
];

pub(crate) static ENTRY_WATERCOLOR_1242471837856686461: VariantsMap = [
    &["watercolor"],
    &["watercolour"],
    &["watercolour"],
    &["watercolour"],
];

pub(crate) static ENTRY_WEASELED_7269396054259240547: VariantsMap =
    [&["weaseled"], &["weaselled"], &["weaseled"], &["weaselled"]];

pub(crate) static ENTRY_WEASELING_2632216130329270938: VariantsMap = [
    &["weaseling"],
    &["weaselling"],
    &["weaseling"],
    &["weaselling"],
];

pub(crate) static ENTRY_WEATHERIZED_18030948967314137256: VariantsMap = [
    &["weatherized"],
    &["weatherised"],
    &["weatherized"],
    &["weatherised"],
];

pub(crate) static ENTRY_WEATHERIZES_761792162885352580: VariantsMap = [
    &["weatherizes"],
    &["weatherises"],
    &["weatherizes"],
    &["weatherises"],
];

pub(crate) static ENTRY_WEATHERIZE_4961563587908804252: VariantsMap = [
    &["weatherize"],
    &["weatherise"],
    &["weatherize"],
    &["weatherise"],
];

pub(crate) static ENTRY_WEATHERIZING_10998488814413655578: VariantsMap = [
    &["weatherizing"],
    &["weatherising"],
    &["weatherizing"],
    &["weatherising"],
];

pub(crate) static ENTRY_WEEVILED_5671527057159191731: VariantsMap = [
    &["weeviled"],
    &["weevilled"],
    &["weevilled"],
    &["weevilled"],
];

pub(crate) static ENTRY_WEFTWIZE_18228736157171688040: VariantsMap =
    [&["weftwize"], &["weftwise"], &["weftwize"], &["weftwise"]];

pub(crate) static ENTRY_WEIZED_11856800976027190563: VariantsMap =
    [&["weized"], &["weised"], &["weized"], &["weised"]];

pub(crate) static ENTRY_WEIZES_7549448166735182951: VariantsMap =
    [&["weizes"], &["weises"], &["weizes"], &["weises"]];

pub(crate) static ENTRY_WEIZE_4692929171720256071: VariantsMap =
    [&["weize"], &["weise"], &["weize"], &["weise"]];

pub(crate) static ENTRY_WEIZING_13035760845280706799: VariantsMap =
    [&["weizing"], &["weising"], &["weizing"], &["weising"]];

pub(crate) static ENTRY_WER_11639588756994874397: VariantsMap =
    [&["wer"], &["waer"], &["waer"], &["waer"]];

pub(crate) static ENTRY_WESTERNIZATIONS_17887310843739967172: VariantsMap = [
    &["westernizations"],
    &["westernisations"],
    &["westernizations"],
    &["westernisations"],
];

pub(crate) static ENTRY_WESTERNIZATION_10693435618580655065: VariantsMap = [
    &["westernization"],
    &["westernisation"],
    &["westernization"],
    &["westernisation"],
];

pub(crate) static ENTRY_WESTERNIZED_17634020200167691104: VariantsMap = [
    &["westernized"],
    &["westernised"],
    &["westernized"],
    &["westernised"],
];

pub(crate) static ENTRY_WESTERNIZES_4968126506243709279: VariantsMap = [
    &["westernizes"],
    &["westernises"],
    &["westernizes"],
    &["westernises"],
];

pub(crate) static ENTRY_WESTERNIZE_11346667543067253389: VariantsMap = [
    &["westernize"],
    &["westernise"],
    &["westernize"],
    &["westernise"],
];

pub(crate) static ENTRY_WESTERNIZING_14820707154271141813: VariantsMap = [
    &["westernizing"],
    &["westernising"],
    &["westernizing"],
    &["westernising"],
];

pub(crate) static ENTRY_WHISKEYS_7436468433370877238: VariantsMap =
    [&["whiskeys"], &["whiskies"], &["whiskies"], &["whiskies"]];

pub(crate) static ENTRY_WHITMANIZES_14406113232286981648: VariantsMap = [
    &["whitmanizes"],
    &["whitmanises"],
    &["whitmanizes"],
    &["whitmanises"],
];

pub(crate) static ENTRY_WHITMANIZE_12604676802077785810: VariantsMap = [
    &["whitmanize"],
    &["whitmanise"],
    &["whitmanize"],
    &["whitmanise"],
];

pub(crate) static ENTRY_WILLFULER_5381487143875928951: VariantsMap =
    [&["willfuler"], &["wilfuler"], &["wilfuler"], &["wilfuler"]];

pub(crate) static ENTRY_WILLFULEST_14812841215434133378: VariantsMap = [
    &["willfulest"],
    &["wilfulest"],
    &["wilfulest"],
    &["wilfulest"],
];

pub(crate) static ENTRY_WILLFULLIER_15285733710201810363: VariantsMap = [
    &["willfullier"],
    &["wilfullier"],
    &["wilfullier"],
    &["wilfullier"],
];

pub(crate) static ENTRY_WILLFULLIEST_1229078038469558436: VariantsMap = [
    &["willfulliest"],
    &["wilfulliest"],
    &["wilfulliest"],
    &["wilfulliest"],
];

pub(crate) static ENTRY_WILLFULLY_11177950727637010120: VariantsMap =
    [&["willfully"], &["wilfully"], &["wilfully"], &["wilfully"]];

pub(crate) static ENTRY_WILLFULNESS_10353200066895422050: VariantsMap = [
    &["willfulness"],
    &["wilfulness"],
    &["wilfulness"],
    &["wilfulness"],
];

pub(crate) static ENTRY_WILLFUL_888733828666730475: VariantsMap =
    [&["willful"], &["wilful"], &["wilful"], &["wilful"]];

pub(crate) static ENTRY_WINTERIZATIONS_10939012107648324861: VariantsMap = [
    &["winterizations"],
    &["winterisations"],
    &["winterizations"],
    &["winterisations"],
];

pub(crate) static ENTRY_WINTERIZATION_347749948628387205: VariantsMap = [
    &["winterization"],
    &["winterisation"],
    &["winterization"],
    &["winterisation"],
];

pub(crate) static ENTRY_WINTERIZED_13138859505846530038: VariantsMap = [
    &["winterized"],
    &["winterised"],
    &["winterized"],
    &["winterised"],
];

pub(crate) static ENTRY_WINTERIZES_6133753376693721696: VariantsMap = [
    &["winterizes"],
    &["winterises"],
    &["winterizes"],
    &["winterises"],
];

pub(crate) static ENTRY_WINTERIZE_2183252607445844863: VariantsMap = [
    &["winterize"],
    &["winterise"],
    &["winterize"],
    &["winterise"],
];

pub(crate) static ENTRY_WINTERIZING_3911142690065298063: VariantsMap = [
    &["winterizing"],
    &["winterising"],
    &["winterizing"],
    &["winterising"],
];

pub(crate) static ENTRY_WIZEN_4334319069968315511: VariantsMap =
    [&["wizen"], &["wisen"], &["wizen"], &["wisen"]];

pub(crate) static ENTRY_WOMANIZATIONS_6214286373586139061: VariantsMap = [
    &["womanizations"],
    &["womanisations"],
    &["womanizations"],
    &["womanisations"],
];

pub(crate) static ENTRY_WOMANIZATION_2912095657356208823: VariantsMap = [
    &["womanization"],
    &["womanisation"],
    &["womanization"],
    &["womanisation"],
];

pub(crate) static ENTRY_WOMANIZED_6823201211994765463: VariantsMap = [
    &["womanized"],
    &["womanised"],
    &["womanized"],
    &["womanised"],
];

pub(crate) static ENTRY_WOMANIZERS_2730363125830539583: VariantsMap = [
    &["womanizers"],
    &["womanisers"],
    &["womanizers"],
    &["womanisers"],
];

pub(crate) static ENTRY_WOMANIZER_12959923156017407936: VariantsMap = [
    &["womanizer"],
    &["womaniser"],
    &["womanizer"],
    &["womaniser"],
];

pub(crate) static ENTRY_WOMANIZES_1396386385917615542: VariantsMap = [
    &["womanizes"],
    &["womanises"],
    &["womanizes"],
    &["womanises"],
];

pub(crate) static ENTRY_WOMANIZE_13944014032617070061: VariantsMap =
    [&["womanize"], &["womanise"], &["womanize"], &["womanise"]];

pub(crate) static ENTRY_WOMANIZING_14010372556431313508: VariantsMap = [
    &["womanizing"],
    &["womanising"],
    &["womanizing"],
    &["womanising"],
];

pub(crate) static ENTRY_WOODCOCKIZES_14952192357364422589: VariantsMap = [
    &["woodcockizes"],
    &["woodcockises"],
    &["woodcockizes"],
    &["woodcockises"],
];

pub(crate) static ENTRY_WOODCOCKIZE_5663866505253252015: VariantsMap = [
    &["woodcockize"],
    &["woodcockise"],
    &["woodcockize"],
    &["woodcockise"],
];

pub(crate) static ENTRY_WOOLENIZATIONS_9008183640003333341: VariantsMap = [
    &["woolenizations"],
    &["woollenisations"],
    &["woollenizations"],
    &["woollenisations"],
];

pub(crate) static ENTRY_WOOLENIZATION_8391870250405491314: VariantsMap = [
    &["woolenization"],
    &["woollenisation"],
    &["woollenization"],
    &["woollenisation"],
];

pub(crate) static ENTRY_WOOLENIZES_13915140718286830624: VariantsMap = [
    &["woolenizes"],
    &["woollenises"],
    &["woollenizes"],
    &["woollenises"],
];

pub(crate) static ENTRY_WOOLENIZE_5989697679481924564: VariantsMap = [
    &["woolenize"],
    &["woollenise"],
    &["woollenize"],
    &["woollenise"],
];

pub(crate) static ENTRY_WOOLENNER_16121158420209065321: VariantsMap = [
    &["woolenner"],
    &["woollenner"],
    &["woollenner"],
    &["woollenner"],
];

pub(crate) static ENTRY_WOOLENNEST_9962428894247675717: VariantsMap = [
    &["woolennest"],
    &["woollennest"],
    &["woollennest"],
    &["woollennest"],
];

pub(crate) static ENTRY_WOOLENS_6397410426801008847: VariantsMap =
    [&["woolens"], &["woollens"], &["woollens"], &["woollens"]];

pub(crate) static ENTRY_WOOLEN_16877039187309954068: VariantsMap =
    [&["woolen"], &["woollen"], &["woollen"], &["woollen"]];

pub(crate) static ENTRY_WORNIL_15281974950870959304: VariantsMap =
    [&["wornil"], &["wournil"], &["wournil"], &["wournil"]];

pub(crate) static ENTRY_WORSHIPED_13801735218945656036: VariantsMap = [
    &["worshiped"],
    &["worshipped"],
    &["worshipped"],
    &["worshipped"],
];

pub(crate) static ENTRY_WORSHIPERS_2792179872387820015: VariantsMap = [
    &["worshipers"],
    &["worshippers"],
    &["worshippers"],
    &["worshippers"],
];

pub(crate) static ENTRY_WORSHIPER_9520180601499296676: VariantsMap = [
    &["worshiper"],
    &["worshipper"],
    &["worshipper"],
    &["worshipper"],
];

pub(crate) static ENTRY_WORSHIPING_9531564570456686375: VariantsMap = [
    &["worshiping"],
    &["worshipping"],
    &["worshipping"],
    &["worshipping"],
];

pub(crate) static ENTRY_YODELED_15671817307109302642: VariantsMap =
    [&["yodeled"], &["yodelled"], &["yodelled"], &["yodelled"]];

pub(crate) static ENTRY_YODELERS_18010970770053754843: VariantsMap = [
    &["yodelers"],
    &["yodellers"],
    &["yodellers"],
    &["yodellers"],
];

pub(crate) static ENTRY_YODELER_7988137706216703211: VariantsMap =
    [&["yodeler"], &["yodeller"], &["yodeller"], &["yodeller"]];

pub(crate) static ENTRY_YODELING_5584968248317185710: VariantsMap = [
    &["yodeling"],
    &["yodelling"],
    &["yodelling"],
    &["yodelling"],
];

pub(crate) static ENTRY_YOGURTS_12979282136707959016: VariantsMap =
    [&["yogurts"], &["yogurts"], &["yogourts"], &["yoghurts"]];

pub(crate) static ENTRY_YOGURT_4836021873407169494: VariantsMap =
    [&["yogurt"], &["yogurt"], &["yogourt"], &["yoghurt"]];

pub(crate) static ENTRY_ZAFFERS_18135861342380490241: VariantsMap =
    [&["zaffers"], &["zaffres"], &["zaffres"], &["zaffres"]];

pub(crate) static ENTRY_ZAFFER_1782028266821462296: VariantsMap =
    [&["zaffer"], &["zaffre"], &["zaffre"], &["zaffre"]];

pub(crate) static ENTRY_ZEAS_5878550334347614910: VariantsMap =
    [&["zeas"], &["zoeas"], &["zoeas"], &["zoeas"]];

pub(crate) static ENTRY_ZEA_18144512594597847862: VariantsMap =
    [&["zea"], &["zoea"], &["zoea"], &["zoea"]];

pub(crate) static ENTRY_ZEROIZED_14083500582707636275: VariantsMap =
    [&["zeroized"], &["zeroised"], &["zeroized"], &["zeroised"]];

pub(crate) static ENTRY_ZEROIZES_18412755642364966459: VariantsMap =
    [&["zeroizes"], &["zeroises"], &["zeroizes"], &["zeroises"]];

pub(crate) static ENTRY_ZEROIZE_12861688847880490798: VariantsMap =
    [&["zeroize"], &["zeroise"], &["zeroize"], &["zeroise"]];

pub(crate) static ENTRY_ZEROIZING_11012654682606419940: VariantsMap = [
    &["zeroizing"],
    &["zeroising"],
    &["zeroizing"],
    &["zeroising"],
];

pub(crate) static ENTRY_ZOEAE_6587921986871953627: VariantsMap =
    [&["zoeae"], &["zooeae"], &["zooeae"], &["zooeae"]];

pub(crate) static ENTRY_ZOEAL_10183908722620440824: VariantsMap =
    [&["zoeal"], &["zooeal"], &["zooeal"], &["zooeal"]];

pub(crate) static ENTRY_ZOEAS_681757442323763522: VariantsMap =
    [&["zoeas"], &["zooeas"], &["zooeas"], &["zooeas"]];

pub(crate) static ENTRY_ZOEA_5407976721583269765: VariantsMap =
    [&["zoea"], &["zoaea"], &["zoaea"], &["zoaea"]];

pub(crate) static ENTRY_ZOEA_7677728383051875918: VariantsMap =
    [&["zoea"], &["zooea"], &["zooea"], &["zooea"]];

pub(crate) static ENTRY_ZOECIA_3187153722664521655: VariantsMap =
    [&["zoecia"], &["zooecia"], &["zooecia"], &["zooecia"]];

pub(crate) static ENTRY_ZOECIUM_6905291993571367110: VariantsMap =
    [&["zoecium"], &["zooecium"], &["zooecium"], &["zooecium"]];

pub(crate) static ENTRY_ZONESTHESIA_5241288651423447523: VariantsMap = [
    &["zonesthesia"],
    &["zonaesthesia"],
    &["zonaesthesia"],
    &["zonaesthesia"],
];

pub(crate) static ENTRY_ZONULE_9256134977663685758: VariantsMap =
    [&["zonule"], &["zonulae"], &["zonulae"], &["zonulae"]];

pub(crate) static ENTRY_ZOOGLEAE_1475063023468604603: VariantsMap = [
    &["zoogleae"],
    &["zoogloeae"],
    &["zoogloeae"],
    &["zoogloeae"],
];

pub(crate) static ENTRY_ZOOGLEAL_8144222639814201645: VariantsMap = [
    &["zoogleal"],
    &["zoogloeal"],
    &["zoogloeal"],
    &["zoogloeal"],
];

pub(crate) static ENTRY_ZOOGLEAS_18230224253523630238: VariantsMap = [
    &["zoogleas"],
    &["zoogloeas"],
    &["zoogloeas"],
    &["zoogloeas"],
];

pub(crate) static ENTRY_ZOOGLEA_12784694771058649379: VariantsMap =
    [&["zooglea"], &["zoogloea"], &["zoogloea"], &["zoogloea"]];

pub(crate) static ENTRY_ZYGENID_6699911520066413279: VariantsMap =
    [&["zygenid"], &["zygaenid"], &["zygaenid"], &["zygaenid"]];
